// Note: For maximum-speed code, see "Optimizing Code" on the Emscripten wiki, https://github.com/kripken/emscripten/wiki/Optimizing-Code
// Note: Some Emscripten settings may limit the speed of the generated code.
// The Module object: Our interface to the outside world. We import
// and export values on it, and do the work to get that through
// closure compiler if necessary. There are various ways Module can be used:
// 1. Not defined. We create it here
// 2. A function parameter, function(Module) { ..generated code.. }
// 3. pre-run appended it, var Module = {}; ..generated code..
// 4. External script tag defines var Module.
// We need to do an eval in order to handle the closure compiler
// case, where this code here is minified but Module was defined
// elsewhere (e.g. case 4 above). We also need to check if Module
// already exists (e.g. case 3 above).
// Note that if you want to run closure, and also to use Module
// after the generated code, you will need to define   var Module = {};
// before the code. Then that object will be used in the code, and you
// can continue to use Module afterwards as well.
var Module;
if (!Module) Module = eval('(function() { try { return Module || {} } catch(e) { return {} } })()');
// Sometimes an existing Module object exists with properties
// meant to overwrite the default module functionality. Here
// we collect those properties and reapply _after_ we configure
// the current environment's defaults to avoid having to be so
// defensive during initialization.
var moduleOverrides = {};
for (var key in Module) {
  if (Module.hasOwnProperty(key)) {
    moduleOverrides[key] = Module[key];
  }
}
// The environment setup code below is customized to use Module.
// *** Environment setup code ***
var ENVIRONMENT_IS_NODE = typeof process === 'object' && typeof require === 'function';
var ENVIRONMENT_IS_WEB = typeof window === 'object';
var ENVIRONMENT_IS_WORKER = typeof importScripts === 'function';
var ENVIRONMENT_IS_SHELL = !ENVIRONMENT_IS_WEB && !ENVIRONMENT_IS_NODE && !ENVIRONMENT_IS_WORKER;
if (ENVIRONMENT_IS_NODE) {
  // Expose functionality in the same simple way that the shells work
  // Note that we pollute the global namespace here, otherwise we break in node
  Module['print'] = function(x) {
    process['stdout'].write(x + '\n');
  };
  Module['printErr'] = function(x) {
    process['stderr'].write(x + '\n');
  };
  var nodeFS = require('fs');
  var nodePath = require('path');
  Module['read'] = function(filename, binary) {
    filename = nodePath['normalize'](filename);
    var ret = nodeFS['readFileSync'](filename);
    // The path is absolute if the normalized version is the same as the resolved.
    if (!ret && filename != nodePath['resolve'](filename)) {
      filename = path.join(__dirname, '..', 'src', filename);
      ret = nodeFS['readFileSync'](filename);
    }
    if (ret && !binary) ret = ret.toString();
    return ret;
  };
  Module['readBinary'] = function(filename) { return Module['read'](filename, true) };
  Module['load'] = function(f) {
    globalEval(read(f));
  };
  Module['arguments'] = process['argv'].slice(2);
  module.exports = Module;
}
else if (ENVIRONMENT_IS_SHELL) {
  Module['print'] = print;
  if (typeof printErr != 'undefined') Module['printErr'] = printErr; // not present in v8 or older sm
  if (typeof read != 'undefined') {
    Module['read'] = read;
  } else {
    Module['read'] = function() { throw 'no read() available (jsc?)' };
  }
  Module['readBinary'] = function(f) {
    return read(f, 'binary');
  };
  if (typeof scriptArgs != 'undefined') {
    Module['arguments'] = scriptArgs;
  } else if (typeof arguments != 'undefined') {
    Module['arguments'] = arguments;
  }
  this['Module'] = Module;
}
else if (ENVIRONMENT_IS_WEB || ENVIRONMENT_IS_WORKER) {
  Module['read'] = function(url) {
    var xhr = new XMLHttpRequest();
    xhr.open('GET', url, false);
    xhr.send(null);
    return xhr.responseText;
  };
  if (typeof arguments != 'undefined') {
    Module['arguments'] = arguments;
  }
  if (ENVIRONMENT_IS_WEB) {
    Module['print'] = function(x) {
      console.log(x);
    };
    Module['printErr'] = function(x) {
      console.log(x);
    };
    this['Module'] = Module;
  } else if (ENVIRONMENT_IS_WORKER) {
    // We can do very little here...
    var TRY_USE_DUMP = false;
    Module['print'] = (TRY_USE_DUMP && (typeof(dump) !== "undefined") ? (function(x) {
      dump(x);
    }) : (function(x) {
      // self.postMessage(x); // enable this if you want stdout to be sent as messages
    }));
    Module['load'] = importScripts;
  }
}
else {
  // Unreachable because SHELL is dependant on the others
  throw 'Unknown runtime environment. Where are we?';
}
function globalEval(x) {
  eval.call(null, x);
}
if (!Module['load'] == 'undefined' && Module['read']) {
  Module['load'] = function(f) {
    globalEval(Module['read'](f));
  };
}
if (!Module['print']) {
  Module['print'] = function(){};
}
if (!Module['printErr']) {
  Module['printErr'] = Module['print'];
}
if (!Module['arguments']) {
  Module['arguments'] = [];
}
// *** Environment setup code ***
// Closure helpers
Module.print = Module['print'];
Module.printErr = Module['printErr'];
// Callbacks
Module['preRun'] = [];
Module['postRun'] = [];
// Merge back in the overrides
for (var key in moduleOverrides) {
  if (moduleOverrides.hasOwnProperty(key)) {
    Module[key] = moduleOverrides[key];
  }
}
// === Auto-generated preamble library stuff ===
//========================================
// Runtime code shared with compiler
//========================================
var Runtime = {
  stackSave: function () {
    return STACKTOP;
  },
  stackRestore: function (stackTop) {
    STACKTOP = stackTop;
  },
  forceAlign: function (target, quantum) {
    quantum = quantum || 4;
    if (quantum == 1) return target;
    if (isNumber(target) && isNumber(quantum)) {
      return Math.ceil(target/quantum)*quantum;
    } else if (isNumber(quantum) && isPowerOfTwo(quantum)) {
      var logg = log2(quantum);
      return '((((' +target + ')+' + (quantum-1) + ')>>' + logg + ')<<' + logg + ')';
    }
    return 'Math.ceil((' + target + ')/' + quantum + ')*' + quantum;
  },
  isNumberType: function (type) {
    return type in Runtime.INT_TYPES || type in Runtime.FLOAT_TYPES;
  },
  isPointerType: function isPointerType(type) {
  return type[type.length-1] == '*';
},
  isStructType: function isStructType(type) {
  if (isPointerType(type)) return false;
  if (isArrayType(type)) return true;
  if (/<?{ ?[^}]* ?}>?/.test(type)) return true; // { i32, i8 } etc. - anonymous struct types
  // See comment in isStructPointerType()
  return type[0] == '%';
},
  INT_TYPES: {"i1":0,"i8":0,"i16":0,"i32":0,"i64":0},
  FLOAT_TYPES: {"float":0,"double":0},
  or64: function (x, y) {
    var l = (x | 0) | (y | 0);
    var h = (Math.round(x / 4294967296) | Math.round(y / 4294967296)) * 4294967296;
    return l + h;
  },
  and64: function (x, y) {
    var l = (x | 0) & (y | 0);
    var h = (Math.round(x / 4294967296) & Math.round(y / 4294967296)) * 4294967296;
    return l + h;
  },
  xor64: function (x, y) {
    var l = (x | 0) ^ (y | 0);
    var h = (Math.round(x / 4294967296) ^ Math.round(y / 4294967296)) * 4294967296;
    return l + h;
  },
  getNativeTypeSize: function (type, quantumSize) {
    if (Runtime.QUANTUM_SIZE == 1) return 1;
    var size = {
      '%i1': 1,
      '%i8': 1,
      '%i16': 2,
      '%i32': 4,
      '%i64': 8,
      "%float": 4,
      "%double": 8
    }['%'+type]; // add '%' since float and double confuse Closure compiler as keys, and also spidermonkey as a compiler will remove 's from '_i8' etc
    if (!size) {
      if (type.charAt(type.length-1) == '*') {
        size = Runtime.QUANTUM_SIZE; // A pointer
      } else if (type[0] == 'i') {
        var bits = parseInt(type.substr(1));
        assert(bits % 8 == 0);
        size = bits/8;
      }
    }
    return size;
  },
  getNativeFieldSize: function (type) {
    return Math.max(Runtime.getNativeTypeSize(type), Runtime.QUANTUM_SIZE);
  },
  dedup: function dedup(items, ident) {
  var seen = {};
  if (ident) {
    return items.filter(function(item) {
      if (seen[item[ident]]) return false;
      seen[item[ident]] = true;
      return true;
    });
  } else {
    return items.filter(function(item) {
      if (seen[item]) return false;
      seen[item] = true;
      return true;
    });
  }
},
  set: function set() {
  var args = typeof arguments[0] === 'object' ? arguments[0] : arguments;
  var ret = {};
  for (var i = 0; i < args.length; i++) {
    ret[args[i]] = 0;
  }
  return ret;
},
  STACK_ALIGN: 8,
  getAlignSize: function (type, size, vararg) {
    // we align i64s and doubles on 64-bit boundaries, unlike x86
    if (type == 'i64' || type == 'double' || vararg) return 8;
    if (!type) return Math.min(size, 8); // align structures internally to 64 bits
    return Math.min(size || (type ? Runtime.getNativeFieldSize(type) : 0), Runtime.QUANTUM_SIZE);
  },
  calculateStructAlignment: function calculateStructAlignment(type) {
    type.flatSize = 0;
    type.alignSize = 0;
    var diffs = [];
    var prev = -1;
    var index = 0;
    type.flatIndexes = type.fields.map(function(field) {
      index++;
      var size, alignSize;
      if (Runtime.isNumberType(field) || Runtime.isPointerType(field)) {
        size = Runtime.getNativeTypeSize(field); // pack char; char; in structs, also char[X]s.
        alignSize = Runtime.getAlignSize(field, size);
      } else if (Runtime.isStructType(field)) {
        if (field[1] === '0') {
          // this is [0 x something]. When inside another structure like here, it must be at the end,
          // and it adds no size
          // XXX this happens in java-nbody for example... assert(index === type.fields.length, 'zero-length in the middle!');
          size = 0;
          alignSize = type.alignSize || QUANTUM_SIZE;
        } else {
          size = Types.types[field].flatSize;
          alignSize = Runtime.getAlignSize(null, Types.types[field].alignSize);
        }
      } else if (field[0] == 'b') {
        // bN, large number field, like a [N x i8]
        size = field.substr(1)|0;
        alignSize = 1;
      } else {
        throw 'Unclear type in struct: ' + field + ', in ' + type.name_ + ' :: ' + dump(Types.types[type.name_]);
      }
      if (type.packed) alignSize = 1;
      type.alignSize = Math.max(type.alignSize, alignSize);
      var curr = Runtime.alignMemory(type.flatSize, alignSize); // if necessary, place this on aligned memory
      type.flatSize = curr + size;
      if (prev >= 0) {
        diffs.push(curr-prev);
      }
      prev = curr;
      return curr;
    });
    type.flatSize = Runtime.alignMemory(type.flatSize, type.alignSize);
    if (diffs.length == 0) {
      type.flatFactor = type.flatSize;
    } else if (Runtime.dedup(diffs).length == 1) {
      type.flatFactor = diffs[0];
    }
    type.needsFlattening = (type.flatFactor != 1);
    return type.flatIndexes;
  },
  generateStructInfo: function (struct, typeName, offset) {
    var type, alignment;
    if (typeName) {
      offset = offset || 0;
      type = (typeof Types === 'undefined' ? Runtime.typeInfo : Types.types)[typeName];
      if (!type) return null;
      if (type.fields.length != struct.length) {
        printErr('Number of named fields must match the type for ' + typeName + ': possibly duplicate struct names. Cannot return structInfo');
        return null;
      }
      alignment = type.flatIndexes;
    } else {
      var type = { fields: struct.map(function(item) { return item[0] }) };
      alignment = Runtime.calculateStructAlignment(type);
    }
    var ret = {
      __size__: type.flatSize
    };
    if (typeName) {
      struct.forEach(function(item, i) {
        if (typeof item === 'string') {
          ret[item] = alignment[i] + offset;
        } else {
          // embedded struct
          var key;
          for (var k in item) key = k;
          ret[key] = Runtime.generateStructInfo(item[key], type.fields[i], alignment[i]);
        }
      });
    } else {
      struct.forEach(function(item, i) {
        ret[item[1]] = alignment[i];
      });
    }
    return ret;
  },
  dynCall: function (sig, ptr, args) {
    if (args && args.length) {
      if (!args.splice) args = Array.prototype.slice.call(args);
      args.splice(0, 0, ptr);
      return Module['dynCall_' + sig].apply(null, args);
    } else {
      return Module['dynCall_' + sig].call(null, ptr);
    }
  },
  functionPointers: [],
  addFunction: function (func) {
    for (var i = 0; i < Runtime.functionPointers.length; i++) {
      if (!Runtime.functionPointers[i]) {
        Runtime.functionPointers[i] = func;
        return 2 + 2*i;
      }
    }
    throw 'Finished up all reserved function pointers. Use a higher value for RESERVED_FUNCTION_POINTERS.';
  },
  removeFunction: function (index) {
    Runtime.functionPointers[(index-2)/2] = null;
  },
  warnOnce: function (text) {
    if (!Runtime.warnOnce.shown) Runtime.warnOnce.shown = {};
    if (!Runtime.warnOnce.shown[text]) {
      Runtime.warnOnce.shown[text] = 1;
      Module.printErr(text);
    }
  },
  funcWrappers: {},
  getFuncWrapper: function (func, sig) {
    assert(sig);
    if (!Runtime.funcWrappers[func]) {
      Runtime.funcWrappers[func] = function() {
        return Runtime.dynCall(sig, func, arguments);
      };
    }
    return Runtime.funcWrappers[func];
  },
  UTF8Processor: function () {
    var buffer = [];
    var needed = 0;
    this.processCChar = function (code) {
      code = code & 0xFF;
      if (buffer.length == 0) {
        if ((code & 0x80) == 0x00) {        // 0xxxxxxx
          return String.fromCharCode(code);
        }
        buffer.push(code);
        if ((code & 0xE0) == 0xC0) {        // 110xxxxx
          needed = 1;
        } else if ((code & 0xF0) == 0xE0) { // 1110xxxx
          needed = 2;
        } else {                            // 11110xxx
          needed = 3;
        }
        return '';
      }
      if (needed) {
        buffer.push(code);
        needed--;
        if (needed > 0) return '';
      }
      var c1 = buffer[0];
      var c2 = buffer[1];
      var c3 = buffer[2];
      var c4 = buffer[3];
      var ret;
      if (buffer.length == 2) {
        ret = String.fromCharCode(((c1 & 0x1F) << 6)  | (c2 & 0x3F));
      } else if (buffer.length == 3) {
        ret = String.fromCharCode(((c1 & 0x0F) << 12) | ((c2 & 0x3F) << 6)  | (c3 & 0x3F));
      } else {
        // http://mathiasbynens.be/notes/javascript-encoding#surrogate-formulae
        var codePoint = ((c1 & 0x07) << 18) | ((c2 & 0x3F) << 12) |
                        ((c3 & 0x3F) << 6)  | (c4 & 0x3F);
        ret = String.fromCharCode(
          Math.floor((codePoint - 0x10000) / 0x400) + 0xD800,
          (codePoint - 0x10000) % 0x400 + 0xDC00);
      }
      buffer.length = 0;
      return ret;
    }
    this.processJSString = function(string) {
      string = unescape(encodeURIComponent(string));
      var ret = [];
      for (var i = 0; i < string.length; i++) {
        ret.push(string.charCodeAt(i));
      }
      return ret;
    }
  },
  stackAlloc: function (size) { var ret = STACKTOP;STACKTOP = (STACKTOP + size)|0;STACKTOP = ((((STACKTOP)+7)>>3)<<3); return ret; },
  staticAlloc: function (size) { var ret = STATICTOP;STATICTOP = (STATICTOP + size)|0;STATICTOP = ((((STATICTOP)+7)>>3)<<3); return ret; },
  dynamicAlloc: function (size) { var ret = DYNAMICTOP;DYNAMICTOP = (DYNAMICTOP + size)|0;DYNAMICTOP = ((((DYNAMICTOP)+7)>>3)<<3); if (DYNAMICTOP >= TOTAL_MEMORY) enlargeMemory();; return ret; },
  alignMemory: function (size,quantum) { var ret = size = Math.ceil((size)/(quantum ? quantum : 8))*(quantum ? quantum : 8); return ret; },
  makeBigInt: function (low,high,unsigned) { var ret = (unsigned ? ((+(((low)>>>(0))))+((+(((high)>>>(0))))*(+(4294967296)))) : ((+(((low)>>>(0))))+((+(((high)|(0))))*(+(4294967296))))); return ret; },
  GLOBAL_BASE: 8,
  QUANTUM_SIZE: 4,
  __dummy__: 0
}
//========================================
// Runtime essentials
//========================================
var __THREW__ = 0; // Used in checking for thrown exceptions.
var ABORT = false; // whether we are quitting the application. no code should run after this. set in exit() and abort()
var EXITSTATUS = 0;
var undef = 0;
// tempInt is used for 32-bit signed values or smaller. tempBigInt is used
// for 32-bit unsigned values or more than 32 bits. TODO: audit all uses of tempInt
var tempValue, tempInt, tempBigInt, tempInt2, tempBigInt2, tempPair, tempBigIntI, tempBigIntR, tempBigIntS, tempBigIntP, tempBigIntD;
var tempI64, tempI64b;
var tempRet0, tempRet1, tempRet2, tempRet3, tempRet4, tempRet5, tempRet6, tempRet7, tempRet8, tempRet9;
function assert(condition, text) {
  if (!condition) {
    abort('Assertion failed: ' + text);
  }
}
var globalScope = this;
// C calling interface. A convenient way to call C functions (in C files, or
// defined with extern "C").
//
// Note: LLVM optimizations can inline and remove functions, after which you will not be
//       able to call them. Closure can also do so. To avoid that, add your function to
//       the exports using something like
//
//         -s EXPORTED_FUNCTIONS='["_main", "_myfunc"]'
//
// @param ident      The name of the C function (note that C++ functions will be name-mangled - use extern "C")
// @param returnType The return type of the function, one of the JS types 'number', 'string' or 'array' (use 'number' for any C pointer, and
//                   'array' for JavaScript arrays and typed arrays; note that arrays are 8-bit).
// @param argTypes   An array of the types of arguments for the function (if there are no arguments, this can be ommitted). Types are as in returnType,
//                   except that 'array' is not possible (there is no way for us to know the length of the array)
// @param args       An array of the arguments to the function, as native JS values (as in returnType)
//                   Note that string arguments will be stored on the stack (the JS string will become a C string on the stack).
// @return           The return value, as a native JS value (as in returnType)
function ccall(ident, returnType, argTypes, args) {
  return ccallFunc(getCFunc(ident), returnType, argTypes, args);
}
Module["ccall"] = ccall;
// Returns the C function with a specified identifier (for C++, you need to do manual name mangling)
function getCFunc(ident) {
  try {
    var func = Module['_' + ident]; // closure exported function
    if (!func) func = eval('_' + ident); // explicit lookup
  } catch(e) {
  }
  assert(func, 'Cannot call unknown function ' + ident + ' (perhaps LLVM optimizations or closure removed it?)');
  return func;
}
// Internal function that does a C call using a function, not an identifier
function ccallFunc(func, returnType, argTypes, args) {
  var stack = 0;
  function toC(value, type) {
    if (type == 'string') {
      if (value === null || value === undefined || value === 0) return 0; // null string
      if (!stack) stack = Runtime.stackSave();
      var ret = Runtime.stackAlloc(value.length+1);
      writeStringToMemory(value, ret);
      return ret;
    } else if (type == 'array') {
      if (!stack) stack = Runtime.stackSave();
      var ret = Runtime.stackAlloc(value.length);
      writeArrayToMemory(value, ret);
      return ret;
    }
    return value;
  }
  function fromC(value, type) {
    if (type == 'string') {
      return Pointer_stringify(value);
    }
    assert(type != 'array');
    return value;
  }
  var i = 0;
  var cArgs = args ? args.map(function(arg) {
    return toC(arg, argTypes[i++]);
  }) : [];
  var ret = fromC(func.apply(null, cArgs), returnType);
  if (stack) Runtime.stackRestore(stack);
  return ret;
}
// Returns a native JS wrapper for a C function. This is similar to ccall, but
// returns a function you can call repeatedly in a normal way. For example:
//
//   var my_function = cwrap('my_c_function', 'number', ['number', 'number']);
//   alert(my_function(5, 22));
//   alert(my_function(99, 12));
//
function cwrap(ident, returnType, argTypes) {
  var func = getCFunc(ident);
  return function() {
    return ccallFunc(func, returnType, argTypes, Array.prototype.slice.call(arguments));
  }
}
Module["cwrap"] = cwrap;
// Sets a value in memory in a dynamic way at run-time. Uses the
// type data. This is the same as makeSetValue, except that
// makeSetValue is done at compile-time and generates the needed
// code then, whereas this function picks the right code at
// run-time.
// Note that setValue and getValue only do *aligned* writes and reads!
// Note that ccall uses JS types as for defining types, while setValue and
// getValue need LLVM types ('i8', 'i32') - this is a lower-level operation
function setValue(ptr, value, type, noSafe) {
  type = type || 'i8';
  if (type.charAt(type.length-1) === '*') type = 'i32'; // pointers are 32-bit
    switch(type) {
      case 'i1': HEAP8[(ptr)]=value; break;
      case 'i8': HEAP8[(ptr)]=value; break;
      case 'i16': HEAP16[((ptr)>>1)]=value; break;
      case 'i32': HEAP32[((ptr)>>2)]=value; break;
      case 'i64': (tempI64 = [value>>>0,(tempDouble=value,(+(Math.abs(tempDouble))) >= (+(1)) ? (tempDouble > (+(0)) ? ((Math.min((+(Math.floor((tempDouble)/(+(4294967296))))), (+(4294967295))))|0)>>>0 : (~~((+(Math.ceil((tempDouble - +(((~~(tempDouble)))>>>0))/(+(4294967296)))))))>>>0) : 0)],HEAP32[((ptr)>>2)]=tempI64[0],HEAP32[(((ptr)+(4))>>2)]=tempI64[1]); break;
      case 'float': HEAPF32[((ptr)>>2)]=value; break;
      case 'double': HEAPF64[((ptr)>>3)]=value; break;
      default: abort('invalid type for setValue: ' + type);
    }
}
Module['setValue'] = setValue;
// Parallel to setValue.
function getValue(ptr, type, noSafe) {
  type = type || 'i8';
  if (type.charAt(type.length-1) === '*') type = 'i32'; // pointers are 32-bit
    switch(type) {
      case 'i1': return HEAP8[(ptr)];
      case 'i8': return HEAP8[(ptr)];
      case 'i16': return HEAP16[((ptr)>>1)];
      case 'i32': return HEAP32[((ptr)>>2)];
      case 'i64': return HEAP32[((ptr)>>2)];
      case 'float': return HEAPF32[((ptr)>>2)];
      case 'double': return HEAPF64[((ptr)>>3)];
      default: abort('invalid type for setValue: ' + type);
    }
  return null;
}
Module['getValue'] = getValue;
var ALLOC_NORMAL = 0; // Tries to use _malloc()
var ALLOC_STACK = 1; // Lives for the duration of the current function call
var ALLOC_STATIC = 2; // Cannot be freed
var ALLOC_DYNAMIC = 3; // Cannot be freed except through sbrk
var ALLOC_NONE = 4; // Do not allocate
Module['ALLOC_NORMAL'] = ALLOC_NORMAL;
Module['ALLOC_STACK'] = ALLOC_STACK;
Module['ALLOC_STATIC'] = ALLOC_STATIC;
Module['ALLOC_DYNAMIC'] = ALLOC_DYNAMIC;
Module['ALLOC_NONE'] = ALLOC_NONE;
// allocate(): This is for internal use. You can use it yourself as well, but the interface
//             is a little tricky (see docs right below). The reason is that it is optimized
//             for multiple syntaxes to save space in generated code. So you should
//             normally not use allocate(), and instead allocate memory using _malloc(),
//             initialize it with setValue(), and so forth.
// @slab: An array of data, or a number. If a number, then the size of the block to allocate,
//        in *bytes* (note that this is sometimes confusing: the next parameter does not
//        affect this!)
// @types: Either an array of types, one for each byte (or 0 if no type at that position),
//         or a single type which is used for the entire block. This only matters if there
//         is initial data - if @slab is a number, then this does not matter at all and is
//         ignored.
// @allocator: How to allocate memory, see ALLOC_*
function allocate(slab, types, allocator, ptr) {
  var zeroinit, size;
  if (typeof slab === 'number') {
    zeroinit = true;
    size = slab;
  } else {
    zeroinit = false;
    size = slab.length;
  }
  var singleType = typeof types === 'string' ? types : null;
  var ret;
  if (allocator == ALLOC_NONE) {
    ret = ptr;
  } else {
    ret = [_malloc, Runtime.stackAlloc, Runtime.staticAlloc, Runtime.dynamicAlloc][allocator === undefined ? ALLOC_STATIC : allocator](Math.max(size, singleType ? 1 : types.length));
  }
  if (zeroinit) {
    var ptr = ret, stop;
    assert((ret & 3) == 0);
    stop = ret + (size & ~3);
    for (; ptr < stop; ptr += 4) {
      HEAP32[((ptr)>>2)]=0;
    }
    stop = ret + size;
    while (ptr < stop) {
      HEAP8[((ptr++)|0)]=0;
    }
    return ret;
  }
  if (singleType === 'i8') {
    if (slab.subarray || slab.slice) {
      HEAPU8.set(slab, ret);
    } else {
      HEAPU8.set(new Uint8Array(slab), ret);
    }
    return ret;
  }
  var i = 0, type, typeSize, previousType;
  while (i < size) {
    var curr = slab[i];
    if (typeof curr === 'function') {
      curr = Runtime.getFunctionIndex(curr);
    }
    type = singleType || types[i];
    if (type === 0) {
      i++;
      continue;
    }
    if (type == 'i64') type = 'i32'; // special case: we have one i32 here, and one i32 later
    setValue(ret+i, curr, type);
    // no need to look up size unless type changes, so cache it
    if (previousType !== type) {
      typeSize = Runtime.getNativeTypeSize(type);
      previousType = type;
    }
    i += typeSize;
  }
  return ret;
}
Module['allocate'] = allocate;
function Pointer_stringify(ptr, /* optional */ length) {
  // TODO: use TextDecoder
  // Find the length, and check for UTF while doing so
  var hasUtf = false;
  var t;
  var i = 0;
  while (1) {
    t = HEAPU8[(((ptr)+(i))|0)];
    if (t >= 128) hasUtf = true;
    else if (t == 0 && !length) break;
    i++;
    if (length && i == length) break;
  }
  if (!length) length = i;
  var ret = '';
  if (!hasUtf) {
    var MAX_CHUNK = 1024; // split up into chunks, because .apply on a huge string can overflow the stack
    var curr;
    while (length > 0) {
      curr = String.fromCharCode.apply(String, HEAPU8.subarray(ptr, ptr + Math.min(length, MAX_CHUNK)));
      ret = ret ? ret + curr : curr;
      ptr += MAX_CHUNK;
      length -= MAX_CHUNK;
    }
    return ret;
  }
  var utf8 = new Runtime.UTF8Processor();
  for (i = 0; i < length; i++) {
    t = HEAPU8[(((ptr)+(i))|0)];
    ret += utf8.processCChar(t);
  }
  return ret;
}
Module['Pointer_stringify'] = Pointer_stringify;
// Memory management
var PAGE_SIZE = 4096;
function alignMemoryPage(x) {
  return ((x+4095)>>12)<<12;
}
var HEAP;
var HEAP8, HEAPU8, HEAP16, HEAPU16, HEAP32, HEAPU32, HEAPF32, HEAPF64;
var STATIC_BASE = 0, STATICTOP = 0, staticSealed = false; // static area
var STACK_BASE = 0, STACKTOP = 0, STACK_MAX = 0; // stack area
var DYNAMIC_BASE = 0, DYNAMICTOP = 0; // dynamic area handled by sbrk
function enlargeMemory() {
  abort('Cannot enlarge memory arrays in asm.js. Either (1) compile with -s TOTAL_MEMORY=X with X higher than the current value, or (2) set Module.TOTAL_MEMORY before the program runs.');
}
var TOTAL_STACK = Module['TOTAL_STACK'] || 5242880;
var TOTAL_MEMORY = Module['TOTAL_MEMORY'] || 67108864;
var FAST_MEMORY = Module['FAST_MEMORY'] || 2097152;
// Initialize the runtime's memory
// check for full engine support (use string 'subarray' to avoid closure compiler confusion)
assert(!!Int32Array && !!Float64Array && !!(new Int32Array(1)['subarray']) && !!(new Int32Array(1)['set']),
       'Cannot fallback to non-typed array case: Code is too specialized');
var buffer = new ArrayBuffer(TOTAL_MEMORY);
HEAP8 = new Int8Array(buffer);
HEAP16 = new Int16Array(buffer);
HEAP32 = new Int32Array(buffer);
HEAPU8 = new Uint8Array(buffer);
HEAPU16 = new Uint16Array(buffer);
HEAPU32 = new Uint32Array(buffer);
HEAPF32 = new Float32Array(buffer);
HEAPF64 = new Float64Array(buffer);
// Endianness check (note: assumes compiler arch was little-endian)
HEAP32[0] = 255;
assert(HEAPU8[0] === 255 && HEAPU8[3] === 0, 'Typed arrays 2 must be run on a little-endian system');
Module['HEAP'] = HEAP;
Module['HEAP8'] = HEAP8;
Module['HEAP16'] = HEAP16;
Module['HEAP32'] = HEAP32;
Module['HEAPU8'] = HEAPU8;
Module['HEAPU16'] = HEAPU16;
Module['HEAPU32'] = HEAPU32;
Module['HEAPF32'] = HEAPF32;
Module['HEAPF64'] = HEAPF64;
function callRuntimeCallbacks(callbacks) {
  while(callbacks.length > 0) {
    var callback = callbacks.shift();
    if (typeof callback == 'function') {
      callback();
      continue;
    }
    var func = callback.func;
    if (typeof func === 'number') {
      if (callback.arg === undefined) {
        Runtime.dynCall('v', func);
      } else {
        Runtime.dynCall('vi', func, [callback.arg]);
      }
    } else {
      func(callback.arg === undefined ? null : callback.arg);
    }
  }
}
var __ATPRERUN__  = []; // functions called before the runtime is initialized
var __ATINIT__    = []; // functions called during startup
var __ATMAIN__    = []; // functions called when main() is to be run
var __ATEXIT__    = []; // functions called during shutdown
var __ATPOSTRUN__ = []; // functions called after the runtime has exited
var runtimeInitialized = false;
function preRun() {
  // compatibility - merge in anything from Module['preRun'] at this time
  if (Module['preRun']) {
    if (typeof Module['preRun'] == 'function') Module['preRun'] = [Module['preRun']];
    while (Module['preRun'].length) {
      addOnPreRun(Module['preRun'].shift());
    }
  }
  callRuntimeCallbacks(__ATPRERUN__);
}
function ensureInitRuntime() {
  if (runtimeInitialized) return;
  runtimeInitialized = true;
  callRuntimeCallbacks(__ATINIT__);
}
function preMain() {
  callRuntimeCallbacks(__ATMAIN__);
}
function exitRuntime() {
  callRuntimeCallbacks(__ATEXIT__);
}
function postRun() {
  // compatibility - merge in anything from Module['postRun'] at this time
  if (Module['postRun']) {
    if (typeof Module['postRun'] == 'function') Module['postRun'] = [Module['postRun']];
    while (Module['postRun'].length) {
      addOnPostRun(Module['postRun'].shift());
    }
  }
  callRuntimeCallbacks(__ATPOSTRUN__);
}
function addOnPreRun(cb) {
  __ATPRERUN__.unshift(cb);
}
Module['addOnPreRun'] = Module.addOnPreRun = addOnPreRun;
function addOnInit(cb) {
  __ATINIT__.unshift(cb);
}
Module['addOnInit'] = Module.addOnInit = addOnInit;
function addOnPreMain(cb) {
  __ATMAIN__.unshift(cb);
}
Module['addOnPreMain'] = Module.addOnPreMain = addOnPreMain;
function addOnExit(cb) {
  __ATEXIT__.unshift(cb);
}
Module['addOnExit'] = Module.addOnExit = addOnExit;
function addOnPostRun(cb) {
  __ATPOSTRUN__.unshift(cb);
}
Module['addOnPostRun'] = Module.addOnPostRun = addOnPostRun;
// Tools
// This processes a JS string into a C-line array of numbers, 0-terminated.
// For LLVM-originating strings, see parser.js:parseLLVMString function
function intArrayFromString(stringy, dontAddNull, length /* optional */) {
  var ret = (new Runtime.UTF8Processor()).processJSString(stringy);
  if (length) {
    ret.length = length;
  }
  if (!dontAddNull) {
    ret.push(0);
  }
  return ret;
}
Module['intArrayFromString'] = intArrayFromString;
function intArrayToString(array) {
  var ret = [];
  for (var i = 0; i < array.length; i++) {
    var chr = array[i];
    if (chr > 0xFF) {
      chr &= 0xFF;
    }
    ret.push(String.fromCharCode(chr));
  }
  return ret.join('');
}
Module['intArrayToString'] = intArrayToString;
// Write a Javascript array to somewhere in the heap
function writeStringToMemory(string, buffer, dontAddNull) {
  var array = intArrayFromString(string, dontAddNull);
  var i = 0;
  while (i < array.length) {
    var chr = array[i];
    HEAP8[(((buffer)+(i))|0)]=chr
    i = i + 1;
  }
}
Module['writeStringToMemory'] = writeStringToMemory;
function writeArrayToMemory(array, buffer) {
  for (var i = 0; i < array.length; i++) {
    HEAP8[(((buffer)+(i))|0)]=array[i];
  }
}
Module['writeArrayToMemory'] = writeArrayToMemory;
function unSign(value, bits, ignore, sig) {
  if (value >= 0) {
    return value;
  }
  return bits <= 32 ? 2*Math.abs(1 << (bits-1)) + value // Need some trickery, since if bits == 32, we are right at the limit of the bits JS uses in bitshifts
                    : Math.pow(2, bits)         + value;
}
function reSign(value, bits, ignore, sig) {
  if (value <= 0) {
    return value;
  }
  var half = bits <= 32 ? Math.abs(1 << (bits-1)) // abs is needed if bits == 32
                        : Math.pow(2, bits-1);
  if (value >= half && (bits <= 32 || value > half)) { // for huge values, we can hit the precision limit and always get true here. so don't do that
                                                       // but, in general there is no perfect solution here. With 64-bit ints, we get rounding and errors
                                                       // TODO: In i64 mode 1, resign the two parts separately and safely
    value = -2*half + value; // Cannot bitshift half, as it may be at the limit of the bits JS uses in bitshifts
  }
  return value;
}
if (!Math['imul']) Math['imul'] = function(a, b) {
  var ah  = a >>> 16;
  var al = a & 0xffff;
  var bh  = b >>> 16;
  var bl = b & 0xffff;
  return (al*bl + ((ah*bl + al*bh) << 16))|0;
};
Math.imul = Math['imul'];
// A counter of dependencies for calling run(). If we need to
// do asynchronous work before running, increment this and
// decrement it. Incrementing must happen in a place like
// PRE_RUN_ADDITIONS (used by emcc to add file preloading).
// Note that you can add dependencies in preRun, even though
// it happens right before run - run will be postponed until
// the dependencies are met.
var runDependencies = 0;
var runDependencyTracking = {};
var calledInit = false, calledRun = false;
var runDependencyWatcher = null;
function addRunDependency(id) {
  runDependencies++;
  if (Module['monitorRunDependencies']) {
    Module['monitorRunDependencies'](runDependencies);
  }
  if (id) {
    assert(!runDependencyTracking[id]);
    runDependencyTracking[id] = 1;
  } else {
    Module.printErr('warning: run dependency added without ID');
  }
}
Module['addRunDependency'] = addRunDependency;
function removeRunDependency(id) {
  runDependencies--;
  if (Module['monitorRunDependencies']) {
    Module['monitorRunDependencies'](runDependencies);
  }
  if (id) {
    assert(runDependencyTracking[id]);
    delete runDependencyTracking[id];
  } else {
    Module.printErr('warning: run dependency removed without ID');
  }
  if (runDependencies == 0) {
    if (runDependencyWatcher !== null) {
      clearInterval(runDependencyWatcher);
      runDependencyWatcher = null;
    } 
    // If run has never been called, and we should call run (INVOKE_RUN is true, and Module.noInitialRun is not false)
    if (!calledRun && shouldRunNow) run();
  }
}
Module['removeRunDependency'] = removeRunDependency;
Module["preloadedImages"] = {}; // maps url to image data
Module["preloadedAudios"] = {}; // maps url to audio data
function loadMemoryInitializer(filename) {
  function applyData(data) {
    HEAPU8.set(data, STATIC_BASE);
  }
  // always do this asynchronously, to keep shell and web as similar as possible
  addOnPreRun(function() {
    if (ENVIRONMENT_IS_NODE || ENVIRONMENT_IS_SHELL) {
      applyData(Module['readBinary'](filename));
    } else {
      Browser.asyncLoad(filename, function(data) {
        applyData(data);
      }, function(data) {
        throw 'could not load memory initializer ' + filename;
      });
    }
  });
}
// === Body ===
STATIC_BASE = 8;
STATICTOP = STATIC_BASE + 1394552;
/* global initializers */ __ATINIT__.push({ func: function() { runPostSets() } });
var _stdout;
var _stderr;
var _stdout = _stdout=allocate([0,0,0,0,0,0,0,0], "i8", ALLOC_STATIC);
var _stderr = _stderr=allocate([0,0,0,0,0,0,0,0], "i8", ALLOC_STATIC);
/* memory initializer */ allocate([0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,0,0,128,63,8,0,0,0,4,0,0,0,72,0,0,0,82,0,0,0,34,0,0,0,30,0,0,0,112,0,0,0,120,1,1,0,36,5,0,0,148,2,0,0,2,0,0,0,114,0,0,0,40,0,0,0,38,0,0,0,112,0,0,0,0,0,0,0,0,0,0,0,0,0,128,63,0,0,128,63,0,0,128,63,0,0,0,0,0,0,0,0,0,0,128,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,63,0,0,0,0,0,0,0,0,0,0,128,63,0,0,128,63,0,0,128,63,11,0,0,0,10,0,0,0,9,0,0,0,8,0,0,0,7,0,0,0,6,0,0,0,5,0,0,0,4,0,0,0,3,0,0,0,2,0,0,0,1,0,0,0,0,0,0,0,24,139,8,0,216,147,8,0,1,1,0,0,1,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,3,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,17,18,0,8,7,9,6,10,5,11,4,12,3,13,2,14,1,15,0,0,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,9,0,0,0,10,0,0,0,11,0,0,0,13,0,0,0,15,0,0,0,17,0,0,0,19,0,0,0,23,0,0,0,27,0,0,0,31,0,0,0,35,0,0,0,43,0,0,0,51,0,0,0,59,0,0,0,67,0,0,0,83,0,0,0,99,0,0,0,115,0,0,0,131,0,0,0,163,0,0,0,195,0,0,0,227,0,0,0,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,3,0,0,0,3,0,0,0,4,0,0,0,4,0,0,0,5,0,0,0,5,0,0,0,6,0,0,0,6,0,0,0,7,0,0,0,7,0,0,0,8,0,0,0,8,0,0,0,9,0,0,0,9,0,0,0,10,0,0,0,10,0,0,0,11,0,0,0,11,0,0,0,12,0,0,0,12,0,0,0,13,0,0,0,13,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,4,0,0,0,5,0,0,0,7,0,0,0,9,0,0,0,13,0,0,0,17,0,0,0,25,0,0,0,33,0,0,0,49,0,0,0,65,0,0,0,97,0,0,0,129,0,0,0,193,0,0,0,1,1,0,0,129,1,0,0,1,2,0,0,1,3,0,0,1,4,0,0,1,6,0,0,1,8,0,0,1,12,0,0,1,16,0,0,1,24,0,0,1,32,0,0,1,48,0,0,1,64,0,0,1,96,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,63,0,0,0,0,0,0,0,0,0,0,128,63,0,0,128,63,0,0,128,63,160,228,0,0,0,0,0,0,232,142,0,0,1,0,0,0,88,223,0,0,2,0,0,0,72,220,0,0,3,0,0,0,208,215,0,0,4,0,0,0,96,212,0,0,5,0,0,0,232,208,0,0,6,0,0,0,144,205,0,0,7,0,0,0,64,202,0,0,8,0,0,0,32,153,0,0,9,0,0,0,176,195,0,0,10,0,0,0,224,48,1,0,11,0,0,0,184,188,0,0,12,0,0,0,224,184,0,0,13,0,0,0,88,179,0,0,14,0,0,0,0,177,0,0,15,0,0,0,192,174,0,0,16,0,0,0,200,171,0,0,17,0,0,0,32,169,0,0,18,0,0,0,104,166,0,0,19,0,0,0,56,164,0,0,20,0,0,0,152,161,0,0,21,0,0,0,104,160,0,0,22,0,0,0,184,157,0,0,23,0,0,0,88,154,0,0,24,0,0,0,0,152,0,0,25,0,0,0,144,149,0,0,26,0,0,0,72,148,0,0,27,0,0,0,96,147,0,0,28,0,0,0,32,146,0,0,29,0,0,0,176,144,0,0,30,0,0,0,240,142,0,0,31,0,0,0,104,141,0,0,32,0,0,0,136,139,0,0,33,0,0,0,224,136,0,0,34,0,0,0,64,135,0,0,35,0,0,0,168,133,0,0,36,0,0,0,184,131,0,0,37,0,0,0,112,130,0,0,38,0,0,0,160,128,0,0,39,0,0,0,0,127,0,0,40,0,0,0,200,124,0,0,41,0,0,0,72,123,0,0,42,0,0,0,128,121,0,0,43,0,0,0,32,119,0,0,44,0,0,0,160,117,0,0,45,0,0,0,40,116,0,0,46,0,0,0,120,114,0,0,47,0,0,0,72,113,0,0,48,0,0,0,0,112,0,0,49,0,0,0,232,110,0,0,50,0,0,0,112,109,0,0,51,0,0,0,224,107,0,0,52,0,0,0,128,106,0,0,53,0,0,0,160,103,0,0,54,0,0,0,0,102,0,0,55,0,0,0,77,97,112,95,83,117,102,97,109,105,84,117,114,98,111,76,111,82,79,77,77,97,112,0,77,97,112,95,82,79,77,50,52,77,66,83,76,111,82,79,77,77,97,112,0,0,0,0,77,97,112,95,78,111,77,65,68,49,76,111,82,79,77,77,97,112,0,0,0,0,0,0,77,97,112,95,83,68,68,49,76,111,82,79,77,77,97,112,0,0,0,0,0,0,0,0,77,97,112,95,83,65,49,76,111,82,79,77,77,97,112,0,77,97,112,95,83,117,112,101,114,70,88,76,111,82,79,77,77,97,112,0,0,0,0,0,77,97,112,95,83,101,116,97,68,83,80,76,111,82,79,77,77,97,112,0,0,0,0,0,77,97,112,95,83,97,109,101,71,97,109,101,72,105,82,79,77,77,97,112,0,0,0,0,65,112,112,108,105,101,100,32,85,110,105,114,97,99,101,114,115,32,104,97,99,107,46,0,73,110,118,97,108,105,100,32,86,82,65,77,32,97,99,99,101,115,115,32,104,97,99,107,0,0,0,0,0,0,0,0,77,97,112,95,76,111,82,79,77,77,97,112,0,0,0,0,77,97,112,95,83,82,65,77,53,49,50,75,76,111,82,79,77,77,97,112,0,0,0,0,77,97,112,95,74,117,109,98,111,76,111,82,79,77,77,97,112,0,0,0,0,0,0,0,77,97,112,95,72,105,82,79,77,77,97,112,0,0,0,0,66,83,58,32,83,105,122,101,32,109,105,115,109,97,116,99,104,0,0,0,0,0,0,0,77,97,112,95,83,117,102,97,109,105,84,117,114,98,111,80,115,101,117,100,111,76,111,82,79,77,77,97,112,0,0,0,77,97,112,95,69,120,116,101,110,100,101,100,72,105,82,79,77,77,97,112,0,0,0,0,77,97,112,95,83,80,67,55,49,49,48,72,105,82,79,77,77,97,112,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,64,0,32,0,16,0,8,0,4,0,2,0,1,128,0,64,0,32,0,16,0,2,0,0,0,124,0,0,0,6,0,0,0,160,76,1,0,128,64,96,32,112,48,80,16,120,56,88,24,104,40,72,8,124,60,92,28,108,44,76,12,116,52,84,20,100,36,68,4,126,62,94,30,110,46,78,14,118,54,86,22,102,38,70,6,122,58,90,26,106,42,74,10,114,50,82,18,98,34,66,2,127,63,95,31,111,47,79,15,119,55,87,23,103,39,71,7,123,59,91,27,107,43,75,11,115,51,83,19,99,35,67,3,125,61,93,29,109,45,77,13,117,53,85,21,101,37,69,5,121,57,89,25,105,41,73,9,113,49,81,17,97,33,65,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,78,111,114,109,97,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,57,48,32,100,101,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,49,56,48,32,100,101,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,50,55,48,32,100,101,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,5,0,0,0,2,0,0,0,1,1,0,0,4,1,0,0,4,2,0,0,4,3,0,0,4,0,0,0,0,0,0,0,5,0,0,0,1,0,0,0,6,0,0,0,2,0,0,0,7,0,0,0,3,0,0,0,8,0,0,0,4,0,0,0,0,0,0,0,5,0,0,0,3,0,0,0,6,0,0,0,2,0,0,0,7,0,0,0,24,139,8,0,0,0,0,0,4,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,8,0,0,0,0,0,0,0,9,0,0,0,1,0,0,0,3,0,0,0,2,0,0,0,10,0,0,0,11,0,0,0,12,0,0,0,13,0,0,0,14,0,0,0,15,0,0,0,24,31,1,0,160,48,12,0,200,108,1,0,168,48,12,0,88,0,1,0,96,48,12,0,136,216,0,0,48,48,12,0,112,180,0,0,80,48,12,0,64,155,0,0,16,48,12,0,160,137,0,0,136,48,12,0,168,119,0,0,32,48,12,0,88,104,0,0,24,48,12,0,32,88,0,0,208,48,12,0,120,135,1,0,224,48,12,0,160,118,1,0,216,48,12,0,144,102,1,0,152,48,12,0,232,88,1,0,232,48,12,0,168,76,1,0,176,48,12,0,24,63,1,0,144,48,12,0,176,49,1,0,88,48,12,0,40,37,1,0,192,48,12,0,72,25,1,0,184,48,12,0,176,16,1,0,200,48,12,0,176,11,1,0,128,48,12,0,80,5,1,0,40,48,12,0,128,253,0,0,56,48,12,0,72,247,0,0,72,48,12,0,248,241,0,0,120,48,12,0,152,238,0,0,64,48,12,0,112,234,0,0,112,48,12,0,128,230,0,0,104,48,12,0,0,0,0,0,0,0,0,0,64,19,1,0,40,107,1,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,136,67,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,1,0,0,0,96,66,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,2,0,0,0,64,65,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,3,0,0,0,168,63,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,4,0,0,0,32,62,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,5,0,0,0,160,60,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,6,0,0,0,224,58,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,7,0,0,0,176,57,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,8,0,0,0,112,56,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,9,0,0,0,80,55,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,10,0,0,0,72,54,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,11,0,0,0,40,53,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,12,0,0,0,8,52,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,13,0,0,0,24,50,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,14,0,0,0,168,48,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,15,0,0,0,128,47,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,16,0,0,0,224,45,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,17,0,0,0,208,44,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,18,0,0,0,208,43,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,19,0,0,0,152,42,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,20,0,0,0,160,41,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,21,0,0,0,112,40,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,22,0,0,0,64,39,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,23,0,0,0,104,37,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,24,0,0,0,16,36,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,0,0,0,0,136,67,1,0,122,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,1,0,0,0,96,66,1,0,97,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,2,0,0,0,64,65,1,0,47,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,3,0,0,0,168,63,1,0,13,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,4,0,0,0,32,62,1,0,17,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,5,0,0,0,160,60,1,0,18,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,6,0,0,0,224,58,1,0,20,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,7,0,0,0,176,57,1,0,19,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,8,0,0,0,112,56,1,0,120,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,9,0,0,0,80,55,1,0,115,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,10,0,0,0,72,54,1,0,113,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,11,0,0,0,40,53,1,0,119,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,12,0,0,0,8,52,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,13,0,0,0,24,50,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,14,0,0,0,168,48,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,15,0,0,0,128,47,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,16,0,0,0,224,45,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,17,0,0,0,208,44,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,18,0,0,0,208,43,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,19,0,0,0,152,42,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,20,0,0,0,160,41,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,21,0,0,0,112,40,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,22,0,0,0,64,39,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,23,0,0,0,104,37,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,24,0,0,0,16,36,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,25,0,0,0,216,34,1,0,32,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,26,0,0,0,144,33,1,0,108,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,27,0,0,0,248,75,1,0,29,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,28,0,0,0,224,77,1,0,27,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,29,0,0,0,192,30,1,0,102,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,30,0,0,0,224,29,1,0,27,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,31,0,0,0,40,29,1,0,32,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,32,0,0,0,0,28,1,0,31,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,33,0,0,0,48,82,0,0,114,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,34,0,0,0,216,23,1,0,111,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,35,0,0,0,136,22,1,0,112,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,36,0,0,0,24,21,1,0,107,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,37,0,0,0,16,20,1,0,104,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,38,0,0,0,48,19,1,0,109,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,39,0,0,0,208,18,1,0,110,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,40,0,0,0,112,18,1,0,121,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,41,0,0,0,32,18,1,0,116,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,42,0,0,0,200,17,1,0,117,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,43,0,0,0,16,17,1,0,33,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,44,0,0,0,88,16,1,0,99,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,45,0,0,0,232,85,0,0,34,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,46,0,0,0,24,15,1,0,105,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,47,0,0,0,184,14,1,0,101,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,48,0,0,0,136,14,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,49,0,0,0,56,14,1,0,14,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,50,0,0,0,8,14,1,0,13,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,51,0,0,0,160,13,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,52,0,0,0,72,13,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,53,0,0,0,16,12,1,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,54,0,0,0,64,121,1,0,36,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,55,0,0,0,232,10,1,0,26,1,0,0,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,1,3,7,15,31,0,0,2,6,14,30,0,0,0,4,12,28,0,0,0,0,8,24,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,255,0,245,246,241,245,254,254,4,3,14,14,26,26,14,22,2,3,0,1,244,0,1,1,7,6,14,14,27,14,14,23,5,6,3,4,255,3,4,4,10,9,14,14,26,251,14,23,8,9,6,7,2,6,7,7,13,12,14,14,27,252,14,24,11,12,9,10,5,9,10,10,16,15,14,14,254,252,14,24,14,15,12,13,8,12,13,13,19,18,14,14,254,220,14,24,17,18,15,16,11,15,16,16,22,21,14,14,28,253,14,25,20,21,18,19,14,18,19,19,25,24,14,14,14,29,14,25,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,29,48,61,0,0,0,0,0,0,189,1,5,0,0,0,0,0,37,0,0,0,20,1,0,0,39,0,0,0,19,1,0,0,38,0,0,0,17,1,0,0,40,0,0,0,18,1,0,0,13,0,0,0,13,0,0,0,9,0,0,0,9,0,0,0,45,0,0,0,21,1,0,0,46,0,0,0,127,0,0,0,16,0,0,0,47,1,0,0,16,0,0,0,48,1,0,0,17,0,0,0,50,1,0,0,35,0,0,0,23,1,0,0,36,0,0,0,22,1,0,0,34,0,0,0,25,1,0,0,33,0,0,0,24,1,0,0,18,0,0,0,52,1,0,0,32,0,0,0,32,0,0,0,27,0,0,0,27,0,0,0,8,0,0,0,8,0,0,0,13,0,0,0,15,1,0,0,107,0,0,0,14,1,0,0,109,0,0,0,13,1,0,0,106,0,0,0,12,1,0,0,111,0,0,0,11,1,0,0,192,0,0,0,96,0,0,0,19,0,0,0,19,0,0,0,96,0,0,0,0,1,0,0,97,0,0,0,1,1,0,0,98,0,0,0,2,1,0,0,99,0,0,0,3,1,0,0,100,0,0,0,4,1,0,0,101,0,0,0,5,1,0,0,102,0,0,0,6,1,0,0,103,0,0,0,7,1,0,0,104,0,0,0,8,1,0,0,105,0,0,0,9,1,0,0,48,0,0,0,48,0,0,0,49,0,0,0,49,0,0,0,50,0,0,0,50,0,0,0,51,0,0,0,51,0,0,0,52,0,0,0,52,0,0,0,53,0,0,0,53,0,0,0,54,0,0,0,54,0,0,0,55,0,0,0,55,0,0,0,56,0,0,0,56,0,0,0,57,0,0,0,57,0,0,0,112,0,0,0,26,1,0,0,113,0,0,0,27,1,0,0,114,0,0,0,28,1,0,0,115,0,0,0,29,1,0,0,116,0,0,0,30,1,0,0,117,0,0,0,31,1,0,0,118,0,0,0,32,1,0,0,119,0,0,0,33,1,0,0,120,0,0,0,34,1,0,0,121,0,0,0,35,1,0,0,122,0,0,0,36,1,0,0,123,0,0,0,37,1,0,0,65,0,0,0,97,0,0,0,66,0,0,0,98,0,0,0,67,0,0,0,99,0,0,0,68,0,0,0,100,0,0,0,69,0,0,0,101,0,0,0,70,0,0,0,102,0,0,0,71,0,0,0,103,0,0,0,72,0,0,0,104,0,0,0,73,0,0,0,105,0,0,0,74,0,0,0,106,0,0,0,75,0,0,0,107,0,0,0,76,0,0,0,108,0,0,0,77,0,0,0,109,0,0,0,78,0,0,0,110,0,0,0,79,0,0,0,111,0,0,0,80,0,0,0,112,0,0,0,81,0,0,0,113,0,0,0,82,0,0,0,114,0,0,0,83,0,0,0,115,0,0,0,84,0,0,0,116,0,0,0,85,0,0,0,117,0,0,0,86,0,0,0,118,0,0,0,87,0,0,0,119,0,0,0,88,0,0,0,120,0,0,0,89,0,0,0,121,0,0,0,90,0,0,0,122,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,64,0,0,0,0,0,0,89,64,0,0,0,0,0,136,195,64,0,0,0,0,132,215,151,65,0,128,224,55,121,195,65,67,23,110,5,181,181,184,147,70,245,249,63,233,3,79,56,77,50,29,48,249,72,119,130,90,60,191,115,127,221,79,21,117,0,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,4,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,8,0,0,0,2,0,0,0,0,0,0,0,4,0,0,0,4,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,4,0,0,0,1,0,0,0,0,0,0,0,2,0,0,0,2,0,0,0,0,0,0,0,1,0,0,0,1,0,0,0,2,0,0,0,1,0,0,0,2,0,0,0,4,0,0,0,8,0,0,0,1,0,0,0,2,0,0,0,4,0,0,0,8,0,0,0,16,0,0,0,0,0,0,0,137,80,78,71,13,10,26,10,1,0,0,0,0,0,0,0,8,0,0,0,8,0,0,0,16,0,0,0,16,0,0,0,8,0,0,0,8,0,0,0,32,0,0,0,32,0,0,0,8,0,0,0,8,0,0,0,64,0,0,0,64,0,0,0,16,0,0,0,16,0,0,0,32,0,0,0,32,0,0,0,16,0,0,0,16,0,0,0,64,0,0,0,64,0,0,0,32,0,0,0,32,0,0,0,64,0,0,0,64,0,0,0,16,0,0,0,32,0,0,0,32,0,0,0,64,0,0,0,16,0,0,0,32,0,0,0,32,0,0,0,32,0,0,0,0,0,0,0,254,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,2,2,2,2,2,2,2,2,2,0,0,0,0,1,1,1,1,1,1,1,1,2,2,2,2,2,2,2,3,3,3,3,3,3,3,3,4,4,4,4,4,0,0,0,1,1,1,1,1,2,2,2,2,2,3,3,3,3,3,4,4,4,4,4,5,5,5,5,5,6,6,6,6,0,0,1,1,1,1,2,2,2,2,3,3,3,3,4,4,4,5,5,5,5,6,6,6,6,7,7,7,7,8,8,8,0,0,1,1,1,2,2,2,3,3,3,4,4,4,5,5,5,6,6,6,7,7,7,8,8,8,9,9,9,10,10,10,0,0,1,1,2,2,2,3,3,4,4,4,5,5,6,6,6,7,7,8,8,8,9,9,10,10,10,11,11,12,12,12,0,0,1,1,2,2,3,3,4,4,5,5,6,6,7,7,7,8,8,9,9,10,10,11,11,12,12,13,13,14,14,14,0,1,1,2,2,3,3,4,4,5,5,6,6,7,7,8,9,9,10,10,11,11,12,12,13,13,14,14,15,15,16,17,0,1,1,2,2,3,4,4,5,5,6,7,7,8,8,9,10,10,11,11,12,13,13,14,14,15,16,16,17,17,18,19,0,1,1,2,3,3,4,5,5,6,7,7,8,9,9,10,11,11,12,13,13,14,15,15,16,17,17,18,19,19,20,21,0,1,1,2,3,4,4,5,6,7,7,8,9,10,10,11,12,12,13,14,15,15,16,17,18,18,19,20,21,21,22,23,0,1,2,2,3,4,5,6,6,7,8,9,10,10,11,12,13,14,14,15,16,17,18,18,19,20,21,22,22,23,24,25,0,1,2,3,3,4,5,6,7,8,9,10,10,11,12,13,14,15,16,16,17,18,19,20,21,22,23,23,24,25,26,27,0,1,2,3,4,5,6,7,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,21,22,23,24,25,26,27,28,29,0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,31,0,0,0,28,0,0,0,31,0,0,0,30,0,0,0,31,0,0,0,30,0,0,0,31,0,0,0,31,0,0,0,30,0,0,0,31,0,0,0,30,0,0,0,31,0,0,0,1,2,3,8,13,14,15,16,17,18,19,20,21,22,23,24,25,26,25,26,25,26,25,26,25,26,27,28,29,30,31,31,31,31,31,31,31,31,31,31,31,31,31,31,31,31,31,31,31,31,31,31,31,31,31,31,31,31,31,31,31,31,31,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,139,8,0,216,147,8,0,152,156,8,0,88,165,8,0,24,174,8,0,216,182,8,0,152,191,8,0,88,200,8,0,28,0,0,0,110,0,0,0,2,0,0,0,16,0,0,0,94,0,0,0,0,0,0,0,16,132,1,0,42,0,0,0,232,208,0,0,20,1,0,0,144,205,0,0,19,1,0,0,208,215,0,0,17,1,0,0,96,212,0,0,18,1,0,0,152,114,1,0,13,0,0,0,248,112,1,0,15,1,0,0,208,111,1,0,9,0,0,0,96,110,1,0,21,1,0,0,152,108,1,0,127,0,0,0,240,106,1,0,23,1,0,0,208,105,1,0,22,1,0,0,136,104,1,0,47,1,0,0,192,39,1,0,48,1,0,0,200,100,1,0,50,1,0,0,168,98,1,0,52,1,0,0,112,97,1,0,32,0,0,0,128,96,1,0,27,0,0,0,80,95,1,0,14,1,0,0,16,94,1,0,13,1,0,0,216,92,1,0,14,1,0,0,184,91,1,0,13,1,0,0,176,90,1,0,26,1,0,0,144,88,1,0,27,1,0,0,96,87,1,0,28,1,0,0,72,86,1,0,29,1,0,0,40,85,1,0,30,1,0,0,48,84,1,0,31,1,0,0,24,83,1,0,32,1,0,0,200,81,1,0,33,1,0,0,176,80,1,0,34,1,0,0,176,79,1,0,35,1,0,0,112,78,1,0,36,1,0,0,72,76,1,0,37,1,0,0,240,74,1,0,48,0,0,0,136,73,1,0,49,0,0,0,72,72,1,0,50,0,0,0,232,70,1,0,51,0,0,0,192,69,1,0,52,0,0,0,128,68,1,0,53,0,0,0,64,67,1,0,54,0,0,0,16,66,1,0,55,0,0,0,240,64,1,0,56,0,0,0,208,62,1,0,57,0,0,0,176,61,1,0,24,1,0,0,216,59,1,0,25,1,0,0,136,58,1,0,0,1,0,0,104,57,1,0,1,1,0,0,40,56,1,0,2,1,0,0,248,54,1,0,3,1,0,0,240,53,1,0,4,1,0,0,224,52,1,0,5,1,0,0,192,51,1,0,6,1,0,0,96,49,1,0,7,1,0,0,72,48,1,0,8,1,0,0,208,46,1,0,9,1,0,0,160,46,1,0,46,0,0,0,80,45,1,0,45,1,0,0,80,44,1,0,44,1,0,0,40,43,1,0,8,0,0,0,48,42,1,0,12,1,0,0,248,40,1,0,11,1,0,0,200,39,1,0,60,1,0,0,160,38,1,0,46,1,0,0,168,36,1,0,96,0,0,0,72,35,1,0,96,0,0,0,40,34,1,0,19,0,0,0,32,33,1,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,160,228,0,0,96,227,0,0,0,0,0,0,1,0,0,0,0,0,0,0,232,142,0,0,96,162,0,0,1,0,0,0,1,0,0,0,0,0,0,0,88,223,0,0,168,125,0,0,2,0,0,0,1,0,0,0,0,0,0,0,72,220,0,0,224,93,0,0,3,0,0,0,1,0,0,0,0,0,0,0,208,215,0,0,16,125,1,0,4,0,0,0,1,0,0,0,0,0,0,0,96,212,0,0,48,93,1,0,5,0,0,0,1,0,0,0,0,0,0,0,232,208,0,0,176,67,1,0,6,0,0,0,1,0,0,0,0,0,0,0,144,205,0,0,192,41,1,0,7,0,0,0,1,0,0,0,0,0,0,0,64,202,0,0,136,18,1,0,8,0,0,0,1,0,0,0,0,0,0,0,32,153,0,0,144,8,1,0,9,0,0,0,1,0,0,0,0,0,0,0,176,195,0,0,80,249,0,0,10,0,0,0,1,0,0,0,0,0,0,0,224,48,1,0,184,239,0,0,11,0,0,0,1,0,0,0,0,0,0,0,184,188,0,0,208,231,0,0,12,0,0,0,1,0,0,0,0,0,0,0,224,184,0,0,48,226,0,0,13,0,0,0,1,0,0,0,0,0,0,0,88,179,0,0,88,221,0,0,14,0,0,0,1,0,0,0,0,0,0,0,0,177,0,0,216,212,0,0,15,0,0,0,1,0,0,0,0,0,0,0,192,174,0,0,240,205,0,0,16,0,0,0,1,0,0,0,0,0,0,0,200,171,0,0,48,199,0,0,17,0,0,0,1,0,0,0,0,0,0,0,32,169,0,0,152,192,0,0,18,0,0,0,1,0,0,0,0,0,0,0,104,166,0,0,240,185,0,0,19,0,0,0,1,0,0,0,0,0,0,0,56,164,0,0,96,177,0,0,20,0,0,0,1,0,0,0,0,0,0,0,152,161,0,0,160,172,0,0,21,0,0,0,1,0,0,0,0,0,0,0,104,160,0,0,216,166,0,0,22,0,0,0,1,0,0,0,0,0,0,0,184,157,0,0,232,161,0,0,23,0,0,0,1,0,0,0,0,0,0,0,88,154,0,0,152,158,0,0,24,0,0,0,1,0,0,0,1,0,0,0,0,152,0,0,88,152,0,0,25,0,0,0,1,0,0,0,2,0,0,0,144,149,0,0,184,148,0,0,26,0,0,0,1,0,0,0,1,0,0,0,72,148,0,0,152,146,0,0,27,0,0,0,1,0,0,0,1,0,0,0,96,147,0,0,96,143,0,0,28,0,0,0,1,0,0,0,2,0,0,0,32,146,0,0,96,140,0,0,29,0,0,0,1,0,0,0,2,0,0,0,176,144,0,0,56,69,1,0,30,0,0,0,1,0,0,0,2,0,0,0,240,142,0,0,72,132,0,0,31,0,0,0,1,0,0,0,2,0,0,0,104,141,0,0,24,129,0,0,32,0,0,0,1,0,0,0,1,0,0,0,136,139,0,0,48,82,0,0,33,0,0,0,1,0,0,0,2,0,0,0,224,136,0,0,232,121,0,0,34,0,0,0,1,0,0,0,2,0,0,0,64,135,0,0,248,117,0,0,35,0,0,0,1,0,0,0,2,0,0,0,168,133,0,0,200,114,0,0,36,0,0,0,1,0,0,0,2,0,0,0,184,131,0,0,104,112,0,0,37,0,0,0,1,0,0,0,2,0,0,0,112,130,0,0,200,109,0,0,38,0,0,0,1,0,0,0,2,0,0,0,160,128,0,0,8,107,0,0,39,0,0,0,1,0,0,0,2,0,0,0,0,127,0,0,80,102,0,0,40,0,0,0,1,0,0,0,2,0,0,0,200,124,0,0,240,98,0,0,41,0,0,0,1,0,0,0,2,0,0,0,72,123,0,0,112,96,0,0,42,0,0,0,1,0,0,0,2,0,0,0,128,121,0,0,104,93,0,0,43,0,0,0,1,0,0,0,2,0,0,0,32,119,0,0,152,90,0,0,44,0,0,0,1,0,0,0,2,0,0,0,160,117,0,0,96,86,0,0,45,0,0,0,1,0,0,0,2,0,0,0,40,116,0,0,176,83,0,0,46,0,0,0,1,0,0,0,2,0,0,0,120,114,0,0,120,81,0,0,47,0,0,0,1,0,0,0,2,0,0,0,72,113,0,0,248,78,0,0,48,0,0,0,1,0,0,0,2,0,0,0,0,112,0,0,88,138,1,0,49,0,0,0,1,0,0,0,2,0,0,0,232,110,0,0,128,133,1,0,50,0,0,0,1,0,0,0,2,0,0,0,112,109,0,0,208,130,1,0,51,0,0,0,1,0,0,0,2,0,0,0,224,107,0,0,0,128,1,0,52,0,0,0,1,0,0,0,2,0,0,0,128,106,0,0,136,124,1,0,53,0,0,0,1,0,0,0,2,0,0,0,160,103,0,0,64,121,1,0,54,0,0,0,1,0,0,0,1,0,0,0,0,102,0,0,72,116,1,0,55,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,1,0,0,0,0,0,0,10,10,10,10,10,10,10,10,10,10,0,0,0,0,0,0,0,0,0,48,46,12,0,240,222,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,14,0,0,0,222,0,0,0,80,40,1,0,0,0,0,0,26,0,0,0,6,0,0,0,36,0,0,0,76,0,0,0,2,0,0,0,134,0,0,0,230,0,0,0,76,0,0,0,0,0,0,0,34,0,0,0,6,0,0,0,4,0,0,0,6,0,0,0,84,0,0,0,2,0,0,0,32,0,0,0,154,5,0,0,2,0,0,0,42,0,0,0,20,0,0,0,42,0,0,0,76,0,0,0,22,0,0,0,98,0,0,0,90,0,0,0,30,0,0,0,2,0,0,0,152,48,0,0,2,0,0,0,56,48,0,0,0,0,0,0,36,48,0,0,8,0,0,0,35,48,0,0,8,0,0,0,34,48,0,0,8,0,0,0,33,48,0,0,8,0,0,0,51,48,0,0,4,0,0,0,56,48,0,0,0,0,0,0,22,0,0,0,238,16,0,0,42,0,0,0,10,0,0,0,44,0,0,0,70,0,0,0,2,0,0,0,236,14,0,0,2,0,0,0,62,0,0,0,26,0,0,0,56,7,0,0,98,0,0,0,72,0,0,0,30,0,0,0,2,0,0,0,0,0,0,0,88,39,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,1,0,2,0,2,0,2,0,2,0,2,0,2,0,2,0,3,0,3,0,3,0,3,0,3,0,4,0,4,0,4,0,4,0,4,0,5,0,5,0,5,0,5,0,6,0,6,0,6,0,6,0,7,0,7,0,7,0,8,0,8,0,8,0,9,0,9,0,9,0,10,0,10,0,10,0,11,0,11,0,11,0,12,0,12,0,13,0,13,0,14,0,14,0,15,0,15,0,15,0,16,0,16,0,17,0,17,0,18,0,19,0,19,0,20,0,20,0,21,0,21,0,22,0,23,0,23,0,24,0,24,0,25,0,26,0,27,0,27,0,28,0,29,0,29,0,30,0,31,0,32,0,32,0,33,0,34,0,35,0,36,0,36,0,37,0,38,0,39,0,40,0,41,0,42,0,43,0,44,0,45,0,46,0,47,0,48,0,49,0,50,0,51,0,52,0,53,0,54,0,55,0,56,0,58,0,59,0,60,0,61,0,62,0,64,0,65,0,66,0,67,0,69,0,70,0,71,0,73,0,74,0,76,0,77,0,78,0,80,0,81,0,83,0,84,0,86,0,87,0,89,0,90,0,92,0,94,0,95,0,97,0,99,0,100,0,102,0,104,0,106,0,107,0,109,0,111,0,113,0,115,0,117,0,118,0,120,0,122,0,124,0,126,0,128,0,130,0,132,0,134,0,137,0,139,0,141,0,143,0,145,0,147,0,150,0,152,0,154,0,156,0,159,0,161,0,163,0,166,0,168,0].concat([171,0,173,0,175,0,178,0,180,0,183,0,186,0,188,0,191,0,193,0,196,0,199,0,201,0,204,0,207,0,210,0,212,0,215,0,218,0,221,0,224,0,227,0,230,0,233,0,236,0,239,0,242,0,245,0,248,0,251,0,254,0,1,1,4,1,7,1,11,1,14,1,17,1,20,1,24,1,27,1,30,1,34,1,37,1,41,1,44,1,48,1,51,1,55,1,58,1,62,1,65,1,69,1,72,1,76,1,80,1,83,1,87,1,91,1,95,1,98,1,102,1,106,1,110,1,114,1,118,1,122,1,125,1,129,1,133,1,137,1,141,1,145,1,149,1,154,1,158,1,162,1,166,1,170,1,174,1,178,1,183,1,187,1,191,1,195,1,200,1,204,1,208,1,213,1,217,1,221,1,226,1,230,1,235,1,239,1,243,1,248,1,252,1,1,2,5,2,10,2,15,2,19,2,24,2,28,2,33,2,38,2,42,2,47,2,51,2,56,2,61,2,65,2,70,2,75,2,80,2,84,2,89,2,94,2,99,2,103,2,108,2,113,2,118,2,123,2,128,2,132,2,137,2,142,2,147,2,152,2,157,2,162,2,166,2,171,2,176,2,181,2,186,2,191,2,196,2,201,2,206,2,211,2,216,2,220,2,225,2,230,2,235,2,240,2,245,2,250,2,255,2,4,3,9,3,14,3,19,3,24,3,29,3,34,3,38,3,43,3,48,3,53,3,58,3,63,3,68,3,73,3,78,3,83,3,87,3,92,3,97,3,102,3,107,3,112,3,116,3,121,3,126,3,131,3,136,3,140,3,145,3,150,3,155,3,159,3,164,3,169,3,173,3,178,3,183,3,187,3,192,3,197,3,201,3,206,3,210,3,215,3,220,3,224,3,229,3,233,3,237,3,242,3,246,3,251,3,255,3,3,4,8,4,12,4,16,4,21,4,25,4,29,4,33,4,37,4,42,4,46,4,50,4,54,4,58,4,62,4,66,4,70,4,74,4,78,4,82,4,85,4,89,4,93,4,97,4,101,4,104,4,108,4,112,4,115,4,119,4,122,4,126,4,129,4,133,4,136,4,140,4,143,4,146,4,150,4,153,4,156,4,159,4,162,4,166,4,169,4,172,4,175,4,178,4,181,4,183,4,186,4,189,4,192,4,195,4,197,4,200,4,203,4,205,4,208,4,210,4,213,4,215,4,217,4,220,4,222,4,224,4,227,4,229,4,231,4,233,4,235,4,237,4,239,4,241,4,243,4,245,4,246,4,248,4,250,4,251,4,253,4,255,4,0,5,2,5,3,5,4,5,6,5,7,5,8,5,10,5,11,5,12,5,13,5,14,5,15,5,16,5,17,5,17,5,18,5,19,5,20,5,20,5,21,5,22,5,22,5,23,5,23,5,23,5,24,5,24,5,24,5,24,5,24,5,25,5,25,5,0,0,0,0,0,0,0,0,16,0,0,0,32,0,0,0,32,0,0,0,64,0,0,0,128,0,0,0,160,0,0,0,192,0,0,0,0,1,0,0,152,4,0,0,42,1,0,0,42,1,0,0,252,9,0,0,148,13,0,0,72,15,0,0,38,2,0,0,38,2,0,0,226,10,0,0,56,5,0,0,112,2,0,0,174,3,0,0,162,8,0,0,92,8,0,0,68,7,0,0,32,9,0,0,200,12,0,0,246,4,0,0,114,1,0,0,14,15,0,0,88,11,0,0,162,5,0,0,26,8,0,0,16,8,0,0,34,13,0,0,184,13,0,0,92,0,0,0,90,0,0,0,96,0,0,0,94,0,0,0,86,0,0,0,84,0,0,0,162,1,0,0,88,0,0,0,82,0,0,0,80,0,0,0,24,5,0,0,22,5,0,0,28,5,0,0,26,5,0,0,20,5,0,0,18,5,0,0,16,11,0,0,18,11,0,0,12,11,0,0,14,11,0,0,24,11,0,0,26,11,0,0,20,11,0,0,22,11,0,0,28,11,0,0,30,11,0,0,202,16,0,0,204,16,0,0,206,16,0,0,208,16,0,0,186,13,0,0,200,16,0,0,134,13,0,0,132,13,0,0,130,13,0,0,128,13,0,0,130,11,0,0,126,11,0,0,136,13,0,0,114,11,0,0,108,13,0,0,144,13,0,0,86,9,0,0,114,2,0,0,118,3,0,0,206,0,0,0,204,0,0,0,202,0,0,0,170,1,0,0,172,1,0,0,160,1,0,0,168,1,0,0,104,15,0,0,202,1,0,0,178,1,0,0,180,1,0,0,146,3,0,0,148,3,0,0,50,14,0,0,52,14,0,0,152,4,0,0,48,10,0,0,4,8,0,0,168,3,0,0,154,11,0,0,156,11,0,0,158,11,0,0,160,11,0,0,146,11,0,0,148,11,0,0,150,11,0,0,152,11,0,0,162,11,0,0,164,11,0,0,180,7,0,0,182,7,0,0,176,7,0,0,178,7,0,0,172,7,0,0,174,7,0,0,34,17,0,0,32,17,0,0,38,17,0,0,36,17,0,0,42,17,0,0,40,17,0,0,82,15,0,0,44,17,0,0,38,15,0,0,34,15,0,0,64,12,0,0,62,12,0,0,42,10,0,0,34,10,0,0,60,12,0,0,58,12,0,0,12,4,0,0,28,0,0,0,24,0,0,0,26,0,0,0,20,0,0,0,22,0,0,0,16,0,0,0,18,0,0,0,42,0,0,0,44,0,0,0,198,3,0,0,200,3,0,0,202,3,0,0,204,3,0,0,72,2,0,0,74,2,0,0,52,13,0,0,54,13,0,0,56,13,0,0,58,13,0,0,44,13,0,0,46,13,0,0,48,13,0,0,194,8,0,0,36,13,0,0,38,13,0,0,142,7,0,0,144,7,0,0,138,7,0,0,140,7,0,0,134,7,0,0,136,7,0,0,12,15,0,0,184,8,0,0,182,8,0,0,180,8,0,0,100,15,0,0,46,7,0,0,254,9,0,0,58,7,0,0,100,5,0,0,114,5,0,0,2,15,0,0,4,15,0,0,254,14,0,0,0,15,0,0,124,3,0,0,152,12,0,0,222,5,0,0,224,5,0,0,218,5,0,0,220,5,0,0,230,5,0,0,232,5,0,0,226,5,0,0,228,5,0,0,212,5,0,0,214,5,0,0,112,7,0,0,114,7,0,0,116,7,0,0,118,7,0,0,120,7,0,0,122,7,0,0,120,2,0,0,180,13,0,0,188,2,0,0,118,2,0,0,128,2,0,0,130,2,0,0,124,2,0,0,126,2,0,0,132,2,0,0,134,2,0,0,22,6,0,0,24,6,0,0,26,6,0,0,28,6,0,0,16,6,0,0,18,6,0,0,202,10,0,0,180,3,0,0,184,3,0,0,182,3,0,0,60,2,0,0,186,3,0,0,190,3,0,0,188,3,0,0,194,3,0,0,192,3,0,0,40,7,0,0,54,1,0,0,60,1,0,0,58,1,0,0,64,1,0,0,62,1,0,0,144,3,0,0,142,3,0,0,140,3,0,0,138,3,0,0,136,3,0,0,134,3,0,0,132,3,0,0,130,3,0,0,152,3,0,0,150,3,0,0,136,0,0,0,134,0,0,0,132,0,0,0,130,0,0,0,128,0,0,0,50,5,0,0,188,5,0,0,182,12,0,0,180,12,0,0,178,12,0,0,192,12,0,0,190,12,0,0,188,12,0,0,186,12,0,0,194,5,0,0,168,12,0,0,14,3,0,0,12,3,0,0,10,3,0,0,8,3,0,0,18,3,0,0,106,4,0,0,196,6,0,0,194,6,0,0,192,6,0,0,190,6,0,0,204,6,0,0,202,6,0,0,200,6,0,0,198,6,0,0,208,6,0,0,206,6,0,0,178,15,0,0,176,15,0,0,174,15,0,0,172,15,0,0,184,15,0,0,182,15,0,0,112,2,0,0,174,3,0,0,162,8,0,0,92,8,0,0,68,7,0,0,32,9,0,0,200,12,0,0,246,4,0,0,114,1,0,0,14,15,0,0,88,11,0,0,162,5,0,0,26,8,0,0,16,8,0,0,34,13,0,0,184,13,0,0,92,0,0,0,90,0,0,0,96,0,0,0,94,0,0,0,86,0,0,0,84,0,0,0,162,1,0,0,88,0,0,0,82,0,0,0,80,0,0,0,24,5,0,0,22,5,0,0,28,5,0,0,26,5,0,0,20,5,0,0,18,5,0,0,16,11,0,0,18,11,0,0,12,11,0,0,14,11,0,0,24,11,0,0,26,11,0,0,20,11,0,0,22,11,0,0,28,11,0,0,30,11,0,0,202,16,0,0,204,16,0,0,206,16,0,0,208,16,0,0,186,13,0,0,200,16,0,0,92,3,0,0,94,3,0,0,96,3,0,0,80,1,0,0,100,3,0,0,102,3,0,0,104,3,0,0,106,3,0,0,108,3,0,0,110,3,0,0,134,1,0,0,130,9,0,0,118,3,0,0,206,0,0,0,204,0,0,0,202,0,0,0,138,4,0,0,136,4,0,0,142,4,0,0,186,2,0,0,130,4,0,0,128,4,0,0,214,7,0,0,132,4,0,0,124,4,0,0,122,4,0,0,6,5,0,0,4,5,0,0,72,15,0,0,48,10,0,0,24,14,0,0,168,3,0,0,6,7,0,0,54,5,0,0,72,5,0,0,62,5,0,0,14,7,0,0,78,5,0,0,94,5,0,0,86,5,0,0,254,6,0,0,252,6,0,0,124,9,0,0,122,9,0,0,128,9,0,0,126,9,0,0,120,9,0,0,118,9,0,0,40,0,0,0,38,0,0,0,200,0,0,0,198,0,0,0,32,0,0,0,30,0,0,0,36,0,0,0,34,0,0,0,126,15,0,0,168,0,0,0,224,11,0,0,222,11,0,0,228,11,0,0,158,6,0,0,232,11,0,0,230,11,0,0,12,4,0,0,232,0,0,0,236,0,0,0,234,0,0,0,240,0,0,0,238,0,0,0,244,0,0,0,242,0,0,0,232,4,0,0,222,4,0,0,116,0,0,0,114,0,0,0,120,0,0,0,118,0,0,0,112,0,0,0,110,0,0,0,182,1,0,0,184,1,0,0,186,1,0,0,188,1,0,0,190,1,0,0,192,1,0,0,194,1,0,0,196,1,0,0,198,1,0,0,200,1,0,0,252,3,0,0,254,3,0,0,248,3,0,0,250,3,0,0,0,4,0,0,2,4,0,0,12,15,0,0,184,8,0,0,182,8,0,0,180,8,0,0,100,15,0,0,46,7,0,0,112,5,0,0,58,7,0,0,224,2,0,0,224,12,0,0,18,2,0,0,16,2,0,0,22,2,0,0,20,2,0,0,124,3,0,0,78,8,0,0,60,17,0,0,58,17,0,0,122,15,0,0,56,17,0,0,68,17,0,0,214,10,0,0,64,17,0,0,62,17,0,0,50,17,0,0,48,17,0,0,30,12,0,0,28,12,0,0,26,12,0,0,24,12,0,0,36,12,0,0,34,12,0,0,120,2,0,0,180,13,0,0,188,2,0,0,118,2,0,0,128,2,0,0,130,2,0,0,124,2,0,0,126,2,0,0,132,2,0,0,134,2,0,0,22,6,0,0,24,6,0,0,26,6,0,0,28,6,0,0,16,6,0,0,18,6,0,0,202,10,0,0,88,7,0,0,84,7,0,0,86,7,0,0,94,7,0,0,96,7,0,0,90,7,0,0,92,7,0,0,98,7,0,0,100,7,0,0,38,6,0,0,40,6,0,0,42,6,0,0,44,6,0,0,46,6,0,0,48,6,0,0,144,3,0,0,142,3,0,0,140,3,0,0,138,3,0,0,136,3,0,0,134,3,0,0,132,3,0,0,130,3,0,0,152,3,0,0,150,3,0,0,136,0,0,0,134,0,0,0,132,0,0,0,130,0,0,0,128,0,0,0,50,5,0,0,188,5,0,0,182,12,0,0,180,12,0,0,178,12,0,0,192,12,0,0,190,12,0,0,188,12,0,0,186,12,0,0,194,5,0,0,168,12,0,0,14,3,0,0,12,3,0,0,10,3,0,0,8,3,0,0,18,3,0,0,240,15,0,0,152,9,0,0,150,9,0,0,148,9,0,0,146,9,0,0,144,9,0,0,90,3,0,0,140,9,0,0,138,9,0,0,162,9,0,0,160,9,0,0,60,9,0,0,58,9,0,0,56,9,0,0,54,9,0,0,52,9,0,0,50,9,0,0,112,2,0,0,174,3,0,0,162,8,0,0,92,8,0,0,68,7,0,0,32,9,0,0,200,12,0,0,246,4,0,0,114,1,0,0,14,15,0,0,88,11,0,0,162,5,0,0,26,8,0,0,16,8,0,0,34,13,0,0,184,13,0,0,92,0,0,0,90,0,0,0,96,0,0,0,94,0,0,0,86,0,0,0,84,0,0,0,162,1,0,0,88,0,0,0,82,0,0,0,80,0,0,0,24,5,0,0,22,5,0,0,28,5,0,0,26,5,0,0,20,5,0,0,18,5,0,0,16,11,0,0,18,11,0,0,12,11,0,0,14,11,0,0,24,11,0,0,26,11,0,0,20,11,0,0,22,11,0,0,28,11,0,0,30,11,0,0,202,16,0,0,204,16,0,0,206,16,0,0,208,16,0,0,186,13,0,0,200,16,0,0,134,13,0,0,132,13,0,0,130,13,0,0,128,13,0,0,130,11,0,0,126,11,0,0,136,13,0,0,114,11,0,0,108,13,0,0,144,13,0,0,86,9,0,0,114,2,0,0,118,3,0,0,206,0,0,0,204,0,0,0,202,0,0,0,170,1,0,0,172,1,0,0,160,1,0,0,168,1,0,0,104,15,0,0,202,1,0,0,178,1,0,0,180,1,0,0,146,3,0,0,148,3,0,0,50,14,0,0,52,14,0,0,152,4,0,0,48,10,0,0,4,8,0,0,168,3,0,0,158,15,0,0,156,15,0,0,162,15,0,0,160,15,0,0,166,15,0,0,164,15,0,0,170,15,0,0,168,15,0,0,154,15,0,0,152,15,0,0,36,4,0,0,34,4,0,0,40,4,0,0,38,4,0,0,32,4,0,0,30,4,0,0,12,13,0,0,14,13,0,0,16,13,0,0,18,13,0,0,4,13,0,0,6,13,0,0,8,13,0,0,10,13,0,0,28,13,0,0,30,13,0,0,2,16,0,0,36,9,0,0,254,15,0,0,0,16,0,0,250,15,0,0,252,15,0,0,12,4,0,0,112,11,0,0,110,11,0,0,108,11,0,0,106,11,0,0,104,11,0,0,28,16,0,0,100,11,0,0,124,11,0,0,122,11,0,0,236,11,0,0,234,11,0,0,146,1,0,0,142,1,0,0,138,1,0,0,226,11,0,0,84,2,0,0,82,2,0,0,88,2,0,0,86,2,0,0,92,2,0,0,90,2,0,0,96,2,0,0,94,2,0,0,78,2,0,0,76,2,0,0,254,5,0,0,252,5,0,0,2,6,0,0,0,6,0,0,250,5,0,0,60,16,0,0,12,15,0,0,184,8,0,0,182,8,0,0,180,8,0,0,100,15,0,0,46,7,0,0,254,9,0,0,58,7,0,0,100,5,0,0,114,5,0,0,2,15,0,0,4,15,0,0,254,14,0,0,0,15,0,0,124,3,0,0,152,12,0,0,8,7,0,0,10,7,0,0,4,7,0,0,60,5,0,0,16,7,0,0,18,7,0,0,12,7,0,0,84,5,0,0,0,7,0,0,2,7,0,0,56,8,0,0,58,8,0,0,60,8,0,0,62,8,0,0,64,8,0,0,66,8,0,0,120,2,0,0,180,13,0,0,188,2,0,0,118,2,0,0,128,2,0,0,130,2,0,0,124,2,0,0,126,2,0,0,132,2,0,0,134,2,0,0,22,6,0,0,24,6,0,0,26,6,0,0,28,6,0,0,16,6,0,0,18,6,0,0,202,10,0,0,86,12,0,0,88,12,0,0,90,12,0,0,92,12,0,0,94,12,0,0,96,12,0,0,98,12,0,0,58,4,0,0,100,12,0,0,214,9,0,0,216,9,0,0,210,9,0,0,212,9,0,0,218,9,0,0,220,9,0,0,144,3,0,0,142,3,0,0,140,3,0,0,138,3,0,0,136,3,0,0,134,3,0,0,132,3,0,0,130,3,0,0,152,3,0,0,150,3,0,0,136,0,0,0,134,0,0,0,132,0,0,0,130,0,0,0,128,0,0,0,140,4,0,0,188,5,0,0,182,12,0,0,180,12,0,0,178,12,0,0,192,12,0,0,190,12,0,0,188,12,0,0,186,12,0,0,194,5,0,0,168,12,0,0,14,3,0,0,12,3,0,0,10,3,0,0,8,3,0,0,18,3,0,0,2,1,0,0,16,10,0,0,18,10,0,0,206,10,0,0,22,10,0,0,8,10,0,0,10,10,0,0,12,10,0,0,20,6,0,0,26,10,0,0,28,10,0,0,64,0,0,0,66,0,0,0,60,0,0,0,62,0,0,0,56,0,0,0,58,0,0,0,112,2,0,0,174,3,0,0,162,8,0,0,92,8,0,0,68,7,0,0,32,9,0,0,200,12,0,0,246,4,0,0,114,1,0,0,14,15,0,0,88,11,0,0,162,5,0,0,26,8,0,0,16,8,0,0,34,13,0,0,184,13,0,0,92,0,0,0,90,0,0,0,96,0,0,0,94,0,0,0,86,0,0,0,84,0,0,0,162,1,0,0,88,0,0,0,82,0,0,0,80,0,0,0,24,5,0,0,22,5,0,0,28,5,0,0,26,5,0,0,20,5,0,0,18,5,0,0,16,11,0,0,18,11,0,0,12,11,0,0,14,11,0,0,24,11,0,0,26,11,0,0,20,11,0,0,22,11,0,0,28,11,0,0,30,11,0,0,202,16,0,0,204,16,0,0,206,16,0,0,208,16,0,0,186,13,0,0,200,16,0,0,92,3,0,0,94,3,0,0,96,3,0,0,80,1,0,0,100,3,0,0,102,3,0,0,104,3,0,0,106,3,0,0,108,3,0,0,110,3,0,0,134,1,0,0,130,9,0,0,118,3,0,0,206,0,0,0,204,0,0,0,202,0,0,0,138,4,0,0,136,4,0,0,142,4,0,0,186,2,0,0,130,4,0,0,128,4,0,0,214,7,0,0,132,4,0,0,124,4,0,0,122,4,0,0,6,5,0,0,4,5,0,0,72,15,0,0,48,10,0,0,24,14,0,0,168,3,0,0,60,15,0,0,62,15,0,0,64,15,0,0,66,15,0,0,52,15,0,0,54,15,0,0,56,15,0,0,58,15,0,0,68,15,0,0,70,15,0,0,248,11,0,0,250,11,0,0,112,14,0,0,246,11,0,0,240,11,0,0,242,11,0,0,74,6,0,0,72,6,0,0,70,6,0,0,68,6,0,0,66,6,0,0,64,6,0,0,62,6,0,0,60,6,0,0,82,6,0,0,80,6,0,0,156,6,0,0,154,6,0,0,152,6,0,0,150,6,0,0,148,6,0,0,146,6,0,0,12,4,0,0,200,9,0,0,202,9,0,0,204,9,0,0,192,9,0,0,194,9,0,0,196,9,0,0,232,9,0,0,164,4,0,0,208,9,0,0,80,3,0,0,82,3,0,0,76,3,0,0,78,3,0,0,72,3,0,0,74,3,0,0,238,5,0,0,100,8,0,0,116,8,0,0,110,8,0,0,124,8,0,0,120,8,0,0,130,8,0,0,128,8,0,0,22,13,0,0,20,13,0,0,122,12,0,0,120,12,0,0,186,4,0,0,76,7,0,0,130,12,0,0,128,12,0,0,12,15,0,0,184,8,0,0,182,8,0,0,180,8,0,0,100,15,0,0,46,7,0,0,112,5,0,0,58,7,0,0,224,2,0,0,224,12,0,0,18,2,0,0,16,2,0,0,22,2,0,0,20,2,0,0,124,3,0,0,78,8,0,0,60,17,0,0,58,17,0,0,122,15,0,0,56,17,0,0,68,17,0,0,214,10,0,0,64,17,0,0,62,17,0,0,50,17,0,0,48,17,0,0,30,12,0,0,28,12,0,0,26,12,0,0,24,12,0,0,36,12,0,0,34,12,0,0,120,2,0,0,180,13,0,0,188,2,0,0,118,2,0,0,128,2,0,0,130,2,0,0,124,2,0,0,126,2,0,0,132,2,0,0,134,2,0,0,22,6,0,0,24,6,0,0,26,6,0,0,28,6,0,0,16,6,0,0,18,6,0,0,202,10,0,0,158,3,0,0,156,3,0,0,154,3,0,0,166,3,0,0,38,9,0,0,162,3,0,0,160,3,0,0,172,3,0,0,170,3,0,0,226,14,0,0,224,14,0,0,222,14,0,0,220,14,0,0,230,14,0,0,228,14,0,0,144,3,0,0,142,3,0,0,140,3,0,0,138,3,0,0,136,3,0,0,134,3,0,0,132,3,0,0,130,3,0,0,152,3,0,0,150,3,0,0,136,0,0,0,134,0,0,0,132,0,0,0,130,0,0,0,128,0,0,0,24,8,0,0,188,5,0,0,182,12,0,0,180,12,0,0,178,12,0,0,192,12,0,0,190,12,0,0,188,12,0,0,186,12,0,0,194,5,0,0,168,12,0,0,14,3,0,0,12,3,0,0,10,3,0,0,8,3,0,0,18,3,0,0,184,2,0,0,152,9,0,0,150,9,0,0,148,9,0,0,146,9,0,0,144,9,0,0,90,3,0,0,140,9,0,0,138,9,0,0,162,9,0,0,160,9,0,0,60,9,0,0,58,9,0,0,56,9,0,0,54,9,0,0,52,9,0,0,50,9,0,0,77,0,80,0,0,0,43,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,115,1,0,80,97,0,0,208,86,1,0,0,0,0,0,90,1,1,1,37,6,2,0,17,8,3,0,8,10,4,0,3,12,5,0,1,15,5,0,90,7,7,1,63,19,8,0,44,21,9,0,32,22,10,0,23,23,11,0,17,25,12,0,12,26,13,0,9,28,14,0,7,29,15,0,5,31,16,0,4,32,17,0,3,34,18,0,2,35,5,0,90,20,20,1,72,39,21,0,58,40,22,0,46,42,23,0,38,44,24,0,31,45,25,0,25,46,26,0,21,25,27,0,17,26,28,0,14,26,29,0,11,27,30,0,9,28,31,0,8,29,32,0,7,30,33,0,5,31,34,0,4,33,35,0,4,33,36,0,3,34,37,0,2,35,38,0,2,36,5,0,88,39,40,1,77,47,41,0,67,48,42,0,59,49,43,0,52,50,44,0,46,51,45,0,41,44,46,0,37,45,24,0,86,47,48,1,79,47,49,0,71,48,50,0,65,49,51,0,60,50,52,0,55,51,43,0,0,0,0,0,0,25,25,0,2,1,0,3,1,0,4,2,0,5,3,1,6,4,1,7,5,1,8,6,1,9,7,2,10,8,2,11,9,2,12,10,2,13,11,3,14,12,3,15,13,3,16,14,3,17,15,4,18,16,4,19,17,5,20,18,5,21,19,6,22,20,6,23,21,7,24,22,7,24,23,0,26,1,1,27,2,2,28,4,3,29,8,4,30,12,5,31,16,6,32,18,7,24,22,0,0,0,0,0,72,43,1,0,128,31,1,0,128,117,1,0,0,135,1,0,16,9,1,0,248,0,1,0,0,250,0,0,104,244,0,0,8,240,0,0,24,236,0,0,152,99,1,0,24,98,1,0,80,207,0,0,32,96,1,0,192,94,1,0,144,93,1,0,69,139,90,154,228,130,27,120,0,0,170,150,137,14,224,128,42,73,61,186,20,160,172,197,0,0,81,187,156,78,123,255,244,253,87,50,55,217,66,34,0,0,91,60,159,27,135,154,111,39,175,123,229,104,10,217,0,0,154,197,156,78,123,255,234,33,120,79,221,237,36,20,0,0,119,177,209,54,193,103,82,87,70,61,89,244,135,164,0,0,126,68,0,78,123,255,117,245,6,151,16,195,36,187,0,0,123,122,224,96,18,15,247,116,28,229,57,61,115,193,0,0,122,179,255,78,123,255,40,71,52,54,38,84,84,104,72,71,69,86,85,101,34,70,40,71,52,54,38,84,84,116,72,71,69,86,85,101,34,56,40,71,52,54,38,68,84,102,72,71,69,86,85,69,34,67,40,71,52,54,38,68,84,117,72,71,69,86,85,85,34,54,40,71,52,54,38,84,82,69,72,71,69,86,85,85,34,197,56,71,52,54,38,68,82,68,72,71,69,86,85,85,34,52,56,71,69,71,37,100,82,73,72,71,86,103,69,85,34,131,40,71,52,54,36,83,67,64,72,71,69,86,52,84,34,96,254,255,255,255,254,255,255,255,96,214,0,0,232,210,0,0,104,207,0,0,32,204,0,0,168,200,0,0,64,197,0,0,192,193,0,0,208,190,0,0,72,187,0,0,8,183,0,0,24,178,0,0,168,175,0,0,112,173,0,0,128,170,0,0,144,167,0,0,32,165,0,0,160,162,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,100,16,183,29,200,32,110,59,172,48,217,38,144,65,220,118,244,81,107,107,88,97,178,77,60,113,5,80,32,131,184,237,68,147,15,240,232,163,214,214,140,179,97,203,176,194,100,155,212,210,211,134,120,226,10,160,28,242,189,189,0,0,0,0,150,48,7,119,44,97,14,238,186,81,9,153,25,196,109,7,143,244,106,112,53,165,99,233,163,149,100,158,50,136,219,14,164,184,220,121,30,233,213,224,136,217,210,151,43,76,182,9,189,124,177,126,7,45,184,231,145,29,191,144,100,16,183,29,242,32,176,106,72,113,185,243,222,65,190,132,125,212,218,26,235,228,221,109,81,181,212,244,199,133,211,131,86,152,108,19,192,168,107,100,122,249,98,253,236,201,101,138,79,92,1,20,217,108,6,99,99,61,15,250,245,13,8,141,200,32,110,59,94,16,105,76,228,65,96,213,114,113,103,162,209,228,3,60,71,212,4,75,253,133,13,210,107,181,10,165,250,168,181,53,108,152,178,66,214,201,187,219,64,249,188,172,227,108,216,50,117,92,223,69,207,13,214,220,89,61,209,171,172,48,217,38,58,0,222,81,128,81,215,200,22,97,208,191,181,244,180,33,35,196,179,86,153,149,186,207,15,165,189,184,158,184,2,40,8,136,5,95,178,217,12,198,36,233,11,177,135,124,111,47,17,76,104,88,171,29,97,193,61,45,102,182,144,65,220,118,6,113,219,1,188,32,210,152,42,16,213,239,137,133,177,113,31,181,182,6,165,228,191,159,51,212,184,232,162,201,7,120,52,249,0,15,142,168,9,150,24,152,14,225,187,13,106,127,45,61,109,8,151,108,100,145,1,92,99,230,244,81,107,107,98,97,108,28,216,48,101,133,78,0,98,242,237,149,6,108,123,165,1,27,193,244,8,130,87,196,15,245,198,217,176,101,80,233,183,18,234,184,190,139,124,136,185,252,223,29,221,98,73,45,218,21,243,124,211,140,101,76,212,251,88,97,178,77,206,81,181,58,116,0,188,163,226,48,187,212,65,165,223,74,215,149,216,61,109,196,209,164,251,244,214,211,106,233,105,67,252,217,110,52,70,136,103,173,208,184,96,218,115,45,4,68,229,29,3,51,95,76,10,170,201,124,13,221,60,113,5,80,170,65,2,39,16,16,11,190,134,32,12,201,37,181,104,87,179,133,111,32,9,212,102,185,159,228,97,206,14,249,222,94,152,201,217,41,34,152,208,176,180,168,215,199,23,61,179,89,129,13,180,46,59,92,189,183,173,108,186,192,32,131,184,237,182,179,191,154,12,226,182,3,154,210,177,116,57,71,213,234,175,119,210,157,21,38,219,4,131,22,220,115,18,11,99,227,132,59,100,148,62,106,109,13,168,90,106,122,11,207,14,228,157,255,9,147,39,174,0,10,177,158,7,125,68,147,15,240,210,163,8,135,104,242,1,30,254,194,6,105,93,87,98,247,203,103,101,128,113,54,108,25,231,6,107,110,118,27,212,254,224,43,211,137,90,122,218,16,204,74,221,103,111,223,185,249,249,239,190,142,67,190,183,23,213,142,176,96,232,163,214,214,126,147,209,161,196,194,216,56,82,242,223,79,241,103,187,209,103,87,188,166,221,6,181,63,75,54,178,72,218,43,13,216,76,27,10,175,246,74,3,54,96,122,4,65,195,239,96,223,85,223,103,168,239,142,110,49,121,190,105,70,140,179,97,203,26,131,102,188,160,210,111,37,54,226,104,82,149,119,12,204,3,71,11,187,185,22,2,34,47,38,5,85,190,59,186,197,40,11,189,178,146,90,180,43,4,106,179,92,167,255,215,194,49,207,208,181,139,158,217,44,29,174,222,91,176,194,100,155,38,242,99,236,156,163,106,117,10,147,109,2,169,6,9,156,63,54,14,235,133,103,7,114,19,87,0,5,130,74,191,149,20,122,184,226,174,43,177,123,56,27,182,12,155,142,210,146,13,190,213,229,183,239,220,124,33,223,219,11,212,210,211,134,66,226,212,241,248,179,221,104,110,131,218,31,205,22,190,129,91,38,185,246,225,119,176,111,119,71,183,24,230,90,8,136,112,106,15,255,202,59,6,102,92,11,1,17,255,158,101,143,105,174,98,248,211,255,107,97,69,207,108,22,120,226,10,160,238,210,13,215,84,131,4,78,194,179,3,57,97,38,103,167,247,22,96,208,77,71,105,73,219,119,110,62,74,106,209,174,220,90,214,217,102,11,223,64,240,59,216,55,83,174,188,169,197,158,187,222,127,207,178,71,233,255,181,48,28,242,189,189,138,194,186,202,48,147,179,83,166,163,180,36,5,54,208,186,147,6,215,205,41,87,222,84,191,103,217,35,46,122,102,179,184,74,97,196,2,27,104,93,148,43,111,42,55,190,11,180,161,142,12,195,27,223,5,90,141,239,2,45,1,120,0,0,0,8,0,0,0,6,0,0,0,5,0,0,0,4,0,0,0,3,0,0,128,2,0,0,0,2,0,0,128,1,0,0,64,1,0,0,0,1,0,0,192,0,0,0,160,0,0,0,128,0,0,0,96,0,0,0,80,0,0,0,64,0,0,0,48,0,0,0,40,0,0,0,32,0,0,0,24,0,0,0,20,0,0,0,16,0,0,0,12,0,0,0,10,0,0,0,8,0,0,0,6,0,0,0,5,0,0,0,4,0,0,0,3,0,0,0,2,0,0,0,1,0,0,0,1,0,0,0,0,0,0,0,16,4,0,0,24,2,0,0,0,0,0,0,16,4,0,0,24,2,0,0,0,0,0,0,16,4,0,0,24,2,0,0,0,0,0,0,16,4,0,0,24,2,0,0,0,0,0,0,16,4,0,0,24,2,0,0,0,0,0,0,16,4,0,0,24,2,0,0,0,0,0,0,16,4,0,0,24,2,0,0,0,0,0,0,16,4,0,0,24,2,0,0,0,0,0,0,16,4,0,0,24,2,0,0,0,0,0,0,16,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,85,0,0,0,0,0,0,0,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,120,216,0,0,2,0,0,0,88,180,0,0,3,0,0,0,40,155,0,0,5,0,0,0,128,137,0,0,4,0,0,0,24,139,8,0,216,147,8,0,152,156,8,0,88,165,8,0,24,174,8,0,216,182,8,0,152,191,8,0,88,200,8,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,62,0,0,0,30,0,0,0,34,0,0,0,2,0,0,0,16,79,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,16,66,8,32,0,0,74,41,0,0,0,0,0,0,168,175,212,87,0,0,128,248,226,232,35,0,0,0,136,170,168,138,0,0,192,164,100,82,116,0,0,132,16,0,0,0,0,0,136,8,33,132,32,8,0,130,32,132,16,34,2,0,0,144,234,42,1,0,0,0,16,242,9,1,0,0,0,0,0,0,32,2,0,0,0,240,1,0,0,0,0,0,0,0,32,0,0,16,34,68,136,16,1,0,192,197,88,99,116,0,0,128,24,66,8,113,0,0,192,69,200,68,248,0,0,192,69,200,96,116,0,0,0,49,149,62,66,0,0,224,135,240,96,116,0,0,128,137,240,98,116,0,0,224,67,132,8,17,0,0,192,197,232,98,116,0,0,192,197,232,33,50,0,0,0,0,2,0,1,0,0,0,0,2,0,17,0,0,0,64,54,24,4,0,0,0,128,15,62,0,0,0,0,4,131,77,0,0,0,192,69,136,8,32,0,0,192,135,214,122,240,0,0,128,16,165,92,140,0,0,224,197,248,98,124,0,0,192,197,16,66,116,0,0,224,164,24,99,58,0,0,224,135,240,66,248,0,0,224,135,240,66,8,0,0,192,197,144,99,244,0,0,32,198,248,99,140,0,0,192,17,66,8,113,0,0,128,67,8,33,124,0,0,32,166,50,74,138,0,0,32,132,16,66,248,0,0,32,198,189,107,141,0,0,96,206,90,107,206,0,0,192,197,24,99,116,0,0,224,197,248,66,8,0,0,192,197,24,99,246,0,0,224,197,248,98,140,0,0,192,197,224,96,116,0,0,224,19,66,8,33,0,0,32,198,24,99,116,0,0,32,198,168,20,33,0,0,32,214,90,149,82,0,0,32,70,69,84,140,0,0,32,198,232,8,33,0,0,224,67,68,68,248,0,0,78,8,33,132,16,14,0,33,8,65,8,66,16,0,14,33,132,16,66,14,0,128,168,8,0,0,0,0,0,0,0,0,0,31,0,128,32,0,0,0,0,0,0,0,7,125,244,0,0,33,132,23,99,124,0,0,0,0,31,66,240,0,0,16,66,31,99,244,0,0,0,0,23,127,240,0,0,92,136,39,132,16,0,0,0,0,23,99,244,208,1,33,132,23,99,140,0,0,128,0,67,8,33,0,0,0,1,134,16,66,232,0,66,8,169,140,146,0,0,134,16,66,8,33,0,0,0,128,85,107,173,0,0,0,128,23,99,140,0,0,0,0,23,99,116,0,0,0,128,23,99,124,33,0,0,0,31,99,244,16,2,0,128,54,67,8,0,0,0,0,31,28,124,0,0,64,8,39,132,224,0,0,0,128,24,99,244,0,0,0,128,24,149,34,0,0,0,128,88,171,82,0,0,0,128,168,136,138,0,0,0,128,24,99,244,208,1,0,128,143,136,248,0,0,136,16,34,8,33,8,0,132,16,66,8,33,4,0,130,16,130,8,33,2,0,0,0,96,50,0,0,0,0,0,0,0,0,0,0,63,132,16,66,8,225,3,0,0,0,0,0,0,0,0,0,0,0,64,4,0,152,16,71,8,33,68,0,0,0,0,0,80,10,0,0,0,0,0,168,0,0,132,124,66,8,33,4,0,132,124,242,9,33,4,0,68,1,0,0,0,0,0,0,72,69,84,2,0,0,138,0,31,62,124,0,0,0,0,68,4,65,0,0,192,166,148,83,178,0,0,0,0,0,0,0,0,0,138,128,143,136,248,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,132,32,0,0,0,0,0,8,17,0,0,0,0,0,74,81,0,0,0,0,0,148,42,0,0,0,0,0,0,0,192,24,0,0,0,0,0,0,62,0,0,0,0,0,0,62,0,0,0,0,0,64,21,0,0,0,0,128,175,149,2,0,0,138,0,31,28,124,0,0,0,0,130,32,34,0,0,0,0,155,114,178,0,0,0,0,0,0,0,0,0,138,128,143,136,248,0,0,10,196,24,29,33,0,0,0,0,0,0,0,0,0,128,0,66,8,33,0,0,0,32,174,20,71,0,0,152,16,79,68,248,0,0,0,4,47,165,15,0,0,32,70,71,62,33,0,0,132,16,2,8,33,4,0,152,16,23,163,35,100,0,64,1,0,0,0,0,0,192,135,86,90,240,0,0,4,49,197,0,0,0,0,0,0,34,147,36,0,0,0,0,224,33,132,0,0,0,0,0,0,0,0,0,192,135,84,74,240,0,0,224,3,0,0,0,0,0,128,56,2,0,0,0,0,0,16,242,9,249,0,0,6,17,225,0,0,0,0,6,25,100,0,0,0,0,136,0,0,0,0,0,0,0,0,41,165,116,34,0,192,223,107,41,165,148,2,0,0,64,0,0,0,0,0,0,0,0,96,136,0,196,16,226,0,0,0,0,68,41,2,0,0,0,0,0,128,36,137,76,0,0,48,166,68,168,22,1,0,48,166,68,137,148,1,0,81,46,85,168,22,1,0,128,0,130,96,116,0,0,130,0,226,92,140,0,0,68,0,226,92,140,0,0,68,1,226,92,140,0,0,84,1,226,92,140,0,0,64,1,226,92,140,0,0,196,17,226,92,140,0,0,128,59,231,83,202,0,0,192,197,16,66,116,68,0,130,128,31,94,248,0,0,68,128,31,94,248,0,0,68,129,31,94,248,0,0,64,129,31,94,248,0,0,130,0,71,8,113,0,0,68,0,71,8,113,0,0,68,1,71,8,113,0,0,64,1,71,8,113,0,0,192,73,241,132,116,0,0,84,129,89,107,206,0,0,130,0,23,99,116,0,0,68,0,23,99,116,0,0,68,1,23,99,116,0,0,84,1,23,99,116,0,0,64,1,23,99,116,0,0,0,68,69,84,4,0,0,0,48,169,173,108,0,0,130,128,24,99,116,0,0,68,128,24,99,116,0,0,68,129,24,99,116,0,0,64,129,24,99,116,0,0,136,196,24,29,33,0,0,64,8,39,165,19,2,0,192,73,233,164,116,1,0,130,0,7,125,244,0,0,68,0,7,125,244,0,0,68,1,7,125,244,0,0,84,1,7,125,244,0,0,64,1,7,125,244,0,0,196,17,7,125,244,0,0,0,0,139,124,178,0,0,0,0,31,66,240,68,0,130,0,23,127,240,0,0,68,0,23,127,240,0,0,68,1,23,127,240,0,0,64,1,23,127,240,0,0,130,0,67,8,33,0,0,68,0,67,8,33,0,0,68,1,67,8,33,0,0,64,1,67,8,33,0,0,192,34,232,99,116,0,0,84,129,23,99,140,0,0,130,0,23,99,116,0,0,68,0,23,99,116,0,0,68,1,23,99,116,0,0,170,0,23,99,116,0,0,64,1,23,99,116,0,0,0,16,240,1,1,0,0,0,48,169,173,108,0,0,130,128,24,99,244,0,0,68,128,24,99,244,0,0,68,129,24,99,244,0,0,64,129,24,99,244,0,0,68,128,24,99,244,208,1,32,132,23,99,124,33,0,64,129,24,99,244,208,1,176,19,1,0,248,18,1,0,184,18,1,0,72,18,1,0,232,17,1,0,152,17,1,0,128,16,1,0,8,16,1,0,12,0,0,0,34,0,0,0,28,0,0,0,42,0,0,0,108,0,0,0,46,0,0,0,36,0,0,0,136,115,1,0,78,0,0,0,22,0,0,0,22,0,0,0,6,0,0,0,20,0,0,0,52,0,0,0,48,0,0,0,104,0,0,0,6,0,0,0,200,75,1,0,0,0,0,0,0,0,0,0,16,75,0,0,56,75,0,0,52,58,51,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,147,169,170,63,49,54,58,57,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,243,142,227,63,49,54,58,49,48,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,205,204,204,63,49,54,58,49,53,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,137,136,136,63,67,111,110,102,105,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,83,113,117,97,114,101,32,112,105,120,101,108,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,63,67,111,114,101,32,112,114,111,118,105,100,101,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,63,67,117,115,116,111,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,79,66,74,91,51,51,93,46,72,70,108,105,112,0,0,0,79,66,74,91,51,51,93,46,86,80,111,115,0,0,0,0,79,66,74,91,51,51,93,46,72,80,111,115,0,0,0,0,79,66,74,91,51,50,93,46,83,105,122,101,0,0,0,0,99,111,110,102,105,103,95,115,97,118,101,95,111,110,95,101,120,105,116,0,0,0,0,0,79,66,74,91,51,50,93,46,80,97,108,101,116,116,101,0,79,66,74,91,51,50,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,79,66,74,91,51,50,93,46,78,97,109,101,0,0,0,0,79,66,74,91,51,50,93,46,86,70,108,105,112,0,0,0,84,114,121,32,39,102,111,114,99,101,32,110,111,45,104,101,97,100,101,114,39,32,111,112,116,105,111,110,32,105,102,32,116,104,101,32,103,97,109,101,32,100,111,101,115,110,39,116,32,119,111,114,107,0,0,0,68,101,98,117,103,32,73,110,102,111,32,77,101,115,115,97,103,101,115,0,0,0,0,0,84,46,77,46,78,46,84,46,0,0,0,0,0,0,0,0,115,105,122,101,0,0,0,0,100,101,99,111,109,112,95,111,102,102,115,101,116,0,0,0,79,66,74,91,51,50,93,46,72,70,108,105,112,0,0,0,79,66,74,91,51,50,93,46,86,80,111,115,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,109,111,118,105,101,32,102,105,108,101,58,32,34,37,115,34,46,10,0,0,69,110,97,98,108,101,32,104,111,116,107,101,121,115,0,0,79,66,74,91,51,50,93,46,72,80,111,115,0,0,0,0,79,66,74,91,51,49,93,46,83,105,122,101,0,0,0,0,79,66,74,91,51,49,93,46,80,97,108,101,116,116,101,0,79,66,74,91,51,49,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,106,111,121,112,97,100,95,97,117,116,111,99,111,110,102,105,103,95,100,105,114,0,0,0,79,66,74,91,51,49,93,46,78,97,109,101,0,0,0,0,79,66,74,91,51,49,93,46,86,70,108,105,112,0,0,0,79,66,74,91,51,49,93,46,72,70,108,105,112,0,0,0,79,66,74,91,51,49,93,46,86,80,111,115,0,0,0,0,84,46,77,46,72,46,84,46,52,0,0,0,0,0,0,0,67,111,110,102,105,103,32,83,97,118,101,32,79,110,32,69,120,105,116,0,0,0,0,0,115,99,97,108,101,95,121,0,100,101,99,111,109,112,95,109,111,100,101,0,0,0,0,0,79,66,74,91,51,49,93,46,72,80,111,115,0,0,0,0,79,66,74,91,51,48,93,46,83,105,122,101,0,0,0,0])
.concat([82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,117,110,109,117,116,101,32,97,117,100,105,111,46,10,0,0,0,79,66,74,91,51,48,93,46,80,97,108,101,116,116,101,0,79,66,74,91,51,48,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,79,66,74,91,51,48,93,46,78,97,109,101,0,0,0,0,79,66,74,91,51,48,93,46,86,70,108,105,112,0,0,0,105,110,112,117,116,95,97,117,116,111,100,101,116,101,99,116,95,101,110,97,98,108,101,0,79,66,74,91,51,48,93,46,72,70,108,105,112,0,0,0,79,66,74,91,51,48,93,46,86,80,111,115,0,0,0,0,79,66,74,91,51,48,93,46,72,80,111,115,0,0,0,0,79,66,74,91,50,57,93,46,83,105,122,101,0,0,0,0,74,89,85,84,69,73,32,83,69,78,75,73,0,0,0,0,82,101,119,105,110,100,32,71,114,97,110,117,108,97,114,105,116,121,0,0,0,0,0,0,115,99,97,108,101,95,120,0,114,116,99,95,115,116,97,116,101,0,0,0,0,0,0,0,79,66,74,91,50,57,93,46,80,97,108,101,116,116,101,0,79,66,74,91,50,57,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,65,117,100,105,111,32,117,110,109,117,116,101,100,46,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,82,79,84,65,84,73,79,78,58,32,37,117,10,0,0,0,0,83,108,111,119,32,109,111,116,105,111,110,0,0,0,0,0,79,66,74,91,50,57,93,46,78,97,109,101,0,0,0,0,79,66,74,91,50,57,93,46,86,70,108,105,112,0,0,0,79,66,74,91,50,57,93,46,72,70,108,105,112,0,0,0,79,66,74,91,50,57,93,46,86,80,111,115,0,0,0,0,105,110,112,117,116,95,100,101,98,117,103,95,101,110,97,98,108,101,0,0,0,0,0,0,79,66,74,91,50,57,93,46,72,80,111,115,0,0,0,0,79,66,74,91,50,56,93,46,83,105,122,101,0,0,0,0,79,66,74,91,50,56,93,46,80,97,108,101,116,116,101,0,79,66,74,91,50,56,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,74,51,0,0,0,0,0,0,82,101,119,105,110,100,0,0,115,99,97,108,101,0,0,0,114,52,56,52,50,0,0,0,79,66,74,91,50,56,93,46,78,97,109,101,0,0,0,0,79,66,74,91,50,56,93,46,86,70,108,105,112,0,0,0,65,117,100,105,111,32,109,117,116,101,100,46,0,0,0,0,79,66,74,91,50,56,93,46,72,70,108,105,112,0,0,0,79,66,74,91,50,56,93,46,86,80,111,115,0,0,0,0,79,66,74,91,50,56,93,46,72,80,111,115,0,0,0,0,79,66,74,91,50,55,93,46,83,105,122,101,0,0,0,0,105,110,112,117,116,95,100,117,116,121,95,99,121,99,108,101,0,0,0,0,0,0,0,0,79,66,74,91,50,55,93,46,80,97,108,101,116,116,101,0,79,66,74,91,50,55,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,79,66,74,91,50,55,93,46,78,97,109,101,0,0,0,0,79,66,74,91,50,55,93,46,86,70,108,105,112,0,0,0,74,79,69,32,38,32,77,65,67,32,50,0,0,0,0,0,78,111,32,111,112,116,105,111,110,115,32,97,118,97,105,108,97,98,108,101,46,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,88,77,76,58,32,73,110,118,97,108,105,100,32,112,114,111,112,101,114,116,121,32,102,111,114,32,102,105,108,116,101,114,46,10,0,0,114,52,56,52,49,0,0,0,79,66,74,91,50,55,93,46,72,70,108,105,112,0,0,0,79,66,74,91,50,55,93,46,86,80,111,115,0,0,0,0,86,111,108,117,109,101,58,32,37,46,49,102,32,100,66,0,78,101,116,112,108,97,121,32,102,108,105,112,32,112,108,97,121,101,114,115,0,0,0,0,79,66,74,91,50,55,93,46,72,80,111,115,0,0,0,0,79,66,74,91,50,54,93,46,83,105,122,101,0,0,0,0,79,66,74,91,50,54,93,46,80,97,108,101,116,116,101,0,79,66,74,91,50,54,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,105,110,112,117,116,95,116,117,114,98,111,95,112,101,114,105,111,100,0,0,0,0,0,0,79,66,74,91,50,54,93,46,78,97,109,101,0,0,0,0,61,61,61,32,67,111,110,102,105,103,32,61,61,61,10,0,79,66,74,91,50,54,93,46,86,70,108,105,112,0,0,0,79,66,74,91,50,54,93,46,72,70,108,105,112,0,0,0,79,66,74,91,50,54,93,46,86,80,111,115,0,0,0,0,74,79,69,32,65,78,68,32,77,65,67,0,0,0,0,0,82,97,116,101,32,67,111,110,116,114,111,108,32,68,101,108,116,97,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,88,77,76,58,32,83,104,97,100,101,114,32,102,111,114,99,101,115,32,71,76,95,76,73,78,69,65,82,46,10,0,0,0,0,0,0,0,114,52,56,52,48,0,0,0,79,66,74,91,50,54,93,46,72,80,111,115,0,0,0,0,79,66,74,91,50,53,93,46,83,105,122,101,0,0,0,0,79,66,74,91,50,53,93,46,80,97,108,101,116,116,101,0,79,66,74,91,50,53,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,65,100,106,117,115,116,105,110,103,32,97,115,112,101,99,116,32,114,97,116,105,111,32,116,111,32,37,46,50,102,10,0,0,0,0,0,0,79,66,74,91,50,53,93,46,78,97,109,101,0,0,0,0,79,66,74,91,50,53,93,46,86,70,108,105,112,0,0,0,103,97,109,101,95,104,105,115,116,111,114,121,95,115,105,122,101,0,0,0,0,0,0,0,79,66,74,91,50,53,93,46,72,70,108,105,112,0,0,0,79,66,74,91,50,53,93,46,86,80,111,115,0,0,0,0,82,101,116,114,111,65,114,99,104,45,37,109,37,100,45,37,72,37,77,37,83,46,0,0,79,66,74,91,50,53,93,46,72,80,111,115,0,0,0,0,79,66,74,91,50,52,93,46,83,105,122,101,0,0,0,0,65,74,76,0,0,0,0,0,77,117,116,101,32,65,117,100,105,111,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,88,77,76,58,32,83,104,97,100,101,114,32,102,111,114,99,101,115,32,71,76,95,78,69,65,82,69,83,84,46,10,0,0,0,0,0,0,102,120,95,111,102,102,115,101,116,0,0,0,0,0,0,0,79,66,74,91,50,52,93,46,80,97,108,101,116,116,101,0,79,66,74,91,50,52,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,65,117,100,105,111,32,109,117,116,101,32,116,111,103,103,108,101,0,0,0,0,0,0,0,79,66,74,91,50,52,93,46,78,97,109,101,0,0,0,0,79,66,74,91,50,52,93,46,86,70,108,105,112,0,0,0,82,101,116,114,111,65,114,99,104,58,32,76,111,97,100,105,110,103,32,115,116,97,116,101,58,32,34,37,115,34,46,10,0,0,0,0,0,0,0,0,79,66,74,91,50,52,93,46,72,70,108,105,112,0,0,0,79,66,74,91,50,52,93,46,86,80,111,115,0,0,0,0,103,97,109,101,95,104,105,115,116,111,114,121,95,112,97,116,104,0,0,0,0,0,0,0,79,66,74,91,50,52,93,46,72,80,111,115,0,0,0,0,79,66,74,91,50,51,93,46,83,105,122,101,0,0,0,0,79,66,74,91,50,51,93,46,80,97,108,101,116,116,101,0,79,66,74,91,50,51,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,65,50,74,0,0,0,0,0,68,105,115,107,32,73,109,97,103,101,32,65,112,112,101,110,100,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,73,110,118,97,108,105,100,32,76,85,84,32,102,105,108,116,101,114,32,116,121,112,101,46,10,0,0,101,120,95,111,102,102,115,101,116,0,0,0,0,0,0,0,79,66,74,91,50,51,93,46,78,97,109,101,0,0,0,0,79,66,74,91,50,51,93,46,86,70,108,105,112,0,0,0,82,105,103,104,116,0,0,0,82,101,116,114,111,65,114,99,104,58,32,71,114,97,98,32,109,111,117,115,101,32,115,116,97,116,101,58,32,37,115,46,10,0,0,0,0,0,0,0,79,66,74,91,50,51,93,46,72,70,108,105,112,0,0,0,77,111,117,115,101,50,32,76,0,0,0,0,0,0,0,0,79,66,74,91,50,51,93,46,86,80,111,115,0,0,0,0,103,108,67,111,112,121,84,101,120,83,117,98,73,109,97,103,101,51,68,79,69,83,0,0,117,110,105,102,111,114,109,32,115,97,109,112,108,101,114,50,68,32,84,101,120,116,117,114,101,59,10,105,110,32,118,101,99,50,32,116,101,120,95,99,111,111,114,100,59,10,105,110,32,118,101,99,52,32,99,111,108,111,114,59,10,111,117,116,32,118,101,99,52,32,70,114,97,103,67,111,108,111,114,59,10,118,111,105,100,32,109,97,105,110,40,41,32,123,10,32,32,32,70,114,97,103,67,111,108,111,114,32,61,32,99,111,108,111,114,32,42,32,116,101,120,116,117,114,101,40,84,101,120,116,117,114,101,44,32,116,101,120,95,99,111,111,114,100,41,59,10,125,0,0,0,0,79,66,74,91,50,51,93,46,72,80,111,115,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,71,76,93,58,32,70,97,105,108,101,100,32,116,111,32,99,114,101,97,116,101,32,72,87,32,114,101,110,100,101,114,32,70,66,79,32,35,37,117,44,32,101,114,114,111,114,58,32,48,120,37,117,46,10,0,0,0,0,79,66,74,91,50,50,93,46,83,105,122,101,0,0,0,0,115,116,100,105,110,95,99,109,100,95,101,110,97,98,108,101,0,0,0,0,0,0,0,0,79,66,74,91,50,50,93,46,80,97,108,101,116,116,101,0,79,66,74,91,50,50,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,79,66,74,91,50,50,93,46,78,97,109,101,0,0,0,0,115,116,121,108,101,0,0,0,79,66,74,91,50,50,93,46,86,70,108,105,112,0,0,0,74,111,121,112,97,100,53,32,68,111,119,110,0,0,0,0,83,116,114,101,101,116,32,70,105,103,104,116,101,114,50,32,84,117,114,98,111,49,0,0,68,105,115,107,32,73,110,100,101,120,0,0,0,0,0,0,111,118,101,114,108,97,121,37,117,95,110,97,109,101,0,0,110,101,97,114,101,115,116,0,100,120,95,111,102,102,115,101,116,0,0,0,0,0,0,0,79,66,74,91,50,50,93,46,72,70,108,105,112,0,0,0,60,33,45,45,0,0,0,0,114,98,0,0,0,0,0,0,83,82,65,0,0,0,0,0,79,66,74,91,50,50,93,46,86,80,111,115,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,114,101,115,117,109,101,32,97,117,100,105,111,32,100,114,105,118,101,114,46,32,87,105,108,108,32,99,111,110,116,105,110,117,101,32,119,105,116,104,111,117,116,32,97,117,100,105,111,46,10,0,0,0,0,0,0,0,68,83,80,32,99,111,110,102,105,103,0,0,0,0,0,0,79,66,74,91,50,50,93,46,72,80,111,115,0,0,0,0,79,66,74,91,50,49,93,46,83,105,122,101,0,0,0,0,79,66,74,91,50,49,93,46,80,97,108,101,116,116,101,0,79,66,74,91,50,49,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,110,101,116,119,111,114,107,95,99,109,100,95,112,111,114,116,0,0,0,0,0,0,0,0,79,66,74,91,50,49,93,46,78,97,109,101,0,0,0,0,79,66,74,91,50,49,93,46,86,70,108,105,112,0,0,0,79,66,74,91,50,49,93,46,72,70,108,105,112,0,0,0,79,66,74,91,50,49,93,46,86,80,111,115,0,0,0,0,74,111,121,112,97,100,53,32,85,112,0,0,0,0,0,0,83,101,99,114,101,116,32,111,102,32,77,65,78,65,0,0,69,115,116,105,109,97,116,101,100,32,77,111,110,105,116,111,114,32,70,80,83,0,0,0,108,105,110,101,97,114,0,0,114,52,56,51,52,0,0,0,79,66,74,91,50,49,93,46,72,80,111,115,0,0,0,0,79,66,74,91,50,48,93,46,83,105,122,101,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,85,110,112,97,117,115,101,100,46,10,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,109,101,109,111,114,121,32,102,111,114,32,114,101,119,105,110,100,32,98,117,102,102,101,114,46,10,0,0,0,0,0,0,79,66,74,91,50,48,93,46,80,97,108,101,116,116,101,0,79,66,74,91,50,48,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,79,66,74,91,50,48,93,46,78,97,109,101,0,0,0,0,79,66,74,91,50,48,93,46,86,70,108,105,112,0,0,0,110,101,116,119,111,114,107,95,99,109,100,95,101,110,97,98,108,101,0,0,0,0,0,0,79,66,74,91,50,48,93,46,72,70,108,105,112,0,0,0,79,66,74,91,50,48,93,46,86,80,111,115,0,0,0,0,79,66,74,91,50,48,93,46,72,80,111,115,0,0,0,0,79,66,74,91,49,57,93,46,83,105,122,101,0,0,0,0,74,111,121,112,97,100,53,32,82,105,103,104,116,0,0,0,65,51,67,0,0,0,0,0,72,97,114,100,32,71,80,85,32,83,121,110,99,32,70,114,97,109,101,115,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,32,110,111,116,32,102,105,110,100,32,102,105,108,101,110,97,109,101,32,105,110,32,116,101,120,116,117,114,101,46,10,0,0,0,0,0,0,0,114,52,56,51,51,0,0,0,79,66,74,91,49,57,93,46,80,97,108,101,116,116,101,0,79,66,74,91,49,57,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,80,97,117,115,101,100,46,10,0,0,0,0,0,84,97,107,101,32,115,99,114,101,101,110,115,104,111,116,0,79,66,74,91,49,57,93,46,78,97,109,101,0,0,0,0,79,66,74,91,49,57,93,46,86,70,108,105,112,0,0,0,79,66,74,91,49,57,93,46,72,70,108,105,112,0,0,0,79,66,74,91,49,57,93,46,86,80,111,115,0,0,0,0,115,97,118,101,115,116,97,116,101,95,97,117,116,111,95,108,111,97,100,0,0,0,0,0,79,66,74,91,49,57,93,46,72,80,111,115,0,0,0,0,83,116,97,114,116,32,98,117,116,116,111,110,0,0,0,0,79,66,74,91,49,56,93,46,83,105,122,101,0,0,0,0,79,66,74,91,49,56,93,46,80,97,108,101,116,116,101,0,79,66,74,91,49,56,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,74,111,121,112,97,100,53,32,76,101,102,116,0,0,0,0,74,73,77,32,80,79,87,69,82,32,84,72,69,32,76,79,83,84,32,68,73,79,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,77,111,118,105,101,32,102,111,114,109,97,116,32,115,101,101,109,115,32,116,111,32,104,97,118,101,32,97,32,100,105,102,102,101,114,101,110,116,32,115,101,114,105,97,108,105,122,101,114,32,118,101,114,115,105,111,110,46,32,87,105,108,108,32,109,111,115,116,32,108,105,107,101,108,121,32,102,97,105,108,46,10,0,0,72,97,114,100,32,71,80,85,32,83,121,110,99,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,32,110,111,116,32,102,105,110,100,32,73,68,32,105,110,32,116,101,120,116,117,114,101,46,10,0,0,0,0,0,114,52,56,51,50,0,0,0,79,66,74,91,49,56,93,46,78,97,109,101,0,0,0,0,79,66,74,91,49,56,93,46,86,70,108,105,112,0,0,0,82,101,97,99,104,101,100,32,101,110,100,32,111,102,32,114,101,119,105,110,100,32,98,117,102,102,101,114,46,0,0,0,79,66,74,91,49,56,93,46,72,70,108,105,112,0,0,0,79,66,74,91,49,56,93,46,86,80,111,115,0,0,0,0,79,66,74,91,49,56,93,46,72,80,111,115,0,0,0,0,79,66,74,91,49,55,93,46,83,105,122,101,0,0,0,0,115,97,118,101,115,116,97,116,101,95,97,117,116,111,95,115,97,118,101,0,0,0,0,0,79,66,74,91,49,55,93,46,80,97,108,101,116,116,101,0,79,66,74,91,49,55,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,79,66,74,91,49,55,93,46,78,97,109,101,0,0,0,0,79,66,74,91,49,55,93,46,86,70,108,105,112,0,0,0,74,111,121,112,97,100,53,32,82,0,0,0,0,0,0,0,65,87,74,0,0,0,0,0,86,83,121,110,99,0,0,0,102,105,108,116,101,114,0,0,114,52,56,51,49,0,0,0,79,66,74,91,49,55,93,46,72,70,108,105,112,0,0,0,79,66,74,91,49,55,93,46,86,80,111,115,0,0,0,0,82,101,119,105,110,100,105,110,103,46,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,77,69,83,83,65,71,69,58,32,37,115,10,0,0,0,0,0,67,104,101,97,116,32,116,111,103,103,108,101,0,0,0,0,79,66,74,91,49,55,93,46,72,80,111,115,0,0,0,0,79,66,74,91,49,54,93,46,83,105,122,101,0,0,0,0,79,66,74,91,49,54,93,46,80,97,108,101,116,116,101,0,79,66,74,91,49,54,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,115,97,118,101,115,116,97,116,101,95,97,117,116,111,95,105,110,100,101,120,0,0,0,0,79,66,74,91,49,54,93,46,78,97,109,101,0,0,0,0,79,66,74,91,49,54,93,46,86,70,108,105,112,0,0,0,79,66,74,91,49,54,93,46,72,70,108,105,112,0,0,0,79,66,74,91,49,54,93,46,86,80,111,115,0,0,0,0,74,111,121,112,97,100,53,32,76,0,0,0,0,0,0,0,80,101,114,102,101,99,116,32,69,108,101,118,101,110,0,0,82,111,116,97,116,105,111,110,0,0,0,0,0,0,0,0,102,105,108,101,0,0,0,0,114,52,56,51,48,0,0,0,79,66,74,91,49,54,93,46,72,80,111,115,0,0,0,0,79,66,74,91,49,53,93,46,83,105,122,101,0,0,0,0,83,108,111,119,32,109,111,116,105,111,110,46,0,0,0,0,79,66,74,91,49,53,93,46,80,97,108,101,116,116,101,0,79,66,74,91,49,53,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,79,66,74,91,49,53,93,46,78,97,109,101,0,0,0,0,79,66,74,91,49,53,93,46,86,70,108,105,112,0,0,0,98,108,111,99,107,95,115,114,97,109,95,111,118,101,114,119,114,105,116,101,0,0,0,0,79,66,74,91,49,53,93,46,72,70,108,105,112,0,0,0,79,66,74,91,49,53,93,46,86,80,111,115,0,0,0,0,79,66,74,91,49,53,93,46,72,80,111,115,0,0,0,0,79,66,74,91,49,52,93,46,83,105,122,101,0,0,0,0,74,111,121,112,97,100,53,32,83,116,97,114,116,0,0,0,85,46,78,46,83,113,117,97,100,114,111,110,0,0,0,0,84,111,103,103,108,101,32,70,117,108,108,115,99,114,101,101,110,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,84,111,111,32,109,97,110,121,32,116,101,120,116,117,114,101,32,105,109,97,103,101,115,46,32,73,103,110,111,114,105,110,103,32,46,46,46,10,0,0,0,0,0,0,114,52,56,50,102,0,0,0,79,66,74,91,49,52,93,46,80,97,108,101,116,116,101,0,79,66,74,91,49,52,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,83,108,111,119,32,109,111,116,105,111,110,32,114,101,119,105,110,100,46,0,0,0,0,0,67,104,101,97,116,32,105,110,100,101,120,32,45,0,0,0,79,66,74,91,49,52,93,46,78,97,109,101,0,0,0,0,79,66,74,91,49,52,93,46,86,70,108,105,112,0,0,0,79,66,74,91,49,52,93,46,72,70,108,105,112,0,0,0,79,66,74,91,49,52,93,46,86,80,111,115,0,0,0,0,99,104,101,97,116,95,115,101,116,116,105,110,103,115,95,112,97,116,104,0,0,0,0,0,79,66,74,91,49,52,93,46,72,80,111,115,0,0,0,0,79,66,74,91,49,51,93,46,83,105,122,101,0,0,0,0,79,66,74,91,49,51,93,46,80,97,108,101,116,116,101,0,79,66,74,91,49,51,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,74,111,121,112,97,100,53,32,83,101,108,101,99,116,0,0,65,82,69,65,56,56,0,0,67,117,115,116,111,109,32,82,97,116,105,111,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,78,111,32,82,65,77,32,97,100,100,114,101,115,115,32,115,112,101,99,105,102,105,99,101,100,32,102,111,114,32,105,109,112,111,114,116,32,118,97,108,117,101,46,10,0,0,0,0,0,0,0,114,52,56,50,101,0,0,0,79,66,74,91,49,51,93,46,78,97,109,101,0,0,0,0,79,66,74,91,49,51,93,46,86,70,108,105,112,0,0,0,82,101,116,114,111,65,114,99,104,58,32,77,111,118,105,101,32,112,108,97,121,98,97,99,107,32,101,110,100,101,100,46,10,0,0,0,0,0,0,0,79,66,74,91,49,51,93,46,72,70,108,105,112,0,0,0,79,66,74,91,49,51,93,46,86,80,111,115,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,65,117,100,105,111,32,114,97,116,101,32,99,111,110,116,114,111,108,32,119,97,115,32,100,101,115,105,114,101,100,44,32,98,117,116,32,100,114,105,118,101,114,32,100,111,101,115,32,110,111,116,32,115,117,112,112,111,114,116,32,110,101,101,100,101,100,32,102,101,97,116,117,114,101,115,46,10,0,0,0,0,0,0,0,79,66,74,91,49,51,93,46,72,80,111,115,0,0,0,0,79,66,74,91,49,50,93,46,83,105,122,101,0,0,0,0,99,104,101,97,116,95,100,97,116,97,98,97,115,101,95,112,97,116,104,0,0,0,0,0,79,66,74,91,49,50,93,46,80,97,108,101,116,116,101,0,79,66,74,91,49,50,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,102,105,108,101,95,112,97,116,104,46,99,0,0,0,0,0,79,66,74,91,49,50,93,46,78,97,109,101,0,0,0,0,79,66,74,91,49,50,93,46,86,70,108,105,112,0,0,0,37,115,32,124,124,32,70,80,83,58,32,37,54,46,49,102,32,124,124,32,70,114,97,109,101,115,58,32,37,100,0,0,74,111,121,112,97,100,53,32,89,0,0,0,0,0,0,0,83,117,112,101,114,32,77,101,116,114,111,105,100,0,0,0,65,115,112,101,99,116,32,82,97,116,105,111,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,73,110,118,97,108,105,100,32,105,110,112,117,116,32,115,108,111,116,32,102,111,114,32,105,109,112,111,114,116,46,10,0,0,0,0,109,101,110,117,95,116,111,103,103,108,101,0,0,0,0,0,114,52,56,50,100,0,0,0,79,66,74,91,49,50,93,46,72,70,108,105,112,0,0,0,79,66,74,91,49,50,93,46,86,80,111,115,0,0,0,0,77,111,118,105,101,32,112,108,97,121,98,97,99,107,32,101,110,100,101,100,46,0,0,0,67,104,101,97,116,32,105,110,100,101,120,32,43,0,0,0,79,66,74,91,49,50,93,46,72,80,111,115,0,0,0,0,79,66,74,91,49,49,93,46,83,105,122,101,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,115,97,118,101,32,115,116,97,116,101,32,116,111,32,34,37,115,34,46,10,0,0,0,0,0,79,66,74,91,49,49,93,46,80,97,108,101,116,116,101,0,79,66,74,91,49,49,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,97,117,116,111,115,97,118,101,95,105,110,116,101,114,118,97,108,0,0,0,0,0,0,0,79,66,74,91,49,49,93,46,78,97,109,101,0,0,0,0,79,66,74,91,49,49,93,46,86,70,108,105,112,0,0,0,79,66,74,91,49,49,93,46,72,70,108,105,112,0,0,0,79,66,74,91,49,49,93,46,86,80,111,115,0,0,0,0,74,111,121,112,97,100,53,32,88,0,0,0,0,0,0,0,65,68,56,0,0,0,0,0,73,110,116,101,103,101,114,32,83,99,97,108,101,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,73,110,118,97,108,105,100,32,115,101,109,97,110,116,105,99,32,102,111,114,32,105,109,112,111,114,116,32,118,97,108,117,101,46,10,0,0,0,0,0,0,0,0,103,114,97,98,95,109,111,117,115,101,95,116,111,103,103,108,101,0,0,0,0,0,0,0,114,52,56,50,99,0,0,0,79,66,74,91,49,49,93,46,72,80,111,115,0,0,0,0,79,66,74,91,49,48,93,46,83,105,122,101,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,115,116,97,114,116,32,109,111,118,105,101,32,114,101,99,111,114,100,46,10,0,0,0,0,0,79,66,74,91,49,48,93,46,80,97,108,101,116,116,101,0,76,101,102,116,0,0,0,0,77,111,117,115,101,49,32,82,0,0,0,0,0,0,0,0,79,66,74,91,49,48,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,103,108,84,101,120,83,117,98,73,109,97,103,101,51,68,79,69,83,0,0,0,0,0,0,35,105,102,100,101,102,32,71,76,95,69,83,10,112,114,101,99,105,115,105,111,110,32,109,101,100,105,117,109,112,32,102,108,111,97,116,59,10,35,101,110,100,105,102,10,117,110,105,102,111,114,109,32,115,97,109,112,108,101,114,50,68,32,84,101,120,116,117,114,101,59,10,118,97,114,121,105,110,103,32,118,101,99,50,32,116,101,120,95,99,111,111,114,100,59,10,118,97,114,121,105,110,103,32,118,101,99,52,32,99,111,108,111,114,59,10,118,111,105,100,32,109,97,105,110,40,41,32,123,10,32,32,32,103,108,95,70,114,97,103,67,111,108,111,114,32,61,32,99,111,108,111,114,32,42,32,116,101,120,116,117,114,101,50,68,40,84,101,120,116,117,114,101,44,32,116,101,120,95,99,111,111,114,100,41,59,10,125,0,0,0,0,79,66,74,91,49,48,93,46,78,97,109,101,0,0,0,0,79,69,83,95,112,97,99,107,101,100,95,100,101,112,116,104,95,115,116,101,110,99,105,108,0,0,0,0,0,0,0,0,79,66,74,91,49,48,93,46,86,70,108,105,112,0,0,0,112,97,117,115,101,95,110,111,110,97,99,116,105,118,101,0,79,66,74,91,49,48,93,46,72,70,108,105,112,0,0,0,79,66,74,91,49,48,93,46,86,80,111,115,0,0,0,0,79,66,74,91,49,48,93,46,72,80,111,115,0,0,0,0,71,76,83,76,0,0,0,0,79,66,74,91,57,93,46,83,105,122,101,0,0,0,0,0,74,111,121,112,97,100,53,32,66,0,0,0,0,0,0,0,68,79,78,75,69,89,32,75,79,78,71,32,67,79,85,78,84,82,89,0,0,0,0,0,83,104,97,100,101,114,32,79,112,116,105,111,110,115,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,67,111,110,102,105,103,32,107,101,121,58,32,37,115,32,105,115,32,110,111,116,32,115,101,116,46,10,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,78,111,32,115,101,109,97,110,116,105,99,32,111,114,32,73,68,32,102,111,114,32,105,109,112,111,114,116,32,118,97,108,117,101,46,10,0,0,0,0,0,0,0,100,105,115,107,95,110,101,120,116,0,0,0,0,0,0,0,114,52,56,50,98,0,0,0,79,66,74,91,57,93,46,80,97,108,101,116,116,101,0,0,61,34,0,0,0,0,0,0,82,65,77,0,0,0,0,0,79,66,74,91,57,93,46,80,114,105,111,114,105,116,121,0,82,101,116,114,111,65,114,99,104,58,32,83,116,97,114,116,105,110,103,32,109,111,118,105,101,32,114,101,99,111,114,100,32,116,111,32,34,37,115,34,46,10,0,0,0,0,0,0,79,66,74,91,57,93,46,78,97,109,101,0,0,0,0,0,80,114,101,118,105,111,117,115,32,115,104,97,100,101,114,0,79,66,74,91,57,93,46,86,70,108,105,112,0,0,0,0,79,66,74,91,57,93,46,72,70,108,105,112,0,0,0,0,79,66,74,91,57,93,46,86,80,111,115,0,0,0,0,0,102,97,115,116,102,111,114,119,97,114,100,95,114,97,116,105,111,0,0,0,0,0,0,0,79,66,74,91,57,93,46,72,80,111,115,0,0,0,0,0,79,66,74,91,56,93,46,83,105,122,101,0,0,0,0,0,79,66,74,91,56,93,46,80,97,108,101,116,116,101,0,0,79,66,74,91,56,93,46,80,114,105,111,114,105,116,121,0,74,111,121,112,97,100,53,32,65,0,0,0,0,0,0,0,83,84,65,82,32,70,79,88,32,50,0,0,0,0,0,0,83,104,97,100,101,114,32,35,37,117,32,83,99,97,108,101,0,0,0,0,0,0,0,0,101,113,117,97,108,0,0,0,100,105,115,107,95,101,106,101,99,116,95,116,111,103,103,108,101,0,0,0,0,0,0,0,114,52,56,50,97,0,0,0,79,66,74,91,56,93,46,78,97,109,101,0,0,0,0,0,79,66,74,91,56,93,46,86,70,108,105,112,0,0,0,0,70,97,105,108,101,100,32,116,111,32,115,116,97,114,116,32,109,111,118,105,101,32,114,101,99,111,114,100,46,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,73,109,112,108,101,109,101,110,116,97,116,105,111,110,32,100,111,101,115,32,110,111,116,32,115,117,112,112,111,114,116,32,115,97,118,101,32,115,116,97,116,101,115,46,32,67,97,110,110,111,116,32,117,115,101,32,114,101,119,105,110,100,46,10,0,0,0,79,66,74,91,56,93,46,72,70,108,105,112,0,0,0,0,79,66,74,91,56,93,46,86,80,111,115,0,0,0,0,0,79,66,74,91,56,93,46,72,80,111,115,0,0,0,0,0,79,66,74,91,55,93,46,83,105,122,101,0,0,0,0,0,115,108,111,119,109,111,116,105,111,110,95,114,97,116,105,111,0,0,0,0,0,0,0,0,79,66,74,91,55,93,46,80,97,108,101,116,116,101,0,0,79,66,74,91,55,93,46,80,114,105,111,114,105,116,121,0,79,66,74,91,55,93,46,78,97,109,101,0,0,0,0,0,79,66,74,91,55,93,46,86,70,108,105,112,0,0,0,0,74,111,121,112,97,100,52,32,68,111,119,110,0,0,0,0,83,84,65,82,32,87,73,78,71,0,0,0,0,0,0,0,83,104,97,100,101,114,32,35,37,117,32,70,105,108,116,101,114,0,0,0,0,0,0,0,109,97,115,107,0,0,0,0,111,118,101,114,108,97,121,95,110,101,120,116,0,0,0,0,114,52,56,50,57,0,0,0,79,66,74,91,55,93,46,72,70,108,105,112,0,0,0,0,79,66,74,91,55,93,46,86,80,111,115,0,0,0,0,0,83,116,97,114,116,105,110,103,32,109,111,118,105,101,32,114,101,99,111,114,100,32,116,111,32,34,37,115,34,46,0,0,78,101,120,116,32,115,104,97,100,101,114,0,0,0,0,0,79,66,74,91,55,93,46,72,80,111,115,0,0,0,0,0,79,66,74,91,54,93,46,83,105,122,101,0,0,0,0,0,79,66,74,91,54,93,46,80,97,108,101,116,116,101,0,0,79,66,74,91,54,93,46,80,114,105,111,114,105,116,121,0,114,101,119,105,110,100,95,103,114,97,110,117,108,97,114,105,116,121,0,0,0,0,0,0,79,66,74,91,54,93,46,78,97,109,101,0,0,0,0,0,79,66,74,91,54,93,46,86,70,108,105,112,0,0,0,0,79,66,74,91,54,93,46,72,70,108,105,112,0,0,0,0,79,66,74,91,54,93,46,86,80,111,115,0,0,0,0,0,74,111,121,112,97,100,52,32,85,112,0,0,0,0,0,0,83,84,65,82,32,70,79,88,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,110,39,116,32,114,101,97,100,32,115,116,97,116,101,32,102,114,111,109,32,109,111,118,105,101,46,10,0,0,0,83,104,97,100,101,114,32,35,37,117,0,0,0,0,0,0,105,110,112,117,116,95,115,108,111,116,0,0,0,0,0,0,118,111,108,117,109,101,95,100,111,119,110,0,0,0,0,0,114,52,56,50,56,0,0,0,79,66,74,91,54,93,46,72,80,111,115,0,0,0,0,0,79,66,74,91,53,93,46,83,105,122,101,0,0,0,0,0,37,115,46,98,115,118,0,0,79,66,74,91,53,93,46,80,97,108,101,116,116,101,0,0,79,66,74,91,53,93,46,80,114,105,111,114,105,116,121,0,79,66,74,91,53,93,46,78,97,109,101,0,0,0,0,0,79,66,74,91,53,93,46,86,70,108,105,112,0,0,0,0,114,101,119,105,110,100,95,98,117,102,102,101,114,95,115,105,122,101,0,0,0,0,0,0,79,66,74,91,53,93,46,72,70,108,105,112,0,0,0,0,79,66,74,91,53,93,46,86,80,111,115,0,0,0,0,0,79,66,74,91,53,93,46,72,80,111,115,0,0,0,0,0,79,66,74,91,52,93,46,83,105,122,101,0,0,0,0,0,74,111,121,112,97,100,52,32,82,105,103,104,116,0,0,0,83,117,112,101,114,32,83,116,114,101,101,116,32,70,105,103,104,116,101,114,50,49,0,0,83,104,97,100,101,114,32,80,97,115,115,101,115,0,0,0,119,114,97,109,0,0,0,0,118,111,108,117,109,101,95,117,112,0,0,0,0,0,0,0,114,52,56,50,55,0,0,0,79,66,74,91,52,93,46,80,97,108,101,116,116,101,0,0,79,66,74,91,52,93,46,80,114,105,111,114,105,116,121,0,37,115,37,117,46,98,115,118,0,0,0,0,0,0,0,0,46,114,101,116,114,111,97,114,99,104,45,99,111,114,101,45,111,112,116,105,111,110,115,46,99,102,103,0,0,0,0,0,82,101,115,101,116,32,103,97,109,101,0,0,0,0,0,0,79,66,74,91,52,93,46,78,97,109,101,0,0,0,0,0,79,66,74,91,52,93,46,86,70,108,105,112,0,0,0,0,79,66,74,91,52,93,46,72,70,108,105,112,0,0,0,0,79,66,74,91,52,93,46,86,80,111,115,0,0,0,0,0,114,101,119,105,110,100,95,101,110,97,98,108,101,0,0,0,79,66,74,91,52,93,46,72,80,111,115,0,0,0,0,0,79,66,74,91,51,93,46,83,105,122,101,0,0,0,0,0,79,66,74,91,51,93,46,80,97,108,101,116,116,101,0,0,79,66,74,91,51,93,46,80,114,105,111,114,105,116,121,0,74,111,121,112,97,100,52,32,76,101,102,116,0,0,0,0,86,79,82,84,69,88,0,0,76,111,97,100,32,83,104,97,100,101,114,32,80,114,101,115,101,116,0,0,0,0,0,0,115,101,109,97,110,116,105,99,0,0,0,0,0,0,0,0,101,110,97,98,108,101,95,104,111,116,107,101,121,0,0,0,114,52,56,50,54,0,0,0,79,66,74,91,51,93,46,78,97,109,101,0,0,0,0,0,79,66,74,91,51,93,46,86,70,108,105,112,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,116,111,112,112,105,110,103,32,109,111,118,105,101,32,114,101,99,111,114,100,46,10,0,0,0,0,0,0,79,66,74,91,51,93,46,72,70,108,105,112,0,0,0,0,79,66,74,91,51,93,46,86,80,111,115,0,0,0,0,0,79,66,74,91,51,93,46,72,80,111,115,0,0,0,0,0,79,66,74,91,50,93,46,83,105,122,101,0,0,0,0,0,105,110,112,117,116,95,111,118,101,114,108,97,121,95,115,99,97,108,101,0,0,0,0,0,79,66,74,91,50,93,46,80,97,108,101,116,116,101,0,0,79,66,74,91,50,93,46,80,114,105,111,114,105,116,121,0,79,66,74,91,50,93,46,78,97,109,101,0,0,0,0,0,79,66,74,91,50,93,46,86,70,108,105,112,0,0,0,0,74,111,121,112,97,100,52,32,82,0,0,0,0,0,0,0,82,79,77,65,78,67,73,78,71,32,83,65,71,65,51,0,68,101,102,97,117,108,116,32,70,105,108,116,101,114,0,0,105,100,0,0,0,0,0,0,115,108,111,119,109,111,116,105,111,110,0,0,0,0,0,0,114,52,56,50,53,0,0,0,79,66,74,91,50,93,46,72,70,108,105,112,0,0,0,0,79,66,74,91,50,93,46,86,80,111,115,0,0,0,0,0,83,116,111,112,112,105,110,103,32,109,111,118,105,101,32,114,101,99,111,114,100,46,0,0,70,114,97,109,101,97,100,118,97,110,99,101,0,0,0,0,79,66,74,91,50,93,46,72,80,111,115,0,0,0,0,0,79,66,74,91,49,93,46,83,105,122,101,0,0,0,0,0,79,66,74,91,49,93,46,80,97,108,101,116,116,101,0,0,79,66,74,91,49,93,46,80,114,105,111,114,105,116,121,0,105,110,112,117,116,95,111,118,101,114,108,97,121,95,111,112,97,99,105,116,121,0,0,0,79,66,74,91,49,93,46,78,97,109,101,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,97,112,112,101,110,100,32,99,111,110,102,105,103,32,34,37,115,34,10,0,0,0,0,0,0,79,66,74,91,49,93,46,86,70,108,105,112,0,0,0,0,79,66,74,91,49,93,46,72,70,108,105,112,0,0,0,0,79,66,74,91,49,93,46,86,80,111,115,0,0,0,0,0,74,111,121,112,97,100,52,32,76,0,0,0,0,0,0,0,83,101,105,107,101,110,68,101,110,115,101,116,115,117,51,83,97,109,112,108,101,49,0,0,37,102,0,0,0,0,0,0,65,112,112,108,121,32,83,104,97,100,101,114,32,67,104,97,110,103,101,115,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,84,111,111,32,109,97,110,121,32,105,109,112,111,114,116,32,118,97,114,105,97,98,108,101,115,32,46,46,46,10,0,0,0,0,0,110,101,116,112,108,97,121,95,102,108,105,112,95,112,108,97,121,101,114,115,0,0,0,0,114,52,56,50,52,0,0,0,79,66,74,91,49,93,46,72,80,111,115,0,0,0,0,0,79,66,74,91,48,93,46,83,105,122,101,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,97,112,112,108,121,32,115,104,97,100,101,114,46,10,0,0,0,0,79,66,74,91,48,93,46,80,97,108,101,116,116,101,0,0,79,66,74,91,48,93,46,80,114,105,111,114,105,116,121,0,79,66,74,91,48,93,46,78,97,109,101,0,0,0,0,0,40,100,101,102,97,117,108,116,41,0,0,0,0,0,0,0,79,66,74,91,48,93,46,86,70,108,105,112,0,0,0,0,105,110,112,117,116,95,111,118,101,114,108,97,121,0,0,0,79,66,74,91,48,93,46,72,70,108,105,112,0,0,0,0,79,66,74,91,48,93,46,86,80,111,115,0,0,0,0,0,79,66,74,91,48,93,46,72,80,111,115,0,0,0,0,0,67,71,68,65,84,65,0,0,74,111,121,112,97,100,52,32,83,116,97,114,116,0,0,0,83,101,105,107,101,110,68,101,110,115,101,116,115,117,51,0,37,115,32,40,37,100,44,32,37,100,32,58,32,37,52,117,120,37,52,117,41,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,97,110,110,111,116,32,102,105,110,100,32,80,121,116,104,111,110,32,115,99,114,105,112,116,46,10,0,0,0,0,0,0,0,0,97,117,100,105,111,95,109,117,116,101,0,0,0,0,0,0,114,52,56,50,51,0,0,0,67,71,65,68,68,0,0,0,67,71,70,76,73,80,82,101,97,100,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,65,112,112,108,121,105,110,103,32,115,104,97,100,101,114,32,34,37,115,34,46,10,0,0,0,0,0,0,0,80,97,117,115,101,32,116,111,103,103,108,101,0,0,0,0,67,71,70,76,73,80,0,0,66,71,51,80,114,105,111,114,105,116,121,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,116,97,116,101,32,115,105,122,101,58,32,37,100,32,98,121,116,101,115,46,10,0,0,0,0,0,0,0,66,71,77,111,100,101,0,0,66,71,91,51,93,46,83,67,83,105,122,101,0,0,0,0,111,118,101,114,108,97,121,95,100,105,114,101,99,116,111,114,121,0,0,0,0,0,0,0,66,71,91,51,93,46,78,97,109,101,66,97,115,101,0,0,66,71,91,51,93,46,66,71,83,105,122,101,0,0,0,0,66,71,91,51,93,46,86,79,102,102,115,101,116,0,0,0,66,71,91,51,93,46,72,79,102,102,115,101,116,0,0,0,74,111,121,112,97,100,52,32,83,101,108,101,99,116,0,0,65,51,53,0,0,0,0,0,83,101,116,32,66,111,116,116,111,109,45,82,105,103,104,116,32,67,111,114,110,101,114,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,83,99,114,105,112,116,32,108,97,110,103,117,97,103,101,32,105,115,32,110,111,116,32,80,121,116,104,111,110,46,10,0,0,0,0,100,115,112,95,99,111,110,102,105,103,0,0,0,0,0,0,114,52,56,50,50,0,0,0,66,71,91,51,93,46,83,67,66,97,115,101,0,0,0,0,66,71,91,50,93,46,83,67,83,105,122,101,0,0,0,0,83,104,97,100,101,114,32,35,37,117,58,32,34,37,115,34,46,0,0,0,0,0,0,0,66,71,91,50,93,46,78,97,109,101,66,97,115,101,0,0,77,111,117,115,101,49,32,76,0,0,0,0,0,0,0,0,66,71,91,50,93,46,66,71,83,105,122,101,0,0,0,0,68,111,119,110,0,0,0,0,103,108,84,101,120,73,109,97,103,101,51,68,79,69,83,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,105,110,105,116,32,115,116,97,116,101,32,116,114,97,99,107,101,114,46,10,0,0,0,0,0,0,66,71,91,50,93,46,86,79,102,102,115,101,116,0,0,0,82,101,116,114,111,65,114,99])
.concat([104,58,32,91,71,76,93,58,32,77,97,120,32,116,101,120,116,117,114,101,32,115,105,122,101,58,32,37,100,32,112,120,44,32,114,101,110,100,101,114,98,117,102,102,101,114,32,115,105,122,101,58,32,37,117,32,112,120,46,10,0,0,0,0,66,71,91,50,93,46,72,79,102,102,115,101,116,0,0,0,114,103,117,105,95,98,114,111,119,115,101,114,95,100,105,114,101,99,116,111,114,121,0,0,66,71,91,50,93,46,83,67,66,97,115,101,0,0,0,0,78,47,65,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,66,105,116,32,100,101,112,116,104,32,111,102,32,84,71,65,32,105,109,97,103,101,32,105,115,32,119,114,111,110,103,46,32,79,110,108,121,32,51,50,45,98,105,116,32,97,110,100,32,50,52,45,98,105,116,32,115,117,112,112,111,114,116,101,100,46,10,0,0,0,0,0,0,0,0,66,71,91,49,93,46,83,67,83,105,122,101,0,0,0,0,66,71,91,49,93,46,78,97,109,101,66,97,115,101,0,0,108,97,110,103,117,97,103,101,0,0,0,0,0,0,0,0,66,71,91,49,93,46,66,71,83,105,122,101,0,0,0,0,74,111,121,112,97,100,52,32,89,0,0,0,0,0,0,0,66,105,103,32,83,107,121,32,84,114,111,111,112,101,114,0,83,101,116,32,85,112,112,101,114,45,76,101,102,116,32,67,111,114,110,101,114,0,0,0,111,118,101,114,108,97,121,37,117,95,111,118,101,114,108,97,121,0,0,0,0,0,0,0,99,108,97,115,115,0,0,0,115,99,114,101,101,110,115,104,111,116,0,0,0,0,0,0,114,52,56,50,49,0,0,0,66,71,91,49,93,46,86,79,102,102,115,101,116,0,0,0,32,10,9,12,11,13,0,0,86,82,65,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,9,9,37,115,10,0,0,0,0,0,0,0,0,66,71,91,49,93,46,72,79,102,102,115,101,116,0,0,0,46,99,103,112,0,0,0,0,77,111,118,105,101,32,114,101,99,111,114,100,32,116,111,103,103,108,101,0,0,0,0,0,66,71,91,49,93,46,83,67,66,97,115,101,0,0,0,0,66,71,91,48,93,46,83,67,83,105,122,101,0,0,0,0,66,71,91,48,93,46,78,97,109,101,66,97,115,101,0,0,66,71,91,48,93,46,66,71,83,105,122,101,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,115,99,114,101,101,110,115,104,111,116,95,100,105,114,101,99,116,111,114,121,32,105,115,32,110,111,116,32,97,110,32,101,120,105,115,116,105,110,103,32,100,105,114,101,99,116,111,114,121,44,32,105,103,110,111,114,105,110,103,32,46,46,46,10,0,0,0,0,66,71,91,48,93,46,86,79,102,102,115,101,116,0,0,0,66,71,91,48,93,46,72,79,102,102,115,101,116,0,0,0,66,71,91,48,93,46,83,67,66,97,115,101,0,0,0,0,87,82,65,77,0,0,0,0,74,111,121,112,97,100,52,32,88,0,0,0,0,0,0,0,80,79,82,75,89,32,80,73,71,83,32,72,65,85,78,84,69,68,0,0,0,0,0,0,37,115,32,40,37,52,117,120,37,52,117,44,32,37,117,32,120,32,37,117,32,115,99,97,108,101,41,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,83,99,114,105,112,116,32,97,108,114,101,97,100,121,32,105,109,112,111,114,116,101,100,46,10,0,0,99,104,101,97,116,95,116,111,103,103,108,101,0,0,0,0,114,52,56,50,48,0,0,0,86,77,65,46,83,104,105,102,116,0,0,0,0,0,0,0,86,77,65,46,70,117,108,108,71,114,97,112,104,105,99,67,111,117,110,116,0,0,0,0,46,99,103,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,73,109,112,108,101,109,101,110,116,97,116,105,111,110,32,117,115,101,115,32,116,104,114,101,97,100,101,100,32,97,117,100,105,111,46,32,67,97,110,110,111,116,32,117,115,101,32,114,101,119,105,110,100,46,10,0,0,0,0,86,77,65,46,77,97,115,107,49,0,0,0,0,0,0,0,86,77,65,46,65,100,100,114,101,115,115,0,0,0,0,0,86,77,65,46,73,110,99,114,101,109,101,110,116,0,0,0,86,77,65,46,72,105,103,104,0,0,0,0,0,0,0,0,115,99,114,101,101,110,115,104,111,116,95,100,105,114,101,99,116,111,114,121,0,0,0,0,100,109,97,91,55,93,46,68,111,84,114,97,110,115,102,101,114,0,0,0,0,0,0,0,100,109,97,91,55,93,46,85,110,107,110,111,119,110,66,121,116,101,0,0,0,0,0,0,100,109,97,91,55,93,46,76,105,110,101,67,111,117,110,116,0,0,0,0,0,0,0,0,100,109,97,91,55,93,46,82,101,112,101,97,116,0,0,0,74,111,121,112,97,100,52,32,66,0,0,0,0,0,0,0,68,79,79,77,32,84,82,79,79,80,69,82,83,0,0,0,83,101,116,32,115,99,97,108,101,0,0,0,0,0,0,0,63,63,63,0,0,0,0,0,99,104,101,97,116,95,105,110,100,101,120,95,109,105,110,117,115,0,0,0,0,0,0,0,114,52,56,49,53,95,108,97,116,99,104,0,0,0,0,0,100,109,97,91,55,93,46,65,100,100,114,101,115,115,0,0,100,109,97,91,55,93,46,73,110,100,105,114,101,99,116,66,97,110,107,0,0,0,0,0,46,115,104,97,100,101,114,0,100,109,97,91,55,93,46,68,77,65,67,111,117,110,116,95,79,114,95,72,68,77,65,73,110,100,105,114,101,99,116,65,100,100,114,101,115,115,0,0,100,109,97,91,55,93,46,65,66,97,110,107,0,0,0,0,100,109,97,91,55,93,46,65,65,100,100,114,101,115,115,0,100,109,97,91,55,93,46,66,65,100,100,114,101,115,115,0,99,111,114,101,95,111,112,116,105,111,110,115,95,112,97,116,104,0,0,0,0,0,0,0,100,109,97,91,55,93,46,84,114,97,110,115,102,101,114,77,111,100,101,0,0,0,0,0,83,101,108,101,99,116,32,98,117,116,116,111,110,0,0,0,100,109,97,91,55,93,46,65,65,100,100,114,101,115,115,68,101,99,114,101,109,101,110,116,0,0,0,0,0,0,0,0,100,109,97,91,55,93,46,65,65,100,100,114,101,115,115,70,105,120,101,100,0,0,0,0,100,109,97,91,55,93,46,85,110,117,115,101,100,66,105,116,52,51,120,48,0,0,0,0,74,111,121,112,97,100,52,32,65,0,0,0,0,0,0,0,80,82,73,77,65,76,32,82,65,71,69,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,83,101,116,116,105,110,103,32,82,71,85,73,32,67,71,80,32,102,97,105,108,101,100,46,10,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,67,82,67,51,50,32,99,104,101,99,107,115,117,109,32,109,105,115,109,97,116,99,104,32,98,101,116,119,101,101,110,32,82,79,77,32,102,105,108,101,32,97,110,100,32,115,97,118,101,100,32,82,79,77,32,99,104,101,99,107,115,117,109,32,105,110,32,114,101,112,108,97,121,32,102,105,108,101,32,104,101,97,100,101,114,59,32,114,101,112,108,97,121,32,104,105,103,104,108,121,32,108,105,107,101,108,121,32,116,111,32,100,101,115,121,110,99,32,111,110,32,112,108,97,121,98,97,99,107,46,10,0,109,105,114,114,111,114,101,100,95,114,101,112,101,97,116,0,99,104,101,97,116,95,105,110,100,101,120,95,112,108,117,115,0,0,0,0,0,0,0,0,114,52,56,49,52,95,108,97,116,99,104,0,0,0,0,0,100,109,97,91,55,93,46,72,68,77,65,73,110,100,105,114,101,99,116,65,100,100,114,101,115,115,105,110,103,0,0,0,100,109,97,91,55,93,46,82,101,118,101,114,115,101,84,114,97,110,115,102,101,114,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,71,111,116,32,105,110,118,97,108,105,100,32,100,105,115,107,32,105,110,100,101,120,32,102,114,111,109,32,108,105,98,114,101,116,114,111,46,10,0,0,0,0,0,100,109,97,91,54,93,46,68,111,84,114,97,110,115,102,101,114,0,0,0,0,0,0,0,100,109,97,91,54,93,46,85,110,107,110,111,119,110,66,121,116,101,0,0,0,0,0,0,100,109,97,91,54,93,46,76,105,110,101,67,111,117,110,116,0,0,0,0,0,0,0,0,100,109,97,91,54,93,46,82,101,112,101,97,116,0,0,0,108,105,98,114,101,116,114,111,95,112,97,116,104,0,0,0,100,109,97,91,54,93,46,65,100,100,114,101,115,115,0,0,100,109,97,91,54,93,46,73,110,100,105,114,101,99,116,66,97,110,107,0,0,0,0,0,100,109,97,91,54,93,46,68,77,65,67,111,117,110,116,95,79,114,95,72,68,77,65,73,110,100,105,114,101,99,116,65,100,100,114,101,115,115,0,0,100,109,97,91,54,93,46,65,66,97,110,107,0,0,0,0,74,111,121,112,97,100,51,32,68,111,119,110,0,0,0,0,84,72,69,32,77,65,83,75,0,0,0,0,0,0,0,0,78,47,65,32,40,115,116,111,99,107,41,0,0,0,0,0,114,101,112,101,97,116,0,0,115,104,97,100,101,114,95,112,114,101,118,0,0,0,0,0,114,52,56,49,120,0,0,0,100,109,97,91,54,93,46,65,65,100,100,114,101,115,115,0,100,109,97,91,54,93,46,66,65,100,100,114,101,115,115,0,82,101,116,114,111,65,114,99,104,58,32,66,83,82,77,58,32,37,115,10,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,86,65,82,73,65,66,76,69,83,46,10,0,0,0,0,0,0,83,97,118,101,115,116,97,116,101,32,115,108,111,116,32,45,0,0,0,0,0,0,0,0,100,109,97,91,54,93,46,84,114,97,110,115,102,101,114,77,111,100,101,0,0,0,0,0,100,109,97,91,54,93,46,65,65,100,100,114,101,115,115,68,101,99,114,101,109,101,110,116,0,0,0,0,0,0,0,0,100,109,97,91,54,93,46,65,65,100,100,114,101,115,115,70,105,120,101,100,0,0,0,0,100,109,97,91,54,93,46,85,110,117,115,101,100,66,105,116,52,51,120,48,0,0,0,0,105,110,112,117,116,95,106,111,121,112,97,100,95,100,114,105,118,101,114,0,0,0,0,0,100,109,97,91,54,93,46,72,68,77,65,73,110,100,105,114,101,99,116,65,100,100,114,101,115,115,105,110,103,0,0,0,100,109,97,91,54,93,46,82,101,118,101,114,115,101,84,114,97,110,115,102,101,114,0,0,100,109,97,91,53,93,46,68,111,84,114,97,110,115,102,101,114,0,0,0,0,0,0,0,100,109,97,91,53,93,46,85,110,107,110,111,119,110,66,121,116,101,0,0,0,0,0,0,74,111,121,112,97,100,51,32,85,112,0,0,0,0,0,0,77,83,80,65,67,77,65,78,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,101,116,116,105,110,103,32,82,71,85,73,32,115,104,97,100,101,114,58,32,37,115,46,10,0,0,0,0,99,108,97,109,112,95,116,111,95,101,100,103,101,0,0,0,115,104,97,100,101,114,95,110,101,120,116,0,0,0,0,0,114,52,56,49,56,0,0,0,100,109,97,91,53,93,46,76,105,110,101,67,111,117,110,116,0,0,0,0,0,0,0,0,100,109,97,91,53,93,46,82,101,112,101,97,116,0,0,0,82,101,116,114,111,65,114,99,104,58,32,65,83,82,77,58,32,37,115,10,0,0,0,0,100,109,97,91,53,93,46,65,100,100,114,101,115,115,0,0,100,109,97,91,53,93,46,73,110,100,105,114,101,99,116,66,97,110,107,0,0,0,0,0,100,109,97,91,53,93,46,68,77,65,67,111,117,110,116,95,79,114,95,72,68,77,65,73,110,100,105,114,101,99,116,65,100,100,114,101,115,115,0,0,100,109,97,91,53,93,46,65,66,97,110,107,0,0,0,0,100,109,97,91,53,93,46,65,65,100,100,114,101,115,115,0,100,109,97,91,53,93,46,66,65,100,100,114,101,115,115,0,100,109,97,91,53,93,46,84,114,97,110,115,102,101,114,77,111,100,101,0,0,0,0,0,100,109,97,91,53,93,46,65,65,100,100,114,101,115,115,68,101,99,114,101,109,101,110,116,0,0,0,0,0,0,0,0,74,111,121,112,97,100,51,32,82,105,103,104,116,0,0,0,78,66,65,32,72,97,110,103,116,105,109,101,0,0,0,0,37,115,32,40,37,115,41,0,99,108,97,109,112,95,116,111,95,98,111,114,100,101,114,0,114,101,115,101,116,0,0,0,114,52,56,49,55,0,0,0,100,109,97,91,53,93,46,65,65,100,100,114,101,115,115,70,105,120,101,100,0,0,0,0,100,109,97,91,53,93,46,85,110,117,115,101,100,66,105,116,52,51,120,48,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,97,118,105,110,103,32,83,117,102,97,109,105,32,116,117,114,98,111,32,65,47,66,32,82,65,77,46,10,0,0,0,0,0,0,0,0,100,109,97,91,53,93,46,72,68,77,65,73,110,100,105,114,101,99,116,65,100,100,114,101,115,115,105,110,103,0,0,0,83,97,118,101,115,116,97,116,101,32,115,108,111,116,32,43,0,0,0,0,0,0,0,0,100,109,97,91,53,93,46,82,101,118,101,114,115,101,84,114,97,110,115,102,101,114,0,0,100,109,97,91,52,93,46,68,111,84,114,97,110,115,102,101,114,0,0,0,0,0,0,0,100,109,97,91,52,93,46,85,110,107,110,111,119,110,66,121,116,101,0,0,0,0,0,0,97,117,100,105,111,95,100,115,112,95,112,108,117,103,105,110,0,0,0,0,0,0,0,0,100,109,97,91,52,93,46,76,105,110,101,67,111,117,110,116,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,65,112,112,101,110,100,105,110,103,32,99,111,110,102,105,103,32,34,37,115,34,10,0,0,0,0,0,0,0,100,109,97,91,52,93,46,82,101,112,101,97,116,0,0,0,100,109,97,91,52,93,46,65,100,100,114,101,115,115,0,0,100,109,97,91,52,93,46,73,110,100,105,114,101,99,116,66,97,110,107,0,0,0,0,0,74,111,121,112,97,100,51,32,76,101,102,116,0,0,0,0,69,65,82,84,72,87,79,82,77,32,74,73,77,32,50,0,60,85,115,101,32,116,104,105,115,32,100,105,114,101,99,116,111,114,121,62,0,0,0,0,97,98,115,111,108,117,116,101,0,0,0,0,0,0,0,0,100,109,97,91,52,93,46,68,77,65,67,111,117,110,116,95,79,114,95,72,68,77,65,73,110,100,105,114,101,99,116,65,100,100,114,101,115,115,0,0,102,114,97,109,101,95,97,100,118,97,110,99,101,0,0,0,114,52,56,49,54,0,0,0,37,48,50,120,0,0,0,0,100,109,97,91,52,93,46,65,66,97,110,107,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,80,83,82,77,58,32,37,115,10,0,0,0,0,100,109,97,91,52,93,46,65,65,100,100,114,101,115,115,0,100,109,97,91,52,93,46,66,65,100,100,114,101,115,115,0,100,109,97,91,52,93,46,84,114,97,110,115,102,101,114,77,111,100,101,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,105,110,105,116,105,97,108,105,122,101,32,114,101,115,97,109,112,108,101,114,32,34,37,115,34,46,10,0,0,0,0,0,0,100,109,97,91,52,93,46,65,65,100,100,114,101,115,115,68,101,99,114,101,109,101,110,116,0,0,0,0,0,0,0,0,97,117,100,105,111,95,100,114,105,118,101,114,0,0,0,0,100,109,97,91,52,93,46,65,65,100,100,114,101,115,115,70,105,120,101,100,0,0,0,0,100,109,97,91,52,93,46,85,110,117,115,101,100,66,105,116,52,51,120,48,0,0,0,0,100,109,97,91,52,93,46,72,68,77,65,73,110,100,105,114,101,99,116,65,100,100,114,101,115,115,105,110,103,0,0,0,100,109,97,91,52,93,46,82,101,118,101,114,115,101,84,114,97,110,115,102,101,114,0,0,74,111,121,112,97,100,51,32,82,0,0,0,0,0,0,0,83,65,78,75,89,79,32,70,101,118,101,114,33,32,204,168,176,202,222,176,33,0,0,0,37,115,124,122,105,112,0,0,118,105,101,119,112,111,114,116,0,0,0,0,0,0,0,0,112,97,117,115,101,95,116,111,103,103,108,101,0,0,0,0,114,52,56,49,53,0,0,0,100,109,97,91,51,93,46,68,111,84,114,97,110,115,102,101,114,0,0,0,0,0,0,0,100,109,97,91,51,93,46,85,110,107,110,111,119,110,66,121,116,101,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,82,77,58,32,32,37,115,10,0,0,0,0,100,109,97,91,51,93,46,76,105,110,101,67,111,117,110,116,0,0,0,0,0,0,0,0,100,109,97,91,51,93,46,82,101,112,101,97,116,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,109,101,109,111,114,121,32,102,111,114,32,115,97,118,101,32,115,116,97,116,101,32,98,117,102,102,101,114,46,10,0,0,100,109,97,91,51,93,46,65,100,100,114,101,115,115,0,0,100,109,97,91,51,93,46,73,110,100,105,114,101,99,116,66,97,110,107,0,0,0,0,0,118,105,100,101,111,95,103,108,95,99,111,110,116,101,120,116,0,0,0,0,0,0,0,0,100,109,97,91,51,93,46,68,77,65,67,111,117,110,116,95,79,114,95,72,68,77,65,73,110,100,105,114,101,99,116,65,100,100,114,101,115,115,0,0,100,109,97,91,51,93,46,65,66,97,110,107,0,0,0,0,100,109,97,91,51,93,46,65,65,100,100,114,101,115,115,0,100,109,97,91,51,93,46,66,65,100,100,114,101,115,115,0,74,111,121,112,97,100,51,32,76,0,0,0,0,0,0,0,72,69,73,87,65,32,80,97,114,108,111,114,33,77,105,110,105,56,0,0,0,0,0,0,99,102,103,0,0,0,0,0,115,111,117,114,99,101,0,0,109,111,118,105,101,95,114,101,99,111,114,100,95,116,111,103,103,108,101,0,0,0,0,0,114,52,56,49,52,0,0,0,100,109,97,91,51,93,46,84,114,97,110,115,102,101,114,77,111,100,101,0,0,0,0,0,100,109,97,91,51,93,46,65,65,100,100,114,101,115,115,68,101,99,114,101,109,101,110,116,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,97,118,105,110,103,32,66,83,88,32,40,80,41,82,65,77,46,10,0,0,100,109,97,91,51,93,46,65,65,100,100,114,101,115,115,70,105,120,101,100,0,0,0,0,80,111,105,110,116,101,114,32,77,111,117,115,101,50,0,0,80,76,84,69,0,0,0,0,100,109,97,91,51,93,46,85,110,117,115,101,100,66,105,116,52,51,120,48,0,0,0,0,103,108,71,101,116,66,117,102,102,101,114,80,111,105,110,116,101,114,118,79,69,83,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,71,76,93,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,76,85,84,115,46,10,0,0,0,0,0,0,0,0,100,109,97,91,51,93,46,72,68,77,65,73,110,100,105,114,101,99,116,65,100,100,114,101,115,115,105,110,103,0,0,0,85,112,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,71,76,93,58,32,73,110,105,116,105,97,108,105,122,105,110,103,32,72,87,32,114,101,110,100,101,114,32,40,37,117,32,120,32,37,117,41,46,10,0,0,0,0,0,100,109,97,91,51,93,46,82,101,118,101,114,115,101,84,114,97,110,115,102,101,114,0,0,100,109,97,91,50,93,46,68,111,84,114,97,110,115,102,101,114,0,0,0,0,0,0,0,118,105,100,101,111,95,100,114,105,118,101,114,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,84,71,65,32,112,105,120,101,108,115,46,10,0,0,0,0,100,109,97,91,50,93,46,85,110,107,110,111,119,110,66,121,116,101,0,0,0,0,0,0,100,109,97,91,50,93,46,76,105,110,101,67,111,117,110,116,0,0,0,0,0,0,0,0,115,104,97,100,101,114,0,0,100,109,97,91,50,93,46,82,101,112,101,97,116,0,0,0,74,111,121,112,97,100,51,32,83,116,97,114,116,0,0,0,80,97,114,108,111,114,0,0,99,103,124,103,108,115,108,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,67,111,117,108,100,110,39,116,32,102,105,110,100,32,111,118,101,114,108,97,121,32,99,97,108,108,101,100,58,32,34,37,115,34,46,10,0,0,0,0,115,99,97,108,101,95,37,115,37,117,0,0,0,0,0,0,114,101,119,105,110,100,0,0,114,52,56,49,51,0,0,0,67,104,101,97,116,58,32,35,37,117,32,91,37,115,93,58,32,37,115,0,0,0,0,0,100,109,97,91,50,93,46,65,100,100,114,101,115,115,0,0,60,47,0,0,0,0,0,0,68,77,65,0,0,0,0,0,46,99,104,116,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,9,80,111,115,115,105,98,108,101,32,118,97,108,117,101,115,58,10,0,0,0,100,109,97,91,50,93,46,73,110,100,105,114,101,99,116,66,97,110,107,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,97,118,105,110,103,32,71,97,109,101,98,111,121,32,83,82,65,77,46,10,0,0,0,0,0,0,0,0,100,109,97,91,50,93,46,68,77,65,67,111,117,110,116,95,79,114,95,72,68,77,65,73,110,100,105,114,101,99,116,65,100,100,114,101,115,115,0,0,70,117,108,108,115,99,114,101,101,110,32,116,111,103,103,108,101,0,0,0,0,0,0,0,100,109,97,91,50,93,46,65,66,97,110,107,0,0,0,0,100,109,97,91,50,93,46,65,65,100,100,114,101,115,115,0,100,109,97,91,50,93,46,66,65,100,100,114,101,115,115,0,100,109,97,91,50,93,46,84,114,97,110,115,102,101,114,77,111,100,101,0,0,0,0,0,97,117,100,105,111,95,118,111,108,117,109,101,0,0,0,0,100,109,97,91,50,93,46,65,65,100,100,114,101,115,115,68,101,99,114,101,109,101,110,116,0,0,0,0,0,0,0,0,100,109,97,91,50,93,46,65,65,100,100,114,101,115,115,70,105,120,101,100,0,0,0,0,100,109,97,91,50,93,46,85,110,117,115,101,100,66,105,116,52,51,120,48,0,0,0,0,74,111,121,112,97,100,51,32,83,101,108,101,99,116,0,0,84,72,69,32,70,73,83,72,73,78,71,32,77,65,83,84,69,82,0,0,0,0,0,0,99,103,112,124,103,108,115,108,112,0,0,0,0,0,0,0,115,99,97,108,101,95,116,121,112,101,95,37,115,37,117,0,115,116,97,116,101,95,115,108,111,116,95,100,101,99,114,101,97,115,101,0,0,0,0,0,114,52,56,49,50,0,0,0,100,109,97,91,50,93,46,72,68,77,65,73,110,100,105,114,101,99,116,65,100,100,114,101,115,115,105,110,103,0,0,0,100,109,97,91,50,93,46,82,101,118,101,114,115,101,84,114,97,110,115,102,101,114,0,0,82,101,116,114,111,65,114,99,104,58,32,82,84,67,58,32,37,115,10,0,0,0,0,0,114,101,116,114,111,97,114,99,104,46,99,0,0,0,0,0,100,109,97,91,49,93,46,68,111,84,114,97,110,115,102,101,114,0,0,0,0,0,0,0,100,109,97,91,49,93,46,85,110,107,110,111,119,110,66,121,116,101,0,0,0,0,0,0,100,109,97,91,49,93,46,76,105,110,101,67,111,117,110,116,0,0,0,0,0,0,0,0,100,109,97,91,49,93,46,82,101,112,101,97,116,0,0,0,100,109,97,91,49,93,46,65,100,100,114,101,115,115,0,0,97,117,100,105,111,95,114,97,116,101,95,99,111,110,116,114,111,108,95,100,101,108,116,97,0,0,0,0,0,0,0,0,100,109,97,91,49,93,46,73,110,100,105,114,101,99,116,66,97,110,107,0,0,0,0,0,100,109,97,91,49,93,46,68,77,65,67,111,117,110,116,95,79,114,95,72,68,77,65,73,110,100,105,114,101,99,116,65,100,100,114,101,115,115,0,0,100,109,97,91,49,93,46,65,66,97,110,107,0,0,0,0,74,111,121,112,97,100,51,32,89,0,0,0,0,0,0,0,76,69,84,115,32,80,65,67,72,73,78,75,79,40,0,0,47,0,0,0,0,0,0,0,121,0,0,0,0,0,0,0,115,116,97,116,101,95,115,108,111,116,95,105,110,99,114,101,97,115,101,0,0,0,0,0,114,52,56,49,49,0,0,0,100,109,97,91,49,93,46,65,65,100,100,114,101,115,115,0,100,109,97,91,49,93,46,66,65,100,100,114,101,115,115,0,82,101,116,114,111,65,114,99,104,58,32,83,82,77,58,32,37,115,10,0,0,0,0,0,100,109,97,91,49,93,46,84,114,97,110,115,102,101,114,77,111,100,101,0,0,0,0,0,83,97,118,101,32,115,116,97,116,101,0,0,0,0,0,0,100,109,97,91,49,93,46,65,65,100,100,114,101,115,115,68,101,99,114,101,109,101,110,116,0,0,0,0,0,0,0,0,100,109,97,91,49,93,46,65,65,100,100,114,101,115,115,70,105,120,101,100,0,0,0,0,100,109,97,91,49,93,46,85,110,117,115,101,100,66,105,116,52,51,120,48,0,0,0,0,100,109,97,91,49,93,46,72,68,77,65,73,110,100,105,114,101,99,116,65,100,100,114,101,115,115,105,110,103,0,0,0,97,117,100,105,111,95,114,97,116,101,95,99,111,110,116,114,111,108,0,0,0,0,0,0,100,109,97,91,49,93,46,82,101,118,101,114,115,101,84,114,97,110,115,102,101,114,0,0,100,109,97,91,48,93,46,68,111,84,114,97,110,115,102,101,114,0,0,0,0,0,0,0,100,109,97,91,48,93,46,85,110,107,110,111,119,110,66,121,116,101,0,0,0,0,0,0,74,111,121,112,97,100,51,32,88,0,0,0,0,0,0,0,83,87,79,82,68,32,87,79,82,76,68,32,83,70,67,0,37,99,32,37,45,42,46,42,115,32,37,45,42,115,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,77,111,118,105,101,32,102,105,108,101,32,105,115,32,110,111,116,32,97,32,118,97,108,105,100,32,66,83,86,49,32,102,105,108,101,46,10,0,0,0,0,0,0,101,120,105,116,95,101,109,117,108,97,116,111,114,0,0,0,114,52,56,48,99,0,0,0,100,109,97,91,48,93,46,76,105,110,101,67,111,117,110,116,0,0,0,0,0,0,0,0,100,109,97,91,48,93,46,82,101,112,101,97,116,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,97,118,105,110,103,32,114,101,103,117,108,97,114,32,83,82,65,77,46,10,0,0,0,0,0,0,0,0,100,109,97,91,48,93,46,65,100,100,114,101,115,115,0,0,100,109,97,91,48,93,46,73,110,100,105,114,101,99,116,66,97,110,107,0,0,0,0,0,100,109,97,91,48,93,46,68,77,65,67,111,117,110,116,95,79,114,95,72,68,77,65,73,110,100,105,114,101,99,116,65,100,100,114,101,115,115,0,0,100,109,97,91,48,93,46,65,66,97,110,107,0,0,0,0,100,109,97,91,48,93,46,65,65,100,100,114,101,115,115,0,97,117,100,105,111,95,115,121,110,99,0,0,0,0,0,0,100,109,97,91,48,93,46,66,65,100,100,114,101,115,115,0,100,109,97,91,48,93,46,84,114,97,110,115,102,101,114,77,111,100,101,0,0,0,0,0,100,109,97,91,48,93,46,65,65,100,100,114,101,115,115,68,101,99,114,101,109,101,110,116,0,0,0,0,0,0,0,0,74,111,121,112,97,100,51,32,66,0,0,0,0,0,0,0,84,111,107,121,111,68,111,109,101,32,39,57,53,66,97,116,116,108,101,32,55,0,0,0,102,108,111,97,116,95,102,114,97,109,101,98,117,102,102,101,114,37,117,0,0,0,0,0,116,111,103,103,108,101,95,102,117,108,108,115,99,114,101,101,110,0,0,0,0,0,0,0,114,52,56,48,98,0,0,0,100,109,97,91,48,93,46,65,65,100,100,114,101,115,115,70,105,120,101,100,0,0,0,0,100,109,97,91,48,93,46,85,110,117,115,101,100,66,105,116,52,51,120,48,0,0,0,0,102,97,105,108,101,100,0,0,100,109,97,91,48,93,46,72,68,77,65,73,110,100,105,114,101,99,116,65,100,100,114,101,115,115,105,110,103,0,0,0,76,111,97,100,32,115,116,97,116,101,0,0,0,0,0,0,100,109,97,91,48,93,46,82,101,118,101,114,115,101,84,114,97,110,115,102,101,114,0,0,37,115,58,45,45,45,45,45,45,58,0,0,0,0,0,0,37,115,58,37,48,54,100,58,0,0,0,0,0,0,0,0,105,110,116,101,114,110,97,108,0,0,0,0,0,0,0,0,97,117,100,105,111,95,108,97,116,101,110,99,121,0,0,0,112,97,100,95,114,101,97,100,0,0,0,0,0,0,0,0,100,117,109,109,121,51,0,0,106,117,115,116,105,102,105,101,114,95,115,101,108,101,99,116,0,0,0,0,0,0,0,0,74,111,121,112,97,100,51,32,65,0,0,0,0,0,0,0,90,69,78,75,73,32,84,69,78,67,72,73,77,69,73,68,79,85,0,0,0,0,0,0,63,0,0,0,0,0,0,0,115,97,118,101,95,115,116,97,116,101,0,0,0,0,0,0,114,52,56,48,97,0,0,0,109,111,117,115,101,95,115,112,101,101,100,0,0,0,0,0,100,117,109,109,121,50,0,0,115,117,99,99,101,101,100,101,100,0,0,0,0,0,0,0,112,111,114,116,50,95,114,101,97,100,95,105,100,120,0,0,100,117,109,109,121,49,0,0,112,111,114,116,49,95,114,101,97,100,95,105,100,120,0,0,118,101,114,0,0,0,0,0,65,80,85,83,112,101,101,100,117,112,0,0,0,0,0,0,97,117,100,105,111,95,100,101,118,105,99,101,0,0,0,0,73,82,81,80,101,110,100,67,111,117,110,116,0,0,0,0,78,77,73,68,77,65,68,101,108,97,121,0,0,0,0,0,68,77,65,67,80,85,83,121,110,99,0,0,0,0,0,0,74,111,121,112,97,100,50,32,68,111,119,110,0,0,0,0,83,70,67,32,182,210,221,215,178,192,222,176,0,0,0,0,112,121,116,104,111,110,0,0,108,111,97,100,95,115,116,97,116,101,0,0,0,0,0,0,114,52,56,48,57,0,0,0,73,110,116,101,114,108,97,99,101,70,105,101,108,100,0,0,82,101,110,100,101,114,80,111,115,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,65,117,116,111,32,115,97,118,101,32,115,116,97,116,101,32,116,111,32,34,37,115,34,32,37,115,46,10,0,87,82,65,77,82,101,102,114,101,115,104,80,111,115,0,0,70,97,115,116,32,102,111,114,119,97,114,100,32,104,111,108,100,0,0,0,0,0,0,0,78,77,73,84,114,105,103,103,101,114,80,111,115,0,0,0,72,68,77,65,83,116,97,114,116,0,0,0,0,0,0,0,72,68,77,65,73,110,105,116,0,0,0,0,0,0,0,0,72,66,108,97,110,107,69,110,100,0,0,0,0,0,0,0,97,117,100,105,111,95,111,117,116,95,114,97,116,101,0,0,44,0,0,0,0,0,0,0,72,66,108,97,110,107,83,116,97,114,116,0,0,0,0,0,86,95,77,97,120,0,0,0,86,95,77,97,120,95,77,97,115,116,101,114,0,0,0,0,74,111,121,112,97,100,50,32,85,112,0,0,0,0,0,0,77,65,83,84,69,82,83,0,48,0,0,0,0,0,0,0,85,110,107,110,111,119,110,0,116,114,97,110,115,105,116,105,111,110,95,112,114,101,118,105,111,117,115,0,0,0,0,0,104,111,108,100,95,102,97,115,116,95,102,111,114,119,97,114,100,0,0,0,0,0,0,0,114,52,56,48,56,0,0,0,72,95,77,97,120,0,0,0,72,95,77,97,120,95,77,97,115,116,101,114,0,0,0,0,46,97,117,116,111,0,0,0,118,83,67,66,82,68,105,114,116,121,0,0,0,0,0,0,118,73,110,115,116,67,111,117,110,116,0,0,0,0,0,0,118,67,111,117,110,116,101,114,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,105,110,105,116,105,97,108,105,122,101,32,97,117,100,105,111,32,100,114,105,118,101,114,46,32,87,105,108,108,32,99,111,110,116,105,110,117,101,32,119,105,116,104,111,117,116,32,97,117,100,105,111,46,10,0,0,0,97,118,67,97,99,104,101,66,97,99,107,117,112,0,0,0,112,118,67,97,99,104,101,0,97,117,100,105,111,95,101,110,97,98,108,101,0,0,0,0,98,67,97,99,104,101,65,99,116,105,118,101,0,0,0,0,97,112,118,82,97,109,66,97,110,107,91,51,93,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,111,112,101,110,32,100,105,114,101,99,116,111,114,121,58,32,34,37,115,34,10,0,0,0,0,97,112,118,82,97,109,66,97,110,107,91,50,93,0,0,0,74,111,121,112,97,100,50,32,82,105,103,104,116,0,0,0,79,72,77,79,78,79,32,66,76,65,67,75,66,65,83,83,0,0,0,0,0,0,0,0,105,110,32,118,101,99,50,32,84,101,120,67,111,111,114,100,59,10,105,110,32,118,101,99,50,32,86,101,114,116,101,120,67,111,111,114,100,59,10,105,110,32,118,101,99,52,32,67,111,108,111,114,59,10,117,110,105,102,111,114,109,32,109,97,116,52,32,77,86,80,77,97,116,114,105,120,59,10,111,117,116,32,118,101,99,50,32,116,101,120,95,99,111,111,114,100,59,10,118,111,105,100,32,109,97,105,110,40,41,32,123,10,32,32,32,103,108,95,80,111,115,105,116,105,111,110,32,61,32,77,86,80,77,97,116,114,105,120,32,42,32,118,101,99,52,40,86,101,114,116,101,120,67,111,111,114,100,44,32,48,46,48,44,32,49,46,48,41,59,10,32,32,32,116,101,120,95,99,111,111,114,100,32,61,32,84,101,120,67,111,111,114,100,59,10,125,0,0,0,0,83,117,112,101,114,83,99,111,112,101,0,0,0,0,0,0,99,97,112,116,117,114,101,95,112,114,101,118,105,111,117,115,0,0,0,0,0,0,0,0,116,111,103,103,108,101,95,102,97,115,116,95,102,111,114,119,97,114,100,0,0,0,0,0,114,52,56,48,55,0,0,0,97,112,118,82,97,109,66,97,110,107,91,49,93,0,0,0,97,112,118,82,97,109,66,97,110,107,91,48,93,0,0,0,45,118,0,0,0,0,0,0,112,118,80,114,103,66,97,110,107,0,0,0,0,0,0,0,70,97,115,116,32,102,111,114,119,97,114,100,32,116,111,103,103,108,101,0,0,0,0,0,112,118,82,111,109,66,97,110,107,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,97,118,105,110,103,32,115,116,97,116,101,58,32,34,37,115,34,46,10,0,112,118,82,97,109,66,97,110,107,0,0,0,0,0,0,0,118,83,99,114,101,101,110,83,105,122,101,0,0,0,0,0,118,80,114,101,118,83,99,114,101,101,110,72,101,105,103,104,116,0,0,0,0,0,0,0,105,110,112,117,116,95,112,108,97,121,101,114,37,117,95,106,111,121,112,97,100,95,105,110,100,101,120,0,0,0,0,0,118,83,99,114,101,101,110,82,101,97,108,72,101,105,103,104,116,0,0,0,0,0,0,0,118,83,99,114,101,101,110,72,101,105,103,104,116,0,0,0,120,0,0,0,0,0,0,0,74,111,121,112,97,100,50,32,76,101,102,116,0,0,0,0,70,73,83,72,73,78,71,32,84,79,32,66,65,83,83,73,78,71,0,0,0,0,0,0,97,116,116,114,105,98,117,116,101,32,118,101,99,50,32,84,101,120,67,111,111,114,100,59,10,97,116,116,114,105,98,117,116,101,32,118,101,99,50,32,86,101,114,116,101,120,67,111,111,114,100,59,10,97,116,116,114,105,98,117,116,101,32,118,101,99,52,32,67,111,108,111,114,59,10,117,110,105,102,111,114,109,32,109,97,116,52,32,77,86,80,77,97,116,114,105,120,59,10,118,97,114,121,105,110,103,32,118,101,99,50,32,116,101,120,95,99,111,111,114,100,59,10,118,111,105,100,32,109,97,105,110,40,41,32,123,10,32,32,32,103,108,95,80,111,115,105,116,105,111,110,32,61,32,77,86,80,77,97,116,114,105,120,32,42,32,118,101,99,52,40,86,101,114,116,101,120,67,111,111,114,100,44,32,48,46,48,44,32,49,46,48,41,59,10,32,32,32,116,101,120,95,99,111,111,114,100,32,61,32,84,101,120,67,111,111,114,100,59,10,125,0,0,0,74,117,115,116,105,102,105,101,114,115,0,0,0,0,0,0,116,114,97,110,115,105,116,105,111,110,95,99,111,117,110,116,0,0,0,0,0,0,0,0,114,95,121,95,109,105,110,117,115,0,0,0,0,0,0,0,114,52,56,48,54,0,0,0,97,112,118,83,99,114,101,101,110,91,51,49,93,0,0,0,97,112,118,83,99,114,101,101,110,91,51,48,93,0,0,0,45,99,0,0,0,0,0,0,97,112,118,83,99,114,101,101,110,91,50,57,93,0,0,0,80,111,105,110,116,101,114,32,77,111,117,115,101,49,43,83,117,112,101,114,115,99,111,112,101,43,74,117,115,116,105,102,105,101,114,49,0,0,0,0,37,120,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,70,105,108,101,32,67,82,67,32,100,105,102,102,101,114,115,32,102,114,111,109,32,90,73,80,32,67,82,67,46,32,70,105,108,101,58,32,48,120,37,120,44,32,90,73,80,58,32,48,120,37,120,46,10,0,0,0,0,0,0,73,69,78,68,0,0,0,0,97,112,118,83,99,114,101,101,110,91,50,56,93,0,0,0,103,108,85,110,109,97,112,66,117,102,102,101,114,79,69,83,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,71,76,83,76,32,115,116,111,99,107,32,112,114,111,103,114,97,109,115,32,102,97,105,108,101,100,32,116,111,32,99,111,109,112,105,108,101,46,10,0,0,0,0,97,112,118,83,99,114,101,101,110,91,50,55,93,0,0,0,82,101,116,114,111,65,114,99,104,58,32,71,76,58,32,85,115,105,110,103,32,37,117,32,116,101,120,116,117,114,101,115,46,10,0,0,0,0,0,0,97,112,118,83,99,114,101,101,110,91,50,54,93,0,0,0,74,111,121,112,97,100,0,0,97,112,118,83,99,114,101,101,110,91,50,53,93,0,0,0,110,101,116,112,108,97,121,95,99,108,105,101,110,116,95,115,119,97,112,95,105,110,112,117,116,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,76,111,97,100,101,100,32,84,71,65,58,32,40,37,117,120,37,117,32,64,32,37,117,32,98,112,112,41,10,0,0,0,0,0,0,0,0,97,112,118,83,99,114,101,101,110,91,50,52,93,0,0,0,97,112,118,83,99,114,101,101,110,91,50,51,93,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,112,97,114,115,101,32,88,77,76,32,102,105,108,101,58,32,37,115,10,0,0,0,0,0,0,97,112,118,83,99,114,101,101,110,91,50,50,93,0,0,0,74,111,121,112,97,100,50,32,82,0,0,0,0,0,0,0,70,79,82,84,85,78,69,32,81,85,69,83,84,0,0,0,117,110,105,102,111,114,109,32,115,97,109,112,108,101,114,50,68,32,84,101,120,116,117,114,101,59,10,105,110,32,118,101,99,50,32,116,101,120,95,99,111,111,114,100,59,10,111,117,116,32,118,101,99,52,32,70,114,97,103,67,111,108,111,114,59,10,118,111,105,100,32,109,97,105,110,40,41,32,123,10,32,32,32,70,114,97,103,67,111,108,111,114,32,61,32,118,101,99,52,40,116,101,120,116,117,114,101,40,84,101,120,116,117,114,101,44,32,116,101,120,95,99,111,111,114,100,41,46,114,103,98,44,32,49,46,48,41,59,10,125,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,70,97,105,108,101,100,32,116,111,32,114,101,115,111,108,118,101,32,110,101,120,116,32,116,97,114,103,101,116,115,46,10,0,0,0,0,0,0,0,0,116,114,97,110,115,105,116,105,111,110,0,0,0,0,0,0,114,95,121,95,112,108,117,115,0,0,0,0,0,0,0,0,114,52,56,48,53,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,68,105,100,32,110,111,116,32,102,105,110,100,32,97,110,121,32,99,104,101,97,116,115,32,105,110,32,88,77,76,32,102,105,108,101,58,32,37,115,10,0,0,0,97,112,118,83,99,114,101,101,110,91,50,49,93,0,0,0,93,93,62,0,0,0,0,0,80,80,85,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,9,67,117,114,114,101,110,116,32,118,97,108,117,101,58,32,37,115,10,0,0,70,105,120,105,110,103,32,115,119,97,112,112,101,100,32,69,120,72,105,82,79,77,46,46,46,0,0,0,0,0,0,0,97,112,118,83,99,114,101,101,110,91,50,48,93,0,0,0,45,83,0,0,0,0,0,0,97,112,118,83,99,114,101,101,110,91,49,57,93,0,0,0,82,105,103,104,116,32,97,110,97,108,111,103,32,89,45,32,40,117,112,41,0,0,0,0,97,112,118,83,99,114,101,101,110,91,49,56,93,0,0,0,97,112,118,83,99,114,101,101,110,91,49,55,93,0,0,0,97,112,118,83,99,114,101,101,110,91,49,54,93,0,0,0,97,112,118,83,99,114,101,101,110,91,49,53,93,0,0,0,105,110,112,117,116,95,97,120,105,115,95,116,104,114,101,115,104,111,108,100,0,0,0,0,97,112,118,83,99,114,101,101,110,91,49,52,93,0,0,0,97,112,118,83,99,114,101,101,110,91,49,51,93,0,0,0,97,112,118,83,99,114,101,101,110,91,49,50,93,0,0,0,74,111,121,112,97,100,50,32,76,0,0,0,0,0,0,0,195,221,188,201,179,192,0,0,35,105,102,100,101,102,32,71,76,95,69,83,10,112,114,101,99,105,115,105,111,110,32,109,101,100,105,117,109,112,32,102,108,111,97,116,59,10,35,101,110,100,105,102,10,117,110,105,102,111,114,109,32,115,97,109,112,108,101,114,50,68,32,84,101,120,116,117,114,101,59,10,118,97,114,121,105,110,103,32,118,101,99,50,32,116,101,120,95,99,111,111,114,100,59,10,118,111,105,100,32,109,97,105,110,40,41,32,123,10,32,32,32,103,108,95,70,114,97,103,67,111,108,111,114,32,61,32,118,101,99,52,40,116,101,120,116,117,114,101,50,68,40,84,101,120,116,117,114,101,44,32,116,101,120,95,99,111,111,114,100,41,46,114,103,98,44,32,49,46,48,41,59,10,125,0,82,101,116,114,111,65,114,99])
.concat([104,32,91,87,65,82,78,93,32,58,58,32,70,66,79,32,116,101,120,116,117,114,101,115,32,101,120,99,101,101,100,101,100,32,109,97,120,105,109,117,109,32,115,105,122,101,32,111,102,32,71,80,85,32,40,37,117,120,37,117,41,46,32,82,101,115,105,122,105,110,103,32,116,111,32,102,105,116,46,10,0,0,0,0,0,0,0,0,99,97,112,116,117,114,101,0,114,95,120,95,109,105,110,117,115,0,0,0,0,0,0,0,114,52,56,48,52,0,0,0,97,112,118,83,99,114,101,101,110,91,49,49,93,0,0,0,97,112,118,83,99,114,101,101,110,91,49,48,93,0,0,0,45,115,0,0,0,0,0,0,97,112,118,83,99,114,101,101,110,91,57,93,0,0,0,0,97,112,118,83,99,114,101,101,110,91,56,93,0,0,0,0,97,112,118,83,99,114,101,101,110,91,55,93,0,0,0,0,97,112,118,83,99,114,101,101,110,91,54,93,0,0,0,0,97,112,118,83,99,114,101,101,110,91,53,93,0,0,0,0,100,101,102,97,117,108,116,0,97,112,118,83,99,114,101,101,110,91,52,93,0,0,0,0,97,112,118,83,99,114,101,101,110,91,51,93,0,0,0,0,97,112,118,83,99,114,101,101,110,91,50,93,0,0,0,0,74,111,121,112,97,100,50,32,83,116,97,114,116,0,0,0,82,101,116,114,111,65,114,99,104,58,32,70,66,79,32,112,97,115,115,32,35,37,100,32,105,115,32,102,108,111,97,116,105,110,103,45,112,111,105,110,116,46,10,0,0,0,0,0,77,117,108,116,105,116,97,112,0,0,0,0,0,0,0,0,72,73,79,85,68,69,78,0,37,115,95,101,113,117,97,108,0,0,0,0,0,0,0,0,114,95,120,95,112,108,117,115,0,0,0,0,0,0,0,0,114,52,56,48,51,0,0,0,97,112,118,83,99,114,101,101,110,91,49,93,0,0,0,0,97,112,118,83,99,114,101,101,110,91,48,93,0,0,0,0,45,45,109,101,110,117,0,0,112,118,83,99,114,101,101,110,66,97,115,101,0,0,0,0,82,105,103,104,116,32,97,110,97,108,111,103,32,89,43,32,40,100,111,119,110,41,0,0,118,80,114,101,118,77,111,100,101,0,0,0,0,0,0,0,118,77,111,100,101,0,0,0,110,82,111,109,66,97,110,107,115,0,0,0,0,0,0,0,110,82,97,109,66,97,110,107,115,0,0,0,0,0,0,0,118,105,100,101,111,95,115,104,97,100,101,114,95,100,105,114,0,0,0,0,0,0,0,0,118,83,116,101,112,80,111,105,110,116,0,0,0,0,0,0,89,32,98,117,116,116,111,110,32,40,108,101,102,116,41,0,118,66,114,101,97,107,80,111,105,110,116,0,0,0,0,0,98,66,114,101,97,107,80,111,105,110,116,0,0,0,0,0,74,111,121,112,97,100,50,32,83,101,108,101,99,116,0,0,96,32,32,32,32,32,32,35,32,32,32,32,32,32,32,32,32,32,32,32,32,32,35,32,32,32,32,32,32,32,32,32,32,32,32,32,32,35,32,32,32,32,32,32,32,32,32,32,46,46,46,46,35,46,46,46,46,32,32,32,32,32,32,46,32,32,32,35,32,32,32,46,32,32,32,32,32,32,46,32,32,32,35,32,32,32,46,32,32,32,32,32,32,46,32,32,32,35,32,32,32,46,32,32,32,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,32,32,32,46,32,32,32,35,32,32,32,46,32,32,32,32,32,32,46,32,32,32,35,32,32,32,46,32,32,32,32,32,32,46,32,32,32,35,32,32,32,46,32,32,32,32,32,32,46,46,46,46,35,46,46,46,46,32,32,32,32,32,32,32,32,32,32,35,32,32,32,32,32,32,32,32,32,32,32,32,32,32,35,32,32,32,32,32,32,32,32,32,32,32,32,32,32,35,32,32,32,32,32,32,32,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,79,69,83,95,116,101,120,116,117,114,101,95,102,108,111,97,116,95,108,105,110,101,97,114,32,101,120,116,101,110,115,105,111,110,32,110,111,116,32,102,111,117,110,100,46,10,0,0,0,0,0,74,111,121,112,97,100,32,119,47,32,65,110,97,108,111,103,0,0,0,0,0,0,0,0,90,65,78,51,32,83,70,67,0,0,0,0,0,0,0,0,37,115,95,109,97,115,107,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,110,39,116,32,114,101,97,100,32,109,111,118,105,101,32,104,101,97,100,101,114,46,10,0,0,0,0,0,0,0,108,95,121,95,109,105,110,117,115,0,0,0,0,0,0,0,114,52,56,48,50,0,0,0,118,73,108,108,101,103,97,108,65,100,100,114,101,115,115,0,118,69,114,114,111,114,67,111,100,101,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,78,111,32,82,79,77,44,32,115,116,97,114,116,105,110,103,32,100,117,109,109,121,32,99,111,114,101,46,10,0,0,0,0,0,0,0,0,118,79,118,101,114,102,108,111,119,0,0,0,0,0,0,0,118,67,97,114,114,121,0,0,118,90,101,114,111,0,0,0,118,83,105,103,110,0,0,0,118,80,105,112,101,65,100,114,0,0,0,0,0,0,0,0,118,105,100,101,111,95,103,112,117,95,115,99,114,101,101,110,115,104,111,116,0,0,0,0,118,80,105,112,101,0,0,0,118,82,111,109,66,117,102,102,101,114,0,0,0,0,0,0,112,118,83,114,101,103,0,0,74,111,121,112,97,100,50,32,89,0,0,0,0,0,0,0,96,32,32,46,35,32,32,32,32,32,35,46,32,32,32,32,32,32,46,35,32,32,32,32,32,35,46,32,32,32,32,32,32,46,35,32,32,32,32,32,35,46,32,32,32,46,46,46,46,35,32,32,32,32,32,35,46,46,46,46,35,35,35,35,35,32,32,32,32,32,35,35,35,35,35,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,35,35,35,35,35,32,32,32,32,32,35,35,35,35,35,46,46,46,46,35,32,32,32,32,32,35,46,46,46,46,32,32,32,46,35,32,32,32,32,32,35,46,32,32,32,32,32,32,46,35,32,32,32,32,32,35,46,32,32,32,32,32,32,46,35,32,32,32,32,32,35,46,32,32,32,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,104,97,100,101,114,32,108,111,103,58,32,37,115,10,0,0,0,0,0,0,79,69,83,95,116,101,120,116,117,114,101,95,102,108,111,97,116,95,108,105,110,101,97,114,0,0,0,0,0,0,0,0,68,65,82,75,32,75,73,78,71,68,79,77,0,0,0,0,37,115,95,105,110,112,117,116,95,115,108,111,116,0,0,0,108,95,121,95,112,108,117,115,0,0,0,0,0,0,0,0,114,52,56,48,49,0,0,0,112,118,68,114,101,103,0,0,118,76,97,115,116,82,97,109,65,100,114,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,85,115,105,110,103,32,82,79,77,58,32,37,115,46,10,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,9,37,115,10,0,118,67,97,99,104,101,70,108,97,103,115,0,0,0,0,0,82,105,103,104,116,32,97,110,97,108,111,103,32,88,45,32,40,108,101,102,116,41,0,0,118,67,97,99,104,101,66,97,115,101,82,101,103,0,0,0,118,82,97,109,66,97,110,107,82,101,103,0,0,0,0,0,118,82,111,109,66,97,110,107,82,101,103,0,0,0,0,0,118,80,114,103,66,97,110,107,82,101,103,0,0,0,0,0,118,105,100,101,111,95,103,112,117,95,114,101,99,111,114,100,0,0,0,0,0,0,0,0,118,83,116,97,116,117,115,82,101,103,0,0,0,0,0,0,46,98,114,97,109,0,0,0,118,80,108,111,116,79,112,116,105,111,110,82,101,103,0,0,118,67,111,108,111,114,82,101,103,0,0,0,0,0,0,0,74,111,121,112,97,100,50,32,88,0,0,0,0,0,0,0,96,35,35,35,35,32,32,32,32,32,35,35,35,35,32,35,46,46,46,46,32,32,32,32,32,46,46,46,46,35,35,46,32,32,32,32,32,32,32,32,32,32,32,46,35,35,46,32,32,32,32,32,32,32,32,32,32,32,46,35,35,46,32,32,32,32,32,32,32,32,32,32,32,46,35,32,32,32,32,32,32,32,35,32,32,32,32,32,32,32,32,32,32,32,32,32,32,35,32,32,32,32,32,32,32,32,32,32,32,32,35,35,35,35,35,32,32,32,32,32,32,32,32,32,32,32,32,35,32,32,32,32,32,32,32,32,32,32,32,32,32,32,35,32,32,32,32,32,32,32,35,46,32,32,32,32,32,32,32,32,32,32,32,46,35,35,46,32,32,32,32,32,32,32,32,32,32,32,46,35,35,46,32,32,32,32,32,32,32,32,32,32,32,46,35,35,46,46,46,46,32,32,32,32,32,46,46,46,46,35,32,35,35,35,35,32,32,32,32,32,35,35,35,35,32,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,71,76,93,58,32,85,115,105,110,103,32,71,76,83,76,32,118,101,114,115,105,111,110,32,37,117,46,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,115,101,116,32,117,112,32,102,114,97,109,101,32,98,117,102,102,101,114,32,111,98,106,101,99,116,115,46,32,77,117,108,116,105,45,112,97,115,115,32,115,104,97,100,105,110,103,32,119,105,108,108,32,110,111,116,32,119,111,114,107,46,10,0,0,78,111,110,101,0,0,0,0,65,80,66,0,0,0,0,0,37,115,95,119,114,97,109,0,108,95,120,95,109,105,110,117,115,0,0,0,0,0,0,0,114,116,99,95,105,110,100,101,120,0,0,0,0,0,0,0,97,118,82,101,103,0,0,0,118,97,114,105,97,98,108,101,95,98,105,116,95,112,111,115,0,0,0,0,0,0,0,0,114,101,116,114,111,97,114,99,104,0,0,0,0,0,0,0,86,105,114,116,117,97,108,66,105,116,109,97,112,70,111,114,109,97,116,0,0,0,0,0,115,117,109,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,85,78,83,85,80,80,79,82,84,69,68,32,40,35,37,117,41,46,10,0,0,97,114,105,116,104,109,101,116,105,99,95,111,112,0,0,0,111,112,50,0,0,0,0,0,111,112,49,0,0,0,0,0,118,105,100,101,111,95,112,111,115,116,95,102,105,108,116,101,114,95,114,101,99,111,114,100,0,0,0,0,0,0,0,0,105,110,95,99,104,97,114,95,100,109,97,0,0,0,0,0,46,97,114,97,109,0,0,0,111,118,101,114,102,108,111,119,0,0,0,0,0,0,0,0,87,97,105,116,105,110,103,70,111,114,73,110,116,101,114,114,117,112,116,0,0,0,0,0,70,111,117,110,100,32,109,117,108,116,105,112,108,101,32,82,79,77,32,102,105,108,101,32,104,101,97,100,101,114,115,32,40,97,110,100,32,105,103,110,111,114,101,100,32,116,104,101,109,41,46,0,0,0,0,0,74,111,121,112,97,100,50,32,66,0,0,0,0,0,0,0,96,32,32,32,32,32,32,46,32,32,32,32,32,32,32,32,35,32,32,32,32,32,46,32,32,32,32,32,35,32,32,32,35,32,32,32,32,46,32,32,32,32,35,32,32,32,32,32,35,32,32,32,46,32,32,32,35,32,32,32,32,32,32,32,35,32,32,46,32,32,35,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,46,46,46,46,46,32,32,32,32,32,46,46,46,46,46,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,35,32,32,46,32,32,35,32,32,32,32,32,32,32,35,32,32,32,46,32,32,32,35,32,32,32,32,32,35,32,32,32,32,46,32,32,32,32,35,32,32,32,35,32,32,32,32,32,46,32,32,32,32,32,35,32,32,32,32,32,32,32,32,46,32,32,32,32,32,32,32,0,0,0,0,0,0,0,35,118,101,114,115,105,111,110,32,37,117,10,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,68,105,100,110,39,116,32,102,105,110,100,32,71,76,32,99,111,110,116,101,120,116,58,32,37,115,46,10,0,0,0,0,0,0,0,89,57,32,0,0,0,0,0,37,115,95,115,101,109,97,110,116,105,99,0,0,0,0,0,108,95,120,95,112,108,117,115,0,0,0,0,0,0,0,0,73,82,81,65,99,116,105,118,101,0,0,0,0,0,0,0,114,116,99,95,109,111,100,101,0,0,0,0,0,0,0,0,70,111,117,110,100,32,82,79,77,32,102,105,108,101,32,104,101,97,100,101,114,32,40,97,110,100,32,105,103,110,111,114,101,100,32,105,116,41,46,0,70,108,97,103,115,0,0,0,78,111,32,82,79,77,32,102,105,108,101,32,104,101,97,100,101,114,32,102,111,117,110,100,46,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,114,101,109,111,118,101,32,116,101,109,112,111,114,97,114,121,32,102,105,108,101,58,32,37,115,46,10,0,0,0,0,0,0,83,104,105,102,116,101,100,68,66,0,0,0,0,0,0,0,115,102,0,0,0,0,0,0,82,105,103,104,116,32,97,110,97,108,111,103,32,88,43,32,40,114,105,103,104,116,41,0,83,104,105,102,116,101,100,80,66,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,70,82,65,77,69,95,84,73,77,69,95,67,65,76,76,66,65,67,75,46,10,0,0,0,0,80,67,119,0,0,0,0,0,89,46,87,0,0,0,0,0,88,46,87,0,0,0,0,0,46,114,116,99,0,0,0,0,118,105,100,101,111,95,109,101,115,115,97,103,101,95,99,111,108,111,114,0,0,0,0,0,115,101,116,116,105,110,103,115,46,99,0,0,0,0,0,0,83,46,87,0,0,0,0,0,46,112,114,97,109,0,0,0,68,46,87,0,0,0,0,0,65,46,87,0,0,0,0,0,74,111,121,112,97,100,50,32,65,0,0,0,0,0,0,0,96,46,32,32,32,32,32,32,32,32,32,32,32,46,32,46,35,46,32,32,32,32,32,32,32,32,32,46,35,46,32,46,35,46,32,32,32,32,32,32,32,46,35,46,32,32,32,46,35,46,32,32,32,32,32,46,35,46,32,32,32,32,32,46,35,46,32,32,32,46,35,46,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,46,35,46,32,32,32,46,35,46,32,32,32,32,32,46,35,46,32,32,32,32,32,46,35,46,32,32,32,46,35,46,32,32,32,32,32,32,32,46,35,46,32,46,35,46,32,32,32,32,32,32,32,32,32,46,35,46,32,46,32,32,32,32,32,32,32,32,32,32,32,46,32,0,0,0,0,0,0,0,35,118,101,114,115,105,111,110,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,105,110,105,116,32,71,76,32,99,111,110,116,101,120,116,58,32,37,115,46,10,0,0,0,0,78,47,65,32,40,112,111,114,116,32,35,37,117,41,0,0,102,97,108,115,101,0,0,0,89,55,32,0,0,0,0,0,116,117,114,98,111,0,0,0,116,101,115,116,50,49,57,50,0,0,0,0,0,0,0,0,80,46,87,0,0,0,0,0,68,66,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,82,101,109,111,118,105,110,103,32,116,101,109,112,111,97,114,121,32,82,79,77,32,102,105,108,101,58,32,37,115,46,10,0,0,0,0,0,80,66,0,0,0,0,0,0,79,112,51,56,68,0,0,0,110,111,0,0,0,0,0,0,79,112,51,56,82,0,0,0,100,114,105,118,101,114,46,99,0,0,0,0,0,0,0,0,79,112,51,56,90,0,0,0,79,112,51,56,89,0,0,0,99,117,115,116,111,109,95,118,105,101,119,112,111,114,116,95,104,101,105,103,104,116,0,0,79,112,51,56,88,0,0,0,79,112,49,56,68,0,0,0,37,100,77,98,105,116,115,0,46,46,0,0,0,0,0,0,79,112,49,56,82,0,0,0,74,111,121,112,97,100,49,32,68,111,119,110,0,0,0,0,96,32,32,32,32,32,46,35,46,32,32,32,32,32,32,32,32,32,32,32,32,46,35,46,32,32,32,32,32,32,32,32,32,32,32,32,46,35,46,32,32,32,32,32,32,32,32,32,32,32,32,46,35,46,32,32,32,32,32,32,32,32,32,32,32,32,46,35,46,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,46,46,46,46,46,32,32,32,32,32,46,46,46,46,46,35,35,35,35,35,32,32,32,32,32,35,35,35,35,35,46,46,46,46,46,32,32,32,32,32,46,46,46,46,46,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,46,35,46,32,32,32,32,32,32,32,32,32,32,32,32,46,35,46,32,32,32,32,32,32,32,32,32,32,32,32,46,35,46,32,32,32,32,32,32,32,32,32,32,32,32,46,35,46,32,32,32,32,32,32,32,32,32,32,32,32,46,35,46,32,32,32,32,32,32,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,76,105,110,107,101,114,32,108,111,103,58,32,37,115,10,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,98,105,110,100,32,65,80,73,32,37,115,32,116,111,32,99,111,110,116,101,120,116,32,37,115,46,10,0,0,0,0,0,0,35,37,100,0,0,0,0,0,65,52,66,0,0,0,0,0,114,51,0,0,0,0,0,0,79,112,49,56,90,0,0,0,112,114,101,118,77,77,67,0,37,115,37,115,0,0,0,0,79,112,49,56,89,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,82,65,77,32,119,105,108,108,32,110,111,116,32,98,101,32,115,97,118,101,100,46,10,0,0,0,0,0,79,112,49,56,88,0,0,0,43,68,83,80,45,37,100,0,76,101,102,116,32,97,110,97,108,111,103,32,89,45,32,40,117,112,41,0,0,0,0,0,79,112,48,56,76,104,0,0,121,101,115,0,0,0,0,0,79,112,48,56,76,108,0,0,79,112,48,56,90,0,0,0,79,112,48,56,89,0,0,0,99,117,115,116,111,109,95,118,105,101,119,112,111,114,116,95,119,105,100,116,104,0,0,0,79,112,48,56,88,0,0,0,43,83,45,82,84,67,0,0,79,112,50,70,83,105,122,101,0,0,0,0,0,0,0,0,43,83,80,67,55,49,49,48,0,0,0,0,0,0,0,0,79,112,50,70,85,110,107,110,111,119,110,0,0,0,0,0,43,83,80,67,55,49,49,48,43,82,84,67,0,0,0,0,74,111,121,112,97,100,49,32,85,112,0,0,0,0,0,0,96,32,32,32,32,32,46,35,46,32,32,32,32,32,32,32,32,32,32,32,32,46,35,46,32,32,32,32,32,32,32,32,32,32,32,32,46,35,46,32,32,32,32,32,32,32,32,32,46,46,46,46,35,46,46,46,46,32,32,32,32,32,32,46,35,35,35,35,35,35,35,46,32,32,32,32,32,32,46,35,32,32,32,32,32,35,46,32,32,32,46,46,46,46,35,32,32,32,32,32,35,46,46,46,46,35,35,35,35,35,32,32,32,32,32,35,35,35,35,35,46,46,46,46,35,32,32,32,32,32,35,46,46,46,46,32,32,32,46,35,32,32,32,32,32,35,46,32,32,32,32,32,32,46,35,35,35,35,35,35,35,46,32,32,32,32,32,32,46,46,46,46,35,46,46,46,46,32,32,32,32,32,32,32,32,32,46,35,46,32,32,32,32,32,32,32,32,32,32,32,32,46,35,46,32,32,32,32,32,32,32,32,32,32,32,32,46,35,46,32,32,32,32,32,32,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,108,105,110,107,32,112,114,111,103,114,97,109,32,35,37,117,46,10,0,0,0,0,0,0,0,79,112,101,110,71,76,32,69,83,0,0,0,0,0,0,0,37,46,50,102,0,0,0,0,65,80,82,0,0,0,0,0,108,51,0,0,0,0,0,0,79,112,48,70,80,97,115,115,0,0,0,0,0,0,0,0,77,77,67,0,0,0,0,0,43,83,65,45,49,0,0,0,79,112,48,70,82,97,109,115,105,122,101,0,0,0,0,0,43,79,66,67,49,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,107,105,112,112,105,110,103,32,83,82,65,77,32,108,111,97,100,46,10,0,79,112,49,67,90,50,0,0,43,83,45,68,68,49,0,0,83,78,69,83,57,120,32,78,101,120,116,0,0,0,0,0,66,83,45,88,46,98,105,111,115,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,68,105,100,110,39,116,32,102,105,110,100,32,97,110,121,32,82,79,77,83,32,116,104,97,116,32,109,97,116,99,104,101,100,32,118,97,108,105,100,32,101,120,116,101,110,115,105,111,110,115,32,102,111,114,32,108,105,98,114,101,116,114,111,32,105,109,112,108,101,109,101,110,116,97,116,105,111,110,46,10,0,0,0,79,112,49,67,89,50,0,0,73,68,65,84,0,0,0,0,43,83,117,112,101,114,32,70,88,0,0,0,0,0,0,0,103,108,77,97,112,66,117,102,102,101,114,79,69,83,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,83,85,80,80,79,82,84,95,78,79,95,71,65,77,69,58,32,37,115,46,10,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,71,76,93,58,32,71,76,69,83,32,99,111,110,116,101,120,116,32,105,115,32,117,115,101,100,44,32,98,117,116,32,115,104,97,100,101,114,32,105,115,32,110,111,116,32,109,111,100,101,114,110,46,32,67,97,110,110,111,116,32,117,115,101,32,105,116,46,10,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,69,77,83,67,82,73,80,84,69,78,47,69,71,76,93,58,32,68,105,109,101,110,115,105,111,110,115,58,32,37,117,120,37,117,10,0,79,112,49,67,88,50,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,91,71,76,93,58,32,70,97,105,108,101,100,32,116,111,32,115,101,116,32,109,117,108,116,105,112,97,115,115,32,115,104,97,100,101,114,46,32,70,97,108,108,105,110,103,32,98,97,99,107,32,116,111,32,115,116,111,99,107,46,10,0,0,0,0,0,0,0,79,112,49,67,90,49,0,0,82,79,77,43,82,65,77,43,66,65,84,0,0,0,0,0,79,112,49,67,89,49,0,0,82,79,77,43,82,65,77,0,74,111,121,112,97,100,37,100,32,117,115,101,100,32,109,111,114,101,32,116,104,97,110,32,111,110,99,101,33,32,68,105,115,97,98,108,105,110,103,32,101,120,116,114,97,32,105,110,115,116,97,110,99,101,115,0,99,117,115,116,111,109,95,118,105,101,119,112,111,114,116,95,121,0,0,0,0,0,0,0,68,73,83,75,32,65,80,80,69,78,68,32,37,115,0,0,79,112,49,67,88,49,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,84,71,65,32,105,109,97,103,101,32,105,115,32,110,111,116,32,117,110,99,111,109,112,114,101,115,115,101,100,32,82,71,66,46,10,0,0,0,0,0,0,0,0,82,79,77,0,0,0,0,0,79,112,49,67,90,65,82,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,70,97,105,108,101,100,32,46,46,46,32,67,97,110,110,111,116,32,114,101,99,111,118,101,114,32,115,97,118,101,32,102,105,108,101,46,10,0,0,0,0,0,0,0,37,100,75,98,105,116,115,0,82,101,116,114,111,65,114,99,104,58,32,76,111,97,100,105,110,103,32,88,77,76,32,115,104,97,100,101,114,58,32,37,115,10,0,0,0,0,0,0,79,112,49,67,89,65,82,0,74,111,121,112,97,100,49,32,82,105,103,104,116,0,0,0,96,32,32,32,32,32,35,35,35,32,32,32,32,32,32,32,32,32,32,35,35,32,46,32,35,35,32,32,32,32,32,32,32,35,32,32,32,46,32,32,32,35,32,32,32,32,32,35,32,32,32,32,46,32,32,32,32,35,32,32,32,35,32,32,32,32,32,46,32,32,32,32,32,35,32,32,35,32,32,32,32,32,46,32,32,32,32,32,35,32,35,32,32,32,32,32,32,46,32,32,32,32,32,32,35,35,46,46,46,46,46,46,35,46,46,46,46,46,46,35,35,32,32,32,32,32,32,46,32,32,32,32,32,32,35,32,35,32,32,32,32,32,46,32,32,32,32,32,35,32,32,35,32,32,32,32,32,46,32,32,32,32,32,35,32,32,32,35,32,32,32,32,46,32,32,32,32,35,32,32,32,32,32,35,32,32,32,46,32,32,32,35,32,32,32,32,32,32,32,35,35,32,46,32,35,35,32,32,32,32,32,32,32,32,32,32,35,35,35,32,32,32,32,32,32,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,76,105,110,107,105,110,103,32,71,76,83,76,32,112,114,111,103,114,97,109,46,10,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,91,71,76,93,58,32,71,76,69,83,32,105,109,112,108,101,109,101,110,116,97,116,105,111,110,32,100,111,101,115,32,110,111,116,32,104,97,118,101,32,66,71,82,65,56,56,56,56,32,101,120,116,101,110,115,105,111,110,46,10,51,50,45,98,105,116,32,112,97,116,104,32,119,105,108,108,32,114,101,113,117,105,114,101,32,99,111,110,118,101,114,115,105,111,110,46,10,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,111,118,101,114,108,97,121,32,35,37,117,46,10,0,0,0,0,65,82,70,0,0,0,0,0,78,84,83,67,0,0,0,0,114,50,0,0,0,0,0,0,79,112,49,67,88,65,82,0,111,117,116,112,117,116,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,103,114,97,98,32,99,104,101,97,116,115,46,32,84,104,105,115,32,115,104,111,117,108,100,32,110,111,116,32,104,97,112,112,101,110,46,10,0,0,0,0,60,33,91,67,68,65,84,65,91,0,0,0,0,0,0,0,82,69,71,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,9,75,101,121,58,32,37,115,10,0,0,0,0,82,79,77,32,108,105,101,100,32,97,98,111,117,116,32,105,116,115,32,116,121,112,101,33,32,84,114,121,105,110,103,32,97,103,97,105,110,46,0,0,79,112,49,67,90,66,82,0,80,65,76,0,0,0,0,0,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,10,0,0,0,0,0,0,79,112,49,67,89,66,82,0,76,111,82,79,77,0,0,0,76,101,102,116,32,97,110,97,108,111,103,32,89,43,32,40,100,111,119,110,41,0,0,0,79,112,49,67,88,66,82,0,72,105,82,79,77,0,0,0,82,101,116,114,111,65,114,99,104,58,32,82,101,113,117,101,115,116,105,110,103,32,117,110,107,110,111,119,110,32,99,111,110,116,101,120,116,46,10,0,79,112,49,67,90,0,0,0,69,120,72,105,82,79,77,0,79,112,49,67,89,0,0,0,98,97,100,32,99,104,101,99,107,115,117,109,0,0,0,0,79,112,49,67,88,0,0,0,110,111,32,99,104,101,99,107,115,117,109,0,0,0,0,0,99,117,115,116,111,109,95,118,105,101,119,112,111,114,116,95,120,0,0,0,0,0,0,0,79,112,50,56,82,0,0,0,99,104,101,99,107,115,117,109,32,111,107,0,0,0,0,0,79,112,50,56,90,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,83,117,99,99,101,101,100,101,100,32,105,110,32,115,97,118,105,110,103,32,82,65,77,32,100,97,116,97,32,116,111,32,34,37,115,34,46,10,0,0,0,0,0,0,34,37,115,34,32,91,37,115,93,32,37,115,44,32,37,115,44,32,37,115,44,32,37,115,44,32,83,82,65,77,58,37,115,44,32,73,68,58,37,115,44,32,67,82,67,51,50,58,37,48,56,88,0,0,0,0,79,112,50,56,89,0,0,0,74,111,121,112,97,100,49,32,76,101,102,116,0,0,0,0,96,32,32,32,32,32,32,35,32,32,32,32,32,32,32,32,32,32,32,32,32,35,46,35,32,32,32,32,32,32,32,32,32,32,32,35,32,46,32,35,32,32,32,32,32,32,32,32,32,35,32,32,46,32,32,35,32,32,32,32,32,32,32,35,32,32,32,46,32,32,32,35,32,32,32,32,32,35,32,32,32,32,46,32,32,32,32,35,32,32,32,35,32,32,32,32,32,46,32,32,32,32,32,35,32,35,46,46,46,46,46,46,35,46,46,46,46,46,46,35,32,35,32,32,32,32,32,46,32,32,32,32,32,35,32,32,32,35,32,32,32,32,46,32,32,32,32,35,32,32,32,32,32,35,32,32,32,46,32,32,32,35,32,32,32,32,32,32,32,35,32,32,46,32,32,35,32,32,32,32,32,32,32,32,32,35,32,46,32,35,32,32,32,32,32,32,32,32,32,32,32,35,46,35,32,32,32,32,32,32,32,32,32,32,32,32,32,35,32,32,32,32,32,32,32,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,99,111,109,112,105,108,101,32,102,114,97,103,109,101,110,116,32,115,104,97,100,101,114,32,35,37,117,10,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,71,76,93,58,32,66,71,82,65,56,56,56,56,32,101,120,116,101,110,115,105,111,110,32,102,111,117,110,100,32,102,111,114,32,71,76,69,83,46,10,0,0,0,0,105,109,112,111,114,116,115,0,65,84,86,0,0,0,0,0,108,50,0,0,0,0,0,0,111,117,116,95,105,110,100,101,120,0,0,0,0,0,0,0,79,112,50,56,88,0,0,0,79,112,50,66,83,0,0,0,83,70,88,32,197,178,196,182,222,221,192,222,209,211,201,182,222,192,216,32,49,0,0,0,61,61,61,32,66,117,105,108,100,32,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,116,97,107,101,32,115,99,114,101,101,110,115,104,111,116,46,0,0,0,0,0,0,79,112,50,66,90,0,0,0,103,111,101,109,111,110,32,52,0,0,0,0,0,0,0,0,79,112,50,66,89,0,0,0,83,65,84,65,78,32,73,83,32,79,85,82,32,70,65,84,72,69,82,33,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,82,101,113,117,101,115,116,105,110,103,32,79,112,101,110,71,76,32,99,111,110,116,101,120,116,44,32,98,117,116,32,82,101,116,114,111,65,114,99,104,32,105,115,32,99,111,109,112,105,108,101,100,32,97,103,97,105,110,115,116,32,79,112,101,110,71,76,69,83,50,46,32,67,97,110,110,111,116,32,117,115,101,32,72,87,32,99,111,110,116,101,120,116,46,10,0,0,0,0,79,112,50,66,88,0,0,0,83,85,80,69,82,32,68,82,73,70,84,32,79,85,84,0,79,112,49,66,83,0,0,0,72,73,84,79,77,73,51,0,79,112,49,66,90,0,0,0,118,105,100,101,111,95,109,101,115,115,97,103,101,95,112,111,115,95,121,0,0,0,0,0,79,112,49,66,89,0,0,0,102,105,110,100,95,97,117,100,105,111,95,100,114,105,118,101,114,40,41,0,0,0,0,0,88,45,77,69,78,0,0,0,79,112,49,66,88,0,0,0,37,89,45,37,109,45,37,100,45,37,72,45,37,77,45,37,83,0,0,0,0,0,0,0,66,65,84,84,76,69,32,66,76,65,90,69,0,0,0,0,79,112,48,66,83,0,0,0,65,101,114,111,32,116,104,101,32,65,99,114,111,66,97,116,32,50,0,0,0,0,0,0,74,111,121,112,97,100,49,32,82,0,0,0,0,0,0,0,96,32,32,32,32,32,32,46,32,32,32,32,32,32,32,32,35,32,32,32,32,32,46,32,32,32,32,32,35,32,32,32,35,32,32,32,32,46,32,32,32,32,35,32,32,32,32,32,35,32,32,32,46,32,32,32,35,32,32,32,32,32,32,32,35,32,32,46,32,32,35,32,32,32,32,32,32,32,32,32,35,32,46,32,35,32,32,32,32,32,32,32,32,32,32,32,35,46,35,32,32,32,32,32,32,46,46,46,46,46,46,46,35,46,46,46,46,46,46,46,32,32,32,32,32,32,35,46,35,32,32,32,32,32,32,32,32,32,32,32,35,32,46,32,35,32,32,32,32,32,32,32,32,32,35,32,32,46,32,32,35,32,32,32,32,32,32,32,35,32,32,32,46,32,32,32,35,32,32,32,32,32,35,32,32,32,32,46,32,32,32,32,35,32,32,32,35,32,32,32,32,32,46,32,32,32,32,32,35,32,32,32,32,32,32,32,32,46,32,32,32,32,32,32,32,0,0,0,0,0,0,0,35,100,101,102,105,110,101,32,70,82,65,71,77,69,78,84,10,0,0,0,0,0,0,0,66,71,82,65,56,56,56,56,0,0,0,0,0,0,0,0,105,109,112,111,114,116,95,115,99,114,105,112,116,95,99,108,97,115,115,0,0,0,0,0,65,81,84,0,0,0,0,0,79,112,48,66,90,0,0,0,110,101,119,95,119,114,105,116,101,0,0,0,0,0,0,0,73,82,81,32,99,111,117,110,116,32,104,97,99,107,58,32,37,100,10,0,0,0,0,0,79,112,48,66,89,0,0,0,84,82,65,86,69,82,83,69,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,116,97,108,32,101,114,114,111,114,32,114,101,99,101,105,118,101,100,32,105,110,58,32,34,37,115,34,10,0,0,0,0,0,79,112,48,66,88,0,0,0,68,77,65,32,115,121,110,99,58,32,37,100,10,0,0,0,76,101,102,116,32,97,110,97,108,111,103,32,88,45,32,40,108,101,102,116,41,0,0,0,79,112,48,69,89,0,0,0,66,65,84,84,76,69,32,71,82,65,78,68,80,82,73,88,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,82,101,113,117,101,115,116,105,110,103,32,79,112,101,110,71,76,69,83,50,32,99,111,110,116,101,120,116,46,10,0,0,0,0,0,0,0,79,112,48,69,88,0,0,0,89,79,83,72,73,39,83,32,83,65,70,65,82,73,0,0,79,112,48,69,86,0,0,0,88,32,90,79,78,69,0,0,79,112,48,69,72,0,0,0,83,85,80,69,82,32,83,67,79,80,69,32,54,0,0,0,118,105,100,101,111,95,109,101,115,115,97,103,101,95,112,111,115,95,120,0,0,0,0,0,79,112,49,52,89,114,114,0,65,118,97,105,108,97,98,108,101,32,97,117,100,105,111,32,100,114,105,118,101,114,115,32,97,114,101,58,10,0,0,0,77,69,84,65,76,32,67,79,77,66,65,84,0,0,0,0,79,112,49,52,88,114,114,0,37,115,47,82,101,116,114,111,65,114,99,104,45,114,101,99,111,118,101,114,121,45,0,0,83,80,65,67,69,32,66,65,90,79,79,75,65,0,0,0,96,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,35,32,32,46,32,32,35,32,32,32,32,32,32,32,32,32,35,32,46,32,35,32,32,32,32,32,32,32,32,32,32,32,35,46,35,32,32,32,32,32,32,32,32,32,32,46,46,46,35,46,46,46,32,32,32,32,32,32,32,32,32,32,35,46,35,32,32,32,32,32,32,32,32,32,32,32,35,32,46,32,35,32,32,32,32,32,32,32,32,32,35,32,32,46,32,32,35,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,79,112,49,52,90,114,114,0,66,65,84,84,76,69,32,67,76,65,83,72,0,0,0,0,74,111,121,112,97,100,49,32,76,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,70,111,117,110,100,32,71,76,83,76,32,102,114,97,103,109,101,110,116,32,115,104,97,100,101,114,46,10,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,71,76,93,58,32,70,97,105,108,101,100,32,116,111,32,105,110,105,116,32,115,104,97,100,101,114,44,32,102,97,108,108,105,110,103,32,98,97,99,107,32,116,111,32,115,116,111,99,107,46,10,0,0,0,0,0,0,0,37,46,51,102,0,0,0,0,105,109,112,111,114,116,95,115,99,114,105,112,116,0,0,0,65,99,116,82,97,105,115,101,114,45,50,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,110,39,116,32,111,112,101,110,32,66,83,86,32,102,105,108,101,32,34,37,115,34,32,102,111,114,32,112,108,97,121,98,97,99,107,46,10,0,108,0,0,0,0,0,0,0,79,112,49,52,76,0,0,0,111,108,100,95,119,114,105,116,101,0,0,0,0,0,0,0,90,65,78,50,32,83,80,73,82,73,84,83,0,0,0,0,79,112,49,52,70,0,0,0,87,79,78,68,69,82,80,82,79,74,69,67,84,32,74,0,90,73,80,124,122,105,112,0,79,112,49,52,85,0,0,0,87,79,76,70,69,78,83,84,69,73,78,32,51,68,0,0,79,112,49,52,89,114,0,0,85,84,79,80,73,65,0,0,82,101,116,114,111,65,114,99,104,58,32,82,101,113,117,101,115,116,105,110,103,32,110,111,32,72,87,32,99,111,110,116,101,120,116,46,10,0,0,0,79,112,49,52,88,114,0,0,84,114,111,100,100,108,101,114,115,0,0,0,0,0,0,0,79,112,49,52,90,114,0,0,65,77,56,74,0,0,0,0,79,112,50,51,90,0,0,0,84,79,75,73,77,69,75,73,32,77,69,77,79,82,73,65,76,0,0,0,0,0,0,0,118,105,100,101,111,95,102,111,110,116,95,115,99,97,108,101,0,0,0,0,0,0,0,0,79,112,50,51,89,0,0,0,57,78,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,110,39,116,32,102,105,110,100,32,97,110,121,32,97,117,100,105,111,32,100,114,105,118,101,114,32,110,97,109,101,100,32,34,37,115,34,10,0,79,112,50,51,88,0,0,0,84,73,78,83,84,65,82,0,79,112,50,51,85,0,0,0,84,69,82,77,73,78,65,84,79,82,50,32,84,72,69,32,77,79,86,73,69,48,0,0,74,111,121,112,97,100,49,32,83,116,97,114,116,0,0,0,96,46,32,32,32,32,32,32,32,32,32,32,32,46,32,46,35,46,32,32,32,32,32,32,32,32,32,46,35,46,32,46,35,46,32,32,32,32,32,32,32,46,35,46,32,32,32,46,35,46,32,32,32,32,32,46,35,46,32,32,32,32,32,46,35,46,32,32,32,46,35,46,32,32,32,32,32,32,32,46,35,46,32,46,35,46,32,32,32,32,32,32,32,32,32,46,35,46,35,46,32,32,32,32,32,32,32,32,32,32,32,46,35,46,32,32,32,32,32,32,32,32,32,32,32,46,35,46,35,46,32,32,32,32,32,32,32,32,32,46,35,46,32,46,35,46,32,32,32,32,32,32,32,46,35,46,32,32,32,46,35,46,32,32,32,32,32,46,35,46,32,32,32,32,32,46,35,46,32,32,32,46,35,46,32,32,32,32,32,32,32,46,35,46,32,46,35,46,32,32,32,32,32,32,32,32,32,46,35,46,32,46,32,32,32,32,32,32,32,32,32,32,32,46,32,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,99,111,109,112,105,108,101,32,118,101,114,116,101,120,32,115,104,97,100,101,114,32,35,37,117,10,0,0,0,0,0,0,0,37,115,95,119,114,97,112,95,109,111,100,101,0,0,0,0,65,67,84,82,65,73,83,69,82,0,0,0,0,0,0,0,79,112,50,51,76,0,0,0,102,108,97,115,104,95,99,111,109,109,97,110,100,0,0,0,83,85,80,69,82,32,90,69,78,75,79,75,85,66,65,78,0,0,0,0,0,0,0,0,79,112,50,51,70,0,0,0,83,85,80,69,82,32,83,79,76,73,84,65,73,82,69,0,82,101,116,114,111,65,114,99,104,32,58,32,37,115,32,37,115,0,0,0,0,0,0,0,79,112,49,51,90,0,0,0,83,117,112,101,114,80,97,99,104,105,83,108,111,116,77,97,104,106,111,110,103,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,71,69,84,95,86,65,82,73,65,66,76,69,32,37,115,58,10,0,0,0,0,76,101,102,116,32,97,110,97,108,111,103,32,88,43,32,40,114,105,103,104,116,41,0,0,79,112,49,51,89,0,0,0,65,86,73,74,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,72,87,95,82,69,78,68,69,82,46,10,0,0,0,0,0,0,79,112,49,51,88,0,0,0,83,85,80,69,82,32,67,65,83,84,76,69,83,0,0,0,79,112,49,51,85,0,0,0,83,85,80,69,82,32,67,65,69,83,65,82,83,32,80,65,76,65,67,69,0,0,0,0,79,112,49,51,76,0,0,0,83,78,79,79,80,89,32,67,79,78,67,69,82,84,0,0,118,105,100,101,111,95,102,111,110,116,95,101,110,97,98,108,101,0,0,0,0,0,0,0,79,112,49,51,70,0,0,0,83,105,109,65,110,116,0,0,102,105,110,100,95,118,105,100,101,111,95,100,114,105,118,101])
.concat([114,40,41,0,0,0,0,0,79,112,48,51,90,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,78,111,32,82,79,77,32,105,115,32,117,115,101,100,44,32,98,117,116,32,108,105,98,114,101,116,114,111,32,99,111,114,101,32,100,111,101,115,32,110,111,116,32,115,117,112,112,111,114,116,32,116,104,105,115,46,10,0,0,83,72,73,69,78,39,83,32,82,69,86,69,78,71,69,0,79,112,48,51,89,0,0,0,83,72,73,69,78,32,84,72,69,32,66,76,65,68,69,32,67,72,65,83,69,48,0,0,74,111,121,112,97,100,49,32,83,101,108,101,99,116,0,0,96,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,46,32,32,32,32,32,46,32,32,32,32,32,32,32,46,35,46,32,32,32,46,35,46,32,32,32,32,32,32,32,46,35,46,32,46,35,46,32,32,32,32,32,32,32,32,32,46,35,46,35,46,32,32,32,32,32,32,32,32,32,32,32,46,35,46,32,32,32,32,32,32,32,32,32,32,32,46,35,46,35,46,32,32,32,32,32,32,32,32,32,46,35,46,32,46,35,46,32,32,32,32,32,32,32,46,35,46,32,32,32,46,35,46,32,32,32,32,32,32,32,46,32,32,32,32,32,46,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,35,100,101,102,105,110,101,32,86,69,82,84,69,88,10,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,71,76,93,58,32,68,105,100,110,39,116,32,102,105,110,100,32,118,97,108,105,100,32,115,104,97,100,101,114,32,98,97,99,107,101,110,100,46,32,67,111,110,116,105,110,117,105,110,103,32,119,105,116,104,111,117,116,32,115,104,97,100,101,114,115,46,10,0,0,0,0,0,0,0,37,46,51,102,32,72,122,32,40,37,46,49,102,37,37,32,100,101,118,44,32,37,117,32,115,97,109,112,108,101,115,41,0,0,0,0,0,0,0,0,37,115,95,108,105,110,101,97,114,0,0,0,0,0,0,0,69,57,32,0,0,0,0,0,97,0,0,0,0,0,0,0,79,112,48,51,88,0,0,0,114,101,97,100,95,101,110,97,98,108,101,0,0,0,0,0,84,69,78,66,85,32,83,80,73,82,73,84,0,0,0,0,82,111,121,97,108,32,67,111,110,113,117,101,115,116,0,0,79,112,48,51,85,0,0,0,83,101,116,116,105,110,103,32,114,101,102,114,101,115,104,32,114,97,116,101,32,116,111,58,32,37,46,51,102,32,72,122,46,0,0,0,0,0,0,0,118,48,0,0,0,0,0,0,79,112,48,51,76,0,0,0,65,88,82,0,0,0,0,0,79,112,48,51,70,0,0,0,82,101,118,111,108,117,116,105,111,110,32,88,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,68,73,83,75,95,67,79,78,84,82,79,76,95,73,78,84,69,82,70,65,67,69,46,10,0,79,112,50,68,85,0,0,0,80,79,87,69,82,77,79,78,71,69,82,0,0,0,0,0,79,112,50,68,76,0,0,0,80,79,80,85,76,79,85,83,32,73,73,0,0,0,0,0,79,112,50,68,70,0,0,0,79,80,69,82,65,84,73,79,78,32,84,72,85,78,68,69,82,66,79,76,84,49,0,0,118,105,100,101,111,95,102,111,110,116,95,115,105,122,101,0,79,112,50,68,90,0,0,0,79,78,32,84,72,69,32,66,65,76,76,0,0,0,0,0,65,118,97,105,108,97,98,108,101,32,118,105,100,101,111,32,100,114,105,118,101,114,115,32,97,114,101,58,10,0,0,0,79,112,50,68,89,0,0,0,82,101,116,114,111,65,114,99,104,58,32,70,111,117,110,100,32,88,77,76,32,109,101,109,111,114,121,32,109,97,112,32,105,110,32,34,37,115,34,10,0,0,0,0,0,0,0,0,78,111,98,117,110,97,103,97,39,115,32,65,109,98,105,116,105,111,110,0,0,0,0,0,79,112,50,68,88,0,0,0,87,79,78,68,69,82,32,75,73,84,67,72,69,78,0,0,74,111,121,112,97,100,49,32,89,0,0,0,0,0,0,0,96,32,32,32,32,32,46,35,46,32,32,32,32,32,32,32,32,32,32,32,32,46,35,46,32,32,32,32,32,32,32,32,32,32,32,32,46,35,46,32,32,32,32,32,32,32,32,32,32,32,32,46,35,46,32,32,32,32,32,32,32,32,32,32,32,32,46,35,46,32,32,32,32,32,32,32,32,32,32,32,32,46,35,46,32,32,32,32,32,32,46,46,46,46,46,46,46,35,46,46,46,46,46,46,46,35,35,35,35,35,35,35,35,35,35,35,35,35,35,35,46,46,46,46,46,46,46,35,46,46,46,46,46,46,46,32,32,32,32,32,32,46,35,46,32,32,32,32,32,32,32,32,32,32,32,32,46,35,46,32,32,32,32,32,32,32,32,32,32,32,32,46,35,46,32,32,32,32,32,32,32,32,32,32,32,32,46,35,46,32,32,32,32,32,32,32,32,32,32,32,32,46,35,46,32,32,32,32,32,32,32,32,32,32,32,32,46,35,46,32,32,32,32,32,32,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,70,111,117,110,100,32,71,76,83,76,32,118,101,114,116,101,120,32,115,104,97,100,101,114,46,10,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,71,76,93,58,32,85,115,105,110,103,32,71,76,83,76,32,115,104,97,100,101,114,32,98,97,99,107,101,110,100,46,10,0,0,0,0,37,117,0,0,0,0,0,0,116,101,120,116,117,114,101,115,0,0,0,0,0,0,0,0,83,76,65,80,32,83,84,73,67,75,32,49,32,74,80,78,0,0,0,0,0,0,0,0,114,105,103,104,116,0,0,0,79,112,49,68,85,0,0,0,119,114,105,116,101,95,101,110,97,98,108,101,0,0,0,0,77,73,71,72,84,32,32,65,78,68,32,77,65,71,73,67,32,73,73,73,0,0,0,0,79,112,49,68,76,0,0,0,77,69,71,65,32,76,79,32,77,65,78,73,65,0,0,0,79,112,49,68,70,0,0,0,65,77,69,69,0,0,0,0,84,117,114,98,111,32,101,110,97,98,108,101,0,0,0,0,79,112,49,68,90,0,0,0,77,69,89,32,32,80,114,101,115,99,104,111,111,108,32,70,117,110,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,75,69,89,66,79,65,82,68,95,67,65,76,76,66,65,67,75,46,10,0,0,0,0,0,0,79,112,49,68,89,0,0,0,77,65,82,73,79,80,65,73,78,84,0,0,0,0,0,0,79,112,49,68,88,0,0,0,65,67,88,74,0,0,0,0,79,112,48,68,85,0,0,0,83,85,80,69,82,32,80,73,67,82,79,83,83,0,0,0,118,105,100,101,111,95,102,111,110,116,95,112,97,116,104,0,79,112,48,68,76,0,0,0,77,97,114,105,111,38,87,97,114,105,111,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,110,39,116,32,102,105,110,100,32,97,110,121,32,118,105,100,101,111,32,100,114,105,118,101,114,32,110,97,109,101,100,32,34,37,115,34,10,0,79,112,48,68,70,0,0,0,76,79,82,68,32,77,79,78,65,82,67,72,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,112,97,116,99,104,32,37,115,58,32,69,114,114,111,114,32,35,37,117,10,0,0,0,0,0,79,112,48,68,90,0,0,0,76,50,0,0,0,0,0,0,74,111,121,112,97,100,49,32,88,0,0,0,0,0,0,0,96,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,46,35,46,32,32,32,32,32,32,32,32,32,32,32,32,46,35,46,32,32,32,32,32,32,32,32,32,32,46,46,46,35,46,46,46,32,32,32,32,32,32,32,32,35,35,35,35,35,35,35,32,32,32,32,32,32,32,32,46,46,46,35,46,46,46,32,32,32,32,32,32,32,32,32,32,46,35,46,32,32,32,32,32,32,32,32,32,32,32,32,46,35,46,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,99,114,101,97,116,101,32,71,76,32,112,114,111,103,114,97,109,32,35,37,117,46,10,0,0,82,101,116,114,111,65,114,99,104,58,32,91,71,76,93,58,32,78,111,116,32,108,111,97,100,105,110,103,32,97,110,121,32,115,104,97,100,101,114,46,10,0,0,0,0,0,0,0,37,100,0,0,0,0,0,0,49,0,0,0,0,0,0,0,59,0,0,0,0,0,0,0,83,79,85,76,66,76,65,90,69,82,32,45,32,49,32,85,83,65,0,0,0,0,0,0,108,101,102,116,0,0,0,0,79,112,48,68,89,0,0,0,102,108,97,115,104,95,101,110,97,98,108,101,0,0,0,0,76,101,109,109,105,110,103,115,32,50,44,84,104,101,32,84,114,105,98,101,115,0,0,0,79,112,48,68,88,0,0,0,76,65,77,66,79,82,71,72,73,78,73,32,65,77,69,82,73,67,65,78,0,0,0,0,70,97,105,108,101,100,32,116,111,32,114,101,109,111,118,101,32,100,105,115,107,32,102,114,111,109,32,116,114,97,121,46,0,0,0,0,0,0,0,0,79,112,50,49,89,114,0,0,65,80,90,74,0,0,0,0,79,112,50,49,88,114,0,0,75,79,85,84,69,84,83,85,45,78,79,32,75,73,83,72,73,32,51,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,9,82,101,116,114,111,80,97,100,44,32,80,108,97,121,101,114,32,37,117,44,32,66,117,116,116,111,110,32,34,37,115,34,32,61,62,32,34,37,115,34,10,0,0,0,79,112,50,49,90,114,0,0,75,79,85,84,69,84,83,85,45,78,79,32,75,73,83,72,73,32,50,0,0,0,0,0,79,112,50,49,109,0,0,0,75,79,85,84,69,84,83,85,45,78,79,32,75,73,83,72,73,0,0,0,0,0,0,0,79,112,49,49,89,114,0,0,75,105,110,103,32,65,114,116,104,117,114,115,32,87,111,114,108,100,0,0,0,0,0,0,118,105,100,101,111,95,97,108,108,111,119,95,114,111,116,97,116,101,0,0,0,0,0,0,79,112,49,49,88,114,0,0,71,65,76,65,88,89,32,82,79,66,79,0,0,0,0,0,102,105,110,100,95,105,110,112,117,116,95,100,114,105,118,101,114,40,41,0,0,0,0,0,79,112,49,49,90,114,0,0,70,117,110,32,39,78,32,71,97,109,101,115,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,82,79,77,32,112,97,116,99,104,101,100,32,115,117,99,99,101,115,115,102,117,108,108,121,32,40,37,115,41,46,10,0,0,0,0,0,0,46,0,0,0,0,0,0,0,79,112,49,49,109,0,0,0,65,50,70,74,0,0,0,0,74,111,121,112,97,100,49,32,66,0,0,0,0,0,0,0,96,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,35,46,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,71,76,83,76,32,115,104,97,100,101,114,58,32,37,115,46,10,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,78,111,110,32,115,112,101,99,105,102,105,101,100,32,71,76,32,101,114,114,111,114,46,10,0,0,0,102,114,97,109,101,95,99,111,117,110,116,95,109,111,100,37,117,0,0,0,0,0,0,0,83,79,85,76,66,76,65,68,69,82,32,45,32,49,0,0,100,111,119,110,0,0,0,0,79,112,48,49,89,114,0,0,98,111,111,116,117,112,0,0,70,65,82,76,65,78,68,83,84,79,82,89,50,0,0,0,79,112,48,49,88,114,0,0,69,121,101,32,111,102,32,116,104,101,32,66,101,104,111,108,100,101,114,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,115,101,116,32,100,105,115,107,32,37,117,32,111,102,32,37,117,46,0,0,0,0,79,112,48,49,90,114,0,0,65,56,55,74,0,0,0,0,82,51,32,98,117,116,116,111,110,32,40,114,105,103,104,116,32,97,110,97,108,111,103,32,98,117,116,116,111,110,41,0,79,112,48,49,109,0,0,0,68,82,65,71,79,78,32,75,78,73,71,72,84,32,52,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,73,78,80,85,84,95,68,69,83,67,82,73,80,84,79,82,83,58,10,0,0,0,0,0,0,79,112,48,54,77,0,0,0,65,56,56,74,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,68,105,100,110,39,116,32,114,101,97,100,32,119,104,111,108,101,32,102,105,108,101,46,10,0,0,0,0,79,112,48,54,86,0,0,0,83,85,80,69,82,32,82,79,66,79,84,32,87,65,82,83,32,52,0,0,0,0,0,0,79,112,48,54,72,0,0,0,65,82,52,74,0,0,0,0,118,105,100,101,111,95,115,104,97,100,101,114,95,101,110,97,98,108,101,0,0,0,0,0,79,112,48,54,90,0,0,0,77,32,86,101,0,0,0,0,9,37,115,10,0,0,0,0,65,67,78,80,0,0,0,0,79,112,48,54,89,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,109,101,109,111,114,121,32,102,111,114,32,112,97,116,99,104,101,100,32,82,79,77,32,46,46,46,10,0,0,0,0,0,79,112,48,54,88,0,0,0,67,65,78,78,79,78,32,70,79,68,68,69,82,0,0,0,74,111,121,112,97,100,49,32,65,0,0,0,0,0,0,0,96,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,32,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,116,101,120,116,117,114,101,32,105,109,97,103,101,32,102,114,111,109,58,32,34,37,115,34,10,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,71,76,58,32,79,117,116,32,111,102,32,109,101,109,111,114,121,46,10,0,0,0,0,0,0,0,0,119,114,97,112,95,109,111,100,101,37,117,0,0,0,0,0,67,81,32,32,0,0,0,0,117,112,0,0,0,0,0,0,79,112,48,65,68,0,0,0,100,105,114,116,121,50,0,0,67,65,77,69,76,84,82,89,0,0,0,0,0,0,0,0,79,112,48,65,67,0,0,0,69,81,0,0,0,0,0,0,82,101,109,111,118,101,100,32,100,105,115,107,32,102,114,111,109,32,116,114,97,121,46,0,79,112,48,65,66,0,0,0,67,73,86,73,76,73,90,65,84,73,79,78,0,0,0,0,118,49,46,53,50,46,52,0,82,101,116,114,111,65,114,99,104,58,32,79,70,70,83,69,84,58,32,37,117,44,32,67,83,73,90,69,58,32,37,117,44,32,83,73,90,69,58,32,37,117,46,10,0,0,0,0,79,112,48,65,65,0,0,0,73,72,68,82,0,0,0,0,65,66,88,69,0,0,0,0,103,108,80,114,111,103,114,97,109,66,105,110,97,114,121,79,69,83,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,91,71,76,93,58,32,83,116,111,99,107,32,71,76,83,76,32,115,104,97,100,101,114,115,32,119,105,108,108,32,98,101,32,117,115,101,100,46,10,0,0,0,0,0,79,112,48,65,86,83,0,0,82,101,116,114,111,65,114,99,104,58,32,91,69,77,83,67,82,73,80,84,69,78,47,69,71,76,93,58,32,65,116,116,101,109,112,116,101,100,32,116,111,32,114,101,45,105,110,105,116,105,97,108,105,122,101,32,100,114,105,118,101,114,46,10,0,0,0,0,0,0,0,0,66,82,69,65,75,84,82,72,85,33,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,71,76,93,58,32,67,97,110,110,111,116,32,102,105,110,100,32,115,104,97,100,101,114,32,99,111,114,101,32,102,111,114,32,112,97,116,104,58,32,37,115,46,10,0,0,0,0,0,0,0,79,112,48,50,67,89,0,0,65,81,73,74,0,0,0,0,79,112,48,50,67,88,0,0,66,82,65,78,68,73,83,72,50,32,69,88,80,69,82,84,0,0,0,0,0,0,0,0,67,79,82,69,32,83,69,76,69,67,84,73,79,78,32,37,115,0,0,0,0,0,0,0,118,105,100,101,111,95,115,104,97,100,101,114,0,0,0,0,99,103,0,0,0,0,0,0,83,70,67,32,83,65,73,76,79,82,77,79,79,78,32,83,0,0,0,0,0,0,0,0,79,112,48,50,86,86,65,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,114,101,97,100,32,105,109,97,103,101,58,32,37,115,46,10,0,74,117,115,116,105,102,105,101,114,32,117,115,101,100,32,109,111,114,101,32,116,104,97,110,32,111,110,99,101,33,32,68,105,115,97,98,108,105,110,103,32,101,120,116,114,97,32,105,110,115,116,97,110,99,101,115,0,0,0,0,0,0,0,0,65,118,97,105,108,97,98,108,101,32,105,110,112,117,116,32,100,114,105,118,101,114,115,32,97,114,101,58,10,0,0,0,79,112,48,50,86,79,70,0,65,54,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,70,111,117,110,100,32,37,115,32,102,105,108,101,32,105,110,32,34,37,115,34,44,32,97,116,116,101,109,112,116,105,110,103,32,116,111,32,112,97,116,99,104,32,46,46,46,10,0,0,0,0,0,0,79,112,48,50,65,90,83,0,65,82,75,65,78,79,73,68,32,68,79,72,32,73,84,32,65,71,65,73,78,48,0,0,91,108,105,98,114,101,116,114,111,93,58,32,70,97,105,108,101,100,32,116,111,32,105,110,105,116,32,77,101,109,111,114,121,32,111,114,32,65,80,85,46,10,0,0,0,0,0,0,69,82,82,79,82,58,32,82,101,106,101,99,116,105,110,103,32,97,116,116,101,109,112,116,32,116,111,32,99,111,110,116,114,111,108,32,74,117,115,116,105,102,105,101,114,50,32,119,105,116,104,32,116,119,111,32,112,111,105,110,116,101,114,115,10,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,76,111,97,100,105,110,103,32,116,101,120,116,117,114,101,32,105,109,97,103,101,32,102,114,111,109,58,32,34,37,115,34,32,46,46,46,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,71,76,58,32,73,110,118,97,108,105,100,32,111,112,101,114,97,116,105,111,110,46,10,0,0,0,0,79,70,70,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,111,118,101,114,108,97,121,115,32,118,97,114,105,97,98,108,101,32,110,111,116,32,100,101,102,105,110,101,100,32,105,110,32,99,111,110,102,105,103,46,10,0,0,102,105,108,116,101,114,95,108,105,110,101,97,114,37,117,0,74,71,32,32,0,0,0,0,115,116,97,114,116,0,0,0,79,112,48,50,65,65,83,0,100,105,114,116,121,0,0,0,115,104,97,50,53,54,0,0,65,65,76,74,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,119,114,105,116,101,32,105,109,97,103,101,32,104,101,97,100,101,114,46,10,0,0,0,0,0,60,47,37,115,62,0,0,0,67,80,85,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,9,68,101,115,99,114,105,112,116,105,111,110,58,32,37,115,10,0,0,0,0,82,79,77,32,105,109,97,103,101,32,105,115,32,105,110,32,105,110,116,101,114,108,101,97,118,101,100,32,102,111,114,109,97,116,32,45,32,99,111,110,118,101,114,116,105,110,103,46,46,46,0,0,0,0,0,0,79,112,48,50,76,69,83,0,65,76,73,67,69,32,80,65,73,78,84,0,0,0,0,0,83,101,116,116,105,110,103,32,100,105,115,107,32,37,117,32,111,102,32,37,117,32,105,110,32,116,114,97,121,46,0,0,79,112,48,50,76,70,69,0,65,67,77,0,0,0,0,0,76,51,32,98,117,116,116,111,110,32,40,108,101,102,116,32,97,110,97,108,111,103,32,98,117,116,116,111,110,41,0,0,79,112,48,50,70,90,0,0,65,67,77,69,32,65,78,73,77,65,84,73,79,78,32,70,65,67,84,79,82,0,0,0,79,112,48,50,70,89,0,0,81,52,0,0,0,0,0,0,79,112,48,50,70,88,0,0,77,73,67,82,79,32,77,65,67,72,73,78,69,83,0,0,79,112,48,67,89,50,0,0,77,65,68,68,69,78,0,0,118,105,100,101,111,95,114,101,102,114,101,115,104,95,114,97,116,101,0,0,0,0,0,0,79,112,48,67,88,50,0,0,78,72,76,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,110,39,116,32,102,105,110,100,32,97,110,121,32,105,110,112,117,116,32,100,114,105,118,101,114,32,110,97,109,101,100,32,34,37,115,34,10,0,79,112,48,67,89,49,0,0,70,73,70,65,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,68,105,100,32,110,111,116,32,102,105,110,100,32,97,32,118,97,108,105,100,32,82,79,77,32,112,97,116,99,104,46,10,0,0,0,0,0,79,112,48,67,88,49,0,0,65,87,70,0,0,0,0,0,91,108,105,98,114,101,116,114,111,93,58,32,85,110,107,110,111,119,110,32,100,101,118,105,99,101,46,46,46,10,0,0,69,82,82,79,82,58,32,82,101,106,101,99,116,105,110,103,32,97,116,116,101,109,112,116,32,116,111,32,99,111,110,116,114,111,108,32,74,117,115,116,105,102,105,101,114,49,32,119,105,116,104,32,116,119,111,32,112,111,105,110,116,101,114,115,10,0,0,0,0,0,0,0,114,117,98,121,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,71,76,58,32,73,110,118,97,108,105,100,32,118,97,108,117,101,46,10,0,0,0,0,0,0,0,0,79,78,0,0,0,0,0,0,115,104,97,100,101,114,37,117,0,0,0,0,0,0,0,0,71,65,73,65,32,71,69,78,83,79,85,75,73,32,49,32,74,80,78,0,0,0,0,0,115,101,108,101,99,116,0,0,79,112,48,67,65,0,0,0,78,65,77,0,0,0,0,0,86,105,114,116,117,97,108,32,83,111,99,99,101,114,0,0,79,112,48,52,67,111,115,0,86,69,71,65,83,32,83,84,65,75,69,83,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,37,115,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,116,97,107,101,32,115,99,114,101,101,110,115,104,111,116,32,46,46,46,10,0,0,0,0,0,0,79,112,48,52,83,105,110,0,84,105,110,121,32,84,111,111,110,32,83,112,111,114,116,115,0,0,0,0,0,0,0,0,79,112,48,52,82,97,100,105,117,115,0,0,0,0,0,0,84,72,69,32,80,69,65,67,69,32,75,69,69,80,69,82,83,0,0,0,0,0,0,0,79,112,48,52,65,110,103,108,101,0,0,0,0,0,0,0,65,70,89,0,0,0,0,0,79,112,49,48,69,120,112,111,110,101,110,116,82,0,0,0,65,84,51,74,0,0,0,0,79,112,49,48,67,111,101,102,102,105,99,105,101,110,116,82,0,0,0,0,0,0,0,0,65,55,80,74,0,0,0,0,118,105,100,101,111,95,97,115,112,101,99,116,95,114,97,116,105,111,95,97,117,116,111,0,79,112,49,48,69,120,112,111,110,101,110,116,0,0,0,0,65,81,81,74,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,101,116,32,97,117,100,105,111,32,105,110,112,117,116,32,114,97,116,101,32,116,111,58,32,37,46,50,102,32,72,122,46,10,0,0,0,79,112,49,48,67,111,101,102,102,105,99,105,101,110,116,0,65,80,52,74,0,0,0,0,73,80,83,0,0,0,0,0,79,112,50,48,82,101,115,117,108,116,0,0,0,0,0,0,65,70,53,74,0,0,0,0,49,48,48,77,72,122,0,0,69,82,82,79,82,58,32,82,101,106,101,99,116,105,110,103,32,97,116,116,101,109,112,116,32,116,111,32,99,111,110,116,114,111,108,32,83,117,112,101,114,83,99,111,112,101,32,119,105,116,104,32,116,119,111,32,112,111,105,110,116,101,114,115,10,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,71,76,58,32,73,110,118,97,108,105,100,32,101,110,117,109,46,10,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,88,77,76,32,115,104,97,100,101,114,32,46,46,46,10,0,0,0,0,0,65,86,67,74,0,0,0,0,79,112,50,48,77,117,108,116,105,112,108,105,101,114,0,0,65,80,66,74,0,0,0,0,79,112,50,48,77,117,108,116,105,112,108,105,99,97,110,100,0,0,0,0,0,0,0,0,65,52,66,74,0,0,0,0,99,108,111,115,101,0,0,0,79,112,48,48,82,101,115,117,108,116,0,0,0,0,0,0,65,79,57,0,0,0,0,0,82,50,32,98,117,116,116,111,110,32,40,114,105,103,104,116,32,115,104,111,117,108,100,101,114,32,35,50,41,0,0,0,79,112,48,48,77,117,108,116,105,112,108,105,101,114,0,0,83,117,103,111,114,111,32,81,117,101,115,116,43,43,0,0,79,112,48,48,77,117,108,116,105,112,108,105,99,97,110,100,0,0,0,0,0,0,0,0,83,85,71,79,73,32,72,69,66,69,82,69,75,69,0,0,109,97,116,114,105,120,67,91,50,93,0,0,0,0,0,0,83,77,65,83,72,32,84,69,78,78,73,83,0,0,0,0,109,97,116,114,105,120,66,91,50,93,0,0,0,0,0,0,83,101,105,107,101,110,68,101,110,115,101,116,115,117,32,50,0,0,0,0,0,0,0,0,97,115,112,101,99,116,95,114,97,116,105,111,95,105,110,100,101,120,0,0,0,0,0,0,109,97,116,114,105,120,65,91,50,93,0,0,0,0,0,0,83,46,78,105,103,104,116,32,83,76,65,77,32,77,65,83,84,69,82,83,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,71,97,109,101,32,70,80,83,32,62,32,77,111,110,105,116,111,114,32,70,80,83,46,32,67,97,110,110,111,116,32,114,101,108,121,32,111,110,32,86,83,121,110,99,46,10,0,0,0,0,0,0,0,66,32,98,117,116,116,111,110,32,40,100,111,119,110,41,0,37,117,58,37,117,32,40,49,58,49,32,80,65,82,41,0,109,97,116,114,105,120,67,91,49,93,0,0,0,0,0,0,82,85,83,72,73,78,71,32,66,69,65,84,32,83,89,85,82,65,0,0,0,0,0,0,66,80,83,0,0,0,0,0,109,97,116,114,105,120,66,91,49,93,0,0,0,0,0,0,65,82,86,69,0,0,0,0,56,48,77,72,122,0,0,0,69,82,82,79,82,58,32,82,101,106,101,99,116,105,110,103,32,97,116,116,101,109,112,116,32,116,111,32,99,111,110,116,114,111,108,32,77,111,117,115,101,50,32,119,105,116,104,32,116,119,111,32,112,111,105,110,116,101,114,115,10,0,0,0,84,101,120,116,117,114,101,0,82,101,116,114,111,65,114,99,104,58,32,71,76,58,32,76,111,97,100,101,100,32,37,117,32,112,114,111,103,114,97,109,40,115,41,46,10,0,0,0,78,101,97,114,101,115,116,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,110,39,116,32,102,105,110,100,32,118,101,114,116,101,120,32,115,104,97,100,101,114,32,110,111,114,32,102,114,97,103,109,101,110,116,32,115,104,97,100,101,114,32,105,110,32,88,77,76,32,102,105,108,101,46,10,0,0,0,0,0,0,98,0,0,0,0,0,0,0,109,97,116,114,105,120,65,91,49,93,0,0,0,0,0,0,90,53,0,0,0,0,0,0,109,97,116,114,105,120,67,91,48,93,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,82,101,97,100,106,117,115,116,101,100,32,114,101,119,105,110,100,32,98,117,102,102,101,114,32,115,105,122,101,32,116,111,32,37,117,32,77,105,66,10,0,0,0,0,0,80,73,69,67,69,83,0,0,101,106,101,99,116,0,0,0,109,97,116,114,105,120,66,91,48,93,0,0,0,0,0,0,65,81,66,0,0,0,0,0,109,97,116,114,105,120,65,91,48,93,0,0,0,0,0,0,81,57,0,0,0,0,0,0,71,95,76,101,115,0,0,0,65,70,66,69,0,0,0,0,69,95,76,101,115,0,0,0,65,70,73,69,0,0,0,0,67,95,76,101,115,0,0,0,65,74,84,0,0,0,0,0,118,105,100,101,111,95,97,115,112,101,99,116,95,114,97,116,105,111,0,0,0,0,0,0,71,122,0,0,0,0,0,0,65,78,74,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,84,105,109,105,110,103,115,32,100,101,118,105,97,116,101,32,116,111,111,32,109,117,99,104,46,32,87,105,108,108,32,110,111,116,32,97,100,106,117,115,116,46,32,40,68,105,115,112,108,97,121,32,61,32,37,46,50,102,32,72,122,44,32,71,97,109,101,32,61,32,37,46,50,102,32,72,122,41,10,0,0,0,0,0,0,71,121,0,0,0,0,0,0,67,72,65,77,80,32,87,82,69,83,84,76,73,78,71,0,85,80,83,0,0,0,0,0,69,82,82,79,82,58,32,82,101,106,101,99,116,105,110,103,32,97,116,116,101,109,112,116,32,116,111,32,99,111,110,116,114,111,108,32,77,111,117,115,101,49,32,119,105,116,104,32,116,119,111,32,112,111,105,110,116,101,114,115,10,0,0,0,71,120,0,0,0,0,0,0,77,85,83,67,76,69,32,66,79,77,66,69,82,0,0,0,54,48,77,72,122,0,0,0,103,108,71,101,116,80,111,105,110,116,101,114,118,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,71,76,93,58,32,83,104,97,100,101,114,32,105,110,105,116,32,102,97,105,108,101,100,46,10,0,76,105,110,101,97,114,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,83,99,114,105,112,116,32,105,115,32,105,110,118,97,108,105,100,46,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,72,105,116,98,111,120,32,116,121,112,101,32,40,37,115,41,32,105,115,32,105,110,118,97,108,105,100,46,32,85,115,101,32,34,114,97,100,105,97,108,34,32,111,114,32,34,114,101,99,116,34,46,10,0,0,0,78,122,0,0,0,0,0,0,66,83,88,0,0,0,0,0,65,51,86,74,0,0,0,0,78,121,0,0,0,0,0,0,65,89,72,74,0,0,0,0,70,97,105,108,101,100,32,116,111,32,37,115,32,118,105,114,116,117,97,108,32,100,105,115,107,32,116,114,97,121,46,0,78,120,0,0,0,0,0,0,65,76,84,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,71,69,84,95,67,65,78,95,68,85,80,69,58,32,116,114,117,101,10,0,0,76,50,32,98,117,116,116,111,110,32,40,108,101,102,116,32,115,104,111,117,108,100,101,114,32,35,50,41,0,0,0,0,83,101,99,65,90,83,95,69,50,0,0,0,0,0,0,0,76,65,83,32,86,69,71,65,83,32,68,82,69,65,77,0,83,101,99,65,90,83,95,67,50,0,0,0,0,0,0,0,74,73,77,77,89,32,67,79,78,78,79,82,83,32,84,69,78,78,73,83,0,0,0,0,83,101,99,65,90,83,95,69,49,0,0,0,0,0,0,0,74,73,71,83,65,87,32,80,65,82,84,89,0,0,0,0,74,45,76,69,65,71,85,69,32,83,85,80,69,82,32,83,79,67,67,69,82,48,0,0,83,101,99,65,90,83,95,67,49,0,0,0,0,0,0,0,118,105,100,101,111,95,99,114,111,112,95,111,118,101,114,115,99,97,110,0,0,0,0,0,72,69,66,69,82,69,75,69,32,78,79,32,80,85,90,90,76,69,0,0,0,0,0,0,67,111,115,65,90,83,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,65,117,100,105,111,32,98,97,99,107,101,110,100,32,102,97,105,108,101,100,32,116,111,32,119,114,105,116,101,46,32,87,105,108,108,32,99,111,110,116,105,110,117,101,32,119,105,116,104,111,117,116,32,115,111,117,110,100,46,10,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,65,109,111,117,110,116,32,111,102,32,116,105,109,101,32,115,112,101,110,116,32,99,108,111,115,101,32,116,111,32,117,110,100,101,114,114,117,110,58,32,37,46,50,102,32,37,37,46,32,67,108,111,115,101,32,116,111,32,98,108,111,99,107,105,110,103,58,32,37,46,50,102,32,37,37,46,10,0,0,0,0,0,0,0,0,72,65,84,32,84,82,73,67,75,32,72,69,82,79,32,50,0,0,0,0,0,0,0,0,83,105,110,65,90,83,0,0,82,101,116,114,111,65,114,99,104,58,32,67,111,110,110,101,99,116,105,110,103,32,115,99,111,112,101,32,116,111,32,112,111,114,116,32,37,117,46,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,83,101,118,101,114,97,108,32,112,97,116,99,104,101,115,32,97,114,101,32,101,120,112,108,105,99,105,116,108,121,32,100,101,102,105,110,101,100,44,32,105,103,110,111,114,105,110,103,32,97,108,108,32,46,46,46,10,0,0,0,70,85,82,73,45,70,85,82,73,32,71,73,82,76,83,0,67,111,115,65,122,115,0,0,82,101,116,114,111,65,114,99,104,58,32,67,111,110,110,101,99,116,105,110,103,32,77,117,108,116,105,116,97,112,32,116,111,32,112,111,114,116,32,37,117,46,10,0,0,0,0,0,52,48,77,72,122,0,0,0,74,117,115,116,105,102,105,101,114,50,0,0,0,0,0,0,103,108,71,101,116,79,98,106,101,99,116,80,116,114,76,97,98,101,108,0,0,0,0,0,80,114,101,118,37,117,0,0,82,101,116,114,111,65,114,99,104,58,32,71,76,58,32,85,115,105,110,103,32,114,101,115,111,108,117,116,105,111,110,32,37,117,120,37,117,10,0,0,37,115,0,0,0,0,0,0,115,99,114,105,112,116,0,0,65,86,83,0,0,0,0,0,114,101,99,116,0,0,0,0,83,105,110,65,122,115,0,0,67,76,75,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,67,111,110,110,101,99,116,105,110,103,32,74,117,115,116,105,102,105,101,114,115,32,116,111,32,112,111,114,116,32,37,117,46,10,0,0,0,66,114,117,99,101,32,76,101,101,0,0,0,0,0,0,0,67,111,115,65,97,115,0,0,82,101,116,114,111,65,114,99,104,58,32,67,111,110,110,101,99,116,105,110,103,32,74,117,115,116,105,102,105,101,114,32,116,111,32,112,111,114,116,32,37,117,46,10,0,0,0,0,67,108,111,115,101,100,0,0,65,67,51,74,0,0,0,0,83,105,110,65,97,115,0,0,82,101,116,114,111,65,114,99,104,58,32,67,111,110,110,101,99,116,105,110,103,32,109,111,117,115,101,32,116,111,32,112,111,114,116,32,37,117,46,10,0,0,0,0,0,0,0,0,65,78,89,69,0,0,0,0,86,80,108,97,110,101,95,69,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,67,111,110,110,101,99,116,105,110,103,32,100,117,97,108,97,110,97,108,111,103,32,116,111,32,112,111,114,116,32,37,117,46,10,0,0,0,66,105,108,108,32,87,97,108,115,104,32,67,111,108,108,101,103,101,32,70,66,49,0,0,86,80,108,97,110,101,95,67,0,0,0,0,0,0,0,0,88,32,40,117,112,41,0,0,82,101,116,114,111,65,114,99,104,58,32,68,105,115,99,111,110,110,101,99,116,105,110,103,32,100,101,118,105,99,101,32,102,114,111,109,32,112,111,114,116,32,37,117,46,10,0,0,65,66,67,74,0,0,0,0,86,79,102,102,115,101,116,0,82,101,116,114,111,65,114,99,104,58,32,68,105,100,32,110,111,116,32,102,105,110,100,32,99,111,110,102,105,103,32,102,105,108,101,46,32,85,115,105,110,103,32,115,121,115,116,101,109,32,100,101,102,97,117,108,116,46,10,0,0,0,0,0,66,65,82,75,76,69,89,0,67,101,110,116,114,101,89,0,82,101,116,114,111,65,114,99,104,58,32,82,101,100,105,114,101,99,116,105,110,103,32,99,111,110,102,105,103,32,102,105,108,101,32,116,111,32,34,37,115,34,46,10,0,0,0,0,118,105,100,101,111,95,115,99,97,108,101,95,105,110,116,101,103,101,114,0,0,0,0,0,99,111,108,100,97,116,97,95,117,112,100,97,116,101,95,115,99,114,101,101,110,32,61,32,37,100,10,0,0,0,0,0,67,101,110,116,114,101,88,0,46,99,102,103,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,65,118,101,114,97,103,101,32,97,117,100,105,111,32,98,117,102,102,101,114,32,115,97,116,117,114,97,116,105,111,110,58,32,37,46,50,102,32,37,37,44,32,115,116,97,110,100,97,114,100,32,100,101,118,105,97,116,105,111,110,32,40,112,101,114,99,101,110,116,97,103,101,32,112,111,105,110,116,115,41,58,32,37,46,50,102,32,37,37,46,10,0,0,80,80,85,46,83,70,88,83,112,101,101,100,117,112,72,97,99,107,32,61,32,37,100,10,0,0,0,0,0,0,0,0,102,105,114,115,116,95,112,97,114,97,109,101,116,101,114,0,82,101,116,114,111,65,114,99,104,58,32,82,101,100,105,114,101,99,116,105,110,103,32,115,97,118,101,32,115,116,97,116,101,32,116,111,32,34,37,115,34,46,10,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,67,82,67,51,50,58,32,48,120,37,120,44,32,83,72,65,50,53,54,58,32,37,115,10,0,0,0,0,0,83,101,116,116,105,110,103,115,46,83,112,101,101,100,104,97,99,107,71,97,109,101,73,68,32,61,32,37,100,10,0,0,79,112,48,68,73,110,76,101,110,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,82,101,100,105,114,101,99,116,105,110,103,32,115,97,118,101,32,102,105,108,101,32,116,111,32,34,37,115,34,46,10,0,0,0,0,0,0,100,105,115,97,98,108,101,100,0,0,0,0,0,0,0,0,74,117,115,116,105,102,105,101,114,49,0,0,0,0,0,0,103,108,79,98,106,101,99,116,80,116,114,76,97,98,101,108,0,0,0,0,0,0,0,0,80,114,101,118,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,71,76,93,58,32,86,101,114,115,105,111,110,58,32,37,115,46,10,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,73,109,112,111,114,116,32,118,97,108,117,101,32,105,115,32,105,110,118,97,108,105,100,46,10,0,0,83,101,116,116,105,110,103,115,46,84,114,97,110,115,112,97,114,101,110,99,121,32,61,32,37,100,10,0,0,0,0,0,114,97,100,105,97,108,0,0,79,112,48,68,79,117,116,76,101,110,0,0,0,0,0,0,83,82,84,0,0,0,0,0,46,120,109,108,0,0,0,0,80,80,85,46,70,117,108,108,67,108,105,112,112,105,110,103,32,61,32,37,100,10,0,0,79,112,48,68,72,97,115,76,101,110,0,0,0,0,0,0,46,105,112,115,0,0,0,0,69,106,101,99,116,101,100,0,80,80,85,46,82,101,110,100,101,114,83,117,98,32,61,32,37,100,10,0,0,0,0,0,79,112,48,57,87,111,114,100,50,0,0,0,0,0,0,0,46,98,112,115,0,0,0,0,82,32,98,117,116,116,111,110,32,40,114,105,103,104,116,32,115,104,111,117,108,100,101,114,41,0,0,0,0,0,0,0,65,67,57,74,0,0,0,0,79,112,48,57,87,111,114,100,49,0,0,0,0,0,0,0,46,117,112,115,0,0,0,0,65,67,84,0,0,0,0,0,79,112,48,54,76,101,110,0])
.concat([65,32,40,114,105,103,104,116,41,0,0,0,0,0,0,0,88,65,82,68,73,79,78,0,79,112,48,54,72,97,115,76,101,110,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,83,117,102,97,109,105,32,84,117,114,98,111,32,83,82,65,77,32,112,97,116,104,115,32,119,105,108,108,32,98,101,32,105,110,102,101,114,114,101,100,32,102,114,111,109,32,116,104,101,105,114,32,114,101,115,112,101,99,116,105,118,101,32,112,97,116,104,115,32,116,111,32,97,118,111,105,100,32,99,111,110,102,108,105,99,116,115,46,10,0,0,0,88,65,75,32,49,0,0,0,79,112,48,53,84,114,97,110,115,112,97,114,101,110,116,0,118,105,100,101,111,95,102,111,114,99,101,95,97,115,112,101,99,116,0,0,0,0,0,0,68,79,79,77,0,0,0,0,79,112,48,53,76,101,110,0,46,112,115,114,109,0,0,0,82,101,116,114,111,65,114,99,104,58,32,70,111,117,110,100,32,115,104,97,100,101,114,32,34,37,115,34,10,0,0,0,68,85,78,71,69,79,78,32,77,65,83,84,69,82,0,0,79,112,48,53,72,97,115,76,101,110,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,103,97,109,101,46,10,0,0,0,0,0,0,83,85,80,69,82,32,84,85,82,82,73,67,65,78,32,50,0,0,0,0,0,0,0,0,79,65,77,95,82,111,119,0,9,45,68,47,45,45,100,101,116,97,99,104,58,32,68,101,116,97,99,104,32,82,101,116,114,111,65,114,99,104,32,102,114,111,109,32,116,104,101,32,114,117,110,110,105,110,103,32,99,111,110,115,111,108,101,46,32,78,111,116,32,114,101,108,101,118,97,110,116,32,102,111,114,32,97,108,108,32,112,108,97,116,102,111,114,109,115,46,10,0,0,0,0,0,0,0,118,97,108,117,101,58,32,37,115,10,0,0,0,0,0,0,83,117,112,101,114,115,99,111,112,101,0,0,0,0,0,0,103,108,71,101,116,79,98,106,101,99,116,76,97,98,101,108,0,0,0,0,0,0,0,0,80,97,115,115,37,117,0,0,82,101,116,114,111,65,114,99,104,58,32,91,71,76,93,58,32,86,101,110,100,111,114,58,32,37,115,44,32,82,101,110,100,101,114,101,114,58,32,37,115,46,10,0,0,0,0,0,102,114,111,110,116,101,110,100,47,109,101,110,117,47,46,46,47,46,46,47,103,102,120,47,46,46,47,103,101,110,101,114,97,108,46,104,0,0,0,0,105,109,112,111,114,116,0,0,70,73,78,65,76,32,70,73,71,72,84,32,50,0,0,0,65,68,68,45,79,78,32,66,65,83,69,32,67,65,83,83,69,84,69,0,0,0,0,0,111,118,101,114,108,97,121,37,117,95,100,101,115,99,37,117,95,110,101,120,116,95,116,97,114,103,101,116,0,0,0,0,79,65,77,95,82,111,119,77,97,120,0,0,0,0,0,0,83,55,49,0,0,0,0,0,9,45,88,47,45,45,120,109,108,58,32,83,112,101,99,105,102,105,101,115,32,112,97,116,104,32,116,111,32,88,77,76,32,109,101,109,111,114,121,32,109,97,112,46,0,0,0,0,80,72,65,76,65,78,88,0,79,65,77,95,98,105,116,115,0,0,0,0,0,0,0,0,9,45,45,110,111,45,112,97,116,99,104,58,32,68,105,115,97,98,108,101,115,32,97,108,108,32,102,111,114,109,115,32,111,102,32,114,111,109,32,112,97,116,99,104,105,110,103,46,0,0,0,0,0,0,0,0,37,115,32,118,105,114,116,117,97,108,32,100,105,115,107,32,116,114,97,121,46,0,0,0,88,45,75,65,76,73,66,69,82,32,50,48,57,55,0,0,79,65,77,95,105,110,100,101,120,0,0,0,0,0,0,0,9,45,45,105,112,115,58,32,83,112,101,99,105,102,105,101,115,32,112,97,116,104,32,102,111,114,32,73,80,83,32,112,97,116,99,104,32,116,104,97,116,32,119,105,108,108,32,98,101,32,97,112,112,108,105,101,100,32,116,111,32,82,79,77,46,0,0,0,0,0,0,0,83,85,80,69,82,32,71,72,79,85,76,83,39,78,32,71,72,79,83,84,83,0,0,0,79,65,77,95,97,116,116,114,0,0,0,0,0,0,0,0,9,45,45,98,112,115,58,32,83,112,101,99,105,102,105,101,115,32,112,97,116,104,32,102,111,114,32,66,80,83,32,112,97,116,99,104,32,116,104,97,116,32,119,105,108,108,32,98,101,32,97,112,112,108,105,101,100,32,116,111,32,82,79,77,46,0,0,0,0,0,0,0,67,72,79,72,77,65,75,65,73,77,85,82,65,0,0,0,112,111,108,121,95,112,108,97,110,101,0,0,0,0,0,0,68,45,80,97,100,32,82,105,103,104,116,0,0,0,0,0,9,45,85,47,45,45,117,112,115,58,32,83,112,101,99,105,102,105,101,115,32,112,97,116,104,32,102,111,114,32,85,80,83,32,112,97,116,99,104,32,116,104,97,116,32,119,105,108,108,32,98,101,32,97,112,112,108,105,101,100,32,116,111,32,82,79,77,46,0,0,0,0,67,79,78,84,82,65,51,32,84,72,69,32,65,76,73,69,78,32,87,65,82,83,0,0,112,111,108,121,95,115,116,97,114,116,0,0,0,0,0,0,9,45,118,47,45,45,118,101,114,98,111,115,101,58,32,86,101,114,98,111,115,101,32,108,111,103,103,105,110,103,46,0,83,85,80,69,82,32,83,87,73,86,0,0,0,0,0,0,112,111,108,121,95,99,120,91,49,93,0,0,0,0,0,0,9,9,68,111,32,110,111,116,101,32,116,104,97,116,32,110,111,108,111,97,100,45,115,97,118,101,32,105,109,112,108,105,101,115,32,116,104,97,116,32,115,97,118,101,32,102,105,108,101,115,32,119,105,108,108,32,98,101,32,100,101,108,101,116,101,100,32,97,110,100,32,111,118,101,114,119,114,105,116,116,101,110,46,0,0,0,0,0,118,105,100,101,111,95,115,109,111,111,116,104,0,0,0,0,82,79,67,75,77,65,78,38,70,79,82,84,69,0,0,0,112,111,108,121,95,98,111,116,116,111,109,91,49,93,0,0,9,9,123,110,111,44,125,108,111,97,100,45,123,110,111,44,125,115,97,118,101,32,100,101,115,99,114,105,98,101,115,32,105,102,32,83,82,65,77,32,115,104,111,117,108,100,32,98,101,32,108,111,97,100,101,100,44,32,97,110,100,32,105,102,32,83,82,65,77,32,115,104,111,117,108,100,32,98,101,32,115,97,118,101,100,46,0,0,115,104,97,100,101,114,124,99,103,124,99,103,112,124,103,108,115,108,124,103,108,115,108,112,0,0,0,0,0,0,0,0,65,76,83,74,0,0,0,0,112,111,108,121,95,116,111,112,91,49,93,0,0,0,0,0,9,45,77,47,45,45,115,114,97,109,45,109,111,100,101,58,32,84,97,107,101,115,32,97,110,32,97,114,103,117,109,101,110,116,32,116,101,108,108,105,110,103,32,104,111,119,32,83,82,65,77,32,115,104,111,117,108,100,32,98,101,32,104,97,110,100,108,101,100,32,105,110,32,116,104,101,32,115,101,115,115,105,111,110,46,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,32,110,111,116,32,114,101,97,100,32,82,79,77,32,102,105,108,101,58,32,34,37,115,34,46,10,0,0,0,0,77,111,117,115,101,50,0,0,65,80,85,69,0,0,0,0,112,111,108,121,95,114,97,115,116,101,114,91,49,93,0,0,9,45,82,47,45,45,98,115,118,114,101,99,111,114,100,58,32,83,116,97,114,116,32,114,101,99,111,114,100,105,110,103,32,97,32,66,83,86,32,109,111,118,105,101,32,102,105,108,101,32,102,114,111,109,32,116,104,101,32,98,101,103,105,110,110,105,110,103,46,0,0,0,66,83,45,88,46,98,105,110,0,0,0,0,0,0,0,0,103,108,79,98,106,101,99,116,76,97,98,101,108,0,0,0,80,97,115,115,80,114,101,118,37,117,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,68,101,116,101,99,116,105,110,103,32,115,99,114,101,101,110,32,114,101,115,111,108,117,116,105,111,110,32,37,117,120,37,117,46,10,0,0,48,46,57,46,57,46,51,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,65,115,115,101,114,116,105,111,110,32,102,97,105,108,101,100,32,97,116,32,37,115,58,37,100,46,10,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,84,101,120,116,117,114,101,32,105,109,97,103,101,32,102,97,105,108,101,100,32,116,111,32,108,111,97,100,46,10,0,0,0,0,0,65,82,57,0,0,0,0,0,112,111,108,121,95,112,116,114,91,49,93,0,0,0,0,0,79,66,77,0,0,0,0,0,9,45,80,47,45,45,98,115,118,112,108,97,121,58,32,80,108,97,121,98,97,99,107,32,97,32,66,83,86,32,109,111,118,105,101,32,102,105,108,101,46,0,0,0,0,0,0,0,65,51,50,74,0,0,0,0,112,111,108,121,95,99,108,105,112,82,116,91,49,93,0,0,9,45,52,47,45,45,109,117,108,116,105,116,97,112,58,32,67,111,110,110,101,99,116,32,97,32,83,78,69,83,32,109,117,108,116,105,116,97,112,32,116,111,32,112,111,114,116,32,50,46,32,40,83,78,69,83,32,115,112,101,99,105,102,105,99,41,46,0,0,0,0,0,65,112,112,101,110,100,101,100,32,100,105,115,107,58,32,37,115,0,0,0,0,0,0,0,66,70,82,74,0,0,0,0,112,111,108,121,95,99,108,105,112,76,102,91,49,93,0,0,9,45,74,47,45,45,106,117,115,116,105,102,105,101,114,115,58,32,68,97,105,115,121,32,99,104,97,105,110,32,116,119,111,32,118,105,114,116,117,97,108,32,75,111,110,97,109,105,32,74,117,115,116,105,102,105,101,114,115,32,105,110,116,111,32,112,111,114,116,32,50,46,32,40,83,78,69,83,32,115,112,101,99,105,102,105,99,41,46,0,0,0,0,0,0,0,76,32,98,117,116,116,111,110,32,40,108,101,102,116,32,115,104,111,117,108,100,101,114,41,0,0,0,0,0,0,0,0,83,72,86,67,32,70,73,82,69,69,77,66,76,69,77,0,112,111,108,121,95,99,120,91,48,93,0,0,0,0,0,0,9,45,106,47,45,45,106,117,115,116,105,102,105,101,114,58,32,67,111,110,110,101,99,116,32,97,32,118,105,114,116,117,97,108,32,75,111,110,97,109,105,32,74,117,115,116,105,102,105,101,114,32,105,110,116,111,32,112,111,114,116,32,50,46,32,40,83,78,69,83,32,115,112,101,99,105,102,105,99,41,46,0,0,0,0,0,0,0,65,82,87,0,0,0,0,0,112,111,108,121,95,98,111,116,116,111,109,91,48,93,0,0,68,45,80,97,100,32,76,101,102,116,0,0,0,0,0,0,9,45,112,47,45,45,115,99,111,112,101,58,32,67,111,110,110,101,99,116,32,97,32,118,105,114,116,117,97,108,32,83,117,112,101,114,83,99,111,112,101,32,105,110,116,111,32,112,111,114,116,32,50,46,32,40,83,78,69,83,32,115,112,101,99,105,102,105,99,41,46,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,110,39,116,32,97,108,108,111,99,97,116,101,32,109,101,109,111,114,121,46,10,0,84,72,69,32,78,73,78,74,65,87,65,82,82,73,79,82,83,0,0,0,0,0,0,0,112,111,108,121,95,116,111,112,91,48,93,0,0,0,0,0,9,45,109,47,45,45,109,111,117,115,101,58,32,67,111,110,110,101,99,116,32,97,32,109,111,117,115,101,32,105,110,116,111,32,112,111,114,116,32,111,102,32,116,104,101,32,100,101,118,105,99,101,32,40,49,32,116,111,32,37,100,41,46,10,0,0,0,0,0,0,0,0,82,45,84,89,80,69,32,51,0,0,0,0,0,0,0,0,112,111,108,121,95,114,97,115,116,101,114,91,48,93,0,0,9,45,65,47,45,45,100,117,97,108,97,110,97,108,111,103,58,32,67,111,110,110,101,99,116,32,97,32,68,117,97,108,65,110,97,108,111,103,32,99,111,110,116,114,111,108,108,101,114,32,116,111,32,112,111,114,116,32,40,49,32,116,111,32,37,100,41,46,10,0,0,0,118,105,100,101,111,95,116,104,114,101,97,100,101,100,0,0,32,10,9,12,13,11,0,0,87,73,76,68,32,71,85,78,83,0,0,0,0,0,0,0,112,111,108,121,95,112,116,114,91,48,93,0,0,0,0,0,9,45,78,47,45,45,110,111,100,101,118,105,99,101,58,32,68,105,115,99,111,110,110,101,99,116,115,32,99,111,110,116,114,111,108,108,101,114,32,100,101,118,105,99,101,32,99,111,110,110,101,99,116,101,100,32,116,111,32,112,111,114,116,32,40,49,32,116,111,32,37,100,41,46,10,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,48,82,71,66,49,53,53,53,32,112,105,120,101,108,32,102,111,114,109,97,116,32,105,115,32,100,101,112,114,101,99,97,116,101,100,44,32,97,110,100,32,119,105,108,108,32,98,101,32,115,108,111,119,101,114,46,32,70,111,114,32,49,53,47,49,54,45,98,105,116,44,32,82,71,66,53,54,53,32,102,111,114,109,97,116,32,105,115,32,112,114,101,102,101,114,114,101,100,46,10,0,0,0,0,0,0,0,0,83,85,80,69,82,32,87,73,68,71,69,84,0,0,0,0,112,111,108,121,95,99,108,105,112,82,116,91,48,93,0,0,9,45,45,115,117,102,97,109,105,66,58,32,80,97,116,104,32,116,111,32,66,32,115,108,111,116,32,111,102,32,83,117,102,97,109,105,32,84,117,114,98,111,46,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,82,79,77,32,108,111,97,100,105,110,103,32,115,107,105,112,112,101,100,46,32,73,109,112,108,101,109,101,110,116,97,116,105,111,110,32,119,105,108,108,32,108,111,97,100,32,105,116,32,111,110,32,105,116,115,32,111,119,110,46,10,0,0,0,0,0,0,0,0,65,83,82,0,0,0,0,0,112,111,108,121,95,99,108,105,112,76,102,91,48,93,0,0,9,45,45,115,117,102,97,109,105,65,58,32,80,97,116,104,32,116,111,32,65,32,115,108,111,116,32,111,102,32,83,117,102,97,109,105,32,84,117,114,98,111,46,32,76,111,97,100,32,83,117,102,97,109,105,32,98,97,115,101,32,99,97,114,116,32,97,115,32,114,101,103,117,108,97,114,32,114,111,109,46,0,0,0,0,0,0,0,77,111,117,115,101,49,0,0,103,108,80,111,112,68,101,98,117,103,71,114,111,117,112,0,79,114,105,103,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,70,111,117,110,100,32,71,76,32,99,111,110,116,101,120,116,58,32,37,115,10,0,0,0,0,0,0,0,0,37,115,32,45,32,37,115,32,37,115,0,0,0,0,0,0,46,46,46,0,0,0,0,0,116,101,120,116,117,114,101,0,65,67,54,74,0,0,0,0,82,80,71,45,84,67,79,79,76,32,50,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,79,118,101,114,108,97,121,32,100,101,115,99,32,105,115,32,105,110,118,97,108,105,100,46,32,82,101,113,117,105,114,101,115,32,97,116,32,108,101,97,115,116,32,54,32,116,111,107,101,110,115,46,10,0,0,0,115,112,114,105,116,101,95,99,111,117,110,116,0,0,0,0,79,66,67,0,0,0,0,0,9,45,66,47,45,45,98,115,120,115,108,111,116,58,32,80,97,116,104,32,116,111,32,66,83,88,32,115,108,111,116,116,101,100,32,114,111,109,46,32,76,111,97,100,32,66,83,88,32,66,73,79,83,32,97,115,32,116,104,101,32,114,101,103,117,108,97,114,32,114,111,109,46,0,0,0,0,0,0,0,37,115,10,0,0,0,0,0,83,85,80,69,82,32,68,79,78,75,69,89,32,75,79,78,71,0,0,0,0,0,0,0,115,112,114,105,116,101,95,99,108,105,112,121,0,0,0,0,9,45,98,47,45,45,98,115,120,58,32,80,97,116,104,32,116,111,32,66,83,88,32,114,111,109,46,32,76,111,97,100,32,66,83,88,32,66,73,79,83,32,97,115,32,116,104,101,32,114,101,103,117,108,97,114,32,114,111,109,46,0,0,0,82,101,115,101,116,46,0,0,83,32,79,32,83,0,0,0,115,112,114,105,116,101,95,115,105,122,101,0,0,0,0,0,9,45,103,47,45,45,103,97,109,101,98,111,121,58,32,80,97,116,104,32,116,111,32,71,97,109,101,98,111,121,32,82,79,77,46,32,76,111,97,100,32,83,117,112,101,114,71,97,109,101,66,111,121,32,97,115,32,116,104,101,32,114,101,103,117,108,97,114,32,114,111,109,46,0,0,0,0,0,0,0,115,109,99,124,102,105,103,124,115,102,99,124,103,100,51,124,103,100,55,124,100,120,50,124,98,115,120,124,115,119,99,0,83,97,116,101,108,108,97,118,105,101,119,32,66,83,45,88,32,32,32,32,32,0,0,0,65,82,81,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,90,73,80,32,101,120,116,114,97,99,116,105,111,110,32,102,97,105,108,101,100,32,97,116,32,108,105,110,101,58,32,37,100,46,10,0,0,0,0,0,0,0,0,115,112,114,105,116,101,95,97,116,116,114,0,0,0,0,0,9,9,77,117,108,116,105,112,108,101,32,99,111,110,102,105,103,115,32,97,114,101,32,100,101,108,105,109,105,116,101,100,32,98,121,32,39,44,39,46,0,0,0,0,0,0,0,0,103,108,71,101,116,80,114,111,103,114,97,109,66,105,110,97,114,121,79,69,83,0,0,0,65,88,66,69,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,71,76,93,58,32,70,97,105,108,101,100,32,116,111,32,112,97,114,115,101,32,71,76,83,76,32,115,104,97,100,101,114,46,10,0,0,0,0,0,0,0,0,115,112,114,105,116,101,95,121,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,69,77,83,67,82,73,80,84,69,78,47,69,71,76,93,58,32,73,110,105,116,105,97,108,105,122,105,110,103,46,46,46,10,0,0,0,68,45,80,97,100,32,68,111,119,110,0,0,0,0,0,0,9,45,45,97,112,112,101,110,100,99,111,110,102,105,103,58,32,69,120,116,114,97,32,99,111,110,102,105,103,32,102,105,108,101,115,32,97,114,101,32,108,111,97,100,101,100,32,105,110,44,32,97,110,100,32,116,97,107,101,32,112,114,105,111,114,105,116,121,32,111,118,101,114,32,99,111,110,102,105,103,32,115,101,108,101,99,116,101,100,32,105,110,32,45,99,32,40,111,114,32,100,101,102,97,117,108,116,41,46,0,0,0,103,108,0,0,0,0,0,0,37,115,10,37,115,10,37,115,10,0,0,0,0,0,0,0,65,82,70,74,0,0,0,0,115,112,114,105,116,101,95,120,0,0,0,0,0,0,0,0,9,45,99,47,45,45,99,111,110,102,105,103,58,32,80,97,116,104,32,102,111,114,32,99,111,110,102,105,103,32,102,105,108,101,46,10,9,9,66,121,32,100,101,102,97,117,108,116,32,108,111,111,107,115,32,102,111,114,32,99,111,110,102,105,103,32,105,110,32,36,88,68,71,95,67,79,78,70,73,71,95,72,79,77,69,47,114,101,116,114,111,97,114,99,104,47,114,101,116,114,111,97,114,99,104,46,99,102,103,44,10,9,9,36,72,79,77,69,47,46,99,111,110,102,105,103,47,114,101,116,114,111,97,114,99,104,47,114,101,116,114,111,97,114,99,104,46,99,102,103,44,10,9,9,97,110,100,32,36,72,79,77,69,47,46,114,101,116,114,111,97,114,99,104,46,99,102,103,46,0,0,0,0,0,65,51,90,0,0,0,0,0,118,105,101,119,112,111,114,116,95,98,111,116,116,111,109,0,9,45,83,47,45,45,115,97,118,101,115,116,97,116,101,58,32,80,97,116,104,32,116,111,32,117,115,101,32,102,111,114,32,115,97,118,101,32,115,116,97,116,101,115,46,32,73,102,32,110,111,116,32,115,101,108,101,99,116,101,100,44,32,42,46,115,116,97,116,101,32,119,105,108,108,32,98,101,32,97,115,115,117,109,101,100,46,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,111,118,101,114,108,97,121,46,10,0,0,0,118,105,100,101,111,95,104,97,114,100,95,115,121,110,99,95,102,114,97,109,101,115,0,0,34,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,73,78,67,32,112,97,114,97,109,115,32,40,37,117,32,112,104,97,115,101,32,98,105,116,115,44,32,37,117,32,116,97,112,115,41,46,10,0,0,0,0,0,0,0,76,69,77,77,73,78,71,83,0,0,0,0,0,0,0,0,118,105,101,119,112,111,114,116,95,116,111,112,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,82,80,78,71,93,58,32,85,115,105,110,103,32,82,80,78,71,32,108,111,97,100,101,114,46,10,0,0,9,45,102,47,45,45,102,117,108,108,115,99,114,101,101,110,58,32,83,116,97,114,116,32,82,101,116,114,111,65,114,99,104,32,105,110,32,102,117,108,108,115,99,114,101,101,110,32,114,101,103,97,114,100,108,101,115,115,32,111,102,32,99,111,110,102,105,103,32,115,101,116,116,105,110,103,115,46,0,0,83,117,112,101,114,115,99,111,112,101,32,117,115,101,100,32,109,111,114,101,32,116,104,97,110,32,111,110,99,101,33,32,68,105,115,97,98,108,105,110,103,32,101,120,116,114,97,32,105,110,115,116,97,110,99,101,115,0,0,0,0,0,0,0,75,82,85,83,84,89,83,32,83,85,80,69,82,70,85,78,72,79,85,83,69,0,0,0,118,105,101,119,112,111,114,116,95,114,105,103,104,116,0,0,9,45,115,47,45,45,115,97,118,101,58,32,80,97,116,104,32,102,111,114,32,115,97,118,101,32,102,105,108,101,32,40,42,46,115,114,109,41,46,0,82,101,116,114,111,65,114,99,104,58,32,82,79,77,32,115,105,122,101,58,32,37,117,32,98,121,116,101,115,46,10,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,78,101,101,100,32,116,111,32,100,101,102,105,110,101,32,97,116,32,108,101,97,115,116,32,49,32,115,104,97,100,101,114,46,10,0,75,82,85,83,84,89,83,32,83,85,80,69,82,32,70,85,78,72,79,85,83,69,0,0,118,105,101,119,112,111,114,116,95,108,101,102,116,0,0,0,9,45,45,102,101,97,116,117,114,101,115,58,32,80,114,105,110,116,115,32,97,118,97,105,108,97,98,108,101,32,102,101,97,116,117,114,101,115,32,99,111,109,112,105,108,101,100,32,105,110,116,111,32,82,101,116,114,111,65,114,99,104,46,0,80,111,105,110,116,101,114,32,0,0,0,0,0,0,0,0,103,108,80,117,115,104,68,101,98,117,103,71,114,111,117,112,0,0,0,0,0,0,0,0,70,114,97,109,101,68,105,114,101,99,116,105,111,110,0,0,82,101,116,114,111,65,114,99,104,58,32,82,101,99,114,101,97,116,105,110,103,32,70,66,79,32,116,101,120,116,117,114,101,32,35,37,100,58,32,37,117,120,37,117,10,0,0,0,71,65,77,69,32,40,37,115,41,32,37,115,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,82,71,85,73,93,58,32,79,112,101,110,105,110,103,32,104,105,115,116,111,114,121,58,32,37,115,46,10,0,0,0,0,0,0,0,0,111,118,101,114,108,97,121,115,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,88,77,76,32,115,104,97,100,101,114,32,97,116,116,114,105,98,117,116,101,115,32,100,111,32,110,111,116,32,99,111,109,112,108,121,32,119,105,116,104,32,115,112,101,99,105,102,105,99,97,116,105,111,110,115,46,10,0,0,65,80,74,74,0,0,0,0,84,72,79,82,79,85,71,72,66,82,69,68,32,66,82,69,69,68,69,82,51,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,70,97,105,108,101,100,32,116,111,32,115,112,108,105,116,32,111,118,101,114,108,97,121,32,100,101,115,99,46,10,0,0,118,105,101,119,112,111,114,116,95,99,121,0,0,0,0,0,83,84,48,0,0,0,0,0,99,97,114,116,114,105,100,103,101,0,0,0,0,0,0,0,9,9,73,102,32,110,111,32,97,114,103,117,109,101,110,116,115,32,97,114,101,32,112,97,115,115,101,100,32,116,111,32,82,101,116,114,111,65,114,99,104,44,32,105,116,32,105,115,32,101,113,117,105,118,97,108,101,110,116,32,116,111,32,117,115,105,110,103,32,45,45,109,101,110,117,32,97,115,32,111,110,108,121,32,97,114,103,117,109,101,110,116,46,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,111,112,101,110,32,102,105,108,101,32,34,37,115,34,32,102,111,114,32,115,99,114,101,101,110,115,104,111,116,46,10,0,0,47,62,0,0,0,0,0,0,78,65,77,58,37,48,54,100,58,37,115,37,99,0,0,0,82,101,116,114,111,65,114,99,104,58,32,67,111,114,101,32,111,112,116,105,111,110,58,10,0,0,0,0,0,0,0,0,65,88,83,80,0,0,0,0,118,105,101,119,112,111,114,116,95,99,120,0,0,0,0,0,66,65,84,77,65,78,45,45,82,69,86,69,78,71,69,32,74,79,75,69,82,0,0,0,9,45,45,109,101,110,117,58,32,68,111,32,110,111,116,32,114,101,113,117,105,114,101,32,82,79,77,32,111,114,32,108,105,98,114,101,116,114,111,32,99,111,114,101,32,116,111,32,98,101,32,108,111,97,100,101,100,44,32,115,116,97,114,116,115,32,100,105,114,101,99,116,108,121,32,105,110,32,109,101,110,117,46,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,82,101,115,101,116,116,105,110,103,32,103,97,109,101,46,10,0,0,0,0,0,65,66,90,69,0,0,0,0,118,105,101,119,95,116,117,114,110,111,102,102,95,100,120,0,9,45,104,47,45,45,104,101,108,112,58,32,83,104,111,119,32,116,104,105,115,32,104,101,108,112,32,109,101,115,115,97,103,101,46,0,0,0,0,0,88,32,98,117,116,116,111,110,32,40,116,111,112,41,0,0,65,78,79,84,72,69,82,32,87,79,82,76,68,0,0,0,118,105,101,119,95,116,117,114,110,111,102,102,95,120,0,0,85,115,97,103,101,58,32,114,101,116,114,111,97,114,99,104,32,91,114,111,109,32,102,105,108,101,93,32,91,111,112,116,105,111,110,115,46,46,46,93,0,0,0,0,0,0,0,0,79,85,84,69,82,32,87,79,82,76,68,0,0,0,0,0,118,105,101,119,95,121,111,102,115,101,110,118,0,0,0,0,68,45,80,97,100,32,85,112,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,70,114,111,110,116,101,110,100,32,102,111,114,32,108,105,98,114,101,116,114,111,32,45,45,32,118,48,46,57,46,57,46,51,32,45,45,0,79,85,84,32,79,70,32,84,72,73,83,32,87,79,82,76,68,0,0,0,0,0,0,0,118,105,101,119,95,121,111,102,115,50,0,0,0,0,0,0,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,61,0,0,0,0,0,70,73,78,65,76,32,70,65,78,84,65,83,89,32,53,0,118,105,101,119,95,120,111,102,115,50,0,0,0,0,0,0,83,99,114,105,112,116,32,115,117,112,112,111,114,116,32,105,110,32,115,104,97,100,101,114,115,0,0,0,0,0,0,0,118,105,100,101,111,95,104,97,114,100,95,115,121,110,99,0,33,33,33,32,35,105,110,99,108,117,100,101,32,100,101,112,116,104,32,101,120,99,101,101,100,101,100,32,102,111,114,32,99,111,110,102,105,103,46,32,77,105,103,104,116,32,98,101,32,97,32,99,121,99,108,101,46,10,0,0,0,0,0,0,80,82,73,78,67,69,32,79,70,32,80,69,82,83,73,65,0,0,0,0,0,0,0,0,118,105,101,119,95,121,111,102,115,49,0,0,0,0,0,0,80,121,116,104,111,110,0,0,82,101,116,114,111,65,114,99,104,58,32,65,118,101,114,97,103,101,32,109,111,110,105,116,111,114,32,72,122,58,32,37,46,54,102,32,72,122,46,32,40,37,46,51,102,32,37,37,32,102,114,97,109,101,32,116,105,109,101,32,100,101,118,105,97,116,105,111,110,44,32,98,97,115,101,100,32,111,110,32,37,117,32,108,97,115,116,32,115,97,109,112,108,101,115,41,46,10,0,0,0,0,0,0,77,101,110,117,32,116,111,103,103,108,101,0,0,0,0,0,80,65,82,79,68,73,85,83,0,0,0,0,0,0,0,0,118,105,101,119,95,120,111,102,115,49,0,0,0,0,0,0,80,101,101,114,45,116,111,45,112,101,101,114,32,110,101,116,112,108,97,121,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,32,110,111,116,32,114,101,97,100,32,82,79,77,32,102,105,108,101,46,10,0,0,80,65,67,32,65,84,84,65,67,75,0,0,0,0,0,0,118,105,101,119,95,100,121,0,78,101,116,112,108,97,121,0,91,108,105,98,114,101,116,114,111,93,58,32,82,111,109,32,108,111,97,100,105,110,103,32,102,97,105,108,101,100,46,46,46,10,0,0,0,0,0,0,84,114,105,103,103,101,114,0,103,108,71,101,116,68,101,98,117,103,77,101,115,115,97,103,101,76,111,103,0,0,0,0,70,114,97,109,101,67,111,117,110,116,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,114,101,105,110,105,116,32,70,66,79,32,116,101,120,116,117,114,101,46,10,0,0,0,0,0,0,68,105,115,107,32,83,119,97,112,32,78,101,120,116,0,0,78,111,32,67,111,114,101,0,46,114,101,116,114,111,97,114,99,104,45,103,97,109,101,45,104,105,115,116,111,114,121,46,116,120,116,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,77,111,100,101,114,110,32,71,76,83,76,32,119,97,115,32,99,104,111,115,101,110,32,97,110,100,32,118,101,114,116,101,120,32,115,104,97,100,101,114,32,119,97,115,32,110,111,116,32,112,114,111,118,105,100,101,100,46,32,84,104,105,115,32,105,115,32,97,110,32,101,114,114,111,114,46,10,0,0,0,0,0,0,78,79,83,70,69,82,65,84,85,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,68,105,100,110,39,116,32,102,105,110,100,32,107,101,121,58,32,37,115,46,10,0,0,0,68,69,82,66,89,32,83,84,65,76,76,73,79,78,32,57,54,0,0,0,0,0,0,0,118,105,101,119,95,100,120,0,67,88,52,0,0,0,0,0,84,84,70,32,102,111,110,116,32,114,101,110,100,101,114,105,110,103,32,119,105,116,104,32,70,114,101,101,84,121,112,101,0,0,0,0,0,0,0,0,68,105,115,107,32,69,106,101,99,116,32,84,111,103,103,108,101,0,0,0,0,0,0,0,109,121,115,116,105,99,97,108,32,110,105,110,106,97,0,0,118,105,101,119,95,121,50,0,70,114,101,101,84,121,112,101,0,0,0,0,0,0,0,0,84,97,107,105,110,103,32,115,99,114,101,101,110,115,104,111,116,46,0,0,0,0,0,0,78,101,120,116,32,79,118,101,114,108,97,121,0,0,0,0,71,65,78,66,65,82,69,32,71,79,69,77,79,78,32,50,0,0,0,0,0,0,0,0,118,105,101,119,95,120,50,0,79,110,45,116,104,101,45,102,108,121,32,114,101,99,111,114,100,105,110,103,32,111,102,32,103,97,109,101,112,108,97,121,32,119,105,116,104,32,108,105,98,97,118,99,111,100,101,99,0,0,0,0,0,0,0,0,86,111,108,117,109,101,32,68,111,119,110,0,0,0,0,0,71,65,78,66,65,82,69,32,71,79,69,77,79,78,0,0,118,105,101,119,95,121,49,0,70,70,109,112,101,103,0,0,86,111,108,117,109,101,32,85,112,0,0,0,0,0,0,0,65,90,71,74,0,0,0,0,118,105,101,119,95,120,49,0,68,121,110,97,109,105,99,32,114,117,110,45,116,105,109,101,32,108,111,97,100,105,110,103,32,111,102,32,108,105,98,114,101,116,114,111,32,108,105,98,114,97,114,121,0,0,0,0,69,110,97,98,108,101,32,72,111,116,107,101,121,0,0,0,65,71,67,0,0,0,0,0,119,111,114,108,100,95,121,111,102,115,0,0,0,0,0,0,68,121,110,97,109,105,99,0,83,108,111,119,109,111,116,105,111,110,0,0,0,0,0,0,68,65,82,73,85,83,32,70,79,82,67,69,0,0,0,0,119,111,114,108,100,95,120,101,110,118,0,0,0,0,0,0,79,112,101,110,71,76,32,114,101,110,100,101,114,45,116,111,45,116,101,120,116,117,114,101,32,40,109,117,108,116,105,45,112,97,115,115,32,115,104,97,100,101,114,115,41,0,0,0,78,101,116,112,108,97,121,32,70,108,105,112,32,80,108,97,121,101,114,115,0,0,0,0,118,105,100,101,111,95,118,115,121,110,99,0,0,0,0,0,105,110,99,108,117,100,101,32,0,0,0,0,0,0,0,0,65,81,54,74,0,0,0,0,119,111,114,108,100,95,100,100,121,0,0,0,0,0,0,0,70,66,79,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,68,111,101,115,32,110,111,116,32,104,97,118,101,32,101,110,111,117,103,104,32,115,97,109,112,108,101,115,32,102,111,114,32,109,111,110,105,116,111,114,32,114,101,102,114,101,115,104,32,114,97,116,101,32,101,115,116,105,109,97,116,105,111,110,46,32,82,101,113,117,105,114,101,115,32,116,111,32,114,117,110,32,102,111,114,32,97,116,32,108,101,97,115,116,32,37,117,32,102,114,97,109,101,115,46,10,0,0,0,68,82,65,71,79,78,81,85,69,83,84,53,0,0,0,0,119,111,114,108,100,95,100,100,120,0,0,0,0,0,0,0,105,110,112,117,116,95,112,108,97,121,101,114,56,0,0,0,83,68,76,95,105,109,97,103,101,32,105,109,97,103,101,32,108,111,97,100,105,110,103,0,82,101,116,114,111,65,114,99,104,58,32,76,111,97,100,105,110,103,32,82,79,77,32,102,105,108,101,58,32,37,115,46,10,0,0,0,0,0,0,0,68,83,80,32,67,111,110,102,105,103,0,0,0,0,0,0,65,81,51,0,0,0,0,0,119,111,114,108,100,95,100,121,0,0,0,0,0,0,0,0,105,110,112,117,116,95,112,108,97,121,101,114,55,0,0,0,83,68,76,95,105,109,97,103,101,0,0,0,0,0,0,0,74,117,115,116,105,102,105,101,114,0,0,0,0,0,0,0,103,108,68,101,98,117,103,77,101,115,115,97,103,101,67,97,108,108,98,97,99,107,0,0,84,101,120,116,117,114,101,83,105,122,101,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,71,76,93,58,32,70,97,105,108,101,100,32,116,111,32,99,114,101,97,116,101,32,69,71,76,32,105,109,97,103,101,46,10,0,83,99,114,101,101,110,115,104,111,116,0,0,0,0,0,0,83,89,83,84,69,77,32,68,73,82,32,37,115,0,0,0,102,114,97,103,109,101,110,116,0,0,0,0,0,0,0,0,79,103,114,101,32,66,97,116,116,108,101,32,85,83,65,0,111,118,101,114,108,97,121,37,117,95,100,101,115,99,37,117,0,0,0,0,0,0,0,0,83,79,85,78,68,32,78,79,86,69,76,45,84,67,79,79,76,0,0,0,0,0,0,0,119,111,114,108,100,95,100,120,0,0,0,0,0,0,0,0,43,0,0,0,0,0,0,0,105,110,112,117,116,95,112,108,97,121,101,114,54,0,0,0,68,80,52,0,0,0,0,0,108,105,98,120,109,108,50,32,88,77,76,32,112,97,114,115,105,110,103,0,0,0,0,0,67,104,101,97,116,32,84,111,103,103,108,101,0,0,0,0,65,79,55,0,0,0,0,0,119,111,114,108,100,95,121,0,105,110,112,117,116,95,112,108,97,121,101,114,53,0,0,0,108,105,98,120,109,108,50,0,83,97,118,101,32,115,116,97,116,101,47,109,111,118,105,101,32,115,108,111,116,58,32,37,117,0,0,0,0,0,0,0,67,104,101,97,116,32,73,110,100,101,120,32,77,105,110,117,115,0,0,0,0,0,0,0,116,119,105,110,98,101,101,0,119,111,114,108,100,95,120,0,105,110,112,117,116,95,112,108,97,121,101,114,52,0,0,0,67,103,32,112,105,120,101,108,32,115,104,97,100,101,114,115,0,0,0,0,0,0,0,0,67,104,101,97,116,32,73,110,100,101,120,32,80,108,117,115,0,0,0,0,0,0,0,0,65,32,98,117,116,116,111,110,32,40,114,105,103,104,116,41,0,0,0,0,0,0,0,0,65,78,73,0,0,0,0,0,115,101,103,109,101,110,116,115,0,0,0,0,0,0,0,0,105,110,112,117,116,95,112,108,97,121,101,114,51,0,0,0,67,103,0,0,0,0,0,0,80,114,101,118,105,111,117,115,32,83,104,97,100,101,114,0,75,73,75,73,75,65,73,75,65,73,0,0,0,0,0,0,114,97,115,116,101,114,0,0,105,110,112,117,116,95,112,108,97,121,101,114,50,0,0,0,69,120,116,101,114,110,97,108,32,102,105,108,116,101,114,32,97,110,100,32,112,108,117,103,105,110,32,115,117,112,112,111,114,116,0,0,0,0,0,0,78,101,120,116,32,83,104,97,100,101,114,0,0,0,0,0,115,110,101,115,57,120,95,111,112,116,48,0,0,0,0,0,78,101,120,116,69,118,101,110,116,0,0,0,0,0,0,0,87,104,105,99,104,69,118,101,110,116,0,0,0,0,0,0,72,68,77,65,82,97,110,73,110,68,77,65,0,0,0,0,80,79,67,75,89,32,82,79,67,75,89,0,0,0,0,0,73,110,87,82,65,77,68,77,65,111,114,72,68,77,65,0,100,105,115,116,97,110,99,101,0,0,0,0,0,0,0,0,105,110,112,117,116,95,112,108,97,121,101,114,49,0,0,0,73,110,68,77,65,111,114,72,68,77,65,0,0,0,0,0,73,110,72,68,77,65,0,0,69,120,116,101,114,110,97,108,0,0,0,0,0,0,0,0,73,110,68,77,65,0,0,0,70,97,115,116,82,79,77,83,112,101,101,100,0,0,0,0,77,101,109,83,112,101,101,100,120,50,0,0,0,0,0,0,82,101,115,101,116,0,0,0,77,101,109,83,112,101,101,100,0,0,0,0,0,0,0,0,73,82,81,80,101,110,100,105,110,103,0,0,0,0,0,0,86,95,67,111,117,110,116,101,114,0,0,0,0,0,0,0,80,114,101,118,67,121,99,108,101,115,0,0,0,0,0,0,65,89,76,0,0,0,0,0,67,121,99,108,101,115,0,0,108,99,118,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,70,111,117,110,100,32,105,110,118,97,108,105,100,32,104,97,116,32,105,110,32,99,111,110,102,105,103,33,10,0,0,0,0,0,0,0,79,112,101,110,66,117,115,50,0,0,0,0,0,0,0,0,79,112,101,110,66,117,115,49,0,0,0,0,0,0,0,0,79,112,101,110,65,76,0,0,72,68,77,65,69,110,100,101,100,0,0,0,0,0,0,0,72,68,77,65,0,0,0,0,77,55,98,121,116,101,0,0,83,111,117,110,100,32,98,117,102,102,101,114,32,115,105,122,101,58,32,37,100,32,40,37,100,32,115,97,109,112,108,101,115,41,10,0,0,0,0,0,70,114,97,109,101,32,65,100,118,97,110,99,101,0,0,0,66,71,110,120,79,70,83,98,121,116,101,0,0,0,0,0,118,105,100,101,111,95,100,105,115,97,98,108,101,95,99,111,109,112,111,115,105,116,105,111,110,0,0,0,0,0,0,0,78,101,101,100,49,54,120,56,77,117,108,105,116,112,108,121,0,0,0,0,0,0,0,0,83,99,114,101,101,110,72,101,105,103,104,116,0,0,0,0,66,114,105,103,104,116,110,101,115,115,0,0,0,0,0,0,65,83,54,0,0,0,0,0,70,105,120,101,100,67,111,108,111,117,114,66,108,117,101,0,76,111,103,105,99,0,0,0,70,105,120,101,100,67,111,108,111,117,114,71,114,101,101,110,0,0,0,0,0,0,0,0,70,105,120,101,100,67,111,108,111,117,114,82,101,100,0,0,80,78,71,32,101,110,99,111,100,101,47,100,101,99,111,100,101,32,97,110,100,32,46,122,105,112,32,101,120,116,114,97,99,116,105,111,110,0,0,0,70,111,114,99,101,100,66,108,97,110,107,105,110,103,0,0,82,101,116,114,111,65,114,99,104,58,32,77,111,110,105,116,111,114,32,70,80,83,32,101,115,116,105,109,97,116,105,111,110,32,105,115,32,100,105,115,97,98,108,101,100,32,102,111,114,32,116,104,114,101,97,100,101,100,32,118,105,100,101,111,46,10,0,0,0,0,0,0,67,108,105,112,87,105,110,100,111,119,50,73,110,115,105,100,101,91,53,93,0,0,0,0,67,108,105,112,87,105,110,100,111,119,49,73,110,115,105,100,101,91,53,93,0,0,0,0,80,97,117,115,101,32,84,111,103,103,108,101,0,0,0,0,67,108,105,112,87,105,110,100,111,119,50,69,110,97,98,108,101,91,53,93,0,0,0,0,67,108,105,112,87,105,110,100,111,119,49,69,110,97,98,108,101,91,53,93,0,0,0,0,67,108,105,112,87,105,110,100,111,119,79,118,101,114,108,97,112,76,111,103,105,99,91,53,93,0,0,0,0,0,0,0,67,108,105,112,67,111,117,110,116,115,91,53,93,0,0,0,83,85,80,69,82,32,66,79,77,66,69,82,77,65,78,50,0,0,0,0,0,0,0,0,67,108,105,112,87,105,110,100,111,119,50,73,110,115,105,100,101,91,52,93,0,0,0,0,98,121,116,101,0,0,0,0,67,108,105,112,87,105,110,100,111,119,49,73,110,115,105,100,101,91,52,93,0,0,0,0,67,108,105,112,87,105,110,100,111,119,50,69,110,97,98,108,101,91,52,93,0,0,0,0,122,108,105,98,0,0,0,0,67,108,105,112,87,105,110,100,111,119,49,69,110,97,98,108,101,91,52,93,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,73,110,118,97,108,105,100,32,82,79,77,32,116,121,112,101,46,10,0,67,108,105,112,87,105,110,100,111,119,79,118,101,114,108,97,112,76,111,103,105,99,91,52,93,0,0,0,0,0,0,0,67,108,105,112,67,111,117,110,116,115,91,52,93,0,0,0,77,111,118,105,101,32,82,101,99,111,114,100,32,84,111,103,103,108,101,0,0,0,0,0,67,108,105,112,87,105,110,100,111,119,50,73,110,115,105,100,101,91,51,93,0,0,0,0])
.concat([67,108,105,112,87,105,110,100,111,119,49,73,110,115,105,100,101,91,51,93,0,0,0,0,67,108,105,112,87,105,110,100,111,119,50,69,110,97,98,108,101,91,51,93,0,0,0,0,67,108,105,112,87,105,110,100,111,119,49,69,110,97,98,108,101,91,51,93,0,0,0,0,83,85,80,69,82,32,66,79,77,66,69,82,77,65,78,0,67,108,105,112,87,105,110,100,111,119,79,118,101,114,108,97,112,76,111,103,105,99,91,51,93,0,0,0,0,0,0,0,112,97,114,97,109,101,116,101,114,115,0,0,0,0,0,0,67,108,105,112,67,111,117,110,116,115,91,51,93,0,0,0,105,110,112,117,116,95,100,114,105,118,101,114,0,0,0,0,67,108,105,112,87,105,110,100,111,119,50,73,110,115,105,100,101,91,50,93,0,0,0,0,88,65,117,100,105,111,50,0,67,108,105,112,87,105,110,100,111,119,49,73,110,115,105,100,101,91,50,93,0,0,0,0,70,114,111,110,116,101,110,100,32,115,117,112,112,111,114,116,115,32,82,71,66,53,54,53,32,45,32,119,105,108,108,32,117,115,101,32,116,104,97,116,32,105,110,115,116,101,97,100,32,111,102,32,88,82,71,66,49,53,53,53,46,10,0,0,80,97,117,115,101,0,0,0,67,108,105,112,87,105,110,100,111,119,50,69,110,97,98,108,101,91,50,93,0,0,0,0,103,108,68,101,98,117,103,77,101,115,115,97,103,101,73,110,115,101,114,116,0,0,0,0,79,117,116,112,117,116,83,105,122,101,0,0,0,0,0,0,67,108,105,112,87,105,110,100,111,119,49,69,110,97,98,108,101,91,50,93,0,0,0,0,111,110,0,0,0,0,0,0,67,108,105,112,87,105,110,100,111,119,79,118,101,114,108,97,112,76,111,103,105,99,91,50,93,0,0,0,0,0,0,0,67,108,105,112,67,111,117,110,116,115,91,50,93,0,0,0,79,86,69,82,76,65,89,32,68,73,82,32,37,115,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,32,110,111,116,32,105,110,105,116,105,97,108,105,122,101,32,109,101,110,117,46,10,0,0,0,0,0,0,0,0,67,108,105,112,87,105,110,100,111,119,50,73,110,115,105,100,101,91,49,93,0,0,0,0,67,108,105,112,87,105,110,100,111,119,49,73,110,115,105,100,101,91,49,93,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,83,104,97,100,101,114,32,115,111,117,114,99,101,32,102,105,108,101,32,119,97,115,32,112,114,111,118,105,100,101,100,44,32,98,117,116,32,102,97,105,108,101,100,32,116,111,32,114,101,97,100,46,10,0,0,0,0,0,0,67,89,66,69,82,78,65,84,79,82,0,0,0,0,0,0,67,108,105,112,87,105,110,100,111,119,50,69,110,97,98,108,101,91,49,93,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,111,118,101,114,108,97,121,32,100,101,115,99,115,32,102,111,114,32,111,118,101,114,108,97,121,32,35,37,117,46,10,0,0,87,65,78,68,69,82,69,82,83,32,70,82,79,77,32,89,83,0,0,0,0,0,0,0,111,117,116,95,99,111,117,110,116,0,0,0,0,0,0,0,99,111,100,101,0,0,0,0,67,108,105,112,87,105,110,100,111,119,49,69,110,97,98,108,101,91,49,93,0,0,0,0,68,80,50,0,0,0,0,0,67,108,105,112,87,105,110,100,111,119,79,118,101,114,108,97,112,76,111,103,105,99,91,49,93,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,110,39,116,32,111,112,101,110,32,66,83,86,32,34,37,115,34,32,102,111,114,32,114,101,99,111,114,100,105,110,103,46,10,0,0,0,0,0,68,105,114,101,99,116,83,111,117,110,100,0,0,0,0,0,67,108,105,112,67,111,117,110,116,115,91,49,93,0,0,0,67,108,105,112,87,105,110,100,111,119,50,73,110,115,105,100,101,91,48,93,0,0,0,0,67,108,105,112,87,105,110,100,111,119,49,73,110,115,105,100,101,91,48,93,0,0,0,0,83,116,97,116,101,32,83,108,111,116,32,77,105,110,117,115,0,0,0,0,0,0,0,0,67,108,105,112,87,105,110,100,111,119,50,69,110,97,98,108,101,91,48,93,0,0,0,0,67,108,105,112,87,105,110,100,111,119,49,69,110,97,98,108,101,91,48,93,0,0,0,0,67,108,105,112,87,105,110,100,111,119,79,118,101,114,108,97,112,76,111,103,105,99,91,48,93,0,0,0,0,0,0,0,67,108,105,112,67,111,117,110,116,115,91,48,93,0,0,0,86,65,76,75,69,78,0,0,82,101,99,111,109,112,117,116,101,67,108,105,112,87,105,110,100,111,119,115,0,0,0,0,105,110,95,105,110,100,101,120,0,0,0,0,0,0,0,0,87,105,110,100,111,119,50,82,105,103,104,116,0,0,0,0,87,105,110,100,111,119,50,76,101,102,116,0,0,0,0,0,80,117,108,115,101,65,117,100,105,111,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,115,97,118,101,32,115,116,97,116,101,32,116,111,32,34,37,115,34,46,0,0,0,87,105,110,100,111,119,49,82,105,103,104,116,0,0,0,0,87,105,110,100,111,119,49,76,101,102,116,0,0,0,0,0,66,71,77,111,115,97,105,99,0,0,0,0,0,0,0,0,83,116,97,116,101,32,83,108,111,116,32,80,108,117,115,0,77,111,115,97,105,99,83,116,97,114,116,0,0,0,0,0,77,111,115,97,105,99,0,0,77,55,86,79,70,83,0,0,77,55,72,79,70,83,0,0,83,85,80,69,82,32,65,76,69,83,84,69,0,0,0,0,77,97,116,114,105,120,68,0,105,110,95,99,111,117,110,116,0,0,0,0,0,0,0,0,37,115,95,37,115,95,97,120,105,115,0,0,0,0,0,0,77,97,116,114,105,120,67,0,77,97,116,114,105,120,66,0,82,111,97,114,65,117,100,105,111,0,0,0,0,0,0,0,77,97,116,114,105,120,65,0,77,111,100,101,55,82,101,112,101,97,116,0,0,0,0,0,77,111,100,101,55,86,70,108,105,112,0,0,0,0,0,0,81,117,105,116,32,75,101,121,0,0,0,0,0,0,0,0,77,111,100,101,55,72,70,108,105,112,0,0,0,0,0,0,72,86,66,101,97,109,67,111,117,110,116,101,114,76,97,116,99,104,101,100,0,0,0,0,71,117,110,86,76,97,116,99,104,0,0,0,0,0,0,0,71,117,110,72,76,97,116,99,104,0,0,0,0,0,0,0,65,82,88,0,0,0,0,0,86,66,101,97,109,80,111,115,76,97,116,99,104,101,100,0,99,111,109,109,97,110,100,0,37,115,95,37,115,95,98,116,110,0,0,0,0,0,0,0,72,66,101,97,109,80,111,115,76,97,116,99,104,101,100,0,86,66,101,97,109,70,108,105,112,0,0,0,0,0,0,0,82,83,111,117,110,100,0,0,72,66,101,97,109,70,108,105,112,0,0,0,0,0,0,0,73,82,81,86,66,101,97,109,80,111,115,0,0,0,0,0,73,82,81,72,66,101,97,109,80,111,115,0,0,0,0,0,70,117,108,108,115,99,114,101,101,110,32,84,111,103,103,108,101,0,0,0,0,0,0,0,86,84,105,109,101,114,80,111,115,105,116,105,111,110,0,0,72,84,105,109,101,114,80,111,115,105,116,105,111,110,0,0,86,84,105,109,101,114,69,110,97,98,108,101,100,0,0,0,72,84,105,109,101,114,69,110,97,98,108,101,100,0,0,0,103,108,69,71,76,73,109,97,103,101,84,97,114,103,101,116,84,101,120,116,117,114,101,50,68,79,69,83,0,0,0,0,83,80,65,67,69,32,77,69,71,65,70,79,82,67,69,0,76,97,115,116,83,112,114,105,116,101,0,0,0,0,0,0,104,97,108,102,95,99,111,109,109,97,110,100,0,0,0,0,105,110,112,117,116,0,0,0,70,105,114,115,116,83,112,114,105,116,101,0,0,0,0,0,89,32,40,108,101,102,116,41,0,0,0,0,0,0,0,0,79,65,77,68,97,116,97,0,74,97,99,107,0,0,0,0,79,65,77,87,114,105,116,101,82,101,103,105,115,116,101,114,0,0,0,0,0,0,0,0,79,65,77,84,105,108,101,65,100,100,114,101,115,115,0,0,79,65,77,82,101,97,100,70,108,105,112,0,0,0,0,0,79,65,77,70,108,105,112,0,79,65,77,80,114,105,111,114,105,116,121,82,111,116,97,116,105,111,110,0,0,0,0,0,83,97,118,101,100,79,65,77,65,100,100,114,0,0,0,0,79,65,77,65,100,100,114,0,66,84,32,73,78,32,66,65,84,84,76,69,77,65,78,73,65,67,83,0,0,0,0,0,79,66,74,83,105,122,101,83,101,108,101,99,116,0,0,0,119,97,105,116,105,110,103,52,99,111,109,109,97,110,100,0,37,115,95,37,115,0,0,0,79,66,74,78,97,109,101,83,101,108,101,99,116,0,0,0,79,66,74,78,97,109,101,66,97,115,101,0,0,0,0,0,79,83,83,0,0,0,0,0,79,66,74,65,100,100,105,116,105,111,110,0,0,0,0,0,79,66,74,84,104,114,111,117,103,104,83,117,98,0,0,0,79,66,74,84,104,114,111,117,103,104,77,97,105,110,0,0,79,66,74,91,49,50,55,93,46,83,105,122,101,0,0,0,79,66,74,91,49,50,55,93,46,80,97,108,101,116,116,101,0,0,0,0,0,0,0,0,79,66,74,91,49,50,55,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,79,66,74,91,49,50,55,93,46,78,97,109,101,0,0,0,65,77,52,74,0,0,0,0,79,66,74,91,49,50,55,93,46,86,70,108,105,112,0,0,99,111,110,116,114,111,108,95,101,110,97,98,108,101,0,0,110,117,108,0,0,0,0,0,79,66,74,91,49,50,55,93,46,72,70,108,105,112,0,0,79,66,74,91,49,50,55,93,46,86,80,111,115,0,0,0,97,117,100,105,111,32,100,114,105,118,101,114,0,0,0,0,79,66,74,91,49,50,55,93,46,72,80,111,115,0,0,0,79,66,74,91,49,50,54,93,46,83,105,122,101,0,0,0,79,66,74,91,49,50,54,93,46,80,97,108,101,116,116,101,0,0,0,0,0,0,0,0,70,97,115,116,32,70,111,114,119,97,114,100,32,72,111,108,100,0,0,0,0,0,0,0,79,66,74,91,49,50,54,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,118,105,100,101,111,95,109,111,110,105,116,111,114,95,105,110,100,101,120,0,0,0,0,0,79,66,74,91,49,50,54,93,46,78,97,109,101,0,0,0,79,66,74,91,49,50,54,93,46,86,70,108,105,112,0,0,79,66,74,91,49,50,54,93,46,72,70,108,105,112,0,0,65,51,77,0,0,0,0,0,79,66,74,91,49,50,54,93,46,86,80,111,115,0,0,0,101,120,101,99,117,116,101,0,112,97,117,115,101,0,0,0,79,66,74,91,49,50,54,93,46,72,80,111,115,0,0,0,79,66,74,91,49,50,53,93,46,83,105,122,101,0,0,0,65,76,83,65,0,0,0,0,79,66,74,91,49,50,53,93,46,80,97,108,101,116,116,101,0,0,0,0,0,0,0,0,79,66,74,91,49,50,53,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,97,110,110,111,116,32,102,105,110,100,32,105,110,112,117,116,32,100,114,105,118,101,114,46,32,69,120,105,116,105,110,103,32,46,46,46,10,0,0,0,0,0,79,66,74,91,49,50,53,93,46,78,97,109,101,0,0,0,70,97,115,116,32,70,111,114,119,97,114,100,0,0,0,0,79,66,74,91,49,50,53,93,46,86,70,108,105,112,0,0,79,66,74,91,49,50,53,93,46,72,70,108,105,112,0,0,79,66,74,91,49,50,53,93,46,86,80,111,115,0,0,0,79,66,74,91,49,50,53,93,46,72,80,111,115,0,0,0,65,68,90,0,0,0,0,0,79,66,74,91,49,50,52,93,46,83,105,122,101,0,0,0,111,112,95,114,101,103,0,0,98,97,99,107,113,117,111,116,101,0,0,0,0,0,0,0,79,66,74,91,49,50,52,93,46,80,97,108,101,116,116,101,0,0,0,0,0,0,0,0,79,66,74,91,49,50,52,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,88,86,105,100,101,111,32,111,117,116,112,117,116,0,0,0,79,66,74,91,49,50,52,93,46,78,97,109,101,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,101,120,116,114,97,99,116,32,82,79,77,32,102,114,111,109,32,122,105,112,112,101,100,32,102,105,108,101,58,32,37,115,46,10,0,0,0,0,0,0,0,79,66,74,91,49,50,52,93,46,86,70,108,105,112,0,0,79,66,74,91,49,50,52,93,46,72,70,108,105,112,0,0,82,105,103,104,116,32,65,110,97,108,111,103,32,89,32,45,0,0,0,0,0,0,0,0,79,66,74,91,49,50,52,93,46,86,80,111,115,0,0,0,79,66,74,91,49,50,52,93,46,72,80,111,115,0,0,0,79,66,74,91,49,50,51,93,46,83,105,122,101,0,0,0,79,66,74,91,49,50,51,93,46,80,97,108,101,116,116,101,0,0,0,0,0,0,0,0,72,65,82,86,69,83,84,32,77,79,79,78,0,0,0,0,79,66,74,91,49,50,51,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,111,117,116,112,117,116,95,112,97,114,97,109,115,0,0,0,116,105,108,100,101,0,0,0,79,66,74,91,49,50,51,93,46,78,97,109,101,0,0,0,79,66,74,91,49,50,51,93,46,86,70,108,105,112,0,0,88,86,105,100,101,111,0,0,79,66,74,91,49,50,51,93,46,72,70,108,105,112,0,0,91,108,105,98,114,101,116,114,111,93,58,32,73,110,118,97,108,105,100,32,100,101,118,105,99,101,33,10,0,0,0,0,84,111,103,103,108,101,84,117,114,98,111,0,0,0,0,0,79,66,74,91,49,50,51,93,46,86,80,111,115,0,0,0,103,108,68,101,98,117,103,77,101,115,115,97,103,101,67,111,110,116,114,111,108,0,0,0,73,110,112,117,116,83,105,122,101,0,0,0,0,0,0,0,79,66,74,91,49,50,51,93,46,72,80,111,115,0,0,0,111,102,102,0,0,0,0,0,82,105,103,104,116,32,65,110,97,108,111,103,32,89,32,43,0,0,0,0,0,0,0,0,79,66,74,91,49,50,50,93,46,83,105,122,101,0,0,0,79,66,74,91,49,50,50,93,46,80,97,108,101,116,116,101,0,0,0,0,0,0,0,0,103,108,115,108,0,0,0,0,83,65,86,69,70,73,76,69,32,68,73,82,32,37,115,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,114,97,114,99,104,95,109,97,105,110,95,105,110,105,116,95,119,114,97,112,40,41,32,102,97,105,108,101,100,46,10,0,0,0,0,79,66,74,91,49,50,50,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,79,66,74,91,49,50,50,93,46,78,97,109,101,0,0,0,115,114,99,0,0,0,0,0,52,81,0,0,0,0,0,0,79,66,74,91,49,50,50,93,46,86,70,108,105,112,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,70,97,105,108,101,100,32,116,111,32,97,108,108,111,99,97,116,101,32,100,101,115,99,115,46,10,0,0,0,0,0,0,105,110,112,117,116,95,112,97,114,97,109,115,0,0,0,0,100,101,115,99,114,105,112,116,105,111,110,0,0,0,0,0,115,99,114,111,108,108,95,108,111,99,107,0,0,0,0,0,79,66,74,91,49,50,50,93,46,72,70,108,105,112,0,0,68,80,49,0,0,0,0,0,79,66,74,91,49,50,50,93,46,86,80,111,115,0,0,0,79,112,101,110,86,71,32,111,117,116,112,117,116,32,115,117,112,112,111,114,116,0,0,0,79,66,74,91,49,50,50,93,46,72,80,111,115,0,0,0,79,66,74,91,49,50,49,93,46,83,105,122,101,0,0,0,79,66,74,91,49,50,49,93,46,80,97,108,101,116,116,101,0,0,0,0,0,0,0,0,79,66,74,91,49,50,49,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,82,105,103,104,116,32,65,110,97,108,111,103,32,88,32,45,0,0,0,0,0,0,0,0,101,109,115,99,114,105,112,116,101,110,0,0,0,0,0,0,79,66,74,91,49,50,49,93,46,78,97,109,101,0,0,0,79,66,74,91,49,50,49,93,46,86,70,108,105,112,0,0,79,66,74,91,49,50,49,93,46,72,70,108,105,112,0,0,83,85,80,69,82,77,65,82,73,79,32,67,79,76,76,69,67,84,73,79,78,0,0,0,79,66,74,91,49,50,49,93,46,86,80,111,115,0,0,0,115,104,105,102,116,0,0,0,112,114,105,110,116,95,115,99,114,101,101,110,0,0,0,0,79,66,74,91,49,50,49,93,46,72,80,111,115,0,0,0,79,66,74,91,49,50,48,93,46,83,105,122,101,0,0,0,79,112,101,110,86,71,0,0,83,97,118,101,100,32,115,116,97,116,101,32,116,111,32,115,108,111,116,32,35,37,117,46,0,0,0,0,0,0,0,0,79,66,74,91,49,50,48,93,46,80,97,108,101,116,116,101,0,0,0,0,0,0,0,0,79,66,74,91,49,50,48,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,71,76,32,114,97,115,116,101,114,0,0,0,0,0,0,0,79,66,74,91,49,50,48,93,46,78,97,109,101,0,0,0,82,105,103,104,116,32,65,110,97,108,111,103,32,88,32,43,0,0,0,0,0,0,0,0,79,66,74,91,49,50,48,93,46,86,70,108,105,112,0,0,79,66,74,91,49,50,48,93,46,72,70,108,105,112,0,0,79,66,74,91,49,50,48,93,46,86,80,111,115,0,0,0,79,66,74,91,49,50,48,93,46,72,80,111,115,0,0,0,83,85,80,69,82,32,77,65,82,73,79,32,65,76,76,95,83,84,65,82,83,0,0,0,79,66,74,91,49,49,57,93,46,83,105,122,101,0,0,0,98,97,115,101,80,116,114,0,100,105,118,105,100,101,0,0,79,66,74,91,49,49,57,93,46,80,97,108,101,116,116,101,0,0,0,0,0,0,0,0,79,66,74,91,49,49,57,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,69,71,76,32,99,111,110,116,101,120,116,32,115,117,112,112,111,114,116,0,0,0,0,0,79,66,74,91,49,49,57,93,46,78,97,109,101,0,0,0,79,66,74,91,49,49,57,93,46,86,70,108,105,112,0,0,79,66,74,91,49,49,57,93,46,72,70,108,105,112,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,71,69,84,95,79,86,69,82,83,67,65,78,58,32,37,117,10,0,0,0,0,76,101,102,116,32,65,110,97,108,111,103,32,89,32,45,0,79,66,74,91,49,49,57,93,46,86,80,111,115,0,0,0,82,105,103,104,116,32,68,45,112,97,100,0,0,0,0,0,79,66,74,91,49,49,57,93,46,72,80,111,115,0,0,0,79,66,74,91,49,49,56,93,46,83,105,122,101,0,0,0,79,66,74,91,49,49,56,93,46,80,97,108,101,116,116,101,0,0,0,0,0,0,0,0,53,77,0,0,0,0,0,0,79,66,74,91,49,49,56,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,97,100,100,114,101,115,115,0,109,117,108,116,105,112,108,121,0,0,0,0,0,0,0,0,79,66,74,91,49,49,56,93,46,78,97,109,101,0,0,0,79,66,74,91,49,49,56,93,46,86,70,108,105,112,0,0,69,71,76,0,0,0,0,0,79,66,74,91,49,49,56,93,46,72,70,108,105,112,0,0,79,66,74,91,49,49,56,93,46,86,80,111,115,0,0,0,79,66,74,91,49,49,56,93,46,72,80,111,115,0,0,0,76,101,102,116,32,65,110,97,108,111,103,32,89,32,43,0,79,66,74,91,49,49,55,93,46,83,105,122,101,0,0,0,79,66,74,91,49,49,55,93,46,80,97,108,101,116,116,101,0,0,0,0,0,0,0,0,79,66,74,91,49,49,55,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,79,66,74,91,49,49,55,93,46,78,97,109,101,0,0,0,65,66,84,0,0,0,0,0,79,66,74,91,49,49,55,93,46,86,70,108,105,112,0,0,99,111,110,116,101,120,116,91,51,49,93,46,105,110,118,101,114,116,0,0,0,0,0,0,98,97,99,107,115,112,97,99,101,0,0,0,0,0,0,0,79,66,74,91,49,49,55,93,46,72,70,108,105,112,0,0,66,32,40,98,111,116,116,111,109,41,0,0,0,0,0,0,79,66,74,91,49,49,55,93,46,86,80,111,115,0,0,0,75,77,83,47,69,71,76,32,99,111,110,116,101,120,116,32,115,117,112,112,111,114,116,0,79,66,74,91,49,49,55,93,46,72,80,111,115,0,0,0,79,66,74,91,49,49,54,93,46,83,105,122,101,0,0,0,79,66,74,91,49,49,54,93,46,80,97,108,101,116,116,101,0,0,0,0,0,0,0,0,79,66,74,91,49,49,54,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,76,101,102,116,32,65,110,97,108,111,103,32,88,32,45,0,79,66,74,91,49,49,54,93,46,78,97,109,101,0,0,0,79,66,74,91,49,49,54,93,46,86,70,108,105,112,0,0,79,66,74,91,49,49,54,93,46,72,70,108,105,112,0,0,71,79,75,85,74,89,79,85,32,80,65,82,79,68,73,85,83,0,0,0,0,0,0,0,79,66,74,91,49,49,54,93,46,86,80,111,115,0,0,0,99,111,110,116,101,120,116,91,51,49,93,46,105,110,100,101,120,0,0,0,0,0,0,0,110,117,109,108,111,99,107,0,79,66,74,91,49,49,54,93,46,72,80,111,115,0,0,0,79,66,74,91,49,49,53,93,46,83,105,122,101,0,0,0,75,77,83,0,0,0,0,0,79,66,74,91,49,49,53,93,46,80,97,108,101,116,116,101,0,0,0,0,0,0,0,0,79,66,74,91,49,49,53,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,79,66,74,91,49,49,53,93,46,78,97,109,101,0,0,0,79,66,74,91,49,49,53,93,46,86,70,108,105,112,0,0,76,101,102,116,32,65,110,97,108,111,103,32,88,32,43,0,79,66,74,91,49,49,53,93,46,72,70,108,105,112,0,0,79,66,74,91,49,49,53,93,46,86,80,111,115,0,0,0,79,66,74,91,49,49,53,93,46,72,80,111,115,0,0,0,83,79,85,76,66,76,65,90,69,82,32,45,32,49,32,69,78,71,0,0,0,0,0,0,79,66,74,91,49,49,52,93,46,83,105,122,101,0,0,0,99,111,110,116,101,120,116,91,51,48,93,46,105,110,118,101,114,116,0,0,0,0,0,0,99,97,112,115,108,111,99,107,0,0,0,0,0,0,0,0,79,66,74,91,49,49,52,93,46,80,97,108,101,116,116,101,0,0,0,0,0,0,0,0,79,66,74,91,49,49,52,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,79,112,101,110,71,76,32,100,114,105,118,101,114,0,0,0,79,66,74,91,49,49,52,93,46,78,97,109,101,0,0,0,79,66,74,91,49,49,52,93,46,86,70,108,105,112,0,0,79,66,74,91,49,49,52,93,46,72,70,108,105,112,0,0,79,66,74,91,49,49,52,93,46,86,80,111,115,0,0,0,84,117,114,98,111,32,69,110,97,98,108,101,0,0,0,0,118,105,100,101,111,95,119,105,110,100,111,119,101,100,95,102,117,108,108,115,99,114,101,101,110,0,0,0,0,0,0,0,79,66,74,91,49,49,52,93,46,72,80,111,115,0,0,0,79,66,74,91,49,49,51,93,46,83,105,122,101,0,0,0,79,66,74,91,49,49,51,93,46,80,97,108,101,116,116,101,0,0,0,0,0,0,0,0,40,105,110,99,108,117,100,101,100,41,0,0,0,0,0,0,84,72,69,32,77,65,71,73,67,65,76,32,81,85,69,83,84,0,0,0,0,0,0,0,79,66,74,91,49,49,51,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,99,111,110,116,101,120,116,91,51,48,93,46,105,110,100,101,120,0,0,0,0,0,0,0,112,101,114,105,111,100,0,0,79,66,74,91,49,49,51,93,46,78,97,109,101,0,0,0,79,66,74,91,49,49,51,93,46,86,70,108,105,112,0,0,79,112,101,110,71,76,0,0,107,101,121,112,97,100,57,0,79,66,74,91,49,49,51,93,46,72,70,108,105,112,0,0,79,66,74,91,49,49,51,93,46,86,80,111,115,0,0,0,82,101,116,114,111,65,114,99,104,58,32,67,114,101,97,116,105,110,103,32,70,66,79,32,37,100,32,64,32,37,117,120,37,117,10,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,97,110,110,111,116,32,105,110,105,116,32,105,110,112,117,116,32,100,114,105,118,101,114,46,32,69,120,105,116,105,110,103,32,46,46,46,10,0,0,0,0,0,79,66,74,91,49,49,51,93,46,72,80,111,115,0,0,0,79,66,74,91,49,49,50,93,46,83,105,122,101,0,0,0,82,101,116,114,111,80,97,100,32,82,51,32,66,117,116,116,111,110,0,0,0,0,0,0,79,66,74,91,49,49,50,93,46,80,97,108,101,116,116,101,0,0,0,0,0,0,0,0,79,66,74,91,49,49,50,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,79,66,74,91,49,49,50,93,46,78,97,109,101,0,0,0,74,85,82,65,83,83,73,67,32,80,65,82,75,0,0,0,79,66,74,91,49,49,50,93,46,86,70,108,105,112,0,0,99,111,110,116,101,120,116,91,50,57,93,46,105,110,118,101,114,116,0,0,0,0,0,0,79,66,74,91,49,49,50,93,46,72,70,108,105,112,0,0,79,66,74,91,49,49,50,93,46,86,80,111,115,0,0,0,84,104,114,101,97,100,105,110,103,32,115,117,112,112,111,114,116,0,0,0,0,0,0,0,107,101,121,112,97,100,56,0,79,66,74,91,49,49,50,93,46,72,80,111,115,0,0,0,122,105,112,0,0,0,0,0,79,66,74,91,49,49,49,93,46,83,105,122,101,0,0,0,79,66,74,91,49,49,49,93,46,80,97,108,101,116,116,101,0,0,0,0,0,0,0,0,79,66,74,91,49,49,49,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,82,101,116,114,111,80,97,100,32,76,51,32,66,117,116,116,111,110,0,0,0,0,0,0,79,66,74,91,49,49,49,93,46,78,97,109,101,0,0,0,79,66,74,91,49,49,49,93,46,86,70,108,105,112,0,0,114,0,0,0,0,0,0,0,79,66,74,91,49,49,49,93,46,72,70,108,105,112,0,0,67,117,114,115,111,114,0,0,67,72,82,79,78,79,32,84,82,73,71,71,69,82,0,0,79,66,74,91,49,49,49,93,46,86,80,111,115,0,0,0,99,111,110,116,101,120,116,91,50,57,93,46,105,110,100,101,120,0,0,0,0,0,0,0,79,66,74,91,49,49,49,93,46,72,80,111,115,0,0,0,79,66,74,91,49,49,48,93,46,83,105,122,101,0,0,0,84,104,114,101,97,100,115,0,107,101,121,112,97,100,55,0,79,66,74,91,49,49,48,93,46,80,97,108,101,116,116,101,0,0,0,0,0,0,0,0,74,117,115,116,105,102,105,101,114,49,32,83,116,97,114,116,0,0,0,0,0,0,0,0,79,66,74,91,49,49,48,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,103,108,73,115,86,101,114,116,101,120,65,114,114,97,121,79,69,83,0,0,0,0,0,0,76,85,84,84,101,120,67,111,111,114,100,0,0,0,0,0,79,66,74,91,49,49,48,93,46,78,97,109,101,0,0,0,82,101,116,114,111,65,114,99,104,58,32,71,76,32,86,83,121,110,99,32,61,62,32,37,115,10,0,0,0,0,0,0,79,66,74,91,49,49,48,93,46,86,70,108,105,112,0,0,82,101,116,114,111,80,97,100,32,82,50,32,66,117,116,116,111,110,0,0,0,0,0,0,79,66,74,91,49,49,48,93,46,72,70,108,105,112,0,0,83,65,86,69,83,84,65,84,69,32,68,73,82,32,37,115,0,0,0,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,37,115,46,10,0,0,0,0,0,79,66,74,91,49,49,48,93,46,86,80,111,115,0,0,0,79,66,74,91,49,49,48,93,46,72,80,111,115,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,97,110,110,111,116,32,104,97,118,101,32,109,111,114,101,32,116,104,97,110,32,111,110,101,32,118,101,114,116,101,120,32,115,104,97,100,101,114,32,105,110,32,97,32,112,114,111,103,114,97,109,46,10,0,0,0,0,0,85,78,73,82,65,76,76,89,0,0,0,0,0,0,0,0,79,66,74,91,49,48,57,93,46,83,105,122,101,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,70,97,105,108,101,100,32,116,111,32,114,101,97,100,32,110,117,109,98,101,114,32,111,102,32,100,101,115,99,115,32,102,114,111,109,32,99,111,110,102,105,103,32,107,101,121,58,32,37,115,46,10,0,0,0,0,99,111,110,116,101,120,116,91,50,56,93,46,105,110,118,101,114,116,0,0,0,0,0,0,99,104,101,97,116,0,0,0,79,66,74,91,49,48,57,93,46,80,97,108,101,116,116,101,0,0,0,0,0,0,0,0,83,65,82,0,0,0,0,0,79,66,74,91,49,48,57,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,83,68,76,32,100,114,105,118,101,114,115,0,0,0,0,0,107,101,121,112,97,100,54,0,79,66,74,91,49,48,57,93,46,78,97,109,101,0,0,0,79,66,74,91,49,48,57,93,46,86,70,108,105,112,0,0,79,66,74,91,49,48,57,93,46,72,70,108,105,112,0,0,79,66,74,91,49,48,57,93,46,86,80,111,115,0,0,0,82,101,116,114,111,80,97,100,32,76,50,32,66,117,116,116,111,110,0,0,0,0,0,0,79,66,74,91,49,48,57,93,46,72,80,111,115,0,0,0,79,66,74,91,49,48,56,93,46,83,105,122,101,0,0,0,79,66,74,91,49,48,56,93,46,80,97,108,101,116,116,101,0,0,0,0,0,0,0,0,85,78,73,82,65,67,69,82,83,0,0,0,0,0,0,0,79,66,74,91,49,48,56,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,99,111,110,116,101,120,116,91,50,56,93,46,105,110,100,101,120,0,0,0,0,0,0,0,79,66,74,91,49,48,56,93,46,78,97,109,101,0,0,0,79,66,74,91,49,48,56,93,46,86,70,108,105,112,0,0,83,68,76,0,0,0,0,0,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,115,116,97,116,101,32,102,114,111,109,32,34,37,115,34,46,0,107,101,121,112,97,100,53,0,79,66,74,91,49,48,56,93,46,72,70,108,105,112,0,0,79,66,74,91,49,48,56,93,46,86,80,111,115,0,0,0,79,66,74,91,49,48,56,93,46,72,80,111,115,0,0,0,79,66,74,91,49,48,55,93,46,83,105,122,101,0,0,0,82,101,116,114,111,80,97,100,32,82,32,66,117,116,116,111,110,0,0,0,0,0,0,0,79,66,74,91,49,48,55,93,46,80,97,108,101,116,116,101,0,0,0,0,0,0,0,0,79,66,74,91,49,48,55,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,79,66,74,91,49,48,55,93,46,78,97,109,101,0,0,0,90,79,77,66,73,69,83,32,65,84,69,32,77,89,32,78,69,73,71,72,66,0,0,0,79,66,74,91,49,48,55,93,46,86,70,108,105,112,0,0,99,111,110,116,101,120,116,91,50,55,93,46,105,110,118,101,114,116,0,0,0,0,0,0,79,66,74,91,49,48,55,93,46,72,70,108,105,112,0,0,79,66,74,91,49,48,55,93,46,86,80,111,115,0,0,0,9,37,115,58,10,9,9,37,115,58,32,37,115,10,0,0,107,101,121,112,97,100,52,0,79,66,74,91,49,48,55,93,46,72,80,111,115,0,0,0,79,66,74,91,49,48,54,93,46,83,105,122,101,0,0,0,79,66,74,91,49,48,54,93,46,80,97,108,101,116,116,101,0,0,0,0,0,0,0,0,79,66,74,91,49,48,54,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,82,101,116,114,111,80,97,100,32,76,32,66,117,116,116,111,110,0,0,0,0,0,0,0,79,66,74,91,49,48,54,93,46,78,97,109,101,0,0,0,79,66,74,91,49,48,54,93,46,86,70,108,105,112,0,0,79,66,74,91,49,48,54,93,46,72,70,108,105,112,0,0,84,72,69,32,74,85,78,71,76,69,32,66,79,79,75,0,79,66,74,91,49,48,54,93,46,86,80,111,115,0,0,0,99,111,110,116,101,120,116,91,50,55,93,46,105,110,100,101,120,0,0,0,0,0,0,0,79,66,74,91,49,48,54,93,46,72,80,111,115,0,0,0,79,66,74,91,49,48,53,93,46,83,105,122,101,0,0,0,70,101,97,116,117,114,101,115,58,0,0,0,0,0,0,0,107,101,121,112,97,100,51,0,79,66,74,91,49,48,53,93,46,80,97,108,101,116,116,101,0,0,0,0,0,0,0,0,79,66,74,91,49,48,53,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,79,66,74,91,49,48,53,93,46,78,97,109,101,0,0,0,79,66,74,91,49,48,53,93,46,86,70,108,105,112,0,0,82,101,116,114,111,80,97,100,32,88,32,66,117,116,116,111,110,0,0,0,0,0,0,0,79,66,74,91,49,48,53,93,46,72,70,108,105,112,0,0,79,66,74,91,49,48,53,93,46,86,80,111,115,0,0,0,79,66,74,91,49,48,53,93,46,72,80,111,115,0,0,0,90,79,77,66,73,69,83,0,79,66,74,91,49,48,52,93,46,83,105,122,101,0,0,0,99,111,110,116,101,120,116,91,50,54,93,46,105,110,118,101,114,116,0,0,0,0,0,0,79,66,74,91,49,48,52,93,46,80,97,108,101,116,116,101,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,80,73,88,69,76,95,70,79,82,77,65,84,58,32,88,82,71,66,56,56,56,56,46,10,0,79,66,74,91,49,48,52,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,107,101,121,112,97,100,50,0,79,66,74,91,49,48,52,93,46,78,97,109,101,0,0,0,79,66,74,91,49,48,52,93,46,86,70,108,105,112,0,0,79,66,74,91,49,48,52,93,46,72,70,108,105,112,0,0,79,66,74,91,49,48,52,93,46,86,80,111,115,0,0,0,82,101,116,114,111,80,97,100,32,65,32,66,117,116,116,111,110,0,0,0,0,0,0,0,79,66,74,91,49,48,52,93,46,72,80,111,115,0,0,0,79,66,74,91,49,48,51,93,46,83,105,122,101,0,0,0,79,66,74,91,49,48,51,93,46,80,97,108,101,116,116,101,0,0,0,0,0,0,0,0,74,65,75,73,32,67,82,85,83,72,0,0,0,0,0,0,79,66,74,91,49,48,51,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,99,111,110,116,101,120,116,91,50,54,93,46,105,110,100,101,120,0,0,0,0,0,0,0,79,66,74,91,49,48,51,93,46,78,97,109,101,0,0,0,79,66,74,91,49,48,51,93,46,86,70,108,105,112,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,45,45,109,101,110,117,32,119,97,115,32,117,115,101,100,44,32,98,117,116,32,82,79,77,32,102,105,108,101,32,119,97,115,32,112,97,115,115,101,100,32,97,115,32,119,101,108,108,46,10,0,107,101,121,112,97,100,49,0,79,66,74,91,49,48,51,93,46,72,70,108,105,112,0,0,79,66,74,91,49,48,51,93,46,86,80,111,115,0,0,0,79,66,74,91,49,48,51,93,46,72,80,111,115,0,0,0,79,66,74,91,49,48,50,93,46,83,105,122,101,0,0,0,82,101,116,114,111,80,97,100,32,68,45,80,97,100,32,82,105,103,104,116,0,0,0,0,79,66,74,91,49,48,50,93,46,80,97,108,101,116,116,101,0,0,0,0,0,0,0,0,79,66,74,91,49,48,50,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,79,66,74,91,49,48,50,93,46,78,97,109,101,0,0,0,65,88,69,76,65,89,0,0,79,66,74,91,49,48,50,93,46,86,70,108,105,112,0,0,99,111,110,116,101,120,116,91,50,53,93,46,105,110,118,101,114,116,0,0,0,0,0,0,79,66,74,91,49,48,50,93,46,72,70,108,105,112,0,0,79,66,74,91,49,48,50,93,46,86,80,111,115,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,69,114,114,111,114,32,112,97,114,115,105,110,103,32,97,114,103,117,109,101,110,116,115,46,10,0,0,107,101,121,112,97,100,48,0,79,66,74,91,49,48,50,93,46,72,80,111,115,0,0,0,79,66,74,91,49,48,49,93,46,83,105,122,101,0,0,0,79,66,74,91,49,48,49,93,46,80,97,108,101,116,116,101,0,0,0,0,0,0,0,0,79,66,74,91,49,48,49,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,82,101,116,114,111,80,97,100,32,68,45,80,97,100,32,76,101,102,116,0,0,0,0,0,118,105,100,101,111,95,102,117,108,108,115,99,114,101,101,110,0,0,0,0,0,0,0,0,79,66,74,91,49,48,49,93,46,78,97,109,101,0,0,0,79,66,74,91,49,48,49,93,46,86,70,108,105,112,0,0,79,66,74,91,49,48,49,93,46,72,70,108,105,112,0,0,37,115,32,61,32,34,37,115,34,32,37,115,10,0,0,0,51,90,0,0,0,0,0,0,79,66,74,91,49,48,49,93,46,86,80,111,115,0,0,0,99,111,110,116,101,120,116,91,50,53,93,46,105,110,100,101,120,0,0,0,0,0,0,0,79,66,74,91,49,48,49,93,46,72,80,111,115,0,0,0,79,66,74,91,49,48,48,93,46,83,105,122,101,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,73,110,118,97,108,105,100,32,97,114,103,117,109,101,110,116,32,105,110,32,45,45,115,114,97,109,45,109,111,100,101,46,10,0,0,112,97,103,101,100,111,119,110,0,0,0,0,0,0,0,0,79,66,74,91,49,48,48,93,46,80,97,108,101,116,116,101,0,0,0,0,0,0,0,0,79,66,74,91,49,48,48,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,71,114,97,112,104,105,99,115,32,100,114,105,118,101,114,32,100,105,100,32,110,111,116,32,105,110,105,116,105,97,108,105,122,101,32,97,110,32,105,110,112,117,116,32,100,114,105,118,101,114,46,32,65,116,116,101,109,112,116,105,110,103,32,116,111,32,112,105,99,107,32,97,32,115,117,105,116,97,98,108,101,32,100,114,105,118,101,114,46,10,0,0,0,79,66,74,91,49,48,48,93,46,78,97,109,101,0,0,0,79,66,74,91,49,48,48,93,46,86,70,108,105,112,0,0,82,101,116,114,111,80,97,100,32,68,45,80,97,100,32,68,111,119,110,0,0,0,0,0,79,66,74,91,49,48,48,93,46,72,70,108,105,112,0,0,79,66,74,91,49,48,48,93,46,86,80,111,115,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,97,110,110,111,116,32,114,101,115,111,108,118,101,32,97,112,112,108,105,99,97,116,105,111,110,32,112,97,116,104,33,32,84,104,105,115,32,115,104,111,117,108,100,32,110,111,116,32,104,97,112,112,101,110,46,10,0,0,79,66,74,91,49,48,48,93,46,72,80,111,115,0,0,0,84,73,78,89,84,79,79,78,32,97,100,118,101,110,116,117,114,101,115,0,0,0,0,0,79,66,74,91,57,57,93,46,83,105,122,101,0,0,0,0,99,111,110,116,101,120,116,91,50,52,93,46,105,110,118,101,114,116,0,0,0,0,0,0,79,66,74,91,57,57,93,46,80,97,108,101,116,116,101,0,79,66,74,91,57,57,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,108,111,97,100,45,115,97,118,101,0,0,0,0,0,0,0,112,97,103,101,117,112,0,0,79,66,74,91,57,57,93,46,78,97,109,101,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,97,118,101,100,32,115,117,99,99,101,115,115,102,117,108,108,121,32,116,111,32,34,37,115,34,46,10,0,79,66,74,91,57,57,93,46,86,70,108,105,112,0,0,0,79,66,74,91,57,57,93,46,72,70,108,105,112,0,0,0,79,66,74,91,57,57,93,46,86,80,111,115,0,0,0,0,82,101,116,114,111,80,97,100,32,68,45,80,97,100,32,85,112,0,0,0,0,0,0,0,79,66,74,91,57,57,93,46,72,80,111,115,0,0,0,0,79,66,74,91,57,56,93,46,83,105,122,101,0,0,0,0,79,66,74,91,57,56,93,46,80,97,108,101,116,116,101,0,83,84,50,0,0,0,0,0,79,66,74,91,57,56,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,99,111,110,116,101,120,116,91,50,52,93,46,105,110,100,101,120,0,0,0,0,0,0,0,79,66,74,91,57,56,93,46,78,97,109,101,0,0,0,0,79,66,74,91,57,56,93,46,86,70,108,105,112,0,0,0,108,111,97,100,45,110,111,115,97,118,101,0,0,0,0,0,110,117,109,57,0,0,0,0,79,66,74,91,57,56,93,46,72,70,108,105,112,0,0,0,74,117,115,116,105,102,105,101,114,49,32,84,114,105,103,103,101,114,0,0,0,0,0,0,70,105,114,101,0,0,0,0,79,66,74,91,57,56,93,46,86,80,111,115,0,0,0,0,103,108,71,101,110,86,101,114,116,101,120,65,114,114,97,121,115,79,69,83,0,0,0,0,67,111,108,111,114,0,0,0,79,66,74,91,57,56,93,46,72,80,111,115,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,91,71,76,93,58,32,51,50,45,98,105,116,32,70,66,79,32,110,111,116,32,115,117,112,112,111,114,116,101,100,46,32,70,97,108,108,105,110,103,32,98,97,99,107,32,116,111,32,49,54,45,98,105,116,46,10,0,0,0,0,79,66,74,91,57,55,93,46,83,105,122,101,0,0,0,0,82,101,116,114,111,80,97,100,32,83,116,97,114,116,32,66,117,116,116,111,110,0,0,0,79,66,74,91,57,55,93,46,80,97,108,101,116,116,101,0,83,72,65,68,69,82,32,68,73,82,32,37,115,0,0,0,82,101,116,114,111,65,114,99,104,58,32,114,97,114,99,104,95,109,97,105,110,95,105,110,105,116,95,119,114,97,112,40,41,32,115,117,99,99,101,101])
.concat([100,101,100,46,10,0,0,0,79,66,74,91,57,55,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,79,66,74,91,57,55,93,46,78,97,109,101,0,0,0,0,118,101,114,116,101,120,0,0,79,66,74,91,57,55,93,46,86,70,108,105,112,0,0,0,77,79,82,84,65,76,32,75,79,77,66,65,84,32,73,73,0,0,0,0,0,0,0,0,111,118,101,114,108,97,121,37,117,95,100,101,115,99,115,0,99,111,110,116,101,120,116,91,50,51,93,46,105,110,118,101,114,116,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,70,111,117,110,100,32,99,104,101,97,116,32,102,111,114,32,103,97,109,101,58,32,34,37,115,34,10,0,0,79,66,74,91,57,55,93,46,72,70,108,105,112,0,0,0,83,65,49,0,0,0,0,0,79,66,74,91,57,55,93,46,86,80,111,115,0,0,0,0,110,111,108,111,97,100,45,115,97,118,101,0,0,0,0,0,110,117,109,56,0,0,0,0,79,66,74,91,57,55,93,46,72,80,111,115,0,0,0,0,79,66,74,91,57,54,93,46,83,105,122,101,0,0,0,0,79,66,74,91,57,54,93,46,80,97,108,101,116,116,101,0,79,66,74,91,57,54,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,82,101,116,114,111,80,97,100,32,83,101,108,101,99,116,32,66,117,116,116,111,110,0,0,79,66,74,91,57,54,93,46,78,97,109,101,0,0,0,0,79,66,74,91,57,54,93,46,86,70,108,105,112,0,0,0,79,66,74,91,57,54,93,46,72,70,108,105,112,0,0,0,79,66,74,91,57,54,93,46,86,80,111,115,0,0,0,0,77,79,82,84,65,76,32,75,79,77,66,65,84,0,0,0,99,111,110,116,101,120,116,91,50,51,93,46,105,110,100,101,120,0,0,0,0,0,0,0,79,66,74,91,57,54,93,46,72,80,111,115,0,0,0,0,79,66,74,91,57,53,93,46,83,105,122,101,0,0,0,0,110,111,108,111,97,100,45,110,111,115,97,118,101,0,0,0,76,111,97,100,101,100,32,115,116,97,116,101,32,102,114,111,109,32,115,108,111,116,32,35,37,117,46,0,0,0,0,0,110,117,109,55,0,0,0,0,79,66,74,91,57,53,93,46,80,97,108,101,116,116,101,0,79,66,74,91,57,53,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,79,66,74,91,57,53,93,46,78,97,109,101,0,0,0,0,79,66,74,91,57,53,93,46,86,70,108,105,112,0,0,0,82,101,116,114,111,80,97,100,32,89,32,66,117,116,116,111,110,0,0,0,0,0,0,0,79,66,74,91,57,53,93,46,72,70,108,105,112,0,0,0,79,66,74,91,57,53,93,46,86,80,111,115,0,0,0,0,79,66,74,91,57,53,93,46,72,80,111,115,0,0,0,0,79,66,74,91,57,52,93,46,83,105,122,101,0,0,0,0,65,51,84,0,0,0,0,0,99,111,110,116,101,120,116,91,50,50,93,46,105,110,118,101,114,116,0,0,0,0,0,0,79,66,74,91,57,52,93,46,80,97,108,101,116,116,101,0,79,66,74,91,57,52,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,68,105,115,99,111,110,110,101,99,116,32,100,101,118,105,99,101,32,102,114,111,109,32,97,32,118,97,108,105,100,32,112,111,114,116,46,10,0,0,0,0,0,0,110,117,109,54,0,0,0,0,79,66,74,91,57,52,93,46,78,97,109,101,0,0,0,0,79,66,74,91,57,52,93,46,86,70,108,105,112,0,0,0,79,66,74,91,57,52,93,46,72,70,108,105,112,0,0,0,79,66,74,91,57,52,93,46,86,80,111,115,0,0,0,0,82,101,116,114,111,80,97,100,32,66,32,66,117,116,116,111,110,0,0,0,0,0,0,0,79,66,74,91,57,52,93,46,72,80,111,115,0,0,0,0,76,101,102,116,32,68,45,112,97,100,0,0,0,0,0,0,79,66,74,91,57,51,93,46,83,105,122,101,0,0,0,0,79,66,74,91,57,51,93,46,80,97,108,101,116,116,101,0,79,66,74,91,57,51,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,82,73,83,69,32,79,70,32,84,72,69,32,82,79,66,79,84,83,0,0,0,0,0,0,99,111,110,116,101,120,116,91,50,50,93,46,105,110,100,101,120,0,0,0,0,0,0,0,79,66,74,91,57,51,93,46,78,97,109,101,0,0,0,0,79,66,74,91,57,51,93,46,86,70,108,105,112,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,110,110,101,99,116,32,109,111,117,115,101,32,116,111,32,97,32,118,97,108,105,100,32,112,111,114,116,46,10,0,0,0,0,110,117,109,53,0,0,0,0,79,66,74,91,57,51,93,46,72,70,108,105,112,0,0,0,79,66,74,91,57,51,93,46,86,80,111,115,0,0,0,0,79,66,74,91,57,51,93,46,72,80,111,115,0,0,0,0,79,66,74,91,57,50,93,46,83,105,122,101,0,0,0,0,46,47,103,101,110,101,114,97,108,46,104,0,0,0,0,0,79,66,74,91,57,50,93,46,80,97,108,101,116,116,101,0,79,66,74,91,57,50,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,79,66,74,91,57,50,93,46,78,97,109,101,0,0,0,0,79,66,74,91,57,50,93,46,86,70,108,105,112,0,0,0,82,79,67,75,32,78,39,32,82,79,76,76,32,82,65,67,73,78,71,0,0,0,0,0,81,117,105,116,32,82,101,116,114,111,65,114,99,104,0,0,99,111,110,116,101,120,116,91,50,49,93,46,105,110,118,101,114,116,0,0,0,0,0,0,79,66,74,91,57,50,93,46,72,70,108,105,112,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,80,73,88,69,76,95,70,79,82,77,65,84,58,32,82,71,66,53,54,53,46,10,0,0,0,79,66,74,91,57,50,93,46,86,80,111,115,0,0,0,0,112,97,114,115,101,95,105,110,112,117,116,40,41,0,0,0,110,117,109,52,0,0,0,0,79,66,74,91,57,50,93,46,72,80,111,115,0,0,0,0,79,66,74,91,57,49,93,46,83,105,122,101,0,0,0,0,79,66,74,91,57,49,93,46,80,97,108,101,116,116,101,0,79,66,74,91,57,49,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,79,66,74,91,57,49,93,46,78,97,109,101,0,0,0,0,79,66,74,91,57,49,93,46,86,70,108,105,112,0,0,0,79,66,74,91,57,49,93,46,72,70,108,105,112,0,0,0,79,66,74,91,57,49,93,46,86,80,111,115,0,0,0,0,65,74,79,74,0,0,0,0,82,101,115,116,97,114,116,32,82,101,116,114,111,65,114,99,104,0,0,0,0,0,0,0,99,111,110,116,101,120,116,91,50,49,93,46,105,110,100,101,120,0,0,0,0,0,0,0,79,66,74,91,57,49,93,46,72,80,111,115,0,0,0,0,79,66,74,91,57,48,93,46,83,105,122,101,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,110,110,101,99,116,32,100,117,97,108,97,110,97,108,111,103,32,116,111,32,97,32,118,97,108,105,100,32,112,111,114,116,46,10,0,0,0,0,0,0,0,110,117,109,51,0,0,0,0,79,66,74,91,57,48,93,46,80,97,108,101,116,116,101,0,79,66,74,91,57,48,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,79,66,74,91,57,48,93,46,78,97,109,101,0,0,0,0,79,66,74,91,57,48,93,46,86,70,108,105,112,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,110,39,116,32,102,105,110,100,32,99,111,110,102,105,103,32,97,116,32,112,97,116,104,58,32,34,37,115,34,10,0,0,0,0,0,0,0,0,79,66,74,91,57,48,93,46,72,70,108,105,112,0,0,0,79,66,74,91,57,48,93,46,86,80,111,115,0,0,0,0,79,66,74,91,57,48,93,46,72,80,111,115,0,0,0,0,79,66,74,91,56,57,93,46,83,105,122,101,0,0,0,0,84,79,84,65,76,32,67,65,82,78,65,71,69,0,0,0,82,101,115,116,97,114,116,32,71,97,109,101,0,0,0,0,99,111,110,116,101,120,116,91,50,48,93,46,105,110,118,101,114,116,0,0,0,0,0,0,79,66,74,91,56,57,93,46,80,97,108,101,116,116,101,0,79,66,74,91,56,57,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,104,115,58,102,118,83,58,109,58,112,52,106,74,65,58,103,58,98,58,99,58,66,58,89,58,90,58,85,58,68,78,58,88,58,80,58,82,58,77,58,0,0,0,0,0,0,0,0,110,117,109,50,0,0,0,0,79,66,74,91,56,57,93,46,78,97,109,101,0,0,0,0,79,66,74,91,56,57,93,46,86,70,108,105,112,0,0,0,79,66,74,91,56,57,93,46,72,70,108,105,112,0,0,0,79,66,74,91,56,57,93,46,86,80,111,115,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,70,111,117,110,100,32,100,101,102,97,117,108,116,32,99,111,110,102,105,103,58,32,37,115,46,10,0,0,0,118,105,100,101,111,95,102,117,108,108,115,99,114,101,101,110,95,121,0,0,0,0,0,0,79,66,74,91,56,57,93,46,72,80,111,115,0,0,0,0,79,66,74,91,56,56,93,46,83,105,122,101,0,0,0,0,79,66,74,91,56,56,93,46,80,97,108,101,116,116,101,0,37,115,32,61,32,34,37,115,34,10,0,0,0,0,0,0,79,66,74,91,56,56,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,65,84,81,0,0,0,0,0,82,101,115,117,109,101,32,71,97,109,101,0,0,0,0,0,99,111,110,116,101,120,116,91,50,48,93,46,105,110,100,101,120,0,0,0,0,0,0,0,79,66,74,91,56,56,93,46,78,97,109,101,0,0,0,0,79,66,74,91,56,56,93,46,86,70,108,105,112,0,0,0,102,101,97,116,117,114,101,115,0,0,0,0,0,0,0,0,110,117,109,49,0,0,0,0,79,66,74,91,56,56,93,46,72,70,108,105,112,0,0,0,79,66,74,91,56,56,93,46,86,80,111,115,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,97,110,110,111,116,32,111,112,101,110,32,118,105,100,101,111,32,100,114,105,118,101,114,32,46,46,46,32,69,120,105,116,105,110,103,32,46,46,46,10,0,0,79,66,74,91,56,56,93,46,72,80,111,115,0,0,0,0,79,66,74,91,56,55,93,46,83,105,122,101,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,76,111,97,100,105,110,103,32,100,101,102,97,117,108,116,32,99,111,110,102,105,103,46,10,0,0,0,0,0,79,66,74,91,56,55,93,46,80,97,108,101,116,116,101,0,79,66,74,91,56,55,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,47,112,114,111,99,47,37,117,47,37,115,0,0,0,0,0,79,66,74,91,56,55,93,46,78,97,109,101,0,0,0,0,79,66,74,91,56,55,93,46,86,70,108,105,112,0,0,0,71,83,32,77,73,75,65,77,73,0,0,0,0,0,0,0,84,97,107,101,32,83,99,114,101,101,110,115,104,111,116,0,99,111,110,116,101,120,116,91,49,57,93,46,105,110,118,101,114,116,0,0,0,0,0,0,79,66,74,91,56,55,93,46,72,70,108,105,112,0,0,0,79,66,74,91,56,55,93,46,86,80,111,115,0,0,0,0,100,101,116,97,99,104,0,0,110,117,109,48,0,0,0,0,79,66,74,91,56,55,93,46,72,80,111,115,0,0,0,0,79,66,74,91,56,54,93,46,83,105,122,101,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,65,116,116,101,109,112,116,105,110,103,32,116,111,32,114,101,99,111,118,101,114,32,46,46,46,10,0,0,79,66,74,91,56,54,93,46,80,97,108,101,116,116,101,0,79,66,74,91,56,54,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,76,111,97,100,105,110,103,32,99,111,110,102,105,103,32,102,114,111,109,58,32,37,115,46,10,0,0,0,0,79,66,74,91,56,54,93,46,78,97,109,101,0,0,0,0,79,66,74,91,56,54,93,46,86,70,108,105,112,0,0,0,79,66,74,91,56,54,93,46,72,70,108,105,112,0,0,0,110,117,108,108,0,0,0,0,79,66,74,91,56,54,93,46,86,80,111,115,0,0,0,0,84,65,76,69,83,32,79,70,32,80,72,65,78,84,65,83,73,65,0,0,0,0,0,0,76,111,97,100,32,83,116,97,116,101,0,0,0,0,0,0,99,111,110,116,101,120,116,91,49,57,93,46,105,110,100,101,120,0,0,0,0,0,0,0,79,66,74,91,56,54,93,46,72,80,111,115,0,0,0,0,79,66,74,91,56,53,93,46,83,105,122,101,0,0,0,0,120,109,108,0,0,0,0,0,102,49,50,0,0,0,0,0,79,66,74,91,56,53,93,46,80,97,108,101,116,116,101,0,83,117,112,101,114,115,99,111,112,101,32,80,97,117,115,101,0,0,0,0,0,0,0,0,65,105,109,79,102,102,115,99,114,101,101,110,0,0,0,0,79,66,74,91,56,53,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,115,105,110,99,0,0,0,0,103,108,68,101,108,101,116,101,86,101,114,116,101,120,65,114,114,97,121,115,79,69,83,0,86,101,114,116,101,120,67,111,111,114,100,0,0,0,0,0,79,66,74,91,56,53,93,46,78,97,109,101,0,0,0,0,65,82,77,95,97,114,103,98,56,0,0,0,0,0,0,0,79,66,74,91,56,53,93,46,86,70,108,105,112,0,0,0,114,101,116,114,111,97,114,99,104,46,99,102,103,0,0,0,79,66,74,91,56,53,93,46,72,70,108,105,112,0,0,0,66,82,79,87,83,69,82,32,68,73,82,32,37,115,0,0,79,66,74,91,56,53,93,46,86,80,111,115,0,0,0,0,79,66,74,91,56,53,93,46,72,80,111,115,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,91,71,76,93,58,32,76,101,103,97,99,121,32,115,104,97,100,101,114,115,32,97,114,101,32,100,101,112,114,101,99,97,116,101,100,46,10,0,0,0,0,0,0,0,79,66,74,91,56,52,93,46,83,105,122,101,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,67,111,110,102,105,103,93,58,32,81,117,101,114,121,105,110,103,32,97,112,112,108,105,99,97,116,105,111,110,32,112,97,116,104,58,32,37,115,46,10,0,0,0,0,65,87,68,0,0,0,0,0,83,97,118,101,32,83,116,97,116,101,0,0,0,0,0,0,111,118,101,114,108,97,121,37,117,95,102,117,108,108,95,115,99,114,101,101,110,0,0,0,119,98,0,0,0,0,0,0,99,111,110,116,101,120,116,91,49,56,93,46,105,110,118,101,114,116,0,0,0,0,0,0,110,97,109,101,0,0,0,0,79,66,74,91,56,52,93,46,80,97,108,101,116,116,101,0,83,70,88,0,0,0,0,0,79,66,74,91,56,52,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,110,111,45,112,97,116,99,104,0,0,0,0,0,0,0,0,102,49,49,0,0,0,0,0,79,66,74,91,56,52,93,46,78,97,109,101,0,0,0,0,79,66,74,91,56,52,93,46,86,70,108,105,112,0,0,0,79,66,74,91,56,52,93,46,72,70,108,105,112,0,0,0,79,66,74,91,56,52,93,46,86,80,111,115,0,0,0,0,46,116,103,97,0,0,0,0,47,101,116,99,0,0,0,0,79,66,74,91,56,52,93,46,72,80,111,115,0,0,0,0,79,66,74,91,56,51,93,46,83,105,122,101,0,0,0,0,79,66,74,91,56,51,93,46,80,97,108,101,116,116,101,0,79,66,74,91,56,51,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,98,105,116,109,97,112,0,0,84,72,69,32,67,72,65,79,83,32,69,78,71,73,78,69,0,0,0,0,0,0,0,0,68,105,115,107,32,79,112,116,105,111,110,115,0,0,0,0,99,111,110,116,101,120,116,91,49,56,93,46,105,110,100,101,120,0,0,0,0,0,0,0,79,66,74,91,56,51,93,46,78,97,109,101,0,0,0,0,79,66,74,91,56,51,93,46,86,70,108,105,112,0,0,0,82,101,116,114,111,65,114,99,104,58,32,85,115,105,110,103,32,102,111,110,116,32,114,101,110,100,101,114,105,110,103,32,98,97,99,107,101,110,100,58,32,37,115,46,10,0,0,0,105,112,115,0,0,0,0,0,102,49,48,0,0,0,0,0,79,66,74,91,56,51,93,46,72,70,108,105,112,0,0,0,79,66,74,91,56,51,93,46,86,80,111,115,0,0,0,0,79,66,74,91,56,51,93,46,72,80,111,115,0,0,0,0,79,66,74,91,56,50,93,46,83,105,122,101,0,0,0,0,37,115,47,46,114,101,116,114,111,97,114,99,104,46,99,102,103,0,0,0,0,0,0,0,79,66,74,91,56,50,93,46,80,97,108,101,116,116,101,0,79,66,74,91,56,50,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,79,66,74,91,56,50,93,46,78,97,109,101,0,0,0,0,79,66,74,91,56,50,93,46,86,70,108,105,112,0,0,0,65,88,71,0,0,0,0,0,83,101,116,116,105,110,103,115,0,0,0,0,0,0,0,0,99,111,110,116,101,120,116,91,49,55,93,46,105,110,118,101,114,116,0,0,0,0,0,0,79,66,74,91,56,50,93,46,72,70,108,105,112,0,0,0,79,66,74,91,56,50,93,46,86,80,111,115,0,0,0,0,98,112,115,0,0,0,0,0,102,57,0,0,0,0,0,0,79,66,74,91,56,50,93,46,72,80,111,115,0,0,0,0,79,66,74,91,56,49,93,46,83,105,122,101,0,0,0,0,79,66,74,91,56,49,93,46,80,97,108,101,116,116,101,0,79,66,74,91,56,49,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,76,111,111,107,105,110,103,32,102,111,114,32,99,111,110,102,105,103,32,105,110,58,32,34,37,115,34,46,10,0,0,0,0,0,0,0,0,79,66,74,91,56,49,93,46,78,97,109,101,0,0,0,0,79,66,74,91,56,49,93,46,86,70,108,105,112,0,0,0,79,66,74,91,56,49,93,46,72,70,108,105,112,0,0,0,79,66,74,91,56,49,93,46,86,80,111,115,0,0,0,0,65,80,84,0,0,0,0,0,80,97,116,104,32,79,112,116,105,111,110,115,0,0,0,0,99,111,110,116,101,120,116,91,49,55,93,46,105,110,100,101,120,0,0,0,0,0,0,0,79,66,74,91,56,49,93,46,72,80,111,115,0,0,0,0,79,66,74,91,56,48,93,46,83,105,122,101,0,0,0,0,117,112,115,0,0,0,0,0,102,56,0,0,0,0,0,0,79,66,74,91,56,48,93,46,80,97,108,101,116,116,101,0,79,66,74,91,56,48,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,79,66,74,91,56,48,93,46,78,97,109,101,0,0,0,0,79,66,74,91,56,48,93,46,86,70,108,105,112,0,0,0,37,115,47,46,99,111,110,102,105,103,47,114,101,116,114,111,97,114,99,104,47,114,101,116,114,111,97,114,99,104,46,99,102,103,0,0,0,0,0,0,79,66,74,91,56,48,93,46,72,70,108,105,112,0,0,0,79,66,74,91,56,48,93,46,86,80,111,115,0,0,0,0,79,66,74,91,56,48,93,46,72,80,111,115,0,0,0,0,79,66,74,91,55,57,93,46,83,105,122,101,0,0,0,0,65,56,0,0,0,0,0,0,73,110,112,117,116,32,79,112,116,105,111,110,115,0,0,0,99,111,110,116,101,120,116,91,49,54,93,46,105,110,118,101,114,116,0,0,0,0,0,0,79,66,74,91,55,57,93,46,80,97,108,101,116,116,101,0,79,66,74,91,55,57,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,115,114,97,109,45,109,111,100,101,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,69,84,95,80,73,88,69,76,95,70,79,82,77,65,84,58,32,48,82,71,66,49,53,53,53,46,10,0,102,55,0,0,0,0,0,0,79,66,74,91,55,57,93,46,78,97,109,101,0,0,0,0,79,66,74,91,55,57,93,46,86,70,108,105,112,0,0,0,79,66,74,91,55,57,93,46,72,70,108,105,112,0,0,0,79,66,74,91,55,57,93,46,86,80,111,115,0,0,0,0,37,115,47,114,101,116,114,111,97,114,99,104,47,114,101,116,114,111,97,114,99,104,46,99,102,103,0,0,0,0,0,0,79,66,74,91,55,57,93,46,72,80,111,115,0,0,0,0,79,66,74,91,55,56,93,46,83,105,122,101,0,0,0,0,79,66,74,91,55,56,93,46,80,97,108,101,116,116,101,0,79,66,74,91,55,56,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,65,99,116,82,97,105,115,101,114,45,50,32,85,83,65,0,65,117,100,105,111,32,79,112,116,105,111,110,115,0,0,0,79,66,74,91,55,56,93,46,78,97,109,101,0,0,0,0,99,111,110,116,101,120,116,91,49,54,93,46,105,110,100,101,120,0,0,0,0,0,0,0,79,66,74,91,55,56,93,46,86,70,108,105,112,0,0,0,98,115,118,114,101,99,111,114,100,0,0,0,0,0,0,0,102,54,0,0,0,0,0,0,79,66,74,91,55,56,93,46,72,70,108,105,112,0,0,0,79,66,74,91,55,56,93,46,86,80,111,115,0,0,0,0,79,66,74,91,55,56,93,46,72,80,111,115,0,0,0,0,79,66,74,91,55,55,93,46,83,105,122,101,0,0,0,0,72,79,77,69,0,0,0,0,79,66,74,91,55,55,93,46,80,97,108,101,116,116,101,0,79,66,74,91,55,55,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,79,66,74,91,55,55,93,46,78,97,109,101,0,0,0,0,79,66,74,91,55,55,93,46,86,70,108,105,112,0,0,0,65,99,116,82,97,105,115,101,114,45,50,32,74,80,78,0,86,105,100,101,111,32,79,112,116,105,111,110,115,0,0,0,99,111,110,116,101,120,116,91,49,53,93,46,105,110,118,101,114,116,0,0,0,0,0,0,79,66,74,91,55,55,93,46,72,70,108,105,112,0,0,0,79,66,74,91,55,55,93,46,86,80,111,115,0,0,0,0,98,115,118,112,108,97,121,0,102,53,0,0,0,0,0,0,79,66,74,91,55,55,93,46,72,80,111,115,0,0,0,0,79,66,74,91,55,54,93,46,83,105,122,101,0,0,0,0,79,66,74,91,55,54,93,46,80,97,108,101,116,116,101,0,79,66,74,91,55,54,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,88,68,71,95,67,79,78,70,73,71,95,72,79,77,69,0,118,105,100,101,111,95,102,117,108,108,115,99,114,101,101,110,95,120,0,0,0,0,0,0,79,66,74,91,55,54,93,46,78,97,109,101,0,0,0,0,79,66,74,91,55,54,93,46,86,70,108,105,112,0,0,0,79,66,74,91,55,54,93,46,72,70,108,105,112,0,0,0,35,105,110,99,108,117,100,101,32,34,37,115,34,10,0,0,79,66,74,91,55,54,93,46,86,80,111,115,0,0,0,0,65,76,65,68,68,73,78,0,67,111,114,101,32,79,112,116,105,111,110,115,0,0,0,0,99,111,110,116,101,120,116,91,49,53,93,46,105,110,100,101,120,0,0,0,0,0,0,0,79,66,74,91,55,54,93,46,72,80,111,115,0,0,0,0,79,66,74,91,55,53,93,46,83,105,122,101,0,0,0,0,115,117,102,97,109,105,66,0,102,52,0,0,0,0,0,0,79,66,74,91,55,53,93,46,80,97,108,101,116,116,101,0,79,66,74,91,55,53,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,105,110,105,116,95,118,105,100,101,111,95,105,110,112,117,116,40,41,0,0,0,0,0,0,79,66,74,91,55,53,93,46,78,97,109,101,0,0,0,0,79,66,74,91,55,53,93,46,86,70,108,105,112,0,0,0,79,66,74,91,55,53,93,46,72,70,108,105,112,0,0,0,79,66,74,91,55,53,93,46,86,80,111,115,0,0,0,0,112,97,116,104,47,97,46,111,117,116,0,0,0,0,0,0,79,66,74,91,55,53,93,46,72,80,111,115,0,0,0,0,79,66,74,91,55,52,93,46,83,105,122,101,0,0,0,0,80,76,79,75,0,0,0,0,76,111,97,100,32,71,97,109,101,0,0,0,0,0,0,0,99,111,110,116,101,120,116,91,49,52,93,46,105,110,118,101,114,116,0,0,0,0,0,0,79,66,74,91,55,52,93,46,80,97,108,101,116,116,101,0,79,66,74,91,55,52,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,115,117,102,97,109,105,65,0,102,51,0,0,0,0,0,0,79,66,74,91,55,52,93,46,78,97,109,101,0,0,0,0,79,66,74,91,55,52,93,46,86,70,108,105,112,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,115,97,118,101,32,83,82,65,77,46,10,0,0,0,0,0,0,79,66,74,91,55,52,93,46,72,70,108,105,112,0,0,0,79,66,74,91,55,52,93,46,86,80,111,115,0,0,0,0,79,66,74,91,55,52,93,46,72,80,111,115,0,0,0,0,79,66,74,91,55,51,93,46,83,105,122,101,0,0,0,0,79,66,74,91,55,51,93,46,80,97,108,101,116,116,101,0,79,66,74,91,55,51,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,84,50,32,65,82,67,65,68,69,0,0,0,0,0,0,0,76,111,97,100,32,71,97,109,101,32,40,72,105,115,116,111,114,121,41,0,0,0,0,0,99,111,110,116,101,120,116,91,49,52,93,46,105,110,100,101,120,0,0,0,0,0,0,0,79,66,74,91,55,51,93,46,78,97,109,101,0,0,0,0,79,66,74,91,55,51,93,46,86,70,108,105,112,0,0,0,109,117,108,116,105,116,97,112,0,0,0,0,0,0,0,0,102,50,0,0,0,0,0,0,79,66,74,91,55,51,93,46,72,70,108,105,112,0,0,0,83,117,112,101,114,115,99,111,112,101,32,84,111,103,103,108,101,84,117,114,98,111,0,0,83,117,112,101,114,115,99,111,112,101,32,0,0,0,0,0,3,3,11,0,0,0,0,0,79,66,74,91,55,51,93,46,86,80,111,115,0,0,0,0,103,108,66,105,110,100,86,101,114,116,101,120,65,114,114,97,121,79,69,83,0,0,0,0,84,101,120,67,111,111,114,100,0,0,0,0,0,0,0,0,79,66,74,91,55,51,93,46,72,80,111,115,0,0,0,0,79,69,83,95,114,103,98,56,95,114,103,98,97,56,0,0,79,66,74,91,55,50,93,46,83,105,122,101,0,0,0,0,79,66,74,91,55,50,93,46,80,97,108,101,116,116,101,0,79,86,69,82,76,65,89,32,37,115,0,0,0,0,0,0,73,78,70,79,32,45,32,76,111,97,100,105,110,103,32,37,115,32,46,46,46,0,0,0,79,66,74,91,55,50,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,79,66,74,91,55,50,93,46,78,97,109,101,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,71,76,93,58,32,83,104,97,100,101,114,32,114,101,112,111,114,116,115,32,97,32,71,76,69,83,50,32,115,116,121,108,101,32,115,104,97,100,101,114,46,10,0,0,79,66,74,91,55,50,93,46,86,70,108,105,112,0,0,0,83,73,77,67,73,84,89,0,114,103,117,105,46,99,103,112,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,91,79,118,101,114,108,97,121,93,58,32,70,97,105,108,101,100,32,116,111,32,115,112,108,105,116,32,114,101,99,116,32,34,37,115,34,32,105,110,116,111,32,97,116,32,108,101,97,115,116,32,102,111,117,114,32,116,111,107,101,110,115,46,10,0,0,0,115,99,97,108,101,95,121,37,117,0,0,0,0,0,0,0,99,111,110,116,101,120,116,91,49,51,93,46,105,110,118,101,114,116,0,0,0,0,0,0,79,66,74,91,55,50,93,46,72,70,108,105,112,0,0,0,84,73,77,0,0,0,0,0,79,66,74,91,55,50,93,46,86,80,111,115,0,0,0,0,98,115,120,115,108,111,116,0,102,49,0,0,0,0,0,0,79,66,74,91,55,50,93,46,72,80,111,115,0,0,0,0,79,66,74,91,55,49,93,46,83,105,122,101,0,0,0,0,79,66,74,91,55,49,93,46,80,97,108,101,116,116,101,0,79,66,74,91,55,49,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,79,66,74,91,55,49,93,46,78,97,109,101,0,0,0,0,79,66,74,91,55,49,93,46,86,70,108,105,112,0,0,0,79,66,74,91,55,49,93,46,72,70,108,105,112,0,0,0,79,66,74,91,55,49,93,46,86,80,111,115,0,0,0,0,83,80,65,82,75,83,84,69,82,0,0,0,0,0,0,0,114,103,117,105,46,103,108,115,108,112,0,0,0,0,0,0,115,99,97,108,101,95,120,37,117,0,0,0,0,0,0,0,99,111,110,116,101,120,116,91,49,51,93,46,105,110,100,101,120,0,0,0,0,0,0,0,79,66,74,91,55,49,93,46,72,80,111,115,0,0,0,0,79,66,74,91,55,48,93,46,83,105,122,101,0,0,0,0,98,115,120,0,0,0,0,0,37,115,37,117,0,0,0,0,107,112,95,109,105,110,117,115,0,0,0,0,0,0,0,0,79,66,74,91,55,48,93,46,80,97,108,101,116,116,101,0,79,66,74,91,55,48,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,79,66,74,91,55,48,93,46,78,97,109,101,0,0,0,0,79,66,74,91,55,48,93,46,86,70,108,105,112,0,0,0,79,66,74,91,55,48,93,46,72,70,108,105,112,0,0,0,79,66,74,91,55,48,93,46,86,80,111,115,0,0,0,0,79,66,74,91,55,48,93,46,72,80,111,115,0,0,0,0,79,66,74,91,54,57,93,46,83,105,122,101,0,0,0,0,90,69,76,68,65,78,79,68,69,78,83,69,84,83,85,0,82,101,116,114,111,65,114,99,104,58,32,65,112,112,108,121,105,110,103,32,115,104,97,100,101,114,32,46,46,46,10,0,115,99,97,108,101,37,117,0,99,111,110,116,101,120,116,91,49,50,93,46,105,110,118,101,114,116,0,0,0,0,0,0,79,66,74,91,54,57,93,46,80,97,108,101,116,116,101,0,79,66,74,91,54,57,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,115,97,118,101,115,116,97,116,101,0,0,0,0,0,0,0,107,112,95,112,108,117,115,0,79,66,74,91,54,57,93,46,78,97,109,101,0,0,0,0,79,66,74,91,54,57,93,46,86,70,108,105,112,0,0,0,79,66,74,91,54,57,93,46,72,70,108,105,112,0,0,0,79,66,74,91,54,57,93,46,86,80,111,115,0,0,0,0,79,66,74,91,54,57,93,46,72,80,111,115,0,0,0,0,68,111,119,110,32,68,45,112,97,100,0,0,0,0,0,0,79,66,74,91,54,56,93,46,83,105,122,101,0,0,0,0,79,66,74,91,54,56,93,46,80,97,108,101,116,116,101,0,79,66,74,91,54,56,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,76,65,32,76,69,71,69,78,68,69,32,68,69,32,90,69,76,68,65,0,0,0,0,0,82,51,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,73,110,118,97,108,105,100,32,97,116,116,114,105,98,117,116,101,46,10,0,0,0,0,0,0,0,0,99,111,110,116,101,120,116,91,49,50,93,46,105,110,100,101,120,0,0,0,0,0,0,0,79,66,74,91,54,56,93,46,78,97,109,101,0,0,0,0,79,66,74,91,54,56,93,46,86,70,108,105,112,0,0,0,100,117,97,108,97,110,97,108,111,103,0,0,0,0,0,0,115,117,98,116,114,97,99,116,0,0,0,0,0,0,0,0,79,66,74,91,54,56,93,46,72,70,108,105,112,0,0,0,79,66,74,91,54,56,93,46,86,80,111,115,0,0,0,0,79,66,74,91,54,56,93,46,72,80,111,115,0,0,0,0,79,66,74,91,54,55,93,46,83,105,122,101,0,0,0,0,79,66,74,91,54,55,93,46,80,97,108,101,116,116,101,0,79,66,74,91,54,55,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,79,66,74,91,54,55,93,46,78,97,109,101,0,0,0,0,79,66,74,91,54,55,93,46,86,70,108,105,112,0,0,0,84,72,69,32,76,69,71,69,78,68,32,79,70,32,90,69,76,68,65,0,0,0,0,0,76,51,0,0,0,0,0,0,115,99,97,108,101,95,116,121,112,101,95,121,37,117,0,0,99,111,110,116,101,120,116,91,49,49,93,46,105,110,118,101,114,116,0,0,0,0,0,0,79,66,74,91,54,55,93,46,72,70,108,105,112,0,0,0,79,66,74,91,54,55,93,46,86,80,111,115,0,0,0,0,106,117,115,116,105,102,105,101,114,115,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,89,83,84,69,77,95,68,73,82,69,67,84,79,82,89,58,32,34,37,115,34,46,10,0,0,0,0,0,97,100,100,0,0,0,0,0,79,66,74,91,54,55,93,46,72,80,111,115,0,0,0,0,115,104,97,100,101,114,115,0,79,66,74,91,54,54,93,46,83,105,122,101,0,0,0,0,79,66,74,91,54,54,93,46,80,97,108,101,116,116,101,0,79,66,74,91,54,54,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,79,66,74,91,54,54,93,46,78,97,109,101,0,0,0,0,79,117,116,32,88,32,61,32,37,100,32,61,62,32,73,110,32,88,32,61,32,37,100,10,0,0,0,0,0,0,0,0,79,66,74,91,54,54,93,46,86,70,108,105,112,0,0,0,79,66,74,91,54,54,93,46,72,70,108,105,112,0,0,0,79,66,74,91,54,54,93,46,86,80,111,115,0,0,0,0,83,85,80,69,82,32,77,65,82,73,79,87,79,82,76,68,0,0,0,0,0,0,0,0,82,50,0,0,0,0,0,0,115,99,97,108,101,95,116,121,112,101,95,120,37,117,0,0,99,111,110,116,101,120,116,91,49,49,93,46,105,110,100,101,120,0,0,0,0,0,0,0,79,66,74,91,54,54,93,46,72,80,111,115,0,0,0,0,79,66,74,91,54,53,93,46,83,105,122,101,0,0,0,0,106,117,115,116,105,102,105,101,114,0,0,0,0,0,0,0,101,115,99,97,112,101,0,0,79,66,74,91,54,53,93,46,80,97,108,101,116,116,101,0,79,66,74,91,54,53,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,79,66,74,91,54,53,93,46,78,97,109,101,0,0,0,0,79,66,74,91,54,53,93,46,86,70,108,105,112,0,0,0,79,66,74,91,54,53,93,46,72,70,108,105,112,0,0,0,79,66,74,91,54,53,93,46,86,80,111,115,0,0,0,0,79,66,74,91,54,53,93,46,72,80,111,115,0,0,0,0,79,66,74,91,54,52,93,46,83,105,122,101,0,0,0,0,65,70,74,0,0,0,0,0,115,99,97,108,101,95,116,121,112,101,37,117,0,0,0,0,99,111,110,116,101,120,116,91,49,48,93,46,105,110,118,101,114,116,0,0,0,0,0,0,79,66,74,91,54,52,93,46,80,97,108,101,116,116,101,0,79,66,74,91,54,52,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,115,99,111,112,101,0,0,0,115,112,97,99,101,0,0,0,79,66,74,91,54,52,93,46,78,97,109,101,0,0,0,0,79,66,74,91,54,52,93,46,86,70,108,105,112,0,0,0,79,66,74,91,54,52,93,46,72,70,108,105,112,0,0,0,79,66,74,91,54,52,93,46,86,80,111,115,0,0,0,0,118,105,100,101,111,95,121,115,99,97,108,101,0,0,0,0,79,66,74,91,54,52,93,46,72,80,111,115,0,0,0,0,79,66,74,91,54,51,93,46,83,105,122,101,0,0,0,0,79,66,74,91,54,51,93,46,80,97,108,101,116,116,101,0,79,66,74,91,54,51,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,89,73,0,0,0,0,0,0,82,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,111,117,108,100,110,39,116,32,112,97,114,115,101,32,115,104,97,100,101,114,32,115,111,117,114,99,101,32,40,37,115,41,46,10,0,0,0,0,0,0,0,0,99,111,110,116,101,120,116,91,49,48,93,46,105,110,100,101,120,0,0,0,0,0,0,0,79,66,74,91,54,51,93,46,78,97,109,101,0,0,0,0,79,66,74,91,54,51,93,46,86,70,108,105,112,0,0,0,110,111,100,101,118,105,99,101,0,0,0,0,0,0,0,0,97,108,116,0,0,0,0,0,79,66,74,91,54,51,93,46,72,70,108,105,112,0,0,0,79,66,74,91,54,51,93,46,86,80,111,115,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,105,110,105,116,32,112,105,120,101,108,32,99,111,110,118,101,114,116,101,114,46,10,0,0,0,79,66,74,91,54,51,93,46,72,80,111,115,0,0,0,0,79,66,74,91,54,50,93,46,83,105,122,101,0,0,0,0,105,110,112,117,116,95,100,101,118,105,99,101,95,112,37,117,0,0,0,0,0,0,0,0,79,66,74,91,54,50,93,46,80,97,108,101,116,116,101,0,79,66,74,91,54,50,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,109,111,117,115,101,0,0,0,79,66,74,91,54,50,93,46,78,97,109,101,0,0,0,0,79,66,74,91,54,50,93,46,86,70,108,105,112,0,0,0,65,69,74,0,0,0,0,0,76,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,73,110,118,97,108,105,100,32,119,114,97,112,112,105,110,103,32,116,121,112,101,32,37,115,46,32,86,97,108,105,100,32,111,110,101,115,32,97,114,101,58,32,99,108,97,109,112,95,116,111,95,98,111,114,100,101,114,32,40,100,101,102,97,117,108,116,41,44,32,99,108,97,109,112,95,116,111,95,101,100,103,101,44,32,114,101,112,101,97,116,32,97,110,100,32,109,105,114,114,111,114,101,100,95,114,101,112,101,97,116,46,32,70,97,108,108,105,110,103,32,98,97,99,107,32,116,111,32,100,101,102,97,117,108,116,46,10,0,0,0,99,111,110,116,101,120,116,91,57,93,46,105,110,118,101,114,116,0,0,0,0,0,0,0,79,66,74,91,54,50,93,46,72,70,108,105,112,0,0,0,79,66,74,91,54,50,93,46,86,80,111,115,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,105,110,105,116,32,114,101,119,105,110,100,32,98,117,102,102,101,114,46,32,82,101,119,105,110,100,105,110,103,32,119,105,108,108,32,98,101,32,100,105,115,97,98,108,101,100,46,10,0,0,99,116,114,108,0,0,0,0,79,66,74,91,54,50,93,46,72,80,111,115,0,0,0,0,79,66,74,91,54,49,93,46,83,105,122,101,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,66,108,111,99,107,105,110,103,32,83,82,65,77,32,111,118,101,114,119,114,105,116,101,46,10,0,0,0,0,79,66,74,91,54,49,93,46,80,97,108,101,116,116,101,0,79,66,74,91,54,49,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,105,110,112,117,116,95,100,112,97,100,95,101,109,117,108,97,116,105,111,110,95,112,37,117,0,0,0,0,0,0,0,0,79,66,74,91,54,49,93,46,78,97,109,101,0,0,0,0,79,66,74,91,54,49,93,46,86,70,108,105,112,0,0,0,79,66,74,91,54,49,93,46,72,70,108,105,112,0,0,0,79,66,74,91,54,49,93,46,86,80,111,115,0,0,0,0,73,76,76,85,83,73,79,78,32,79,70,32,71,65,73,65,32,85,83,65,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,97,110,110,111,116,32,102,105,110,100,32,112,97,116,104,32,116,111,32,116,101,120,116,117,114,101,32,34,37,115,34,32,46,46,46,10,0,0,0,0,0,0,99,111,110,116,101,120,116,91,57,93,46,105,110,100,101,120,0,0,0,0,0,0,0,0,79,66,74,91,54,49,93,46,72,80,111,115,0,0,0,0,79,66,74,91,54,48,93,46,83,105,122,101,0,0,0,0,97,112,112,101,110,100,99,111,110,102,105,103,0,0,0,0,79,66,74,91,54,48,93,46,80,97,108,101,116,116,101,0,83,117,112,101,114,115,99,111,112,101,32,67,117,114,115,111,114,0,0,0,0,0,0,0,77,111,117,115,101,0,0,0,2,3,7,0,0,0,0,0,79,66,74,91,54,48,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,103,108,70,114,97,109,101,98,117,102,102,101,114,84,101,120,116,117,114,101,51,68,79,69,83,0,0,0,0,0,0,0,77,86,80,77,97,116,114,105,120,0,0,0,0,0,0,0,79,66,74,91,54,48,93,46,78,97,109,101,0,0,0,0,100,111,101,115,110,39,116,32,101,120,105,115,116,0,0,0,79,66,74,91,54,48,93,46,86,70,108,105,112,0,0,0,99,117,115,116,111,109,95,98,103,109,95,101,110,97,98,108,101,0,0,0,0,0,0,0,79,66,74,91,54,48,93,46,72,70,108,105,112,0,0,0,37,115,46,122,105,112,0,0,79,66,74,91,54,48,93,46,86,80,111,115,0,0,0,0,79,66,74,91,54,48,93,46,72,80,111,115,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,91,71,76,93,58,32,85,115,105,110,103,32,117,110,105,102,111,114,109,32,97,110,100,32,97,116,116,114,105,98,32,112,114,101,102,105,120,58,32,37,115,10,0,0,0,79,66,74,91,53,57,93,46,83,105,122,101,0,0,0,0,70,73,78,65,76,32,70,65,78,84,65,83,89,32,51,0,44,32,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,78,111,32,97,100,100,114,101,115,115,32,97,115,115,105,103,110,101,100,32,116,111,32,115,101,109,97,110,116,105,99,46,10,0,0,99,111,110,116,101,120,116,91,56,93,46,105,110,118,101,114,116,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105])
.concat([108,101,100,32,116,111,32,119,114,105,116,101,32,88,77,76,32,99,104,101,97,116,32,115,101,116,116,105,110,103,115,32,116,111,32,34,37,115,34,46,32,67,104,101,99,107,32,112,101,114,109,105,115,115,105,111,110,115,46,10,0,0,0,0,79,66,74,91,53,57,93,46,80,97,108,101,116,116,101,0,63,62,10,0,0,0,0,0,67,84,76,0,0,0,0,0,79,66,74,91,53,57,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,99,111,110,102,105,103,0,0,114,115,104,105,102,116,0,0,79,66,74,91,53,57,93,46,78,97,109,101,0,0,0,0,79,66,74,91,53,57,93,46,86,70,108,105,112,0,0,0,79,66,74,91,53,57,93,46,72,70,108,105,112,0,0,0,79,66,74,91,53,57,93,46,86,80,111,115,0,0,0,0,115,99,114,101,101,110,95,111,114,105,101,110,116,97,116,105,111,110,0,0,0,0,0,0,79,66,74,91,53,57,93,46,72,80,111,115,0,0,0,0,79,66,74,91,53,56,93,46,83,105,122,101,0,0,0,0,79,66,74,91,53,56,93,46,80,97,108,101,116,116,101,0,79,66,74,91,53,56,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,70,73,78,65,76,32,70,65,78,84,65,83,89,32,54,0,89,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,73,110,118,97,108,105,100,32,115,101,109,97,110,116,105,99,46,10,0,99,111,110,116,101,120,116,91,56,93,46,105,110,100,101,120,0,0,0,0,0,0,0,0,79,66,74,91,53,56,93,46,78,97,109,101,0,0,0,0,79,66,74,91,53,56,93,46,86,70,108,105,112,0,0,0,103,97,109,101,98,111,121,0,82,101,116,114,111,65,114,99,104,58,32,84,97,107,105,110,103,32,115,99,114,101,101,110,115,104,111,116,46,10,0,0,104,111,109,101,0,0,0,0,79,66,74,91,53,56,93,46,72,70,108,105,112,0,0,0,79,66,74,91,53,56,93,46,86,80,111,115,0,0,0,0,79,66,74,91,53,56,93,46,72,80,111,115,0,0,0,0,79,66,74,91,53,55,93,46,83,105,122,101,0,0,0,0,79,66,74,91,53,55,93,46,80,97,108,101,116,116,101,0,79,66,74,91,53,55,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,79,66,74,91,53,55,93,46,78,97,109,101,0,0,0,0,79,66,74,91,53,55,93,46,86,70,108,105,112,0,0,0,70,73,78,65,76,32,70,73,71,72,84,0,0,0,0,0,88,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,78,111,32,115,101,109,97,110,116,105,99,32,102,111,114,32,105,109,112,111,114,116,32,118,97,114,105,97,98,108,101,46,10,0,0,99,111,110,116,101,120,116,91,55,93,46,105,110,118,101,114,116,0,0,0,0,0,0,0,79,66,74,91,53,55,93,46,72,70,108,105,112,0,0,0,79,66,74,91,53,55,93,46,86,80,111,115,0,0,0,0,118,101,114,98,111,115,101,0,101,110,100,0,0,0,0,0,79,66,74,91,53,55,93,46,72,80,111,115,0,0,0,0,79,66,74,91,53,54,93,46,83,105,122,101,0,0,0,0,79,66,74,91,53,54,93,46,80,97,108,101,116,116,101,0,83,117,112,101,114,70,88,32,79,118,101,114,99,108,111,99,107,59,32,100,105,115,97,98,108,101,100,124,52,48,77,72,122,124,54,48,77,72,122,124,56,48,77,72,122,124,49,48,48,77,72,122,0,0,0,0,79,66,74,91,53,54,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,115,116,97,116,101,95,115,108,111,116,0,0,0,0,0,0,79,66,74,91,53,54,93,46,78,97,109,101,0,0,0,0,65,80,85,32,115,112,101,101,100,117,112,32,104,97,99,107,58,32,37,100,10,0,0,0,79,66,74,91,53,54,93,46,86,70,108,105,112,0,0,0,79,66,74,91,53,54,93,46,72,70,108,105,112,0,0,0,79,66,74,91,53,54,93,46,86,80,111,115,0,0,0,0,80,73,76,79,84,87,73,78,71,83,0,0,0,0,0,0,66,0,0,0,0,0,0,0,124,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,76,111,97,100,105,110,103,32,101,120,116,101,114,110,97,108,32,115,111,117,114,99,101,32,102,114,111,109,32,34,37,115,34,46,10,0,0,99,111,110,116,101,120,116,91,55,93,46,105,110,100,101,120,0,0,0,0,0,0,0,0,79,66,74,91,53,54,93,46,72,80,111,115,0,0,0,0,91,82,80,78,71,93,58,32,69,114,114,111,114,32,105,110,32,108,105,110,101,32,37,100,46,10,0,0,0,0,0,0,79,66,74,91,53,53,93,46,83,105,122,101,0,0,0,0,102,117,108,108,115,99,114,101,101,110,0,0,0,0,0,0,100,101,108,0,0,0,0,0,79,66,74,91,53,53,93,46,80,97,108,101,116,116,101,0,79,66,74,91,53,53,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,103,108,69,71,76,73,109,97,103,101,84,97,114,103,101,116,82,101,110,100,101,114,98,117,102,102,101,114,83,116,111,114,97,103,101,79,69,83,0,0,79,66,74,91,53,53,93,46,78,97,109,101,0,0,0,0,79,66,74,91,53,53,93,46,86,70,108,105,112,0,0,0,115,111,117,110,100,95,109,111,100,101,0,0,0,0,0,0,79,66,74,91,53,53,93,46,72,70,108,105,112,0,0,0,79,66,74,91,53,53,93,46,86,80,111,115,0,0,0,0,79,66,74,91,53,53,93,46,72,80,111,115,0,0,0,0,79,66,74,91,53,52,93,46,83,105,122,101,0,0,0,0,78,66,65,32,74,65,77,0,103,108,115,108,112,0,0,0,65,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,71,111,116,32,111,117,116,115,99,97,108,101,95,121,32,97,116,116,114,58,32,37,46,49,102,10,0,0,0,99,111,110,116,101,120,116,91,54,93,46,105,110,118,101,114,116,0,0,0,0,0,0,0,79,66,74,91,53,52,93,46,80,97,108,101,116,116,101,0,82,101,116,114,111,65,114,99,104,58,32,37,115,10,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,67,111,117,108,100,110,39,116,32,105,110,105,116,32,102,111,110,116,32,114,101,110,100,101,114,101,114,46,10,0,0,0,0,0,0,0,79,66,74,91,53,52,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,115,97,118,101,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,80,69,82,70,79,82,77,65,78,67,69,95,76,69,86,69,76,58,32,37,117,46,10,0,0,0,0,0,0,105,110,115,101,114,116,0,0,79,66,74,91,53,52,93,46,78,97,109,101,0,0,0,0,79,66,74,91,53,52,93,46,86,70,108,105,112,0,0,0,79,66,74,91,53,52,93,46,72,70,108,105,112,0,0,0,79,66,74,91,53,52,93,46,86,80,111,115,0,0,0,0,99,117,114,114,101,110,116,95,114,101,115,111,108,117,116,105,111,110,95,105,100,0,0,0,79,66,74,91,53,52,93,46,72,80,111,115,0,0,0,0,79,66,74,91,53,51,93,46,83,105,122,101,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,99,114,101,97,116,101,32,70,66,79,32,116,97,114,103,101,116,115,46,32,87,105,108,108,32,99,111,110,116,105,110,117,101,32,119,105,116,104,111,117,116,32,70,66,79,46,10,0,0,79,66,74,91,53,51,93,46,80,97,108,101,116,116,101,0,119,0,0,0,0,0,0,0,79,66,74,91,53,51,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,65,75,76,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,71,111,116,32,111,117,116,115,99,97,108,101,95,120,32,97,116,116,114,58,32,37,46,49,102,10,0,0,0,99,111,110,116,101,120,116,91,54,93,46,105,110,100,101,120,0,0,0,0,0,0,0,0,79,66,74,91,53,51,93,46,78,97,109,101,0,0,0,0,79,66,74,91,53,51,93,46,86,70,108,105,112,0,0,0,104,101,108,112,0,0,0,0,116,97,98,0,0,0,0,0,79,66,74,91,53,51,93,46,72,70,108,105,112,0,0,0,79,66,74,91,53,51,93,46,86,80,111,115,0,0,0,0,79,66,74,91,53,51,93,46,72,80,111,115,0,0,0,0,79,66,74,91,53,50,93,46,83,105,122,101,0,0,0,0,115,111,102,116,95,102,105,108,116,101,114,95,105,110,100,101,120,0,0,0,0,0,0,0,79,66,74,91,53,50,93,46,80,97,108,101,116,116,101,0,79,66,74,91,53,50,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,79,66,74,91,53,50,93,46,78,97,109,101,0,0,0,0,79,66,74,91,53,50,93,46,86,70,108,105,112,0,0,0,83,69,67,82,69,84,32,79,70,32,69,86,69,82,77,79,82,69,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,71,111,116,32,111,117,116,115,99,97,108,101,32,97,116,116,114,58,32,37,46,49,102,10,0,0,0,0,0,99,111,110,116,101,120,116,91,53,93,46,105,110,118,101,114,116,0,0,0,0,0,0,0,79,66,74,91,53,50,93,46,72,70,108,105,112,0,0,0,79,66,74,91,53,50,93,46,86,80,111,115,0,0,0,0,109,101,110,117,0,0,0,0,107,112,95,101,110,116,101,114,0,0,0,0,0,0,0,0,79,66,74,91,53,50,93,46,72,80,111,115,0,0,0,0,79,66,74,91,53,49,93,46,83,105,122,101,0,0,0,0,79,66,74,91,53,49,93,46,80,97,108,101,116,116,101,0,79,66,74,91,53,49,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,102,108,105,99,107,101,114,95,102,105,108,116,101,114,95,105,110,100,101,120,0,0,0,0,79,66,74,91,53,49,93,46,78,97,109,101,0,0,0,0,118,105,100,101,111,95,120,115,99,97,108,101,0,0,0,0,79,66,74,91,53,49,93,46,86,70,108,105,112,0,0,0,99,103,112,0,0,0,0,0,79,66,74,91,53,49,93,46,72,70,108,105,112,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,105,110,99,32,114,101,115,97,109,112,108,101,114,32,91,67,93,10,0,0,79,66,74,91,53,49,93,46,86,80,111,115,0,0,0,0,65,82,51,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,71,111,116,32,115,105,122,101,95,121,32,97,116,116,114,58,32,37,117,10,0,99,111,110,116,101,120,116,91,53,93,46,105,110,100,101,120,0,0,0,0,0,0,0,0,79,66,74,91,53,49,93,46,72,80,111,115,0,0,0,0,46,112,110,103,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,99,114,101,97,116,101,32,114,101,110,100,101,114,105,110,103,32,98,97,99,107,101,110,100,58,32,37,115,46,10,0,0,0,79,66,74,91,53,48,93,46,83,105,122,101,0,0,0,0,83,101,112,32,49,48,32,50,48,49,51,0,0,0,0,0,101,110,116,101,114,0,0,0,79,66,74,91,53,48,93,46,80,97,108,101,116,116,101,0,79,66,74,91,53,48,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,86,105,100,101,111,32,64,32,102,117,108,108,115,99,114,101,101,110,10,0,0,79,66,74,91,53,48,93,46,78,97,109,101,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,79,118,101,114,108,97,121,32,105,110,116,101,114,102,97,99,101,32,105,115,32,110,111,116,32,112,114,101,115,101,110,116,32,105,110,32,118,105,100,101,111,32,100,114,105,118,101,114,46,10,0,79,66,74,91,53,48,93,46,86,70,108,105,112,0,0,0,102,108,105,99,107,101,114,95,102,105,108,116,101,114,95,101,110,97,98,108,101,0,0,0,79,66,74,91,53,48,93,46,72,70,108,105,112,0,0,0,79,66,74,91,53,48,93,46,86,80,111,115,0,0,0,0,114,119,101,98,97,117,100,105,111,0,0,0,0,0,0,0,101,120,101,0,0,0,0,0,79,66,74,91,53,48,93,46,72,80,111,115,0,0,0,0,79,66,74,91,52,57,93,46,83,105,122,101,0,0,0,0,83,85,80,69,82,32,77,65,82,73,79,32,75,65,82,84,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,71,111,116,32,115,105,122,101,95,120,32,97,116,116,114,58,32,37,117,10,0,99,111,110,116,101,120,116,91,52,93,46,105,110,118,101,114,116,0,0,0,0,0,0,0,79,66,74,91,52,57,93,46,80,97,108,101,116,116,101,0,79,66,74,91,52,57,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,66,117,105,108,116,58,32,37,115,10,0,0,0,0,0,0,82,71,85,73,32,109,101,110,117,32,116,111,103,103,108,101,0,0,0,0,0,0,0,0,79,66,74,91,52,57,93,46,78,97,109,101,0,0,0,0,79,66,74,91,52,57,93,46,86,70,108,105,112,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,116,97,116,101,32,115,105,122,101,58,32,37,117,32,98,121,116,101,115,46,10,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,97,110,110,111,116,32,102,105,110,100,32,34,115,104,97,100,101,114,115,34,32,112,97,114,97,109,46,10,0,0,0,0,0,0,79,66,74,91,52,57,93,46,72,70,108,105,112,0,0,0,79,117,116,32,89,32,61,32,37,100,32,61,62,32,73,110,32,89,32,61,32,37,100,10,0,0,0,0,0,0,0,0,79,66,74,91,52,57,93,46,86,80,111,115,0,0,0,0,115,111,102,116,95,102,105,108,116,101,114,95,101,110,97,98,108,101,0,0,0,0,0,0,79,66,74,91,52,57,93,46,72,80,111,115,0,0,0,0,79,66,74,91,52,56,93,46,83,105,122,101,0,0,0,0,79,66,74,91,52,56,93,46,80,97,108,101,116,116,101,0,79,66,74,91,52,56,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,83,101,108,101,99,116,0,0,77,111,117,115,101,37,100,32,117,115,101,100,32,109,111,114,101,32,116,104,97,110,32,111,110,99,101,33,32,68,105,115,97,98,108,105,110,103,32,101,120,116,114,97,32,105,110,115,116,97,110,99,101,115,0,0,68,80,97,100,32,69,109,117,108,97,116,105,111,110,0,0,69,81,85,73,78,79,88,0,82,101,116,114,111,65,114,99,104,58,32,71,111,116,32,115,105,122,101,32,97,116,116,114,58,32,37,117,10,0,0,0,99,111,110,116,101,120,116,91,52,93,46,105,110,100,101,120,0,0,0,0,0,0,0,0,79,66,74,91,52,56,93,46,78,97,109,101,0,0,0,0,79,66,74,91,52,56,93,46,86,70,108,105,112,0,0,0,52,46,50,46,49,32,67,111,109,112,97,116,105,98,108,101,32,67,108,97,110,103,32,51,46,50,32,40,116,97,103,115,47,82,69,76,69,65,83,69,95,51,50,47,102,105,110,97,108,41,0,0,0,0,0,0,79,66,74,91,52,56,93,46,72,70,108,105,112,0,0,0,83,117,112,101,114,115,99,111,112,101,32,70,105,114,101,0,5,5,4,0,0,0,0,0,79,66,74,91,52,56,93,46,86,80,111,115,0,0,0,0,103,108,67,111,109,112,114,101,115,115,101,100,84,101,120,83,117,98,73,109,97,103,101,51,68,79,69,83,0,0,0,0,105,110,32,118,101,99,50,32,84,101,120,67,111,111,114,100,59,10,105,110,32,118,101,99,50,32,86,101,114,116,101,120,67,111,111,114,100,59,10,105,110,32,118,101,99,52,32,67,111,108,111,114,59,10,117,110,105,102,111,114,109,32,109,97,116,52,32,77,86,80,77,97,116,114,105,120,59,10,111,117,116,32,118,101,99,50,32,116,101,120,95,99,111,111,114,100,59,10,111,117,116,32,118,101,99,52,32,99,111,108,111,114,59,10,118,111,105,100,32,109,97,105,110,40,41,32,123,10,32,32,32,103,108,95,80,111,115,105,116,105,111,110,32,61,32,77,86,80,77,97,116,114,105,120,32,42,32,118,101,99,52,40,86,101,114,116,101,120,67,111,111,114,100,44,32,48,46,48,44,32,49,46,48,41,59,10,32,32,32,116,101,120,95,99,111,111,114,100,32,61,32,84,101,120,67,111,111,114,100,59,10,32,32,32,99,111,108,111,114,32,61,32,67,111,108,111,114,59,10,125,0,0,79,66,74,91,52,56,93,46,72,80,111,115,0,0,0,0,101,120,105,115,116,115,0,0,79,66,74,91,52,55,93,46,83,105,122,101,0,0,0,0,105,110,102,111,95,109,115,103,95,101,110,97,98,108,101,0,79,66,74,91,52,55,93,46,80,97,108,101,116,116,101,0,77,69,78,85,32,37,115,0,37,117,120,0,0,0,0,0,79,66,74,91,52,55,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,99,111,110,102,105,103,32,102,105,108,101,58,32,37,115,46,10,0,0,0,79,66,74,91,52,55,93,46,78,97,109,101,0,0,0,0,112,114,101,102,105,120,0,0,79,66,74,91,52,55,93,46,86,70,108,105,112,0,0,0,70,45,90,69,82,79,0,0,68,101,118,105,99,101,32,84,121,112,101,0,0,0,0,0,111,118,101,114,108,97,121,37,117,95,114,101,99,116,0,0,82,101,116,114,111,65,114,99,104,58,32,71,111,116,32,115,99,97,108,101,95,121,32,97,116,116,114,58,32,37,46,49,102,10,0,0,0,0,0,0,99,111,110,116,101,120,116,91,51,93,46,105,110,118,101,114,116,0,0,0,0,0,0,0,37,117,59,0,0,0,0,0,79,66,74,91,52,55,93,46,72,70,108,105,112,0,0,0,60,63,120,109,108,0,0,0,83,78,68,0,0,0,0,0,79,66,74,91,52,55,93,46,86,80,111,115,0,0,0,0,67,108,97,110,103,47,76,76,86,77,32,40,37,115,41,32,37,117,45,98,105,116,10,0,100,97,116,97,98,97,115,101,0,0,0,0,0,0,0,0,71,114,97,98,32,109,111,117,115,101,32,116,111,103,103,108,101,0,0,0,0,0,0,0,79,66,74,91,52,55,93,46,72,80,111,115,0,0,0,0,79,66,74,91,52,54,93,46,83,105,122,101,0,0,0,0,99,111,109,112,97,116,47,99,111,109,112,97,116,46,99,0,79,66,74,91,52,54,93,46,80,97,108,101,116,116,101,0,79,66,74,91,52,54,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,116,114,105,112,108,101,95,98,117,102,102,101,114,105,110,103,95,101,110,97,98,108,101,0,79,66,74,91,52,54,93,46,78,97,109,101,0,0,0,0,35,33,115,57,120,115,110,112,0,0,0,0,0,0,0,0,79,66,74,91,52,54,93,46,86,70,108,105,112,0,0,0,79,66,74,91,52,54,93,46,72,70,108,105,112,0,0,0,79,66,74,91,52,54,93,46,86,80,111,115,0,0,0,0,65,55,82,0,0,0,0,0,68,101,118,105,99,101,0,0,82,101,116,114,111,65,114,99,104,58,32,71,111,116,32,115,99,97,108,101,95,120,32,97,116,116,114,58,32,37,46,49,102,10,0,0,0,0,0,0,99,111,110,116,101,120,116,91,51,93,46,105,110,100,101,120,0,0,0,0,0,0,0,0,79,66,74,91,52,54,93,46,72,80,111,115,0,0,0,0,79,66,74,91,52,53,93,46,83,105,122,101,0,0,0,0,89,85,89,85,32,78,79,32,81,85,73,90,32,68,69,32,71,79,33,71,79,33,0,0,10,67,111,109,112,105,108,101,114,58,32,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,73,110,105,116,105,110,103,32,114,101,119,105,110,100,32,98,117,102,102,101,114,32,119,105,116,104,32,115,105,122,101,58,32,37,117,32,77,66,10,0,0,0,0,0,0,79,66,74,91,52,53,93,46,80,97,108,101,116,116,101,0,79,66,74,91,52,53,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,79,66,74,91,52,53,93,46,78,97,109,101,0,0,0,0,79,66,74,91,52,53,93,46,86,70,108,105,112,0,0,0,103,97,109,109,97,95,99,111,114,114,101,99,116,105,111,110,0,0,0,0,0,0,0,0,79,66,74,91,52,53,93,46,72,70,108,105,112,0,0,0,79,66,74,91,52,53,93,46,86,80,111,115,0,0,0,0,79,66,74,91,52,53,93,46,72,80,111,115,0,0,0,0,79,66,74,91,52,52,93,46,83,105,122,101,0,0,0,0,98,109,112,0,0,0,0,0,77,69,71,65,77,65,78,32,88,0,0,0,0,0,0,0,80,108,97,121,101,114,0,0,82,101,116,114,111,65,114,99,104,58,32,71,111,116,32,115,99,97,108,101,32,97,116,116,114,58,32,37,46,49,102,10,0,0,0,0,0,0,0,0,99,111,110,116,101,120,116,91,50,93,46,105,110,118,101,114,116,0,0,0,0,0,0,0,79,66,74,91,52,52,93,46,80,97,108,101,116,116,101,0,79,66,74,91,52,52,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,82,101,116,114,111,65,114,99,104,32,105,115,32,99,111,109,112,105,108,101,100,32,97,103,97,105,110,115,116,32,97,32,100,105,102,102,101,114,101,110,116,32,118,101,114,115,105,111,110,32,111,102,32,108,105,98,114,101,116,114,111,32,116,104,97,110,32,116,104,105,115,32,108,105,98,114,101,116,114,111,32,105,109,112,108,101,109,101,110,116,97,116,105,111,110,46,10,0,0,0,68,105,115,107,32,110,101,120,116,0,0,0,0,0,0,0,79,66,74,91,52,52,93,46,78,97,109,101,0,0,0,0,79,66,74,91,52,52,93,46,86,70,108,105,112,0,0,0,79,66,74,91,52,52,93,46,72,70,108,105,112,0,0,0,79,66,74,91,52,52,93,46,86,80,111,115,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,97,118,105,110,103,32,99,111,110,102,105,103,32,97,116,32,112,97,116,104,58,32,34,37,115,34,10,0,79,66,74,91,52,52,93,46,72,80,111,115,0,0,0,0,85,112,32,68,45,112,97,100,0,0,0,0,0,0,0,0,79,66,74,91,52,51,93,46,83,105,122,101,0,0,0,0,79,66,74,91,52,51,93,46,80,97,108,101,116,116,101,0,79,66,74,91,52,51,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,65,84,86,69,0,0,0,0,79,118,101,114,108,97,121,32,83,99,97,108,101,0,0,0,82,101,116,114,111,65,114,99,104,58,32,71,111,116,32,102,114,97,109,101,32,99,111,117,110,116,32,109,111,100,32,97,116,116,114,58,32,37,117,10,0,0,0,0,0,0,0,0,99,111,110,116,101,120,116,91,50,93,46,105,110,100,101,120,0,0,0,0,0,0,0,0,79,66,74,91,52,51,93,46,78,97,109,101,0,0,0,0,79,66,74,91,52,51,93,46,86,70,108,105,112,0,0,0,82,101,116,114,111,65,114,99,104,58,32,67,111,109,112,105,108,101,100,32,97,103,97,105,110,115,116,32,65,80,73,58,32,37,117,10,0,0,0,0,79,66,74,91,52,51,93,46,72,70,108,105,112,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,85,115,105,110,103,32,82,88,77,76,32,97,115,32,100,114,111,112,32,105,110,32,102,111,114,32,108,105,98,120,109,108,50,46,32,66,101,104,97,118,105,111,114,32,109,105,103,104,116,32,98,101,32,118,101,114,121,32,98,117,103,103,121,46,10,0,0,0,79,66,74,91,52,51,93,46,86,80,111,115,0,0,0,0,79,66,74,91,52,51,93,46,72,80,111,115,0,0,0,0,79,66,74,91,52,50,93,46,83,105,122,101,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,115,121,115,116,101,109,95,100,105,114,101,99,116,111,114,121,32,105,115,32,110,111,116,32,115,101,116,32,105,110,32,99,111,110,102,105,103,46,32,65,115,115,117,109,105,110,103,32,115,121,115,116,101,109,32,100,105,114,101,99,116,111,114,121,32,105,115,32,115,97,109,101,32,102,111,108,100,101,114,32,97,115,32,103,97,109,101,58,32,34,37,115,34,46,10,0,0,0,0,0,79,66,74,91,52,50,93,46,80,97,108,101,116,116,101,0,79,66,74,91,52,50,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,79,66,74,91,52,50,93,46,78,97,109,101,0,0,0,0,79,66,74,91,52,50,93,46,86,70,108,105,112,0,0,0,65,75,85,77,65,74,79,32,68,82,65,67,85,76,65,0,79,118,101,114,108,97,121,32,79,112,97,99,105,116,121,0,116,114,117,101,0,0,0,0,99,111,110,116,101,120,116,91,49,93,46,105,110,118,101,114,116,0,0,0,0,0,0,0,79,66,74,91,52,50,93,46,72,70,108,105,112,0,0,0,79,66,74,91,52,50,93,46,86,80,111,115,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,86,101,114,115,105,111,110,32,111,102,32,108,105,98,114,101,116,114,111,32,65,80,73,58,32,37,117,10,0,82,101,116,114,111,65,114,99,104,58,32,69,110,118,105,114,111,110,32,83,72,85,84,68,79,87,78,46,10,0,0,0,68,105,115,107,32,101,106,101,99,116,32,116,111,103,103,108,101,0,0,0,0,0,0,0,79,66,74,91,52,50,93,46,72,80,111,115,0,0,0,0,79,66,74,91,52,49,93,46,83,105,122,101,0,0,0,0,79,66,74,91,52,49,93,46,80,97,108,101,116,116,101,0,79,66,74,91,52,49,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,115,121,115,116,101,109,95,100,105,114,101,99,116,111,114,121,0,0,0,0,0,0,0,0,79,66,74,91,52,49,93,46,78,97,109,101,0,0,0,0,79,66,74,91,52,49,93,46,86,70,108,105,112,0,0,0,79,66,74,91,52,49,93,46,72,70,108,105,112,0,0,0,79,66,74,91,52,49,93,46,86,80,111,115,0,0,0,0,83,85,80,69,82,32,67,65,83,84,76,69,86,65,78,73,65,32,52,0,0,0,0,0,79,118,101,114,108,97,121,32,80,114,101,115,101,116,0,0,102,108,111,97,116,95,102,114,97,109,101,98,117,102,102,101,114,0,0,0,0,0,0,0,99,111,110,116,101,120,116,91,49,93,46,105,110,100,101,120,0,0,0,0,0,0,0,0,79,66,74,91,52,49,93,46,72,80,111,115,0,0,0,0,79,66,74,91,52,48,93,46,83,105,122,101,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,70,111,117,110,100,32,108,97,115,116,32,115,116,97,116,101,32,115,108,111,116,58,32,35,37,117,10,0,0,79,66,74,91,52,48,93,46,80,97,108,101,116,116,101,0,79,66,74,91,52,48,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,79,66,74,91,52,48,93,46,78,97,109,101,0,0,0,0,79,66,74,91,52,48,93,46,86,70,108,105,112,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,115,97,118,101,115,116,97,116,101,95,100,105,114,101,99,116,111,114,121,32,105,115,32,110,111,116,32,97,32,100,105,114,101,99,116,111,114,121,44,32,105,103,110,111,114,105,110,103,32,46,46,46,10,0,0,0,0,0,0,0,79,66,74,91,52,48,93,46,72,70,108,105,112,0,0,0,79,66,74,91,52,48,93,46,86,80,111,115,0,0,0,0,79,66,74,91,52,48,93,46,72,80,111,115,0,0,0,0,79,66,74,91,51,57,93,46,83,105,122,101,0,0,0,0,84,46,77,46,78,46,84,46,53,0,0,0,0,0,0,0,83,121,115,116,101,109,32,68,105,114,101,99,116,111,114,121,0,0,0,0,0,0,0,0,102,114,97,109,101,95,99,111,117,110,116,95,109,111,100,0,99,111,110,116,101,120,116,91,48,93,46,105,110,118,101,114,116,0,0,0,0,0,0,0,79,66,74,91,51,57,93,46,80,97,108,101,116,116,101,0,79,66,74,91,51,57,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,65,117,116,111,45,108,111,97,100,105,110,103,32,115,97,118,101,115,116,97,116,101,32,102,114,111,109,32,34,37,115,34,32,37,115,46,0,0,0,0,79,118,101,114,108,97,121,32,110,101,120,116,0,0,0,0,79,66,74,91,51,57,93,46,78,97,109,101,0,0,0,0,79,66,74,91,51,57,93,46,86,70,108,105,112,0,0,0,79,66,74,91,51,57,93,46,72,70,108,105,112,0,0,0,79,66,74,91,51,57,93,46,86,80,111,115,0,0,0,0,46,115,116,97,116,101,0,0,79,66,74,91,51,57,93,46,72,80,111,115,0,0,0,0,37,115,58,37,48,52,100,10,0,0,0,0,0,0,0,0,61,61,61,32,67,111,110,102,105,103,32,101,110,100,32,61,61,61,10,0,0,0,0,0,79,66,74,91,51,56,93,46,83,105,122,101,0,0,0,0,79,66,74,91,51,56,93,46,80,97,108,101,116,116,101,0,59,32,0,0,0,0,0,0,79,66,74,91,51,56,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,84,46,77,46,78,46,84,46,32,84,70,0,0,0,0,0,79,118,101,114,108,97,121,32,68,105,114,101,99,116,111,114,121,0,0,0,0,0,0,0,111,117,116,115,99,97,108,101,95,121,0,0,0,0,0,0,99,111,110,116,101,120,116,91,48,93,46,105,110,100,101,120,0,0,0,0,0,0,0,0,79,66,74,91,51,56,93,46,78,97,109,101,0,0,0,0,79,66,74,91,51,56,93,46,86,70,108,105,112,0,0,0,114,119,101,98,105,110,112,117,116,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,70,111,117,110,100,32,97,117,116,111,32,115,97,118,101,115,116,97,116,101,32,105,110,58,32,37,115,10,0,79,66,74,91,51,56,93,46,72,70,108,105,112,0,0,0,79,66,74,91,51,56,93,46,86,80,111,115,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,86,105,100,101,111,32,64,32,37,117,120,37,117,10,0,0,0,0,0,0,0,79,66,74,91,51,56,93,46,72,80,111,115,0,0,0,0,79,66,74,91,51,55,93,46,83,105,122,101,0,0,0,0,115,97,118,101,115,116,97,116,101,95,100,105,114,101,99,116,111,114,121,0,0,0,0,0,79,66,74,91,51,55,93,46,80,97,108,101,116,116,101,0,79,66,74,91,51,55,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,46,37,115,0,0,0,0,0,79,66,74,91,51,55,93,46,78,97,109,101,0,0,0,0,79,66,74,91,51,55,93,46,86,70,108,105,112,0,0,0,84,46,77,46,72,46,84,32,84,70,0,0,0,0,0,0,83,97,118,101,102,105,108,101,32,68,105,114,101,99,116,111,114,121,0,0,0,0,0,0,111,117,116,115,99,97,108,101,95,120,0,0,0,0,0,0,100,101,99,111,109,112,95,98,117,102,102,101,114,95,108,101,110,103,116,104,0,0,0,0,79,66,74,91,51,55,93,46,72,70,108,105,112,0,0,0,79,66,74,91,51,55,93,46,86,80,111,115,0,0,0,0,86,111,108,117,109,101,32,45,0,0,0,0,0,0,0,0,79,66,74,91,51,55,93,46,72,80,111,115,0,0,0,0,79,66,74,91,51,54,93,46,83,105,122,101,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,115,116,97,116,101,32,102,114,111,109,32,34,37,115,34,46,10,0,0,0,79,66,74,91,51,54,93,46,80,97,108,101,116,116,101,0,79,66,74,91,51,54,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,87,65,82,78,93,32,58,58,32,115,97,118,101,102,105,108,101,95,100,105,114,101,99,116,111,114,121,32,105,115,32,110,111,116,32,97,32,100,105,114,101,99,116,111,114,121,44,32,105,103,110,111,114,105,110,103,32,46,46,46,10,0,0,0,0,0,0,0,0,79,66,74,91,51,54,93,46,78,97,109,101,0,0,0,0,79,66,74,91,51,54,93,46,86,70,108,105,112,0,0,0,79,66,74,91,51,54,93,46,72,70,108,105,112,0,0,0,79,66,74,91,51,54,93,46,86,80,111,115,0,0,0,0,84,46,77,46,78,46,84,46,32,77,87,0,0,0,0,0,83,97,118,101,115,116,97,116,101,32,68,105,114,101,99,116,111,114,121,0,0,0,0,0,111,117,116,115,99,97,108,101,0,0,0,0,0,0,0,0,79,66,74,91,51,54,93,46,72,80,111,115,0,0,0,0,100,101,99,111,109,112,95,98,117,102,102,101,114,95,119,114,111,102,102,115,101,116,0,0,83,116,97,114,116,0,0,0,79,66,74,91,51,53,93,46,83,105,122,101,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,83,116,97,114,116,105,110,103,32,109,111,118,105,101,32,112,108,97,121,98,97,99,107,46,10,0,0,0,0,79,66,74,91,51,53,93,46,80,97,108,101,116,116,101,0,77,111,117,115,101,50,32,82,0,0,0,0,0,0,0,0,79,66,74,91,51,53,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,103,108,67,111,109,112,114,101,115,115,101,100,84,101,120,73,109,97,103,101,51,68,79,69,83,0,0,0,0,0,0,0,97,116,116,114,105,98,117,116,101,32,118,101,99,50,32,84,101,120,67,111,111,114,100,59,10,97,116,116,114,105,98,117,116,101,32,118,101,99,50,32,86,101,114,116,101,120,67,111,111,114,100,59,10,97,116,116,114,105,98,117,116,101,32,118,101,99,52,32,67,111,108,111,114,59,10,117,110,105,102,111,114,109,32,109,97,116,52,32,77,86,80,77,97,116,114,105,120,59,10,118,97,114,121,105,110,103,32,118,101,99,50,32,116,101,120,95,99,111,111,114,100,59,10,118,97,114,121,105,110,103,32,118,101,99,52,32,99,111,108,111,114,59,10,118,111,105,100,32,109,97,105,110,40,41,32,123,10,32,32,32,103,108,95,80,111,115,105,116,105,111,110,32,61,32,77,86,80,77,97,116,114,105,120,32,42,32,118,101,99,52,40,86,101,114,116,101,120,67,111,111,114,100,44,32,48,46,48,44,32,49,46,48,41,59,10,32,32,32,116,101,120,95,99,111,111,114,100,32,61,32,84,101,120,67,111,111,114,100,59,10,32,32,32,99,111,108,111,114,32,61,32,67,111,108,111,114,59,10,125,0,0,0,0,0,79,66,74,91,51,53,93,46,78,97,109,101,0,0,0,0,82,101,116,114,111,65,114,99,104,58,32,81,117,101,114,121,105,110,103,32,71,76,32,101,120,116,101,110,115,105,111,110,58,32,37,115,32,61,62,32,37,115,10,0,0,0,0,0,79,66,74,91,51,53,93,46,86,70,108,105,112,0,0,0,79,66,74,91,51,53,93,46,72,70,108,105,112,0,0,0,83,72,65,68,69,82,32,37,115,0,0,0,0,0,0,0,79,66,74,91,51,53,93,46,86,80,111,115,0,0,0,0,79,66,74,91,51,53,93,46,72,80,111,115,0,0,0,0,71,76,69,83,50,0,0,0,79,66,74,91,51,52,93,46,83,105,122,101,0,0,0,0,84,46,77,46,78,46,84,46,32,52,0,0,0,0,0,0,83,104,97,100,101,114,32,68,105,114,101,99,116,111,114,121,0,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,108,111,97,100,32,105,109,97,103,101,58,32,37,115,46,10,0,115,105,122,101,95,121,0,0,100,101,99,111,109,112,95,98,117,102,102,101,114,95,114,100,111,102,102,115,101,116,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,97,110,110,111,116,32,115,97,118,101,32,88,77,76,32,99,104,101,97,116,32,115,101,116,116,105,110,103,115,46,10,0,0,0,79,66,74,91,51,52,93,46,80,97,108,101,116,116,101,0,45,45,62,0,0,0,0,0,46,115,114,109,0,0,0,0,70,73,76,0,0,0,0,0,79,66,74,91,51,52,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,83,116,97,114,116,105,110,103,32,109,111,118,105,101,32,112,108,97,121,98,97,99,107,46,0,0,0,0,0,0,0,0,86,111,108,117,109,101,32,43,0,0,0,0,0,0,0,0,79,66,74,91,51,52,93,46,78,97,109,101,0,0,0,0,79,66,74,91,51,52,93,46,86,70,108,105,112,0,0,0,79,66,74,91,51,52,93,46,72,70,108,105,112,0,0,0,79,66,74,91,51,52,93,46,86,80,111,115,0,0,0,0,115,97,118,101,102,105,108,101,95,100,105,114,101,99,116,111,114,121,0,0,0,0,0,0,79,66,74,91,51,52,93,46,72,80,111,115,0,0,0,0,79,66,74,91,51,51,93,46,83,105,122,101,0,0,0,0,79,66,74,91,51,51,93,46,80,97,108,101,116,116,101,0,79,66,74,91,51,51,93,46,80,114,105,111,114,105,116,121,0,0,0,0,0,0,0,0,84,46,77,46,78,46,84,46,52,0,0,0,0,0,0,0,66,114,111,119,115,101,114,32,68,105,114,101,99,116,111,114,121,0,0,0,0,0,0,0,115,105,122,101,95,120,0,0,100,101,99,111,109,112,95,98,117,102,102,101,114,0,0,0,79,66,74,91,51,51,93,46,78,97,109,101,0,0,0,0,79,66,74,91,51,51,93,46,86,70,108,105,112,0,0,0,105,110,105,116,95,109,111,118,105,101,40,41,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,70,97,105,108,101,100,32,116,111,32,112,101,114,102,111,114,109,32,105,110,105,116,105,97,108,32,115,101,114,105,97,108,105,122,97,116,105,111,110,32,102,111,114,32,114,101,119,105,110,100,46,10,0,0,0,0,0,0,0,82,101,116,114,111,65,114,99,104,32,91,69,82,82,79,82,93,32,58,58,32,67,97,110,110,111,116,32,116,97,107,101,32,115,99,114,101,101,110,115,104,111,116,46,32,71,80,85,32,114,101,110,100,101,114,105,110,103,32,105,115,32,117,115,101,100,32,97,110,100,32,114,101,97,100,95,118,105,101,119,112,111,114,116,32,105,115,32,110,111,116,32,115,117,112,112,111,114,116,101,100,46,10,0,152,47,138,66,145,68,55,113,207,251,192,181,165,219,181,233,91,194,86,57,241,17,241,89,164,130,63,146,213,94,28,171,152,170,7,216,1,91,131,18,190,133,49,36,195,125,12,85,116,93,190,114,254,177,222,128,167,6,220,155,116,241,155,193,193,105,155,228,134,71,190,239,198,157,193,15,204,161,12,36,111,44,233,45,170,132,116,74,220,169,176,92,218,136,249,118,82,81,62,152,109,198,49,168,200,39,3,176,199,127,89,191,243,11,224,198,71,145,167,213,81,99,202,6,103,41,41,20,133,10,183,39,56,33,27,46,252,109,44,77,19,13,56,83,84,115,10,101,187,10,106,118,46,201,194,129,133,44,114,146,161,232,191,162,75,102,26,168,112,139,75,194,163,81,108,199,25,232,146,209,36,6,153,214,133,53,14,244,112,160,106,16,22,193,164,25,8,108,55,30,76,119,72,39,181,188,176,52,179,12,28,57,74,170,216,78,79,202,156,91,243,111,46,104,238,130,143,116,111,99,165,120,20,120,200,132,8,2,199,140,250,255,190,144,235,108,80,164,247,163,249,190,242,120,113,198,103,230,9,106,133,174,103,187,114,243,110,60,58,245,79,165,127,82,14,81,140,104,5,155,171,217,131,31,25,205,224,91,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,184,149,0,0,4,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,176,149,0,0,8,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,64,149,0,0,12,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,56,149,0,0,16,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,40,149,0,0,20,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,0,149,0,0,24,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,240,148,0,0,28,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,224,148,0,0,32,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,208,148,0,0,36,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,168,148,0,0,40,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,112,148,0,0,44,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,96,148,0,0,48,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,16,148,0,0,52,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,0,148,0,0,56,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,240,147,0,0,60,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,208,147,0,0,0,0,0,0,0,0,0,0,16,0,0,0,1,0,0,0,6,0,15,39,128,38,1,0,16,0,0,0,0,0,0,0,16,0,0,0,1,0,0,0,6,0,15,39,152,36,1,0,32,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,64,35,1,0,33,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,32,34,1,0,34,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,16,33,1,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,232,171,0,0,4,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,48,169,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,120,166,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,72,164,0,0,2,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,168,161,0,0,3,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,120,160,0,0,4,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,200,157,0,0,5,0,0,0,0,0,0,0])
.concat([1,0,0,0,0,0,0,0,6,0,15,39,104,154,0,0,6,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,24,152,0,0,7,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,168,149,0,0,8,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,88,148,0,0,9,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,112,147,0,0,10,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,56,146,0,0,11,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,192,144,0,0,12,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,8,143,0,0,13,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,128,141,0,0,14,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,144,139,0,0,15,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,248,136,0,0,16,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,80,135,0,0,17,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,184,133,0,0,18,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,192,131,0,0,19,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,128,130,0,0,20,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,176,128,0,0,21,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,24,127,0,0,22,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,224,124,0,0,23,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,88,123,0,0,24,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,144,121,0,0,25,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,48,119,0,0,26,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,176,117,0,0,27,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,64,116,0,0,28,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,136,114,0,0,29,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,88,113,0,0,30,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,16,112,0,0,31,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,248,110,0,0,32,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,128,109,0,0,33,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,248,107,0,0,34,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,144,106,0,0,35,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,184,103,0,0,36,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,16,102,0,0,37,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,16,100,0,0,38,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,168,98,0,0,39,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,88,97,0,0,40,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,16,96,0,0,41,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,0,95,0,0,42,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,32,93,0,0,43,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,136,91,0,0,44,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,248,89,0,0,48,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,144,87,0,0,52,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,40,86,0,0,56,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,208,84,0,0,57,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,120,83,0,0,58,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,64,82,0,0,60,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,8,81,0,0,64,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,232,171,0,0,68,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,48,169,0,0,72,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,216,79,0,0,76,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,144,78,0,0,80,0,0,0,0,0,0,0,64,0,0,0,1,0,0,0,6,0,15,39,56,139,1,0,144,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,168,137,1,0,148,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,232,134,1,0,152,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,72,133,1,0,156,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,216,131,1,0,157,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,104,130,1,0,158,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,248,128,1,0,159,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,128,127,1,0,160,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,160,125,1,0,161,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,208,123,1,0,162,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,80,122,1,0,163,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,200,120,1,0,164,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,248,117,1,0,165,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,248,115,1,0,166,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,8,114,1,0,167,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,184,112,1,0,168,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,144,111,1,0,169,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,160,109,1,0,170,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,48,108,1,0,171,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,176,106,1,0,172,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,112,105,1,0,173,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,216,103,1,0,174,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,248,101,1,0,175,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,64,100,1,0,176,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,96,98,1,0,177,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,40,97,1,0,178,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,56,96,1,0,179,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,216,94,1,0,180,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,200,93,1,0,181,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,136,92,1,0,182,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,112,91,1,0,183,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,104,90,1,0,184,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,72,88,1,0,185,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,24,87,1,0,186,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,8,86,1,0,187,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,232,84,1,0,188,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,248,83,1,0,189,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,152,82,1,0,190,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,136,81,1,0,191,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,112,80,1,0,192,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,64,79,1,0,193,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,16,78,1,0,194,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,8,76,1,0,195,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,176,74,1,0,196,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,64,73,1,0,197,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,216,71,1,0,198,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,112,70,1,0,199,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,72,69,1,0,200,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,16,68,1,0,201,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,192,66,1,0,202,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,168,65,1,0,203,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,120,64,1,0,204,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,136,62,1,0,205,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,96,61,1,0,206,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,104,59,1,0,207,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,32,58,1,0,208,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,232,56,1,0,209,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,176,55,1,0,210,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,176,54,1,0,211,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,168,53,1,0,212,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,128,52,1,0,213,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,88,51,1,0,214,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,32,49,1,0,215,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,248,47,1,0,216,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,136,46,1,0,217,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,56,45,1,0,218,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,56,44,1,0,219,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,16,43,1,0,18,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,24,175,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,224,174,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,216,174,0,0,4,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,88,173,0,0,6,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,80,173,0,0,8,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,64,173,0,0,10,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,8,173,0,0,12,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,0,173,0,0,16,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,248,172,0,0,12,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,184,172,0,0,16,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,136,172,0,0,20,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,32,172,0,0,28,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,216,171,0,0,29,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,32,170,0,0,36,128,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,16,170,0,0,37,128,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,248,169,0,0,38,128,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,208,169,0,0,40,128,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,200,169,0,0,44,128,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,184,169,0,0,48,128,0,0,0,0,0,0,8,0,0,0,0,0,0,0,6,0,15,39,136,169,0,0,56,128,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,112,169,0,0,57,128,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,72,169,0,0,18,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,24,175,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,224,174,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,216,174,0,0,4,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,88,173,0,0,6,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,80,173,0,0,8,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,64,173,0,0,10,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,8,173,0,0,12,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,0,173,0,0,16,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,248,172,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,16,124,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,0,124,0,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,240,123,0,0,4,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,224,123,0,0,6,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,112,123,0,0,8,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,96,123,0,0,12,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,200,122,0,0,16,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,184,122,0,0,18,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,168,122,0,0,20,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,152,122,0,0,22,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,48,122,0,0,24,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,32,122,0,0,26,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,16,122,0,0,28,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,0,122,0,0,30,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,208,121,0,0,32,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,152,121,0,0,34,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,24,121,0,0,36,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,248,120,0,0,38,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,232,120,0,0,40,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,112,120,0,0,42,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,72,120,0,0,44,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,240,119,0,0,46,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,144,119,0,0,48,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,112,119,0,0,50,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,72,119,0,0,52,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,56,119,0,0,54,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,168,118,0,0,56,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,152,118,0,0,58,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,136,118,0,0,60,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,120,118,0,0,62,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,80,118,0,0,64,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,72,118,0,0,65,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,16,118,0,0,67,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,8,118,0,0,68,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,192,117,0,0,69,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,184,117,0,0,70,0,0,0,0,0,0,0,0,1,0,0,2,0,0,0,6,0,15,39,40,117,0,0,70,2,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,24,117,0,0,72,2,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,8,117,0,0,74,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,248,116,0,0,75,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,216,116,0,0,76,2,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,184,116,0,0,78,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,168,116,0,0,79,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,152,116,0,0,80,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,88,116,0,0,82,2,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,72,116,0,0,84,2,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,152,115,0,0,86,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,136,115,0,0,87,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,120,115,0,0,88,2,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,48,115,0,0,90,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,8,115,0,0,91,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,248,114,0,0,92,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,232,114,0,0,94,2,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,216,114,0,0,96,2,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,160,114,0,0,98,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,144,114,0,0,99,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,48,114,0,0,100,2,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,32,114,0,0,102,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,16,114,0,0,103,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,0,114,0,0,104,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,216,113,0,0,106,2,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,200,113,0,0,108,2,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,184,113,0,0,110,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,168,113,0,0,111,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,112,113,0,0,112,2,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,96,113,0,0,114,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,248,112,0,0,115,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,232,112,0,0,116,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,216,112,0,0,118,2,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,200,112,0,0,120,2,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,168,112,0,0,122,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,152,112,0,0,123,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,136,112,0,0,124,2,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,120,112,0,0,126,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,40,112,0,0,127,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,24,112,0,0,128,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,176,111,0,0,130,2,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,160,111,0,0,132,2,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,144,111,0,0,134,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,128,111,0,0,135,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,88,111,0,0,136,2,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,72,111,0,0,138,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,56,111,0,0,139,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,40,111,0,0,140,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,16,111,0,0,142,2,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,0,111,0,0,144,2,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,96,110,0,0,146,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,80,110,0,0,147,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,64,110,0,0,148,2,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,48,110,0,0,150,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,8,110,0,0,151,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,248,109,0,0,152,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,232,109,0,0,154,2,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,216,109,0,0,156,2,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,152,109,0,0,158,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,136,109,0,0,159,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,32,109,0,0,160,2,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,16,109,0,0,162,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,0,109,0,0,163,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,240,108,0,0,164,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,200,108,0,0,166,2,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,184,108,0,0,168,2,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,168,108,0,0,170,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,152,108,0,0,171,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,16,108,0,0,172,2,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,0,108,0,0,174,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,144,107,0,0,175,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,128,107,0,0,176,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,112,107,0,0,178,2,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,96,107,0,0,180,2,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,56,107,0,0,182,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,40,107,0,0,183,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,24,107,0,0,184,2,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,248,106,0,0,186,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,184,106,0,0,187,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,152,106,0,0,188,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,184,105,0,0,190,2,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,160,105,0,0,192,2,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,144,105,0,0,194,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,128,105,0,0,195,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,96,105,0,0,196,2,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,48,105,0,0,198,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,64,104,0,0,199,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,24,104,0,0,200,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,208,103,0,0,202,2,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,192,103,0,0,204,2,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,40,103,0,0,206,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,24,103,0,0,207,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,8,103,0,0,208,2,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,248,102,0,0,210,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,200,102,0,0,211,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,184,102,0,0,212,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,112,102,0,0,214,2,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,96,102,0,0,216,2,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,40,102,0,0,218,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,24,102,0,0,219,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,104,101,0,0,220,2,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,88,101,0,0,222,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,48,101,0,0,223,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,32,101,0,0,224,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,248,100,0,0,226,2,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,232,100,0,0,228,2,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,112,100,0,0,230,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,96,100,0,0,231,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,40,100,0,0,232,2,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,24,100,0,0,234,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,136,99,0,0,235,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,120,99,0,0,236,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,104,99,0,0,238,2,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,88,99,0,0,240,2,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,48,99,0,0,242,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,32,99,0,0,243,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,16,99,0,0,244,2,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,0,99,0,0,246,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,192,98,0,0,247,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,176,98,0,0,248,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,32,98,0,0,250,2,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,16,98,0,0,252,2,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,0,98,0,0,254,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,240,97,0,0,255,2,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,200,97,0,0,0,3,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,184,97,0,0,2,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,160,97,0,0,3,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,144,97,0,0,4,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,112,97,0,0,6,3,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,96,97,0,0,8,3,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,16,97,0,0,10,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,0,97,0,0,11,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,240,96,0,0,12,3,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,224,96,0,0,14,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,176,96,0,0,15,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,160,96,0,0,16,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,144,96,0,0,18,3,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,128,96,0,0,20,3,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,40,96,0,0,22,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,24,96,0,0,23,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,216,95,0,0,24,3,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,200,95,0,0,26,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,176,95,0,0,27,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,160,95,0,0,28,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,120,95,0,0,30,3,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,104,95,0,0,32,3,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,88,95,0,0,34,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,72,95,0,0,35,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,24,95,0,0,36,3,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,8,95,0,0,38,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,16,94,0,0,39,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,0,94,0,0,40,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,240,93,0,0,42,3,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,208,93,0,0,44,3,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,168,93,0,0,46,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,152,93,0,0,47,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,136,93,0,0,48,3,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,120,93,0,0,50,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,56,93,0,0,51,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,40,93,0,0,52,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,160,92,0,0,54,3,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,144,92,0,0,56,3,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,128,92,0,0,58,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,112,92,0,0,59,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,72,92,0,0,60,3,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,56,92,0,0,62,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,32,92,0,0,63,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,16,92,0,0,64,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,160,91,0,0,66,3,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,144,91,0,0,68,3,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,56,91,0,0,70,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,40,91,0,0,71,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,24,91,0,0,72,3,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,8,91,0,0,74,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,216,90,0,0,75,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,200,90,0,0,76,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,184,90,0,0,78,3,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,168,90,0,0,80,3,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,48,90,0,0,82,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,8,90,0,0,83,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,152,89,0,0,84,3,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,128,89,0,0,86,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,104,89,0,0,87,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,88,89,0,0,88,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,48,89,0,0,90,3,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,208,88,0,0,92,3,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,16,88,0,0,94,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,240,87,0,0,95,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,176,87,0,0,96,3,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,160,87,0,0,98,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,40,87,0,0,99,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,24,87,0,0,100,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,8,87,0,0,102,3,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,248,86,0,0,104,3,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,208,86,0,0,106,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,192,86,0,0,107,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,136,86,0,0,108,3,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,120,86,0,0,110,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,72,86,0,0,111,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,56,86,0,0,112,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,208,85,0,0,114,3,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,192,85,0,0,116,3,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,152,85,0,0,118,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,136,85,0,0,119,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,96,85,0,0,120,3,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,80,85,0,0,122,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,8,85,0,0,123,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,248,84,0,0,124,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,232,84,0,0,126,3,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,216,84,0,0,128,3,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,104,84,0,0,130,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,88,84,0,0,131,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,72,84,0,0,132,3,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,40,84,0,0,134,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,248,83,0,0,135,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,232,83,0,0,136,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,216,83,0,0,138,3,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,200,83,0,0,140,3,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,144,83,0,0,142,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,128,83,0,0,143,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,8,83,0,0,144,3,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,248,82,0,0,146,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,224,82,0,0,147,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,208,82,0,0,148,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,168,82,0,0,150,3,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,152,82,0,0,152,3,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,136,82,0,0,154,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,120,82,0,0,155,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,88,82,0,0,156,3,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,72,82,0,0,158,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,16,82,0,0,159,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,0,82,0,0,160,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,240,81,0,0,162,3,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,224,81,0,0,164,3,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,184,81,0,0,166,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,168,81,0,0,167,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,152,81,0,0,168,3,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,136,81,0,0,170,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,40,81,0,0,171,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,24,81,0,0,172,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,200,80,0,0,174,3,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,184,80,0,0])
.concat([176,3,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,168,80,0,0,178,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,152,80,0,0,179,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,112,80,0,0,180,3,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,96,80,0,0,182,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,72,80,0,0,183,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,56,80,0,0,184,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,248,79,0,0,186,3,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,232,79,0,0,188,3,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,152,79,0,0,190,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,136,79,0,0,191,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,120,79,0,0,192,3,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,104,79,0,0,194,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,56,79,0,0,195,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,40,79,0,0,196,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,24,79,0,0,198,3,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,8,79,0,0,200,3,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,176,78,0,0,202,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,160,78,0,0,203,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,24,78,0,0,204,3,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,8,78,0,0,206,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,240,77,0,0,207,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,224,77,0,0,208,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,184,77,0,0,210,3,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,168,77,0,0,212,3,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,152,77,0,0,214,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,136,77,0,0,215,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,88,139,1,0,216,3,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,72,139,1,0,218,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,240,138,1,0,219,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,224,138,1,0,220,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,208,138,1,0,222,3,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,192,138,1,0,224,3,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,152,138,1,0,226,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,136,138,1,0,227,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,120,138,1,0,228,3,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,104,138,1,0,230,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,32,138,1,0,231,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,248,137,1,0,232,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,56,137,1,0,234,3,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,32,137,1,0,236,3,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,16,137,1,0,238,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,240,136,1,0,239,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,224,136,1,0,240,3,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,160,136,1,0,242,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,96,135,1,0,243,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,64,135,1,0,244,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,8,135,1,0,246,3,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,216,134,1,0,248,3,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,144,134,1,0,250,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,128,134,1,0,251,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,112,134,1,0,252,3,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,96,134,1,0,254,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,248,133,1,0,255,3,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,232,133,1,0,0,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,160,133,1,0,2,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,144,133,1,0,4,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,112,133,1,0,6,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,96,133,1,0,7,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,0,133,1,0,8,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,240,132,1,0,10,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,208,132,1,0,11,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,192,132,1,0,12,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,152,132,1,0,14,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,136,132,1,0,16,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,88,132,1,0,18,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,72,132,1,0,19,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,0,132,1,0,20,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,240,131,1,0,22,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,136,131,1,0,23,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,112,131,1,0,24,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,96,131,1,0,26,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,40,131,1,0,28,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,16,131,1,0,30,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,0,131,1,0,31,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,240,130,1,0,32,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,224,130,1,0,34,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,144,130,1,0,35,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,128,130,1,0,36,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,32,130,1,0,38,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,16,130,1,0,40,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,0,130,1,0,42,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,240,129,1,0,43,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,144,129,1,0,44,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,128,129,1,0,46,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,104,129,1,0,47,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,88,129,1,0,48,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,32,129,1,0,50,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,16,129,1,0,52,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,168,128,1,0,54,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,152,128,1,0,55,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,136,128,1,0,56,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,120,128,1,0,58,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,72,128,1,0,59,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,56,128,1,0,60,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,40,128,1,0,62,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,24,128,1,0,64,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,168,127,1,0,66,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,152,127,1,0,67,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,72,127,1,0,68,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,56,127,1,0,70,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,32,127,1,0,71,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,16,127,1,0,72,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,136,126,1,0,74,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,120,126,1,0,76,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,104,126,1,0,78,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,0,126,1,0,79,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,200,125,1,0,80,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,184,125,1,0,82,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,64,125,1,0,83,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,48,125,1,0,84,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,32,125,1,0,86,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,0,125,1,0,88,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,200,124,1,0,90,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,184,124,1,0,91,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,168,124,1,0,92,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,152,124,1,0,94,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,248,123,1,0,95,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,232,123,1,0,96,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,120,123,1,0,98,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,104,123,1,0,100,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,88,123,1,0,102,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,72,123,1,0,103,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,32,123,1,0,104,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,16,123,1,0,106,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,248,122,1,0,107,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,232,122,1,0,108,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,120,122,1,0,110,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,104,122,1,0,112,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,8,122,1,0,114,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,248,121,1,0,115,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,232,121,1,0,116,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,200,121,1,0,118,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,152,121,1,0,119,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,136,121,1,0,120,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,104,121,1,0,122,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,88,121,1,0,124,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,8,121,1,0,126,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,232,120,1,0,127,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,104,120,1,0,128,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,80,120,1,0,130,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,0,120,1,0,131,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,224,119,1,0,132,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,192,119,1,0,134,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,168,119,1,0,136,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,144,118,1,0,138,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,104,118,1,0,139,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,32,118,1,0,140,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,16,118,1,0,142,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,104,117,1,0,143,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,88,117,1,0,144,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,72,117,1,0,146,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,56,117,1,0,148,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,16,117,1,0,150,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,224,116,1,0,151,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,112,116,1,0,152,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,96,116,1,0,154,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,32,116,1,0,155,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,16,116,1,0,156,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,176,115,1,0,158,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,160,115,1,0,160,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,120,115,1,0,162,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,104,115,1,0,163,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,64,115,1,0,164,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,232,114,1,0,166,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,176,114,1,0,167,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,160,114,1,0,168,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,120,114,1,0,170,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,32,114,1,0,172,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,208,113,1,0,174,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,160,113,1,0,175,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,136,113,1,0,176,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,104,113,1,0,178,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,56,113,1,0,179,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,40,113,1,0,180,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,24,113,1,0,182,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,8,113,1,0,184,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,224,112,1,0,186,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,208,112,1,0,187,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,104,112,1,0,188,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,88,112,1,0,190,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,64,112,1,0,191,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,48,112,1,0,192,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,8,112,1,0,194,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,248,111,1,0,196,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,232,111,1,0,198,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,216,111,1,0,199,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,184,111,1,0,200,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,168,111,1,0,202,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,72,111,1,0,203,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,48,111,1,0,204,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,208,110,1,0,206,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,192,110,1,0,208,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,152,110,1,0,210,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,136,110,1,0,211,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,120,110,1,0,212,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,104,110,1,0,214,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,16,110,1,0,215,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,184,109,1,0,216,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,80,109,1,0,218,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,64,109,1,0,220,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,48,109,1,0,222,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,32,109,1,0,223,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,0,109,1,0,224,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,240,108,1,0,226,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,176,108,1,0,227,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,160,108,1,0,228,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,120,108,1,0,230,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,72,108,1,0,232,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,208,107,1,0,234,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,192,107,1,0,235,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,176,107,1,0,236,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,136,107,1,0,238,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,96,107,1,0,239,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,24,107,1,0,240,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,8,107,1,0,242,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,248,106,1,0,244,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,216,106,1,0,246,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,200,106,1,0,247,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,80,106,1,0,248,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,64,106,1,0,250,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,40,106,1,0,251,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,24,106,1,0,252,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,8,106,1,0,254,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,248,105,1,0,0,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,232,105,1,0,2,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,216,105,1,0,3,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,152,105,1,0,4,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,136,105,1,0,6,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,24,105,1,0,7,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,8,105,1,0,8,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,248,104,1,0,10,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,232,104,1,0,12,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,192,104,1,0,14,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,176,104,1,0,15,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,160,104,1,0,16,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,144,104,1,0,18,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,104,104,1,0,19,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,72,104,1,0,20,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,120,103,1,0,22,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,48,103,1,0,24,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,32,103,1,0,26,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,8,103,1,0,27,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,224,102,1,0,28,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,192,102,1,0,30,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,120,102,1,0,31,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,64,102,1,0,32,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,32,102,1,0,34,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,16,102,1,0,36,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,144,101,1,0,38,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,128,101,1,0,39,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,112,101,1,0,40,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,96,101,1,0,42,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,40,101,1,0,43,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,24,101,1,0,44,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,224,100,1,0,46,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,208,100,1,0,48,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,104,100,1,0,50,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,88,100,1,0,51,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,128,99,1,0,52,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,112,99,1,0,54,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,80,99,1,0,55,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,64,99,1,0,56,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,24,99,1,0,58,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,8,99,1,0,60,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,192,98,1,0,62,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,176,98,1,0,63,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,136,98,1,0,64,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,120,98,1,0,66,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,248,97,1,0,67,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,232,97,1,0,68,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,216,97,1,0,70,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,200,97,1,0,72,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,168,97,1,0,74,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,152,97,1,0,75,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,136,97,1,0,76,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,120,97,1,0,78,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,80,97,1,0,79,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,64,97,1,0,80,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,0,97,1,0,82,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,240,96,1,0,84,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,224,96,1,0,86,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,208,96,1,0,87,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,192,96,1,0,88,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,176,96,1,0,90,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,152,96,1,0,91,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,136,96,1,0,92,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,96,96,1,0,94,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,80,96,1,0,96,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,248,95,1,0,98,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,232,95,1,0,99,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,216,95,1,0,100,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,168,95,1,0,102,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,144,95,1,0,103,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,128,95,1,0,104,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,112,95,1,0,106,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,88,95,1,0,108,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,0,95,1,0,110,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,240,94,1,0,111,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,152,94,1,0,112,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,136,94,1,0,114,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,112,94,1,0,115,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,96,94,1,0,116,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,80,94,1,0,118,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,64,94,1,0,120,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,48,94,1,0,122,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,32,94,1,0,123,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,240,93,1,0,124,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,224,93,1,0,126,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,96,93,1,0,127,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,80,93,1,0,128,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,64,93,1,0,130,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,32,93,1,0,132,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,16,93,1,0,134,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,0,93,1,0,135,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,240,92,1,0,136,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,224,92,1,0,138,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,176,92,1,0,139,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,160,92,1,0,140,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,64,92,1,0,142,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,48,92,1,0,144,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,32,92,1,0,146,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,16,92,1,0,147,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,0,92,1,0,148,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,240,91,1,0,150,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,216,91,1,0,151,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,200,91,1,0,152,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,152,91,1,0,154,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,136,91,1,0,156,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,48,91,1,0,158,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,32,91,1,0,159,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,16,91,1,0,160,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,0,91,1,0,162,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,232,90,1,0,163,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,216,90,1,0,164,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,200,90,1,0,166,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,184,90,1,0,168,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,152,90,1,0,170,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,128,90,1,0,171,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,216,89,1,0,172,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,144,89,1,0,174,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,120,89,1,0,175,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,64,89,1,0,176,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,48,89,1,0,178,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,16,89,1,0,180,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,216,88,1,0,182,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,152,88,1,0,183,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,112,88,1,0,184,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,96,88,1,0,186,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,8,88,1,0,187,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,248,87,1,0,188,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,232,87,1,0,190,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,216,87,1,0,192,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,200,87,1,0,194,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,184,87,1,0,195,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,120,87,1,0,196,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,104,87,1,0,198,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,64,87,1,0,199,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,48,87,1,0,200,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,240,86,1,0,202,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,224,86,1,0,204,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,192,86,1,0,206,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,176,86,1,0,207,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,160,86,1,0,208,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,144,86,1,0,210,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,96,86,1,0,211,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,80,86,1,0,212,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,48,86,1,0,214,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,32,86,1,0,216,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,224,85,1,0,218,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,192,85,1,0,219,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,176,85,1,0,220,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,160,85,1,0,222,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,96,85,1,0,223,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,80,85,1,0,224,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,64,85,1,0,226,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,48,85,1,0,228,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,16,85,1,0,230,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,0,85,1,0,231,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,184,84,1,0,232,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,168,84,1,0,234,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,144,84,1,0,235,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,128,84,1,0,236,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,104,84,1,0,238,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,88,84,1,0,240,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,72,84,1,0,242,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,56,84,1,0,243,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,16,84,1,0,244,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,232,83,1,0,246,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,176,83,1,0,247,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,160,83,1,0,248,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,144,83,1,0,250,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,128,83,1,0,252,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,80,83,1,0,254,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,64,83,1,0,255,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,48,83,1,0,0,6,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,32,83,1,0,2,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,192,82,1,0,3,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,176,82,1,0,4,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,112,82,1,0,6,6,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,96,82,1,0,8,6,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,80,82,1,0,10,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,64,82,1,0,11,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,8,82,1,0,12,6,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,248,81,1,0,14,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,224,81,1,0,15,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,208,81,1,0,16,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,176,81,1,0,18,6,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,160,81,1,0,20,6,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,96,81,1,0,22,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,80,81,1,0,23,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,64,81,1,0,24,6,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,48,81,1,0,26,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,232,80,1,0,27,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,216,80,1,0,28,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,200,80,1,0,30,6,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,184,80,1,0,32,6,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,152,80,1,0,34,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,136,80,1,0,35,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,72,80,1,0,36,6,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,56,80,1,0,38,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,32,80,1,0,39,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,16,80,1,0,40,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,232,79,1,0,42,6,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,216,79,1,0,44,6,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,200,79,1,0,46,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,184,79,1,0,47,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0])
.concat([6,0,15,39,104,79,1,0,48,6,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,88,79,1,0,50,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,248,78,1,0,51,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,232,78,1,0,52,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,216,78,1,0,54,6,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,200,78,1,0,56,6,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,168,78,1,0,58,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,152,78,1,0,59,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,136,78,1,0,60,6,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,120,78,1,0,62,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,72,78,1,0,63,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,48,78,1,0,64,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,144,77,1,0,66,6,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,64,77,1,0,68,6,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,48,77,1,0,70,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,16,77,1,0,71,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,240,76,1,0,72,6,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,208,76,1,0,74,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,136,76,1,0,75,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,80,76,1,0,76,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,48,76,1,0,78,6,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,32,76,1,0,80,6,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,208,75,1,0,82,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,184,75,1,0,83,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,168,75,1,0,84,6,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,152,75,1,0,86,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,88,75,1,0,87,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,72,75,1,0,88,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,8,75,1,0,90,6,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,248,74,1,0,92,6,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,216,74,1,0,94,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,200,74,1,0,95,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,128,74,1,0,96,6,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,112,74,1,0,98,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,72,74,1,0,99,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,56,74,1,0,100,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,0,74,1,0,102,6,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,240,73,1,0,104,6,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,160,73,1,0,106,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,144,73,1,0,107,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,104,73,1,0,108,6,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,88,73,1,0,110,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,16,73,1,0,111,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,240,72,1,0,112,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,224,72,1,0,114,6,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,208,72,1,0,116,6,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,128,72,1,0,118,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,112,72,1,0,119,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,96,72,1,0,120,6,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,80,72,1,0,122,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,0,72,1,0,123,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,240,71,1,0,124,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,168,71,1,0,126,6,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,152,71,1,0,128,6,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,136,71,1,0,130,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,120,71,1,0,131,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,40,71,1,0,132,6,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,24,71,1,0,134,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,0,71,1,0,135,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,240,70,1,0,136,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,152,70,1,0,138,6,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,136,70,1,0,140,6,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,64,70,1,0,142,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,48,70,1,0,143,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,32,70,1,0,144,6,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,16,70,1,0,146,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,248,69,1,0,147,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,232,69,1,0,148,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,216,69,1,0,150,6,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,200,69,1,0,152,6,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,160,69,1,0,154,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,96,69,1,0,155,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,16,69,1,0,156,6,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,0,69,1,0,158,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,232,68,1,0,159,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,216,68,1,0,160,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,184,68,1,0,162,6,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,168,68,1,0,164,6,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,152,68,1,0,166,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,136,68,1,0,167,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,56,68,1,0,168,6,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,40,68,1,0,170,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,224,67,1,0,171,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,208,67,1,0,172,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,192,67,1,0,174,6,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,160,67,1,0,176,6,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,120,67,1,0,178,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,104,67,1,0,179,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,88,67,1,0,180,6,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,72,67,1,0,182,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,232,66,1,0,183,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,216,66,1,0,184,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,168,66,1,0,186,6,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,152,66,1,0,188,6,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,136,66,1,0,190,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,120,66,1,0,191,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,80,66,1,0,192,6,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,64,66,1,0,194,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,40,66,1,0,195,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,24,66,1,0,196,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,208,65,1,0,198,6,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,192,65,1,0,200,6,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,136,65,1,0,202,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,120,65,1,0,203,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,104,65,1,0,204,6,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,88,65,1,0,206,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,40,65,1,0,207,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,24,65,1,0,208,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,8,65,1,0,210,6,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,248,64,1,0,212,6,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,208,64,1,0,214,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,184,64,1,0,215,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,64,64,1,0,216,6,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,40,64,1,0,218,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,16,64,1,0,219,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,192,63,1,0,220,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,152,63,1,0,222,6,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,56,63,1,0,224,6,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,8,63,1,0,226,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,216,62,1,0,227,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,176,62,1,0,228,6,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,160,62,1,0,230,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,112,62,1,0,231,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,88,62,1,0,232,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,72,62,1,0,234,6,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,56,62,1,0,236,6,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,16,62,1,0,238,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,0,62,1,0,239,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,240,61,1,0,240,6,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,184,61,1,0,242,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,136,61,1,0,243,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,120,61,1,0,244,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,80,61,1,0,246,6,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,40,61,1,0,248,6,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,200,60,1,0,250,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,184,60,1,0,251,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,144,60,1,0,252,6,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,128,60,1,0,254,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,0,60,1,0,255,6,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,232,59,1,0,0,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,144,59,1,0,2,7,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,128,59,1,0,4,7,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,88,59,1,0,6,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,48,59,1,0,7,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,32,59,1,0,8,7,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,16,59,1,0,10,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,200,58,1,0,11,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,176,58,1,0,12,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,160,58,1,0,14,7,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,144,58,1,0,16,7,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,72,58,1,0,18,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,56,58,1,0,19,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,16,58,1,0,20,7,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,248,57,1,0,22,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,224,57,1,0,23,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,200,57,1,0,24,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,160,57,1,0,26,7,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,144,57,1,0,28,7,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,128,57,1,0,30,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,112,57,1,0,31,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,16,57,1,0,32,7,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,0,57,1,0,34,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,208,56,1,0,35,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,168,56,1,0,36,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,152,56,1,0,38,7,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,136,56,1,0,40,7,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,96,56,1,0,42,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,80,56,1,0,43,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,64,56,1,0,44,7,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,48,56,1,0,46,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,16,56,1,0,47,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,200,55,1,0,48,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,160,55,1,0,50,7,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,136,55,1,0,52,7,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,120,55,1,0,54,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,104,55,1,0,55,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,64,55,1,0,56,7,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,48,55,1,0,58,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,24,55,1,0,59,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,0,55,1,0,60,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,216,54,1,0,62,7,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,200,54,1,0,64,7,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,160,54,1,0,66,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,128,54,1,0,67,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,112,54,1,0,68,7,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,96,54,1,0,70,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,48,54,1,0,71,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,24,54,1,0,72,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,8,54,1,0,74,7,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,248,53,1,0,76,7,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,208,53,1,0,78,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,192,53,1,0,79,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,152,53,1,0,80,7,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,112,53,1,0,82,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,88,53,1,0,83,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,64,53,1,0,84,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,24,53,1,0,86,7,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,8,53,1,0,88,7,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,248,52,1,0,90,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,232,52,1,0,91,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,168,52,1,0,92,7,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,152,52,1,0,94,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,104,52,1,0,95,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,64,52,1,0,96,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,48,52,1,0,98,7,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,32,52,1,0,100,7,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,248,51,1,0,102,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,232,51,1,0,103,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,216,51,1,0,104,7,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,200,51,1,0,106,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,152,51,1,0,107,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,120,51,1,0,108,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,240,50,1,0,110,7,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,128,50,1,0,112,7,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,112,50,1,0,114,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,48,50,1,0,115,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,8,50,1,0,116,7,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,216,49,1,0,118,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,152,49,1,0,119,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,104,49,1,0,120,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,72,49,1,0,122,7,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,56,49,1,0,124,7,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,16,49,1,0,126,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,232,48,1,0,127,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,208,48,1,0,128,7,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,192,48,1,0,130,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,144,48,1,0,131,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,120,48,1,0,132,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,104,48,1,0,134,7,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,80,48,1,0,136,7,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,32,48,1,0,138,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,16,48,1,0,139,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,232,47,1,0,140,7,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,200,47,1,0,142,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,176,47,1,0,143,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,152,47,1,0,144,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,112,47,1,0,146,7,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,96,47,1,0,148,7,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,232,46,1,0,150,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,216,46,1,0,151,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,184,46,1,0,152,7,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,168,46,1,0,154,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,112,46,1,0,155,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,48,46,1,0,156,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,32,46,1,0,158,7,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,16,46,1,0,160,7,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,208,45,1,0,162,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,192,45,1,0,163,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,176,45,1,0,164,7,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,160,45,1,0,166,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,120,45,1,0,167,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,96,45,1,0,168,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,40,45,1,0,170,7,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,0,45,1,0,172,7,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,240,44,1,0,174,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,224,44,1,0,175,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,192,44,1,0,176,7,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,176,44,1,0,178,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,152,44,1,0,179,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,128,44,1,0,180,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,104,44,1,0,182,7,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,88,44,1,0,184,7,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,40,44,1,0,186,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,0,44,1,0,187,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,240,43,1,0,188,7,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,224,43,1,0,190,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,184,43,1,0,191,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,160,43,1,0,192,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,144,43,1,0,194,7,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,128,43,1,0,196,7,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,88,43,1,0,198,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,56,43,1,0,199,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,0,43,1,0,200,7,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,232,42,1,0,202,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,208,42,1,0,203,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,184,42,1,0,204,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,168,42,1,0,206,7,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,136,42,1,0,208,7,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,120,42,1,0,210,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,104,42,1,0,211,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,80,42,1,0,212,7,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,64,42,1,0,214,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,16,42,1,0,215,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,240,41,1,0,216,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,224,41,1,0,218,7,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,208,41,1,0,220,7,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,176,41,1,0,222,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,104,41,1,0,223,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,88,41,1,0,224,7,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,72,41,1,0,226,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,24,41,1,0,227,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,0,41,1,0,228,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,224,40,1,0,230,7,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,184,40,1,0,232,7,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,168,40,1,0,234,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,152,40,1,0,235,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,136,40,1,0,236,7,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,96,40,1,0,238,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,56,40,1,0,239,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,32,40,1,0,240,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,232,39,1,0,242,7,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,216,39,1,0,244,7,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,176,39,1,0,246,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,136,39,1,0,247,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,120,39,1,0,248,7,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,104,39,1,0,250,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,40,39,1,0,251,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,16,39,1,0,252,7,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,0,39,1,0,254,7,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,240,38,1,0,0,8,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,200,38,1,0,2,8,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,176,38,1,0,3,8,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,48,38,1,0,4,8,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,16,38,1,0,6,8,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,248,37,1,0,7,8,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,144,37,1,0,8,8,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,128,37,1,0,10,8,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,80,37,1,0,12,8,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,24,37,1,0,14,8,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,216,36,1,0,15,8,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,192,36,1,0,16,8,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,176,36,1,0,18,8,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,128,36,1,0,19,8,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,88,36,1,0,20,8,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,72,36,1,0,22,8,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,56,36,1,0,24,8,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,40,36,1,0,26,8,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,0,36,1,0,27,8,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,240,35,1,0,28,8,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,152,35,1,0,30,8,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,112,35,1,0,31,8,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,88,35,1,0,32,8,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,48,35,1,0,34,8,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,24,35,1,0,36,8,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,8,35,1,0,38,8,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,248,34,1,0,39,8,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,232,34,1,0,40,8,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,200,34,1,0,42,8,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,112,34,1,0,43,8,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,88,34,1,0,44,8,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,64,34,1,0,46,8,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,48,34,1,0,48,8,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,16,34,1,0,50,8,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,248,33,1,0,51,8,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,232,33,1,0,52,8,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,216,33,1,0,54,8,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,168,33,1,0,55,8,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,120,33,1,0,56,8,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,104,33,1,0,58,8,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,88,33,1,0,60,8,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,56,33,1,0,62,8,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,40,33,1,0,63,8,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,0,33,1,0,64,8,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,232,32,1,0,66,8,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,208,32,1,0,67,8,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,184,32,1,0,68,8,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,168,32,1,0,70,8,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,152,32,1,0,71,8,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,136,32,1,0,72,8,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,120,32,1,0,74,8,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,96,32,1,0,76,8,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,80,32,1,0,78,8,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,40,32,1,0,80,8,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,8,32,1,0,82,8,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,248,31,1,0,84,8,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,224,31,1,0,85,8,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,216,31,1,0,86,8,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,200,31,1,0,88,8,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,184,31,1,0,90,8,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,160,31,1,0,92,8,0,0,0,0,0,0,32,2,0,0,1,0,0,0,6,0,15,39,144,31,1,0,124,10,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,112,31,1,0,125,10,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,72,31,1,0,127,10,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,8,31,1,0,128,10,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,248,30,1,0,130,10,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,232,30,1,0,132,10,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,216,30,1,0,134,10,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,176,30,1,0,136,10,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,160,30,1,0,138,10,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,144,30,1,0,139,10,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,120,30,1,0,140,10,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,104,30,1,0,142,10,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,64,30,1,0,144,10,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,40,30,1,0,146,10,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,24,30,1,0,148,10,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,0,30,1,0,149,10,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,240,29,1,0,150,10,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,208,29,1,0,151,10,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,192,29,1,0,152,10,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,184,29,1,0,154,10,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,160,29,1,0,156,10,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,152,29,1,0,158,10,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,112,29,1,0,160,10,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,24,237,0,0,162,10,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,168,236,0,0,164,10,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,88,29,1,0,166,10,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,80,29,1,0,168,10,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,72,29,1,0,169,10,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,56,29,1,0,170,10,0,0,0,0,0,0,4,0,0,0,1,0,0,0,6,0,15,39,24,29,1,0,176,10,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,8,29,1,0,177,10,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,248,28,1,0,178,10,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,184,28,1,0,179,10,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,168,28,1,0,180,10,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,128,28,1,0,181,10,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,104,28,1,0,187,10,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,72,28,1,0,193,10,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,48,28,1,0,199,10,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,24,28,1,0,205,10,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,232,27,1,0,211,10,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,208,27,1,0,182,10,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,192,27,1,0,188,10,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,80,27,1,0,194,10,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,48,27,1,0,200,10,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,152,26,1,0,206,10,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,32,26,1,0,212,10,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,8,26,1,0,183,10,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,176,25,1,0,189,10,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,144,25,1,0,195,10,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,112,25,1,0,201,10,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,48,25,1,0,207,10,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,208,24,1,0,213,10,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,176,24,1,0,184,10,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,144,24,1,0,190,10,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,96,24,1,0,196,10,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,56,24,1,0,202,10,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,32,24,1,0,208,10,0,0,0,0,0,0])
.concat([1,0,0,0,0,0,0,0,6,0,15,39,8,24,1,0,214,10,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,240,23,1,0,185,10,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,200,23,1,0,191,10,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,168,23,1,0,197,10,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,104,23,1,0,203,10,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,72,23,1,0,209,10,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,48,23,1,0,215,10,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,16,23,1,0,186,10,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,232,22,1,0,192,10,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,200,22,1,0,198,10,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,176,22,1,0,204,10,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,152,22,1,0,210,10,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,112,22,1,0,216,10,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,88,22,1,0,217,10,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,0,22,1,0,218,10,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,200,21,1,0,219,10,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,176,21,1,0,220,10,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,152,21,1,0,221,10,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,128,21,1,0,222,10,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,112,21,1,0,224,10,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,88,21,1,0,225,10,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,40,21,1,0,226,10,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,232,20,1,0,227,10,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,224,20,1,0,228,10,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,208,20,1,0,229,10,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,184,20,1,0,230,10,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,168,20,1,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,40,42,1,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,240,40,1,0,4,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,192,39,1,0,0,0,0,0,0,0,0,0,16,0,0,0,3,0,0,0,6,0,15,39,64,169,0,0,64,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,112,167,0,0,68,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,96,167,0,0,72,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,72,167,0,0,76,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,32,167,0,0,80,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,16,167,0,0,84,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,0,167,0,0,88,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,240,166,0,0,92,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,200,166,0,0,96,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,136,166,0,0,100,0,0,0,248,7,0,0,4,0,0,0,7,0,0,0,6,0,15,39,128,166,0,0,104,0,0,0,248,7,0,0,4,0,0,0,7,0,0,0,6,0,15,39,8,165,0,0,108,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,248,164,0,0,109,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,240,164,0,0,112,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,200,164,0,0,116,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,192,164,0,0,120,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,184,164,0,0,124,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,176,164,0,0,128,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,160,164,0,0,132,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,96,164,0,0,136,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,80,164,0,0,140,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,128,162,0,0,144,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,112,162,0,0,148,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,80,162,0,0,156,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,40,162,0,0,164,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,24,162,0,0,172,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,16,162,0,0,176,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,0,162,0,0,180,0,0,0,160,0,0,0,4,0,0,0,7,0,0,0,6,0,15,39,216,161,0,0,184,0,0,0,160,0,0,0,4,0,0,0,7,0,0,0,6,0,15,39,192,161,0,0,188,0,0,0,160,0,0,0,4,0,0,0,7,0,0,0,6,0,15,39,176,161,0,0,192,0,0,0,160,0,0,0,4,0,0,0,7,0,0,0,6,0,15,39,32,161,0,0,196,0,0,0,160,0,0,0,4,0,0,0,7,0,0,0,6,0,15,39,16,161,0,0,200,0,0,0,160,0,0,0,4,0,0,0,7,0,0,0,6,0,15,39,0,161,0,0,204,0,0,0,160,0,0,0,4,0,0,0,7,0,0,0,6,0,15,39,232,160,0,0,208,0,0,0,160,0,0,0,4,0,0,0,7,0,0,0,6,0,15,39,216,160,0,0,212,0,0,0,160,0,0,0,4,0,0,0,7,0,0,0,6,0,15,39,200,160,0,0,216,0,0,0,160,0,0,0,4,0,0,0,7,0,0,0,6,0,15,39,184,160,0,0,220,0,0,0,160,0,0,0,4,0,0,0,7,0,0,0,6,0,15,39,168,160,0,0,224,0,0,0,160,0,0,0,4,0,0,0,7,0,0,0,6,0,15,39,144,160,0,0,228,0,0,0,160,0,0,0,4,0,0,0,7,0,0,0,6,0,15,39,128,160,0,0,232,0,0,0,160,0,0,0,4,0,0,0,7,0,0,0,6,0,15,39,40,159,0,0,236,0,0,0,160,0,0,0,4,0,0,0,7,0,0,0,6,0,15,39,24,159,0,0,240,0,0,0,160,0,0,0,4,0,0,0,7,0,0,0,6,0,15,39,8,159,0,0,244,0,0,0,160,0,0,0,4,0,0,0,7,0,0,0,6,0,15,39,224,158,0,0,248,0,0,0,160,0,0,0,4,0,0,0,7,0,0,0,6,0,15,39,208,158,0,0,252,0,0,0,160,0,0,0,4,0,0,0,7,0,0,0,6,0,15,39,192,158,0,0,0,1,0,0,160,0,0,0,4,0,0,0,7,0,0,0,6,0,15,39,176,158,0,0,4,1,0,0,160,0,0,0,4,0,0,0,7,0,0,0,6,0,15,39,136,158,0,0,8,1,0,0,160,0,0,0,4,0,0,0,7,0,0,0,6,0,15,39,112,158,0,0,12,1,0,0,160,0,0,0,4,0,0,0,7,0,0,0,6,0,15,39,16,158,0,0,16,1,0,0,160,0,0,0,4,0,0,0,7,0,0,0,6,0,15,39,160,156,0,0,20,1,0,0,160,0,0,0,4,0,0,0,7,0,0,0,6,0,15,39,88,156,0,0,24,1,0,0,160,0,0,0,4,0,0,0,7,0,0,0,6,0,15,39,72,156,0,0,28,1,0,0,160,0,0,0,4,0,0,0,7,0,0,0,6,0,15,39,232,155,0,0,32,1,0,0,160,0,0,0,4,0,0,0,7,0,0,0,6,0,15,39,208,155,0,0,36,1,0,0,160,0,0,0,4,0,0,0,7,0,0,0,6,0,15,39,152,155,0,0,40,1,0,0,160,0,0,0,4,0,0,0,7,0,0,0,6,0,15,39,48,155,0,0,44,1,0,0,160,0,0,0,4,0,0,0,7,0,0,0,6,0,15,39,152,154,0,0,48,1,0,0,160,0,0,0,4,0,0,0,7,0,0,0,6,0,15,39,128,154,0,0,52,1,0,0,160,0,0,0,4,0,0,0,7,0,0,0,6,0,15,39,112,154,0,0,56,1,0,0,0,0,0,0,32,0,0,0,3,0,0,0,6,0,15,39,32,153,0,0,184,1,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,16,153,0,0,188,1,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,248,152,0,0,192,1,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,192,152,0,0,196,1,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,176,152,0,0,200,1,0,0,212,1,0,0,4,0,0,0,7,0,0,0,6,0,15,39,160,152,0,0,204,1,0,0,228,1,0,0,4,0,0,0,7,0,0,0,6,0,15,39,112,152,0,0,208,1,0,0,228,1,0,0,4,0,0,0,7,0,0,0,6,0,15,39,72,152,0,0,212,1,0,0,160,0,0,0,4,0,0,0,7,0,0,0,6,0,15,39,48,152,0,0,216,1,0,0,160,0,0,0,4,0,0,0,7,0,0,0,6,0,15,39,32,152,0,0,220,1,0,0,160,0,0,0,4,0,0,0,7,0,0,0,6,0,15,39,216,150,0,0,224,1,0,0,160,0,0,0,4,0,0,0,7,0,0,0,6,0,15,39,144,150,0,0,228,5,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,128,150,0,0,232,5,0,0,152,0,0,0,4,0,0,0,7,0,0,0,6,0,15,39,104,150,0,0,236,5,0,0,0,0,0,0,0,2,0,0,1,0,0,0,6,0,15,39,88,150,0,0,236,7,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,240,149,0,0,240,7,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,224,149,0,0,244,7,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,208,149,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,56,32,1,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,88,31,1,0,2,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,80,30,1,0,4,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,120,29,1,0,8,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,152,28,1,0,12,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,24,27,1,0,16,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,192,188,0,0,20,0,0,0,0,0,0,0,0,2,0,0,1,0,0,0,6,0,15,39,128,24,1,0,20,2,0,0,0,0,0,0,0,2,0,0,1,0,0,0,6,0,15,39,240,184,0,0,20,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,40,23,1,0,22,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,40,42,1,0,24,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,168,21,1,0,26,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,104,20,1,0,28,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,160,19,1,0,30,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,240,18,1,0,32,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,168,18,1,0,36,4,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,64,18,1,0,40,4,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,224,17,1,0,44,4,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,128,17,1,0,48,4,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,112,16,1,0,52,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,248,15,1,0,54,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,88,15,1,0,56,4,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,216,14,1,0,60,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,160,14,1,0,62,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,80,14,1,0,64,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,40,14,1,0,66,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,200,13,1,0,68,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,112,13,1,0,70,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,16,13,1,0,72,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,112,11,1,0,74,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,8,11,1,0,76,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,104,10,1,0,78,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,208,9,1,0,80,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,104,9,1,0,82,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,0,9,1,0,84,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,176,8,1,0,86,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,88,8,1,0,88,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,176,7,1,0,90,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,168,6,1,0,92,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,240,4,1,0,94,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,72,4,1,0,96,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,104,3,1,0,98,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,104,2,1,0,100,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,152,1,1,0,102,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,184,0,1,0,104,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,24,0,1,0,106,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,56,255,0,0,108,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,216,254,0,0,110,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,80,254,0,0,112,4,0,0,0,0,0,0,2,0,0,0,2,0,0,0,6,0,15,39,16,253,0,0,120,4,0,0,0,0,0,0,2,0,0,0,2,0,0,0,6,0,15,39,120,252,0,0,128,4,0,0,0,0,0,0,2,0,0,0,2,0,0,0,6,0,15,39,136,251,0,0,136,4,0,0,0,0,0,0,2,0,0,0,2,0,0,0,6,0,15,39,8,251,0,0,144,4,0,0,0,0,0,0,2,0,0,0,2,0,0,0,6,0,15,39,160,250,0,0,152,4,0,0,0,0,0,0,2,0,0,0,2,0,0,0,6,0,15,39,240,249,0,0,160,4,0,0,0,0,0,0,2,0,0,0,2,0,0,0,6,0,15,39,128,249,0,0,116,4,0,0,0,0,0,0,2,0,0,0,2,0,0,0,6,0,15,39,224,248,0,0,124,4,0,0,0,0,0,0,2,0,0,0,2,0,0,0,6,0,15,39,104,248,0,0,132,4,0,0,0,0,0,0,2,0,0,0,2,0,0,0,6,0,15,39,24,248,0,0,140,4,0,0,0,0,0,0,2,0,0,0,2,0,0,0,6,0,15,39,224,246,0,0,148,4,0,0,0,0,0,0,2,0,0,0,2,0,0,0,6,0,15,39,48,246,0,0,156,4,0,0,0,0,0,0,2,0,0,0,2,0,0,0,6,0,15,39,160,245,0,0,164,4,0,0,0,0,0,0,2,0,0,0,2,0,0,0,6,0,15,39,24,245,0,0,168,4,0,0,0,0,0,0,2,0,0,0,2,0,0,0,6,0,15,39,216,244,0,0,172,4,0,0,0,0,0,0,2,0,0,0,2,0,0,0,6,0,15,39,88,244,0,0,176,4,0,0,0,0,0,0,16,0,0,0,2,0,0,0,6,0,15,39,240,243,0,0,208,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,128,243,0,0,210,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,16,243,0,0,212,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,192,242,0,0,214,4,0,0,0,0,0,0,32,0,0,0,2,0,0,0,6,0,15,39,112,241,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,56,32,1,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,80,30,1,0,4,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,120,29,1,0,8,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,152,28,1,0,12,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,24,27,1,0,16,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,192,188,0,0,20,0,0,0,0,0,0,0,0,2,0,0,1,0,0,0,6,0,15,39,128,24,1,0,20,2,0,0,0,0,0,0,0,2,0,0,1,0,0,0,6,0,15,39,240,184,0,0,20,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,24,241,0,0,24,4,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,216,240,0,0,28,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,168,240,0,0,29,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,32,240,0,0,32,4,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,0,240,0,0,36,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,224,239,0,0,38,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,160,239,0,0,40,4,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,104,239,0,0,44,4,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,48,239,0,0,48,4,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,56,238,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,56,32,1,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,176,237,0,0,2,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,80,30,1,0,4,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,120,29,1,0,8,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,152,28,1,0,12,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,24,27,1,0,16,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,192,188,0,0,20,0,0,0,0,0,0,0,0,2,0,0,1,0,0,0,6,0,15,39,128,24,1,0,20,2,0,0,0,0,0,0,0,2,0,0,1,0,0,0,6,0,15,39,240,184,0,0,20,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,24,237,0,0,22,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,168,236,0,0,24,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,88,236,0,0,26,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,8,236,0,0,28,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,176,235,0,0,30,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,112,235,0,0,32,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,40,235,0,0,34,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,216,234,0,0,36,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,32,234,0,0,38,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,136,233,0,0,40,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,176,232,0,0,42,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,112,232,0,0,44,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,56,232,0,0,46,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,16,232,0,0,48,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,240,231,0,0,50,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,152,231,0,0,52,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,104,231,0,0,54,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,80,231,0,0,56,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,96,230,0,0,58,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,0,230,0,0,60,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,144,229,0,0,62,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,104,229,0,0,64,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,88,229,0,0,66,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,72,229,0,0,68,4,0,0,0,0,0,0,3,0,0,0,2,0,0,0,6,0,15,39,48,229,0,0,86,4,0,0,0,0,0,0,3,0,0,0,2,0,0,0,6,0,15,39,24,229,0,0,104,4,0,0,0,0,0,0,3,0,0,0,2,0,0,0,6,0,15,39,192,228,0,0,74,4,0,0,0,0,0,0,3,0,0,0,2,0,0,0,6,0,15,39,168,228,0,0,92,4,0,0,0,0,0,0,3,0,0,0,2,0,0,0,6,0,15,39,176,227,0,0,110,4,0,0,0,0,0,0,3,0,0,0,2,0,0,0,6,0,15,39,128,227,0,0,80,4,0,0,0,0,0,0,3,0,0,0,2,0,0,0,6,0,15,39,248,226,0,0,98,4,0,0,0,0,0,0,3,0,0,0,2,0,0,0,6,0,15,39,184,226,0,0,116,4,0,0,0,0,0,0,3,0,0,0,2,0,0,0,6,0,15,39,152,226,0,0,122,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,112,226,0,0,124,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,80,226,0,0,126,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,24,226,0,0,128,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,240,225,0,0,130,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,216,225,0,0,132,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,8,225,0,0,134,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,232,224,0,0,136,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,160,224,0,0,138,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,104,224,0,0,140,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,80,224,0,0,142,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,56,224,0,0,144,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,16,224,0,0,146,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,240,223,0,0,148,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,128,223,0,0,150,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,96,223,0,0,152,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,120,222,0,0,154,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,56,222,0,0,156,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,232,221,0,0,158,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,192,221,0,0,160,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,168,221,0,0,162,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,152,221,0,0,164,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,120,221,0,0,166,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,72,221,0,0,168,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,16,221,0,0,170,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,80,220,0,0,172,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,232,218,0,0,174,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,152,218,0,0,176,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,0,218,0,0,178,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,152,217,0,0,180,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,136,217,0,0,182,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,224,216,0,0,184,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,112,216,0,0,186,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,32,216,0,0,188,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,248,215,0,0,190,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,216,215,0,0,192,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,56,214,0,0,194,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,232,213,0,0,196,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,200,213,0,0,198,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,160,213,0,0,200,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,128,213,0,0,202,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,64,213,0,0,204,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,248,212,0,0,206,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,200,212,0,0,208,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,136,212,0,0,210,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,104,212,0,0,212,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,200,210,0,0,214,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,120,210,0,0,216,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,72,210,0,0,218,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,16,210,0,0,220,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,240,209,0,0,222,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,208,209,0,0,224,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,120,209,0,0,226,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,104,209,0,0,228,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,32,209,0,0,230,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,240,208,0,0,232,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,72,207,0,0,234,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,248,206,0,0,236,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,160,206,0,0,238,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,120,206,0,0,240,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,104,206,0,0,242,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,80,206,0,0,244,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,0,206,0,0,246,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,224,205,0,0,248,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,200,205,0,0,250,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,152,205,0,0,252,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,248,203,0,0,254,4,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,168,203,0,0,0,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,112,203,0,0,2,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,64,203,0,0,4,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,40,203,0,0,6,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,16,203,0,0,8,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,200,202,0,0,10,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,184,202,0,0,12,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,128,202,0,0,14,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,72,202,0,0,16,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,120,200,0,0,18,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,16,200,0,0,20,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,232,199,0,0,22,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,184,199,0,0,24,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,152,199,0,0,26,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,128,199,0,0,28,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,72,199,0,0,30,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,232,198,0,0,32,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,184,198,0,0,34,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,136,198,0,0,36,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,16,197,0,0,38,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,0,197,0,0,40,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,176,196,0,0,42,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,120,196,0,0,44,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,104,196,0,0,46,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,80,196,0,0,48,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,24,196,0,0,50,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,0,196,0,0,52,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,224,195,0,0,54,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,184,195,0,0,56,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,168,194,0,0,58,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,144,193,0,0,60,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,88,193,0,0,62,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,40,193,0,0,64,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,24,193,0,0,66,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,0,193,0,0,68,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,176,192,0,0,70,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,128,192,0,0,72,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,48,192,0,0,74,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,0,192,0,0,76,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,160,190,0,0,78,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,112,190,0,0,80,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,72,190,0,0,82,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,40,190,0,0,84,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,24,190,0,0,86,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,0,190,0,0,88,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,104,189,0,0,90,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,80,189,0,0,92,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,216,188,0,0,94,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,208,188,0,0,96,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,48,187,0,0,98,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,176,186,0,0,100,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,152,186,0,0,102,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,104,186,0,0,104,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,80,186,0,0,106,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,64,186,0,0,108,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,8,186,0,0,110,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,224,185,0,0,112,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,152,185,0,0,114,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,232,184,0,0,116,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,240,182,0,0,118,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,120,182,0,0,120,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,40,182,0,0,122,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,184,181,0,0,124,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,160,181,0,0,126,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,64,181,0,0,128,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,80,180,0,0,130,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,184,179,0,0,132,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,128,179,0,0,134,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,96,179,0,0,136,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,232,177,0,0,138,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,200,177,0,0,140,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,184,177,0,0,142,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,152,177,0,0,144,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,144,177,0,0,146,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,136,177,0,0,148,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,120,177,0,0,150,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,80,177,0,0,152,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,32,177,0,0,154,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,8,177,0,0,156,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,144,175,0,0,158,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,120,175,0,0,160,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,112,175,0,0,162,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,80,175,0,0,164,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,72,175,0,0,166,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,48,175,0,0,168,5,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,32,175,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,168,146,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,120,146,0,0,2,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,88,146,0,0,3,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,64,146,0,0,4,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,192,145,0,0,5,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,168,145,0,0,6,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,152,145,0,0,8,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,120,145,0,0,10,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,104,145,0,0,12,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,64,145,0,0,14,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,40,145,0,0,16,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,24,145,0,0,18,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,224,144,0,0,19,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,200,144,0,0,20,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,40,144,0,0,21,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,16,144,0,0,22,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,248,143,0,0,23,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,192,143,0,0,24,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,168,143,0,0,25,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,144,143,0,0,26,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,112,143,0,0,27,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,72,143,0,0,28,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,32,143,0,0,30,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,16,143,0,0,32,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,176,142,0,0,34,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,136,142,0,0,36,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,112,142,0,0,38,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,64,142,0,0,40,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,48,142,0,0,41,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,24,142,0,0,42,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,0,142,0,0,43,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,232,141,0,0,44,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,168,141,0,0,45,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,136,141,0,0,46,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,8,141,0,0,47,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,240,140,0,0])
.concat([48,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,208,140,0,0,49,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,168,140,0,0,50,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,152,140,0,0,52,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,136,140,0,0,54,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,120,140,0,0,56,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,56,140,0,0,58,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,248,139,0,0,60,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,176,139,0,0,62,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,0,139,0,0,63,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,224,138,0,0,64,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,200,138,0,0,65,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,104,138,0,0,66,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,80,138,0,0,67,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,240,137,0,0,68,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,136,137,0,0,69,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,88,137,0,0,70,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,24,137,0,0,71,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,0,137,0,0,72,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,152,136,0,0,74,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,136,136,0,0,76,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,120,136,0,0,78,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,80,136,0,0,80,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,32,136,0,0,82,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,16,136,0,0,84,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,184,135,0,0,85,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,160,135,0,0,86,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,112,135,0,0,87,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,88,135,0,0,88,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,232,134,0,0,89,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,200,134,0,0,90,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,176,134,0,0,91,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,152,134,0,0,92,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,104,134,0,0,93,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,16,134,0,0,94,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,0,134,0,0,96,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,240,133,0,0,98,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,200,133,0,0,100,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,128,133,0,0,102,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,32,133,0,0,104,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,16,133,0,0,106,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,0,133,0,0,107,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,192,132,0,0,108,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,144,132,0,0,109,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,120,132,0,0,110,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,96,132,0,0,111,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,40,132,0,0,112,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,224,131,0,0,113,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,200,131,0,0,114,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,96,131,0,0,115,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,72,131,0,0,116,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,56,131,0,0,118,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,40,131,0,0,120,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,24,131,0,0,122,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,240,130,0,0,124,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,216,130,0,0,126,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,200,130,0,0,128,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,160,130,0,0,129,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,136,130,0,0,130,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,0,130,0,0,131,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,232,129,0,0,132,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,208,129,0,0,133,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,176,129,0,0,134,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,128,129,0,0,135,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,104,129,0,0,136,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,72,129,0,0,137,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,48,129,0,0,138,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,200,128,0,0,140,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,184,128,0,0,142,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,88,128,0,0,144,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,48,128,0,0,146,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,24,128,0,0,148,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,8,128,0,0,150,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,232,127,0,0,151,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,208,127,0,0,152,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,184,127,0,0,153,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,160,127,0,0,154,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,72,127,0,0,155,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,40,127,0,0,156,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,240,125,0,0,157,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,216,125,0,0,158,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,184,125,0,0,159,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,144,125,0,0,160,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,104,125,0,0,162,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,88,125,0,0,164,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,72,125,0,0,166,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,32,125,0,0,168,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,0,125,0,0,170,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,6,0,15,39,240,124,0,0,172,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,128,124,0,0,173,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,104,124,0,0,174,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,80,124,0,0,175,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,56,124,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,200,147,0,0,1,0,0,0,0,0,0,0,2,0,0,0,1,0,0,0,6,0,15,39,184,147,0,0,3,0,0,0,0,0,0,0,4,0,0,0,1,0,0,0,6,0,15,39,176,147,0,0,7,0,0,0,0,0,0,0,2,0,0,0,1,0,0,0,6,0,15,39,160,147,0,0,9,0,0,0,0,0,0,0,4,0,0,0,1,0,0,0,6,0,15,39,136,147,0,0,13,0,0,0,0,0,0,0,2,0,0,0,1,0,0,0,6,0,15,39,120,147,0,0,15,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,24,147,0,0,16,0,0,0,0,0,0,0,8,0,0,0,1,0,0,0,6,0,15,39,16,147,0,0,24,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,0,147,0,0,25,0,0,0,0,0,0,0,60,0,0,0,1,0,0,0,6,0,15,39,224,146,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,96,20,1,0,4,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,72,20,1,0,8,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,56,20,1,0,12,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,32,172,0,0,20,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,216,171,0,0,24,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,40,20,1,0,28,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,24,20,1,0,32,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,0,20,1,0,36,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,240,19,1,0,40,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,232,19,1,0,41,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,208,19,1,0,42,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,192,19,1,0,43,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,144,19,1,0,44,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,112,19,1,0,52,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,96,19,1,0,56,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,80,19,1,0,60,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,32,170,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,88,220,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,224,215,0,0,2,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,112,212,0,0,3,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,248,208,0,0,4,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,160,205,0,0,5,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,80,202,0,0,8,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,144,198,0,0,12,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,192,195,0,0,16,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,6,0,15,39,8,192,0,0,20,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,6,0,15,39,192,188,0,0,21,0,0,0,0,0,0,0,32,0,0,0,1,0,0,0,6,0,15,39,240,184,0,0,53,0,0,0,0,0,0,0,32,0,0,0,1,0,0,0,6,0,15,39,40,158,0,0,85,0,0,0,0,0,0,0,16,0,0,0,1,0,0,0,6,0,15,39,112,179,0,0,101,0,0,0,0,0,0,0,16,0,0,0,1,0,0,0,6,0,15,39,16,177,0,0,117,0,0,0,0,0,0,0,32,0,0,0,1,0,0,0,6,0,15,39,200,174,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,3,72,6,106,9,140,12,171,15,200,18,226,21,249,24,11,28,26,31,35,34,40,37,38,40,31,43,17,46,251,48,223,51,186,54,140,57,86,60,23,63,206,65,122,68,28,71,180,73,63,76,191,78,51,81,155,83,245,85,66,88,130,90,179,92,215,94,235,96,241,98,232,100,207,102,166,104,109,106,35,108,201,109,94,111,226,112,84,114,181,115,4,117,65,118,107,119,132,120,137,121,124,122,92,123,41,124,227,124,137,125,29,126,156,126,9,127,97,127,166,127,216,127,245,127,255,127,245,127,216,127,166,127,97,127,9,127,156,126,29,126,137,125,227,124,41,124,92,123,124,122,137,121,132,120,107,119,65,118,4,117,181,115,84,114,226,112,94,111,201,109,35,108,109,106,166,104,207,102,232,100,241,98,235,96,215,94,179,92,130,90,66,88,245,85,155,83,51,81,191,78,63,76,180,73,28,71,122,68,206,65,23,63,86,60,140,57,186,54,223,51,251,48,17,46,31,43,38,40,40,37,35,34,26,31,11,28,248,24,226,21,200,18,171,15,140,12,106,9,72,6,36,3,0,0,220,252,184,249,149,246,116,243,85,240,56,237,30,234,7,231,245,227,230,224,221,221,216,218,218,215,225,212,239,209,5,207,33,204,70,201,115,198,170,195,233,192,50,190,134,187,228,184,76,182,193,179,65,177,205,174,101,172,11,170,190,167,126,165,77,163,41,161,20,159,15,157,24,155,49,153,90,151,147,149,221,147,55,146,162,144,30,143,172,141,75,140,252,138,191,137,149,136,124,135,119,134,132,133,164,132,215,131,29,131,119,130,227,129,100,129,247,128,159,128,90,128,40,128,11,128,1,128,11,128,40,128,90,128,159,128,247,128,100,129,227,129,119,130,29,131,215,131,164,132,132,133,119,134,125,135,149,136,191,137,252,138,75,140,172,141,30,143,162,144,55,146,221,147,147,149,90,151,49,153,24,155,15,157,21,159,41,161,77,163,126,165,190,167,11,170,102,172,205,174,65,177,193,179,77,182,228,184,134,187,51,190,233,192,170,195,116,198,71,201,34,204,5,207,240,209,225,212,218,215,217,218,221,221,231,224,245,227,8,231,30,234,56,237,85,240,117,243,150,246,185,249,220,252,128,3,37,3,218,2,156,2,104,2,59,2,21,2,243,1,213,1,187,1,163,1,142,1,123,1,106,1,90,1,75,1,62,1,50,1,38,1,28,1,18,1,9,1,0,1,248,0,240,0,233,0,227,0,220,0,214,0,209,0,203,0,198,0,193,0,189,0,184,0,180,0,176,0,172,0,168,0,165,0,162,0,158,0,155,0,152,0,149,0,147,0,144,0,141,0,139,0,136,0,134,0,132,0,130,0,128,0,126,0,124,0,122,0,120,0,118,0,116,0,115,0,113,0,111,0,110,0,108,0,107,0,105,0,104,0,103,0,101,0,100,0,99,0,98,0,96,0,95,0,94,0,93,0,92,0,91,0,90,0,89,0,88,0,87,0,86,0,85,0,84,0,83,0,82,0,81,0,81,0,80,0,79,0,78,0,77,0,77,0,76,0,75,0,75,0,74,0,73,0,72,0,72,0,71,0,71,0,70,0,69,0,69,0,68,0,68,0,67,0,66,0,66,0,65,0,65,0,64,0,64,0,63,0,63,0,62,0,62,0,61,0,61,0,60,0,60,0,59,0,59,0,58,0,58,0,58,0,57,0,57,0,56,0,56,0,56,0,55,0,55,0,54,0,54,0,54,0,53,0,53,0,53,0,52,0,52,0,52,0,51,0,51,0,51,0,50,0,50,0,50,0,49,0,49,0,49,0,48,0,48,0,48,0,48,0,47,0,47,0,47,0,46,0,46,0,46,0,46,0,45,0,45,0,45,0,45,0,44,0,44,0,44,0,44,0,43,0,43,0,43,0,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,128,160,173,179,182,184,185,186,187,187,188,188,189,189,189,189,189,190,190,190,190,190,190,190,190,190,190,190,191,191,191,191,128,147,160,168,173,176,179,181,182,183,184,185,185,186,186,187,187,187,187,188,188,188,188,188,189,189,189,189,189,189,189,189,128,141,152,160,166,170,173,176,177,179,180,181,182,183,183,184,184,185,185,186,186,186,186,187,187,187,187,187,188,188,188,188,128,138,147,154,160,165,168,171,173,175,176,178,179,180,181,181,182,183,183,184,184,184,185,185,185,186,186,186,186,186,187,187,128,136,144,150,155,160,164,167,169,171,173,175,176,177,178,179,180,180,181,182,182,182,183,183,184,184,184,185,185,185,185,185,128,135,141,147,152,156,160,163,166,168,170,172,173,174,176,176,177,178,179,180,180,181,181,182,182,182,183,183,183,184,184,184,128,134,139,144,149,153,157,160,163,165,167,169,170,172,173,174,175,176,177,178,178,179,179,180,180,181,181,182,182,182,183,183,128,133,138,143,147,151,154,157,160,162,165,166,168,170,171,172,173,174,175,176,176,177,178,178,179,179,180,180,181,181,181,181,128,133,137,141,145,149,152,155,158,160,160,164,166,167,169,170,171,172,173,174,175,176,176,177,177,178,178,179,179,180,180,180,128,132,136,140,144,147,150,153,155,158,160,162,164,165,167,168,169,170,171,172,173,174,175,175,176,176,177,178,178,178,179,179,128,132,135,139,142,145,148,151,154,156,158,160,162,163,165,166,167,169,170,171,172,172,173,174,174,175,176,176,177,177,178,178,128,131,135,138,141,144,147,150,152,154,156,158,160,162,163,165,166,167,168,169,170,171,172,172,173,174,174,175,176,176,176,177,128,131,134,137,140,143,146,148,150,153,155,157,158,160,162,163,164,165,167,168,169,169,170,171,172,172,173,174,174,175,175,176,128,131,134,137,139,142,144,147,149,151,153,155,157,158,160,161,163,164,165,166,167,168,169,170,170,171,172,173,173,174,174,175,128,131,133,136,139,141,144,146,148,150,152,154,155,157,159,160,161,163,164,165,166,167,168,168,169,170,171,171,172,173,173,174,128,131,133,136,138,140,143,145,147,149,151,153,154,156,157,159,160,161,162,163,165,165,166,167,168,169,170,170,171,171,172,173,128,130,133,135,137,140,142,144,146,148,150,151,153,155,156,157,159,160,161,162,163,164,165,166,167,168,168,169,170,170,171,172,128,130,133,135,137,139,141,143,145,147,149,150,152,153,155,156,158,159,160,161,162,163,164,165,166,167,167,168,169,169,170,171,128,130,132,134,136,138,140,142,144,146,148,149,151,152,154,155,157,158,159,160,161,162,163,164,165,166,166,167,168,168,169,170,128,130,132,134,136,138,140,142,144,145,147,148,150,151,153,154,155,157,158,159,160,161,162,163,164,165,165,166,167,167,168,169,128,130,132,134,136,138,139,141,143,144,146,148,149,151,152,153,155,156,157,158,159,160,161,162,163,164,164,165,166,166,167,168,128,130,132,134,135,137,139,141,142,144,145,147,148,150,151,152,154,155,156,157,158,159,160,161,162,163,163,164,165,166,166,167,128,130,132,133,135,137,138,140,142,143,145,146,148,149,150,152,153,154,155,156,157,158,159,160,161,162,162,163,164,165,165,166,128,130,131,133,135,136,138,140,141,143,144,146,147,148,150,151,152,153,154,155,156,157,158,159,160,161,162,162,163,164,165,165,128,130,131,133,134,136,138,139,141,142,144,145,146,148,149,150,151,152,153,154,155,156,157,158,159,160,161,162,162,163,164,164,128,130,131,133,134,136,137,139,140,142,143,144,146,147,148,149,150,152,153,154,155,156,157,158,158,159,160,161,162,162,163,164,128,130,131,133,134,135,137,138,140,141,142,144,145,146,147,149,150,151,152,153,154,155,156,157,158,158,159,160,161,161,162,163,128,129,131,132,134,135,137,138,139,141,142,143,144,146,147,148,149,150,151,152,153,154,155,156,157,158,158,159,160,161,161,162,128,129,131,132,134,135,136,138,139,140,142,143,144,145,146,147,149,150,151,152,153,154,154,155,156,157,158,159,159,160,161,161,128,129,131,132,133,135,136,137,139,140,141,142,144,145,146,147,148,149,150,151,152,153,154,155,155,156,157,158,159,159,160,161,128,129,131,132,133,135,136,137,138,140,141,142,143,144,145,146,147,148,149,150,151,152,153,154,155,156,156,157,158,159,159,160,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,6,0,7,0,0,0,32,0,64,0,128,0,54,10,0,0,98,3,0,0,174,0,0,0,2,10,0,0,154,13,0,0,132,7,0,0,54,6,0,0,232,8,0,0,76,15,0,0,60,10,0,0,22,1,0,0,158,14,0,0,100,0,0,0,90,14,0,0,12,2,0,0,8,8,0,0,240,16,0,0,144,1,0,0,170,13,0,0,114,10,0,0,112,17,0,0,88,9,0,0,240,13,0,0,100,10,0,0,156,7,0,0,24,17,0,0,32,15,0,0,236,1,0,0,180,11,0,0,210,10,0,0,84,17,0,0,186,8,0,0,180,14,0,0,130,5,0,0,166,12,0,0,220,7,0,0,254,11,0,0,158,0,0,0,54,0,0,0,98,16,0,0,218,7,0,0,170,6,0,0,124,15,0,0,136,11,0,0,102,7,0,0,60,3,0,0,204,5,0,0,88,3,0,0,208,13,0,0,108,7,0,0,32,16,0,0,104,1,0,0,92,16,0,0,150,14,0,0,214,15,0,0,156,8,0,0,112,16,0,0,226,13,0,0,86,17,0,0,212,6,0,0,66,13,0,0,128,16,0,0,74,8,0,0,144,4,0,0,150,5,0,0,64,2,0,0,116,9,0,0,148,14,0,0,242,2,0,0,68,3,0,0,238,3,0,0,44,1,0,0,248,6,0,0,74,1,0,0,50,6,0,0,110,15,0,0,32,2,0,0,82,11,0,0,156,5,0,0,158,13,0,0,200,15,0,0,90,11,0,0,76,14,0,0,210,3,0,0,80,15,0,0,202,7,0,0,118,13,0,0,176,5,0,0,96,11,0,0,178,8,0,0,168,14,0,0,90,10,0,0,10,16,0,0,204,13,0,0,226,3,0,0,112,13,0,0,214,0,0,0,122,3,0,0,236,4,0,0,150,15,0,0,250,1,0,0,76,11,0,0,234,7,0,0,122,8,0,0,34,9,0,0,242,4,0,0,144,12,0,0,204,4,0,0,250,7,0,0,84,12,0,0,188,4,0,0,64,10,0,0,136,15,0,0,106,10,0,0,72,17,0,0,252,10,0,0,80,17,0,0,2,5,0,0,154,16,0,0,56,4,0,0,94,8,0,0,74,5,0,0,120,11,0,0,56,3,0,0,194,15,0,0,46,11,0,0,68,10,0,0,60,4,0,0,250,13,0,0,116,17,0,0,148,7,0,0,234,3,0,0,120,14,0,0,144,14,0,0,88,6,0,0,238,1,0,0,142,0,0,0,38,16,0,0,222,7,0,0,64,16,0,0,24,2,0,0,114,17,0,0,36,2,0,0,232,12,0,0,100,1,0,0,160,0,0,0,250,9,0,0,46,17,0,0,210,6,0,0,68,2,0,0,52,6,0,0,38,3,0,0,30,5,0,0,46,14,0,0,48,4,0,0,180,0,0,0,18,15,0,0,98,15,0,0,26,16,0,0,62,9,0,0,128,7,0,0,16,15,0,0,108,15,0,0,144,10,0,0,192,7,0,0,190,10,0,0,242,16,0,0,48,5,0,0,188,6,0,0,24,7,0,0,152,5,0,0,246,1,0,0,2,8,0,0,152,10,0,0,224,3,0,0,232,13,0,0,32,8,0,0,230,0,0,0,104,13,0,0,194,10,0,0,188,7,0,0,242,9,0,0,86,11,0,0,18,4,0,0,94,17,0,0,238,6,0,0,146,7,0,0,172,2,0,0,10,6,0,0,166,2,0,0,158,2,0,0,2,11,0,0,44,12,0,0,104,4,0,0,186,6,0,0,4,0,0,0,182,11,0,0,192,0,0,0,158,8,0,0,110,1,0,0,102,11,0,0,244,4,0,0,30,16,0,0,112,4,0,0,20,12,0,0,198,15,0,0,228,10,0,0,226,1,0,0,228,3,0,0,96,14,0,0,156,16,0,0,84,15,0,0,116,2,0,0,208,12,0,0,74,16,0,0,14,10,0,0,110,13,0,0,176,4,0,0,208,1,0,0,110,16,0,0,190,16,0,0,144,2,0,0,230,3,0,0,146,10,0,0,90,5,0,0,182,5,0,0,22,4,0,0,134,5,0,0,242,5,0,0,108,5,0,0,234,13,0,0,96,4,0,0,32,11,0,0,8,12,0,0,222,13,0,0,186,5,0,0,126,13,0,0,154,8,0,0,200,8,0,0,164,13,0,0,98,4,0,0,126,17,0,0,160,13,0,0,192,15,0,0,28,7,0,0,62,16,0,0,216,12,0,0,156,0,0,0,206,5,0,0,154,4,0,0,212,2,0,0,100,14,0,0,140,10,0,0,118,8,0,0,216,15,0,0,244,13,0,0,54,10,0,0,178,4,0,0,174,0,0,0,122,0,0,0,6,8,0,0,14,1,0,0,234,5,0,0,198,12,0,0,6,6,0,0,50,13,0,0,230,8,0,0,216,2,0,0,90,1,0,0,54,11,0,0,172,13,0,0,142,9,0,0,10,11,0,0,214,8,0,0,172,4,0,0,170,2,0,0,66,17,0,0,70,10,0,0,204,10,0,0,246,15,0,0,156,7,0,0,84,6,0,0,182,13,0,0,236,1,0,0,44,7,0,0,130,7,0,0,66,5,0,0,76,6,0,0,110,2,0,0,90,16,0,0,164,9,0,0,110,10,0,0,138,8,0,0,24,1,0,0,174,4,0,0,102,0,0,0,190,9,0,0,146,12,0,0,150,2,0,0,80,8,0,0,160,6,0,0,224,7,0,0,10,1,0,0,216,1,0,0,202,5,0,0,218,12,0,0,246,3,0,0,168,8,0,0,204,14,0,0,58,14,0,0,246,6,0,0,56,16,0,0,112,16,0,0,242,7,0,0,108,2,0,0,212,6,0,0,250,6,0,0,148,4,0,0,194,7,0,0,190,11,0,0,150,5,0,0,128,17,0,0,116,9,0,0,30,3,0,0,152,2,0,0,66,3,0,0,254,4,0,0,50,11,0,0,52,1,0,0,186,0,0,0,230,6,0,0,226,7,0,0,148,17,0,0,206,7,0,0,206,4,0,0,82,17,0,0,38,12,0,0,20,9,0,0,76,10,0,0,230,13,0,0,110,5,0,0,196,3,0,0,180,9,0,0,82,9,0,0,96,11,0,0,248,5,0,0,216,8,0,0,90,10,0,0,196,7,0,0,120,4,0,0,174,12,0,0,78,13,0,0,34,3,0,0,106,13,0,0,248,10,0,0,218,6,0,0,192,11,0,0,164,8,0,0,96,5,0,0,114,8,0,0,8,11,0,0,138,14,0,0,220,4,0,0,176,8,0,0,34,8,0,0,42,16,0,0,102,17,0,0,90,8,0,0,238,8,0,0,126,8,0,0,128,15,0,0,224,6,0,0,172,9,0,0,220,13,0,0,164,5,0,0,174,16,0,0,94,8,0,0,140,1,0,0,134,12,0,0,56,3,0,0,190,0,0,0,202,8,0,0,232,6,0,0,224,10,0,0,236,3,0,0,238,11,0,0,222,10,0,0,14,4,0,0,60,11,0,0,152,1,0,0,36,11,0,0,120,1,0,0,176,3,0,0,228,2,0,0,250,8,0,0,80,5,0,0,78,14,0,0,166,10,0,0,164,10,0,0,220,15,0,0,102,12,0,0,108,8,0,0,216,0,0,0,150,13,0,0,118,4,0,0,156,2,0,0,224,8,0,0,132,8,0,0,68,8,0,0,124,1,0,0,48,4,0,0,14,2,0,0,14,0,0,0,46,0,0,0,116,10,0,0,190,5,0,0,246,9,0,0,150,10,0,0,98,2,0,0,36,15,0,0,0,12,0,0,98,5,0,0,44,3,0,0,224,0,0,0,172,0,0,0,128,11,0,0,88,4,0,0,54,4,0,0,0,9,0,0,198,10,0,0,8,4,0,0,102,14,0,0,92,10,0,0,4,3,0,0,160,2,0,0,114,9,0,0,32,12,0,0,82,13,0,0,106,5,0,0,166,8,0,0,94,17,0,0,90,4,0,0,202,4,0,0,216,5,0,0,0,5,0,0,72,9,0,0,28,2,0,0,56,1,0,0,16,12,0,0,174,2,0,0,244,6,0,0,132,1,0,0,188,8,0,0,42,3,0,0,236,8,0,0,58,3,0,0,202,13,0,0,28,17,0,0,4,4,0,0,112,4,0,0,76,8,0,0,48,3,0,0,182,14,0,0,34,7,0,0,168,7,0,0,232,3,0,0,118,1,0,0,96,17,0,0,24,16,0,0,14,16,0,0,200,5,0,0,112,12,0,0,110,13,0,0,28,4,0,0,58,2,0,0,110,16,0,0,86,1,0,0,168,4,0,0,14,17,0,0,16,3,0,0,192,16,0,0,24,3,0,0,52,3,0,0,106,8,0,0,132,11,0,0,18,12,0,0,140,11,0,0,114,15,0,0,78,1,0,0,228,0,0,0,222,13,0,0,186,5,0,0,44,9,0,0,48,11,0,0,242,13,0,0,4,1,0,0,176,12,0,0,214,12,0,0,190,8,0,0,106,15,0,0,136,9,0,0,240,7,0,0,188,13,0,0,102,16,0,0,206,5,0,0,250,0,0,0,38,11,0,0,100,14,0,0,244,7,0,0,226,9,0,0,120,17,0,0,188,10,0,0,54,10,0,0,178,4,0,0,174,0,0,0,122,0,0,0,6,8,0,0,14,1,0,0,234,5,0,0,198,12,0,0,6,6,0,0,50,13,0,0,230,8,0,0,216,2,0,0,90,1,0,0,54,11,0,0,172,13,0,0,142,9,0,0,10,11,0,0,208,10,0,0,172,4,0,0,170,2,0,0,66,17,0,0,70,10,0,0,204,10,0,0,246,15,0,0,156,7,0,0,44,11,0,0,182,13,0,0,236,1,0,0,44,7,0,0,52,10,0,0,120,13,0,0,76,6,0,0,110,2,0,0,90,16,0,0,164,9,0,0,110,10,0,0,138,8,0,0,24,1,0,0,174,4,0,0,102,0,0,0,190,9,0,0,146,12,0,0,150,2,0,0,80,8,0,0,160,6,0,0,224,7,0,0,10,1,0,0,216,1,0,0,202,5,0,0,108,1,0,0,246,3,0,0,168,8,0,0,204,14,0,0,58,14,0,0,246,6,0,0,56,16,0,0,112,16,0,0,154,2,0,0,108,2,0,0,212,6,0,0,148,16,0,0,204,8,0,0,254,8,0,0,190,11,0,0,150,5,0,0,128,17,0,0,116,9,0,0,30,3,0,0,50,2,0,0,66,3,0,0,254,4,0,0,50,11,0,0,52,1,0,0,186,0,0,0,230,6,0,0,226,7,0,0,148,17,0,0,206,7,0,0,206,4,0,0,82,17,0,0,38,12,0,0,96,6,0,0,76,10,0,0,230,13,0,0,210,11,0,0,196,3,0,0,180,9,0,0,82,9,0,0,96,11,0,0,118,14,0,0,62,7,0,0,90,10,0,0,196,7,0,0,208,3,0,0,38,8,0,0,78,13,0,0,34,3,0,0,106,13,0,0,248,10,0,0,218,6,0,0,192,11,0,0,164,8,0,0,96,5,0,0,114,8,0,0,8,11,0,0,138,14,0,0,220,4,0,0,176,8,0,0,34,8,0,0,42,16,0,0,102,17,0,0,90,8,0,0,238,8,0,0,194,11,0,0,128,15,0,0,224,6,0,0,172,9,0,0,220,13,0,0,164,5,0,0,174,16,0,0,94,8,0,0,236,12,0,0,204,15,0,0,56,3,0,0,190,0,0,0,82,12,0,0,146,2,0,0,224,10,0,0,236,3,0,0,238,11,0,0,222,10,0,0,14,4,0,0,190,15,0,0,152,1,0,0,70,11,0,0,120,1,0,0,92,17,0,0,228,2,0,0,250,8,0,0,80,5,0,0,146,15,0,0,166,10,0,0,220,12,0,0,220,15,0,0,102,12,0,0,160,14,0,0,216,0,0,0,150,13,0,0,192,5,0,0,156,2,0,0,208,14,0,0,132,8,0,0,68,8,0,0,252,2,0,0,48,4,0,0,168,10,0,0,14,0,0,0,108,12,0,0,104,6,0,0,190,5,0,0,172,16,0,0,150,10,0,0,168,11,0,0,36,15,0,0,90,9,0,0,98,5,0,0,86,15,0,0,224,0,0,0,50,8,0,0,128,11,0,0,242,8,0,0,54,4,0,0,112,1,0,0,198,10,0,0,232,7,0,0,102,14,0,0,92,10,0,0,204,1,0,0,160,2,0,0,114,9,0,0,194,12,0,0,82,13,0,0,198,8,0,0,166,8,0,0,94,17,0,0,8,1,0,0,244,5,0,0,10,17,0,0,110,4,0,0,106,6,0,0,54,8,0,0,56,1,0,0,234,10,0,0,174,2,0,0,244,6,0,0,132,1,0,0,206,9,0,0,42,3,0,0,236,8,0,0,58,3,0,0,222,15,0,0,28,17,0,0,150,4,0,0,112,4,0,0,12,5,0,0,48,3,0,0,182,14,0,0,34,7,0,0,168,7,0,0,20,3,0,0,118,1,0,0,96,17,0,0,24,16,0,0,14,16,0,0,200,5,0,0,112,12,0,0,110,13,0,0,252,4,0,0,226,15,0,0,110,16,0,0,86,1,0,0,62,10,0,0,204,11,0,0,16,3,0,0,134,9,0,0,24,3,0,0,52,3,0,0,106,8,0,0,108,0,0,0,18,12,0,0,140,11,0,0,114,15,0,0,238,12,0,0,228,0,0,0,222,13,0,0,186,5,0,0,68,0,0,0,48,11,0,0,242,13,0,0,4,1,0,0,176,12,0,0,44,8,0,0,190,8,0,0,106,15,0,0,136,9,0,0,240,7,0,0,188,13,0,0,102,16,0,0,206,5,0,0,4,14,0,0,40,5,0,0,100,14,0,0,244,7,0,0,50,4,0,0,226,16,0,0,188,10,0,0,54,10,0,0,126,4,0,0,174,0,0,0,188,0,0,0,216,7,0,0,84,1,0,0,12,6,0,0,14,6,0,0,6,6,0,0,144,11,0,0,140,16,0,0,216,2,0,0,104,16,0,0,94,13,0,0,162,14,0,0,142,11,0,0,10,11,0,0,98,13,0,0,36,8,0,0,210,1,0,0,106,12,0,0,142,8,0,0,166,7,0,0,218,15,0,0,156,7,0,0,132,6,0,0,82,10,0,0,236,1,0,0,84,8,0,0,142,5,0,0,0,1,0,0,162,2,0,0,110,2,0,0,58,5,0,0,164,9,0,0,162,4,0,0,158,12,0,0,174,14,0,0,52,4,0,0,64,13,0,0,190,9,0,0,108,6,0,0,130,15,0,0,80,8,0,0,170,0,0,0,218,8,0,0,164,14,0,0,56,6,0,0,202,5,0,0,10,0,0,0,188,9,0,0,70,14,0,0,128,3,0,0,102,6,0,0,228,9,0,0,70,13,0,0,112,16,0,0,34,5,0,0,206,11,0,0,212,6,0,0,98,14,0,0,2,0,0,0,180,15,0,0,208,0,0,0,150,5,0,0,8,17,0,0,116,9,0,0,132,5,0,0,152,2,0,0,176,10,0,0,228,12,0,0,52,0,0,0,62,14,0,0,94,10,0,0,230,9,0,0,226,7,0,0,148,17,0,0,178,14,0,0,238,2,0,0,34,2,0,0,38,12,0,0,40,16,0,0,48,1,0,0,80,4,0,0,110,5,0,0,158,1,0,0,54,12,0,0,78,17,0,0,96,11,0,0,220,8,0,0,216,8,0,0,90,10,0,0,196,7,0,0,208,7,0,0,4,16,0,0,52,11,0,0,34,3,0,0,10,14,0,0,248,10,0,0,48,15,0,0,100,9,0,0,214,16,0,0,42,11,0,0,198,9,0,0,86,8,0,0,26,17,0,0,2,12,0,0,176,8,0,0,34,8,0,0,130,17,0,0,138,11,0,0,188,11,0,0,238,8,0,0,136,10,0,0,112,10,0,0,112,9,0,0,196,15,0,0,116,15,0,0,122,5,0,0,154,9,0,0,94,8,0,0,110,7,0,0,134,12,0,0,56,3,0,0,190,0,0,0,130,10,0,0,88,5,0,0,168,13,0,0,236,3,0,0,246,5,0,0,222,10,0,0,244,12,0,0,60,11,0,0,250,2,0,0,36,11,0,0,224,15,0,0,176,3,0,0,98,8,0,0,144,6,0,0,80,5,0,0,78,14,0,0,10,9,0,0,164,10,0,0,74,15,0,0,102,12,0,0,116,13,0,0,150,16,0,0,220,10,0,0,118,4,0,0,182,2,0,0,224,8,0,0,240,5,0,0,230,15,0,0,118,16,0,0,48,4,0,0,14,2,0,0,142,13,0,0,102,1,0,0,234,8,0,0,214,13,0,0,246,9,0,0,112,8,0,0,98,2,0,0,20,10,0,0,0,12,0,0,26,7,0,0,44,3,0,0,206,15,0,0,172,0,0,0,118,5,0,0,88,4,0,0,54,4,0,0,0,9,0,0,148,12,0,0,8,4,0,0,122,1,0,0,92,10,0,0,54,16,0,0,78,15,0,0,30,2,0,0,32,12,0,0,66,16,0,0,106,5,0,0,6,11,0,0,94,17,0,0,52,2,0,0,202,4,0,0,216,5,0,0,0,5,0,0,12,0,0,0,28,2,0,0,188,16,0,0,16,12,0,0,162,16,0,0,244,6,0,0,240,2,0,0,188,8,0,0,252,1,0,0,66,9,0,0,32,10,0,0,202,13,0,0,226,0,0,0,4,4,0,0,112,4,0,0,76,8,0,0,10,5,0,0,176,13,0,0,42,7,0,0,168,7,0,0,32,3,0,0,190,2,0,0,68,5,0,0,24,16,0,0,104,14,0,0,32,5,0,0,168,5,0,0,110,13,0,0,8,15,0,0,58,2,0,0,110,16,0,0,86,1,0,0,164,7,0,0,20,8,0,0,166,4,0,0,192,16,0,0,16,4,0,0,52,3,0,0,146,4,0,0,132,11,0,0,166,14,0,0,36,3,0,0,134,11,0,0,78,1,0,0,74,14,0,0,222,13,0,0,186,5,0,0,44,9,0,0,80,7,0,0,92,1,0,0,112,6,0,0,176,12,0,0,74,13,0,0,214,4,0,0,122,14,0,0,136,9,0,0,68,13,0,0,218,0,0,0,78,9,0,0,206,5,0,0,150,12,0,0,38,11,0,0,100,14,0,0,244,7,0,0,200,10,0,0,194,4,0,0,234,9,0,0,54,10,0,0,126,4,0,0,174,0,0,0,188,0,0,0,216,7,0,0,84,1,0,0,12,6,0,0,14,6,0,0,6,6,0,0,144,11,0,0,140,16,0,0,216,2,0,0,104,16,0,0,94,13,0,0,162,14,0,0,142,11,0,0,10,11,0,0,74,12,0,0,36,8,0,0,210,1,0,0,106,12,0,0,142,8,0,0,166,7,0,0,218,15,0,0,156,7,0,0,220,11,0,0,82,10,0,0,236,1,0,0,84,8,0,0,226,12,0,0,142,10,0,0,162,2,0,0,110,2,0,0,58,5,0,0,164,9,0,0,162,4,0,0,158,12,0,0,174,14,0,0,52,4,0,0,64,13,0,0,190,9,0,0,108,6,0,0,130,15,0,0,80,8,0,0,170,0,0,0,218,8,0,0,164,14,0,0,56,6,0,0,202,5,0,0,196,16,0,0,188,9,0,0,70,14,0,0,128,3,0,0,102,6,0,0,228,9,0,0,70,13,0,0,112,16,0,0,228,4,0,0,206,11,0,0,212,6,0,0,2,2,0,0,154,0,0,0,234,1,0,0,208,0,0,0,150,5,0,0,8,17,0,0,116,9,0,0,132,5,0,0,50,2,0,0,176,10,0,0,228,12,0,0,52,0,0,0,62,14,0,0,94,10,0,0,230,9,0,0,226,7,0,0,148,17,0,0,178,14,0,0,238,2,0,0,34,2,0,0,38,12,0,0,16,1,0,0,48,1,0,0,80,4,0,0,210,11,0,0,158,1,0,0,54,12,0,0,78,17,0,0,96,11,0,0,80,13,0,0,62,7,0,0,90,10,0,0,196,7,0,0,66,7,0,0,86,6,0,0,52,11,0,0,34,3,0,0,10,14,0,0,248,10,0,0,48,15,0,0,100,9,0,0,214,16,0,0,42,11,0,0,198,9,0,0,86,8,0,0,26,17,0,0,2,12,0,0,176,8,0,0,34,8,0,0,130,17,0,0,138,11,0,0,188,11,0,0,238,8,0,0,232,1,0,0,112,10,0,0,112,9,0,0,196,15,0,0,116,15,0,0,122,5,0,0,154,9,0,0,94,8,0,0,220,16,0,0,204,15,0,0,56,3,0,0,190,0,0,0,238,4,0,0,226,2,0,0,168,13,0,0,236,3,0,0,246,5,0,0,222,10,0,0,244,12,0,0,190,15,0,0,250,2,0,0,70,11,0,0,224,15,0,0,92,17,0,0,98,8,0,0,144,6,0,0,80,5,0,0,146,15,0,0,10,9,0,0,220,12,0,0,74,15,0,0,102,12,0,0,36,10,0,0,150,16,0,0,220,10,0,0,192,5,0,0,182,2,0,0,208,14,0,0,240,5,0,0,230,15,0,0,124,17,0,0,48,4,0,0,168,10,0,0,142,13,0,0,104,2,0,0,28,14,0,0,214,13,0,0,172,16,0,0,112,8,0,0,168,11,0,0,20,10,0,0,90,9,0,0,26,7,0,0,86,15,0,0,206,15,0,0,50,8,0,0,118,5,0,0,242,8,0,0,54,4,0,0,112,1,0,0,148,12,0,0,232,7,0,0,122,1,0,0,92,10,0,0,148,15,0,0,78,15,0,0,30,2,0,0,194,12,0,0,66,16,0,0,198,8,0,0,6,11,0,0,94,17,0,0,76,1,0,0,244,5,0,0,10,17,0,0,110,4,0,0,8,5,0,0,54,8,0,0,188,16,0,0,234,10,0,0,162,16,0,0,244,6,0,0,240,2,0,0,206,9,0,0,252,1,0,0,66,9,0,0,32,10,0,0,222,15,0,0,226,0,0,0,150,4,0,0,112,4,0,0,12,5,0,0,10,5,0,0,176,13,0,0,42,7,0,0,168,7,0,0,52,5,0,0,190,2,0,0,68,5,0,0,24,16,0,0,104,14,0,0,32,5,0,0,168,5,0,0,110,13,0,0,66,11,0,0,226,15,0,0,110,16,0,0,86,1,0,0,30,1,0,0,104,10,0,0,166,4,0,0,134,9,0,0,16,4,0,0,52,3,0,0,146,4,0,0,108,0,0,0,166,14,0,0,36,3,0,0,134,11,0,0,238,12,0,0,74,14,0,0,222,13,0,0,186,5,0,0,68,0,0,0,80,7,0,0,92,1,0,0,112,6,0,0,176,12,0,0,136,8,0,0,214,4,0,0,122,14,0,0])
.concat([136,9,0,0,68,13,0,0,218,0,0,0,78,9,0,0,206,5,0,0,114,12,0,0,40,5,0,0,100,14,0,0,244,7,0,0,152,16,0,0,164,6,0,0,234,9,0,0,66,14,0,0,160,5,0,0,64,14,0,0,212,13,0,0,60,7,0,0,58,6,0,0,34,6,0,0,198,16,0,0,222,12,0,0,170,8,0,0,214,1,0,0,118,15,0,0,82,4,0,0,254,13,0,0,240,1,0,0,252,12,0,0,88,13,0,0,6,3,0,0,142,12,0,0,86,4,0,0,110,9,0,0,170,16,0,0,106,14,0,0,62,2,0,0,112,15,0,0,40,14,0,0,200,7,0,0,96,15,0,0,42,9,0,0,124,5,0,0,14,12,0,0,212,1,0,0,100,16,0,0,80,10,0,0,50,0,0,0,106,16,0,0,228,6,0,0,156,4,0,0,76,16,0,0,244,15,0,0,214,14,0,0,142,17,0,0,120,15,0,0,70,8,0,0,140,12,0,0,248,8,0,0,110,14,0,0,224,13,0,0,152,0,0,0,172,8,0,0,114,13,0,0,190,7,0,0,116,1,0,0,154,12,0,0,80,2,0,0,178,9,0,0,32,13,0,0,128,14,0,0,170,4,0,0,246,12,0,0,178,3,0,0,100,13,0,0,6,17,0,0,30,9,0,0,50,1,0,0,122,17,0,0,56,10,0,0,160,10,0,0,206,13,0,0,174,10,0,0,70,2,0,0,192,8,0,0,212,15,0,0,108,16,0,0,156,1,0,0,158,4,0,0,164,12,0,0,132,12,0,0,162,6,0,0,48,7,0,0,208,11,0,0,50,10,0,0,84,11,0,0,244,14,0,0,64,9,0,0,88,1,0,0,98,11,0,0,136,2,0,0,22,3,0,0,210,13,0,0,170,7,0,0,0,3,0,0,168,2,0,0,14,14,0,0,70,4,0,0,6,14,0,0,40,1,0,0,0,8,0,0,212,12,0,0,24,15,0,0,56,11,0,0,156,13,0,0,78,12,0,0,246,10,0,0,208,2,0,0,150,0,0,0,58,10,0,0,78,7,0,0,248,9,0,0,48,0,0,0,72,10,0,0,82,1,0,0,78,4,0,0,154,7,0,0,248,15,0,0,124,6,0,0,244,1,0,0,186,10,0,0,188,14,0,0,52,8,0,0,164,0,0,0,244,8,0,0,46,3,0,0,124,0,0,0,134,8,0,0,212,7,0,0,202,15,0,0,8,9,0,0,174,9,0,0,218,16,0,0,148,8,0,0,254,0,0,0,22,12,0,0,210,12,0,0,254,10,0,0,152,8,0,0,78,10,0,0,54,7,0,0,246,8,0,0,72,13,0,0,2,3,0,0,26,2,0,0,122,6,0,0,6,1,0,0,192,14,0,0,252,8,0,0,84,4,0,0,170,5,0,0,134,4,0,0,82,8,0,0,222,8,0,0,212,3,0,0,78,6,0,0,46,5,0,0,88,8,0,0,80,12,0,0,116,3,0,0,202,12,0,0,178,10,0,0,56,12,0,0,216,13,0,0,70,0,0,0,144,0,0,0,94,1,0,0,226,6,0,0,206,14,0,0,30,17,0,0,242,15,0,0,102,10,0,0,30,14,0,0,120,5,0,0,178,6,0,0,138,6,0,0,236,6,0,0,26,14,0,0,168,16,0,0,62,11,0,0,42,5,0,0,230,12,0,0,96,13,0,0,198,13,0,0,218,2,0,0,96,8,0,0,70,5,0,0,106,0,0,0,46,15,0,0,52,7,0,0,252,16,0,0,92,13,0,0,46,1,0,0,146,13,0,0,196,13,0,0,4,6,0,0,12,14,0,0,214,3,0,0,2,13,0,0,236,5,0,0,176,9,0,0,120,6,0,0,116,4,0,0,72,16,0,0,244,11,0,0,70,16,0,0,130,1,0,0,50,15,0,0,48,2,0,0,60,14,0,0,84,3,0,0,178,2,0,0,44,16,0,0,136,1,0,0,44,10,0,0,178,16,0,0,10,4,0,0,114,4,0,0,124,16,0,0,46,8,0,0,162,7,0,0,86,3,0,0,254,7,0,0,252,11,0,0,40,11,0,0,48,8,0,0,180,16,0,0,148,5,0,0,92,9,0,0,4,10,0,0,190,4,0,0,228,15,0,0,184,5,0,0,104,12,0,0,234,6,0,0,198,7,0,0,198,14,0,0,92,15,0,0,98,9,0,0,224,16,0,0,250,10,0,0,126,3,0,0,102,13,0,0,26,15,0,0,170,12,0,0,20,4,0,0,58,11,0,0,44,14,0,0,44,15,0,0,184,6,0,0,82,7,0,0,140,5,0,0,68,16,0,0,136,14,0,0,180,5,0,0,40,3,0,0,196,12,0,0,70,3,0,0,162,13,0,0,66,14,0,0,224,1,0,0,64,14,0,0,208,4,0,0,238,13,0,0,248,16,0,0,48,9,0,0,198,4,0,0,130,14,0,0,102,9,0,0,70,1,0,0,236,15,0,0,148,1,0,0,80,11,0,0,32,14,0,0,216,6,0,0,110,12,0,0,242,12,0,0,22,15,0,0,52,12,0,0,124,7,0,0,254,12,0,0,68,1,0,0,138,16,0,0,112,15,0,0,240,6,0,0,38,1,0,0,96,15,0,0,100,6,0,0,0,10,0,0,122,13,0,0,232,15,0,0,40,12,0,0,48,12,0,0,0,17,0,0,180,4,0,0,212,4,0,0,98,17,0,0,26,13,0,0,76,0,0,0,214,2,0,0,126,5,0,0,140,14,0,0,106,7,0,0,222,9,0,0,138,10,0,0,80,14,0,0,242,10,0,0,116,16,0,0,140,15,0,0,142,6,0,0,104,0,0,0,178,0,0,0,206,8,0,0,108,10,0,0,156,14,0,0,32,13,0,0,86,10,0,0,182,16,0,0,246,12,0,0,240,14,0,0,140,2,0,0,168,6,0,0,180,6,0,0,50,1,0,0,94,15,0,0,56,10,0,0,40,2,0,0,94,6,0,0,150,17,0,0,104,5,0,0,138,0,0,0,254,16,0,0,216,4,0,0,192,2,0,0,220,0,0,0,10,2,0,0,232,2,0,0,18,8,0,0,156,10,0,0,250,4,0,0,30,15,0,0,166,5,0,0,160,7,0,0,218,10,0,0,70,17,0,0,132,16,0,0,206,2,0,0,22,3,0,0,172,10,0,0,18,14,0,0,0,3,0,0,4,17,0,0,212,14,0,0,174,6,0,0,132,10,0,0,216,11,0,0,14,9,0,0,218,1,0,0,192,13,0,0,146,17,0,0,92,14,0,0,10,12,0,0,0,14,0,0,208,5,0,0,74,9,0,0,6,16,0,0,46,16,0,0,210,16,0,0,90,15,0,0,180,10,0,0,228,16,0,0,146,16,0,0,6,9,0,0,94,14,0,0,80,16,0,0,226,4,0,0,96,10,0,0,80,9,0,0,214,11,0,0,164,0,0,0,30,6,0,0,94,16,0,0,124,0,0,0,126,0,0,0,234,14,0,0,244,2,0,0,200,2,0,0,112,3,0,0,172,11,0,0,242,6,0,0,18,1,0,0,236,7,0,0,178,13,0,0,126,10,0,0,54,14,0,0,40,15,0,0,120,16,0,0,204,12,0,0,164,1,0,0,138,12,0,0,198,11,0,0,196,14,0,0,74,7,0,0,140,17,0,0,228,8,0,0,240,8,0,0,6,2,0,0,32,1,0,0,240,3,0,0,16,16,0,0,222,6,0,0,20,14,0,0,234,2,0,0,88,8,0,0,8,0,0,0,86,14,0,0,76,12,0,0,208,15,0,0,134,6,0,0,120,3,0,0,18,17,0,0,152,7,0,0,186,16,0,0,196,4,0,0,88,16,0,0,246,16,0,0,76,4,0,0,8,2,0,0,230,7,0,0,40,13,0,0,44,2,0,0,118,10,0,0,158,16,0,0,172,5,0,0,200,11,0,0,146,0,0,0,250,14,0,0,176,14,0,0,210,0,0,0,122,2,0,0,74,11,0,0,250,12,0,0,136,5,0,0,106,0,0,0,212,0,0,0,70,7,0,0,14,5,0,0,56,2,0,0,254,1,0,0,166,16,0,0,42,8,0,0,238,10,0,0,48,14,0,0,70,9,0,0,28,3,0,0,218,3,0,0,126,12,0,0,132,17,0,0,102,8,0,0,10,15,0,0,68,12,0,0,36,14,0,0,130,1,0,0,212,16,0,0,196,2,0,0,110,17,0,0,62,3,0,0,184,7,0,0,4,12,0,0,238,14,0,0,182,9,0,0,184,11,0,0,64,11,0,0,74,10,0,0,94,9,0,0,46,8,0,0,158,9,0,0,246,13,0,0,254,7,0,0,252,7,0,0,72,0,0,0,146,8,0,0,22,7,0,0,92,6,0,0,24,10,0,0,84,9,0,0,36,16,0,0,140,13,0,0,38,7,0,0,108,14,0,0,176,11,0,0,218,14,0,0,144,15,0,0,92,15,0,0,98,9,0,0,248,2,0,0,50,16,0,0,248,1,0,0,116,11,0,0,26,1,0,0,116,6,0,0,24,4,0,0,96,1,0,0,58,16,0,0,212,8,0,0,192,10,0,0,126,1,0,0,140,5,0,0,108,9,0,0,18,16,0,0,180,5,0,0,130,6,0,0,166,11,0,0,12,8,0,0,236,16,0,0,66,14,0,0,224,1,0,0,64,14,0,0,208,4,0,0,238,13,0,0,248,16,0,0,48,9,0,0,198,4,0,0,130,14,0,0,102,9,0,0,70,1,0,0,236,15,0,0,148,1,0,0,80,11,0,0,32,14,0,0,216,6,0,0,110,12,0,0,240,12,0,0,22,15,0,0,52,12,0,0,124,7,0,0,254,12,0,0,68,1,0,0,138,16,0,0,112,15,0,0,62,13,0,0,38,1,0,0,96,15,0,0,100,6,0,0,230,4,0,0,124,13,0,0,232,15,0,0,40,12,0,0,48,12,0,0,0,17,0,0,180,4,0,0,212,4,0,0,98,17,0,0,26,13,0,0,76,0,0,0,214,2,0,0,126,5,0,0,140,14,0,0,106,7,0,0,222,9,0,0,138,10,0,0,80,14,0,0,242,10,0,0,116,16,0,0,138,15,0,0,142,6,0,0,104,0,0,0,178,0,0,0,206,8,0,0,108,10,0,0,156,14,0,0,32,13,0,0,88,10,0,0,182,16,0,0,246,12,0,0,242,14,0,0,138,2,0,0,12,16,0,0,180,6,0,0,50,1,0,0,94,15,0,0,56,10,0,0,40,2,0,0,246,0,0,0,150,17,0,0,104,5,0,0,138,0,0,0,254,16,0,0,216,4,0,0,192,2,0,0,220,0,0,0,10,2,0,0,232,2,0,0,18,8,0,0,156,10,0,0,250,4,0,0,28,15,0,0,166,5,0,0,160,7,0,0,216,10,0,0,70,17,0,0,132,16,0,0,206,2,0,0,22,3,0,0,246,7,0,0,16,14,0,0,0,3,0,0,4,17,0,0,210,14,0,0,176,6,0,0,132,10,0,0,216,11,0,0,14,9,0,0,218,1,0,0,192,13,0,0,146,17,0,0,92,14,0,0,10,12,0,0,0,14,0,0,208,5,0,0,74,9,0,0,6,16,0,0,46,16,0,0,210,16,0,0,90,15,0,0,180,10,0,0,228,16,0,0,146,16,0,0,4,9,0,0,94,14,0,0,80,16,0,0,226,4,0,0,96,10,0,0,80,9,0,0,214,11,0,0,164,0,0,0,32,6,0,0,16,17,0,0,124,0,0,0,126,0,0,0,232,14,0,0,246,2,0,0,200,2,0,0,112,3,0,0,172,11,0,0,242,6,0,0,18,1,0,0,238,7,0,0,178,13,0,0,128,10,0,0,54,14,0,0,42,15,0,0,120,16,0,0,204,12,0,0,164,1,0,0,136,12,0,0,198,11,0,0,194,14,0,0,74,7,0,0,140,17,0,0,226,8,0,0,240,8,0,0,6,2,0,0,34,1,0,0,240,3,0,0,176,1,0,0,222,6,0,0,20,14,0,0,236,2,0,0,88,8,0,0,6,0,0,0,86,14,0,0,82,5,0,0,210,15,0,0,134,6,0,0,106,1,0,0,18,17,0,0,150,7,0,0,186,16,0,0,22,9,0,0,88,16,0,0,244,16,0,0,76,4,0,0,164,3,0,0,230,7,0,0,42,13,0,0,44,2,0,0,120,10,0,0,158,16,0,0,174,5,0,0,200,11,0,0,146,0,0,0,232,10,0,0,176,14,0,0,210,0,0,0,174,13,0,0,74,11,0,0,248,12,0,0,136,5,0,0,106,0,0,0,102,4,0,0,172,6,0,0,16,5,0,0,54,2,0,0,0,2,0,0,164,16,0,0,42,8,0,0,236,10,0,0,48,14,0,0,70,9,0,0,28,3,0,0,216,3,0,0,126,12,0,0,132,17,0,0,102,8,0,0,6,15,0,0,68,12,0,0,38,14,0,0,130,1,0,0,252,13,0,0,196,2,0,0,110,17,0,0,62,3,0,0,184,7,0,0,6,12,0,0,238,14,0,0,182,9,0,0,184,11,0,0,64,11,0,0,74,10,0,0,94,9,0,0,46,8,0,0,156,9,0,0,248,13,0,0,254,7,0,0,252,7,0,0,74,0,0,0,144,8,0,0,22,7,0,0,90,6,0,0,24,10,0,0,84,9,0,0,36,16,0,0,138,13,0,0,38,7,0,0,108,14,0,0,176,11,0,0,216,14,0,0,144,15,0,0,92,15,0,0,98,9,0,0,216,16,0,0,50,16,0,0,248,1,0,0,116,11,0,0,26,1,0,0,118,6,0,0,24,4,0,0,96,1,0,0,58,16,0,0,212,8,0,0,192,10,0,0,126,1,0,0,140,5,0,0,106,9,0,0,20,16,0,0,180,5,0,0,130,6,0,0,76,17,0,0,10,8,0,0,236,16,0,0,66,14,0,0,222,1,0,0,64,14,0,0,104,9,0,0,236,13,0,0,250,16,0,0,46,9,0,0,200,4,0,0,130,14,0,0,176,2,0,0,72,1,0,0,236,15,0,0,150,1,0,0,78,11,0,0,34,14,0,0,214,6,0,0,110,12,0,0,246,14,0,0,20,15,0,0,50,12,0,0,126,7,0,0,0,13,0,0,66,1,0,0,136,16,0,0,112,15,0,0,36,6,0,0,36,1,0,0,96,15,0,0,98,6,0,0,30,7,0,0,230,1,0,0,72,14,0,0,40,12,0,0,76,5,0,0,0,17,0,0,156,12,0,0,210,4,0,0,100,17,0,0,24,13,0,0,78,0,0,0,214,2,0,0,128,5,0,0,142,14,0,0,106,7,0,0,224,9,0,0,154,1,0,0,82,14,0,0,240,10,0,0,116,16,0,0,220,2,0,0,140,6,0,0,98,0,0,0,176,0,0,0,208,8,0,0,248,0,0,0,154,14,0,0,32,13,0,0,30,8,0,0,176,16,0,0,246,12,0,0,116,14,0,0,234,4,0,0,172,14,0,0,182,6,0,0,50,1,0,0,118,17,0,0,56,10,0,0,46,2,0,0,94,6,0,0,152,17,0,0,102,5,0,0,140,0,0,0,0,11,0,0,218,4,0,0,194,2,0,0,220,0,0,0,10,2,0,0,230,2,0,0,22,8,0,0,154,10,0,0,250,4,0,0,186,15,0,0,184,14,0,0,158,7,0,0,218,10,0,0,74,17,0,0,130,16,0,0,204,2,0,0,22,3,0,0,72,12,0,0,18,14,0,0,0,3,0,0,4,17,0,0,166,9,0,0,184,4,0,0,134,10,0,0,216,11,0,0,12,9,0,0,218,1,0,0,194,13,0,0,144,17,0,0,126,16,0,0,64,5,0,0,2,14,0,0,210,5,0,0,66,2,0,0,8,16,0,0,46,16,0,0,210,16,0,0,72,4,0,0,182,10,0,0,254,2,0,0,146,16,0,0,170,9,0,0,122,16,0,0,78,16,0,0,224,4,0,0,98,10,0,0,76,9,0,0,212,11,0,0,164,0,0,0,228,13,0,0,94,16,0,0,124,0,0,0,126,0,0,0,88,17,0,0,196,0,0,0,202,2,0,0,112,3,0,0,170,11,0,0,242,6,0,0,20,1,0,0,236,7,0,0,206,12,0,0,126,10,0,0,56,14,0,0,40,15,0,0,134,16,0,0,6,4,0,0,164,1,0,0,138,12,0,0,196,11,0,0,196,14,0,0,72,7,0,0,140,17,0,0,26,9,0,0,232,16,0,0,4,2,0,0,32,1,0,0,242,3,0,0,16,16,0,0,220,6,0,0,22,14,0,0,184,0,0,0,88,8,0,0,8,0,0,0,84,14,0,0,196,5,0,0,86,13,0,0,136,6,0,0,120,3,0,0,20,17,0,0,152,7,0,0,184,16,0,0,196,4,0,0,86,16,0,0,246,16,0,0,74,4,0,0,8,2,0,0,228,7,0,0,40,13,0,0,44,2,0,0,118,10,0,0,160,16,0,0,172,5,0,0,202,11,0,0,146,0,0,0,126,14,0,0,186,14,0,0,108,4,0,0,122,2,0,0,72,11,0,0,250,12,0,0,138,5,0,0,106,0,0,0,220,3,0,0,70,7,0,0,14,5,0,0,56,2,0,0,84,16,0,0,166,16,0,0,40,8,0,0,238,10,0,0,184,12,0,0,70,9,0,0,26,3,0,0,218,3,0,0,124,12,0,0,134,17,0,0,50,3,0,0,10,15,0,0,66,12,0,0,36,14,0,0,130,1,0,0,212,16,0,0,198,2,0,0,108,17,0,0,64,3,0,0,184,7,0,0,210,7,0,0,68,11,0,0,184,9,0,0,184,11,0,0,200,14,0,0,206,1,0,0,96,9,0,0,46,8,0,0,236,9,0,0,246,13,0,0,254,7,0,0,252,7,0,0,54,17,0,0,16,9,0,0,20,7,0,0,92,6,0,0,240,4,0,0,84,9,0,0,34,16,0,0,140,13,0,0,36,7,0,0,12,17,0,0,174,11,0,0,218,14,0,0,142,15,0,0,92,15,0,0,98,9,0,0,248,2,0,0,52,16,0,0,212,10,0,0,118,11,0,0,26,1,0,0,198,5,0,0,26,4,0,0,98,1,0,0,58,16,0,0,210,8,0,0,46,12,0,0,128,1,0,0,140,5,0,0,92,11,0,0,18,16,0,0,180,5,0,0,130,6,0,0,4,11,0,0,116,12,0,0,234,16,0,0,66,14,0,0,222,1,0,0,64,14,0,0,104,9,0,0,236,13,0,0,250,16,0,0,46,9,0,0,200,4,0,0,130,14,0,0,176,2,0,0,72,1,0,0,236,15,0,0,150,1,0,0,78,11,0,0,34,14,0,0,214,6,0,0,110,12,0,0,248,14,0,0,20,15,0,0,50,12,0,0,126,7,0,0,0,13,0,0,66,1,0,0,136,16,0,0,112,15,0,0,106,17,0,0,36,1,0,0,96,15,0,0,98,6,0,0,32,7,0,0,228,1,0,0,72,14,0,0,40,12,0,0,76,5,0,0,0,17,0,0,156,12,0,0,210,4,0,0,100,17,0,0,24,13,0,0,78,0,0,0,214,2,0,0,128,5,0,0,142,14,0,0,106,7,0,0,224,9,0,0,154,1,0,0,82,14,0,0,240,10,0,0,116,16,0,0,222,2,0,0,140,6,0,0,98,0,0,0,176,0,0,0,208,8,0,0,248,0,0,0,154,14,0,0,32,13,0,0,28,8,0,0,176,16,0,0,246,12,0,0,114,14,0,0,6,10,0,0,170,14,0,0,182,6,0,0,50,1,0,0,118,17,0,0,56,10,0,0,46,2,0,0,246,0,0,0,152,17,0,0,102,5,0,0,140,0,0,0,0,11,0,0,218,4,0,0,194,2,0,0,220,0,0,0,10,2,0,0,230,2,0,0,22,8,0,0,154,10,0,0,250,4,0,0,188,15,0,0,184,14,0,0,158,7,0,0,216,10,0,0,74,17,0,0,130,16,0,0,204,2,0,0,22,3,0,0,70,12,0,0,16,14,0,0,0,3,0,0,4,17,0,0,168,9,0,0,182,4,0,0,134,10,0,0,216,11,0,0,12,9,0,0,218,1,0,0,194,13,0,0,144,17,0,0,126,16,0,0,64,5,0,0,2,14,0,0,210,5,0,0,66,2,0,0,8,16,0,0,46,16,0,0,210,16,0,0,72,4,0,0,182,10,0,0,254,2,0,0,146,16,0,0,244,3,0,0,122,16,0,0,78,16,0,0,224,4,0,0,98,10,0,0,76,9,0,0,212,11,0,0,164,0,0,0,146,5,0,0,16,17,0,0,124,0,0,0,126,0,0,0,90,17,0,0,194,0,0,0,202,2,0,0,112,3,0,0,170,11,0,0,242,6,0,0,20,1,0,0,238,7,0,0,206,12,0,0,128,10,0,0,56,14,0,0,42,15,0,0,134,16,0,0,6,4,0,0,164,1,0,0,136,12,0,0,196,11,0,0,194,14,0,0,72,7,0,0,140,17,0,0,28,9,0,0,232,16,0,0,4,2,0,0,34,1,0,0,242,3,0,0,176,1,0,0,220,6,0,0,22,14,0,0,182,0,0,0,88,8,0,0,6,0,0,0,84,14,0,0,134,15,0,0,84,13,0,0,136,6,0,0,106,1,0,0,20,17,0,0,150,7,0,0,184,16,0,0,22,9,0,0,86,16,0,0,244,16,0,0,74,4,0,0,164,3,0,0,228,7,0,0,42,13,0,0,44,2,0,0,120,10,0,0,160,16,0,0,174,5,0,0,202,11,0,0,146,0,0,0,124,14,0,0,186,14,0,0,108,4,0,0,174,13,0,0,72,11,0,0,248,12,0,0,138,5,0,0,106,0,0,0,222,3,0,0,172,6,0,0,16,5,0,0,54,2,0,0,82,16,0,0,164,16,0,0,40,8,0,0,236,10,0,0,184,12,0,0,70,9,0,0,26,3,0,0,216,3,0,0,124,12,0,0,134,17,0,0,50,3,0,0,6,15,0,0,66,12,0,0,38,14,0,0,130,1,0,0,252,13,0,0,198,2,0,0,108,17,0,0,64,3,0,0,184,7,0,0,244,9,0,0,68,11,0,0,184,9,0,0,184,11,0,0,200,14,0,0,206,1,0,0,96,9,0,0,46,8,0,0,238,9,0,0,248,13,0,0,254,7,0,0,252,7,0,0,52,17,0,0,18,9,0,0,20,7,0,0,90,6,0,0,240,4,0,0,84,9,0,0,34,16,0,0,138,13,0,0,36,7,0,0,12,17,0,0,174,11,0,0,216,14,0,0,142,15,0,0,92,15,0,0,98,9,0,0,216,16,0,0,52,16,0,0,212,10,0,0,118,11,0,0,26,1,0,0,132,15,0,0,26,4,0,0,98,1,0,0,58,16,0,0,210,8,0,0,46,12,0,0,128,1,0,0,140,5,0,0,94,11,0,0,20,16,0,0,180,5,0,0,130,6,0,0,190,13,0,0,118,12,0,0,234,16,0,0,66,14,0,0,160,12,0,0,64,14,0,0,208,4,0,0,238,13,0,0,248,16,0,0,48,9,0,0,198,4,0,0,132,14,0,0,102,9,0,0,70,1,0,0,238,15,0,0,148,1,0,0,80,11,0,0,32,14,0,0,216,6,0,0,2,9,0,0,222,16,0,0,240,9,0,0,52,12,0,0,124,7,0,0,104,17,0,0,12,12,0,0,138,16,0,0,112,15,0,0,240,6,0,0,38,1,0,0,96,15,0,0,100,6,0,0,0,10,0,0,122,13,0,0,232,15,0,0,42,12,0,0,204,7,0,0,2,17,0,0,180,4,0,0,212,4,0,0,98,17,0,0,26,13,0,0,76,0,0,0,162,0,0,0,126,5,0,0,140,14,0,0,42,14,0,0,222,9,0,0,138,10,0,0,80,14,0,0,242,10,0,0,114,16,0,0,38,10,0,0,230,10,0,0,104,0,0,0,92,4,0,0,252,14,0,0,100,4,0,0,156,14,0,0,32,13,0,0,86,10,0,0,182,16,0,0,246,12,0,0,240,14,0,0,140,2,0,0,168,6,0,0,180,6,0,0,50,1,0,0,144,5,0,0,56,10,0,0,40,2,0,0,94,6,0,0,150,17,0,0,104,5,0,0,138,0,0,0,8,6,0,0,216,4,0,0,192,2,0,0,222,0,0,0,10,2,0,0,232,2,0,0,18,8,0,0,156,10,0,0,248,4,0,0,248,7,0,0,242,1,0,0,160,7,0,0,218,10,0,0,178,5,0,0,22,17,0,0,206,2,0,0,22,3,0,0,172,10,0,0,162,12,0,0,0,3,0,0,4,17,0,0,212,14,0,0,174,6,0,0,132,10,0,0,218,11,0,0,24,9,0,0,220,1,0,0,192,13,0,0,146,17,0,0,92,14,0,0,10,12,0,0,0,14,0,0,114,6,0,0,74,9,0,0,6,16,0,0,48,16,0,0,210,16,0,0,90,15,0,0,180,10,0,0,228,16,0,0,144,16,0,0,152,13,0,0,46,10,0,0,80,16,0,0,102,15,0,0,68,9,0,0,230,16,0,0,214,11,0,0,164,0,0,0,30,6,0,0,140,8,0,0,124,0,0,0,126,0,0,0,234,14,0,0,244,2,0,0,200,2,0,0,114,3,0,0,166,0,0,0,242,6,0,0,18,1,0,0,236,7,0,0,178,13,0,0,126,10,0,0,54,14,0,0,40,15,0,0,120,16,0,0,204,12,0,0,166,1,0,0,138,12,0,0,198,11,0,0,196,14,0,0,74,7,0,0,138,17,0,0,192,4,0,0,152,14,0,0,6,2,0,0,102,2,0,0,50,7,0,0,194,16,0,0,222,6,0,0,20,14,0,0,234,2,0,0,88,8,0,0,8,0,0,0,86,14,0,0,76,12,0,0,208,15,0,0,134,6,0,0,120,3,0,0,150,8,0,0,152,7,0,0,186,16,0,0,196,4,0,0,88,16,0,0,246,16,0,0,76,4,0,0,8,2,0,0,230,7,0,0,40,13,0,0,42,2,0,0,118,10,0,0,158,16,0,0,172,5,0,0,200,11,0,0,148,0,0,0,76,13,0,0,158,5,0,0,210,0,0,0,180,2,0,0,88,15,0,0,40,10,0,0,136,5,0,0,106,0,0,0,212,0,0,0,70,7,0,0,14,5,0,0,56,2,0,0,254,1,0,0,166,16,0,0,42,8,0,0,238,10,0,0,110,6,0,0,70,9,0,0,28,3,0,0,218,3,0,0,126,12,0,0,132,17,0,0,102,8,0,0,10,15,0,0,68,12,0,0,36,14,0,0,130,1,0,0,212,16,0,0,196,2,0,0,110,17,0,0,62,3,0,0,186,7,0,0,68,14,0,0,142,2,0,0,182,9,0,0,186,11,0,0,96,16,0,0,38,5,0,0,94,9,0,0,46,8,0,0,158,9,0,0,64,7,0,0,254,7,0,0,252,7,0,0,72,0,0,0,146,8,0,0,22,7,0,0,92,6,0,0,142,16,0,0,84,9,0,0,36,16,0,0,140,13,0,0,38,7,0,0,108,14,0,0,176,11,0,0,218,14,0,0,144,15,0,0,92,15,0,0,98,9,0,0,248,2,0,0,50,16,0,0,248,1,0,0,116,11,0,0,28,1,0,0,200,13,0,0,170,10,0,0,96,1,0,0,158,10,0,0,178,11,0,0,66,4,0,0,126,1,0,0,140,5,0,0,108,9,0,0,64,4,0,0,180,5,0,0,126,6,0,0,166,11,0,0,12,8,0,0,236,16,0,0,2,2,2,2,2,2,2,2,1,2,1,1,3,3,3,4,2,2,2,2,2,2,2,2,1,3,1,1,3,3,3,4,3,2,4,2,2,2,2,2,1,2,1,1,3,3,3,4,2,2,2,2,2,2,2,2,1,3,1,1,3,3,3,4,1,2,2,2,3,2,2,2,1,2,1,1,3,3,3,4,2,2,2,2,3,2,2,2,1,3,1,1,4,3,3,4,1,2,3,2,2,2,2,2,1,2,1,1,3,3,3,4,2,2,2,2,2,2,2,2,1,3,1,1,3,3,3,4,2,2,3,2,2,2,2,2,1,2,1,1,3,3,3,4,2,2,2,2,2,2,2,2,1,3,1,1,3,3,3,4,2,2,2,2,2,2,2,2,1,2,1,1,3,3,3,4,2,2,2,2,2,2,2,2,1,3,1,1,3,3,3,4,2,2,2,2,2,2,2,2,1,2,1,1,3,3,3,4,2,2,2,2,2,2,2,2,1,3,1,1,3,3,3,4,2,2,2,2,2,2,2,2,1,2,1,1,3,3,3,4,2,2,2,2,3,2,2,2,1,3,1,1,3,3,3,4,2,2,2,2,2,2,2,2,1,2,1,1,3,3,3,4,2,2,2,2,2,2,2,2,1,3,1,1,3,3,3,4,3,2,4,2,2,2,2,2,1,2,1,1,3,3,3,4,2,2,2,2,2,2,2,2,1,3,1,1,3,3,3,4,1,2,2,2,3,2,2,2,1,2,1,1,3,3,3,4,2,2,2,2,3,2,2,2,1,3,1,1,4,3,3,4,1,2,3,2,2,2,2,2,1,2,1,1,3,3,3,4,2,2,2,2,2,2,2,2,1,3,1,1,3,3,3,4,2,2,3,2,2,2,2,2,1,2,1,1,3,3,3,4,2,2,2,2,2,2,2,2,1,3,1,1,3,3,3,4,3,2,3,2,2,2,2,2,1,2,1,1,3,3,3,4,2,2,2,2,2,2,2,2,1,3,1,1,3,3,3,4,3,2,2,2,2,2,2,2,1,2,1,1,3,3,3,4,2,2,2,2,2,2,2,2,1,3,1,1,3,3,3,4,3,2,2,2,2,2,2,2,1,2,1,1,3,3,3,4,2,2,2,2,3,2,2,2,1,3,1,1,3,3,3,4,2,2,2,2,2,2,2,2,1,3,1,1,3,3,3,4,2,2,2,2,2,2,2,2,1,3,1,1,3,3,3,4,3,2,4,2,2,2,2,2,1,3,1,1,3,3,3,4,2,2,2,2,2,2,2,2,1,3,1,1,3,3,3,4,1,2,2,2,3,2,2,2,1,3,1,1,3,3,3,4,2,2,2,2,3,2,2,2,1,3,1,1,4,3,3,4,1,2,3,2,2,2,2,2,1,3,1,1,3,3,3,4,2,2,2,2,2,2,2,2,1,3,1,1,3,3,3,4,2,2,3,2,2,2,2,2,1,3,1,1,3,3,3,4,2,2,2,2,2,2,2,2,1,3,1,1,3,3,3,4,2,2,2,2,2,2,2,2,1,3,1,1,3,3,3,4,2,2,2,2,2,2,2,2,1,3,1,1,3,3,3,4,2,2,2,2,2,2,2,2,1,3,1,1,3,3,3,4,2,2,2,2,2,2,2,2,1,3,1,1,3,3,3,4,2,2,2,2,2,2,2,2,1,3,1,1,3,3,3,4,2,2,2,2,3,2,2,2,1,3,1,1,3,3,3,4,2,2,2,2,2,2,2,2,1,3,1,1,3,3,3,4,2,2,2,2,2,2,2,2,1,3,1,1,3,3,3,4,3,2,4,2,2,2,2,2,1,3,1,1,3,3,3,4,2,2,2,2,2,2,2,2,1,3,1,1,3,3,3,4,1,2,2,2,3,2,2,2,1,3,1,1,3,3,3,4,2,2,2,2,3,2,2,2,1,3,1,1,4,3,3,4,1,2,3,2,2,2,2,2,1,3,1,1,3,3,3,4,2,2,2,2,2,2,2,2,1,3,1,1,3,3,3,4,2,2,3,2,2,2,2,2,1,3,1,1,3,3,3,4,2,2,2,2,2,2,2,2,1,3,1,1,3,3,3,4,3,2,3,2,2,2,2,2,1,3,1,1,3,3,3,4,2,2,2,2,2,2,2,2,1,3,1,1,3,3,3,4,3,2,2,2,2,2,2,2,1,3,1,1,3,3,3,4,2,2,2,2,2,2,2,2,1,3,1,1,3,3,3,4,3,2,2,2,2,2,2,2,1,3,1,1,3,3,3,4,2,2,2,2,3,2,2,2,1,3,1,1,3,3,3,4,205,239,189,232,0,198,29,208,252,143,170,244,143,187,245,120,204,244,208,251,47,25,235,244,208,252,126,244,208,11,228,245,203,244,215,0,252,208,243,171,1,16,239,126,244,16,235,186,246,218,0,186,244,196,244,221,93,208,219,31,0,0,192,255,0,0,0,1,0,1,0,1,0,1,0,1,0,0,0,0,90,0,0,0,84,0,0,0,50,0,0,0,28,0,0,0,88,0,0,0,48,0,0,0,120,0,0,0,0,0,0,0,54,0,0,0,66,0,0,0,30,0,0,0,52,0,0,0,112,0,0,0,14,0,0,0,118,0,0,0,0,0,0,0,102,0,0,0,100,0,0,0,64,0,0,0,46,0,0,0,6,0,0,0,8,0,0,0,110,0,0,0,0,0,0,0,32,0,0,0,42,0,0,0,56,0,0,0,74,0,0,0,116,0,0,0,94,0,0,0,86,0,0,0,0,0,0,0,80,0,0,0,38,0,0,0,92,0,0,0,36,0,0,0,22,0,0,0,78,0,0,0,40,0,0,0,0,0,0,0,150,0,0,0,146,0,0,0,82,0,0,0,22,0,0,0,154,0,0,0,84,0,0,0,50,0,0,0,0,0,0,0,162,0,0,0,48,0,0,0,164,0,0,0,126,0,0,0,10,0,0,0,36,0,0,0,104,0,0,0,0,0,0,0,144,0,0,0,140,0,0,0,80,0,0,0,34,0,0,0,20,0,0,0,120,0,0,0,118,0,0,0,0,0,0,0,152,0,0,0,8,0,0,0,108,0,0,0,90,0,0,0,4,0,0,0,86,0,0,0,160,0,0,0,0,0,0,0,12,0,0,0,60,0,0,0,130,0,0,0,106,0,0,0,124,0,0,0,158,0,0,0,40,0,0,0,0,0,0,0,196,0,0,0,16,1,0,0,92,0,0,0,174,0,0,0,2,0,0,0,180,0,0,0,178,0,0,0,0,0,0,0,28,0,0,0,6,1,0,0,8,0,0,0,236,0,0,0,72,0,0,0,190,0,0,0,152,0,0,0,0,0,0,0,110,0,0,0,228,0,0,0,150,0,0,0,198,0,0,0,144,0,0,0,48,0,0,0,182,0,0,0,0,0,0,0,12,0,0,0,106,0,0,0,38,1,0,0,56,0,0,0,14,0,0,0,30,1,0,0,12,1,0,0,0,0,0,0,130,0,0,0,18,0,0,0,158,0,0,0,162,0,0,0,128,0,0,0,184,0,0,0,132,0,0,0,0,0,0,0,136,0,0,0,200,0,0,0,8,1,0,0,36,0,0,0,226,0,0,0,234,0,0,0,66,0,0,0,0,0,0,0,0,1,0,0,114,0,0,0,84,0,0,0,60,0,0,0,34,0,0,0,160,0,0,0,6,0,0,0,0,0,0,0,124,0,0,0,80,0,0,0,46,0,0,0,70,0,0,0,146,0,0,0,240,0,0,0,210,0,0,0,0,0,0,0,68,0,0,0,188,0,0,0,100,0,0,0,4,1,0,0,34,1,0,0,94,0,0,0,32,1,0,0,0,0,0,0,214,0,0,0,238,0,0,0,24,0,0,0,38,0,0,0,112,0,0,0,244,0,0,0,30,0,0,0,0,0,0,0,26,0,0,0,108,0,0,0,224,0,0,0,148,0,0,0,242,0,0,0,42,0,0,0,254,0,0,0,0,0,0,0,122,0,0,0,232,0,0,0,26,1,0,0,20,0,0,0,36,1,0,0,208,0,0,0,20,1,0,0,0,0,0,0,74,0,0,0,98,0,0,0,56,0,0,0,122,0,0,0,26,0,0,0,88,0,0,0,38,0,0,0,0,0,0,0,128,0,0,0,44,0,0,0,18,0,0,0,14,0,0,0,62,0,0,0,138,0,0,0,136,0,0,0,0,0,0,0,68,0,0,0,110,0,0,0,102,0,0,0,142,0,0,0,28,0,0,0,156,0,0,0,2,0,0,0,0,0,0,0,46,0,0,0,24,0,0,0,96,0,0,0,54,0,0,0,32,0,0,0,132,0,0,0,42,0,0,0,0,0,0,0,92,0,0,0,64,0,0,0,114,0,0,0,78,0,0,0,6,0,0,0,100,0,0,0,66,0,0,0,0,0,0,0,172,0,0,0,64,0,0,0,104,0,0,0,126,0,0,0,76,0,0,0,156,0,0,0,164,0,0,0,0,0,0,0,176,0,0,0,140,0,0,0,194,0,0,0,14,1,0,0,166,0,0,0,74,0,0,0,10,0,0,0,0,0,0,0,4,0,0,0,170,0,0,0,246,0,0,0,186,0,0,0,212,0,0,0,40,0,0,0,90,0,0,0,0,0,0,0,0,0,0,255,0,0,0,0,112,182,0,0,192,181,0,0,168,181,0,0,0,0,0,0,1,0,0,0,2,0,0,0,2,0,0,0,4,0,0,0,4,0,0,0,4,0,0,0,2,0,0,0,4,0,0,0,64,0,0,0,0,0,0,0,0,0,48,0,96,0,144,0,192,0,240,0,32,1,80,1,128,254,176,254,224,254,16,255,64,255,112,255,160,255,208,255,0,0,0,128,0,64,170,42,0,32,153,25,85,21,73,18,0,16,56,14,204,12,162,11,170,10,216,9,36,9,136,8,0,8,135,7,28,7,188,6,102,6,24,6,209,5,144,5,85,5,30,5,236,4,189,4,146,4,105,4,68,4,33,4,0,4,224,3,195,3,168,3,142,3,117,3,94,3,72,3,51,3,31,3,12,3,250,2,232,2,216,2,200,2,185,2,170,2,156,2,143,2,130,2,118,2,106,2,94,2,83,2,73,2,62,2,52,2,43,2,34,2,25,2,16,2,8,2,0,0,0,0,1,0,1,0,0,0,255,0,255,0,0,0,0,0,255,0,0,0,1,0,1,0,1,0,0,0,0,0,0,0,255,0,255,0,0,0,1,0,0,0,255,0,0,0,0,128,0,64,0,32,0,16,0,8,0,4,0,2,0,1,128,0,64,0,32,0,16,0,8,0,4,0,2,0,1,0,2,0,4,0,8,0,16,0,32,0,64,0,128,0,0,1,0,0,15,0,0,4,0,2,64,1,0,4,0,2,64,0,125,0,126,0,126,0,123,0,124,0,125,0,123,0,124,0,2,0,32,0,48,0,0,0,13,0,25,0,38,0,50,0,62,0,74,0,86,0,98,0,109,0,121,0,132,0,142,0,152,0,162,0,172,0,181,0,190,0,198,0,206,0,213,0,220,0,226,0,231,0,236,0,241,0,245,0,248,0,251,0,253,0,255,0,0,1,0,1,0,1,255,0,253,0,251,0,248,0,245,0,241,0,237,0,231,0,226,0,220,0,213,0,206,0,198,0,190,0,181,0,172,0,162,0,153,0,142,0,132,0,121,0,110,0,98,0,86,0,74,0,62,0,50,0,38,0,25,0,13,0,0,0,243,255,231,255,219,255,206,255,194,255,182,255,170,255,158,255,147,255,135,255,125,255,114,255,104,255,94,255,84,255,75,255,66,255,58,255,50,255,43,255,37,255,30,255,25,255,20,255,15,255,11,255,8,255,5,255,3,255,1,255,0,255,0,255,0,255,1,255,3,255,5,255,8,255,11,255,15,255,19,255,24,255,30,255,36,255,43,255,50,255,58,255,66,255,75,255,84,255,93,255,103,255,114,255,124,255,135,255,146,255,158,255,169,255,181,255,194,255,206,255,218,255,231,255,243,255,43,0,127,0,32,0,255,0,0,255,190,255,0,0,68,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,193,255,1,0,2,0,69,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,197,255,3,0,4,0,5,0,71,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,202,255,6,0,7,0,8,0,9,0,74,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,255,10,0,11,0,12,0,13,0,14,0,78,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,215,255,15,0,16,0,17,0,18,0,19,0,20,0,83,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,223,255,21,0,22,0,23,0,24,0,25,0,26,0,27,0,89,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,255,28,0,29,0,30,0,31,0,32,0,33,0,34,0,35,0,96,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,242,255,36,0,37,0,38,0,39,0,40,0,41,0,42,0,43,0,44,0,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,253,255,45,0,46,0,47,0,48,0,49,0,50,0,51,0,52,0,53,0,54,0,113,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,199,255,55,0,56,0,57,0,58,0,59,0,60,0,61,0,62,0,63,0,64,0,65,0,123,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,212,255,0,0,1,0,2,0,3,0,4,0,5,0,6,0,7,0,8,0,9,0,10,0,11,0,68,0,0,0,0,0,0,0,0,0,0,0,0,0,226,255,12,0,13,0,14,0,15,0,16,0,17,0,18,0,19,0,20,0,21,0,22,0,23,0,24,0,80,0,0,0,0,0,0,0,0,0,0,0,241,255,25,0,26,0,27,0,28,0,29,0,30,0,31,0,32,0,33,0,34,0,35,0,36,0,37,0,38,0,93,0,0,0,0,0,0,0,0,0,203,255,39,0,40,0,41,0,42,0,43,0,44,0,45,0,46,0,47,0,48,0,49,0,50,0,51,0,52,0,53,0,107,0,0,0,0,0,0,0,220,255,0,0,1,0,2,0,3,0,4,0,5,0,6,0,7,0,8,0,9,0,10,0,11,0,12,0,13,0,14,0,15,0,68,0,0,0,0,0,238,255,16,0,17,0,18,0,19,0,20,0,21,0,22,0,23,0,24,0,25,0,26,0,27,0,28,0,29,0,30,0,31,0,32,0,84,0,0,0,238,255,33,0,34,0,35,0,36,0,37,0,38,0,39,0,40,0,41,0,42,0,43,0,44,0,45,0,46,0,47,0,48,0,49,0,50,0,101,0,190,255,0,0,172,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,193,255,1,0,2,0,173,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,197,255,3,0,4,0,5,0,175,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,202,255,6,0,7,0,8,0,9,0,178,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,255,10,0,11,0,12,0,13,0,14,0,182,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,215,255,15,0,16,0,17,0,18,0,19,0,20,0,187,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,223,255,21,0,22,0,23,0,24,0,25,0,26,0,27,0,193,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,255,28,0,29,0,30,0,31,0,32,0,33,0,34,0,35,0,200,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,242,255,36,0,37,0,38,0,39,0,40,0,41,0,42,0,43,0,44,0,208,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,253,255,45,0,46,0,47,0,48,0,49,0,50,0,51,0,52,0,53,0,54,0,217,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,199,255,55,0,56,0,57,0,58,0,59,0,60,0,61,0,62,0,63,0,64,0,65,0,227,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,212,255,0,0,1,0,2,0,3,0,4,0,5,0,6,0,7,0,8,0,9,0,10,0,11,0,172,254,0,0,0,0,0,0,0,0,0,0,0,0,226,255,12,0,13,0,14,0,15,0,16,0,17,0,18,0,19,0,20,0,21,0,22,0,23,0,24,0,184,254,0,0,0,0,0,0,0,0,0,0,241,255,25,0,26,0,27,0,28,0,29,0,30,0,31,0,32,0,33,0,34,0,35,0,36,0,37,0,38,0,197,254,0,0,0,0,0,0,0,0,203,255,39,0,40,0,41,0,42,0,43,0,44,0,45,0,46,0,47,0,48,0,49,0,50,0,51,0,52,0,53,0,211,254,0,0,0,0,0,0,220,255,0,0,1,0,2,0,3,0,4,0,5,0,6,0,7,0,8,0,9,0,10,0,11,0,12,0,13,0,14,0,15,0,172,254,0,0,0,0])
.concat([238,255,16,0,17,0,18,0,19,0,20,0,21,0,22,0,23,0,24,0,25,0,26,0,27,0,28,0,29,0,30,0,31,0,32,0,188,254,0,0,238,255,33,0,34,0,35,0,36,0,37,0,38,0,39,0,40,0,41,0,42,0,43,0,44,0,45,0,46,0,47,0,48,0,49,0,50,0,205,254,84,1,24,2,16,1,176,0,204,0,176,0,136,0,176,0,68,0,176,0,0,0,176,0,254,0,7,255,2,0,255,0,248,0,7,0,254,0,238,0,255,7,0,2,239,0,0,248,0,7,238,0,255,255,255,255,255,255,0,0,0,0,1,0,1,0,1,0,1,0,0,0,0,0,255,255,255,255,255,255,255,255,0,0,0,0,1,0,1,0,1,0,1,0,0,0,0,0,255,255,255,255,0,0,255,255,1,0,0,0,1,0,1,0,0,0,0,0,255,255,255,255,255,255,255,255,0,0,255,255,1,0,0,0,1,0,1,0,0,0,0,0,255,255,255,255,255,255,0,0,0,0,0,0,68,0,136,0,204,0,16,1,84,1,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,36,3,71,6,106,9,139,12,171,15,200,18,226,21,248,24,11,28,25,31,35,34,40,37,38,40,31,43,17,46,251,48,222,51,186,54,140,57,86,60,23,63,206,65,122,68,28,71,180,73,63,76,191,78,51,81,155,83,245,85,66,88,130,90,180,92,215,94,236,96,242,98,232,100,207,102,166,104,109,106,36,108,202,109,95,111,226,112,85,114,181,115,4,117,65,118,108,119,132,120,138,121,125,122,93,123,41,124,227,124,138,125,29,126,157,126,9,127,98,127,167,127,216,127,246,127,255,127,246,127,216,127,167,127,98,127,9,127,157,126,29,126,138,125,227,124,41,124,93,123,125,122,138,121,132,120,108,119,65,118,4,117,181,115,85,114,226,112,95,111,202,109,36,108,109,106,166,104,207,102,232,100,242,98,236,96,215,94,180,92,130,90,66,88,245,85,155,83,51,81,191,78,63,76,180,73,28,71,122,68,206,65,23,63,86,60,140,57,186,54,222,51,251,48,17,46,31,43,38,40,40,37,35,34,25,31,11,28,248,24,226,21,200,18,171,15,139,12,106,9,71,6,36,3,0,0,220,252,185,249,150,246,117,243,85,240,56,237,30,234,8,231,245,227,231,224,221,221,216,218,218,215,225,212,239,209,5,207,34,204,70,201,116,198,170,195,233,192,50,190,134,187,228,184,76,182,193,179,65,177,205,174,101,172,11,170,190,167,126,165,76,163,41,161,20,159,14,157,24,155,49,153,90,151,147,149,220,147,54,146,161,144,30,143,171,141,75,140,252,138,191,137,148,136,124,135,118,134,131,133,163,132,215,131,29,131,118,130,227,129,99,129,247,128,158,128,89,128,40,128,10,128,1,128,10,128,40,128,89,128,158,128,247,128,99,129,227,129,118,130,29,131,215,131,163,132,131,133,118,134,124,135,148,136,191,137,252,138,75,140,171,141,30,143,161,144,54,146,220,147,147,149,90,151,49,153,24,155,14,157,20,159,41,161,76,163,126,165,190,167,11,170,101,172,205,174,65,177,193,179,76,182,228,184,134,187,50,190,233,192,170,195,116,198,70,201,34,204,5,207,239,209,225,212,218,215,216,218,221,221,231,224,245,227,8,231,30,234,56,237,85,240,117,243,150,246,185,249,220,252,180,56,183,56,186,56,190,56,192,56,196,56,199,56,202,56,206,56,208,56,212,56,215,56,218,56,221,56,224,56,228,56,0,0,3,0,6,0,9,0,12,0,15,0,18,0,21,0,25,0,28,0,31,0,34,0,37,0,40,0,43,0,47,0,50,0,53,0,56,0,59,0,62,0,65,0,69,0,72,0,75,0,78,0,81,0,84,0,87,0,91,0,94,0,97,0,100,0,103,0,106,0,109,0,113,0,116,0,119,0,122,0,125,0,128,0,131,0,135,0,138,0,141,0,144,0,147,0,150,0,153,0,157,0,160,0,163,0,166,0,169,0,172,0,175,0,179,0,182,0,185,0,188,0,191,0,194,0,197,0,201,0,204,0,207,0,210,0,213,0,216,0,219,0,223,0,226,0,229,0,232,0,235,0,238,0,241,0,245,0,248,0,251,0,254,0,1,1,4,1,7,1,11,1,14,1,17,1,20,1,23,1,26,1,29,1,33,1,36,1,39,1,42,1,45,1,48,1,51,1,55,1,58,1,61,1,64,1,67,1,70,1,73,1,77,1,80,1,83,1,86,1,89,1,92,1,95,1,99,1,102,1,105,1,108,1,111,1,114,1,117,1,120,1,124,1,127,1,130,1,133,1,136,1,139,1,142,1,146,1,149,1,152,1,155,1,158,1,161,1,164,1,168,1,171,1,174,1,177,1,180,1,183,1,186,1,190,1,193,1,196,1,199,1,202,1,205,1,208,1,212,1,215,1,218,1,221,1,224,1,227,1,230,1,234,1,237,1,240,1,243,1,246,1,249,1,252,1,0,2,3,2,6,2,9,2,12,2,15,2,18,2,22,2,25,2,28,2,31,2,34,2,37,2,40,2,44,2,47,2,50,2,53,2,56,2,59,2,62,2,66,2,69,2,72,2,75,2,78,2,81,2,84,2,88,2,91,2,94,2,97,2,100,2,103,2,106,2,110,2,113,2,116,2,119,2,122,2,125,2,128,2,132,2,135,2,138,2,141,2,144,2,147,2,150,2,154,2,157,2,160,2,163,2,166,2,169,2,172,2,176,2,179,2,182,2,185,2,188,2,191,2,194,2,198,2,201,2,204,2,207,2,210,2,213,2,216,2,219,2,223,2,226,2,229,2,232,2,235,2,238,2,241,2,245,2,248,2,251,2,254,2,1,3,4,3,7,3,11,3,14,3,17,3,20,3,23,3,26,3,29,3,33,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,2,0,4,0,8,0,16,0,32,0,64,0,128,0,0,1,0,2,0,4,0,8,0,16,0,32,0,64,255,127,0,64,0,32,0,16,0,8,0,4,0,2,0,1,128,0,64,0,32,0,1,0,8,0,4,0,2,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,229,255,0,1,255,127,2,127,8,126,18,125,31,124,48,123,69,122,93,121,120,120,151,119,186,118,223,117,7,117,51,116,97,115,147,114,199,113,254,112,56,112,117,111,180,110,246,109,58,109,129,108,202,107,22,107,100,106,180,105,7,105,91,104,178,103,11,103,102,102,196,101,35,101,132,100,231,99,76,99,179,98,28,98,134,97,242,96,96,96,208,95,65,95,181,94,41,94,159,93,23,93,145,92,12,92,136,91,6,91,133,90,6,90,136,89,11,89,144,88,22,88,157,87,38,87,176,86,59,86,200,85,85,85,228,84,116,84,5,84,152,83,43,83,191,82,85,82,236,81,131,81,28,81,182,80,80,80,236,79,137,79,38,79,197,78,100,78,5,78,166,77,72,77,236,76,144,76,52,76,218,75,129,75,40,75,208,74,121,74,35,74,205,73,121,73,37,73,209,72,127,72,45,72,220,71,140,71,60,71,237,70,159,70,81,70,4,70,184,69,108,69,33,69,215,68,141,68,68,68,252,67,180,67,109,67,38,67,224,66,154,66,85,66,17,66,205,65,137,65,70,65,4,65,194,64,129,64,64,64,255,63,247,65,225,67,189,69,141,71,81,73,11,75,187,76,97,78,255,79,148,81,34,83,169,84,40,86,162,87,20,89,129,90,233,91,74,93,167,94,255,95,82,97,160,98,234,99,48,101,114,102,176,103,234,104,32,106,83,107,131,108,175,109,217,110,255,111,34,113,66,114,95,115,122,116,146,117,167,118,186,119,203,120,217,121,229,122,238,123,245,124,250,125,254,126,255,127,0,0,36,3,71,6,106,9,139,12,171,15,200,18,226,21,248,24,11,28,25,31,35,34,40,37,38,40,31,43,17,46,251,48,222,51,186,54,140,57,86,60,23,63,206,65,122,68,28,71,180,73,63,76,191,78,51,81,155,83,245,85,66,88,130,90,180,92,215,94,236,96,242,98,232,100,207,102,166,104,109,106,36,108,202,109,95,111,226,112,85,114,181,115,4,117,65,118,108,119,132,120,138,121,125,122,93,123,41,124,227,124,138,125,29,126,157,126,9,127,98,127,167,127,216,127,246,127,255,127,246,127,216,127,167,127,98,127,9,127,157,126,29,126,138,125,227,124,41,124,93,123,125,122,138,121,132,120,108,119,65,118,4,117,181,115,85,114,226,112,95,111,202,109,36,108,109,106,166,104,207,102,232,100,242,98,236,96,215,94,180,92,130,90,66,88,245,85,155,83,51,81,191,78,63,76,180,73,28,71,122,68,206,65,23,63,86,60,140,57,186,54,222,51,251,48,17,46,31,43,38,40,40,37,35,34,25,31,11,28,248,24,226,21,200,18,171,15,139,12,106,9,71,6,36,3,255,127,246,127,216,127,167,127,98,127,9,127,157,126,29,126,138,125,227,124,41,124,93,123,125,122,138,121,132,120,108,119,65,118,4,117,181,115,85,114,226,112,95,111,202,109,36,108,109,106,166,104,207,102,232,100,242,98,236,96,215,94,180,92,130,90,66,88,245,85,155,83,51,81,191,78,63,76,180,73,28,71,122,68,206,65,23,63,86,60,140,57,186,54,222,51,251,48,17,46,31,43,38,40,40,37,35,34,25,31,11,28,248,24,226,21,200,18,171,15,139,12,106,9,71,6,36,3,0,0,220,252,185,249,150,246,117,243,85,240,56,237,30,234,8,231,245,227,231,224,221,221,216,218,218,215,225,212,239,209,5,207,34,204,70,201,116,198,170,195,233,192,50,190,134,187,228,184,76,182,193,179,65,177,205,174,101,172,11,170,190,167,126,165,76,163,41,161,20,159,14,157,24,155,49,153,90,151,147,149,220,147,54,146,161,144,30,143,171,141,75,140,252,138,191,137,148,136,124,135,118,134,131,133,163,132,215,131,29,131,118,130,227,129,99,129,247,128,158,128,89,128,40,128,10,128,136,100,128,0,255,3,22,1,2,0,128,0,0,64,215,63,175,63,134,63,93,63,52,63,12,63,227,62,186,62,145,62,104,62,64,62,23,62,238,61,197,61,156,61,116,61,75,61,34,61,249,60,208,60,167,60,127,60,86,60,45,60,4,60,219,59,178,59,137,59,96,59,55,59,14,59,229,58,188,58,147,58,105,58,64,58,23,58,238,57,197,57,156,57,114,57,73,57,32,57,246,56,205,56,164,56,122,56,81,56,39,56,254,55,212,55,170,55,129,55,87,55,45,55,4,55,218,54,176,54,134,54,92,54,50,54,9,54,223,53,180,53,138,53,96,53,54,53,12,53,225,52,183,52,141,52,98,52,56,52,13,52,227,51,184,51,141,51,99,51,56,51,13,51,226,50,183,50,140,50,97,50,54,50,11,50,223,49,180,49,136,49,93,49,49,49,6,49,218,48,174,48,131,48,87,48,43,48,255,47,210,47,166,47,122,47,77,47,33,47,244,46,200,46,155,46,110,46,65,46,20,46,231,45,186,45,141,45,96,45,50,45,5,45,215,44,169,44,123,44,77,44,31,44,241,43,195,43,148,43,102,43,55,43,9,43,218,42,171,42,124,42,76,42,29,42,237,41,190,41,142,41,94,41,46,41,254,40,206,40,157,40,109,40,60,40,11,40,218,39,169,39,119,39,70,39,20,39,226,38,176,38,126,38,76,38,25,38,231,37,180,37,129,37,77,37,26,37,230,36,178,36,126,36,74,36,21,36,225,35,172,35,118,35,65,35,11,35,214,34,159,34,105,34,50,34,252,33,196,33,141,33,85,33,29,33,229,32,173,32,116,32,59,32,1,32,199,31,141,31,83,31,24,31,221,30,161,30,102,30,41,30,237,29,176,29,114,29,53,29,246,28,184,28,121,28,57,28,249,27,184,27,119,27,54,27,244,26,177,26,110,26,42,26,230,25,161,25,92,25,21,25,206,24,135,24,63,24,245,23,172,23,97,23,21,23,201,22,124,22,46,22,223,21,142,21,61,21,235,20,151,20,66,20,236,19,149,19,60,19,226,18,134,18,40,18,201,17,103,17,4,17,158,16,54,16,204,15,95,15,239,14,123,14,4,14,137,13,10,13,134,12,253,11,109,11,214,10,54,10,141,9,215,8,17,8,54,7,62,6,25,5,154,3,0,0,255,127,0,1,128,0,29,2,200,0,206,0,72,0,38,10,122,39,206,0,136,100,172,20,1,0,249,0,252,0,255,0,252,0,249,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,255,255,255,0,255,0,0,0,255,255,255,0,0,255,255,0,0,128,255,255,127,0,128,0,255,127,0,255,127,255,127,255,255,0,0,1,255,255,254,0,1,0,255,254,0,0,0,146,1,36,3,182,4,71,6,217,7,106,9,251,10,139,12,27,14,171,15,57,17,200,18,85,20,226,21,109,23,248,24,130,26,11,28,147,29,25,31,159,32,35,34,166,35,40,37,168,38,38,40,163,41,31,43,152,44,17,46,135,47,251,48,110,50,222,51,77,53,186,54,36,56,140,57,242,58,86,60,184,61,23,63,115,64,206,65,37,67,122,68,205,69,28,71,105,72,180,73,251,74,63,76,129,77,191,78,251,79,51,81,105,82,155,83,202,84,245,85,29,87,66,88,100,89,130,90,157,91,180,92,199,93,215,94,227,95,236,96,241,97,242,98,239,99,232,100,221,101,207,102,189,103,166,104,140,105,109,106,74,107,36,108,249,108,202,109,150,110,95,111,35,112,226,112,158,113,85,114,7,115,181,115,95,116,4,117,165,117,65,118,217,118,108,119,250,119,132,120,9,121,138,121,5,122,125,122,239,122,93,123,197,123,41,124,137,124,227,124,57,125,138,125,214,125,29,126,95,126,157,126,213,126,9,127,56,127,98,127,135,127,167,127,194,127,216,127,233,127,246,127,253,127,255,127,253,127,246,127,233,127,216,127,194,127,167,127,135,127,98,127,56,127,9,127,213,126,157,126,95,126,29,126,214,125,138,125,57,125,227,124,137,124,41,124,197,123,93,123,239,122,125,122,5,122,138,121,9,121,132,120,250,119,108,119,217,118,65,118,165,117,4,117,95,116,181,115,7,115,85,114,158,113,226,112,35,112,95,111,150,110,202,109,249,108,36,108,74,107,109,106,140,105,166,104,189,103,207,102,221,101,232,100,239,99,242,98,241,97,236,96,227,95,215,94,199,93,180,92,157,91,130,90,100,89,66,88,29,87,245,85,202,84,155,83,105,82,51,81,251,79,191,78,129,77,63,76,251,74,180,73,105,72,28,71,205,69,122,68,37,67,206,65,115,64,23,63,184,61,86,60,242,58,140,57,36,56,186,54,77,53,222,51,110,50,251,48,135,47,17,46,152,44,31,43,163,41,38,40,168,38,40,37,166,35,35,34,159,32,25,31,147,29,11,28,130,26,248,24,109,23,226,21,85,20,200,18,57,17,171,15,27,14,139,12,251,10,106,9,217,7,71,6,182,4,36,3,146,1,0,0,110,254,220,252,74,251,185,249,39,248,150,246,5,245,117,243,229,241,85,240,199,238,56,237,171,235,30,234,147,232,8,231,126,229,245,227,109,226,231,224,97,223,221,221,90,220,216,218,88,217,218,215,93,214,225,212,104,211,239,209,121,208,5,207,146,205,34,204,179,202,70,201,220,199,116,198,14,197,170,195,72,194,233,192,141,191,50,190,219,188,134,187,51,186,228,184,151,183,76,182,5,181,193,179,127,178,65,177,5,176,205,174,151,173,101,172,54,171,11,170,227,168,190,167,156,166,126,165,99,164,76,163,57,162,41,161,29,160,20,159,15,158,14,157,17,156,24,155,35,154,49,153,67,152,90,151,116,150,147,149,182,148,220,147,7,147,54,146,106,145,161,144,221,143,30,143,98,142,171,141,249,140,75,140,161,139,252,138,91,138,191,137,39,137,148,136,6,136,124,135,247,134,118,134,251,133,131,133,17,133,163,132,59,132,215,131,119,131,29,131,199,130,118,130,42,130,227,129,161,129,99,129,43,129,247,128,200,128,158,128,121,128,89,128,62,128,40,128,23,128,10,128,3,128,1,128,3,128,10,128,23,128,40,128,62,128,89,128,121,128,158,128,200,128,247,128,43,129,99,129,161,129,227,129,42,130,118,130,199,130,29,131,119,131,215,131,59,132,163,132,17,133,131,133,251,133,118,134,247,134,124,135,6,136,148,136,39,137,191,137,91,138,252,138,161,139,75,140,249,140,171,141,98,142,30,143,221,143,161,144,106,145,54,146,7,147,220,147,182,148,147,149,116,150,90,151,67,152,49,153,35,154,24,155,17,156,14,157,15,158,20,159,29,160,41,161,57,162,76,163,99,164,126,165,156,166,190,167,227,168,11,170,54,171,101,172,151,173,205,174,5,176,65,177,127,178,193,179,5,181,76,182,151,183,228,184,51,186,134,187,219,188,50,190,141,191,233,192,72,194,170,195,14,197,116,198,220,199,70,201,179,202,34,204,146,205,5,207,121,208,239,209,104,211,225,212,93,214,218,215,88,217,216,218,90,220,221,221,97,223,231,224,109,226,245,227,126,229,8,231,147,232,30,234,171,235,56,237,199,238,85,240,229,241,117,243,5,245,150,246,39,248,185,249,74,251,220,252,110,254,255,127,253,127,246,127,233,127,216,127,194,127,167,127,135,127,98,127,56,127,9,127,213,126,157,126,95,126,29,126,214,125,138,125,57,125,227,124,137,124,41,124,197,123,93,123,239,122,125,122,5,122,138,121,9,121,132,120,250,119,108,119,217,118,65,118,165,117,4,117,95,116,181,115,7,115,85,114,158,113,226,112,35,112,95,111,150,110,202,109,249,108,36,108,74,107,109,106,140,105,166,104,189,103,207,102,221,101,232,100,239,99,242,98,241,97,236,96,227,95,215,94,199,93,180,92,157,91,130,90,100,89,66,88,29,87,245,85,202,84,155,83,105,82,51,81,251,79,191,78,129,77,63,76,251,74,180,73,105,72,28,71,205,69,122,68,37,67,206,65,115,64,23,63,184,61,86,60,242,58,140,57,36,56,186,54,77,53,222,51,110,50,251,48,135,47,17,46,152,44,31,43,163,41,38,40,168,38,40,37,166,35,35,34,159,32,25,31,147,29,11,28,130,26,248,24,109,23,226,21,85,20,200,18,57,17,171,15,27,14,139,12,251,10,106,9,217,7,71,6,182,4,36,3,146,1,0,0,110,254,220,252,74,251,185,249,39,248,150,246,5,245,117,243,229,241,85,240,199,238,56,237,171,235,30,234,147,232,8,231,126,229,245,227,109,226,231,224,97,223,221,221,90,220,216,218,88,217,218,215,93,214,225,212,104,211,239,209,121,208,5,207,146,205,34,204,179,202,70,201,220,199,116,198,14,197,170,195,72,194,233,192,141,191,50,190,219,188,134,187,51,186,228,184,151,183,76,182,5,181,193,179,127,178,65,177,5,176,205,174,151,173,101,172,54,171,11,170,227,168,190,167,156,166,126,165,99,164,76,163,57,162,41,161,29,160,20,159,15,158,14,157,17,156,24,155,35,154,49,153,67,152,90,151,116,150,147,149,182,148,220,147,7,147,54,146,106,145,161,144,221,143,30,143,98,142,171,141,249,140,75,140,161,139,252,138,91,138,191,137,39,137,148,136,6,136,124,135,247,134,118,134,251,133,131,133,17,133,163,132,59,132,215,131,119,131,29,131,199,130,118,130,42,130,227,129,161,129,99,129,43,129,247,128,200,128,158,128,121,128,89,128,62,128,40,128,23,128,10,128,3,128,1,128,3,128,10,128,23,128,40,128,62,128,89,128,121,128,158,128,200,128,247,128,43,129,99,129,161,129,227,129,42,130,118,130,199,130,29,131,119,131,215,131,59,132,163,132,17,133,131,133,251,133,118,134,247,134,124,135,6,136,148,136,39,137,191,137,91,138,252,138,161,139,75,140,249,140,171,141,98,142,30,143,221,143,161,144,106,145,54,146,7,147,220,147,182,148,147,149,116,150,90,151,67,152,49,153,35,154,24,155,17,156,14,157,15,158,20,159,29,160,41,161,57,162,76,163,99,164,126,165,156,166,190,167,227,168,11,170,54,171,101,172,151,173,205,174,5,176,65,177,127,178,193,179,5,181,76,182,151,183,228,184,51,186,134,187,219,188,50,190,141,191,233,192,72,194,170,195,14,197,116,198,220,199,70,201,179,202,34,204,146,205,5,207,121,208,239,209,104,211,225,212,93,214,218,215,88,217,216,218,90,220,221,221,97,223,231,224,109,226,245,227,126,229,8,231,147,232,30,234,171,235,56,237,199,238,85,240,229,241,117,243,5,245,150,246,39,248,185,249,74,251,220,252,110,254,0,0,146,1,36,3,182,4,71,6,217,7,106,9,251,10,139,12,27,14,171,15,57,17,200,18,85,20,226,21,109,23,248,24,130,26,11,28,147,29,25,31,159,32,35,34,166,35,40,37,168,38,38,40,163,41,31,43,152,44,17,46,135,47,251,48,110,50,222,51,77,53,186,54,36,56,140,57,242,58,86,60,184,61,23,63,115,64,206,65,37,67,122,68,205,69,28,71,105,72,180,73,251,74,63,76,129,77,191,78,251,79,51,81,105,82,155,83,202,84,245,85,29,87,66,88,100,89,130,90,157,91,180,92,199,93,215,94,227,95,236,96,241,97,242,98,239,99,232,100,221,101,207,102,189,103,166,104,140,105,109,106,74,107,36,108,249,108,202,109,150,110,95,111,35,112,226,112,158,113,85,114,7,115,181,115,95,116,4,117,165,117,65,118,217,118,108,119,250,119,132,120,9,121,138,121,5,122,125,122,239,122,93,123,197,123,41,124,137,124,227,124,57,125,138,125,214,125,29,126,95,126,157,126,213,126,9,127,56,127,98,127,135,127,167,127,194,127,216,127,233,127,246,127,253,127,0,0,2,0,4,0,6,0,8,0,10,0,12,0,14,0,0,2,2,2,4,2,6,2,8,2,10,2,12,2,14,2,0,4,2,4,4,4,6,4,8,4,10,4,12,4,14,4,0,6,2,6,4,6,6,6,8,6,10,6,12,6,14,6,0,8,2,8,4,8,6,8,8,8,10,8,12,8,14,8])
, "i8", ALLOC_NONE, Runtime.GLOBAL_BASE)
var tempDoublePtr = Runtime.alignMemory(allocate(12, "i8", ALLOC_STATIC), 8);
assert(tempDoublePtr % 8 == 0);
function copyTempFloat(ptr) { // functions, because inlining this code increases code size too much
  HEAP8[tempDoublePtr] = HEAP8[ptr];
  HEAP8[tempDoublePtr+1] = HEAP8[ptr+1];
  HEAP8[tempDoublePtr+2] = HEAP8[ptr+2];
  HEAP8[tempDoublePtr+3] = HEAP8[ptr+3];
}
function copyTempDouble(ptr) {
  HEAP8[tempDoublePtr] = HEAP8[ptr];
  HEAP8[tempDoublePtr+1] = HEAP8[ptr+1];
  HEAP8[tempDoublePtr+2] = HEAP8[ptr+2];
  HEAP8[tempDoublePtr+3] = HEAP8[ptr+3];
  HEAP8[tempDoublePtr+4] = HEAP8[ptr+4];
  HEAP8[tempDoublePtr+5] = HEAP8[ptr+5];
  HEAP8[tempDoublePtr+6] = HEAP8[ptr+6];
  HEAP8[tempDoublePtr+7] = HEAP8[ptr+7];
}
  function _emscripten_set_canvas_size(width, height) {
      Browser.setCanvasSize(width, height);
    }
  function _emscripten_set_main_loop(func, fps, simulateInfiniteLoop) {
      Module['noExitRuntime'] = true;
      Browser.mainLoop.runner = function() {
        if (ABORT) return;
        if (Browser.mainLoop.queue.length > 0) {
          var start = Date.now();
          var blocker = Browser.mainLoop.queue.shift();
          blocker.func(blocker.arg);
          if (Browser.mainLoop.remainingBlockers) {
            var remaining = Browser.mainLoop.remainingBlockers;
            var next = remaining%1 == 0 ? remaining-1 : Math.floor(remaining);
            if (blocker.counted) {
              Browser.mainLoop.remainingBlockers = next;
            } else {
              // not counted, but move the progress along a tiny bit
              next = next + 0.5; // do not steal all the next one's progress
              Browser.mainLoop.remainingBlockers = (8*remaining + next)/9;
            }
          }
          console.log('main loop blocker "' + blocker.name + '" took ' + (Date.now() - start) + ' ms'); //, left: ' + Browser.mainLoop.remainingBlockers);
          Browser.mainLoop.updateStatus();
          setTimeout(Browser.mainLoop.runner, 0);
          return;
        }
        if (Browser.mainLoop.shouldPause) {
          // catch pauses from non-main loop sources
          Browser.mainLoop.paused = true;
          Browser.mainLoop.shouldPause = false;
          return;
        }
        if (Module['preMainLoop']) {
          Module['preMainLoop']();
        }
        Runtime.dynCall('v', func);
        if (Module['postMainLoop']) {
          Module['postMainLoop']();
        }
        if (Browser.mainLoop.shouldPause) {
          // catch pauses from the main loop itself
          Browser.mainLoop.paused = true;
          Browser.mainLoop.shouldPause = false;
          return;
        }
        Browser.mainLoop.scheduler();
      }
      if (fps && fps > 0) {
        Browser.mainLoop.scheduler = function() {
          setTimeout(Browser.mainLoop.runner, 1000/fps); // doing this each time means that on exception, we stop
        }
      } else {
        Browser.mainLoop.scheduler = function() {
          Browser.requestAnimationFrame(Browser.mainLoop.runner);
        }
      }
      Browser.mainLoop.scheduler();
      if (simulateInfiniteLoop) {
        throw 'SimulateInfiniteLoop';
      }
    }
  var ERRNO_CODES={EPERM:1,ENOENT:2,ESRCH:3,EINTR:4,EIO:5,ENXIO:6,E2BIG:7,ENOEXEC:8,EBADF:9,ECHILD:10,EAGAIN:11,EWOULDBLOCK:11,ENOMEM:12,EACCES:13,EFAULT:14,ENOTBLK:15,EBUSY:16,EEXIST:17,EXDEV:18,ENODEV:19,ENOTDIR:20,EISDIR:21,EINVAL:22,ENFILE:23,EMFILE:24,ENOTTY:25,ETXTBSY:26,EFBIG:27,ENOSPC:28,ESPIPE:29,EROFS:30,EMLINK:31,EPIPE:32,EDOM:33,ERANGE:34,ENOMSG:35,EIDRM:36,ECHRNG:37,EL2NSYNC:38,EL3HLT:39,EL3RST:40,ELNRNG:41,EUNATCH:42,ENOCSI:43,EL2HLT:44,EDEADLK:45,ENOLCK:46,EBADE:50,EBADR:51,EXFULL:52,ENOANO:53,EBADRQC:54,EBADSLT:55,EDEADLOCK:56,EBFONT:57,ENOSTR:60,ENODATA:61,ETIME:62,ENOSR:63,ENONET:64,ENOPKG:65,EREMOTE:66,ENOLINK:67,EADV:68,ESRMNT:69,ECOMM:70,EPROTO:71,EMULTIHOP:74,EDOTDOT:76,EBADMSG:77,ENOTUNIQ:80,EBADFD:81,EREMCHG:82,ELIBACC:83,ELIBBAD:84,ELIBSCN:85,ELIBMAX:86,ELIBEXEC:87,ENOSYS:88,ENOTEMPTY:90,ENAMETOOLONG:91,ELOOP:92,EOPNOTSUPP:95,EPFNOSUPPORT:96,ECONNRESET:104,ENOBUFS:105,EAFNOSUPPORT:106,EPROTOTYPE:107,ENOTSOCK:108,ENOPROTOOPT:109,ESHUTDOWN:110,ECONNREFUSED:111,EADDRINUSE:112,ECONNABORTED:113,ENETUNREACH:114,ENETDOWN:115,ETIMEDOUT:116,EHOSTDOWN:117,EHOSTUNREACH:118,EINPROGRESS:119,EALREADY:120,EDESTADDRREQ:121,EMSGSIZE:122,EPROTONOSUPPORT:123,ESOCKTNOSUPPORT:124,EADDRNOTAVAIL:125,ENETRESET:126,EISCONN:127,ENOTCONN:128,ETOOMANYREFS:129,EUSERS:131,EDQUOT:132,ESTALE:133,ENOTSUP:134,ENOMEDIUM:135,EILSEQ:138,EOVERFLOW:139,ECANCELED:140,ENOTRECOVERABLE:141,EOWNERDEAD:142,ESTRPIPE:143};
  var ERRNO_MESSAGES={0:"Success",1:"Not super-user",2:"No such file or directory",3:"No such process",4:"Interrupted system call",5:"I/O error",6:"No such device or address",7:"Arg list too long",8:"Exec format error",9:"Bad file number",10:"No children",11:"No more processes",12:"Not enough core",13:"Permission denied",14:"Bad address",15:"Block device required",16:"Mount device busy",17:"File exists",18:"Cross-device link",19:"No such device",20:"Not a directory",21:"Is a directory",22:"Invalid argument",23:"Too many open files in system",24:"Too many open files",25:"Not a typewriter",26:"Text file busy",27:"File too large",28:"No space left on device",29:"Illegal seek",30:"Read only file system",31:"Too many links",32:"Broken pipe",33:"Math arg out of domain of func",34:"Math result not representable",35:"No message of desired type",36:"Identifier removed",37:"Channel number out of range",38:"Level 2 not synchronized",39:"Level 3 halted",40:"Level 3 reset",41:"Link number out of range",42:"Protocol driver not attached",43:"No CSI structure available",44:"Level 2 halted",45:"Deadlock condition",46:"No record locks available",50:"Invalid exchange",51:"Invalid request descriptor",52:"Exchange full",53:"No anode",54:"Invalid request code",55:"Invalid slot",56:"File locking deadlock error",57:"Bad font file fmt",60:"Device not a stream",61:"No data (for no delay io)",62:"Timer expired",63:"Out of streams resources",64:"Machine is not on the network",65:"Package not installed",66:"The object is remote",67:"The link has been severed",68:"Advertise error",69:"Srmount error",70:"Communication error on send",71:"Protocol error",74:"Multihop attempted",76:"Cross mount point (not really error)",77:"Trying to read unreadable message",80:"Given log. name not unique",81:"f.d. invalid for this operation",82:"Remote address changed",83:"Can   access a needed shared lib",84:"Accessing a corrupted shared lib",85:".lib section in a.out corrupted",86:"Attempting to link in too many libs",87:"Attempting to exec a shared library",88:"Function not implemented",90:"Directory not empty",91:"File or path name too long",92:"Too many symbolic links",95:"Operation not supported on transport endpoint",96:"Protocol family not supported",104:"Connection reset by peer",105:"No buffer space available",106:"Address family not supported by protocol family",107:"Protocol wrong type for socket",108:"Socket operation on non-socket",109:"Protocol not available",110:"Can't send after socket shutdown",111:"Connection refused",112:"Address already in use",113:"Connection aborted",114:"Network is unreachable",115:"Network interface is not configured",116:"Connection timed out",117:"Host is down",118:"Host is unreachable",119:"Connection already in progress",120:"Socket already connected",121:"Destination address required",122:"Message too long",123:"Unknown protocol",124:"Socket type not supported",125:"Address not available",126:"Connection reset by network",127:"Socket is already connected",128:"Socket is not connected",129:"Too many references",131:"Too many users",132:"Quota exceeded",133:"Stale file handle",134:"Not supported",135:"No medium (in tape drive)",138:"Illegal byte sequence",139:"Value too large for defined data type",140:"Operation canceled",141:"State not recoverable",142:"Previous owner died",143:"Streams pipe error"};
  var ___errno_state=0;function ___setErrNo(value) {
      // For convenient setting and returning of errno.
      HEAP32[((___errno_state)>>2)]=value
      return value;
    }
  var VFS=undefined;
  var PATH={splitPath:function (filename) {
        var splitPathRe = /^(\/?|)([\s\S]*?)((?:\.{1,2}|[^\/]+?|)(\.[^.\/]*|))(?:[\/]*)$/;
        return splitPathRe.exec(filename).slice(1);
      },normalizeArray:function (parts, allowAboveRoot) {
        // if the path tries to go above the root, `up` ends up > 0
        var up = 0;
        for (var i = parts.length - 1; i >= 0; i--) {
          var last = parts[i];
          if (last === '.') {
            parts.splice(i, 1);
          } else if (last === '..') {
            parts.splice(i, 1);
            up++;
          } else if (up) {
            parts.splice(i, 1);
            up--;
          }
        }
        // if the path is allowed to go above the root, restore leading ..s
        if (allowAboveRoot) {
          for (; up--; up) {
            parts.unshift('..');
          }
        }
        return parts;
      },normalize:function (path) {
        var isAbsolute = path.charAt(0) === '/',
            trailingSlash = path.substr(-1) === '/';
        // Normalize the path
        path = PATH.normalizeArray(path.split('/').filter(function(p) {
          return !!p;
        }), !isAbsolute).join('/');
        if (!path && !isAbsolute) {
          path = '.';
        }
        if (path && trailingSlash) {
          path += '/';
        }
        return (isAbsolute ? '/' : '') + path;
      },dirname:function (path) {
        var result = PATH.splitPath(path),
            root = result[0],
            dir = result[1];
        if (!root && !dir) {
          // No dirname whatsoever
          return '.';
        }
        if (dir) {
          // It has a dirname, strip trailing slash
          dir = dir.substr(0, dir.length - 1);
        }
        return root + dir;
      },basename:function (path, ext) {
        // EMSCRIPTEN return '/'' for '/', not an empty string
        if (path === '/') return '/';
        var f = PATH.splitPath(path)[2];
        if (ext && f.substr(-1 * ext.length) === ext) {
          f = f.substr(0, f.length - ext.length);
        }
        return f;
      },extname:function (path) {
        return PATH.splitPath(path)[3];
      },join:function () {
        var paths = Array.prototype.slice.call(arguments, 0);
        return PATH.normalize(paths.filter(function(p, index) {
          if (typeof p !== 'string') {
            throw new TypeError('Arguments to path.join must be strings');
          }
          return p;
        }).join('/'));
      },resolve:function () {
        var resolvedPath = '',
          resolvedAbsolute = false;
        for (var i = arguments.length - 1; i >= -1 && !resolvedAbsolute; i--) {
          var path = (i >= 0) ? arguments[i] : FS.cwd();
          // Skip empty and invalid entries
          if (typeof path !== 'string') {
            throw new TypeError('Arguments to path.resolve must be strings');
          } else if (!path) {
            continue;
          }
          resolvedPath = path + '/' + resolvedPath;
          resolvedAbsolute = path.charAt(0) === '/';
        }
        // At this point the path should be resolved to a full absolute path, but
        // handle relative paths to be safe (might happen when process.cwd() fails)
        resolvedPath = PATH.normalizeArray(resolvedPath.split('/').filter(function(p) {
          return !!p;
        }), !resolvedAbsolute).join('/');
        return ((resolvedAbsolute ? '/' : '') + resolvedPath) || '.';
      },relative:function (from, to) {
        from = PATH.resolve(from).substr(1);
        to = PATH.resolve(to).substr(1);
        function trim(arr) {
          var start = 0;
          for (; start < arr.length; start++) {
            if (arr[start] !== '') break;
          }
          var end = arr.length - 1;
          for (; end >= 0; end--) {
            if (arr[end] !== '') break;
          }
          if (start > end) return [];
          return arr.slice(start, end - start + 1);
        }
        var fromParts = trim(from.split('/'));
        var toParts = trim(to.split('/'));
        var length = Math.min(fromParts.length, toParts.length);
        var samePartsLength = length;
        for (var i = 0; i < length; i++) {
          if (fromParts[i] !== toParts[i]) {
            samePartsLength = i;
            break;
          }
        }
        var outputParts = [];
        for (var i = samePartsLength; i < fromParts.length; i++) {
          outputParts.push('..');
        }
        outputParts = outputParts.concat(toParts.slice(samePartsLength));
        return outputParts.join('/');
      }};
  var TTY={ttys:[],init:function () {
        // https://github.com/kripken/emscripten/pull/1555
        // if (ENVIRONMENT_IS_NODE) {
        //   // currently, FS.init does not distinguish if process.stdin is a file or TTY
        //   // device, it always assumes it's a TTY device. because of this, we're forcing
        //   // process.stdin to UTF8 encoding to at least make stdin reading compatible
        //   // with text files until FS.init can be refactored.
        //   process['stdin']['setEncoding']('utf8');
        // }
      },shutdown:function () {
        // https://github.com/kripken/emscripten/pull/1555
        // if (ENVIRONMENT_IS_NODE) {
        //   // inolen: any idea as to why node -e 'process.stdin.read()' wouldn't exit immediately (with process.stdin being a tty)?
        //   // isaacs: because now it's reading from the stream, you've expressed interest in it, so that read() kicks off a _read() which creates a ReadReq operation
        //   // inolen: I thought read() in that case was a synchronous operation that just grabbed some amount of buffered data if it exists?
        //   // isaacs: it is. but it also triggers a _read() call, which calls readStart() on the handle
        //   // isaacs: do process.stdin.pause() and i'd think it'd probably close the pending call
        //   process['stdin']['pause']();
        // }
      },register:function (dev, ops) {
        TTY.ttys[dev] = { input: [], output: [], ops: ops };
        FS.registerDevice(dev, TTY.stream_ops);
      },stream_ops:{open:function (stream) {
          var tty = TTY.ttys[stream.node.rdev];
          if (!tty) {
            throw new FS.ErrnoError(ERRNO_CODES.ENODEV);
          }
          stream.tty = tty;
          stream.seekable = false;
        },close:function (stream) {
          // flush any pending line data
          if (stream.tty.output.length) {
            stream.tty.ops.put_char(stream.tty, 10);
          }
        },read:function (stream, buffer, offset, length, pos /* ignored */) {
          if (!stream.tty || !stream.tty.ops.get_char) {
            throw new FS.ErrnoError(ERRNO_CODES.ENXIO);
          }
          var bytesRead = 0;
          for (var i = 0; i < length; i++) {
            var result;
            try {
              result = stream.tty.ops.get_char(stream.tty);
            } catch (e) {
              throw new FS.ErrnoError(ERRNO_CODES.EIO);
            }
            if (result === undefined && bytesRead === 0) {
              throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
            }
            if (result === null || result === undefined) break;
            bytesRead++;
            buffer[offset+i] = result;
          }
          if (bytesRead) {
            stream.node.timestamp = Date.now();
          }
          return bytesRead;
        },write:function (stream, buffer, offset, length, pos) {
          if (!stream.tty || !stream.tty.ops.put_char) {
            throw new FS.ErrnoError(ERRNO_CODES.ENXIO);
          }
          for (var i = 0; i < length; i++) {
            try {
              stream.tty.ops.put_char(stream.tty, buffer[offset+i]);
            } catch (e) {
              throw new FS.ErrnoError(ERRNO_CODES.EIO);
            }
          }
          if (length) {
            stream.node.timestamp = Date.now();
          }
          return i;
        }},default_tty_ops:{get_char:function (tty) {
          if (!tty.input.length) {
            var result = null;
            if (ENVIRONMENT_IS_NODE) {
              result = process['stdin']['read']();
              if (!result) {
                if (process['stdin']['_readableState'] && process['stdin']['_readableState']['ended']) {
                  return null;  // EOF
                }
                return undefined;  // no data available
              }
            } else if (typeof window != 'undefined' &&
              typeof window.prompt == 'function') {
              // Browser.
              result = window.prompt('Input: ');  // returns null on cancel
              if (result !== null) {
                result += '\n';
              }
            } else if (typeof readline == 'function') {
              // Command line.
              result = readline();
              if (result !== null) {
                result += '\n';
              }
            }
            if (!result) {
              return null;
            }
            tty.input = intArrayFromString(result, true);
          }
          return tty.input.shift();
        },put_char:function (tty, val) {
          if (val === null || val === 10) {
            Module['print'](tty.output.join(''));
            tty.output = [];
          } else {
            tty.output.push(TTY.utf8.processCChar(val));
          }
        }},default_tty1_ops:{put_char:function (tty, val) {
          if (val === null || val === 10) {
            Module['printErr'](tty.output.join(''));
            tty.output = [];
          } else {
            tty.output.push(TTY.utf8.processCChar(val));
          }
        }}};
  var MEMFS={CONTENT_OWNING:1,CONTENT_FLEXIBLE:2,CONTENT_FIXED:3,ensureFlexible:function (node) {
        if (node.contentMode !== MEMFS.CONTENT_FLEXIBLE) {
          var contents = node.contents;
          node.contents = Array.prototype.slice.call(contents);
          node.contentMode = MEMFS.CONTENT_FLEXIBLE;
        }
      },mount:function (mount) {
        return MEMFS.create_node(null, '/', 0040000 | 0777, 0);
      },create_node:function (parent, name, mode, dev) {
        if (FS.isBlkdev(mode) || FS.isFIFO(mode)) {
          // no supported
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        var node = FS.createNode(parent, name, mode, dev);
        if (FS.isDir(node.mode)) {
          node.node_ops = {
            getattr: MEMFS.node_ops.getattr,
            setattr: MEMFS.node_ops.setattr,
            lookup: MEMFS.node_ops.lookup,
            mknod: MEMFS.node_ops.mknod,
            mknod: MEMFS.node_ops.mknod,
            rename: MEMFS.node_ops.rename,
            unlink: MEMFS.node_ops.unlink,
            rmdir: MEMFS.node_ops.rmdir,
            readdir: MEMFS.node_ops.readdir,
            symlink: MEMFS.node_ops.symlink
          };
          node.stream_ops = {
            llseek: MEMFS.stream_ops.llseek
          };
          node.contents = {};
        } else if (FS.isFile(node.mode)) {
          node.node_ops = {
            getattr: MEMFS.node_ops.getattr,
            setattr: MEMFS.node_ops.setattr
          };
          node.stream_ops = {
            llseek: MEMFS.stream_ops.llseek,
            read: MEMFS.stream_ops.read,
            write: MEMFS.stream_ops.write,
            allocate: MEMFS.stream_ops.allocate,
            mmap: MEMFS.stream_ops.mmap
          };
          node.contents = [];
          node.contentMode = MEMFS.CONTENT_FLEXIBLE;
        } else if (FS.isLink(node.mode)) {
          node.node_ops = {
            getattr: MEMFS.node_ops.getattr,
            setattr: MEMFS.node_ops.setattr,
            readlink: MEMFS.node_ops.readlink
          };
          node.stream_ops = {};
        } else if (FS.isChrdev(node.mode)) {
          node.node_ops = {
            getattr: MEMFS.node_ops.getattr,
            setattr: MEMFS.node_ops.setattr
          };
          node.stream_ops = FS.chrdev_stream_ops;
        }
        node.timestamp = Date.now();
        // add the new node to the parent
        if (parent) {
          parent.contents[name] = node;
        }
        return node;
      },node_ops:{getattr:function (node) {
          var attr = {};
          // device numbers reuse inode numbers.
          attr.dev = FS.isChrdev(node.mode) ? node.id : 1;
          attr.ino = node.id;
          attr.mode = node.mode;
          attr.nlink = 1;
          attr.uid = 0;
          attr.gid = 0;
          attr.rdev = node.rdev;
          if (FS.isDir(node.mode)) {
            attr.size = 4096;
          } else if (FS.isFile(node.mode)) {
            attr.size = node.contents.length;
          } else if (FS.isLink(node.mode)) {
            attr.size = node.link.length;
          } else {
            attr.size = 0;
          }
          attr.atime = new Date(node.timestamp);
          attr.mtime = new Date(node.timestamp);
          attr.ctime = new Date(node.timestamp);
          // NOTE: In our implementation, st_blocks = Math.ceil(st_size/st_blksize),
          //       but this is not required by the standard.
          attr.blksize = 4096;
          attr.blocks = Math.ceil(attr.size / attr.blksize);
          return attr;
        },setattr:function (node, attr) {
          if (attr.mode !== undefined) {
            node.mode = attr.mode;
          }
          if (attr.timestamp !== undefined) {
            node.timestamp = attr.timestamp;
          }
          if (attr.size !== undefined) {
            MEMFS.ensureFlexible(node);
            var contents = node.contents;
            if (attr.size < contents.length) contents.length = attr.size;
            else while (attr.size > contents.length) contents.push(0);
          }
        },lookup:function (parent, name) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
        },mknod:function (parent, name, mode, dev) {
          return MEMFS.create_node(parent, name, mode, dev);
        },rename:function (old_node, new_dir, new_name) {
          // if we're overwriting a directory at new_name, make sure it's empty.
          if (FS.isDir(old_node.mode)) {
            var new_node;
            try {
              new_node = FS.lookupNode(new_dir, new_name);
            } catch (e) {
            }
            if (new_node) {
              for (var i in new_node.contents) {
                throw new FS.ErrnoError(ERRNO_CODES.ENOTEMPTY);
              }
            }
          }
          // do the internal rewiring
          delete old_node.parent.contents[old_node.name];
          old_node.name = new_name;
          new_dir.contents[new_name] = old_node;
        },unlink:function (parent, name) {
          delete parent.contents[name];
        },rmdir:function (parent, name) {
          var node = FS.lookupNode(parent, name);
          for (var i in node.contents) {
            throw new FS.ErrnoError(ERRNO_CODES.ENOTEMPTY);
          }
          delete parent.contents[name];
        },readdir:function (node) {
          var entries = ['.', '..']
          for (var key in node.contents) {
            if (!node.contents.hasOwnProperty(key)) {
              continue;
            }
            entries.push(key);
          }
          return entries;
        },symlink:function (parent, newname, oldpath) {
          var node = MEMFS.create_node(parent, newname, 0777 | 0120000, 0);
          node.link = oldpath;
          return node;
        },readlink:function (node) {
          if (!FS.isLink(node.mode)) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
          return node.link;
        }},stream_ops:{read:function (stream, buffer, offset, length, position) {
          var contents = stream.node.contents;
          var size = Math.min(contents.length - position, length);
          if (size > 8 && contents.subarray) { // non-trivial, and typed array
            buffer.set(contents.subarray(position, position + size), offset);
          } else
          {
            for (var i = 0; i < size; i++) {
              buffer[offset + i] = contents[position + i];
            }
          }
          return size;
        },write:function (stream, buffer, offset, length, position, canOwn) {
          var node = stream.node;
          node.timestamp = Date.now();
          var contents = node.contents;
          if (length && contents.length === 0 && position === 0 && buffer.subarray) {
            // just replace it with the new data
            assert(buffer.length);
            if (canOwn && buffer.buffer === HEAP8.buffer && offset === 0) {
              node.contents = buffer; // this is a subarray of the heap, and we can own it
              node.contentMode = MEMFS.CONTENT_OWNING;
            } else {
              node.contents = new Uint8Array(buffer.subarray(offset, offset+length));
              node.contentMode = MEMFS.CONTENT_FIXED;
            }
            return length;
          }
          MEMFS.ensureFlexible(node);
          var contents = node.contents;
          while (contents.length < position) contents.push(0);
          for (var i = 0; i < length; i++) {
            contents[position + i] = buffer[offset + i];
          }
          return length;
        },llseek:function (stream, offset, whence) {
          var position = offset;
          if (whence === 1) {  // SEEK_CUR.
            position += stream.position;
          } else if (whence === 2) {  // SEEK_END.
            if (FS.isFile(stream.node.mode)) {
              position += stream.node.contents.length;
            }
          }
          if (position < 0) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
          stream.ungotten = [];
          stream.position = position;
          return position;
        },allocate:function (stream, offset, length) {
          MEMFS.ensureFlexible(stream.node);
          var contents = stream.node.contents;
          var limit = offset + length;
          while (limit > contents.length) contents.push(0);
        },mmap:function (stream, buffer, offset, length, position, prot, flags) {
          if (!FS.isFile(stream.node.mode)) {
            throw new FS.ErrnoError(ERRNO_CODES.ENODEV);
          }
          var ptr;
          var allocated;
          var contents = stream.node.contents;
          // Only make a new copy when MAP_PRIVATE is specified.
          if ( !(flags & 0x02) &&
                (contents.buffer === buffer || contents.buffer === buffer.buffer) ) {
            // We can't emulate MAP_SHARED when the file is not backed by the buffer
            // we're mapping to (e.g. the HEAP buffer).
            allocated = false;
            ptr = contents.byteOffset;
          } else {
            // Try to avoid unnecessary slices.
            if (position > 0 || position + length < contents.length) {
              if (contents.subarray) {
                contents = contents.subarray(position, position + length);
              } else {
                contents = Array.prototype.slice.call(contents, position, position + length);
              }
            }
            allocated = true;
            ptr = _malloc(length);
            if (!ptr) {
              throw new FS.ErrnoError(ERRNO_CODES.ENOMEM);
            }
            buffer.set(contents, ptr);
          }
          return { ptr: ptr, allocated: allocated };
        }}};
  var _stdin=allocate(1, "i32*", ALLOC_STATIC);
  var _stdout=allocate(1, "i32*", ALLOC_STATIC);
  var _stderr=allocate(1, "i32*", ALLOC_STATIC);var FS={root:null,nodes:[null],devices:[null],streams:[null],nextInode:1,name_table:null,currentPath:"/",initialized:false,ignorePermissions:true,ErrnoError:function ErrnoError(errno) {
          this.errno = errno;
          for (var key in ERRNO_CODES) {
            if (ERRNO_CODES[key] === errno) {
              this.code = key;
              break;
            }
          }
          this.message = ERRNO_MESSAGES[errno];
        },handleFSError:function (e) {
        if (!(e instanceof FS.ErrnoError)) throw e + ' : ' + new Error().stack;
        return ___setErrNo(e.errno);
      },hashName:function (parentid, name) {
        var hash = 0;
        for (var i = 0; i < name.length; i++) {
          hash = ((hash << 5) - hash + name.charCodeAt(i)) | 0;
        }
        return ((parentid + hash) >>> 0) % FS.name_table.length;
      },hashAddNode:function (node) {
        var hash = FS.hashName(node.parent.id, node.name);
        node.name_next = FS.name_table[hash];
        FS.name_table[hash] = node;
      },hashRemoveNode:function (node) {
        var hash = FS.hashName(node.parent.id, node.name);
        if (FS.name_table[hash] === node) {
          FS.name_table[hash] = node.name_next;
        } else {
          var current = FS.name_table[hash];
          while (current) {
            if (current.name_next === node) {
              current.name_next = node.name_next;
              break;
            }
            current = current.name_next;
          }
        }
      },lookupNode:function (parent, name) {
        var err = FS.mayLookup(parent);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        var hash = FS.hashName(parent.id, name);
        for (var node = FS.name_table[hash]; node; node = node.name_next) {
          if (node.parent.id === parent.id && node.name === name) {
            return node;
          }
        }
        // if we failed to find it in the cache, call into the VFS
        return FS.lookup(parent, name);
      },createNode:function (parent, name, mode, rdev) {
        var node = {
          id: FS.nextInode++,
          name: name,
          mode: mode,
          node_ops: {},
          stream_ops: {},
          rdev: rdev,
          parent: null,
          mount: null
        };
        if (!parent) {
          parent = node;  // root node sets parent to itself
        }
        node.parent = parent;
        node.mount = parent.mount;
        // compatibility
        var readMode = 292 | 73;
        var writeMode = 146;
        // NOTE we must use Object.defineProperties instead of individual calls to
        // Object.defineProperty in order to make closure compiler happy
        Object.defineProperties(node, {
          read: {
            get: function() { return (node.mode & readMode) === readMode; },
            set: function(val) { val ? node.mode |= readMode : node.mode &= ~readMode; }
          },
          write: {
            get: function() { return (node.mode & writeMode) === writeMode; },
            set: function(val) { val ? node.mode |= writeMode : node.mode &= ~writeMode; }
          },
          isFolder: {
            get: function() { return FS.isDir(node.mode); },
          },
          isDevice: {
            get: function() { return FS.isChrdev(node.mode); },
          },
        });
        FS.hashAddNode(node);
        return node;
      },destroyNode:function (node) {
        FS.hashRemoveNode(node);
      },isRoot:function (node) {
        return node === node.parent;
      },isMountpoint:function (node) {
        return node.mounted;
      },isFile:function (mode) {
        return (mode & 0170000) === 0100000;
      },isDir:function (mode) {
        return (mode & 0170000) === 0040000;
      },isLink:function (mode) {
        return (mode & 0170000) === 0120000;
      },isChrdev:function (mode) {
        return (mode & 0170000) === 0020000;
      },isBlkdev:function (mode) {
        return (mode & 0170000) === 0060000;
      },isFIFO:function (mode) {
        return (mode & 0170000) === 0010000;
      },isSocket:function (mode) {
        return (mode & 0140000) === 0140000;
      },cwd:function () {
        return FS.currentPath;
      },lookupPath:function (path, opts) {
        path = PATH.resolve(FS.currentPath, path);
        opts = opts || { recurse_count: 0 };
        if (opts.recurse_count > 8) {  // max recursive lookup of 8
          throw new FS.ErrnoError(ERRNO_CODES.ELOOP);
        }
        // split the path
        var parts = PATH.normalizeArray(path.split('/').filter(function(p) {
          return !!p;
        }), false);
        // start at the root
        var current = FS.root;
        var current_path = '/';
        for (var i = 0; i < parts.length; i++) {
          var islast = (i === parts.length-1);
          if (islast && opts.parent) {
            // stop resolving
            break;
          }
          current = FS.lookupNode(current, parts[i]);
          current_path = PATH.join(current_path, parts[i]);
          // jump to the mount's root node if this is a mountpoint
          if (FS.isMountpoint(current)) {
            current = current.mount.root;
          }
          // follow symlinks
          // by default, lookupPath will not follow a symlink if it is the final path component.
          // setting opts.follow = true will override this behavior.
          if (!islast || opts.follow) {
            var count = 0;
            while (FS.isLink(current.mode)) {
              var link = FS.readlink(current_path);
              current_path = PATH.resolve(PATH.dirname(current_path), link);
              var lookup = FS.lookupPath(current_path, { recurse_count: opts.recurse_count });
              current = lookup.node;
              if (count++ > 40) {  // limit max consecutive symlinks to 40 (SYMLOOP_MAX).
                throw new FS.ErrnoError(ERRNO_CODES.ELOOP);
              }
            }
          }
        }
        return { path: current_path, node: current };
      },getPath:function (node) {
        var path;
        while (true) {
          if (FS.isRoot(node)) {
            return path ? PATH.join(node.mount.mountpoint, path) : node.mount.mountpoint;
          }
          path = path ? PATH.join(node.name, path) : node.name;
          node = node.parent;
        }
      },flagModes:{"r":0,"rs":8192,"r+":2,"w":1537,"wx":3585,"xw":3585,"w+":1538,"wx+":3586,"xw+":3586,"a":521,"ax":2569,"xa":2569,"a+":522,"ax+":2570,"xa+":2570},modeStringToFlags:function (str) {
        var flags = FS.flagModes[str];
        if (typeof flags === 'undefined') {
          throw new Error('Unknown file open mode: ' + str);
        }
        return flags;
      },flagsToPermissionString:function (flag) {
        var accmode = flag & 3;
        var perms = ['r', 'w', 'rw'][accmode];
        if ((flag & 1024)) {
          perms += 'w';
        }
        return perms;
      },nodePermissions:function (node, perms) {
        if (FS.ignorePermissions) {
          return 0;
        }
        // return 0 if any user, group or owner bits are set.
        if (perms.indexOf('r') !== -1 && !(node.mode & 292)) {
          return ERRNO_CODES.EACCES;
        } else if (perms.indexOf('w') !== -1 && !(node.mode & 146)) {
          return ERRNO_CODES.EACCES;
        } else if (perms.indexOf('x') !== -1 && !(node.mode & 73)) {
          return ERRNO_CODES.EACCES;
        }
        return 0;
      },mayLookup:function (dir) {
        return FS.nodePermissions(dir, 'x');
      },mayMknod:function (mode) {
        switch (mode & 0170000) {
          case 0100000:
          case 0020000:
          case 0060000:
          case 0010000:
          case 0140000:
            return 0;
          default:
            return ERRNO_CODES.EINVAL;
        }
      },mayCreate:function (dir, name) {
        try {
          var node = FS.lookupNode(dir, name);
          return ERRNO_CODES.EEXIST;
        } catch (e) {
        }
        return FS.nodePermissions(dir, 'wx');
      },mayDelete:function (dir, name, isdir) {
        var node;
        try {
          node = FS.lookupNode(dir, name);
        } catch (e) {
          return e.errno;
        }
        var err = FS.nodePermissions(dir, 'wx');
        if (err) {
          return err;
        }
        if (isdir) {
          if (!FS.isDir(node.mode)) {
            return ERRNO_CODES.ENOTDIR;
          }
          if (FS.isRoot(node) || FS.getPath(node) === FS.currentPath) {
            return ERRNO_CODES.EBUSY;
          }
        } else {
          if (FS.isDir(node.mode)) {
            return ERRNO_CODES.EISDIR;
          }
        }
        return 0;
      },mayOpen:function (node, flags) {
        if (!node) {
          return ERRNO_CODES.ENOENT;
        }
        if (FS.isLink(node.mode)) {
          return ERRNO_CODES.ELOOP;
        } else if (FS.isDir(node.mode)) {
          if ((flags & 3) !== 0 ||  // opening for write
              (flags & 1024)) {
            return ERRNO_CODES.EISDIR;
          }
        }
        return FS.nodePermissions(node, FS.flagsToPermissionString(flags));
      },chrdev_stream_ops:{open:function (stream) {
          var device = FS.getDevice(stream.node.rdev);
          // override node's stream ops with the device's
          stream.stream_ops = device.stream_ops;
          // forward the open call
          if (stream.stream_ops.open) {
            stream.stream_ops.open(stream);
          }
        },llseek:function () {
          throw new FS.ErrnoError(ERRNO_CODES.ESPIPE);
        }},major:function (dev) {
        return ((dev) >> 8);
      },minor:function (dev) {
        return ((dev) & 0xff);
      },makedev:function (ma, mi) {
        return ((ma) << 8 | (mi));
      },registerDevice:function (dev, ops) {
        FS.devices[dev] = { stream_ops: ops };
      },getDevice:function (dev) {
        return FS.devices[dev];
      },MAX_OPEN_FDS:4096,nextfd:function (fd_start, fd_end) {
        fd_start = fd_start || 1;
        fd_end = fd_end || FS.MAX_OPEN_FDS;
        for (var fd = fd_start; fd <= fd_end; fd++) {
          if (!FS.streams[fd]) {
            return fd;
          }
        }
        throw new FS.ErrnoError(ERRNO_CODES.EMFILE);
      },getStream:function (fd) {
        return FS.streams[fd];
      },createStream:function (stream, fd_start, fd_end) {
        var fd = FS.nextfd(fd_start, fd_end);
        stream.fd = fd;
        // compatibility
        Object.defineProperties(stream, {
          object: {
            get: function() { return stream.node; },
            set: function(val) { stream.node = val; }
          },
          isRead: {
            get: function() { return (stream.flags & 3) !== 1; }
          },
          isWrite: {
            get: function() { return (stream.flags & 3) !== 0; }
          },
          isAppend: {
            get: function() { return (stream.flags & 8); }
          }
        });
        FS.streams[fd] = stream;
        return stream;
      },closeStream:function (fd) {
        FS.streams[fd] = null;
      },getMode:function (canRead, canWrite) {
        var mode = 0;
        if (canRead) mode |= 292 | 73;
        if (canWrite) mode |= 146;
        return mode;
      },joinPath:function (parts, forceRelative) {
        var path = PATH.join.apply(null, parts);
        if (forceRelative && path[0] == '/') path = path.substr(1);
        return path;
      },absolutePath:function (relative, base) {
        return PATH.resolve(base, relative);
      },standardizePath:function (path) {
        return PATH.normalize(path);
      },findObject:function (path, dontResolveLastLink) {
        var ret = FS.analyzePath(path, dontResolveLastLink);
        if (ret.exists) {
          return ret.object;
        } else {
          ___setErrNo(ret.error);
          return null;
        }
      },analyzePath:function (path, dontResolveLastLink) {
        // operate from within the context of the symlink's target
        try {
          var lookup = FS.lookupPath(path, { follow: !dontResolveLastLink });
          path = lookup.path;
        } catch (e) {
        }
        var ret = {
          isRoot: false, exists: false, error: 0, name: null, path: null, object: null,
          parentExists: false, parentPath: null, parentObject: null
        };
        try {
          var lookup = FS.lookupPath(path, { parent: true });
          ret.parentExists = true;
          ret.parentPath = lookup.path;
          ret.parentObject = lookup.node;
          ret.name = PATH.basename(path);
          lookup = FS.lookupPath(path, { follow: !dontResolveLastLink });
          ret.exists = true;
          ret.path = lookup.path;
          ret.object = lookup.node;
          ret.name = lookup.node.name;
          ret.isRoot = lookup.path === '/';
        } catch (e) {
          ret.error = e.errno;
        };
        return ret;
      },createFolder:function (parent, name, canRead, canWrite) {
        var path = PATH.join(typeof parent === 'string' ? parent : FS.getPath(parent), name);
        var mode = FS.getMode(canRead, canWrite);
        return FS.mkdir(path, mode);
      },createPath:function (parent, path, canRead, canWrite) {
        parent = typeof parent === 'string' ? parent : FS.getPath(parent);
        var parts = path.split('/').reverse();
        while (parts.length) {
          var part = parts.pop();
          if (!part) continue;
          var current = PATH.join(parent, part);
          try {
            FS.mkdir(current, 0777);
          } catch (e) {
            // ignore EEXIST
          }
          parent = current;
        }
        return current;
      },createFile:function (parent, name, properties, canRead, canWrite) {
        var path = PATH.join(typeof parent === 'string' ? parent : FS.getPath(parent), name);
        var mode = FS.getMode(canRead, canWrite);
        return FS.create(path, mode);
      },createDataFile:function (parent, name, data, canRead, canWrite, canOwn) {
        var path = name ? PATH.join(typeof parent === 'string' ? parent : FS.getPath(parent), name) : parent;
        var mode = FS.getMode(canRead, canWrite);
        var node = FS.create(path, mode);
        if (data) {
          if (typeof data === 'string') {
            var arr = new Array(data.length);
            for (var i = 0, len = data.length; i < len; ++i) arr[i] = data.charCodeAt(i);
            data = arr;
          }
          // make sure we can write to the file
          FS.chmod(path, mode | 146);
          var stream = FS.open(path, 'w');
          FS.write(stream, data, 0, data.length, 0, canOwn);
          FS.close(stream);
          FS.chmod(path, mode);
        }
        return node;
      },createDevice:function (parent, name, input, output) {
        var path = PATH.join(typeof parent === 'string' ? parent : FS.getPath(parent), name);
        var mode = FS.getMode(!!input, !!output);
        if (!FS.createDevice.major) FS.createDevice.major = 64;
        var dev = FS.makedev(FS.createDevice.major++, 0);
        // Create a fake device that a set of stream ops to emulate
        // the old behavior.
        FS.registerDevice(dev, {
          open: function(stream) {
            stream.seekable = false;
          },
          close: function(stream) {
            // flush any pending line data
            if (output && output.buffer && output.buffer.length) {
              output(10);
            }
          },
          read: function(stream, buffer, offset, length, pos /* ignored */) {
            var bytesRead = 0;
            for (var i = 0; i < length; i++) {
              var result;
              try {
                result = input();
              } catch (e) {
                throw new FS.ErrnoError(ERRNO_CODES.EIO);
              }
              if (result === undefined && bytesRead === 0) {
                throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
              }
              if (result === null || result === undefined) break;
              bytesRead++;
              buffer[offset+i] = result;
            }
            if (bytesRead) {
              stream.node.timestamp = Date.now();
            }
            return bytesRead;
          },
          write: function(stream, buffer, offset, length, pos) {
            for (var i = 0; i < length; i++) {
              try {
                output(buffer[offset+i]);
              } catch (e) {
                throw new FS.ErrnoError(ERRNO_CODES.EIO);
              }
            }
            if (length) {
              stream.node.timestamp = Date.now();
            }
            return i;
          }
        });
        return FS.mkdev(path, mode, dev);
      },createLink:function (parent, name, target, canRead, canWrite) {
        var path = PATH.join(typeof parent === 'string' ? parent : FS.getPath(parent), name);
        return FS.symlink(target, path);
      },forceLoadFile:function (obj) {
        if (obj.isDevice || obj.isFolder || obj.link || obj.contents) return true;
        var success = true;
        if (typeof XMLHttpRequest !== 'undefined') {
          throw new Error("Lazy loading should have been performed (contents set) in createLazyFile, but it was not. Lazy loading only works in web workers. Use --embed-file or --preload-file in emcc on the main thread.");
        } else if (Module['read']) {
          // Command-line.
          try {
            // WARNING: Can't read binary files in V8's d8 or tracemonkey's js, as
            //          read() will try to parse UTF8.
            obj.contents = intArrayFromString(Module['read'](obj.url), true);
          } catch (e) {
            success = false;
          }
        } else {
          throw new Error('Cannot load without read() or XMLHttpRequest.');
        }
        if (!success) ___setErrNo(ERRNO_CODES.EIO);
        return success;
      },createLazyFile:function (parent, name, url, canRead, canWrite) {
        if (typeof XMLHttpRequest !== 'undefined') {
          if (!ENVIRONMENT_IS_WORKER) throw 'Cannot do synchronous binary XHRs outside webworkers in modern browsers. Use --embed-file or --preload-file in emcc';
          // Lazy chunked Uint8Array (implements get and length from Uint8Array). Actual getting is abstracted away for eventual reuse.
          var LazyUint8Array = function() {
            this.lengthKnown = false;
            this.chunks = []; // Loaded chunks. Index is the chunk number
          }
          LazyUint8Array.prototype.get = function(idx) {
            if (idx > this.length-1 || idx < 0) {
              return undefined;
            }
            var chunkOffset = idx % this.chunkSize;
            var chunkNum = Math.floor(idx / this.chunkSize);
            return this.getter(chunkNum)[chunkOffset];
          }
          LazyUint8Array.prototype.setDataGetter = function(getter) {
            this.getter = getter;
          }
          LazyUint8Array.prototype.cacheLength = function() {
              // Find length
              var xhr = new XMLHttpRequest();
              xhr.open('HEAD', url, false);
              xhr.send(null);
              if (!(xhr.status >= 200 && xhr.status < 300 || xhr.status === 304)) throw new Error("Couldn't load " + url + ". Status: " + xhr.status);
              var datalength = Number(xhr.getResponseHeader("Content-length"));
              var header;
              var hasByteServing = (header = xhr.getResponseHeader("Accept-Ranges")) && header === "bytes";
              var chunkSize = 1024*1024; // Chunk size in bytes
              if (!hasByteServing) chunkSize = datalength;
              // Function to get a range from the remote URL.
              var doXHR = (function(from, to) {
                if (from > to) throw new Error("invalid range (" + from + ", " + to + ") or no bytes requested!");
                if (to > datalength-1) throw new Error("only " + datalength + " bytes available! programmer error!");
                // TODO: Use mozResponseArrayBuffer, responseStream, etc. if available.
                var xhr = new XMLHttpRequest();
                xhr.open('GET', url, false);
                if (datalength !== chunkSize) xhr.setRequestHeader("Range", "bytes=" + from + "-" + to);
                // Some hints to the browser that we want binary data.
                if (typeof Uint8Array != 'undefined') xhr.responseType = 'arraybuffer';
                if (xhr.overrideMimeType) {
                  xhr.overrideMimeType('text/plain; charset=x-user-defined');
                }
                xhr.send(null);
                if (!(xhr.status >= 200 && xhr.status < 300 || xhr.status === 304)) throw new Error("Couldn't load " + url + ". Status: " + xhr.status);
                if (xhr.response !== undefined) {
                  return new Uint8Array(xhr.response || []);
                } else {
                  return intArrayFromString(xhr.responseText || '', true);
                }
              });
              var lazyArray = this;
              lazyArray.setDataGetter(function(chunkNum) {
                var start = chunkNum * chunkSize;
                var end = (chunkNum+1) * chunkSize - 1; // including this byte
                end = Math.min(end, datalength-1); // if datalength-1 is selected, this is the last block
                if (typeof(lazyArray.chunks[chunkNum]) === "undefined") {
                  lazyArray.chunks[chunkNum] = doXHR(start, end);
                }
                if (typeof(lazyArray.chunks[chunkNum]) === "undefined") throw new Error("doXHR failed!");
                return lazyArray.chunks[chunkNum];
              });
              this._length = datalength;
              this._chunkSize = chunkSize;
              this.lengthKnown = true;
          }
          var lazyArray = new LazyUint8Array();
          Object.defineProperty(lazyArray, "length", {
              get: function() {
                  if(!this.lengthKnown) {
                      this.cacheLength();
                  }
                  return this._length;
              }
          });
          Object.defineProperty(lazyArray, "chunkSize", {
              get: function() {
                  if(!this.lengthKnown) {
                      this.cacheLength();
                  }
                  return this._chunkSize;
              }
          });
          var properties = { isDevice: false, contents: lazyArray };
        } else {
          var properties = { isDevice: false, url: url };
        }
        var node = FS.createFile(parent, name, properties, canRead, canWrite);
        // This is a total hack, but I want to get this lazy file code out of the
        // core of MEMFS. If we want to keep this lazy file concept I feel it should
        // be its own thin LAZYFS proxying calls to MEMFS.
        if (properties.contents) {
          node.contents = properties.contents;
        } else if (properties.url) {
          node.contents = null;
          node.url = properties.url;
        }
        // override each stream op with one that tries to force load the lazy file first
        var stream_ops = {};
        var keys = Object.keys(node.stream_ops);
        keys.forEach(function(key) {
          var fn = node.stream_ops[key];
          stream_ops[key] = function() {
            if (!FS.forceLoadFile(node)) {
              throw new FS.ErrnoError(ERRNO_CODES.EIO);
            }
            return fn.apply(null, arguments);
          };
        });
        // use a custom read function
        stream_ops.read = function(stream, buffer, offset, length, position) {
          if (!FS.forceLoadFile(node)) {
            throw new FS.ErrnoError(ERRNO_CODES.EIO);
          }
          var contents = stream.node.contents;
          var size = Math.min(contents.length - position, length);
          if (contents.slice) { // normal array
            for (var i = 0; i < size; i++) {
              buffer[offset + i] = contents[position + i];
            }
          } else {
            for (var i = 0; i < size; i++) { // LazyUint8Array from sync binary XHR
              buffer[offset + i] = contents.get(position + i);
            }
          }
          return size;
        };
        node.stream_ops = stream_ops;
        return node;
      },createPreloadedFile:function (parent, name, url, canRead, canWrite, onload, onerror, dontCreateFile, canOwn) {
        Browser.init();
        // TODO we should allow people to just pass in a complete filename instead
        // of parent and name being that we just join them anyways
        var fullname = name ? PATH.resolve(PATH.join(parent, name)) : parent;
        function processData(byteArray) {
          function finish(byteArray) {
            if (!dontCreateFile) {
              FS.createDataFile(parent, name, byteArray, canRead, canWrite, canOwn);
            }
            if (onload) onload();
            removeRunDependency('cp ' + fullname);
          }
          var handled = false;
          Module['preloadPlugins'].forEach(function(plugin) {
            if (handled) return;
            if (plugin['canHandle'](fullname)) {
              plugin['handle'](byteArray, fullname, finish, function() {
                if (onerror) onerror();
                removeRunDependency('cp ' + fullname);
              });
              handled = true;
            }
          });
          if (!handled) finish(byteArray);
        }
        addRunDependency('cp ' + fullname);
        if (typeof url == 'string') {
          Browser.asyncLoad(url, function(byteArray) {
            processData(byteArray);
          }, onerror);
        } else {
          processData(url);
        }
      },indexedDB:function () {
        return window.indexedDB || window.mozIndexedDB || window.webkitIndexedDB || window.msIndexedDB;
      },DB_NAME:function () {
        return 'EM_FS_' + window.location.pathname;
      },DB_VERSION:20,DB_STORE_NAME:"FILE_DATA",saveFilesToDB:function (paths, onload, onerror) {
        onload = onload || function(){};
        onerror = onerror || function(){};
        var indexedDB = FS.indexedDB();
        try {
          var openRequest = indexedDB.open(FS.DB_NAME(), FS.DB_VERSION);
        } catch (e) {
          return onerror(e);
        }
        openRequest.onupgradeneeded = function() {
          console.log('creating db');
          var db = openRequest.result;
          db.createObjectStore(FS.DB_STORE_NAME);
        };
        openRequest.onsuccess = function() {
          var db = openRequest.result;
          var transaction = db.transaction([FS.DB_STORE_NAME], 'readwrite');
          var files = transaction.objectStore(FS.DB_STORE_NAME);
          var ok = 0, fail = 0, total = paths.length;
          function finish() {
            if (fail == 0) onload(); else onerror();
          }
          paths.forEach(function(path) {
            var putRequest = files.put(FS.analyzePath(path).object.contents, path);
            putRequest.onsuccess = function() { ok++; if (ok + fail == total) finish() };
            putRequest.onerror = function() { fail++; if (ok + fail == total) finish() };
          });
          transaction.onerror = onerror;
        };
        openRequest.onerror = onerror;
      },loadFilesFromDB:function (paths, onload, onerror) {
        onload = onload || function(){};
        onerror = onerror || function(){};
        var indexedDB = FS.indexedDB();
        try {
          var openRequest = indexedDB.open(FS.DB_NAME(), FS.DB_VERSION);
        } catch (e) {
          return onerror(e);
        }
        openRequest.onupgradeneeded = onerror; // no database to load from
        openRequest.onsuccess = function() {
          var db = openRequest.result;
          try {
            var transaction = db.transaction([FS.DB_STORE_NAME], 'readonly');
          } catch(e) {
            onerror(e);
            return;
          }
          var files = transaction.objectStore(FS.DB_STORE_NAME);
          var ok = 0, fail = 0, total = paths.length;
          function finish() {
            if (fail == 0) onload(); else onerror();
          }
          paths.forEach(function(path) {
            var getRequest = files.get(path);
            getRequest.onsuccess = function() {
              if (FS.analyzePath(path).exists) {
                FS.unlink(path);
              }
              FS.createDataFile(PATH.dirname(path), PATH.basename(path), getRequest.result, true, true, true);
              ok++;
              if (ok + fail == total) finish();
            };
            getRequest.onerror = function() { fail++; if (ok + fail == total) finish() };
          });
          transaction.onerror = onerror;
        };
        openRequest.onerror = onerror;
      },createDefaultDirectories:function () {
        FS.mkdir('/tmp', 0777);
      },createDefaultDevices:function () {
        // create /dev
        FS.mkdir('/dev', 0777);
        // setup /dev/null
        FS.registerDevice(FS.makedev(1, 3), {
          read: function() { return 0; },
          write: function() { return 0; }
        });
        FS.mkdev('/dev/null', 0666, FS.makedev(1, 3));
        // setup /dev/tty and /dev/tty1
        // stderr needs to print output using Module['printErr']
        // so we register a second tty just for it.
        TTY.register(FS.makedev(5, 0), TTY.default_tty_ops);
        TTY.register(FS.makedev(6, 0), TTY.default_tty1_ops);
        FS.mkdev('/dev/tty', 0666, FS.makedev(5, 0));
        FS.mkdev('/dev/tty1', 0666, FS.makedev(6, 0));
        // we're not going to emulate the actual shm device,
        // just create the tmp dirs that reside in it commonly
        FS.mkdir('/dev/shm', 0777);
        FS.mkdir('/dev/shm/tmp', 0777);
      },createStandardStreams:function () {
        // TODO deprecate the old functionality of a single
        // input / output callback and that utilizes FS.createDevice
        // and instead require a unique set of stream ops
        // by default, we symlink the standard streams to the
        // default tty devices. however, if the standard streams
        // have been overwritten we create a unique device for
        // them instead.
        if (Module['stdin']) {
          FS.createDevice('/dev', 'stdin', Module['stdin']);
        } else {
          FS.symlink('/dev/tty', '/dev/stdin');
        }
        if (Module['stdout']) {
          FS.createDevice('/dev', 'stdout', null, Module['stdout']);
        } else {
          FS.symlink('/dev/tty', '/dev/stdout');
        }
        if (Module['stderr']) {
          FS.createDevice('/dev', 'stderr', null, Module['stderr']);
        } else {
          FS.symlink('/dev/tty1', '/dev/stderr');
        }
        // open default streams for the stdin, stdout and stderr devices
        var stdin = FS.open('/dev/stdin', 'r');
        HEAP32[((_stdin)>>2)]=stdin.fd;
        assert(stdin.fd === 1, 'invalid handle for stdin (' + stdin.fd + ')');
        var stdout = FS.open('/dev/stdout', 'w');
        HEAP32[((_stdout)>>2)]=stdout.fd;
        assert(stdout.fd === 2, 'invalid handle for stdout (' + stdout.fd + ')');
        var stderr = FS.open('/dev/stderr', 'w');
        HEAP32[((_stderr)>>2)]=stderr.fd;
        assert(stderr.fd === 3, 'invalid handle for stderr (' + stderr.fd + ')');
      },staticInit:function () {
        FS.name_table = new Array(4096);
        FS.root = FS.createNode(null, '/', 0040000 | 0777, 0);
        FS.mount(MEMFS, {}, '/');
        FS.createDefaultDirectories();
        FS.createDefaultDevices();
      },init:function (input, output, error) {
        assert(!FS.init.initialized, 'FS.init was previously called. If you want to initialize later with custom parameters, remove any earlier calls (note that one is automatically added to the generated code)');
        FS.init.initialized = true;
        // Allow Module.stdin etc. to provide defaults, if none explicitly passed to us here
        Module['stdin'] = input || Module['stdin'];
        Module['stdout'] = output || Module['stdout'];
        Module['stderr'] = error || Module['stderr'];
        FS.createStandardStreams();
      },quit:function () {
        FS.init.initialized = false;
        for (var i = 0; i < FS.streams.length; i++) {
          var stream = FS.streams[i];
          if (!stream) {
            continue;
          }
          FS.close(stream);
        }
      },mount:function (type, opts, mountpoint) {
        var mount = {
          type: type,
          opts: opts,
          mountpoint: mountpoint,
          root: null
        };
        var lookup;
        if (mountpoint) {
          lookup = FS.lookupPath(mountpoint, { follow: false });
        }
        // create a root node for the fs
        var root = type.mount(mount);
        root.mount = mount;
        mount.root = root;
        // assign the mount info to the mountpoint's node
        if (lookup) {
          lookup.node.mount = mount;
          lookup.node.mounted = true;
          // compatibility update FS.root if we mount to /
          if (mountpoint === '/') {
            FS.root = mount.root;
          }
        }
        return root;
      },lookup:function (parent, name) {
        return parent.node_ops.lookup(parent, name);
      },mknod:function (path, mode, dev) {
        var lookup = FS.lookupPath(path, { parent: true });
        var parent = lookup.node;
        var name = PATH.basename(path);
        var err = FS.mayCreate(parent, name);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        if (!parent.node_ops.mknod) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        return parent.node_ops.mknod(parent, name, mode, dev);
      },create:function (path, mode) {
        mode &= 4095;
        mode |= 0100000;
        return FS.mknod(path, mode, 0);
      },mkdir:function (path, mode) {
        mode &= 511 | 0001000;
        mode |= 0040000;
        return FS.mknod(path, mode, 0);
      },mkdev:function (path, mode, dev) {
        mode |= 0020000;
        return FS.mknod(path, mode, dev);
      },symlink:function (oldpath, newpath) {
        var lookup = FS.lookupPath(newpath, { parent: true });
        var parent = lookup.node;
        var newname = PATH.basename(newpath);
        var err = FS.mayCreate(parent, newname);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        if (!parent.node_ops.symlink) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        return parent.node_ops.symlink(parent, newname, oldpath);
      },rename:function (old_path, new_path) {
        var old_dirname = PATH.dirname(old_path);
        var new_dirname = PATH.dirname(new_path);
        var old_name = PATH.basename(old_path);
        var new_name = PATH.basename(new_path);
        // parents must exist
        var lookup, old_dir, new_dir;
        try {
          lookup = FS.lookupPath(old_path, { parent: true });
          old_dir = lookup.node;
          lookup = FS.lookupPath(new_path, { parent: true });
          new_dir = lookup.node;
        } catch (e) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        }
        // need to be part of the same mount
        if (old_dir.mount !== new_dir.mount) {
          throw new FS.ErrnoError(ERRNO_CODES.EXDEV);
        }
        // source must exist
        var old_node = FS.lookupNode(old_dir, old_name);
        // old path should not be an ancestor of the new path
        var relative = PATH.relative(old_path, new_dirname);
        if (relative.charAt(0) !== '.') {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        // new path should not be an ancestor of the old path
        relative = PATH.relative(new_path, old_dirname);
        if (relative.charAt(0) !== '.') {
          throw new FS.ErrnoError(ERRNO_CODES.ENOTEMPTY);
        }
        // see if the new path already exists
        var new_node;
        try {
          new_node = FS.lookupNode(new_dir, new_name);
        } catch (e) {
          // not fatal
        }
        // early out if nothing needs to change
        if (old_node === new_node) {
          return;
        }
        // we'll need to delete the old entry
        var isdir = FS.isDir(old_node.mode);
        var err = FS.mayDelete(old_dir, old_name, isdir);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        // need delete permissions if we'll be overwriting.
        // need create permissions if new doesn't already exist.
        err = new_node ?
          FS.mayDelete(new_dir, new_name, isdir) :
          FS.mayCreate(new_dir, new_name);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        if (!old_dir.node_ops.rename) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (FS.isMountpoint(old_node) || (new_node && FS.isMountpoint(new_node))) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        }
        // if we are going to change the parent, check write permissions
        if (new_dir !== old_dir) {
          err = FS.nodePermissions(old_dir, 'w');
          if (err) {
            throw new FS.ErrnoError(err);
          }
        }
        // remove the node from the lookup hash
        FS.hashRemoveNode(old_node);
        // do the underlying fs rename
        try {
          old_dir.node_ops.rename(old_node, new_dir, new_name);
        } catch (e) {
          throw e;
        } finally {
          // add the node back to the hash (in case node_ops.rename
          // changed its name)
          FS.hashAddNode(old_node);
        }
      },rmdir:function (path) {
        var lookup = FS.lookupPath(path, { parent: true });
        var parent = lookup.node;
        var name = PATH.basename(path);
        var node = FS.lookupNode(parent, name);
        var err = FS.mayDelete(parent, name, true);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        if (!parent.node_ops.rmdir) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (FS.isMountpoint(node)) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        }
        parent.node_ops.rmdir(parent, name);
        FS.destroyNode(node);
      },readdir:function (path) {
        var lookup = FS.lookupPath(path, { follow: true });
        var node = lookup.node;
        if (!node.node_ops.readdir) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOTDIR);
        }
        return node.node_ops.readdir(node);
      },unlink:function (path) {
        var lookup = FS.lookupPath(path, { parent: true });
        var parent = lookup.node;
        var name = PATH.basename(path);
        var node = FS.lookupNode(parent, name);
        var err = FS.mayDelete(parent, name, false);
        if (err) {
          // POSIX says unlink should set EPERM, not EISDIR
          if (err === ERRNO_CODES.EISDIR) err = ERRNO_CODES.EPERM;
          throw new FS.ErrnoError(err);
        }
        if (!parent.node_ops.unlink) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (FS.isMountpoint(node)) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        }
        parent.node_ops.unlink(parent, name);
        FS.destroyNode(node);
      },readlink:function (path) {
        var lookup = FS.lookupPath(path, { follow: false });
        var link = lookup.node;
        if (!link.node_ops.readlink) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        return link.node_ops.readlink(link);
      },stat:function (path, dontFollow) {
        var lookup = FS.lookupPath(path, { follow: !dontFollow });
        var node = lookup.node;
        if (!node.node_ops.getattr) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        return node.node_ops.getattr(node);
      },lstat:function (path) {
        return FS.stat(path, true);
      },chmod:function (path, mode, dontFollow) {
        var node;
        if (typeof path === 'string') {
          var lookup = FS.lookupPath(path, { follow: !dontFollow });
          node = lookup.node;
        } else {
          node = path;
        }
        if (!node.node_ops.setattr) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        node.node_ops.setattr(node, {
          mode: (mode & 4095) | (node.mode & ~4095),
          timestamp: Date.now()
        });
      },lchmod:function (path, mode) {
        FS.chmod(path, mode, true);
      },fchmod:function (fd, mode) {
        var stream = FS.getStream(fd);
        if (!stream) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        FS.chmod(stream.node, mode);
      },chown:function (path, uid, gid, dontFollow) {
        var node;
        if (typeof path === 'string') {
          var lookup = FS.lookupPath(path, { follow: !dontFollow });
          node = lookup.node;
        } else {
          node = path;
        }
        if (!node.node_ops.setattr) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        node.node_ops.setattr(node, {
          timestamp: Date.now()
          // we ignore the uid / gid for now
        });
      },lchown:function (path, uid, gid) {
        FS.chown(path, uid, gid, true);
      },fchown:function (fd, uid, gid) {
        var stream = FS.getStream(fd);
        if (!stream) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        FS.chown(stream.node, uid, gid);
      },truncate:function (path, len) {
        if (len < 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var node;
        if (typeof path === 'string') {
          var lookup = FS.lookupPath(path, { follow: true });
          node = lookup.node;
        } else {
          node = path;
        }
        if (!node.node_ops.setattr) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (FS.isDir(node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EISDIR);
        }
        if (!FS.isFile(node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var err = FS.nodePermissions(node, 'w');
        if (err) {
          throw new FS.ErrnoError(err);
        }
        node.node_ops.setattr(node, {
          size: len,
          timestamp: Date.now()
        });
      },ftruncate:function (fd, len) {
        var stream = FS.getStream(fd);
        if (!stream) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        if ((stream.flags & 3) === 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        FS.truncate(stream.node, len);
      },utime:function (path, atime, mtime) {
        var lookup = FS.lookupPath(path, { follow: true });
        var node = lookup.node;
        node.node_ops.setattr(node, {
          timestamp: Math.max(atime, mtime)
        });
      },open:function (path, flags, mode, fd_start, fd_end) {
        path = PATH.normalize(path);
        flags = typeof flags === 'string' ? FS.modeStringToFlags(flags) : flags;
        mode = typeof mode === 'undefined' ? 0666 : mode;
        if ((flags & 512)) {
          mode = (mode & 4095) | 0100000;
        } else {
          mode = 0;
        }
        var node;
        try {
          var lookup = FS.lookupPath(path, {
            follow: !(flags & 0200000)
          });
          node = lookup.node;
          path = lookup.path;
        } catch (e) {
          // ignore
        }
        // perhaps we need to create the node
        if ((flags & 512)) {
          if (node) {
            // if O_CREAT and O_EXCL are set, error out if the node already exists
            if ((flags & 2048)) {
              throw new FS.ErrnoError(ERRNO_CODES.EEXIST);
            }
          } else {
            // node doesn't exist, try to create it
            node = FS.mknod(path, mode, 0);
          }
        }
        if (!node) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
        }
        // can't truncate a device
        if (FS.isChrdev(node.mode)) {
          flags &= ~1024;
        }
        // check permissions
        var err = FS.mayOpen(node, flags);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        // do truncation if necessary
        if ((flags & 1024)) {
          FS.truncate(node, 0);
        }
        // register the stream with the filesystem
        var stream = FS.createStream({
          path: path,
          node: node,
          flags: flags,
          seekable: true,
          position: 0,
          stream_ops: node.stream_ops,
          // used by the file family libc calls (fopen, fwrite, ferror, etc.)
          ungotten: [],
          error: false
        }, fd_start, fd_end);
        // call the new stream's open function
        if (stream.stream_ops.open) {
          stream.stream_ops.open(stream);
        }
        return stream;
      },close:function (stream) {
        try {
          if (stream.stream_ops.close) {
            stream.stream_ops.close(stream);
          }
        } catch (e) {
          throw e;
        } finally {
          FS.closeStream(stream.fd);
        }
      },llseek:function (stream, offset, whence) {
        if (!stream.seekable || !stream.stream_ops.llseek) {
          throw new FS.ErrnoError(ERRNO_CODES.ESPIPE);
        }
        return stream.stream_ops.llseek(stream, offset, whence);
      },read:function (stream, buffer, offset, length, position) {
        if (length < 0 || position < 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        if ((stream.flags & 3) === 1) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        if (FS.isDir(stream.node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EISDIR);
        }
        if (!stream.stream_ops.read) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var seeking = true;
        if (typeof position === 'undefined') {
          position = stream.position;
          seeking = false;
        } else if (!stream.seekable) {
          throw new FS.ErrnoError(ERRNO_CODES.ESPIPE);
        }
        var bytesRead = stream.stream_ops.read(stream, buffer, offset, length, position);
        if (!seeking) stream.position += bytesRead;
        return bytesRead;
      },write:function (stream, buffer, offset, length, position, canOwn) {
        if (length < 0 || position < 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        if ((stream.flags & 3) === 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        if (FS.isDir(stream.node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EISDIR);
        }
        if (!stream.stream_ops.write) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var seeking = true;
        if (typeof position === 'undefined') {
          position = stream.position;
          seeking = false;
        } else if (!stream.seekable) {
          throw new FS.ErrnoError(ERRNO_CODES.ESPIPE);
        }
        if (stream.flags & 8) {
          // seek to the end before writing in append mode
          FS.llseek(stream, 0, 2);
        }
        var bytesWritten = stream.stream_ops.write(stream, buffer, offset, length, position, canOwn);
        if (!seeking) stream.position += bytesWritten;
        return bytesWritten;
      },allocate:function (stream, offset, length) {
        if (offset < 0 || length <= 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        if ((stream.flags & 3) === 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        if (!FS.isFile(stream.node.mode) && !FS.isDir(node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.ENODEV);
        }
        if (!stream.stream_ops.allocate) {
          throw new FS.ErrnoError(ERRNO_CODES.EOPNOTSUPP);
        }
        stream.stream_ops.allocate(stream, offset, length);
      },mmap:function (stream, buffer, offset, length, position, prot, flags) {
        // TODO if PROT is PROT_WRITE, make sure we have write access
        if ((stream.flags & 3) === 1) {
          throw new FS.ErrnoError(ERRNO_CODES.EACCES);
        }
        if (!stream.stream_ops.mmap) {
          throw new FS.errnoError(ERRNO_CODES.ENODEV);
        }
        return stream.stream_ops.mmap(stream, buffer, offset, length, position, prot, flags);
      },ioctl:function (stream, cmd, arg) {
        if (!stream.stream_ops.ioctl) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOTTY);
        }
        return stream.stream_ops.ioctl(stream, cmd, arg);
      }};function _fflush(stream) {
      // int fflush(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fflush.html
      // we don't currently perform any user-space buffering of data
    }
  function __exit(status) {
      // void _exit(int status);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/exit.html
      Module.print('exit(' + status + ') called');
      Module['exit'](status);
    }function _exit(status) {
      __exit(status);
    }
  var SOCKFS={mount:function (mount) {
        return FS.createNode(null, '/', 0040000 | 0777, 0);
      },nextname:function () {
        if (!SOCKFS.nextname.current) {
          SOCKFS.nextname.current = 0;
        }
        return 'socket[' + (SOCKFS.nextname.current++) + ']';
      },createSocket:function (family, type, protocol) {
        var streaming = type == 1;
        if (protocol) {
          assert(streaming == (protocol == 6)); // if SOCK_STREAM, must be tcp
        }
        // create our internal socket structure
        var sock = {
          family: family,
          type: type,
          protocol: protocol,
          server: null,
          peers: {},
          pending: [],
          recv_queue: [],
          sock_ops: SOCKFS.websocket_sock_ops
        };
        // create the filesystem node to store the socket structure
        var name = SOCKFS.nextname();
        var node = FS.createNode(SOCKFS.root, name, 0140000, 0);
        node.sock = sock;
        // and the wrapping stream that enables library functions such
        // as read and write to indirectly interact with the socket
        var stream = FS.createStream({
          path: name,
          node: node,
          flags: FS.modeStringToFlags('r+'),
          seekable: false,
          stream_ops: SOCKFS.stream_ops
        });
        // map the new stream to the socket structure (sockets have a 1:1
        // relationship with a stream)
        sock.stream = stream;
        return sock;
      },getSocket:function (fd) {
        var stream = FS.getStream(fd);
        if (!stream || !FS.isSocket(stream.node.mode)) {
          return null;
        }
        return stream.node.sock;
      },stream_ops:{poll:function (stream) {
          var sock = stream.node.sock;
          return sock.sock_ops.poll(sock);
        },ioctl:function (stream, request, varargs) {
          var sock = stream.node.sock;
          return sock.sock_ops.ioctl(sock, request, varargs);
        },read:function (stream, buffer, offset, length, position /* ignored */) {
          var sock = stream.node.sock;
          var msg = sock.sock_ops.recvmsg(sock, length);
          if (!msg) {
            // socket is closed
            return 0;
          }
          buffer.set(msg.buffer, offset);
          return msg.buffer.length;
        },write:function (stream, buffer, offset, length, position /* ignored */) {
          var sock = stream.node.sock;
          return sock.sock_ops.sendmsg(sock, buffer, offset, length);
        },close:function (stream) {
          var sock = stream.node.sock;
          sock.sock_ops.close(sock);
        }},websocket_sock_ops:{createPeer:function (sock, addr, port) {
          var ws;
          if (typeof addr === 'object') {
            ws = addr;
            addr = null;
            port = null;
          }
          if (ws) {
            // for sockets that've already connected (e.g. we're the server)
            // we can inspect the _socket property for the address
            if (ws._socket) {
              addr = ws._socket.remoteAddress;
              port = ws._socket.remotePort;
            }
            // if we're just now initializing a connection to the remote,
            // inspect the url property
            else {
              var result = /ws[s]?:\/\/([^:]+):(\d+)/.exec(ws.url);
              if (!result) {
                throw new Error('WebSocket URL must be in the format ws(s)://address:port');
              }
              addr = result[1];
              port = parseInt(result[2], 10);
            }
          } else {
            // create the actual websocket object and connect
            try {
              var url = 'ws://' + addr + ':' + port;
              // the node ws library API is slightly different than the browser's
              var opts = ENVIRONMENT_IS_NODE ? {} : ['binary'];
              ws = new WebSocket(url, opts);
              ws.binaryType = 'arraybuffer';
            } catch (e) {
              throw new FS.ErrnoError(ERRNO_CODES.EHOSTUNREACH);
            }
          }
          var peer = {
            addr: addr,
            port: port,
            socket: ws,
            dgram_send_queue: []
          };
          SOCKFS.websocket_sock_ops.addPeer(sock, peer);
          SOCKFS.websocket_sock_ops.handlePeerEvents(sock, peer);
          // if this is a bound dgram socket, send the port number first to allow
          // us to override the ephemeral port reported to us by remotePort on the
          // remote end.
          if (sock.type === 2 && typeof sock.sport !== 'undefined') {
            peer.dgram_send_queue.push(new Uint8Array([
                255, 255, 255, 255,
                'p'.charCodeAt(0), 'o'.charCodeAt(0), 'r'.charCodeAt(0), 't'.charCodeAt(0),
                ((sock.sport & 0xff00) >> 8) , (sock.sport & 0xff)
            ]));
          }
          return peer;
        },getPeer:function (sock, addr, port) {
          return sock.peers[addr + ':' + port];
        },addPeer:function (sock, peer) {
          sock.peers[peer.addr + ':' + peer.port] = peer;
        },removePeer:function (sock, peer) {
          delete sock.peers[peer.addr + ':' + peer.port];
        },handlePeerEvents:function (sock, peer) {
          var first = true;
          var handleOpen = function () {
            try {
              var queued = peer.dgram_send_queue.shift();
              while (queued) {
                peer.socket.send(queued);
                queued = peer.dgram_send_queue.shift();
              }
            } catch (e) {
              // not much we can do here in the way of proper error handling as we've already
              // lied and said this data was sent. shut it down.
              peer.socket.close();
            }
          };
          var handleMessage = function(data) {
            assert(typeof data !== 'string' && data.byteLength !== undefined);  // must receive an ArrayBuffer
            data = new Uint8Array(data);  // make a typed array view on the array buffer
            // if this is the port message, override the peer's port with it
            var wasfirst = first;
            first = false;
            if (wasfirst &&
                data.length === 10 &&
                data[0] === 255 && data[1] === 255 && data[2] === 255 && data[3] === 255 &&
                data[4] === 'p'.charCodeAt(0) && data[5] === 'o'.charCodeAt(0) && data[6] === 'r'.charCodeAt(0) && data[7] === 't'.charCodeAt(0)) {
              // update the peer's port and it's key in the peer map
              var newport = ((data[8] << 8) | data[9]);
              SOCKFS.websocket_sock_ops.removePeer(sock, peer);
              peer.port = newport;
              SOCKFS.websocket_sock_ops.addPeer(sock, peer);
              return;
            }
            sock.recv_queue.push({ addr: peer.addr, port: peer.port, data: data });
          };
          if (ENVIRONMENT_IS_NODE) {
            peer.socket.on('open', handleOpen);
            peer.socket.on('message', function(data, flags) {
              if (!flags.binary) {
                return;
              }
              handleMessage((new Uint8Array(data)).buffer);  // copy from node Buffer -> ArrayBuffer
            });
            peer.socket.on('error', function() {
              // don't throw
            });
          } else {
            peer.socket.onopen = handleOpen;
            peer.socket.onmessage = function(event) {
              handleMessage(event.data);
            };
          }
        },poll:function (sock) {
          if (sock.type === 1 && sock.server) {
            // listen sockets should only say they're available for reading
            // if there are pending clients.
            return sock.pending.length ? (0 /* XXX missing C define POLLRDNORM */ | 1) : 0;
          }
          var mask = 0;
          var dest = sock.type === 1 ?  // we only care about the socket state for connection-based sockets
            SOCKFS.websocket_sock_ops.getPeer(sock, sock.daddr, sock.dport) :
            null;
          if (sock.recv_queue.length ||
              !dest ||  // connection-less sockets are always ready to read
              (dest && dest.socket.readyState === dest.socket.CLOSING) ||
              (dest && dest.socket.readyState === dest.socket.CLOSED)) {  // let recv return 0 once closed
            mask |= (0 /* XXX missing C define POLLRDNORM */ | 1);
          }
          if (!dest ||  // connection-less sockets are always ready to write
              (dest && dest.socket.readyState === dest.socket.OPEN)) {
            mask |= 2;
          }
          if ((dest && dest.socket.readyState === dest.socket.CLOSING) ||
              (dest && dest.socket.readyState === dest.socket.CLOSED)) {
            mask |= 16;
          }
          return mask;
        },ioctl:function (sock, request, arg) {
          switch (request) {
            case 1:
              var bytes = 0;
              if (sock.recv_queue.length) {
                bytes = sock.recv_queue[0].data.length;
              }
              HEAP32[((arg)>>2)]=bytes;
              return 0;
            default:
              return ERRNO_CODES.EINVAL;
          }
        },close:function (sock) {
          // if we've spawned a listen server, close it
          if (sock.server) {
            try {
              sock.server.close();
            } catch (e) {
            }
            sock.server = null;
          }
          // close any peer connections
          var peers = Object.keys(sock.peers);
          for (var i = 0; i < peers.length; i++) {
            var peer = sock.peers[peers[i]];
            try {
              peer.socket.close();
            } catch (e) {
            }
            SOCKFS.websocket_sock_ops.removePeer(sock, peer);
          }
          return 0;
        },bind:function (sock, addr, port) {
          if (typeof sock.saddr !== 'undefined' || typeof sock.sport !== 'undefined') {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);  // already bound
          }
          sock.saddr = addr;
          sock.sport = port || _mkport();
          // in order to emulate dgram sockets, we need to launch a listen server when
          // binding on a connection-less socket
          // note: this is only required on the server side
          if (sock.type === 2) {
            // close the existing server if it exists
            if (sock.server) {
              sock.server.close();
              sock.server = null;
            }
            // swallow error operation not supported error that occurs when binding in the
            // browser where this isn't supported
            try {
              sock.sock_ops.listen(sock, 0);
            } catch (e) {
              if (!(e instanceof FS.ErrnoError)) throw e;
              if (e.errno !== ERRNO_CODES.EOPNOTSUPP) throw e;
            }
          }
        },connect:function (sock, addr, port) {
          if (sock.server) {
            throw new FS.ErrnoError(ERRNO_CODS.EOPNOTSUPP);
          }
          // TODO autobind
          // if (!sock.addr && sock.type == 2) {
          // }
          // early out if we're already connected / in the middle of connecting
          if (typeof sock.daddr !== 'undefined' && typeof sock.dport !== 'undefined') {
            var dest = SOCKFS.websocket_sock_ops.getPeer(sock, sock.daddr, sock.dport);
            if (dest) {
              if (dest.socket.readyState === dest.socket.CONNECTING) {
                throw new FS.ErrnoError(ERRNO_CODES.EALREADY);
              } else {
                throw new FS.ErrnoError(ERRNO_CODES.EISCONN);
              }
            }
          }
          // add the socket to our peer list and set our
          // destination address / port to match
          var peer = SOCKFS.websocket_sock_ops.createPeer(sock, addr, port);
          sock.daddr = peer.addr;
          sock.dport = peer.port;
          // always "fail" in non-blocking mode
          throw new FS.ErrnoError(ERRNO_CODES.EINPROGRESS);
        },listen:function (sock, backlog) {
          if (!ENVIRONMENT_IS_NODE) {
            throw new FS.ErrnoError(ERRNO_CODES.EOPNOTSUPP);
          }
          if (sock.server) {
             throw new FS.ErrnoError(ERRNO_CODES.EINVAL);  // already listening
          }
          var WebSocketServer = require('ws').Server;
          var host = sock.saddr;
          sock.server = new WebSocketServer({
            host: host,
            port: sock.sport
            // TODO support backlog
          });
          sock.server.on('connection', function(ws) {
            if (sock.type === 1) {
              var newsock = SOCKFS.createSocket(sock.family, sock.type, sock.protocol);
              // create a peer on the new socket
              var peer = SOCKFS.websocket_sock_ops.createPeer(newsock, ws);
              newsock.daddr = peer.addr;
              newsock.dport = peer.port;
              // push to queue for accept to pick up
              sock.pending.push(newsock);
            } else {
              // create a peer on the listen socket so calling sendto
              // with the listen socket and an address will resolve
              // to the correct client
              SOCKFS.websocket_sock_ops.createPeer(sock, ws);
            }
          });
          sock.server.on('closed', function() {
            sock.server = null;
          });
          sock.server.on('error', function() {
            // don't throw
          });
        },accept:function (listensock) {
          if (!listensock.server) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
          var newsock = listensock.pending.shift();
          newsock.stream.flags = listensock.stream.flags;
          return newsock;
        },getname:function (sock, peer) {
          var addr, port;
          if (peer) {
            if (sock.daddr === undefined || sock.dport === undefined) {
              throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN);
            }
            addr = sock.daddr;
            port = sock.dport;
          } else {
            // TODO saddr and sport will be set for bind()'d UDP sockets, but what
            // should we be returning for TCP sockets that've been connect()'d?
            addr = sock.saddr || 0;
            port = sock.sport || 0;
          }
          return { addr: addr, port: port };
        },sendmsg:function (sock, buffer, offset, length, addr, port) {
          if (sock.type === 2) {
            // connection-less sockets will honor the message address,
            // and otherwise fall back to the bound destination address
            if (addr === undefined || port === undefined) {
              addr = sock.daddr;
              port = sock.dport;
            }
            // if there was no address to fall back to, error out
            if (addr === undefined || port === undefined) {
              throw new FS.ErrnoError(ERRNO_CODES.EDESTADDRREQ);
            }
          } else {
            // connection-based sockets will only use the bound
            addr = sock.daddr;
            port = sock.dport;
          }
          // find the peer for the destination address
          var dest = SOCKFS.websocket_sock_ops.getPeer(sock, addr, port);
          // early out if not connected with a connection-based socket
          if (sock.type === 1) {
            if (!dest || dest.socket.readyState === dest.socket.CLOSING || dest.socket.readyState === dest.socket.CLOSED) {
              throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN);
            } else if (dest.socket.readyState === dest.socket.CONNECTING) {
              throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
            }
          }
          // create a copy of the incoming data to send, as the WebSocket API
          // doesn't work entirely with an ArrayBufferView, it'll just send
          // the entire underlying buffer
          var data;
          if (buffer instanceof Array || buffer instanceof ArrayBuffer) {
            data = buffer.slice(offset, offset + length);
          } else {  // ArrayBufferView
            data = buffer.buffer.slice(buffer.byteOffset + offset, buffer.byteOffset + offset + length);
          }
          // if we're emulating a connection-less dgram socket and don't have
          // a cached connection, queue the buffer to send upon connect and
          // lie, saying the data was sent now.
          if (sock.type === 2) {
            if (!dest || dest.socket.readyState !== dest.socket.OPEN) {
              // if we're not connected, open a new connection
              if (!dest || dest.socket.readyState === dest.socket.CLOSING || dest.socket.readyState === dest.socket.CLOSED) {
                dest = SOCKFS.websocket_sock_ops.createPeer(sock, addr, port);
              }
              dest.dgram_send_queue.push(data);
              return length;
            }
          }
          try {
            // send the actual data
            dest.socket.send(data);
            return length;
          } catch (e) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
        },recvmsg:function (sock, length) {
          // http://pubs.opengroup.org/onlinepubs/7908799/xns/recvmsg.html
          if (sock.type === 1 && sock.server) {
            // tcp servers should not be recv()'ing on the listen socket
            throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN);
          }
          var queued = sock.recv_queue.shift();
          if (!queued) {
            if (sock.type === 1) {
              var dest = SOCKFS.websocket_sock_ops.getPeer(sock, sock.daddr, sock.dport);
              if (!dest) {
                // if we have a destination address but are not connected, error out
                throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN);
              }
              else if (dest.socket.readyState === dest.socket.CLOSING || dest.socket.readyState === dest.socket.CLOSED) {
                // return null if the socket has closed
                return null;
              }
              else {
                // else, our socket is in a valid state but truly has nothing available
                throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
              }
            } else {
              throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
            }
          }
          // queued.data will be an ArrayBuffer if it's unadulterated, but if it's
          // requeued TCP data it'll be an ArrayBufferView
          var queuedLength = queued.data.byteLength || queued.data.length;
          var queuedOffset = queued.data.byteOffset || 0;
          var queuedBuffer = queued.data.buffer || queued.data;
          var bytesRead = Math.min(length, queuedLength);
          var res = {
            buffer: new Uint8Array(queuedBuffer, queuedOffset, bytesRead),
            addr: queued.addr,
            port: queued.port
          };
          // push back any unread data for TCP connections
          if (sock.type === 1 && bytesRead < queuedLength) {
            var bytesRemaining = queuedLength - bytesRead;
            queued.data = new Uint8Array(queuedBuffer, queuedOffset + bytesRead, bytesRemaining);
            sock.recv_queue.unshift(queued);
          }
          return res;
        }}};function _send(fd, buf, len, flags) {
      var sock = SOCKFS.getSocket(fd);
      if (!sock) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      // TODO honor flags
      return _write(fd, buf, len);
    }
  function _pwrite(fildes, buf, nbyte, offset) {
      // ssize_t pwrite(int fildes, const void *buf, size_t nbyte, off_t offset);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/write.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      try {
        var slab = HEAP8;
        return FS.write(stream, slab, buf, nbyte, offset);
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _write(fildes, buf, nbyte) {
      // ssize_t write(int fildes, const void *buf, size_t nbyte);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/write.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      try {
        var slab = HEAP8;
        return FS.write(stream, slab, buf, nbyte);
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _fwrite(ptr, size, nitems, stream) {
      // size_t fwrite(const void *restrict ptr, size_t size, size_t nitems, FILE *restrict stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fwrite.html
      var bytesToWrite = nitems * size;
      if (bytesToWrite == 0) return 0;
      var bytesWritten = _write(stream, ptr, bytesToWrite);
      if (bytesWritten == -1) {
        var streamObj = FS.getStream(stream);
        if (streamObj) streamObj.error = true;
        return 0;
      } else {
        return Math.floor(bytesWritten / size);
      }
    }
  Module["_strlen"] = _strlen;
  function __reallyNegative(x) {
      return x < 0 || (x === 0 && (1/x) === -Infinity);
    }function __formatString(format, varargs) {
      var textIndex = format;
      var argIndex = 0;
      function getNextArg(type) {
        // NOTE: Explicitly ignoring type safety. Otherwise this fails:
        //       int x = 4; printf("%c\n", (char)x);
        var ret;
        if (type === 'double') {
          ret = HEAPF64[(((varargs)+(argIndex))>>3)];
        } else if (type == 'i64') {
          ret = [HEAP32[(((varargs)+(argIndex))>>2)],
                 HEAP32[(((varargs)+(argIndex+8))>>2)]];
          argIndex += 8; // each 32-bit chunk is in a 64-bit block
        } else {
          type = 'i32'; // varargs are always i32, i64, or double
          ret = HEAP32[(((varargs)+(argIndex))>>2)];
        }
        argIndex += Math.max(Runtime.getNativeFieldSize(type), Runtime.getAlignSize(type, null, true));
        return ret;
      }
      var ret = [];
      var curr, next, currArg;
      while(1) {
        var startTextIndex = textIndex;
        curr = HEAP8[(textIndex)];
        if (curr === 0) break;
        next = HEAP8[((textIndex+1)|0)];
        if (curr == 37) {
          // Handle flags.
          var flagAlwaysSigned = false;
          var flagLeftAlign = false;
          var flagAlternative = false;
          var flagZeroPad = false;
          flagsLoop: while (1) {
            switch (next) {
              case 43:
                flagAlwaysSigned = true;
                break;
              case 45:
                flagLeftAlign = true;
                break;
              case 35:
                flagAlternative = true;
                break;
              case 48:
                if (flagZeroPad) {
                  break flagsLoop;
                } else {
                  flagZeroPad = true;
                  break;
                }
              default:
                break flagsLoop;
            }
            textIndex++;
            next = HEAP8[((textIndex+1)|0)];
          }
          // Handle width.
          var width = 0;
          if (next == 42) {
            width = getNextArg('i32');
            textIndex++;
            next = HEAP8[((textIndex+1)|0)];
          } else {
            while (next >= 48 && next <= 57) {
              width = width * 10 + (next - 48);
              textIndex++;
              next = HEAP8[((textIndex+1)|0)];
            }
          }
          // Handle precision.
          var precisionSet = false;
          if (next == 46) {
            var precision = 0;
            precisionSet = true;
            textIndex++;
            next = HEAP8[((textIndex+1)|0)];
            if (next == 42) {
              precision = getNextArg('i32');
              textIndex++;
            } else {
              while(1) {
                var precisionChr = HEAP8[((textIndex+1)|0)];
                if (precisionChr < 48 ||
                    precisionChr > 57) break;
                precision = precision * 10 + (precisionChr - 48);
                textIndex++;
              }
            }
            next = HEAP8[((textIndex+1)|0)];
          } else {
            var precision = 6; // Standard default.
          }
          // Handle integer sizes. WARNING: These assume a 32-bit architecture!
          var argSize;
          switch (String.fromCharCode(next)) {
            case 'h':
              var nextNext = HEAP8[((textIndex+2)|0)];
              if (nextNext == 104) {
                textIndex++;
                argSize = 1; // char (actually i32 in varargs)
              } else {
                argSize = 2; // short (actually i32 in varargs)
              }
              break;
            case 'l':
              var nextNext = HEAP8[((textIndex+2)|0)];
              if (nextNext == 108) {
                textIndex++;
                argSize = 8; // long long
              } else {
                argSize = 4; // long
              }
              break;
            case 'L': // long long
            case 'q': // int64_t
            case 'j': // intmax_t
              argSize = 8;
              break;
            case 'z': // size_t
            case 't': // ptrdiff_t
            case 'I': // signed ptrdiff_t or unsigned size_t
              argSize = 4;
              break;
            default:
              argSize = null;
          }
          if (argSize) textIndex++;
          next = HEAP8[((textIndex+1)|0)];
          // Handle type specifier.
          switch (String.fromCharCode(next)) {
            case 'd': case 'i': case 'u': case 'o': case 'x': case 'X': case 'p': {
              // Integer.
              var signed = next == 100 || next == 105;
              argSize = argSize || 4;
              var currArg = getNextArg('i' + (argSize * 8));
              var origArg = currArg;
              var argText;
              // Flatten i64-1 [low, high] into a (slightly rounded) double
              if (argSize == 8) {
                currArg = Runtime.makeBigInt(currArg[0], currArg[1], next == 117);
              }
              // Truncate to requested size.
              if (argSize <= 4) {
                var limit = Math.pow(256, argSize) - 1;
                currArg = (signed ? reSign : unSign)(currArg & limit, argSize * 8);
              }
              // Format the number.
              var currAbsArg = Math.abs(currArg);
              var prefix = '';
              if (next == 100 || next == 105) {
                if (argSize == 8 && i64Math) argText = i64Math.stringify(origArg[0], origArg[1], null); else
                argText = reSign(currArg, 8 * argSize, 1).toString(10);
              } else if (next == 117) {
                if (argSize == 8 && i64Math) argText = i64Math.stringify(origArg[0], origArg[1], true); else
                argText = unSign(currArg, 8 * argSize, 1).toString(10);
                currArg = Math.abs(currArg);
              } else if (next == 111) {
                argText = (flagAlternative ? '0' : '') + currAbsArg.toString(8);
              } else if (next == 120 || next == 88) {
                prefix = (flagAlternative && currArg != 0) ? '0x' : '';
                if (argSize == 8 && i64Math) {
                  if (origArg[1]) {
                    argText = (origArg[1]>>>0).toString(16);
                    var lower = (origArg[0]>>>0).toString(16);
                    while (lower.length < 8) lower = '0' + lower;
                    argText += lower;
                  } else {
                    argText = (origArg[0]>>>0).toString(16);
                  }
                } else
                if (currArg < 0) {
                  // Represent negative numbers in hex as 2's complement.
                  currArg = -currArg;
                  argText = (currAbsArg - 1).toString(16);
                  var buffer = [];
                  for (var i = 0; i < argText.length; i++) {
                    buffer.push((0xF - parseInt(argText[i], 16)).toString(16));
                  }
                  argText = buffer.join('');
                  while (argText.length < argSize * 2) argText = 'f' + argText;
                } else {
                  argText = currAbsArg.toString(16);
                }
                if (next == 88) {
                  prefix = prefix.toUpperCase();
                  argText = argText.toUpperCase();
                }
              } else if (next == 112) {
                if (currAbsArg === 0) {
                  argText = '(nil)';
                } else {
                  prefix = '0x';
                  argText = currAbsArg.toString(16);
                }
              }
              if (precisionSet) {
                while (argText.length < precision) {
                  argText = '0' + argText;
                }
              }
              // Add sign if needed
              if (flagAlwaysSigned) {
                if (currArg < 0) {
                  prefix = '-' + prefix;
                } else {
                  prefix = '+' + prefix;
                }
              }
              // Add padding.
              while (prefix.length + argText.length < width) {
                if (flagLeftAlign) {
                  argText += ' ';
                } else {
                  if (flagZeroPad) {
                    argText = '0' + argText;
                  } else {
                    prefix = ' ' + prefix;
                  }
                }
              }
              // Insert the result into the buffer.
              argText = prefix + argText;
              argText.split('').forEach(function(chr) {
                ret.push(chr.charCodeAt(0));
              });
              break;
            }
            case 'f': case 'F': case 'e': case 'E': case 'g': case 'G': {
              // Float.
              var currArg = getNextArg('double');
              var argText;
              if (isNaN(currArg)) {
                argText = 'nan';
                flagZeroPad = false;
              } else if (!isFinite(currArg)) {
                argText = (currArg < 0 ? '-' : '') + 'inf';
                flagZeroPad = false;
              } else {
                var isGeneral = false;
                var effectivePrecision = Math.min(precision, 20);
                // Convert g/G to f/F or e/E, as per:
                // http://pubs.opengroup.org/onlinepubs/9699919799/functions/printf.html
                if (next == 103 || next == 71) {
                  isGeneral = true;
                  precision = precision || 1;
                  var exponent = parseInt(currArg.toExponential(effectivePrecision).split('e')[1], 10);
                  if (precision > exponent && exponent >= -4) {
                    next = ((next == 103) ? 'f' : 'F').charCodeAt(0);
                    precision -= exponent + 1;
                  } else {
                    next = ((next == 103) ? 'e' : 'E').charCodeAt(0);
                    precision--;
                  }
                  effectivePrecision = Math.min(precision, 20);
                }
                if (next == 101 || next == 69) {
                  argText = currArg.toExponential(effectivePrecision);
                  // Make sure the exponent has at least 2 digits.
                  if (/[eE][-+]\d$/.test(argText)) {
                    argText = argText.slice(0, -1) + '0' + argText.slice(-1);
                  }
                } else if (next == 102 || next == 70) {
                  argText = currArg.toFixed(effectivePrecision);
                  if (currArg === 0 && __reallyNegative(currArg)) {
                    argText = '-' + argText;
                  }
                }
                var parts = argText.split('e');
                if (isGeneral && !flagAlternative) {
                  // Discard trailing zeros and periods.
                  while (parts[0].length > 1 && parts[0].indexOf('.') != -1 &&
                         (parts[0].slice(-1) == '0' || parts[0].slice(-1) == '.')) {
                    parts[0] = parts[0].slice(0, -1);
                  }
                } else {
                  // Make sure we have a period in alternative mode.
                  if (flagAlternative && argText.indexOf('.') == -1) parts[0] += '.';
                  // Zero pad until required precision.
                  while (precision > effectivePrecision++) parts[0] += '0';
                }
                argText = parts[0] + (parts.length > 1 ? 'e' + parts[1] : '');
                // Capitalize 'E' if needed.
                if (next == 69) argText = argText.toUpperCase();
                // Add sign.
                if (flagAlwaysSigned && currArg >= 0) {
                  argText = '+' + argText;
                }
              }
              // Add padding.
              while (argText.length < width) {
                if (flagLeftAlign) {
                  argText += ' ';
                } else {
                  if (flagZeroPad && (argText[0] == '-' || argText[0] == '+')) {
                    argText = argText[0] + '0' + argText.slice(1);
                  } else {
                    argText = (flagZeroPad ? '0' : ' ') + argText;
                  }
                }
              }
              // Adjust case.
              if (next < 97) argText = argText.toUpperCase();
              // Insert the result into the buffer.
              argText.split('').forEach(function(chr) {
                ret.push(chr.charCodeAt(0));
              });
              break;
            }
            case 's': {
              // String.
              var arg = getNextArg('i8*');
              var argLength = arg ? _strlen(arg) : '(null)'.length;
              if (precisionSet) argLength = Math.min(argLength, precision);
              if (!flagLeftAlign) {
                while (argLength < width--) {
                  ret.push(32);
                }
              }
              if (arg) {
                for (var i = 0; i < argLength; i++) {
                  ret.push(HEAPU8[((arg++)|0)]);
                }
              } else {
                ret = ret.concat(intArrayFromString('(null)'.substr(0, argLength), true));
              }
              if (flagLeftAlign) {
                while (argLength < width--) {
                  ret.push(32);
                }
              }
              break;
            }
            case 'c': {
              // Character.
              if (flagLeftAlign) ret.push(getNextArg('i8'));
              while (--width > 0) {
                ret.push(32);
              }
              if (!flagLeftAlign) ret.push(getNextArg('i8'));
              break;
            }
            case 'n': {
              // Write the length written so far to the next parameter.
              var ptr = getNextArg('i32*');
              HEAP32[((ptr)>>2)]=ret.length
              break;
            }
            case '%': {
              // Literal percent sign.
              ret.push(curr);
              break;
            }
            default: {
              // Unknown specifiers remain untouched.
              for (var i = startTextIndex; i < textIndex + 2; i++) {
                ret.push(HEAP8[(i)]);
              }
            }
          }
          textIndex += 2;
          // TODO: Support a/A (hex float) and m (last error) specifiers.
          // TODO: Support %1${specifier} for arg selection.
        } else {
          ret.push(curr);
          textIndex += 1;
        }
      }
      return ret;
    }function _fprintf(stream, format, varargs) {
      // int fprintf(FILE *restrict stream, const char *restrict format, ...);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/printf.html
      var result = __formatString(format, varargs);
      var stack = Runtime.stackSave();
      var ret = _fwrite(allocate(result, 'i8', ALLOC_STACK), 1, result.length, stream);
      Runtime.stackRestore(stack);
      return ret;
    }
  function _snprintf(s, n, format, varargs) {
      // int snprintf(char *restrict s, size_t n, const char *restrict format, ...);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/printf.html
      var result = __formatString(format, varargs);
      var limit = (n === undefined) ? result.length
                                    : Math.min(result.length, Math.max(n - 1, 0));
      if (s < 0) {
        s = -s;
        var buf = _malloc(limit+1);
        HEAP32[((s)>>2)]=buf;
        s = buf;
      }
      for (var i = 0; i < limit; i++) {
        HEAP8[(((s)+(i))|0)]=result[i];
      }
      if (limit < n || (n === undefined)) HEAP8[(((s)+(i))|0)]=0;
      return result.length;
    }
  Module["_memset"] = _memset;var _llvm_memset_p0i8_i32=_memset;
  function _close(fildes) {
      // int close(int fildes);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/close.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      try {
        FS.close(stream);
        return 0;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }
  function _fsync(fildes) {
      // int fsync(int fildes);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fsync.html
      var stream = FS.getStream(fildes);
      if (stream) {
        // We write directly to the file system, so there's nothing to do here.
        return 0;
      } else {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
    }function _fclose(stream) {
      // int fclose(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fclose.html
      _fsync(stream);
      return _close(stream);
    }
  function _fputc(c, stream) {
      // int fputc(int c, FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fputc.html
      var chr = unSign(c & 0xFF);
      HEAP8[((_fputc.ret)|0)]=chr
      var ret = _write(stream, _fputc.ret, 1);
      if (ret == -1) {
        var streamObj = FS.getStream(stream);
        if (streamObj) streamObj.error = true;
        return -1;
      } else {
        return chr;
      }
    }function _putchar(c) {
      // int putchar(int c);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/putchar.html
      return _fputc(c, HEAP32[((_stdout)>>2)]);
    } 
  Module["_saveSetjmp"] = _saveSetjmp;
  Module["_testSetjmp"] = _testSetjmp;var _setjmp=undefined;
  function _unlink(path) {
      // int unlink(const char *path);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/unlink.html
      path = Pointer_stringify(path);
      try {
        FS.unlink(path);
        return 0;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }
  function _rmdir(path) {
      // int rmdir(const char *path);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/rmdir.html
      path = Pointer_stringify(path);
      try {
        FS.rmdir(path);
        return 0;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _remove(path) {
      // int remove(const char *path);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/remove.html
      var ret = _unlink(path);
      if (ret == -1) ret = _rmdir(path);
      return ret;
    }
  function _strdup(ptr) {
      var len = _strlen(ptr);
      var newStr = _malloc(len + 1);
      (_memcpy(newStr, ptr, len)|0);
      HEAP8[(((newStr)+(len))|0)]=0;
      return newStr;
    }
  Module["_memcpy"] = _memcpy;var _llvm_memcpy_p0i8_p0i8_i32=_memcpy;
  function _usleep(useconds) {
      // int usleep(useconds_t useconds);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/usleep.html
      // We're single-threaded, so use a busy loop. Super-ugly.
      var msec = useconds / 1000;
      if (ENVIRONMENT_IS_WEB && window['performance'] && window['performance']['now']) {
        var start = window['performance']['now']();
        while (window['performance']['now']() - start < msec) {
          // Do nothing.
        }
      } else {
        var start = Date.now();
        while (Date.now() - start < msec) {
          // Do nothing.
        }
      }
      return 0;
    }
  var ___timespec_struct_layout={__size__:8,tv_sec:0,tv_nsec:4};function _nanosleep(rqtp, rmtp) {
      // int nanosleep(const struct timespec  *rqtp, struct timespec *rmtp);
      var seconds = HEAP32[(((rqtp)+(___timespec_struct_layout.tv_sec))>>2)];
      var nanoseconds = HEAP32[(((rqtp)+(___timespec_struct_layout.tv_nsec))>>2)];
      HEAP32[(((rmtp)+(___timespec_struct_layout.tv_sec))>>2)]=0
      HEAP32[(((rmtp)+(___timespec_struct_layout.tv_nsec))>>2)]=0
      return _usleep((seconds * 1e6) + (nanoseconds / 1000));
    }
  function _strrchr(ptr, chr) {
      var ptr2 = ptr + _strlen(ptr);
      do {
        if (HEAP8[(ptr2)] == chr) return ptr2;
        ptr2--;
      } while (ptr2 >= ptr);
      return 0;
    }
  function _strncmp(px, py, n) {
      var i = 0;
      while (i < n) {
        var x = HEAPU8[(((px)+(i))|0)];
        var y = HEAPU8[(((py)+(i))|0)];
        if (x == y && x == 0) return 0;
        if (x == 0) return -1;
        if (y == 0) return 1;
        if (x == y) {
          i ++;
          continue;
        } else {
          return x > y ? 1 : -1;
        }
      }
      return 0;
    }function _strcmp(px, py) {
      return _strncmp(px, py, TOTAL_MEMORY);
    }
  var _llvm_pow_f32=Math.pow;
  function _round(x) {
      return (x < 0) ? -Math.round(-x) : Math.round(x);
    }var _roundf=_round;
  function _longjmp(env, value) {
      asm['setThrew'](env, value || 1);
      throw 'longjmp';
    }
  function _isspace(chr) {
      return (chr == 32) || (chr >= 9 && chr <= 13);
    }function __parseInt(str, endptr, base, min, max, bits, unsign) {
      // Skip space.
      while (_isspace(HEAP8[(str)])) str++;
      // Check for a plus/minus sign.
      var multiplier = 1;
      if (HEAP8[(str)] == 45) {
        multiplier = -1;
        str++;
      } else if (HEAP8[(str)] == 43) {
        str++;
      }
      // Find base.
      var finalBase = base;
      if (!finalBase) {
        if (HEAP8[(str)] == 48) {
          if (HEAP8[((str+1)|0)] == 120 ||
              HEAP8[((str+1)|0)] == 88) {
            finalBase = 16;
            str += 2;
          } else {
            finalBase = 8;
            str++;
          }
        }
      } else if (finalBase==16) {
        if (HEAP8[(str)] == 48) {
          if (HEAP8[((str+1)|0)] == 120 ||
              HEAP8[((str+1)|0)] == 88) {
            str += 2;
          }
        }
      }
      if (!finalBase) finalBase = 10;
      // Get digits.
      var chr;
      var ret = 0;
      while ((chr = HEAP8[(str)]) != 0) {
        var digit = parseInt(String.fromCharCode(chr), finalBase);
        if (isNaN(digit)) {
          break;
        } else {
          ret = ret * finalBase + digit;
          str++;
        }
      }
      // Apply sign.
      ret *= multiplier;
      // Set end pointer.
      if (endptr) {
        HEAP32[((endptr)>>2)]=str
      }
      // Unsign if needed.
      if (unsign) {
        if (Math.abs(ret) > max) {
          ret = max;
          ___setErrNo(ERRNO_CODES.ERANGE);
        } else {
          ret = unSign(ret, bits);
        }
      }
      // Validate range.
      if (ret > max || ret < min) {
        ret = ret > max ? max : min;
        ___setErrNo(ERRNO_CODES.ERANGE);
      }
      if (bits == 64) {
        return ((asm["setTempRet0"]((tempDouble=ret,(+(Math.abs(tempDouble))) >= (+(1)) ? (tempDouble > (+(0)) ? ((Math.min((+(Math.floor((tempDouble)/(+(4294967296))))), (+(4294967295))))|0)>>>0 : (~~((+(Math.ceil((tempDouble - +(((~~(tempDouble)))>>>0))/(+(4294967296)))))))>>>0) : 0)),ret>>>0)|0);
      }
      return ret;
    }function _strtoul(str, endptr, base) {
      return __parseInt(str, endptr, base, 0, 4294967295, 32, true);  // ULONG_MAX.
    }
  function _strtol(str, endptr, base) {
      return __parseInt(str, endptr, base, -2147483648, 2147483647, 32);  // LONG_MIN, LONG_MAX.
    }
  function _fputs(s, stream) {
      // int fputs(const char *restrict s, FILE *restrict stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fputs.html
      return _write(stream, s, _strlen(s));
    }function _puts(s) {
      // int puts(const char *s);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/puts.html
      // NOTE: puts() always writes an extra newline.
      var stdout = HEAP32[((_stdout)>>2)];
      var ret = _fputs(s, stdout);
      if (ret < 0) {
        return ret;
      } else {
        var newlineRet = _fputc(10, stdout);
        return (newlineRet < 0) ? -1 : ret + 1;
      }
    }
  function _printf(format, varargs) {
      // int printf(const char *restrict format, ...);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/printf.html
      var stdout = HEAP32[((_stdout)>>2)];
      return _fprintf(stdout, format, varargs);
    }
  function _llvm_lifetime_start() {}
  function _llvm_lifetime_end() {}
  var _llvm_memset_p0i8_i64=_memset;
  var ___dirent_struct_layout={__size__:1040,d_ino:0,d_name:4,d_off:1028,d_reclen:1032,d_type:1036};function _open(path, oflag, varargs) {
      // int open(const char *path, int oflag, ...);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/open.html
      var mode = HEAP32[((varargs)>>2)];
      path = Pointer_stringify(path);
      try {
        var stream = FS.open(path, oflag, mode);
        return stream.fd;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _fopen(filename, mode) {
      // FILE *fopen(const char *restrict filename, const char *restrict mode);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fopen.html
      var flags;
      mode = Pointer_stringify(mode);
      if (mode[0] == 'r') {
        if (mode.indexOf('+') != -1) {
          flags = 2;
        } else {
          flags = 0;
        }
      } else if (mode[0] == 'w') {
        if (mode.indexOf('+') != -1) {
          flags = 2;
        } else {
          flags = 1;
        }
        flags |= 512;
        flags |= 1024;
      } else if (mode[0] == 'a') {
        if (mode.indexOf('+') != -1) {
          flags = 2;
        } else {
          flags = 1;
        }
        flags |= 512;
        flags |= 8;
      } else {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return 0;
      }
      var ret = _open(filename, flags, allocate([0x1FF, 0, 0, 0], 'i32', ALLOC_STACK));  // All creation permissions.
      return (ret == -1) ? 0 : ret;
    }
  function _lseek(fildes, offset, whence) {
      // off_t lseek(int fildes, off_t offset, int whence);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/lseek.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      try {
        return FS.llseek(stream, offset, whence);
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _fseek(stream, offset, whence) {
      // int fseek(FILE *stream, long offset, int whence);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fseek.html
      var ret = _lseek(stream, offset, whence);
      if (ret == -1) {
        return -1;
      }
      stream = FS.getStream(stream);
      stream.eof = false;
      return 0;
    }
  function _ftell(stream) {
      // long ftell(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/ftell.html
      stream = FS.getStream(stream);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      if (FS.isChrdev(stream.node.mode)) {
        ___setErrNo(ERRNO_CODES.ESPIPE);
        return -1;
      } else {
        return stream.position;
      }
    }
  function _rewind(stream) {
      // void rewind(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/rewind.html
      _fseek(stream, 0, 0);  // SEEK_SET.
      var streamObj = FS.getStream(stream);
      if (streamObj) streamObj.error = false;
    }
  function _recv(fd, buf, len, flags) {
      var sock = SOCKFS.getSocket(fd);
      if (!sock) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      // TODO honor flags
      return _read(fd, buf, len);
    }
  function _pread(fildes, buf, nbyte, offset) {
      // ssize_t pread(int fildes, void *buf, size_t nbyte, off_t offset);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/read.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      try {
        var slab = HEAP8;
        return FS.read(stream, slab, buf, nbyte, offset);
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _read(fildes, buf, nbyte) {
      // ssize_t read(int fildes, void *buf, size_t nbyte);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/read.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      try {
        var slab = HEAP8;
        return FS.read(stream, slab, buf, nbyte);
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _fread(ptr, size, nitems, stream) {
      // size_t fread(void *restrict ptr, size_t size, size_t nitems, FILE *restrict stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fread.html
      var bytesToRead = nitems * size;
      if (bytesToRead == 0) {
        return 0;
      }
      var bytesRead = 0;
      var streamObj = FS.getStream(stream);
      while (streamObj.ungotten.length && bytesToRead > 0) {
        HEAP8[((ptr++)|0)]=streamObj.ungotten.pop()
        bytesToRead--;
        bytesRead++;
      }
      var err = _read(stream, ptr, bytesToRead);
      if (err == -1) {
        if (streamObj) streamObj.error = true;
        return 0;
      }
      bytesRead += err;
      if (bytesRead < bytesToRead) streamObj.eof = true;
      return Math.floor(bytesRead / size);
    }
  function _feof(stream) {
      // int feof(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/feof.html
      stream = FS.getStream(stream);
      return Number(stream && stream.eof);
    }
  function _fgetc(stream) {
      // int fgetc(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fgetc.html
      var streamObj = FS.getStream(stream);
      if (!streamObj) return -1;
      if (streamObj.eof || streamObj.error) return -1;
      var ret = _fread(_fgetc.ret, 1, 1, stream);
      if (ret == 0) {
        return -1;
      } else if (ret == -1) {
        streamObj.error = true;
        return -1;
      } else {
        return HEAPU8[((_fgetc.ret)|0)];
      }
    }function _fgets(s, n, stream) {
      // char *fgets(char *restrict s, int n, FILE *restrict stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fgets.html
      var streamObj = FS.getStream(stream);
      if (!streamObj) return 0;
      if (streamObj.error || streamObj.eof) return 0;
      var byte_;
      for (var i = 0; i < n - 1 && byte_ != 10; i++) {
        byte_ = _fgetc(stream);
        if (byte_ == -1) {
          if (streamObj.error || (streamObj.eof && i == 0)) return 0;
          else if (streamObj.eof) break;
        }
        HEAP8[(((s)+(i))|0)]=byte_
      }
      HEAP8[(((s)+(i))|0)]=0
      return s;
    }
  function _strchr(ptr, chr) {
      ptr--;
      do {
        ptr++;
        var val = HEAP8[(ptr)];
        if (val == chr) return ptr;
      } while (val);
      return 0;
    }
  Module["_tolower"] = _tolower; 
  Module["_strncasecmp"] = _strncasecmp; 
  Module["_strcasecmp"] = _strcasecmp;
  var _environ=allocate(1, "i32*", ALLOC_STATIC);var ___environ=_environ;function ___buildEnvironment(env) {
      // WARNING: Arbitrary limit!
      var MAX_ENV_VALUES = 64;
      var TOTAL_ENV_SIZE = 1024;
      // Statically allocate memory for the environment.
      var poolPtr;
      var envPtr;
      if (!___buildEnvironment.called) {
        ___buildEnvironment.called = true;
        // Set default values. Use string keys for Closure Compiler compatibility.
        ENV['USER'] = 'root';
        ENV['PATH'] = '/';
        ENV['PWD'] = '/';
        ENV['HOME'] = '/home/emscripten';
        ENV['LANG'] = 'en_US.UTF-8';
        ENV['_'] = './this.program';
        // Allocate memory.
        poolPtr = allocate(TOTAL_ENV_SIZE, 'i8', ALLOC_STATIC);
        envPtr = allocate(MAX_ENV_VALUES * 4,
                          'i8*', ALLOC_STATIC);
        HEAP32[((envPtr)>>2)]=poolPtr
        HEAP32[((_environ)>>2)]=envPtr;
      } else {
        envPtr = HEAP32[((_environ)>>2)];
        poolPtr = HEAP32[((envPtr)>>2)];
      }
      // Collect key=value lines.
      var strings = [];
      var totalSize = 0;
      for (var key in env) {
        if (typeof env[key] === 'string') {
          var line = key + '=' + env[key];
          strings.push(line);
          totalSize += line.length;
        }
      }
      if (totalSize > TOTAL_ENV_SIZE) {
        throw new Error('Environment size exceeded TOTAL_ENV_SIZE!');
      }
      // Make new.
      var ptrSize = 4;
      for (var i = 0; i < strings.length; i++) {
        var line = strings[i];
        for (var j = 0; j < line.length; j++) {
          HEAP8[(((poolPtr)+(j))|0)]=line.charCodeAt(j);
        }
        HEAP8[(((poolPtr)+(j))|0)]=0;
        HEAP32[(((envPtr)+(i * ptrSize))>>2)]=poolPtr;
        poolPtr += line.length + 1;
      }
      HEAP32[(((envPtr)+(strings.length * ptrSize))>>2)]=0;
    }var ENV={};function _getenv(name) {
      // char *getenv(const char *name);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/getenv.html
      if (name === 0) return 0;
      name = Pointer_stringify(name);
      if (!ENV.hasOwnProperty(name)) return 0;
      if (_getenv.ret) _free(_getenv.ret);
      _getenv.ret = allocate(intArrayFromString(ENV[name]), 'i8', ALLOC_NORMAL);
      return _getenv.ret;
    }
  function _time(ptr) {
      var ret = Math.floor(Date.now()/1000);
      if (ptr) {
        HEAP32[((ptr)>>2)]=ret
      }
      return ret;
    }
  var ___tm_struct_layout={__size__:44,tm_sec:0,tm_min:4,tm_hour:8,tm_mday:12,tm_mon:16,tm_year:20,tm_wday:24,tm_yday:28,tm_isdst:32,tm_gmtoff:36,tm_zone:40};
  function __isLeapYear(year) {
        return year%4 === 0 && (year%100 !== 0 || year%400 === 0);
    }
  function __arraySum(array, index) {
      var sum = 0;
      for (var i = 0; i <= index; sum += array[i++]);
      return sum;
    }
  var __MONTH_DAYS_LEAP=[31,29,31,30,31,30,31,31,30,31,30,31];
  var __MONTH_DAYS_REGULAR=[31,28,31,30,31,30,31,31,30,31,30,31];function __addDays(date, days) {
      var newDate = new Date(date.getTime());
      while(days > 0) {
        var leap = __isLeapYear(newDate.getFullYear());
        var currentMonth = newDate.getMonth();
        var daysInCurrentMonth = (leap ? __MONTH_DAYS_LEAP : __MONTH_DAYS_REGULAR)[currentMonth];
        if (days > daysInCurrentMonth-newDate.getDate()) {
          // we spill over to next month
          days -= (daysInCurrentMonth-newDate.getDate()+1);
          newDate.setDate(1);
          if (currentMonth < 11) {
            newDate.setMonth(currentMonth+1)
          } else {
            newDate.setMonth(0);
            newDate.setFullYear(newDate.getFullYear()+1);
          }
        } else {
          // we stay in current month 
          newDate.setDate(newDate.getDate()+days);
          return newDate;
        }
      }
      return newDate;
    }function _strftime(s, maxsize, format, tm) {
      // size_t strftime(char *restrict s, size_t maxsize, const char *restrict format, const struct tm *restrict timeptr);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/strftime.html
      var date = {
        tm_sec: HEAP32[(((tm)+(___tm_struct_layout.tm_sec))>>2)],
        tm_min: HEAP32[(((tm)+(___tm_struct_layout.tm_min))>>2)],
        tm_hour: HEAP32[(((tm)+(___tm_struct_layout.tm_hour))>>2)],
        tm_mday: HEAP32[(((tm)+(___tm_struct_layout.tm_mday))>>2)],
        tm_mon: HEAP32[(((tm)+(___tm_struct_layout.tm_mon))>>2)],
        tm_year: HEAP32[(((tm)+(___tm_struct_layout.tm_year))>>2)],
        tm_wday: HEAP32[(((tm)+(___tm_struct_layout.tm_wday))>>2)],
        tm_yday: HEAP32[(((tm)+(___tm_struct_layout.tm_yday))>>2)],
        tm_isdst: HEAP32[(((tm)+(___tm_struct_layout.tm_isdst))>>2)]
      };
      var pattern = Pointer_stringify(format);
      // expand format
      var EXPANSION_RULES_1 = {
        '%c': '%a %b %d %H:%M:%S %Y',     // Replaced by the locale's appropriate date and time representation - e.g., Mon Aug  3 14:02:01 2013
        '%D': '%m/%d/%y',                 // Equivalent to %m / %d / %y
        '%F': '%Y-%m-%d',                 // Equivalent to %Y - %m - %d
        '%h': '%b',                       // Equivalent to %b
        '%r': '%I:%M:%S %p',              // Replaced by the time in a.m. and p.m. notation
        '%R': '%H:%M',                    // Replaced by the time in 24-hour notation
        '%T': '%H:%M:%S',                 // Replaced by the time
        '%x': '%m/%d/%y',                 // Replaced by the locale's appropriate date representation
        '%X': '%H:%M:%S',                 // Replaced by the locale's appropriate date representation
      };
      for (var rule in EXPANSION_RULES_1) {
        pattern = pattern.replace(new RegExp(rule, 'g'), EXPANSION_RULES_1[rule]);
      }
      var WEEKDAYS = ['Sunday', 'Monday', 'Tuesday', 'Wednesday', 'Thursday', 'Friday', 'Saturday'];
      var MONTHS = ['January', 'February', 'March', 'April', 'May', 'June', 'July', 'August', 'September', 'October', 'November', 'December'];
      var leadingSomething = function(value, digits, character) {
        var str = typeof value === 'number' ? value.toString() : (value || '');
        while (str.length < digits) {
          str = character[0]+str;
        }
        return str;
      };
      var leadingNulls = function(value, digits) {
        return leadingSomething(value, digits, '0');
      };
      var compareByDay = function(date1, date2) {
        var sgn = function(value) {
          return value < 0 ? -1 : (value > 0 ? 1 : 0);
        };
        var compare;
        if ((compare = sgn(date1.getFullYear()-date2.getFullYear())) === 0) {
          if ((compare = sgn(date1.getMonth()-date2.getMonth())) === 0) {
            compare = sgn(date1.getDate()-date2.getDate());
          }
        }
        return compare;
      };
      var getFirstWeekStartDate = function(janFourth) {
          switch (janFourth.getDay()) {
            case 0: // Sunday
              return new Date(janFourth.getFullYear()-1, 11, 29);
            case 1: // Monday
              return janFourth;
            case 2: // Tuesday
              return new Date(janFourth.getFullYear(), 0, 3);
            case 3: // Wednesday
              return new Date(janFourth.getFullYear(), 0, 2);
            case 4: // Thursday
              return new Date(janFourth.getFullYear(), 0, 1);
            case 5: // Friday
              return new Date(janFourth.getFullYear()-1, 11, 31);
            case 6: // Saturday
              return new Date(janFourth.getFullYear()-1, 11, 30);
          }
      };
      var getWeekBasedYear = function(date) {
          var thisDate = __addDays(new Date(date.tm_year+1900, 0, 1), date.tm_yday);
          var janFourthThisYear = new Date(thisDate.getFullYear(), 0, 4);
          var janFourthNextYear = new Date(thisDate.getFullYear()+1, 0, 4);
          var firstWeekStartThisYear = getFirstWeekStartDate(janFourthThisYear);
          var firstWeekStartNextYear = getFirstWeekStartDate(janFourthNextYear);
          if (compareByDay(firstWeekStartThisYear, thisDate) <= 0) {
            // this date is after the start of the first week of this year
            if (compareByDay(firstWeekStartNextYear, thisDate) <= 0) {
              return thisDate.getFullYear()+1;
            } else {
              return thisDate.getFullYear();
            }
          } else { 
            return thisDate.getFullYear()-1;
          }
      };
      var EXPANSION_RULES_2 = {
        '%a': function(date) {
          return WEEKDAYS[date.tm_wday].substring(0,3);
        },
        '%A': function(date) {
          return WEEKDAYS[date.tm_wday];
        },
        '%b': function(date) {
          return MONTHS[date.tm_mon].substring(0,3);
        },
        '%B': function(date) {
          return MONTHS[date.tm_mon];
        },
        '%C': function(date) {
          var year = date.tm_year+1900;
          return leadingNulls(Math.floor(year/100),2);
        },
        '%d': function(date) {
          return leadingNulls(date.tm_mday, 2);
        },
        '%e': function(date) {
          return leadingSomething(date.tm_mday, 2, ' ');
        },
        '%g': function(date) {
          // %g, %G, and %V give values according to the ISO 8601:2000 standard week-based year. 
          // In this system, weeks begin on a Monday and week 1 of the year is the week that includes 
          // January 4th, which is also the week that includes the first Thursday of the year, and 
          // is also the first week that contains at least four days in the year. 
          // If the first Monday of January is the 2nd, 3rd, or 4th, the preceding days are part of 
          // the last week of the preceding year; thus, for Saturday 2nd January 1999, 
          // %G is replaced by 1998 and %V is replaced by 53. If December 29th, 30th, 
          // or 31st is a Monday, it and any following days are part of week 1 of the following year. 
          // Thus, for Tuesday 30th December 1997, %G is replaced by 1998 and %V is replaced by 01.
          return getWeekBasedYear(date).toString().substring(2);
        },
        '%G': function(date) {
          return getWeekBasedYear(date);
        },
        '%H': function(date) {
          return leadingNulls(date.tm_hour, 2);
        },
        '%I': function(date) {
          return leadingNulls(date.tm_hour < 13 ? date.tm_hour : date.tm_hour-12, 2);
        },
        '%j': function(date) {
          // Day of the year (001-366)
          return leadingNulls(date.tm_mday+__arraySum(__isLeapYear(date.tm_year+1900) ? __MONTH_DAYS_LEAP : __MONTH_DAYS_REGULAR, date.tm_mon-1), 3);
        },
        '%m': function(date) {
          return leadingNulls(date.tm_mon+1, 2);
        },
        '%M': function(date) {
          return leadingNulls(date.tm_min, 2);
        },
        '%n': function() {
          return '\n';
        },
        '%p': function(date) {
          if (date.tm_hour > 0 && date.tm_hour < 13) {
            return 'AM';
          } else {
            return 'PM';
          }
        },
        '%S': function(date) {
          return leadingNulls(date.tm_sec, 2);
        },
        '%t': function() {
          return '\t';
        },
        '%u': function(date) {
          var day = new Date(date.tm_year+1900, date.tm_mon+1, date.tm_mday, 0, 0, 0, 0);
          return day.getDay() || 7;
        },
        '%U': function(date) {
          // Replaced by the week number of the year as a decimal number [00,53]. 
          // The first Sunday of January is the first day of week 1; 
          // days in the new year before this are in week 0. [ tm_year, tm_wday, tm_yday]
          var janFirst = new Date(date.tm_year+1900, 0, 1);
          var firstSunday = janFirst.getDay() === 0 ? janFirst : __addDays(janFirst, 7-janFirst.getDay());
          var endDate = new Date(date.tm_year+1900, date.tm_mon, date.tm_mday);
          // is target date after the first Sunday?
          if (compareByDay(firstSunday, endDate) < 0) {
            // calculate difference in days between first Sunday and endDate
            var februaryFirstUntilEndMonth = __arraySum(__isLeapYear(endDate.getFullYear()) ? __MONTH_DAYS_LEAP : __MONTH_DAYS_REGULAR, endDate.getMonth()-1)-31;
            var firstSundayUntilEndJanuary = 31-firstSunday.getDate();
            var days = firstSundayUntilEndJanuary+februaryFirstUntilEndMonth+endDate.getDate();
            return leadingNulls(Math.ceil(days/7), 2);
          }
          return compareByDay(firstSunday, janFirst) === 0 ? '01': '00';
        },
        '%V': function(date) {
          // Replaced by the week number of the year (Monday as the first day of the week) 
          // as a decimal number [01,53]. If the week containing 1 January has four 
          // or more days in the new year, then it is considered week 1. 
          // Otherwise, it is the last week of the previous year, and the next week is week 1. 
          // Both January 4th and the first Thursday of January are always in week 1. [ tm_year, tm_wday, tm_yday]
          var janFourthThisYear = new Date(date.tm_year+1900, 0, 4);
          var janFourthNextYear = new Date(date.tm_year+1901, 0, 4);
          var firstWeekStartThisYear = getFirstWeekStartDate(janFourthThisYear);
          var firstWeekStartNextYear = getFirstWeekStartDate(janFourthNextYear);
          var endDate = __addDays(new Date(date.tm_year+1900, 0, 1), date.tm_yday);
          if (compareByDay(endDate, firstWeekStartThisYear) < 0) {
            // if given date is before this years first week, then it belongs to the 53rd week of last year
            return '53';
          } 
          if (compareByDay(firstWeekStartNextYear, endDate) <= 0) {
            // if given date is after next years first week, then it belongs to the 01th week of next year
            return '01';
          }
          // given date is in between CW 01..53 of this calendar year
          var daysDifference;
          if (firstWeekStartThisYear.getFullYear() < date.tm_year+1900) {
            // first CW of this year starts last year
            daysDifference = date.tm_yday+32-firstWeekStartThisYear.getDate()
          } else {
            // first CW of this year starts this year
            daysDifference = date.tm_yday+1-firstWeekStartThisYear.getDate();
          }
          return leadingNulls(Math.ceil(daysDifference/7), 2);
        },
        '%w': function(date) {
          var day = new Date(date.tm_year+1900, date.tm_mon+1, date.tm_mday, 0, 0, 0, 0);
          return day.getDay();
        },
        '%W': function(date) {
          // Replaced by the week number of the year as a decimal number [00,53]. 
          // The first Monday of January is the first day of week 1; 
          // days in the new year before this are in week 0. [ tm_year, tm_wday, tm_yday]
          var janFirst = new Date(date.tm_year, 0, 1);
          var firstMonday = janFirst.getDay() === 1 ? janFirst : __addDays(janFirst, janFirst.getDay() === 0 ? 1 : 7-janFirst.getDay()+1);
          var endDate = new Date(date.tm_year+1900, date.tm_mon, date.tm_mday);
          // is target date after the first Monday?
          if (compareByDay(firstMonday, endDate) < 0) {
            var februaryFirstUntilEndMonth = __arraySum(__isLeapYear(endDate.getFullYear()) ? __MONTH_DAYS_LEAP : __MONTH_DAYS_REGULAR, endDate.getMonth()-1)-31;
            var firstMondayUntilEndJanuary = 31-firstMonday.getDate();
            var days = firstMondayUntilEndJanuary+februaryFirstUntilEndMonth+endDate.getDate();
            return leadingNulls(Math.ceil(days/7), 2);
          }
          return compareByDay(firstMonday, janFirst) === 0 ? '01': '00';
        },
        '%y': function(date) {
          // Replaced by the last two digits of the year as a decimal number [00,99]. [ tm_year]
          return (date.tm_year+1900).toString().substring(2);
        },
        '%Y': function(date) {
          // Replaced by the year as a decimal number (for example, 1997). [ tm_year]
          return date.tm_year+1900;
        },
        '%z': function(date) {
          // Replaced by the offset from UTC in the ISO 8601:2000 standard format ( +hhmm or -hhmm ),
          // or by no characters if no timezone is determinable. 
          // For example, "-0430" means 4 hours 30 minutes behind UTC (west of Greenwich). 
          // If tm_isdst is zero, the standard time offset is used. 
          // If tm_isdst is greater than zero, the daylight savings time offset is used. 
          // If tm_isdst is negative, no characters are returned. 
          // FIXME: we cannot determine time zone (or can we?)
          return '';
        },
        '%Z': function(date) {
          // Replaced by the timezone name or abbreviation, or by no bytes if no timezone information exists. [ tm_isdst]
          // FIXME: we cannot determine time zone (or can we?)
          return '';
        },
        '%%': function() {
          return '%';
        }
      };
      for (var rule in EXPANSION_RULES_2) {
        if (pattern.indexOf(rule) >= 0) {
          pattern = pattern.replace(new RegExp(rule, 'g'), EXPANSION_RULES_2[rule](date));
        }
      }
      var bytes = intArrayFromString(pattern, false);
      if (bytes.length > maxsize) {
        return 0;
      } 
      writeArrayToMemory(bytes, s);
      return bytes.length-1;
    }
  var ___tm_current=allocate(4*26, "i8", ALLOC_STATIC);
  var ___tm_timezone=allocate(intArrayFromString("GMT"), "i8", ALLOC_STATIC);
  var __tzname=allocate(8, "i32*", ALLOC_STATIC);
  var __daylight=allocate(1, "i32*", ALLOC_STATIC);
  var __timezone=allocate(1, "i32*", ALLOC_STATIC);function _tzset() {
      // TODO: Use (malleable) environment variables instead of system settings.
      if (_tzset.called) return;
      _tzset.called = true;
      HEAP32[((__timezone)>>2)]=-(new Date()).getTimezoneOffset() * 60
      var winter = new Date(2000, 0, 1);
      var summer = new Date(2000, 6, 1);
      HEAP32[((__daylight)>>2)]=Number(winter.getTimezoneOffset() != summer.getTimezoneOffset())
      var winterName = 'GMT'; // XXX do not rely on browser timezone info, it is very unpredictable | winter.toString().match(/\(([A-Z]+)\)/)[1];
      var summerName = 'GMT'; // XXX do not rely on browser timezone info, it is very unpredictable | summer.toString().match(/\(([A-Z]+)\)/)[1];
      var winterNamePtr = allocate(intArrayFromString(winterName), 'i8', ALLOC_NORMAL);
      var summerNamePtr = allocate(intArrayFromString(summerName), 'i8', ALLOC_NORMAL);
      HEAP32[((__tzname)>>2)]=winterNamePtr
      HEAP32[(((__tzname)+(4))>>2)]=summerNamePtr
    }function _localtime_r(time, tmPtr) {
      _tzset();
      var offsets = ___tm_struct_layout;
      var date = new Date(HEAP32[((time)>>2)]*1000);
      HEAP32[(((tmPtr)+(offsets.tm_sec))>>2)]=date.getSeconds()
      HEAP32[(((tmPtr)+(offsets.tm_min))>>2)]=date.getMinutes()
      HEAP32[(((tmPtr)+(offsets.tm_hour))>>2)]=date.getHours()
      HEAP32[(((tmPtr)+(offsets.tm_mday))>>2)]=date.getDate()
      HEAP32[(((tmPtr)+(offsets.tm_mon))>>2)]=date.getMonth()
      HEAP32[(((tmPtr)+(offsets.tm_year))>>2)]=date.getFullYear()-1900
      HEAP32[(((tmPtr)+(offsets.tm_wday))>>2)]=date.getDay()
      var start = new Date(date.getFullYear(), 0, 1);
      var yday = Math.floor((date.getTime() - start.getTime()) / (1000 * 60 * 60 * 24));
      HEAP32[(((tmPtr)+(offsets.tm_yday))>>2)]=yday
      HEAP32[(((tmPtr)+(offsets.tm_gmtoff))>>2)]=start.getTimezoneOffset() * 60
      var dst = Number(start.getTimezoneOffset() != date.getTimezoneOffset());
      HEAP32[(((tmPtr)+(offsets.tm_isdst))>>2)]=dst
      HEAP32[(((tmPtr)+(offsets.tm_zone))>>2)]=___tm_timezone
      return tmPtr;
    }function _localtime(time) {
      return _localtime_r(time, ___tm_current);
    }
  function _strtok_r(s, delim, lasts) {
      var skip_leading_delim = 1;
      var spanp;
      var c, sc;
      var tok;
      if (s == 0 && (s = getValue(lasts, 'i8*')) == 0) {
        return 0;
      }
      cont: while (1) {
        c = getValue(s++, 'i8');
        for (spanp = delim; (sc = getValue(spanp++, 'i8')) != 0;) {
          if (c == sc) {
            if (skip_leading_delim) {
              continue cont;
            } else {
              setValue(lasts, s, 'i8*');
              setValue(s - 1, 0, 'i8');
              return s - 1;
            }
          }
        }
        break;
      }
      if (c == 0) {
        setValue(lasts, 0, 'i8*');
        return 0;
      }
      tok = s - 1;
      for (;;) {
        c = getValue(s++, 'i8');
        spanp = delim;
        do {
          if ((sc = getValue(spanp++, 'i8')) == c) {
            if (c == 0) {
              s = 0;
            } else {
              setValue(s - 1, 0, 'i8');
            }
            setValue(lasts, s, 'i8*');
            return tok;
          }
        } while (sc != 0);
      }
      abort('strtok_r error!');
    }
  function _qsort(base, num, size, cmp) {
      if (num == 0 || size == 0) return;
      // forward calls to the JavaScript sort method
      // first, sort the items logically
      var keys = [];
      for (var i = 0; i < num; i++) keys.push(i);
      keys.sort(function(a, b) {
        return Module['dynCall_iii'](cmp, base+a*size, base+b*size);
      });
      // apply the sort
      var temp = _malloc(num*size);
      _memcpy(temp, base, num*size);
      for (var i = 0; i < num; i++) {
        if (keys[i] == i) continue; // already in place
        _memcpy(base+i*size, temp+keys[i]*size, size);
      }
      _free(temp);
    }
  function _opendir(dirname) {
      // DIR *opendir(const char *dirname);
      // http://pubs.opengroup.org/onlinepubs/007908799/xsh/opendir.html
      // NOTE: Calculating absolute path redundantly since we need to associate it
      //       with the opened stream.
      var path = Pointer_stringify(dirname);
      if (!path) {
        ___setErrNo(ERRNO_CODES.ENOENT);
        return 0;
      }
      var node;
      try {
        var lookup = FS.lookupPath(path, { follow: true });
        node = lookup.node;
      } catch (e) {
        FS.handleFSError(e);
        return 0;
      }
      if (!FS.isDir(node.mode)) {
        ___setErrNo(ERRNO_CODES.ENOTDIR);
        return 0;
      }
      var err = _open(dirname, 0, allocate([0, 0, 0, 0], 'i32', ALLOC_STACK));
      // open returns 0 on failure, not -1
      return err === -1 ? 0 : err;
    }
  function _readdir_r(dirp, entry, result) {
      // int readdir_r(DIR *dirp, struct dirent *entry, struct dirent **result);
      // http://pubs.opengroup.org/onlinepubs/007908799/xsh/readdir_r.html
      var stream = FS.getStream(dirp);
      if (!stream) {
        return ___setErrNo(ERRNO_CODES.EBADF);
      }
      var entries;
      try {
        entries = FS.readdir(stream.path);
      } catch (e) {
        return FS.handleFSError(e);
      }
      if (stream.position < 0 || stream.position >= entries.length) {
        HEAP32[((result)>>2)]=0
        return 0;
      }
      var id;
      var type;
      var name = entries[stream.position];
      var offset = stream.position + 1;
      if (!name.indexOf('.')) {
        id = 1;
        type = 4;
      } else {
        var child = FS.lookupNode(stream.node, name);
        id = child.id;
        type = FS.isChrdev(child.mode) ? 2 :  // DT_CHR, character device.
               FS.isDir(child.mode) ? 4 :     // DT_DIR, directory.
               FS.isLink(child.mode) ? 10 :   // DT_LNK, symbolic link.
               8;                             // DT_REG, regular file.
      }
      HEAP32[(((entry)+(___dirent_struct_layout.d_ino))>>2)]=id
      HEAP32[(((entry)+(___dirent_struct_layout.d_off))>>2)]=offset
      HEAP32[(((entry)+(___dirent_struct_layout.d_reclen))>>2)]=name.length + 1
      for (var i = 0; i < name.length; i++) {
        HEAP8[(((entry + ___dirent_struct_layout.d_name)+(i))|0)]=name.charCodeAt(i)
      }
      HEAP8[(((entry + ___dirent_struct_layout.d_name)+(i))|0)]=0
      HEAP8[(((entry)+(___dirent_struct_layout.d_type))|0)]=type
      HEAP32[((result)>>2)]=entry
      stream.position++;
      return 0;
    }function _readdir(dirp) {
      // struct dirent *readdir(DIR *dirp);
      // http://pubs.opengroup.org/onlinepubs/007908799/xsh/readdir_r.html
      var stream = FS.getStream(dirp);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return 0;
      }
      // TODO Is it supposed to be safe to execute multiple readdirs?
      if (!_readdir.entry) _readdir.entry = _malloc(___dirent_struct_layout.__size__);
      if (!_readdir.result) _readdir.result = _malloc(4);
      var err = _readdir_r(dirp, _readdir.entry, _readdir.result);
      if (err) {
        ___setErrNo(err);
        return 0;
      }
      return HEAP32[((_readdir.result)>>2)];
    }
  function _closedir(dirp) {
      // int closedir(DIR *dirp);
      // http://pubs.opengroup.org/onlinepubs/007908799/xsh/closedir.html
      return _close(dirp);
    }
  var ___stat_struct_layout={__size__:68,st_dev:0,st_ino:4,st_mode:8,st_nlink:12,st_uid:16,st_gid:20,st_rdev:24,st_size:28,st_atime:32,st_spare1:36,st_mtime:40,st_spare2:44,st_ctime:48,st_spare3:52,st_blksize:56,st_blocks:60,st_spare4:64};function _stat(path, buf, dontResolveLastLink) {
      // http://pubs.opengroup.org/onlinepubs/7908799/xsh/stat.html
      // int stat(const char *path, struct stat *buf);
      // NOTE: dontResolveLastLink is a shortcut for lstat(). It should never be
      //       used in client code.
      path = typeof path !== 'string' ? Pointer_stringify(path) : path;
      try {
        var stat = dontResolveLastLink ? FS.lstat(path) : FS.stat(path);
        HEAP32[(((buf)+(___stat_struct_layout.st_dev))>>2)]=stat.dev;
        HEAP32[(((buf)+(___stat_struct_layout.st_ino))>>2)]=stat.ino
        HEAP32[(((buf)+(___stat_struct_layout.st_mode))>>2)]=stat.mode
        HEAP32[(((buf)+(___stat_struct_layout.st_nlink))>>2)]=stat.nlink
        HEAP32[(((buf)+(___stat_struct_layout.st_uid))>>2)]=stat.uid
        HEAP32[(((buf)+(___stat_struct_layout.st_gid))>>2)]=stat.gid
        HEAP32[(((buf)+(___stat_struct_layout.st_rdev))>>2)]=stat.rdev
        HEAP32[(((buf)+(___stat_struct_layout.st_size))>>2)]=stat.size
        HEAP32[(((buf)+(___stat_struct_layout.st_atime))>>2)]=Math.floor(stat.atime.getTime() / 1000)
        HEAP32[(((buf)+(___stat_struct_layout.st_mtime))>>2)]=Math.floor(stat.mtime.getTime() / 1000)
        HEAP32[(((buf)+(___stat_struct_layout.st_ctime))>>2)]=Math.floor(stat.ctime.getTime() / 1000)
        HEAP32[(((buf)+(___stat_struct_layout.st_blksize))>>2)]=4096
        HEAP32[(((buf)+(___stat_struct_layout.st_blocks))>>2)]=stat.blocks
        return 0;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }
  function _realpath(file_name, resolved_name) {
      // char *realpath(const char *restrict file_name, char *restrict resolved_name);
      // http://pubs.opengroup.org/onlinepubs/009604499/functions/realpath.html
      var absolute = FS.analyzePath(Pointer_stringify(file_name));
      if (absolute.error) {
        ___setErrNo(absolute.error);
        return 0;
      } else {
        var size = Math.min(4095, absolute.path.length);  // PATH_MAX - 1.
        for (var i = 0; i < size; i++) {
          HEAP8[(((resolved_name)+(i))|0)]=absolute.path.charCodeAt(i)
        }
        HEAP8[(((resolved_name)+(size))|0)]=0
        return resolved_name;
      }
    }
  function _getgid() {
      // gid_t getgid(void);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/getgid.html
      // We have just one process/group/user, all with ID 0.
      return 0;
    }var _getpid=_getgid;
  function _readlink(path, buf, bufsize) {
      // ssize_t readlink(const char *restrict path, char *restrict buf, size_t bufsize);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/readlink.html
      path = Pointer_stringify(path);
      var str;
      try {
        str = FS.readlink(path);
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
      str = str.slice(0, Math.max(0, bufsize - 1));
      writeStringToMemory(str, buf, true);
      return str.length;
    }
  var _sqrt=Math.sqrt;
  var _fabs=Math.abs;
  function ___errno_location() {
      return ___errno_state;
    }var ___errno=___errno_location;
  function __parseInt64(str, endptr, base, min, max, unsign) {
      var isNegative = false;
      // Skip space.
      while (_isspace(HEAP8[(str)])) str++;
      // Check for a plus/minus sign.
      if (HEAP8[(str)] == 45) {
        str++;
        isNegative = true;
      } else if (HEAP8[(str)] == 43) {
        str++;
      }
      // Find base.
      var ok = false;
      var finalBase = base;
      if (!finalBase) {
        if (HEAP8[(str)] == 48) {
          if (HEAP8[((str+1)|0)] == 120 ||
              HEAP8[((str+1)|0)] == 88) {
            finalBase = 16;
            str += 2;
          } else {
            finalBase = 8;
            ok = true; // we saw an initial zero, perhaps the entire thing is just "0"
          }
        }
      } else if (finalBase==16) {
        if (HEAP8[(str)] == 48) {
          if (HEAP8[((str+1)|0)] == 120 ||
              HEAP8[((str+1)|0)] == 88) {
            str += 2;
          }
        }
      }
      if (!finalBase) finalBase = 10;
      start = str;
      // Get digits.
      var chr;
      while ((chr = HEAP8[(str)]) != 0) {
        var digit = parseInt(String.fromCharCode(chr), finalBase);
        if (isNaN(digit)) {
          break;
        } else {
          str++;
          ok = true;
        }
      }
      if (!ok) {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return ((asm["setTempRet0"](0),0)|0);
      }
      // Set end pointer.
      if (endptr) {
        HEAP32[((endptr)>>2)]=str
      }
      try {
        var numberString = isNegative ? '-'+Pointer_stringify(start, str - start) : Pointer_stringify(start, str - start);
        i64Math.fromString(numberString, finalBase, min, max, unsign);
      } catch(e) {
        ___setErrNo(ERRNO_CODES.ERANGE); // not quite correct
      }
      return ((asm["setTempRet0"](((HEAP32[(((tempDoublePtr)+(4))>>2)])|0)),((HEAP32[((tempDoublePtr)>>2)])|0))|0);
    }function _strtoull(str, endptr, base) {
      return __parseInt64(str, endptr, base, 0, '18446744073709551615', true);  // ULONG_MAX.
    }
  function _isgraph(chr) {
      return 0x20 < chr && chr < 0x7F;
    }
  var _getc=_fgetc;
  function _llvm_bswap_i32(x) {
      return ((x&0xff)<<24) | (((x>>8)&0xff)<<16) | (((x>>16)&0xff)<<8) | (x>>>24);
    }
  function _isalpha(chr) {
      return (chr >= 97 && chr <= 122) ||
             (chr >= 65 && chr <= 90);
    }
  var Browser={mainLoop:{scheduler:null,shouldPause:false,paused:false,queue:[],pause:function () {
          Browser.mainLoop.shouldPause = true;
        },resume:function () {
          if (Browser.mainLoop.paused) {
            Browser.mainLoop.paused = false;
            Browser.mainLoop.scheduler();
          }
          Browser.mainLoop.shouldPause = false;
        },updateStatus:function () {
          if (Module['setStatus']) {
            var message = Module['statusMessage'] || 'Please wait...';
            var remaining = Browser.mainLoop.remainingBlockers;
            var expected = Browser.mainLoop.expectedBlockers;
            if (remaining) {
              if (remaining < expected) {
                Module['setStatus'](message + ' (' + (expected - remaining) + '/' + expected + ')');
              } else {
                Module['setStatus'](message);
              }
            } else {
              Module['setStatus']('');
            }
          }
        }},isFullScreen:false,pointerLock:false,moduleContextCreatedCallbacks:[],workers:[],init:function () {
        if (!Module["preloadPlugins"]) Module["preloadPlugins"] = []; // needs to exist even in workers
        if (Browser.initted || ENVIRONMENT_IS_WORKER) return;
        Browser.initted = true;
        try {
          new Blob();
          Browser.hasBlobConstructor = true;
        } catch(e) {
          Browser.hasBlobConstructor = false;
          console.log("warning: no blob constructor, cannot create blobs with mimetypes");
        }
        Browser.BlobBuilder = typeof MozBlobBuilder != "undefined" ? MozBlobBuilder : (typeof WebKitBlobBuilder != "undefined" ? WebKitBlobBuilder : (!Browser.hasBlobConstructor ? console.log("warning: no BlobBuilder") : null));
        Browser.URLObject = typeof window != "undefined" ? (window.URL ? window.URL : window.webkitURL) : undefined;
        if (!Module.noImageDecoding && typeof Browser.URLObject === 'undefined') {
          console.log("warning: Browser does not support creating object URLs. Built-in browser image decoding will not be available.");
          Module.noImageDecoding = true;
        }
        // Support for plugins that can process preloaded files. You can add more of these to
        // your app by creating and appending to Module.preloadPlugins.
        //
        // Each plugin is asked if it can handle a file based on the file's name. If it can,
        // it is given the file's raw data. When it is done, it calls a callback with the file's
        // (possibly modified) data. For example, a plugin might decompress a file, or it
        // might create some side data structure for use later (like an Image element, etc.).
        var imagePlugin = {};
        imagePlugin['canHandle'] = function(name) {
          return !Module.noImageDecoding && /\.(jpg|jpeg|png|bmp)$/i.test(name);
        };
        imagePlugin['handle'] = function(byteArray, name, onload, onerror) {
          var b = null;
          if (Browser.hasBlobConstructor) {
            try {
              b = new Blob([byteArray], { type: Browser.getMimetype(name) });
              if (b.size !== byteArray.length) { // Safari bug #118630
                // Safari's Blob can only take an ArrayBuffer
                b = new Blob([(new Uint8Array(byteArray)).buffer], { type: Browser.getMimetype(name) });
              }
            } catch(e) {
              Runtime.warnOnce('Blob constructor present but fails: ' + e + '; falling back to blob builder');
            }
          }
          if (!b) {
            var bb = new Browser.BlobBuilder();
            bb.append((new Uint8Array(byteArray)).buffer); // we need to pass a buffer, and must copy the array to get the right data range
            b = bb.getBlob();
          }
          var url = Browser.URLObject.createObjectURL(b);
          var img = new Image();
          img.onload = function() {
            assert(img.complete, 'Image ' + name + ' could not be decoded');
            var canvas = document.createElement('canvas');
            canvas.width = img.width;
            canvas.height = img.height;
            var ctx = canvas.getContext('2d');
            ctx.drawImage(img, 0, 0);
            Module["preloadedImages"][name] = canvas;
            Browser.URLObject.revokeObjectURL(url);
            if (onload) onload(byteArray);
          };
          img.onerror = function(event) {
            console.log('Image ' + url + ' could not be decoded');
            if (onerror) onerror();
          };
          img.src = url;
        };
        Module['preloadPlugins'].push(imagePlugin);
        var audioPlugin = {};
        audioPlugin['canHandle'] = function(name) {
          return !Module.noAudioDecoding && name.substr(-4) in { '.ogg': 1, '.wav': 1, '.mp3': 1 };
        };
        audioPlugin['handle'] = function(byteArray, name, onload, onerror) {
          var done = false;
          function finish(audio) {
            if (done) return;
            done = true;
            Module["preloadedAudios"][name] = audio;
            if (onload) onload(byteArray);
          }
          function fail() {
            if (done) return;
            done = true;
            Module["preloadedAudios"][name] = new Audio(); // empty shim
            if (onerror) onerror();
          }
          if (Browser.hasBlobConstructor) {
            try {
              var b = new Blob([byteArray], { type: Browser.getMimetype(name) });
            } catch(e) {
              return fail();
            }
            var url = Browser.URLObject.createObjectURL(b); // XXX we never revoke this!
            var audio = new Audio();
            audio.addEventListener('canplaythrough', function() { finish(audio) }, false); // use addEventListener due to chromium bug 124926
            audio.onerror = function(event) {
              if (done) return;
              console.log('warning: browser could not fully decode audio ' + name + ', trying slower base64 approach');
              function encode64(data) {
                var BASE = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/';
                var PAD = '=';
                var ret = '';
                var leftchar = 0;
                var leftbits = 0;
                for (var i = 0; i < data.length; i++) {
                  leftchar = (leftchar << 8) | data[i];
                  leftbits += 8;
                  while (leftbits >= 6) {
                    var curr = (leftchar >> (leftbits-6)) & 0x3f;
                    leftbits -= 6;
                    ret += BASE[curr];
                  }
                }
                if (leftbits == 2) {
                  ret += BASE[(leftchar&3) << 4];
                  ret += PAD + PAD;
                } else if (leftbits == 4) {
                  ret += BASE[(leftchar&0xf) << 2];
                  ret += PAD;
                }
                return ret;
              }
              audio.src = 'data:audio/x-' + name.substr(-3) + ';base64,' + encode64(byteArray);
              finish(audio); // we don't wait for confirmation this worked - but it's worth trying
            };
            audio.src = url;
            // workaround for chrome bug 124926 - we do not always get oncanplaythrough or onerror
            Browser.safeSetTimeout(function() {
              finish(audio); // try to use it even though it is not necessarily ready to play
            }, 10000);
          } else {
            return fail();
          }
        };
        Module['preloadPlugins'].push(audioPlugin);
        // Canvas event setup
        var canvas = Module['canvas'];
        canvas.requestPointerLock = canvas['requestPointerLock'] ||
                                    canvas['mozRequestPointerLock'] ||
                                    canvas['webkitRequestPointerLock'];
        canvas.exitPointerLock = document['exitPointerLock'] ||
                                 document['mozExitPointerLock'] ||
                                 document['webkitExitPointerLock'] ||
                                 function(){}; // no-op if function does not exist
        canvas.exitPointerLock = canvas.exitPointerLock.bind(document);
        function pointerLockChange() {
          Browser.pointerLock = document['pointerLockElement'] === canvas ||
                                document['mozPointerLockElement'] === canvas ||
                                document['webkitPointerLockElement'] === canvas;
        }
        document.addEventListener('pointerlockchange', pointerLockChange, false);
        document.addEventListener('mozpointerlockchange', pointerLockChange, false);
        document.addEventListener('webkitpointerlockchange', pointerLockChange, false);
        if (Module['elementPointerLock']) {
          canvas.addEventListener("click", function(ev) {
            if (!Browser.pointerLock && canvas.requestPointerLock) {
              canvas.requestPointerLock();
              ev.preventDefault();
            }
          }, false);
        }
      },createContext:function (canvas, useWebGL, setInModule) {
        var ctx;
        try {
          if (useWebGL) {
            ctx = canvas.getContext('experimental-webgl', {
              alpha: false
            });
          } else {
            ctx = canvas.getContext('2d');
          }
          if (!ctx) throw ':(';
        } catch (e) {
          Module.print('Could not create canvas - ' + e);
          return null;
        }
        if (useWebGL) {
          // Set the background of the WebGL canvas to black
          canvas.style.backgroundColor = "black";
          // Warn on context loss
          canvas.addEventListener('webglcontextlost', function(event) {
            alert('WebGL context lost. You will need to reload the page.');
          }, false);
        }
        if (setInModule) {
          Module.ctx = ctx;
          Module.useWebGL = useWebGL;
          Browser.moduleContextCreatedCallbacks.forEach(function(callback) { callback() });
          Browser.init();
        }
        return ctx;
      },destroyContext:function (canvas, useWebGL, setInModule) {},fullScreenHandlersInstalled:false,lockPointer:undefined,resizeCanvas:undefined,requestFullScreen:function (lockPointer, resizeCanvas) {
        Browser.lockPointer = lockPointer;
        Browser.resizeCanvas = resizeCanvas;
        if (typeof Browser.lockPointer === 'undefined') Browser.lockPointer = true;
        if (typeof Browser.resizeCanvas === 'undefined') Browser.resizeCanvas = false;
        var canvas = Module['canvas'];
        function fullScreenChange() {
          Browser.isFullScreen = false;
          if ((document['webkitFullScreenElement'] || document['webkitFullscreenElement'] ||
               document['mozFullScreenElement'] || document['mozFullscreenElement'] ||
               document['fullScreenElement'] || document['fullscreenElement']) === canvas) {
            canvas.cancelFullScreen = document['cancelFullScreen'] ||
                                      document['mozCancelFullScreen'] ||
                                      document['webkitCancelFullScreen'];
            canvas.cancelFullScreen = canvas.cancelFullScreen.bind(document);
            if (Browser.lockPointer) canvas.requestPointerLock();
            Browser.isFullScreen = true;
            if (Browser.resizeCanvas) Browser.setFullScreenCanvasSize();
          } else if (Browser.resizeCanvas){
            Browser.setWindowedCanvasSize();
          }
          if (Module['onFullScreen']) Module['onFullScreen'](Browser.isFullScreen);
        }
        if (!Browser.fullScreenHandlersInstalled) {
          Browser.fullScreenHandlersInstalled = true;
          document.addEventListener('fullscreenchange', fullScreenChange, false);
          document.addEventListener('mozfullscreenchange', fullScreenChange, false);
          document.addEventListener('webkitfullscreenchange', fullScreenChange, false);
        }
        canvas.requestFullScreen = canvas['requestFullScreen'] ||
                                   canvas['mozRequestFullScreen'] ||
                                   (canvas['webkitRequestFullScreen'] ? function() { canvas['webkitRequestFullScreen'](Element['ALLOW_KEYBOARD_INPUT']) } : null);
        canvas.requestFullScreen();
      },requestAnimationFrame:function (func) {
        if (!window.requestAnimationFrame) {
          window.requestAnimationFrame = window['requestAnimationFrame'] ||
                                         window['mozRequestAnimationFrame'] ||
                                         window['webkitRequestAnimationFrame'] ||
                                         window['msRequestAnimationFrame'] ||
                                         window['oRequestAnimationFrame'] ||
                                         window['setTimeout'];
        }
        window.requestAnimationFrame(func);
      },safeCallback:function (func) {
        return function() {
          if (!ABORT) return func.apply(null, arguments);
        };
      },safeRequestAnimationFrame:function (func) {
        return Browser.requestAnimationFrame(function() {
          if (!ABORT) func();
        });
      },safeSetTimeout:function (func, timeout) {
        return setTimeout(function() {
          if (!ABORT) func();
        }, timeout);
      },safeSetInterval:function (func, timeout) {
        return setInterval(function() {
          if (!ABORT) func();
        }, timeout);
      },getMimetype:function (name) {
        return {
          'jpg': 'image/jpeg',
          'jpeg': 'image/jpeg',
          'png': 'image/png',
          'bmp': 'image/bmp',
          'ogg': 'audio/ogg',
          'wav': 'audio/wav',
          'mp3': 'audio/mpeg'
        }[name.substr(name.lastIndexOf('.')+1)];
      },getUserMedia:function (func) {
        if(!window.getUserMedia) {
          window.getUserMedia = navigator['getUserMedia'] ||
                                navigator['mozGetUserMedia'];
        }
        window.getUserMedia(func);
      },getMovementX:function (event) {
        return event['movementX'] ||
               event['mozMovementX'] ||
               event['webkitMovementX'] ||
               0;
      },getMovementY:function (event) {
        return event['movementY'] ||
               event['mozMovementY'] ||
               event['webkitMovementY'] ||
               0;
      },mouseX:0,mouseY:0,mouseMovementX:0,mouseMovementY:0,calculateMouseEvent:function (event) { // event should be mousemove, mousedown or mouseup
        if (Browser.pointerLock) {
          // When the pointer is locked, calculate the coordinates
          // based on the movement of the mouse.
          // Workaround for Firefox bug 764498
          if (event.type != 'mousemove' &&
              ('mozMovementX' in event)) {
            Browser.mouseMovementX = Browser.mouseMovementY = 0;
          } else {
            Browser.mouseMovementX = Browser.getMovementX(event);
            Browser.mouseMovementY = Browser.getMovementY(event);
          }
          // check if SDL is available
          if (typeof SDL != "undefined") {
          	Browser.mouseX = SDL.mouseX + Browser.mouseMovementX;
          	Browser.mouseY = SDL.mouseY + Browser.mouseMovementY;
          } else {
          	// just add the mouse delta to the current absolut mouse position
          	// FIXME: ideally this should be clamped against the canvas size and zero
          	Browser.mouseX += Browser.mouseMovementX;
          	Browser.mouseY += Browser.mouseMovementY;
          }        
        } else {
          // Otherwise, calculate the movement based on the changes
          // in the coordinates.
          var rect = Module["canvas"].getBoundingClientRect();
          var x, y;
          if (event.type == 'touchstart' ||
              event.type == 'touchend' ||
              event.type == 'touchmove') {
            var t = event.touches.item(0);
            if (t) {
              x = t.pageX - (window.scrollX + rect.left);
              y = t.pageY - (window.scrollY + rect.top);
            } else {
              return;
            }
          } else {
            x = event.pageX - (window.scrollX + rect.left);
            y = event.pageY - (window.scrollY + rect.top);
          }
          // the canvas might be CSS-scaled compared to its backbuffer;
          // SDL-using content will want mouse coordinates in terms
          // of backbuffer units.
          var cw = Module["canvas"].width;
          var ch = Module["canvas"].height;
          x = x * (cw / rect.width);
          y = y * (ch / rect.height);
          Browser.mouseMovementX = x - Browser.mouseX;
          Browser.mouseMovementY = y - Browser.mouseY;
          Browser.mouseX = x;
          Browser.mouseY = y;
        }
      },xhrLoad:function (url, onload, onerror) {
        var xhr = new XMLHttpRequest();
        xhr.open('GET', url, true);
        xhr.responseType = 'arraybuffer';
        xhr.onload = function() {
          if (xhr.status == 200 || (xhr.status == 0 && xhr.response)) { // file URLs can return 0
            onload(xhr.response);
          } else {
            onerror();
          }
        };
        xhr.onerror = onerror;
        xhr.send(null);
      },asyncLoad:function (url, onload, onerror, noRunDep) {
        Browser.xhrLoad(url, function(arrayBuffer) {
          assert(arrayBuffer, 'Loading data file "' + url + '" failed (no arrayBuffer).');
          onload(new Uint8Array(arrayBuffer));
          if (!noRunDep) removeRunDependency('al ' + url);
        }, function(event) {
          if (onerror) {
            onerror();
          } else {
            throw 'Loading data file "' + url + '" failed.';
          }
        });
        if (!noRunDep) addRunDependency('al ' + url);
      },resizeListeners:[],updateResizeListeners:function () {
        var canvas = Module['canvas'];
        Browser.resizeListeners.forEach(function(listener) {
          listener(canvas.width, canvas.height);
        });
      },setCanvasSize:function (width, height, noUpdates) {
        var canvas = Module['canvas'];
        canvas.width = width;
        canvas.height = height;
        if (!noUpdates) Browser.updateResizeListeners();
      },windowedWidth:0,windowedHeight:0,setFullScreenCanvasSize:function () {
        var canvas = Module['canvas'];
        this.windowedWidth = canvas.width;
        this.windowedHeight = canvas.height;
        canvas.width = screen.width;
        canvas.height = screen.height;
        // check if SDL is available   
        if (typeof SDL != "undefined") {
        	var flags = HEAPU32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)];
        	flags = flags | 0x00800000; // set SDL_FULLSCREEN flag
        	HEAP32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)]=flags
        }
        Browser.updateResizeListeners();
      },setWindowedCanvasSize:function () {
        var canvas = Module['canvas'];
        canvas.width = this.windowedWidth;
        canvas.height = this.windowedHeight;
        // check if SDL is available       
        if (typeof SDL != "undefined") {
        	var flags = HEAPU32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)];
        	flags = flags & ~0x00800000; // clear SDL_FULLSCREEN flag
        	HEAP32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)]=flags
        }
        Browser.updateResizeListeners();
      }};var RI={temp:null,contexts:[],eventHandler:function (event) {
           var i;
           switch (event.type) {
              case 'mousemove':
                 var x = event['movementX'] || event['mozMovementX'] || event['webkitMovementX'];
                 var y = event['movementY'] || event['mozMovementY'] || event['webkitMovementY'];
                 for (i = 0; i < RI.contexts.length; i++) {
                    var oldX = HEAP32[(((RI.contexts[i].state)+(32))>>2)];
                    var oldY = HEAP32[(((RI.contexts[i].state)+(36))>>2)];
                    x += oldX;
                    y += oldY;
                    HEAP32[(((RI.contexts[i].state)+(32))>>2)]=x;
                    HEAP32[(((RI.contexts[i].state)+(36))>>2)]=y;
                 }
                 break;
              case 'mouseup':
              case 'mousedown':
                 var value;
                 var offset;
                 if (event.button === 0) offset = 40;
                 else if (event.button === 2) offset = 41;
                 else break;
                 if (event.type === 'mouseup') value = 0;
                 else value = 1;
                 for (i = 0; i < RI.contexts.length; i++) {
                    HEAP8[(((RI.contexts[i].state)+(offset))|0)]=value;
                 }
                 break;
              case 'keyup':
              case 'keydown':
                 var key = event.keyCode;
                 var offset = key >> 3;
                 var bit = 1 << (key & 7);
                 if (offset >= 32) throw 'key code error! bad code: ' + key;
                 for (i = 0; i < RI.contexts.length; i++) {
                    var value = HEAP8[(((RI.contexts[i].state)+(offset))|0)];
                    if (event.type === 'keyup') value &= ~bit;
                    else value |= bit;
                    HEAP8[(((RI.contexts[i].state)+(offset))|0)]=value;
                 }
                 event.preventDefault();
                 break;
              case 'blur':
              case 'visibilitychange':
                 for (i = 0; i < RI.contexts.length; i++) {
                    _memset(RI.contexts[i].state, 0, 42);
                 }
                 break;
           }
        }};function _RWebInputDestroy(context) {
        if (context === RI.contexts.length) {
           RI.contexts.pop();
           if (RI.contexts.length === 0) {
              document.removeEventListener('keyup', RI.eventHandler, false);
              document.removeEventListener('keydown', RI.eventHandler, false);
              document.removeEventListener('mousemove', RI.eventHandler, false);
              document.removeEventListener('mouseup', RI.eventHandler, false);
              document.removeEventListener('mousedown', RI.eventHandler, false);
              document.removeEventListener('blur', RI.eventHandler, false);
              document.removeEventListener('onvisbilitychange', RI.eventHandler, false);
           }
        }
     }
  function _RWebInputPoll(context) {
        context -= 1;
        var state = RI.contexts[context].state;
        _memcpy(RI.temp, state, 42);
        // reset mouse movements
        HEAP32[(((RI.contexts[context].state)+(32))>>2)]=0;
        HEAP32[(((RI.contexts[context].state)+(36))>>2)]=0;
        return RI.temp;
     }
  function _RWebInputInit(latency) {
        if (RI.contexts.length === 0) {
           document.addEventListener('keyup', RI.eventHandler, false);
           document.addEventListener('keydown', RI.eventHandler, false);
           document.addEventListener('mousemove', RI.eventHandler, false);
           document.addEventListener('mouseup', RI.eventHandler, false);
           document.addEventListener('mousedown', RI.eventHandler, false);
           document.addEventListener('blur', RI.eventHandler, false);
           document.addEventListener('onvisbilitychange', RI.eventHandler, false);
        }
        if (RI.temp === null) RI.temp = _malloc(42);
        var s = _malloc(42);
        _memset(s, 0, 42);
        RI.contexts.push({
           state: s
        });
        return RI.contexts.length;
     }
  function _strstr(ptr1, ptr2) {
      var check = 0, start;
      do {
        if (!check) {
          start = ptr1;
          check = ptr2;
        }
        var curr1 = HEAP8[((ptr1++)|0)];
        var curr2 = HEAP8[((check++)|0)];
        if (curr2 == 0) return start;
        if (curr2 != curr1) {
          // rewind to one character after start, to find ez in eeez
          ptr1 = start + 1;
          check = 0;
        }
      } while (curr1);
      return 0;
    }
  Module["_memmove"] = _memmove;var _llvm_memmove_p0i8_p0i8_i32=_memmove;
  Module["_memcmp"] = _memcmp;
  var RA={BUFFER_SIZE:256,context:null,buffers:[],numBuffers:0,bufIndex:0,bufOffset:0,startTime:0,nonblock:false,currentTimeWorkaround:false,setStartTime:function () {
           if (RA.context.currentTime) {
              RA.startTime = window['performance']['now']() - RA.context.currentTime * 1000;
              var time1 = RA.context.currentTime;
              _usleep(50);
              if (time1 === RA.context.currentTime) {
                 RA.currentTimeWorkaround = true;
                 if (RA.startTime === 0) throw 'startTime is 0';
              }
              Module["resumeMainLoop"]();
           } else window['setTimeout'](RA.setStartTime, 0);
        },getCurrentPerfTime:function () {
           if (!RA.currentTimeWorkaround) return RA.context.currentTime;
           else if (RA.startTime) return (window['performance']['now']() - RA.startTime) / 1000;
           else throw 'getCurrentPerfTime() called before start time set';
        },process:function (queueBuffers) {
           var currentTime = RA.getCurrentPerfTime();
           for (var i = 0; i < RA.bufIndex; i++) {
              if (RA.buffers[i].endTime < currentTime) {
                 var buf = RA.buffers.splice(i, 1);
                 RA.buffers[RA.numBuffers - 1] = buf[0];
                 i--;
                 RA.bufIndex--;
              }
           }
        },fillBuffer:function (buf, samples) {
           var count = 0;
           var leftBuffer = RA.buffers[RA.bufIndex].getChannelData(0);
           var rightBuffer = RA.buffers[RA.bufIndex].getChannelData(1);
           while (samples && RA.bufOffset !== RA.BUFFER_SIZE) {
              leftBuffer[RA.bufOffset] = HEAPF32[(((buf)+(count * 8))>>2)];
              rightBuffer[RA.bufOffset] = HEAPF32[(((buf)+(count * 8 + 4))>>2)];
              RA.bufOffset++;
              count++;
              samples--;
           }
           return count;
        },queueAudio:function () {
           var index = RA.bufIndex;
           var startTime;
           if (RA.bufIndex) startTime = RA.buffers[RA.bufIndex - 1].endTime;
           else startTime = RA.context.currentTime;
           RA.buffers[index].endTime = startTime + RA.buffers[index].duration;
           var bufferSource = RA.context.createBufferSource();
           bufferSource.buffer = RA.buffers[index];
           bufferSource.connect(RA.context.destination);
           bufferSource.start(startTime);
           RA.bufIndex++;
           RA.bufOffset = 0;
        },block:function () {
           do {
              RA.process();
           } while (RA.bufIndex === RA.numBuffers - 1);
        }};function _RWebAudioBufferSize() {
        return RA.numBuffers * RA.BUFFER_SIZE + RA.BUFFER_SIZE;
     }
  function _RWebAudioWriteAvail() {
        RA.process();
        return ((RA.numBuffers - RA.bufIndex) * RA.BUFFER_SIZE - RA.bufOffset) * 8;
     }
  function _RWebAudioFree() {
        RA.bufIndex = 0;
        RA.bufOffset = 0;
        return;
     }
  function _RWebAudioSetNonblockState(state) {
        RA.nonblock = state;
     }
  function _RWebAudioStart() {
        return true;
     }
  function _RWebAudioStop() {
        RA.bufIndex = 0;
        RA.bufOffset = 0;
        return true;
     }
  function _RWebAudioWrite(buf, size) {
        RA.process();
        var samples = size / 8;
        var count = 0;
        while (samples) {
           var fill = RA.fillBuffer(buf, samples);
           samples -= fill;
           count += fill;
           buf += fill * 8;
           if (RA.bufOffset === RA.BUFFER_SIZE) {
              if (RA.bufIndex === RA.numBuffers - 1) {
                 if (RA.nonblock) break;
                 else RA.block();
              }
              RA.queueAudio();
           }
        }
        return count * 8;
     }
  function _RWebAudioInit(latency) {
        var ac = window['AudioContext'] || window['webkitAudioContext'];
        if (!ac) return 0;
        RA.context = new ac();
        RA.numBuffers = ((latency * RA.context.sampleRate) / (1000 * RA.BUFFER_SIZE))|0;
        if (RA.numBuffers < 2) RA.numBuffers = 2;
        for (var i = 0; i < RA.numBuffers; i++) RA.buffers[i] = RA.context.createBuffer(2, RA.BUFFER_SIZE, RA.context.sampleRate);
        RA.nonblock = false;
        RA.startTime = 0;
        // chrome hack to get currentTime running
        RA.context.createGain();
        window['setTimeout'](RA.setStartTime, 0);
        Module["pauseMainLoop"]();
        return 1;
     }
  function _RWebAudioSampleRate() {
        return RA.context.sampleRate;
     }
  var _fabsf=Math.abs;
  var _sin=Math.sin;
  var _ceil=Math.ceil;
  function _emscripten_get_now() {
      if (!_emscripten_get_now.actual) {
        if (ENVIRONMENT_IS_NODE) {
            _emscripten_get_now.actual = function() {
              var t = process['hrtime']();
              return t[0] * 1e3 + t[1] / 1e6;
            }
        } else if (typeof dateNow !== 'undefined') {
          _emscripten_get_now.actual = dateNow;
        } else if (ENVIRONMENT_IS_WEB && window['performance'] && window['performance']['now']) {
          _emscripten_get_now.actual = function() { return window['performance']['now'](); };
        } else {
          _emscripten_get_now.actual = Date.now;
        }
      }
      return _emscripten_get_now.actual();
    }
  function _llvm_uadd_with_overflow_i32(x, y) {
      x = x>>>0;
      y = y>>>0;
      return ((asm["setTempRet0"](x+y > 4294967295),(x+y)>>>0)|0);
    }
  var GL={counter:1,buffers:[],programs:[],framebuffers:[],renderbuffers:[],textures:[],uniforms:[],shaders:[],currArrayBuffer:0,currElementArrayBuffer:0,byteSizeByTypeRoot:5120,byteSizeByType:[1,1,2,2,4,4,4,2,3,4,8],uniformTable:{},packAlignment:4,unpackAlignment:4,init:function () {
        Browser.moduleContextCreatedCallbacks.push(GL.initExtensions);
      },getNewId:function (table) {
        var ret = GL.counter++;
        for (var i = table.length; i < ret; i++) {
          table[i] = null;
        }
        return ret;
      },MINI_TEMP_BUFFER_SIZE:16,miniTempBuffer:null,miniTempBufferViews:[0],MAX_TEMP_BUFFER_SIZE:2097152,tempBufferIndexLookup:null,tempVertexBuffers:null,tempIndexBuffers:null,tempQuadIndexBuffer:null,generateTempBuffers:function (quads) {
        GL.tempBufferIndexLookup = new Uint8Array(GL.MAX_TEMP_BUFFER_SIZE+1);
        GL.tempVertexBuffers = [];
        GL.tempIndexBuffers = [];
        var last = -1, curr = -1;
        var size = 1;
        for (var i = 0; i <= GL.MAX_TEMP_BUFFER_SIZE; i++) {
          if (i > size) {
            size <<= 1;
          }
          if (size != last) {
            curr++;
            GL.tempVertexBuffers[curr] = Module.ctx.createBuffer();
            Module.ctx.bindBuffer(Module.ctx.ARRAY_BUFFER, GL.tempVertexBuffers[curr]);
            Module.ctx.bufferData(Module.ctx.ARRAY_BUFFER, size, Module.ctx.DYNAMIC_DRAW);
            Module.ctx.bindBuffer(Module.ctx.ARRAY_BUFFER, null);
            GL.tempIndexBuffers[curr] = Module.ctx.createBuffer();
            Module.ctx.bindBuffer(Module.ctx.ELEMENT_ARRAY_BUFFER, GL.tempIndexBuffers[curr]);
            Module.ctx.bufferData(Module.ctx.ELEMENT_ARRAY_BUFFER, size, Module.ctx.DYNAMIC_DRAW);
            Module.ctx.bindBuffer(Module.ctx.ELEMENT_ARRAY_BUFFER, null);
            last = size;
          }
          GL.tempBufferIndexLookup[i] = curr;
        }
        if (quads) {
          // GL_QUAD indexes can be precalculated
          GL.tempQuadIndexBuffer = Module.ctx.createBuffer();
          Module.ctx.bindBuffer(Module.ctx.ELEMENT_ARRAY_BUFFER, GL.tempQuadIndexBuffer);
          var numIndexes = GL.MAX_TEMP_BUFFER_SIZE >> 1;
          var quadIndexes = new Uint16Array(numIndexes);
          var i = 0, v = 0;
          while (1) {
            quadIndexes[i++] = v;
            if (i >= numIndexes) break;
            quadIndexes[i++] = v+1;
            if (i >= numIndexes) break;
            quadIndexes[i++] = v+2;
            if (i >= numIndexes) break;
            quadIndexes[i++] = v;
            if (i >= numIndexes) break;
            quadIndexes[i++] = v+2;
            if (i >= numIndexes) break;
            quadIndexes[i++] = v+3;
            if (i >= numIndexes) break;
            v += 4;
          }
          Module.ctx.bufferData(Module.ctx.ELEMENT_ARRAY_BUFFER, quadIndexes, Module.ctx.STATIC_DRAW);
          Module.ctx.bindBuffer(Module.ctx.ELEMENT_ARRAY_BUFFER, null);
        }
      },findToken:function (source, token) {
        function isIdentChar(ch) {
          if (ch >= 48 && ch <= 57) // 0-9
            return true;
          if (ch >= 65 && ch <= 90) // A-Z
            return true;
          if (ch >= 97 && ch <= 122) // a-z
            return true;
          return false;
        }
        var i = -1;
        do {
          i = source.indexOf(token, i + 1);
          if (i < 0) {
            break;
          }
          if (i > 0 && isIdentChar(source[i - 1])) {
            continue;
          }
          i += token.length;
          if (i < source.length - 1 && isIdentChar(source[i + 1])) {
            continue;
          }
          return true;
        } while (true);
        return false;
      },getSource:function (shader, count, string, length) {
        var source = '';
        for (var i = 0; i < count; ++i) {
          var frag;
          if (length) {
            var len = HEAP32[(((length)+(i*4))>>2)];
            if (len < 0) {
              frag = Pointer_stringify(HEAP32[(((string)+(i*4))>>2)]);
            } else {
              frag = Pointer_stringify(HEAP32[(((string)+(i*4))>>2)], len);
            }
          } else {
            frag = Pointer_stringify(HEAP32[(((string)+(i*4))>>2)]);
          }
          source += frag;
        }
        // Let's see if we need to enable the standard derivatives extension
        type = Module.ctx.getShaderParameter(GL.shaders[shader], 0x8B4F /* GL_SHADER_TYPE */);
        if (type == 0x8B30 /* GL_FRAGMENT_SHADER */) {
          if (GL.findToken(source, "dFdx") ||
              GL.findToken(source, "dFdy") ||
              GL.findToken(source, "fwidth")) {
            source = "#extension GL_OES_standard_derivatives : enable\n" + source;
            var extension = Module.ctx.getExtension("OES_standard_derivatives");
          }
        }
        return source;
      },computeImageSize:function (width, height, sizePerPixel, alignment) {
        function roundedToNextMultipleOf(x, y) {
          return Math.floor((x + y - 1) / y) * y
        }
        var plainRowSize = width * sizePerPixel;
        var alignedRowSize = roundedToNextMultipleOf(plainRowSize, alignment);
        return (height <= 0) ? 0 :
                 ((height - 1) * alignedRowSize + plainRowSize);
      },getTexPixelData:function (type, format, width, height, pixels, internalFormat) {
        var sizePerPixel;
        switch (type) {
          case 0x1401 /* GL_UNSIGNED_BYTE */:
            switch (format) {
              case 0x1906 /* GL_ALPHA */:
              case 0x1909 /* GL_LUMINANCE */:
                sizePerPixel = 1;
                break;
              case 0x1907 /* GL_RGB */:
                sizePerPixel = 3;
                break;
              case 0x1908 /* GL_RGBA */:
                sizePerPixel = 4;
                break;
              case 0x190A /* GL_LUMINANCE_ALPHA */:
                sizePerPixel = 2;
                break;
              default:
                throw 'Invalid format (' + format + ')';
            }
            break;
          case 0x8363 /* GL_UNSIGNED_SHORT_5_6_5 */:
          case 0x8033 /* GL_UNSIGNED_SHORT_4_4_4_4 */:
          case 0x8034 /* GL_UNSIGNED_SHORT_5_5_5_1 */:
            sizePerPixel = 2;
            break;
          case 0x1406 /* GL_FLOAT */:
            assert(GL.floatExt, 'Must have OES_texture_float to use float textures');
            switch (format) {
              case 0x1907 /* GL_RGB */:
                sizePerPixel = 3*4;
                break;
              case 0x1908 /* GL_RGBA */:
                sizePerPixel = 4*4;
                break;
              default:
                throw 'Invalid format (' + format + ')';
            }
            internalFormat = Module.ctx.RGBA;
            break;
          default:
            throw 'Invalid type (' + type + ')';
        }
        var bytes = GL.computeImageSize(width, height, sizePerPixel, GL.unpackAlignment);
        if (type == 0x1401 /* GL_UNSIGNED_BYTE */) {
          pixels = HEAPU8.subarray((pixels),(pixels+bytes));
        } else if (type == 0x1406 /* GL_FLOAT */) {
          pixels = HEAPF32.subarray((pixels)>>2,(pixels+bytes)>>2);
        } else {
          pixels = HEAPU16.subarray((pixels)>>1,(pixels+bytes)>>1);
        }
        return {
          pixels: pixels,
          internalFormat: internalFormat
        }
      },initExtensions:function () {
        if (GL.initExtensions.done) return;
        GL.initExtensions.done = true;
        if (!Module.useWebGL) return; // an app might link both gl and 2d backends
        GL.miniTempBuffer = new Float32Array(GL.MINI_TEMP_BUFFER_SIZE);
        for (var i = 0; i < GL.MINI_TEMP_BUFFER_SIZE; i++) {
          GL.miniTempBufferViews[i] = GL.miniTempBuffer.subarray(0, i+1);
        }
        GL.maxVertexAttribs = Module.ctx.getParameter(Module.ctx.MAX_VERTEX_ATTRIBS);
        GL.compressionExt = Module.ctx.getExtension('WEBGL_compressed_texture_s3tc') ||
                            Module.ctx.getExtension('MOZ_WEBGL_compressed_texture_s3tc') ||
                            Module.ctx.getExtension('WEBKIT_WEBGL_compressed_texture_s3tc');
        GL.anisotropicExt = Module.ctx.getExtension('EXT_texture_filter_anisotropic') ||
                            Module.ctx.getExtension('MOZ_EXT_texture_filter_anisotropic') ||
                            Module.ctx.getExtension('WEBKIT_EXT_texture_filter_anisotropic');
        GL.floatExt = Module.ctx.getExtension('OES_texture_float');
        GL.elementIndexUintExt = Module.ctx.getExtension('OES_element_index_uint');
        GL.standardDerivativesExt = Module.ctx.getExtension('OES_standard_derivatives');
      }};function _glDeleteTextures(n, textures) {
      for (var i = 0; i < n; i++) {
        var id = HEAP32[(((textures)+(i*4))>>2)];
        var texture = GL.textures[id];
        Module.ctx.deleteTexture(texture);
        texture.name = 0;
        GL.textures[id] = null;
      }
    }
  function _glDeleteFramebuffers(n, framebuffers) {
      for (var i = 0; i < n; ++i) {
        var id = HEAP32[(((framebuffers)+(i*4))>>2)];
        var framebuffer = GL.framebuffers[id];
        Module.ctx.deleteFramebuffer(framebuffer);
        framebuffer.name = 0;
        GL.framebuffers[id] = null;
      }
    }
  function _glViewport(x0, x1, x2, x3) { Module.ctx.viewport(x0, x1, x2, x3) }
  function _glGenTextures(n, textures) {
      for (var i = 0; i < n; i++) {
        var id = GL.getNewId(GL.textures);
        var texture = Module.ctx.createTexture();
        texture.name = id;
        GL.textures[id] = texture;
        HEAP32[(((textures)+(i*4))>>2)]=id;
      }
    }
  function _glBindTexture(target, texture) {
      Module.ctx.bindTexture(target, texture ? GL.textures[texture] : null);
    }
  function _glTexParameteri(x0, x1, x2) { Module.ctx.texParameteri(x0, x1, x2) }
  function _glPixelStorei(pname, param) {
      if (pname == 0x0D05 /* GL_PACK_ALIGNMENT */) {
        GL.packAlignment = param;
      } else if (pname == 0x0cf5 /* GL_UNPACK_ALIGNMENT */) {
        GL.unpackAlignment = param;
      }
      Module.ctx.pixelStorei(pname, param);
    }
  function _glTexImage2D(target, level, internalFormat, width, height, border, format, type, pixels) {
      if (pixels) {
        var data = GL.getTexPixelData(type, format, width, height, pixels, internalFormat);
        pixels = data.pixels;
        internalFormat = data.internalFormat;
      } else {
        pixels = null;
      }
      Module.ctx.texImage2D(target, level, internalFormat, width, height, border, format, type, pixels);
    }
  function _glReadPixels(x, y, width, height, format, type, pixels) {
      assert(type == 0x1401 /* GL_UNSIGNED_BYTE */);
      var sizePerPixel;
      switch (format) {
        case 0x1907 /* GL_RGB */:
          sizePerPixel = 3;
          break;
        case 0x1908 /* GL_RGBA */:
          sizePerPixel = 4;
          break;
        default: throw 'unsupported glReadPixels format';
      }
      var totalSize = width*height*sizePerPixel;
      Module.ctx.readPixels(x, y, width, height, format, type, HEAPU8.subarray(pixels, pixels + totalSize));
    }
  function _glDeleteRenderbuffers(n, renderbuffers) {
      for (var i = 0; i < n; i++) {
        var id = HEAP32[(((renderbuffers)+(i*4))>>2)];
        var renderbuffer = GL.renderbuffers[id];
        Module.ctx.deleteRenderbuffer(renderbuffer);
        renderbuffer.name = 0;
        GL.renderbuffers[id] = null;
      }
    }
  function _glGetIntegerv(name_, p) {
      switch(name_) { // Handle a few trivial GLES values
        case 0x8DFA: // GL_SHADER_COMPILER
          HEAP32[((p)>>2)]=1;
          return;
        case 0x8DF9: // GL_NUM_SHADER_BINARY_FORMATS
          HEAP32[((p)>>2)]=0;
          return;
        case 0x86A2: // GL_NUM_COMPRESSED_TEXTURE_FORMATS
          // WebGL doesn't have GL_NUM_COMPRESSED_TEXTURE_FORMATS (it's obsolete since GL_COMPRESSED_TEXTURE_FORMATS returns a JS array that can be queried for length),
          // so implement it ourselves to allow C++ GLES2 code get the length.
          var formats = Module.ctx.getParameter(0x86A3 /*GL_COMPRESSED_TEXTURE_FORMATS*/);
          HEAP32[((p)>>2)]=formats.length;
          return;
      }
      var result = Module.ctx.getParameter(name_);
      switch (typeof(result)) {
        case "number":
          HEAP32[((p)>>2)]=result;
          break;
        case "boolean":
          HEAP8[(p)]=result ? 1 : 0;
          break;
        case "string":
          throw 'Native code calling glGetIntegerv(' + name_ + ') on a name which returns a string!';
        case "object":
          if (result === null) {
            HEAP32[((p)>>2)]=0;
          } else if (result instanceof Float32Array ||
                     result instanceof Uint32Array ||
                     result instanceof Int32Array ||
                     result instanceof Array) {
            for (var i = 0; i < result.length; ++i) {
              HEAP32[(((p)+(i*4))>>2)]=result[i];
            }
          } else if (result instanceof WebGLBuffer) {
            HEAP32[((p)>>2)]=result.name | 0;
          } else if (result instanceof WebGLProgram) {
            HEAP32[((p)>>2)]=result.name | 0;
          } else if (result instanceof WebGLFramebuffer) {
            HEAP32[((p)>>2)]=result.name | 0;
          } else if (result instanceof WebGLRenderbuffer) {
            HEAP32[((p)>>2)]=result.name | 0;
          } else if (result instanceof WebGLTexture) {
            HEAP32[((p)>>2)]=result.name | 0;
          } else {
            throw 'Unknown object returned from WebGL getParameter';
          }
          break;
        case "undefined":
          throw 'Native code calling glGetIntegerv(' + name_ + ') and it returns undefined';
        default:
          throw 'Why did we hit the default case?';
      }
    }
  function _glGenFramebuffers(n, ids) {
      for (var i = 0; i < n; ++i) {
        var id = GL.getNewId(GL.framebuffers);
        var framebuffer = Module.ctx.createFramebuffer();
        framebuffer.name = id;
        GL.framebuffers[id] = framebuffer;
        HEAP32[(((ids)+(i*4))>>2)]=id;
      }
    }
  function _glGenRenderbuffers(n, renderbuffers) {
      for (var i = 0; i < n; i++) {
        var id = GL.getNewId(GL.renderbuffers);
        var renderbuffer = Module.ctx.createRenderbuffer();
        renderbuffer.name = id;
        GL.renderbuffers[id] = renderbuffer;
        HEAP32[(((renderbuffers)+(i*4))>>2)]=id;
      }
    }
  function _glBindFramebuffer(target, framebuffer) {
      Module.ctx.bindFramebuffer(target, framebuffer ? GL.framebuffers[framebuffer] : null);
    }
  function _glFramebufferTexture2D(target, attachment, textarget, texture, level) {
      Module.ctx.framebufferTexture2D(target, attachment, textarget,
                                      GL.textures[texture], level);
    }
  function _glBindRenderbuffer(target, renderbuffer) {
      Module.ctx.bindRenderbuffer(target, renderbuffer ? GL.renderbuffers[renderbuffer] : null);
    }
  function _glRenderbufferStorage(x0, x1, x2, x3) { Module.ctx.renderbufferStorage(x0, x1, x2, x3) }
  function _glFramebufferRenderbuffer(target, attachment, renderbuffertarget, renderbuffer) {
      Module.ctx.framebufferRenderbuffer(target, attachment, renderbuffertarget,
                                         GL.renderbuffers[renderbuffer]);
    }
  function _glCheckFramebufferStatus(x0) { return Module.ctx.checkFramebufferStatus(x0) }
  function _glGetString(name_) {
      switch(name_) {
        case 0x1F00 /* GL_VENDOR */:
        case 0x1F01 /* GL_RENDERER */:
        case 0x1F02 /* GL_VERSION */:
          return allocate(intArrayFromString(Module.ctx.getParameter(name_)), 'i8', ALLOC_NORMAL);
        case 0x1F03 /* GL_EXTENSIONS */:
          return allocate(intArrayFromString(Module.ctx.getSupportedExtensions().join(' ')), 'i8', ALLOC_NORMAL);
        case 0x8B8C /* GL_SHADING_LANGUAGE_VERSION */:
          return allocate(intArrayFromString('OpenGL ES GLSL 1.00 (WebGL)'), 'i8', ALLOC_NORMAL);
        default:
          throw 'Failure: Invalid glGetString value: ' + name_;
      }
    }
  function _glDisable(x0) { Module.ctx.disable(x0) }
  function _glBlendFunc(x0, x1) { Module.ctx.blendFunc(x0, x1) }
  function _glClearColor(x0, x1, x2, x3) { Module.ctx.clearColor(x0, x1, x2, x3) }
  function _glClear(x0) { Module.ctx.clear(x0) }
  function _glDrawArrays(mode, first, count) {
      Module.ctx.drawArrays(mode, first, count);
    }
  function _glEnable(x0) { Module.ctx.enable(x0) }
  function _glTexSubImage2D(target, level, xoffset, yoffset, width, height, format, type, pixels) {
      if (pixels) {
        var data = GL.getTexPixelData(type, format, width, height, pixels, -1);
        pixels = data.pixels;
      } else {
        pixels = null;
      }
      Module.ctx.texSubImage2D(target, level, xoffset, yoffset, width, height, format, type, pixels);
    }
  function _glGetError() { return Module.ctx.getError() }
  var _cosf=Math.cos;
  var _sinf=Math.sin;
  function _glGetFloatv(name_, p) {
      var result = Module.ctx.getParameter(name_);
      switch (typeof(result)) {
        case "number":
          HEAPF32[((p)>>2)]=result;
          break;
        case "boolean":
          HEAPF32[((p)>>2)]=result ? 1.0 : 0.0;
          break;
        case "string":
            HEAPF32[((p)>>2)]=0;
        case "object":
          if (result === null) {
            throw 'Native code calling glGetFloatv(' + name_ + ') and it returns null';
          } else if (result instanceof Float32Array ||
                     result instanceof Uint32Array ||
                     result instanceof Int32Array ||
                     result instanceof Array) {
            for (var i = 0; i < result.length; ++i) {
              HEAPF32[(((p)+(i*4))>>2)]=result[i];
            }
          } else if (result instanceof WebGLBuffer) {
            HEAPF32[((p)>>2)]=result.name | 0;
          } else if (result instanceof WebGLProgram) {
            HEAPF32[((p)>>2)]=result.name | 0;
          } else if (result instanceof WebGLFramebuffer) {
            HEAPF32[((p)>>2)]=result.name | 0;
          } else if (result instanceof WebGLRenderbuffer) {
            HEAPF32[((p)>>2)]=result.name | 0;
          } else if (result instanceof WebGLTexture) {
            HEAPF32[((p)>>2)]=result.name | 0;
          } else {
            throw 'Unknown object returned from WebGL getParameter';
          }
          break;
        case "undefined":
          throw 'Native code calling glGetFloatv(' + name_ + ') and it returns undefined';
        default:
          throw 'Why did we hit the default case?';
      }
    }
  function _glGetBooleanv(name_, p) {
      var result = Module.ctx.getParameter(name_);
      switch (typeof(result)) {
        case "number":
          HEAP8[(p)]=result != 0;
          break;
        case "boolean":
          HEAP8[(p)]=result != 0;
          break;
        case "string":
          throw 'Native code calling glGetBooleanv(' + name_ + ') on a name which returns a string!';
        case "object":
          if (result === null) {
            HEAP8[(p)]=0;
          } else if (result instanceof Float32Array ||
                     result instanceof Uint32Array ||
                     result instanceof Int32Array ||
                     result instanceof Array) {
            for (var i = 0; i < result.length; ++i) {
              HEAP8[(((p)+(i))|0)]=result[i] != 0;
            }
          } else if (result instanceof WebGLBuffer ||
                     result instanceof WebGLProgram ||
                     result instanceof WebGLFramebuffer ||
                     result instanceof WebGLRenderbuffer ||
                     result instanceof WebGLTexture) {
            HEAP8[(p)]=1; // non-zero ID is always 1!
          } else {
            throw 'Unknown object returned from WebGL getParameter';
          }
          break;
        case "undefined":
            throw 'Unknown object returned from WebGL getParameter';
        default:
          throw 'Why did we hit the default case?';
      }
    }
  function _glCompressedTexImage2D(target, level, internalFormat, width, height, border, imageSize, data) {
      assert(GL.compressionExt);
      if (data) {
        data = HEAPU8.subarray((data),(data+imageSize));
      } else {
        data = null;
      }
      Module.ctx['compressedTexImage2D'](target, level, internalFormat, width, height, border, data);
    }
  function _glCompressedTexSubImage2D(target, level, xoffset, yoffset, width, height, format, imageSize, data) {
      assert(GL.compressionExt);
      if (data) {
        data = HEAPU8.subarray((data),(data+imageSize));
      } else {
        data = null;
      }
      Module.ctx['compressedTexSubImage2D'](target, level, xoffset, yoffset, width, height, data);
    }
  function _glGetTexParameterfv(target, pname, params) {
      HEAPF32[((params)>>2)]=Module.getTexParameter(target, pname);
    }
  function _glGetTexParameteriv(target, pname, params) {
      HEAP32[((params)>>2)]=Module.getTexParameter(target, pname);
    }
  function _glTexParameterfv(target, pname, params) {
      var param = HEAPF32[((params)>>2)];
      Module.ctx.texParameterf(target, pname, param);
    }
  function _glTexParameteriv(target, pname, params) {
      var param = HEAP32[((params)>>2)];
      Module.ctx.texParameteri(target, pname, param);
    }
  function _glIsTexture(texture) {
      var texture = GL.textures[texture];
      if (!texture) return 0;
      return Module.ctx.isTexture(texture);
    }
  function _glGenBuffers(n, buffers) {
      for (var i = 0; i < n; i++) {
        var id = GL.getNewId(GL.buffers);
        var buffer = Module.ctx.createBuffer();
        buffer.name = id;
        GL.buffers[id] = buffer;
        HEAP32[(((buffers)+(i*4))>>2)]=id;
      }
    }
  function _glDeleteBuffers(n, buffers) {
      for (var i = 0; i < n; i++) {
        var id = HEAP32[(((buffers)+(i*4))>>2)];
        var buffer = GL.buffers[id];
        // From spec: "glDeleteBuffers silently ignores 0's and names that do not
        // correspond to existing buffer objects."
        if (!buffer) continue;
        Module.ctx.deleteBuffer(buffer);
        buffer.name = 0;
        GL.buffers[id] = null;
        if (id == GL.currArrayBuffer) GL.currArrayBuffer = 0;
        if (id == GL.currElementArrayBuffer) GL.currElementArrayBuffer = 0;
      }
    }
  function _glGetBufferParameteriv(target, value, data) {
      HEAP32[((data)>>2)]=Module.ctx.getBufferParameter(target, value);
    }
  function _glBufferData(target, size, data, usage) {
      switch (usage) { // fix usages, WebGL only has *_DRAW
        case 0x88E1: // GL_STREAM_READ
        case 0x88E2: // GL_STREAM_COPY
          usage = 0x88E0; // GL_STREAM_DRAW
          break;
        case 0x88E5: // GL_STATIC_READ
        case 0x88E6: // GL_STATIC_COPY
          usage = 0x88E4; // GL_STATIC_DRAW
          break;
        case 0x88E9: // GL_DYNAMIC_READ
        case 0x88EA: // GL_DYNAMIC_COPY
          usage = 0x88E8; // GL_DYNAMIC_DRAW
          break;
      }
      Module.ctx.bufferData(target, HEAPU8.subarray(data, data+size), usage);
    }
  function _glBufferSubData(target, offset, size, data) {
      Module.ctx.bufferSubData(target, offset, HEAPU8.subarray(data, data+size));
    }
  function _glIsBuffer(buffer) {
      var b = GL.buffers[buffer];
      if (!b) return 0;
      return Module.ctx.isBuffer(b);
    }
  function _glGetRenderbufferParameteriv(target, pname, params) {
      HEAP32[((params)>>2)]=Module.ctx.getRenderbufferParameter(target, pname);
    }
  function _glIsRenderbuffer(renderbuffer) {
      var rb = GL.renderbuffers[renderbuffer];
      if (!rb) return 0;
      return Module.ctx.isRenderbuffer(rb);
    }
  function _glGetUniformfv(program, location, params) {
      var data = Module.ctx.getUniform(GL.programs[program], GL.uniforms[location]);
      if (typeof data == 'number') {
        HEAPF32[((params)>>2)]=data;
      } else {
        for (var i = 0; i < data.length; i++) {
          HEAPF32[(((params)+(i))>>2)]=data[i];
        }
      }
    }
  function _glGetUniformiv(program, location, params) {
      var data = Module.ctx.getUniform(GL.programs[program], GL.uniforms[location]);
      if (typeof data == 'number' || typeof data == 'boolean') {
        HEAP32[((params)>>2)]=data;
      } else {
        for (var i = 0; i < data.length; i++) {
          HEAP32[(((params)+(i))>>2)]=data[i];
        }
      }
    }
  function _glGetUniformLocation(program, name) {
      name = Pointer_stringify(name);
      var ptable = GL.uniformTable[program];
      if (!ptable) ptable = GL.uniformTable[program] = {};
      var id = ptable[name];
      if (id) return id;
      var loc = Module.ctx.getUniformLocation(GL.programs[program], name);
      if (!loc) return -1;
      id = GL.getNewId(GL.uniforms);
      GL.uniforms[id] = loc;
      ptable[name] = id;
      return id;
    }
  function _glGetVertexAttribfv(index, pname, params) {
      var data = Module.ctx.getVertexAttrib(index, pname);
      if (typeof data == 'number') {
        HEAPF32[((params)>>2)]=data;
      } else {
        for (var i = 0; i < data.length; i++) {
          HEAPF32[(((params)+(i))>>2)]=data[i];
        }
      }
    }
  function _glGetVertexAttribiv(index, pname, params) {
      var data = Module.ctx.getVertexAttrib(index, pname);
      if (typeof data == 'number' || typeof data == 'boolean') {
        HEAP32[((params)>>2)]=data;
      } else {
        for (var i = 0; i < data.length; i++) {
          HEAP32[(((params)+(i))>>2)]=data[i];
        }
      }
    }
  function _glGetVertexAttribPointerv(index, pname, pointer) {
      HEAP32[((pointer)>>2)]=Module.ctx.getVertexAttribOffset(index, pname);
    }
  function _glGetActiveUniform(program, index, bufSize, length, size, type, name) {
      program = GL.programs[program];
      var info = Module.ctx.getActiveUniform(program, index);
      var infoname = info.name.slice(0, Math.max(0, bufSize - 1));
      writeStringToMemory(infoname, name);
      if (length) {
        HEAP32[((length)>>2)]=infoname.length;
      }
      if (size) {
        HEAP32[((size)>>2)]=info.size;
      }
      if (type) {
        HEAP32[((type)>>2)]=info.type;
      }
    }
  function _glUniform1f(location, v0) {
      location = GL.uniforms[location];
      Module.ctx.uniform1f(location, v0);
    }
  function _glUniform2f(location, v0, v1) {
      location = GL.uniforms[location];
      Module.ctx.uniform2f(location, v0, v1);
    }
  function _glUniform3f(location, v0, v1, v2) {
      location = GL.uniforms[location];
      Module.ctx.uniform3f(location, v0, v1, v2);
    }
  function _glUniform4f(location, v0, v1, v2, v3) {
      location = GL.uniforms[location];
      Module.ctx.uniform4f(location, v0, v1, v2, v3);
    }
  function _glUniform1i(location, v0) {
      location = GL.uniforms[location];
      Module.ctx.uniform1i(location, v0);
    }
  function _glUniform2i(location, v0, v1) {
      location = GL.uniforms[location];
      Module.ctx.uniform2i(location, v0, v1);
    }
  function _glUniform3i(location, v0, v1, v2) {
      location = GL.uniforms[location];
      Module.ctx.uniform3i(location, v0, v1, v2);
    }
  function _glUniform4i(location, v0, v1, v2, v3) {
      location = GL.uniforms[location];
      Module.ctx.uniform4i(location, v0, v1, v2, v3);
    }
  function _glUniform1iv(location, count, value) {
      location = GL.uniforms[location];
      value = HEAP32.subarray((value)>>2,(value+count*4)>>2);
      Module.ctx.uniform1iv(location, value);
    }
  function _glUniform2iv(location, count, value) {
      location = GL.uniforms[location];
      count *= 2;
      value = HEAP32.subarray((value)>>2,(value+count*4)>>2);
      Module.ctx.uniform2iv(location, value);
    }
  function _glUniform3iv(location, count, value) {
      location = GL.uniforms[location];
      count *= 3;
      value = HEAP32.subarray((value)>>2,(value+count*4)>>2);
      Module.ctx.uniform3iv(location, value);
    }
  function _glUniform4iv(location, count, value) {
      location = GL.uniforms[location];
      count *= 4;
      value = HEAP32.subarray((value)>>2,(value+count*4)>>2);
      Module.ctx.uniform4iv(location, value);
    }
  function _glUniform1fv(location, count, value) {
      location = GL.uniforms[location];
      var view;
      if (count == 1) {
        // avoid allocation for the common case of uploading one uniform
        view = GL.miniTempBufferViews[0];
        view[0] = HEAPF32[((value)>>2)];
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*4)>>2);
      }
      Module.ctx.uniform1fv(location, view);
    }
  function _glUniform2fv(location, count, value) {
      location = GL.uniforms[location];
      var view;
      if (count == 1) {
        // avoid allocation for the common case of uploading one uniform
        view = GL.miniTempBufferViews[1];
        view[0] = HEAPF32[((value)>>2)];
        view[1] = HEAPF32[(((value)+(4))>>2)];
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*8)>>2);
      }
      Module.ctx.uniform2fv(location, view);
    }
  function _glUniform3fv(location, count, value) {
      location = GL.uniforms[location];
      var view;
      if (count == 1) {
        // avoid allocation for the common case of uploading one uniform
        view = GL.miniTempBufferViews[2];
        view[0] = HEAPF32[((value)>>2)];
        view[1] = HEAPF32[(((value)+(4))>>2)];
        view[2] = HEAPF32[(((value)+(8))>>2)];
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*12)>>2);
      }
      Module.ctx.uniform3fv(location, view);
    }
  function _glUniform4fv(location, count, value) {
      location = GL.uniforms[location];
      var view;
      if (count == 1) {
        // avoid allocation for the common case of uploading one uniform
        view = GL.miniTempBufferViews[3];
        view[0] = HEAPF32[((value)>>2)];
        view[1] = HEAPF32[(((value)+(4))>>2)];
        view[2] = HEAPF32[(((value)+(8))>>2)];
        view[3] = HEAPF32[(((value)+(12))>>2)];
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*16)>>2);
      }
      Module.ctx.uniform4fv(location, view);
    }
  function _glUniformMatrix2fv(location, count, transpose, value) {
      location = GL.uniforms[location];
      var view;
      if (count == 1) {
        // avoid allocation for the common case of uploading one uniform matrix
        view = GL.miniTempBufferViews[3];
        for (var i = 0; i < 4; i++) {
          view[i] = HEAPF32[(((value)+(i*4))>>2)];
        }
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*16)>>2);
      }
      Module.ctx.uniformMatrix2fv(location, transpose, view);
    }
  function _glUniformMatrix3fv(location, count, transpose, value) {
      location = GL.uniforms[location];
      var view;
      if (count == 1) {
        // avoid allocation for the common case of uploading one uniform matrix
        view = GL.miniTempBufferViews[8];
        for (var i = 0; i < 9; i++) {
          view[i] = HEAPF32[(((value)+(i*4))>>2)];
        }
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*36)>>2);
      }
      Module.ctx.uniformMatrix3fv(location, transpose, view);
    }
  function _glUniformMatrix4fv(location, count, transpose, value) {
      location = GL.uniforms[location];
      var view;
      if (count == 1) {
        // avoid allocation for the common case of uploading one uniform matrix
        view = GL.miniTempBufferViews[15];
        for (var i = 0; i < 16; i++) {
          view[i] = HEAPF32[(((value)+(i*4))>>2)];
        }
      } else {
        view = HEAPF32.subarray((value)>>2,(value+count*64)>>2);
      }
      Module.ctx.uniformMatrix4fv(location, transpose, view);
    }
  function _glBindBuffer(target, buffer) {
      var bufferObj = buffer ? GL.buffers[buffer] : null;
      if (target == Module.ctx.ARRAY_BUFFER) {
        GL.currArrayBuffer = buffer;
      } else if (target == Module.ctx.ELEMENT_ARRAY_BUFFER) {
        GL.currElementArrayBuffer = buffer;
      }
      Module.ctx.bindBuffer(target, bufferObj);
    }
  function _glVertexAttrib1fv(index, v) {
      v = HEAPF32.subarray((v)>>2,(v+4)>>2);
      Module.ctx.vertexAttrib1fv(index, v);
    }
  function _glVertexAttrib2fv(index, v) {
      v = HEAPF32.subarray((v)>>2,(v+8)>>2);
      Module.ctx.vertexAttrib2fv(index, v);
    }
  function _glVertexAttrib3fv(index, v) {
      v = HEAPF32.subarray((v)>>2,(v+12)>>2);
      Module.ctx.vertexAttrib3fv(index, v);
    }
  function _glVertexAttrib4fv(index, v) {
      v = HEAPF32.subarray((v)>>2,(v+16)>>2);
      Module.ctx.vertexAttrib4fv(index, v);
    }
  function _glGetAttribLocation(program, name) {
      program = GL.programs[program];
      name = Pointer_stringify(name);
      return Module.ctx.getAttribLocation(program, name);
    }
  function _glGetActiveAttrib(program, index, bufSize, length, size, type, name) {
      program = GL.programs[program];
      var info = Module.ctx.getActiveAttrib(program, index);
      var infoname = info.name.slice(0, Math.max(0, bufSize - 1));
      writeStringToMemory(infoname, name);
      if (length) {
        HEAP32[((length)>>2)]=infoname.length;
      }
      if (size) {
        HEAP32[((size)>>2)]=info.size;
      }
      if (type) {
        HEAP32[((type)>>2)]=info.type;
      }
    }
  function _glCreateShader(shaderType) {
      var id = GL.getNewId(GL.shaders);
      GL.shaders[id] = Module.ctx.createShader(shaderType);
      return id;
    }
  function _glDeleteShader(shader) {
      Module.ctx.deleteShader(GL.shaders[shader]);
      GL.shaders[shader] = null;
    }
  function _glGetAttachedShaders(program, maxCount, count, shaders) {
      var result = Module.ctx.getAttachedShaders(GL.programs[program]);
      var len = result.length;
      if (len > maxCount) {
        len = maxCount;
      }
      HEAP32[((count)>>2)]=len;
      for (var i = 0; i < len; ++i) {
        var id = GL.shaders.indexOf(result[i]);
        assert(id !== -1, 'shader not bound to local id');
        HEAP32[(((shaders)+(i*4))>>2)]=id;
      }
    }
  function _glShaderSource(shader, count, string, length) {
      var source = GL.getSource(shader, count, string, length);
      Module.ctx.shaderSource(GL.shaders[shader], source);
    }
  function _glGetShaderSource(shader, bufSize, length, source) {
      var result = Module.ctx.getShaderSource(GL.shaders[shader]);
      result = result.slice(0, Math.max(0, bufSize - 1));
      writeStringToMemory(result, source);
      if (length) {
        HEAP32[((length)>>2)]=result.length;
      }
    }
  function _glCompileShader(shader) {
      Module.ctx.compileShader(GL.shaders[shader]);
    }
  function _glGetShaderInfoLog(shader, maxLength, length, infoLog) {
      var log = Module.ctx.getShaderInfoLog(GL.shaders[shader]);
      // Work around a bug in Chromium which causes getShaderInfoLog to return null
      if (!log) {
        log = "";
      }
      log = log.substr(0, maxLength - 1);
      writeStringToMemory(log, infoLog);
      if (length) {
        HEAP32[((length)>>2)]=log.length
      }
    }
  function _glGetShaderiv(shader, pname, p) {
      if (pname == 0x8B84) { // GL_INFO_LOG_LENGTH
        HEAP32[((p)>>2)]=Module.ctx.getShaderInfoLog(GL.shaders[shader]).length + 1;
      } else {
        HEAP32[((p)>>2)]=Module.ctx.getShaderParameter(GL.shaders[shader], pname);
      }
    }
  function _glGetProgramiv(program, pname, p) {
      if (pname == 0x8B84) { // GL_INFO_LOG_LENGTH
        HEAP32[((p)>>2)]=Module.ctx.getProgramInfoLog(GL.programs[program]).length + 1;
      } else {
        HEAP32[((p)>>2)]=Module.ctx.getProgramParameter(GL.programs[program], pname);
      }
    }
  function _glIsShader(shader) {
      var s = GL.shaders[shader];
      if (!s) return 0;
      return Module.ctx.isShader(s);
    }
  function _glCreateProgram() {
      var id = GL.getNewId(GL.programs);
      var program = Module.ctx.createProgram();
      program.name = id;
      GL.programs[id] = program;
      return id;
    }
  function _glDeleteProgram(program) {
      var program = GL.programs[program];
      Module.ctx.deleteProgram(program);
      program.name = 0;
      GL.programs[program] = null;
      GL.uniformTable[program] = null;
    }
  function _glAttachShader(program, shader) {
      Module.ctx.attachShader(GL.programs[program],
                              GL.shaders[shader]);
    }
  function _glDetachShader(program, shader) {
      Module.ctx.detachShader(GL.programs[program],
                              GL.shaders[shader]);
    }
  function _glGetShaderPrecisionFormat(shaderType, precisionType, range, precision) {
      var result = Module.ctx.getShaderPrecisionFormat(shaderType, precisionType);
      HEAP32[((range)>>2)]=result.rangeMin;
      HEAP32[(((range)+(4))>>2)]=result.rangeMax;
      HEAP32[((precision)>>2)]=result.precision;
    }
  function _glLinkProgram(program) {
      Module.ctx.linkProgram(GL.programs[program]);
      GL.uniformTable[program] = {}; // uniforms no longer keep the same names after linking
    }
  function _glGetProgramInfoLog(program, maxLength, length, infoLog) {
      var log = Module.ctx.getProgramInfoLog(GL.programs[program]);
      // Work around a bug in Chromium which causes getProgramInfoLog to return null
      if (!log) {
        log = "";
      }
      log = log.substr(0, maxLength - 1);
      writeStringToMemory(log, infoLog);
      if (length) {
        HEAP32[((length)>>2)]=log.length
      }
    }
  function _glUseProgram(program) {
      Module.ctx.useProgram(program ? GL.programs[program] : null);
    }
  function _glValidateProgram(program) {
      Module.ctx.validateProgram(GL.programs[program]);
    }
  function _glIsProgram(program) {
      var program = GL.programs[program];
      if (!program) return 0;
      return Module.ctx.isProgram(program);
    }
  function _glBindAttribLocation(program, index, name) {
      name = Pointer_stringify(name);
      Module.ctx.bindAttribLocation(GL.programs[program], index, name);
    }
  function _glGetFramebufferAttachmentParameteriv(target, attachment, pname, params) {
      var result = Module.ctx.getFramebufferAttachmentParameter(target, attachment, pname);
      HEAP32[((params)>>2)]=params;
    }
  function _glIsFramebuffer(framebuffer) {
      var fb = GL.framebuffers[framebuffer];
      if (!fb) return 0;
      return Module.ctx.isFramebuffer(fb);
    }
  function _glVertexPointer(){ throw 'Legacy GL function (glVertexPointer) called. You need to compile with -s LEGACY_GL_EMULATION=1 to enable legacy GL emulation.'; }
  function _glGenVertexArrays(){ throw 'Legacy GL function (glGenVertexArrays) called. You need to compile with -s LEGACY_GL_EMULATION=1 to enable legacy GL emulation.'; }
  function _glMatrixMode(){ throw 'Legacy GL function (glMatrixMode) called. You need to compile with -s LEGACY_GL_EMULATION=1 to enable legacy GL emulation.'; }
  function _glBegin(){ throw 'Legacy GL function (glBegin) called. You need to compile with -s LEGACY_GL_EMULATION=1 to enable legacy GL emulation.'; }
  function _glLoadIdentity(){ throw 'Legacy GL function (glLoadIdentity) called. You need to compile with -s LEGACY_GL_EMULATION=1 to enable legacy GL emulation.'; }
  function _gluPerspective(fov, aspect, near, far) {
      GL.immediate.matricesModified = true;
      GL.immediate.matrix[GL.immediate.currentMatrix] =
        GL.immediate.matrix.lib.mat4.perspective(fov, aspect, near, far,
                                                 GL.immediate.matrix[GL.immediate.currentMatrix]);
    }
  function _gluLookAt(ex, ey, ez, cx, cy, cz, ux, uy, uz) {
      GL.immediate.matricesModified = true;
      GL.immediate.matrix.lib.mat4.lookAt(GL.immediate.matrix[GL.immediate.currentMatrix], [ex, ey, ez],
          [cx, cy, cz], [ux, uy, uz]);
    }
  function _gluProject(objX, objY, objZ, model, proj, view, winX, winY, winZ) {
      // The algorithm for this functions comes from Mesa
      var inVec = new Float32Array(4);
      var outVec = new Float32Array(4);
      GL.immediate.matrix.lib.mat4.multiplyVec4(HEAPF64.subarray((model)>>3,(model+128)>>3),
          [objX, objY, objZ, 1.0], outVec);
      GL.immediate.matrix.lib.mat4.multiplyVec4(HEAPF64.subarray((proj)>>3,(proj+128)>>3),
          outVec, inVec);
      if (inVec[3] == 0.0) {
        return 0 /* GL_FALSE */;
      }
      inVec[0] /= inVec[3];
      inVec[1] /= inVec[3];
      inVec[2] /= inVec[3];
      // Map x, y and z to range 0-1 */
      inVec[0] = inVec[0] * 0.5 + 0.5;
      inVec[1] = inVec[1] * 0.5 + 0.5;
      inVec[2] = inVec[2] * 0.5 + 0.5;
      // Map x, y to viewport
      inVec[0] = inVec[0] * HEAP32[(((view)+(8))>>2)] + HEAP32[((view)>>2)];
      inVec[1] = inVec[1] * HEAP32[(((view)+(12))>>2)] + HEAP32[(((view)+(4))>>2)];
      HEAPF64[((winX)>>3)]=inVec[0];
      HEAPF64[((winY)>>3)]=inVec[1];
      HEAPF64[((winZ)>>3)]=inVec[2];
      return 1 /* GL_TRUE */;
    }
  function _gluUnProject(winX, winY, winZ, model, proj, view, objX, objY, objZ) {
      var result = GL.immediate.matrix.lib.mat4.unproject([winX, winY, winZ],
          HEAPF64.subarray((model)>>3,(model+128)>>3),
          HEAPF64.subarray((proj)>>3,(proj+128)>>3),
          HEAP32.subarray((view)>>2,(view+16)>>2));
      if (result === null) {
        return 0 /* GL_FALSE */;
      }
      HEAPF64[((objX)>>3)]=result[0];
      HEAPF64[((objY)>>3)]=result[1];
      HEAPF64[((objZ)>>3)]=result[2];
      return 1 /* GL_TRUE */;
    }
  function _gluOrtho2D(left, right, bottom, top) {
      _glOrtho(left, right, bottom, top, -1, 1);
    }
  function _glVertexAttribPointer(index, size, type, normalized, stride, ptr) {
      Module.ctx.vertexAttribPointer(index, size, type, normalized, stride, ptr);
    }
  function _glEnableVertexAttribArray(index) {
      Module.ctx.enableVertexAttribArray(index);
    }
  function _glDisableVertexAttribArray(index) {
      Module.ctx.disableVertexAttribArray(index);
    }
  function _glDrawElements(mode, count, type, indices) {
      Module.ctx.drawElements(mode, count, type, indices);
    }
  function _glFinish() { Module.ctx.finish() }
  function _glFlush() { Module.ctx.flush() }
  function _glClearDepth(x0) { Module.ctx.clearDepth(x0) }
  function _glClearDepthf(x0) { Module.ctx.clearDepth(x0) }
  function _glDepthFunc(x0) { Module.ctx.depthFunc(x0) }
  function _glFrontFace(x0) { Module.ctx.frontFace(x0) }
  function _glCullFace(x0) { Module.ctx.cullFace(x0) }
  function _glLineWidth(x0) { Module.ctx.lineWidth(x0) }
  function _glClearStencil(x0) { Module.ctx.clearStencil(x0) }
  function _glDepthMask(x0) { Module.ctx.depthMask(x0) }
  function _glStencilMask(x0) { Module.ctx.stencilMask(x0) }
  function _glGenerateMipmap(x0) { Module.ctx.generateMipmap(x0) }
  function _glActiveTexture(x0) { Module.ctx.activeTexture(x0) }
  function _glBlendEquation(x0) { Module.ctx.blendEquation(x0) }
  function _glSampleCoverage(x0) { Module.ctx.sampleCoverage(x0) }
  function _glIsEnabled(x0) { return Module.ctx.isEnabled(x0) }
  function _glBlendEquationSeparate(x0, x1) { Module.ctx.blendEquationSeparate(x0, x1) }
  function _glDepthRange(x0, x1) { Module.ctx.depthRange(x0, x1) }
  function _glDepthRangef(x0, x1) { Module.ctx.depthRange(x0, x1) }
  function _glStencilMaskSeparate(x0, x1) { Module.ctx.stencilMaskSeparate(x0, x1) }
  function _glHint(x0, x1) { Module.ctx.hint(x0, x1) }
  function _glPolygonOffset(x0, x1) { Module.ctx.polygonOffset(x0, x1) }
  function _glVertexAttrib1f(x0, x1) { Module.ctx.vertexAttrib1f(x0, x1) }
  function _glTexParameterf(x0, x1, x2) { Module.ctx.texParameterf(x0, x1, x2) }
  function _glVertexAttrib2f(x0, x1, x2) { Module.ctx.vertexAttrib2f(x0, x1, x2) }
  function _glStencilFunc(x0, x1, x2) { Module.ctx.stencilFunc(x0, x1, x2) }
  function _glStencilOp(x0, x1, x2) { Module.ctx.stencilOp(x0, x1, x2) }
  function _glScissor(x0, x1, x2, x3) { Module.ctx.scissor(x0, x1, x2, x3) }
  function _glVertexAttrib3f(x0, x1, x2, x3) { Module.ctx.vertexAttrib3f(x0, x1, x2, x3) }
  function _glColorMask(x0, x1, x2, x3) { Module.ctx.colorMask(x0, x1, x2, x3) }
  function _glBlendFuncSeparate(x0, x1, x2, x3) { Module.ctx.blendFuncSeparate(x0, x1, x2, x3) }
  function _glBlendColor(x0, x1, x2, x3) { Module.ctx.blendColor(x0, x1, x2, x3) }
  function _glStencilFuncSeparate(x0, x1, x2, x3) { Module.ctx.stencilFuncSeparate(x0, x1, x2, x3) }
  function _glStencilOpSeparate(x0, x1, x2, x3) { Module.ctx.stencilOpSeparate(x0, x1, x2, x3) }
  function _glVertexAttrib4f(x0, x1, x2, x3, x4) { Module.ctx.vertexAttrib4f(x0, x1, x2, x3, x4) }
  function _glCopyTexImage2D(x0, x1, x2, x3, x4, x5, x6, x7) { Module.ctx.copyTexImage2D(x0, x1, x2, x3, x4, x5, x6, x7) }
  function _glCopyTexSubImage2D(x0, x1, x2, x3, x4, x5, x6, x7) { Module.ctx.copyTexSubImage2D(x0, x1, x2, x3, x4, x5, x6, x7) }function _emscripten_procAddressTable(name) {
  switch(name) {
  case "glPixelStorei": return 60; break;
  case "glGetString": return 66; break;
  case "glGetIntegerv": return 102; break;
  case "glGetFloatv": return 18; break;
  case "glGetBooleanv": return 110; break;
  case "glGenTextures": return 16; break;
  case "glDeleteTextures": return 28; break;
  case "glCompressedTexImage2D": return 2; break;
  case "glCompressedTexSubImage2D": return 8; break;
  case "glTexImage2D": return 2; break;
  case "glTexSubImage2D": return 4; break;
  case "glReadPixels": return 6; break;
  case "glBindTexture": return 104; break;
  case "glGetTexParameterfv": return 118; break;
  case "glGetTexParameteriv": return 138; break;
  case "glTexParameterfv": return 102; break;
  case "glTexParameteriv": return 202; break;
  case "glIsTexture": return 14; break;
  case "glGenBuffers": return 54; break;
  case "glDeleteBuffers": return 66; break;
  case "glGetBufferParameteriv": return 120; break;
  case "glBufferData": return 20; break;
  case "glBufferSubData": return 96; break;
  case "glIsBuffer": return 94; break;
  case "glGenRenderbuffers": return 40; break;
  case "glDeleteRenderbuffers": return 32; break;
  case "glBindRenderbuffer": return 26; break;
  case "glGetRenderbufferParameteriv": return 44; break;
  case "glIsRenderbuffer": return 40; break;
  case "glGetUniformfv": return 266; break;
  case "glGetUniformiv": return 250; break;
  case "glGetUniformLocation": return 8; break;
  case "glGetVertexAttribfv": return 32; break;
  case "glGetVertexAttribiv": return 258; break;
  case "glGetVertexAttribPointerv": return 142; break;
  case "glGetActiveUniform": return 4; break;
  case "glUniform1f": return 4; break;
  case "glUniform2f": return 2; break;
  case "glUniform3f": return 2; break;
  case "glUniform4f": return 2; break;
  case "glUniform1i": return 120; break;
  case "glUniform2i": return 216; break;
  case "glUniform3i": return 98; break;
  case "glUniform4i": return 4; break;
  case "glUniform1iv": return 86; break;
  case "glUniform2iv": return 248; break;
  case "glUniform3iv": return 220; break;
  case "glUniform4iv": return 252; break;
  case "glUniform1fv": return 96; break;
  case "glUniform2fv": return 168; break;
  case "glUniform3fv": return 206; break;
  case "glUniform4fv": return 98; break;
  case "glUniformMatrix2fv": return 2; break;
  case "glUniformMatrix3fv": return 34; break;
  case "glUniformMatrix4fv": return 4; break;
  case "glBindBuffer": return 50; break;
  case "glVertexAttrib1fv": return 106; break;
  case "glVertexAttrib2fv": return 24; break;
  case "glVertexAttrib3fv": return 122; break;
  case "glVertexAttrib4fv": return 46; break;
  case "glGetAttribLocation": return 116; break;
  case "glGetActiveAttrib": return 2; break;
  case "glCreateShader": return 60; break;
  case "glDeleteShader": return 40; break;
  case "glGetAttachedShaders": return 10; break;
  case "glShaderSource": return 18; break;
  case "glGetShaderSource": return 108; break;
  case "glCompileShader": return 88; break;
  case "glGetShaderInfoLog": return 82; break;
  case "glGetShaderiv": return 50; break;
  case "glGetProgramiv": return 16; break;
  case "glIsShader": return 62; break;
  case "glCreateProgram": return 12; break;
  case "glDeleteProgram": return 74; break;
  case "glAttachShader": return 94; break;
  case "glDetachShader": return 58; break;
  case "glLinkProgram": return 50; break;
  case "glGetProgramInfoLog": return 114; break;
  case "glUseProgram": return 54; break;
  case "glValidateProgram": return 108; break;
  case "glIsProgram": return 100; break;
  case "glBindAttribLocation": return 58; break;
  case "glBindFramebuffer": return 52; break;
  case "glGenFramebuffers": return 12; break;
  case "glDeleteFramebuffers": return 74; break;
  case "glFramebufferRenderbuffer": return 26; break;
  case "glFramebufferTexture2D": return 8; break;
  case "glGetFramebufferAttachmentParameteriv": return 44; break;
  case "glIsFramebuffer": return 58; break;
  case "glVertexAttribPointer": return 94; break;
  case "glEnableVertexAttribArray": return 102; break;
  case "glDisableVertexAttribArray": return 4; break;
  case "glDrawArrays": return 78; break;
  case "glDrawElements": return 68; break;
  case "glGetError": return 8; break;
  case "glFinish": return 2120; break;
  case "glFlush": return 3306; break;
  case "glClearDepth": return 8; break;
  case "glClearDepthf": return 86; break;
  case "glDepthFunc": return 30; break;
  case "glEnable": return 82; break;
  case "glDisable": return 106; break;
  case "glFrontFace": return 16; break;
  case "glCullFace": return 44; break;
  case "glClear": return 66; break;
  case "glLineWidth": return 118; break;
  case "glClearStencil": return 2; break;
  case "glDepthMask": return 96; break;
  case "glStencilMask": return 92; break;
  case "glCheckFramebufferStatus": return 88; break;
  case "glGenerateMipmap": return 12; break;
  case "glActiveTexture": return 100; break;
  case "glBlendEquation": return 22; break;
  case "glSampleCoverage": return 114; break;
  case "glIsEnabled": return 12; break;
  case "glBlendFunc": return 44; break;
  case "glBlendEquationSeparate": return 96; break;
  case "glDepthRange": return 118; break;
  case "glDepthRangef": return 78; break;
  case "glStencilMaskSeparate": return 82; break;
  case "glHint": return 100; break;
  case "glPolygonOffset": return 68; break;
  case "glVertexAttrib1f": return 56; break;
  case "glTexParameteri": return 278; break;
  case "glTexParameterf": return 88; break;
  case "glVertexAttrib2f": return 22; break;
  case "glStencilFunc": return 204; break;
  case "glStencilOp": return 54; break;
  case "glViewport": return 60; break;
  case "glClearColor": return 62; break;
  case "glScissor": return 16; break;
  case "glVertexAttrib3f": return 24; break;
  case "glColorMask": return 76; break;
  case "glRenderbufferStorage": return 104; break;
  case "glBlendFuncSeparate": return 12; break;
  case "glBlendColor": return 72; break;
  case "glStencilFuncSeparate": return 106; break;
  case "glStencilOpSeparate": return 70; break;
  case "glVertexAttrib4f": return 6; break;
  case "glCopyTexImage2D": return 6; break;
  case "glCopyTexSubImage2D": return 4; break;
  }
  return 0;
  }function _emscripten_GetProcAddress(name) {
    name = name.replace('EXT', '').replace('ARB', '');
    switch(name) { // misc renamings
      case 'glCreateProgramObject': name = 'glCreateProgram'; break;
      case 'glUseProgramObject': name = 'glUseProgram'; break;
      case 'glCreateShaderObject': name = 'glCreateShader'; break;
      case 'glAttachObject': name = 'glAttachShader'; break;
      case 'glDetachObject': name = 'glDetachShader'; break;
    }
    var ret = _emscripten_procAddressTable(name);
    if (!ret) Module.printErr('WARNING: getProcAddress failed for ' + name);
    return ret;
  }function _eglGetProcAddress(name_) {
      return _emscripten_GetProcAddress(Pointer_stringify(name_));
    }
  function _emscripten_get_canvas_size(width, height, isFullscreen) {
      var canvas = Module['canvas'];
      HEAP32[((width)>>2)]=canvas.width;
      HEAP32[((height)>>2)]=canvas.height;
      HEAP32[((isFullscreen)>>2)]=Browser.isFullScreen ? 1 : 0;
    }
  var EGL={eglErrorCode:12288,setErrorCode:function (code) {
        EGL.eglErrorCode = code;
      },chooseConfig:function (display, attribList, config, config_size, numConfigs) { 
        if (display != 62000 /* Magic ID for Emscripten 'default display' */) {
          EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
          return 0;
        }
        // TODO: read attribList.
        if ((!config || !config_size) && !numConfigs) {
          EGL.setErrorCode(0x300C /* EGL_BAD_PARAMETER */);
          return 0;
        }
        if (numConfigs) {
          HEAP32[((numConfigs)>>2)]=1; // Total number of supported configs: 1.
        }
        if (config && config_size > 0) {
          HEAP32[((config)>>2)]=62002; 
        }
        EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
        return 1;
      }};function _eglBindAPI(api) {
      if (api == 0x30A0 /* EGL_OPENGL_ES_API */) {
        EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
        return 1;
      } else { // if (api == 0x30A1 /* EGL_OPENVG_API */ || api == 0x30A2 /* EGL_OPENGL_API */) {
        EGL.setErrorCode(0x300C /* EGL_BAD_PARAMETER */);
        return 0;
      }
    }
  function _eglMakeCurrent(display, draw, read, context) { 
      if (display != 62000 /* Magic ID for Emscripten 'default display' */) {
        EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
        return 0;
      }
      //\todo An EGL_NOT_INITIALIZED error is generated if EGL is not initialized for dpy. 
      if (context != 62004 /* Magic ID for Emscripten EGLContext */) {
        EGL.setErrorCode(0x3006 /* EGL_BAD_CONTEXT */);
        return 0;
      }
      if (read != 62006 || draw != 62006 /* Magic ID for Emscripten 'default surface' */) {
        EGL.setErrorCode(0x300D /* EGL_BAD_SURFACE */);
        return 0;
      }
      EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
      return 1;
    }
  function _glutDestroyWindow(name) {
      Module.ctx = Browser.destroyContext(Module['canvas'], true, true);
      return 1;
    }function _eglDestroyContext(display, context) {
      if (display != 62000 /* Magic ID for Emscripten 'default display' */) {
        EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
        return 0;
      }
      if (context != 62004 /* Magic ID for Emscripten EGLContext */) {
        EGL.setErrorCode(0x3006 /* EGL_BAD_CONTEXT */);
        return 0;
      }
      EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
      return 1;
    }
  function _eglDestroySurface(display, surface) { 
      if (display != 62000 /* Magic ID for Emscripten 'default display' */) {
        EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
        return 0; 
      }
      if (surface != 62006 /* Magic ID for the only EGLSurface supported by Emscripten */) {
        EGL.setErrorCode(0x300D /* EGL_BAD_SURFACE */);
        return 1;
      }
      EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
      return 1; /* Magic ID for Emscripten 'default surface' */
    }
  function _eglTerminate(display) {
      if (display != 62000 /* Magic ID for Emscripten 'default display' */) {
        EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
        return 0;
      }
      // TODO: Tear down EGL here. Currently a no-op since we don't need to actually do anything here for the browser.
      EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
      return 1;
    }
  function _eglGetDisplay(nativeDisplayType) {
      EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
      // Note: As a 'conformant' implementation of EGL, we would prefer to init here only if the user
      //       calls this function with EGL_DEFAULT_DISPLAY. Other display IDs would be preferred to be unsupported
      //       and EGL_NO_DISPLAY returned. Uncomment the following code lines to do this.
      // Instead, an alternative route has been preferred, namely that the Emscripten EGL implementation
      // "emulates" X11, and eglGetDisplay is expected to accept/receive a pointer to an X11 Display object.
      // Therefore, be lax and allow anything to be passed in, and return the magic handle to our default EGLDisplay object.
  //    if (nativeDisplayType == 0 /* EGL_DEFAULT_DISPLAY */) {
          return 62000; // Magic ID for Emscripten 'default display'
  //    }
  //    else
  //      return 0; // EGL_NO_DISPLAY
    }
  function _eglInitialize(display, majorVersion, minorVersion) {
      if (display == 62000 /* Magic ID for Emscripten 'default display' */) {
        if (majorVersion) {
          HEAP32[((majorVersion)>>2)]=1; // Advertise EGL Major version: '1'
        }
        if (minorVersion) {
          HEAP32[((minorVersion)>>2)]=4; // Advertise EGL Minor version: '4'
        }
        EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
        return 1;
      } 
      else {
        EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
        return 0;
      }
    }
  function _eglChooseConfig(display, attrib_list, configs, config_size, numConfigs) { 
      return EGL.chooseConfig(display, attrib_list, configs, config_size, numConfigs);
    }
  function _glutCreateWindow(name) {
      Module.ctx = Browser.createContext(Module['canvas'], true, true);
      return Module.ctx ? 1 /* a new GLUT window ID for the created context */ : 0 /* failure */;
    }function _eglCreateContext(display, config, hmm, contextAttribs) {
      if (display != 62000 /* Magic ID for Emscripten 'default display' */) {
        EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
        return 0;
      }
      EGL.windowID = _glutCreateWindow();
      if (EGL.windowID != 0) {
        EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
        return 62004; // Magic ID for Emscripten EGLContext
      } else {
        EGL.setErrorCode(0x3009 /* EGL_BAD_MATCH */); // By the EGL 1.4 spec, an implementation that does not support GLES2 (WebGL in this case), this error code is set.
        return 0; /* EGL_NO_CONTEXT */
      }
    }
  function _eglCreateWindowSurface(display, config, win, attrib_list) { 
      if (display != 62000 /* Magic ID for Emscripten 'default display' */) {
        EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
        return 0;
      }
      if (config != 62002 /* Magic ID for the only EGLConfig supported by Emscripten */) {
        EGL.setErrorCode(0x3005 /* EGL_BAD_CONFIG */);
        return 0;
      }
      // TODO: Examine attrib_list! Parameters that can be present there are:
      // - EGL_RENDER_BUFFER (must be EGL_BACK_BUFFER)
      // - EGL_VG_COLORSPACE (can't be set)
      // - EGL_VG_ALPHA_FORMAT (can't be set)
      EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
      return 62006; /* Magic ID for Emscripten 'default surface' */
    }
  function _eglQuerySurface(display, surface, attribute, value) { 
      if (display != 62000 /* Magic ID for Emscripten 'default display' */) {
        EGL.setErrorCode(0x3008 /* EGL_BAD_DISPLAY */);
        return 0;
      }
      if (surface != 62006 /* Magic ID for Emscripten 'default surface' */) {
        EGL.setErrorCode(0x300D /* EGL_BAD_SURFACE */);
        return 0;
      }
      if (!value) {
        EGL.setErrorCode(0x300C /* EGL_BAD_PARAMETER */);
        return 0;
      }
      EGL.setErrorCode(0x3000 /* EGL_SUCCESS */);
      switch(attribute) {
      case 0x3028: // EGL_CONFIG_ID
        HEAP32[((value)>>2)]=62002;
          return 1;
      case 0x3058: // EGL_LARGEST_PBUFFER
        // Odd EGL API: If surface is not a pbuffer surface, 'value' should not be written to. It's not specified as an error, so true should(?) be returned.
        // Existing Android implementation seems to do so at least.
        return 1;
      case 0x3057: // EGL_WIDTH
        HEAP32[((value)>>2)]=Module.canvas.width;
        return 1;
      case 0x3056: // EGL_HEIGHT
        HEAP32[((value)>>2)]=Module.canvas.height;
        return 1;
      case 0x3090: // EGL_HORIZONTAL_RESOLUTION
        HEAP32[((value)>>2)]=-1;
        return 1;
      case 0x3091: // EGL_VERTICAL_RESOLUTION
        HEAP32[((value)>>2)]=-1;
        return 1;
      case 0x3092: // EGL_PIXEL_ASPECT_RATIO
        HEAP32[((value)>>2)]=-1;
        return 1;
      case 0x3086: // EGL_RENDER_BUFFER
        // The main surface is bound to the visible canvas window - it's always backbuffered. 
        // Alternative to EGL_BACK_BUFFER would be EGL_SINGLE_BUFFER.
        HEAP32[((value)>>2)]=0x3084; 
        return 1;
      case 0x3099: // EGL_MULTISAMPLE_RESOLVE
        HEAP32[((value)>>2)]=0x309A; 
        return 1;
      case 0x3093: // EGL_SWAP_BEHAVIOR
        // The two possibilities are EGL_BUFFER_PRESERVED and EGL_BUFFER_DESTROYED. Slightly unsure which is the
        // case for browser environment, but advertise the 'weaker' behavior to be sure.
        HEAP32[((value)>>2)]=0x3095;
        return 1;
      case 0x3080: // EGL_TEXTURE_FORMAT
      case 0x3081: // EGL_TEXTURE_TARGET
      case 0x3082: // EGL_MIPMAP_TEXTURE
      case 0x3083: // EGL_MIPMAP_LEVEL
        // This is a window surface, not a pbuffer surface. Spec:
        // "Querying EGL_TEXTURE_FORMAT, EGL_TEXTURE_TARGET, EGL_MIPMAP_TEXTURE, or EGL_MIPMAP_LEVEL for a non-pbuffer surface is not an error, but value is not modified."
        // So pass-through.
        return 1;
      default:
        EGL.setErrorCode(0x3004 /* EGL_BAD_ATTRIBUTE */);
        return 0;
      }
    }
  Module["_strcpy"] = _strcpy;
  var _cos=Math.cos;
  var _atan=Math.atan;
  Module["_strncpy"] = _strncpy;
  function _toupper(chr) {
      if (chr >= 97 && chr <= 122) {
        return chr - 97 + 65;
      } else {
        return chr;
      }
    }
  function _isalnum(chr) {
      return (chr >= 48 && chr <= 57) ||
             (chr >= 97 && chr <= 122) ||
             (chr >= 65 && chr <= 90);
    }
  function _sprintf(s, format, varargs) {
      // int sprintf(char *restrict s, const char *restrict format, ...);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/printf.html
      return _snprintf(s, undefined, format, varargs);
    }
  function _atoi(ptr) {
      return _strtol(ptr, null, 10);
    }
  Module["_strcat"] = _strcat;
  function _abort() {
      Module['abort']();
    }
  function _sbrk(bytes) {
      // Implement a Linux-like 'memory area' for our 'process'.
      // Changes the size of the memory area by |bytes|; returns the
      // address of the previous top ('break') of the memory area
      // We control the "dynamic" memory - DYNAMIC_BASE to DYNAMICTOP
      var self = _sbrk;
      if (!self.called) {
        DYNAMICTOP = alignMemoryPage(DYNAMICTOP); // make sure we start out aligned
        self.called = true;
        assert(Runtime.dynamicAlloc);
        self.alloc = Runtime.dynamicAlloc;
        Runtime.dynamicAlloc = function() { abort('cannot dynamically allocate, sbrk now has control') };
      }
      var ret = DYNAMICTOP;
      if (bytes != 0) self.alloc(bytes);
      return ret;  // Previous break location.
    }
  function _sysconf(name) {
      // long sysconf(int name);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/sysconf.html
      switch(name) {
        case 8: return PAGE_SIZE;
        case 54:
        case 56:
        case 21:
        case 61:
        case 63:
        case 22:
        case 67:
        case 23:
        case 24:
        case 25:
        case 26:
        case 27:
        case 69:
        case 28:
        case 101:
        case 70:
        case 71:
        case 29:
        case 30:
        case 199:
        case 75:
        case 76:
        case 32:
        case 43:
        case 44:
        case 80:
        case 46:
        case 47:
        case 45:
        case 48:
        case 49:
        case 42:
        case 82:
        case 33:
        case 7:
        case 108:
        case 109:
        case 107:
        case 112:
        case 119:
        case 121:
          return 200809;
        case 13:
        case 104:
        case 94:
        case 95:
        case 34:
        case 35:
        case 77:
        case 81:
        case 83:
        case 84:
        case 85:
        case 86:
        case 87:
        case 88:
        case 89:
        case 90:
        case 91:
        case 94:
        case 95:
        case 110:
        case 111:
        case 113:
        case 114:
        case 115:
        case 116:
        case 117:
        case 118:
        case 120:
        case 40:
        case 16:
        case 79:
        case 19:
          return -1;
        case 92:
        case 93:
        case 5:
        case 72:
        case 6:
        case 74:
        case 92:
        case 93:
        case 96:
        case 97:
        case 98:
        case 99:
        case 102:
        case 103:
        case 105:
          return 1;
        case 38:
        case 66:
        case 50:
        case 51:
        case 4:
          return 1024;
        case 15:
        case 64:
        case 41:
          return 32;
        case 55:
        case 37:
        case 17:
          return 2147483647;
        case 18:
        case 1:
          return 47839;
        case 59:
        case 57:
          return 99;
        case 68:
        case 58:
          return 2048;
        case 0: return 2097152;
        case 3: return 65536;
        case 14: return 32768;
        case 73: return 32767;
        case 39: return 16384;
        case 60: return 1000;
        case 106: return 700;
        case 52: return 256;
        case 62: return 255;
        case 2: return 100;
        case 65: return 64;
        case 36: return 20;
        case 100: return 16;
        case 20: return 6;
        case 53: return 4;
        case 10: return 1;
      }
      ___setErrNo(ERRNO_CODES.EINVAL);
      return -1;
    }
  var _llvm_memcpy_p0i8_p0i8_i64=_memcpy;
  function _memchr(ptr, chr, num) {
      chr = unSign(chr);
      for (var i = 0; i < num; i++) {
        if (HEAP8[(ptr)] == chr) return ptr;
        ptr++;
      }
      return 0;
    }
FS.staticInit();__ATINIT__.unshift({ func: function() { if (!Module["noFSInit"] && !FS.init.initialized) FS.init() } });__ATMAIN__.push({ func: function() { FS.ignorePermissions = false } });__ATEXIT__.push({ func: function() { FS.quit() } });Module["FS_createFolder"] = FS.createFolder;Module["FS_createPath"] = FS.createPath;Module["FS_createDataFile"] = FS.createDataFile;Module["FS_createPreloadedFile"] = FS.createPreloadedFile;Module["FS_createLazyFile"] = FS.createLazyFile;Module["FS_createLink"] = FS.createLink;Module["FS_createDevice"] = FS.createDevice;
___errno_state = Runtime.staticAlloc(4); HEAP32[((___errno_state)>>2)]=0;
__ATINIT__.unshift({ func: function() { TTY.init() } });__ATEXIT__.push({ func: function() { TTY.shutdown() } });TTY.utf8 = new Runtime.UTF8Processor();
__ATINIT__.push({ func: function() { SOCKFS.root = FS.mount(SOCKFS, {}, null); } });
_fputc.ret = allocate([0], "i8", ALLOC_STATIC);
_fgetc.ret = allocate([0], "i8", ALLOC_STATIC);
___buildEnvironment(ENV);
Module["requestFullScreen"] = function(lockPointer, resizeCanvas) { Browser.requestFullScreen(lockPointer, resizeCanvas) };
  Module["requestAnimationFrame"] = function(func) { Browser.requestAnimationFrame(func) };
  Module["setCanvasSize"] = function(width, height, noUpdates) { Browser.setCanvasSize(width, height, noUpdates) };
  Module["pauseMainLoop"] = function() { Browser.mainLoop.pause() };
  Module["resumeMainLoop"] = function() { Browser.mainLoop.resume() };
  Module["getUserMedia"] = function() { Browser.getUserMedia() }
GL.init()
STACK_BASE = STACKTOP = Runtime.alignMemory(STATICTOP);
staticSealed = true; // seal the static portion of memory
STACK_MAX = STACK_BASE + 5242880;
DYNAMIC_BASE = DYNAMICTOP = Runtime.alignMemory(STACK_MAX);
assert(DYNAMIC_BASE < TOTAL_MEMORY); // Stack must fit in TOTAL_MEMORY; allocations from here on may enlarge TOTAL_MEMORY
 var ctlz_i8 = allocate([8,7,6,6,5,5,5,5,4,4,4,4,4,4,4,4,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,3,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0], "i8", ALLOC_DYNAMIC);
 var cttz_i8 = allocate([8,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,6,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,7,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,6,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0], "i8", ALLOC_DYNAMIC);
var Math_min = Math.min;
function invoke_iiiiiiii(index,a1,a2,a3,a4,a5,a6,a7) {
  try {
    return Module["dynCall_iiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_vif(index,a1,a2) {
  try {
    Module["dynCall_vif"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viiiii(index,a1,a2,a3,a4,a5) {
  try {
    Module["dynCall_viiiii"](index,a1,a2,a3,a4,a5);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_vi(index,a1) {
  try {
    Module["dynCall_vi"](index,a1);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_vii(index,a1,a2) {
  try {
    Module["dynCall_vii"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_iiiiiii(index,a1,a2,a3,a4,a5,a6) {
  try {
    return Module["dynCall_iiiiiii"](index,a1,a2,a3,a4,a5,a6);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_ii(index,a1) {
  try {
    return Module["dynCall_ii"](index,a1);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viiiiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11) {
  try {
    Module["dynCall_viiiiiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9,a10,a11);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viffff(index,a1,a2,a3,a4,a5) {
  try {
    Module["dynCall_viffff"](index,a1,a2,a3,a4,a5);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_if(index,a1) {
  try {
    return Module["dynCall_if"](index,a1);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_iiii(index,a1,a2,a3) {
  try {
    return Module["dynCall_iiii"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viiiiif(index,a1,a2,a3,a4,a5,a6) {
  try {
    Module["dynCall_viiiiif"](index,a1,a2,a3,a4,a5,a6);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8) {
  try {
    Module["dynCall_viiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_vifff(index,a1,a2,a3,a4) {
  try {
    Module["dynCall_vifff"](index,a1,a2,a3,a4);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_fii(index,a1,a2) {
  try {
    return Module["dynCall_fii"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_iiif(index,a1,a2,a3) {
  try {
    return Module["dynCall_iiif"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viff(index,a1,a2,a3) {
  try {
    Module["dynCall_viff"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_iif(index,a1,a2) {
  try {
    return Module["dynCall_iif"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viiiiiii(index,a1,a2,a3,a4,a5,a6,a7) {
  try {
    Module["dynCall_viiiiiii"](index,a1,a2,a3,a4,a5,a6,a7);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_ff(index,a1) {
  try {
    return Module["dynCall_ff"](index,a1);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viiiiiiiii(index,a1,a2,a3,a4,a5,a6,a7,a8,a9) {
  try {
    Module["dynCall_viiiiiiiii"](index,a1,a2,a3,a4,a5,a6,a7,a8,a9);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_iii(index,a1,a2) {
  try {
    return Module["dynCall_iii"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viiiiii(index,a1,a2,a3,a4,a5,a6) {
  try {
    Module["dynCall_viiiiii"](index,a1,a2,a3,a4,a5,a6);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_f(index) {
  try {
    return Module["dynCall_f"](index);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_i(index) {
  try {
    return Module["dynCall_i"](index);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_iiiii(index,a1,a2,a3,a4) {
  try {
    return Module["dynCall_iiiii"](index,a1,a2,a3,a4);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viii(index,a1,a2,a3) {
  try {
    Module["dynCall_viii"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_v(index) {
  try {
    Module["dynCall_v"](index);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function invoke_viiii(index,a1,a2,a3,a4) {
  try {
    Module["dynCall_viiii"](index,a1,a2,a3,a4);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}
function asmPrintInt(x, y) {
  Module.print('int ' + x + ',' + y);// + ' ' + new Error().stack);
}
function asmPrintFloat(x, y) {
  Module.print('float ' + x + ',' + y);// + ' ' + new Error().stack);
}
// EMSCRIPTEN_START_ASM
var asm=(function(global,env,buffer){"use asm";var a=new global.Int8Array(buffer);var b=new global.Int16Array(buffer);var c=new global.Int32Array(buffer);var d=new global.Uint8Array(buffer);var e=new global.Uint16Array(buffer);var f=new global.Uint32Array(buffer);var g=new global.Float32Array(buffer);var h=new global.Float64Array(buffer);var i=env.STACKTOP|0;var j=env.STACK_MAX|0;var k=env.tempDoublePtr|0;var l=env.ABORT|0;var m=env.cttz_i8|0;var n=env.ctlz_i8|0;var o=env._stdout|0;var p=env._stderr|0;var q=+env.NaN;var r=+env.Infinity;var s=0;var t=0;var u=0;var v=0;var w=0,x=0,y=0,z=0,A=0.0,B=0,C=0,D=0,E=0.0;var F=0;var G=0;var H=0;var I=0;var J=0;var K=0;var L=0;var M=0;var N=0;var O=0;var P=global.Math.floor;var Q=global.Math.abs;var R=global.Math.sqrt;var S=global.Math.pow;var T=global.Math.cos;var U=global.Math.sin;var V=global.Math.tan;var W=global.Math.acos;var X=global.Math.asin;var Y=global.Math.atan;var Z=global.Math.atan2;var _=global.Math.exp;var $=global.Math.log;var aa=global.Math.ceil;var ab=global.Math.imul;var ac=env.abort;var ad=env.assert;var ae=env.asmPrintInt;var af=env.asmPrintFloat;var ag=env.min;var ah=env.invoke_iiiiiiii;var ai=env.invoke_vif;var aj=env.invoke_viiiii;var ak=env.invoke_vi;var al=env.invoke_vii;var am=env.invoke_iiiiiii;var an=env.invoke_ii;var ao=env.invoke_viiiiiiiiiii;var ap=env.invoke_viffff;var aq=env.invoke_if;var ar=env.invoke_iiii;var as=env.invoke_viiiiif;var at=env.invoke_viiiiiiii;var au=env.invoke_vifff;var av=env.invoke_fii;var aw=env.invoke_iiif;var ax=env.invoke_viff;var ay=env.invoke_iif;var az=env.invoke_viiiiiii;var aA=env.invoke_ff;var aB=env.invoke_viiiiiiiii;var aC=env.invoke_iii;var aD=env.invoke_viiiiii;var aE=env.invoke_f;var aF=env.invoke_i;var aG=env.invoke_iiiii;var aH=env.invoke_viii;var aI=env.invoke_v;var aJ=env.invoke_viiii;var aK=env._llvm_lifetime_end;var aL=env._lseek;var aM=env._RWebInputDestroy;var aN=env._RWebAudioStop;var aO=env._glClearColor;var aP=env._sysconf;var aQ=env._fclose;var aR=env._RWebAudioInit;var aS=env._glGetVertexAttribPointerv;var aT=env._glGetRenderbufferParameteriv;var aU=env._eglDestroySurface;var aV=env._strtoul;var aW=env._strtoull;var aX=env._glBindTexture;var aY=env._fflush;var aZ=env._glGetUniformiv;var a_=env._fabsf;var a$=env._strtol;var a0=env._fputc;var a1=env._glGetString;var a2=env._fwrite;var a3=env._gluUnProject;var a4=env._send;var a5=env._fputs;var a6=env._glLineWidth;var a7=env._glUniform2fv;var a8=env._emscripten_get_now;var a9=env._eglCreateContext;var ba=env._glBindAttribLocation;var bb=env._glCompileShader;var bc=env._isspace;var bd=env._localtime;var be=env._glDeleteTextures;var bf=env._eglBindAPI;var bg=env._glCompressedTexImage2D;var bh=env._isalnum;var bi=env._glStencilFuncSeparate;var bj=env._read;var bk=env._RWebAudioBufferSize;var bl=env._glDeleteShader;var bm=env._RWebInputInit;var bn=env._glClearDepthf;var bo=env._glUniform4iv;var bp=env._glGetTexParameteriv;var bq=env._glClearStencil;var br=env._glLoadIdentity;var bs=env._glUniform1fv;var bt=env._glIsShader;var bu=env._strstr;var bv=env._glSampleCoverage;var bw=env._fsync;var bx=env._glGenTextures;var by=env._glDepthFunc;var bz=env._remove;var bA=env._glCompressedTexSubImage2D;var bB=env._glUniform1f;var bC=env._opendir;var bD=env._glGetTexParameterfv;var bE=env._RWebAudioWrite;var bF=env._glStencilMaskSeparate;var bG=env._glCreateShader;var bH=env._round;var bI=env._glUniform1i;var bJ=env._strncmp;var bK=env._cosf;var bL=env._glDeleteRenderbuffers;var bM=env._glLinkProgram;var bN=env._snprintf;var bO=env._glUniform2i;var bP=env._fgetc;var bQ=env._glStencilFunc;var bR=env._glShaderSource;var bS=env._readdir;var bT=env._glVertexAttribPointer;var bU=env._glHint;var bV=env._glBindBuffer;var bW=env._glVertexPointer;var bX=env._fgets;var bY=env._close;var bZ=env._getgid;var b_=env._glGetAttachedShaders;var b$=env._glBindFramebuffer;var b0=env._glIsFramebuffer;var b1=env._strchr;var b2=env._glUniform4fv;var b3=env._abort;var b4=env.___setErrNo;var b5=env._glDeleteFramebuffers;var b6=env._eglTerminate;var b7=env._glGetVertexAttribfv;var b8=env._glIsBuffer;var b9=env._emscripten_GetProcAddress;var ca=env._eglGetProcAddress;var cb=env._ftell;var cc=env._glDeleteProgram;var cd=env._exit;var ce=env._sprintf;var cf=env._glRenderbufferStorage;var cg=env._strrchr;var ch=env._glAttachShader;var ci=env._RWebInputPoll;var cj=env._glUniform3i;var ck=env._glIsProgram;var cl=env._glCheckFramebufferStatus;var cm=env.__isLeapYear;var cn=env._gluProject;var co=env._llvm_uadd_with_overflow_i32;var cp=env._localtime_r;var cq=env._glUniform3f;var cr=env._glGetBufferParameteriv;var cs=env._glFlush;var ct=env._glBlendEquationSeparate;var cu=env._emscripten_get_canvas_size;var cv=env._glCopyTexImage2D;var cw=env._glDrawElements;var cx=env._glColorMask;var cy=env._sinf;var cz=env._gluLookAt;var cA=env._eglInitialize;var cB=env._recv;var cC=env.__parseInt64;var cD=env._glVertexAttrib1fv;var cE=env._glUniform2iv;var cF=env._cos;var cG=env._putchar;var cH=env._glUniform1iv;var cI=env._glActiveTexture;var cJ=env._glMatrixMode;var cK=env._glBlendEquation;var cL=env._strcmp;var cM=env._glVertexAttrib1f;var cN=env._RWebAudioWriteAvail;var cO=env._glGenerateMipmap;var cP=env._memchr;var cQ=env._glDetachShader;var cR=env._glGetShaderiv;var cS=env.__exit;var cT=env._strftime;var cU=env._glVertexAttrib3f;var cV=env._glGenRenderbuffers;var cW=env._tzset;var cX=env._RWebAudioSampleRate;var cY=env._glGetShaderPrecisionFormat;var cZ=env._glVertexAttrib4fv;var c_=env._glDepthMask;var c$=env._glDisableVertexAttribArray;var c0=env._glBegin;var c1=env._toupper;var c2=env._printf;var c3=env._glBindRenderbuffer;var c4=env._pread;var c5=env._fopen;var c6=env._open;var c7=env._glDrawArrays;var c8=env._usleep;var c9=env._llvm_pow_f32;var da=env.__arraySum;var db=env._glCopyTexSubImage2D;var dc=env._glDisable;var dd=env._puts;var de=env._glUniform4i;var df=env._nanosleep;var dg=env._glClear;var dh=env._qsort;var di=env._glUniform2f;var dj=env._eglDestroyContext;var dk=env._isalpha;var dl=env._glEnableVertexAttribArray;var dm=env._rmdir;var dn=env._glUniform3fv;var dp=env._glStencilOp;var dq=env._strdup;var dr=env._glDepthRange;var ds=env._glUniform4f;var dt=env._glFramebufferTexture2D;var du=env._glUniformMatrix2fv;var dv=env._glGenVertexArrays;var dw=env._eglMakeCurrent;var dx=env._glUniformMatrix3fv;var dy=env._glutCreateWindow;var dz=env._glBufferData;var dA=env._glBlendColor;var dB=env._glGetUniformLocation;var dC=env._glIsEnabled;var dD=env.__formatString;var dE=env._getenv;var dF=env._glGetError;var dG=env._glGetVertexAttribiv;var dH=env._glTexParameteriv;var dI=env._glGetProgramiv;var dJ=env._glVertexAttrib3fv;var dK=env._glGetFloatv;var dL=env._glBufferSubData;var dM=env._glUniform3iv;var dN=env._glReadPixels;var dO=env._glGenFramebuffers;var dP=env._glFramebufferRenderbuffer;var dQ=env._emscripten_procAddressTable;var dR=env._ceil;var dS=env.___errno_location;var dT=env._glGetIntegerv;var dU=env._RWebAudioFree;var dV=env._llvm_lifetime_start;var dW=env._glIsRenderbuffer;var dX=env._llvm_bswap_i32;var dY=env._sbrk;var dZ=env.__parseInt;var d_=env._RWebAudioSetNonblockState;var d$=env._glVertexAttrib2fv;var d0=env._glGetFramebufferAttachmentParameteriv;var d1=env._glUseProgram;var d2=env._glTexImage2D;var d3=env._glGetProgramInfoLog;var d4=env._glTexSubImage2D;var d5=env._glStencilMask;var d6=env._fread;var d7=env._glStencilOpSeparate;var d8=env._strtok_r;var d9=env._glGetShaderInfoLog;var ea=env._glIsTexture;var eb=env._eglCreateWindowSurface;var ec=env._fprintf;var ed=env._glGetShaderSource;var ee=env._gluPerspective;var ef=env._eglChooseConfig;var eg=env.___buildEnvironment;var eh=env._feof;var ei=env.__addDays;var ej=env._glScissor;var ek=env._glEnable;var el=env._glBlendFuncSeparate;var em=env.__reallyNegative;var en=env._glGetActiveAttrib;var eo=env._fseek;var ep=env._sqrt;var eq=env._glTexParameterfv;var er=env._write;var es=env._glGenBuffers;var et=env._glFinish;var eu=env._glGetAttribLocation;var ev=env._glVertexAttrib4f;var ew=env._rewind;var ex=env._sin;var ey=env._glBlendFunc;var ez=env._glCreateProgram;var eA=env._realpath;var eB=env._stat;var eC=env._longjmp;var eD=env._atan;var eE=env._glViewport;var eF=env._emscripten_set_main_loop;var eG=env._time;var eH=env._glVertexAttrib2f;var eI=env._closedir;var eJ=env._isgraph;var eK=env._readlink;var eL=env._glGetUniformfv;var eM=env._unlink;var eN=env._gluOrtho2D;var eO=env._glUniformMatrix4fv;var eP=env._glClearDepth;var eQ=env._glGetActiveUniform;var eR=env._glutDestroyWindow;var eS=env._pwrite;var eT=env._fabs;var eU=env._glTexParameterf;var eV=env._RWebAudioStart;var eW=env._glTexParameteri;var eX=env._glFrontFace;var eY=env._glCullFace;var eZ=env._glDepthRangef;var e_=env._glDeleteBuffers;var e$=env._eglGetDisplay;var e0=env._emscripten_set_canvas_size;var e1=env._atoi;var e2=env._glGetBooleanv;var e3=env._eglQuerySurface;var e4=env._glPixelStorei;var e5=env._readdir_r;var e6=env._glValidateProgram;var e7=env._glPolygonOffset;
// EMSCRIPTEN_START_FUNCS
function ms(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=b[520836]|0;f=a[(c[348396]|0)+(d&65535)|0]|0;g=(c[348392]|0)+(c[348399]|0)|0;c[348392]=g;h=c[348406]|0;if((g|0)<(h|0)){i=d;j=g;k=h}else{do{j1();l=c[348392]|0;m=c[348406]|0;}while((l|0)>=(m|0));i=b[520836]|0;j=l;k=m}b[520836]=i+1&65535;i=b[520831]|0;m=i+(f&255)&65535;do{if((i&255)<<24>>24==0){n=j;o=k}else{f=j+6|0;c[348392]=f;if((f|0)<(k|0)){n=f;o=k;break}while(1){j1();f=c[348392]|0;l=c[348406]|0;if((f|0)<(l|0)){n=f;o=l;break}}}}while(0);k=(e[520834]|0)+(m&65535)|0;m=n+6|0;c[348392]=m;if((m|0)<(o|0)){p=k&65535;q=a[1041666]|0;j2(q,p);r=a[1041666]|0;a[1044496]=r;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));p=k&65535;q=a[1041666]|0;j2(q,p);r=a[1041666]|0;a[1044496]=r;return}function mt(){var b=0;b=xb()|0;j2(a[1041660]|0,(e[520834]|0)+b|0);a[1044496]=a[1041660]|0;return}function mu(){var b=0;b=(c[348392]|0)+6|0;c[348392]=b;if((b|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}b=a[1041668]|0;a[1041660]=b;a[1106728]=b;a[1106720]=b;return}function mv(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=c[276674]|0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=(d[f+(h+1)|0]|0)<<8|(d[f+h|0]|0);h=(c[348392]|0)+(c[348400]|0)|0;c[348392]=h;f=c[348406]|0;if((h|0)<(f|0)){j=g;k=h;l=f}else{do{j1();m=c[348392]|0;n=c[348406]|0;}while((m|0)>=(n|0));j=b[520836]|0;k=m;l=n}b[520836]=j+2&65535;j=i&65535|e;e=k+6|0;c[348392]=e;if((e|0)<(l|0)){o=b[520834]|0;p=o&65535;q=p+j|0;r=a[1041660]|0;j2(r,q);s=a[1041660]|0;a[1044496]=s;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));o=b[520834]|0;p=o&65535;q=p+j|0;r=a[1041660]|0;j2(r,q);s=a[1041660]|0;a[1044496]=s;return}function mw(){var d=0;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}b[520832]=b[520833]|0;if((b[520829]&256)==0){return}a[1041665|0]=1;return}function mx(){var b=0;b=(c[348392]|0)+6|0;c[348392]=b;if((b|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}b=a[1041666]|0;a[1041668]=b;a[1106728]=b;a[1106720]=b;return}function my(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=c[276674]|0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=(d[f+(h+1)|0]|0)<<8|(d[f+h|0]|0);h=(c[348392]|0)+(c[348400]|0)|0;c[348392]=h;if((h|0)<(c[348406]|0)){j=g;k=j+2&65535;b[520836]=k;l=i&65535;m=l|e;j2(0,m);a[1044496]=0;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));j=b[520836]|0;k=j+2&65535;b[520836]=k;l=i&65535;m=l|e;j2(0,m);a[1044496]=0;return}function mz(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=c[276674]|0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=(d[f+(h+1)|0]|0)<<8|(d[f+h|0]|0);h=(c[348392]|0)+(c[348400]|0)|0;c[348392]=h;f=c[348406]|0;if((h|0)<(f|0)){j=g;k=h;l=f}else{do{j1();m=c[348392]|0;n=c[348406]|0;}while((m|0)>=(n|0));j=b[520836]|0;k=m;l=n}b[520836]=j+2&65535;j=i&65535|e;e=k+6|0;c[348392]=e;if((e|0)<(l|0)){o=b[520833]|0;p=o&65535;q=p+j|0;r=a[1041660]|0;j2(r,q);s=a[1041660]|0;a[1044496]=s;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));o=b[520833]|0;p=o&65535;q=p+j|0;r=a[1041660]|0;j2(r,q);s=a[1041660]|0;a[1044496]=s;return}function mA(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=c[276674]|0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=(d[f+(h+1)|0]|0)<<8|(d[f+h|0]|0);h=(c[348392]|0)+(c[348400]|0)|0;c[348392]=h;f=c[348406]|0;if((h|0)<(f|0)){j=g;k=h;l=f}else{do{j1();m=c[348392]|0;n=c[348406]|0;}while((m|0)>=(n|0));j=b[520836]|0;k=m;l=n}b[520836]=j+2&65535;j=i&65535|e;e=k+6|0;c[348392]=e;if((e|0)<(l|0)){o=b[520833]|0;p=o&65535;q=p+j|0;j2(0,q);a[1044496]=0;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));o=b[520833]|0;p=o&65535;q=p+j|0;j2(0,q);a[1044496]=0;return}function mB(){var f=0,g=0,h=0,i=0,j=0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=(d[f+(h+1)|0]|0)<<8|(d[f+h|0]|0)|(d[f+(h+2)|0]|0)<<16;h=(c[348399]|0)+(c[348400]|0)+(c[348392]|0)|0;c[348392]=h;if((h|0)<(c[348406]|0)){j=g}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));j=b[520836]|0}b[520836]=j+3&65535;j2(a[1041660]|0,(e[520833]|0)+i|0);a[1044496]=a[1041660]|0;return}function mC(){var d=0,e=0,f=0,g=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;if((f|0)<(c[348406]|0)){g=d}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));g=b[520836]|0}b[520836]=g+1&65535;a[1041668]=e;a[1106728]=e;a[1106720]=e;return}function mD(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=b[520836]|0;f=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=f;g=(c[348392]|0)+(c[348399]|0)|0;c[348392]=g;h=c[348406]|0;if((g|0)<(h|0)){i=d;j=g;k=h}else{do{j1();l=c[348392]|0;m=c[348406]|0;}while((l|0)>=(m|0));i=b[520836]|0;j=l;k=m}b[520836]=i+1&65535;i=b[520831]|0;m=i+(f&255)&65535;do{if((i&255)<<24>>24==0){n=j;o=k}else{f=j+6|0;c[348392]=f;if((f|0)<(k|0)){n=f;o=k;break}while(1){j1();f=c[348392]|0;l=c[348406]|0;if((f|0)<(l|0)){n=f;o=l;break}}}}while(0);k=(e[520833]|0)+(m&65535)|0;m=n+6|0;c[348392]=m;if((m|0)>=(o|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}o=j5(k&65535,16777215)|0;a[1044496]=(o&65535)>>>8&255;k=j0(c[276674]|o&65535)|0;a[1044496]=k;a[1041660]=k;a[1106728]=k;a[1106720]=k;return}function mE(){var d=0,e=0,f=0,g=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;if((f|0)<(c[348406]|0)){g=d}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));g=b[520836]|0}b[520836]=g+1&65535;a[1041666]=e;a[1106728]=e;a[1106720]=e;return}function mF(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}b[520836]=h+1&65535;h=(b[520832]|0)+(e&255)&65535;e=i+6|0;c[348392]=e;if((e|0)<(j|0)){m=h&65535;n=j0(m)|0;a[1044496]=n;a[1041660]=n;a[1106728]=n;a[1106720]=n;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));m=h&65535;n=j0(m)|0;a[1044496]=n;a[1041660]=n;a[1106728]=n;a[1106720]=n;return}function mG(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}b[520836]=h+1&65535;h=b[520831]|0;l=h+(e&255)&65535;do{if((h&255)<<24>>24!=0){e=i+6|0;c[348392]=e;if((e|0)<(j|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j=j0(l&65535)|0;a[1044496]=j;a[1041668]=j;a[1106728]=j;a[1106720]=j;return}function mH(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}b[520836]=h+1&65535;h=b[520831]|0;l=h+(e&255)&65535;do{if((h&255)<<24>>24!=0){e=i+6|0;c[348392]=e;if((e|0)<(j|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j=j0(l&65535)|0;a[1044496]=j;a[1041660]=j;a[1106728]=j;a[1106720]=j;return}function mI(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}b[520836]=h+1&65535;h=b[520831]|0;l=h+(e&255)&65535;do{if((h&255)<<24>>24!=0){e=i+6|0;c[348392]=e;if((e|0)<(j|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j=j0(l&65535)|0;a[1044496]=j;a[1041666]=j;a[1106728]=j;a[1106720]=j;return}function mJ(){var b=0;b=j0(xb()|0)|0;a[1044496]=b;a[1041660|0]=b;a[1106728]=b;a[1106720]=b;return}function mK(){var b=0;b=(c[348392]|0)+6|0;c[348392]=b;if((b|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}b=a[1041660]|0;a[1041668]=b;a[1106728]=b;a[1106720]=b;return}function mL(){var d=0,e=0,f=0,g=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;if((f|0)<(c[348406]|0)){g=d}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));g=b[520836]|0}b[520836]=g+1&65535;a[1041660]=e;a[1106728]=e;a[1106720]=e;return}function mM(){var b=0;b=(c[348392]|0)+6|0;c[348392]=b;if((b|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}b=a[1041660]|0;a[1041666]=b;a[1106728]=b;a[1106720]=b;return}function mN(){var d=0,e=0;d=(c[348392]|0)+12|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}d=(b[520832]|0)+1&65535;b[520832]=d;e=j0(d&65535)|0;a[1041656]=e;a[1106728]=e;a[1106720]=e;c[276674]=(e&255)<<16;a[1044496]=e;return}function mO(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=c[276674]|0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[1044496]=i;i=(c[348392]|0)+(c[348400]|0)|0;c[348392]=i;if((i|0)<(c[348406]|0)){k=g}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));k=b[520836]|0}b[520836]=k+2&65535;k=j0(j&65535|e)|0;a[1044496]=k;a[1041668]=k;a[1106728]=k;a[1106720]=k;return}function mP(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=c[276674]|0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[1044496]=i;i=(c[348392]|0)+(c[348400]|0)|0;c[348392]=i;if((i|0)<(c[348406]|0)){k=g}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));k=b[520836]|0}b[520836]=k+2&65535;k=j0(j&65535|e)|0;a[1044496]=k;a[1041660]=k;a[1106728]=k;a[1106720]=k;return}function mQ(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=c[276674]|0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[1044496]=i;i=(c[348392]|0)+(c[348400]|0)|0;c[348392]=i;if((i|0)<(c[348406]|0)){k=g}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));k=b[520836]|0}b[520836]=k+2&65535;k=j0(j&65535|e)|0;a[1044496]=k;a[1041666]=k;a[1106728]=k;a[1106720]=k;return}function mR(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[348396]|0;f=b[520836]|0;g=f&65535;h=a[e+(g+2)|0]|0;i=(d[e+(g+1)|0]|0)<<8|(d[e+g|0]|0)|(h&255)<<16;g=(c[348399]|0)+(c[348400]|0)+(c[348392]|0)|0;c[348392]=g;if((g|0)<(c[348406]|0)){j=f}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));j=b[520836]|0}a[1044496]=h;b[520836]=j+3&65535;j=j0(i)|0;a[1044496]=j;a[1041660]=j;a[1106728]=j;a[1106720]=j;return}function mS(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}l=h+1&65535;b[520836]=l;h=(l&65535)+(e<<24>>24)|0;e=h&65535;k=h&65535;if((a[1106736]|0)==0){return}g=i+6|0;c[348392]=g;if((g|0)<(j|0)){m=l}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));m=b[520836]|0}if(((m&65535^h)&61440|0)==0){b[520836]=k;return}else{j4((c[276676]|0)+e|0);return}}function mT(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=b[520836]|0;g=a[(c[348396]|0)+(f&65535)|0]|0;a[1044496]=g;h=(c[348392]|0)+(c[348399]|0)|0;c[348392]=h;i=c[348406]|0;if((h|0)<(i|0)){j=f;k=h;l=i}else{do{j1();m=c[348392]|0;n=c[348406]|0;}while((m|0)>=(n|0));j=b[520836]|0;k=m;l=n}b[520836]=j+1&65535;j=b[520831]|0;n=j+(g&255)&65535;do{if((j&255)<<24>>24!=0){g=k+6|0;c[348392]=g;if((g|0)<(l|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);l=j5(n&65535,16777215)|0;a[1044496]=(l&65535)>>>8&255;n=c[276674]|l&65535;do{if(((d[1041668]|0)+(n&255)|0)>>>0>255){l=(c[348392]|0)+6|0;c[348392]=l;if((l|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);l=j0((e[520834]|0)+n|0)|0;a[1044496]=l;a[1041660]=l;a[1106728]=l;a[1106720]=l;return}function mU(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}b[520836]=h+1&65535;h=b[520831]|0;l=h+(e&255)&65535;do{if((h&255)<<24>>24!=0){e=i+6|0;c[348392]=e;if((e|0)<(j|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j=j5(l&65535,16777215)|0;a[1044496]=(j&65535)>>>8&255;l=j0(c[276674]|j&65535)|0;a[1044496]=l;a[1041660]=l;a[1106728]=l;a[1106720]=l;return}function mV(){var d=0,f=0,g=0;d=j0(c[260418]|0)|0;a[1044496]=d;b[520836]=(b[520836]|0)+1&65535;f=(b[520832]|0)+(d&255)&65535;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}d=j5(f&65535,16777215)|0;a[1044496]=(d&65535)>>>8&255;f=(e[520834]|0)+(d&65535)+(c[276674]|0)&16777215;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)<(c[348406]|0)){g=j0(f)|0;a[1044496]=g;a[1041660]=g;a[1106728]=g;a[1106720]=g;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));g=j0(f)|0;a[1044496]=g;a[1041660]=g;a[1106728]=g;a[1106720]=g;return}function mW(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=b[520836]|0;f=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=f;g=(c[348392]|0)+(c[348399]|0)|0;c[348392]=g;h=c[348406]|0;if((g|0)<(h|0)){i=d;j=g;k=h}else{do{j1();l=c[348392]|0;m=c[348406]|0;}while((l|0)>=(m|0));i=b[520836]|0;j=l;k=m}b[520836]=i+1&65535;i=b[520831]|0;m=i+(f&255)&65535;do{if((i&255)<<24>>24==0){n=j;o=k}else{f=j+6|0;c[348392]=f;if((f|0)<(k|0)){n=f;o=k;break}while(1){j1();f=c[348392]|0;l=c[348406]|0;if((f|0)<(l|0)){n=f;o=l;break}}}}while(0);k=(e[520833]|0)+(m&65535)|0;m=n+6|0;c[348392]=m;if((m|0)<(o|0)){p=k&65535;q=j0(p)|0;a[1044496]=q;a[1041668]=q;a[1106728]=q;a[1106720]=q;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));p=k&65535;q=j0(p)|0;a[1044496]=q;a[1041668]=q;a[1106728]=q;a[1106720]=q;return}function mX(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=b[520836]|0;f=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=f;g=(c[348392]|0)+(c[348399]|0)|0;c[348392]=g;h=c[348406]|0;if((g|0)<(h|0)){i=d;j=g;k=h}else{do{j1();l=c[348392]|0;m=c[348406]|0;}while((l|0)>=(m|0));i=b[520836]|0;j=l;k=m}b[520836]=i+1&65535;i=b[520831]|0;m=i+(f&255)&65535;do{if((i&255)<<24>>24==0){n=j;o=k}else{f=j+6|0;c[348392]=f;if((f|0)<(k|0)){n=f;o=k;break}while(1){j1();f=c[348392]|0;l=c[348406]|0;if((f|0)<(l|0)){n=f;o=l;break}}}}while(0);k=(e[520833]|0)+(m&65535)|0;m=n+6|0;c[348392]=m;if((m|0)<(o|0)){p=k&65535;q=j0(p)|0;a[1044496]=q;a[1041660]=q;a[1106728]=q;a[1106720]=q;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));p=k&65535;q=j0(p)|0;a[1044496]=q;a[1041660]=q;a[1106728]=q;a[1106720]=q;return}function mY(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=b[520836]|0;f=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=f;g=(c[348392]|0)+(c[348399]|0)|0;c[348392]=g;h=c[348406]|0;if((g|0)<(h|0)){i=d;j=g;k=h}else{do{j1();l=c[348392]|0;m=c[348406]|0;}while((l|0)>=(m|0));i=b[520836]|0;j=l;k=m}b[520836]=i+1&65535;i=b[520831]|0;m=i+(f&255)&65535;do{if((i&255)<<24>>24==0){n=j;o=k}else{f=j+6|0;c[348392]=f;if((f|0)<(k|0)){n=f;o=k;break}while(1){j1();f=c[348392]|0;l=c[348406]|0;if((f|0)<(l|0)){n=f;o=l;break}}}}while(0);k=(e[520834]|0)+(m&65535)|0;m=n+6|0;c[348392]=m;if((m|0)<(o|0)){p=k&65535;q=j0(p)|0;a[1044496]=q;a[1041666]=q;a[1106728]=q;a[1106720]=q;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));p=k&65535;q=j0(p)|0;a[1044496]=q;a[1041666]=q;a[1106728]=q;a[1106720]=q;return}function mZ(){var b=0,c=0;b=xb()|0;c=j0((e[520834]|0)+b|0)|0;a[1044496]=c;a[1041660]=c;a[1106728]=c;a[1106720]=c;return}function m_(){var b=0;a[1106712]=0;b=(c[348392]|0)+6|0;c[348392]=b;if((b|0)<(c[348406]|0)){return}do{j1();}while((c[348392]|0)>=(c[348406]|0));return}function m$(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;do{if(((d[1041668]|0)+(l&255)|0)>>>0>255){f=m+6|0;c[348392]=f;if((f|0)<(n|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);n=j0((e[520834]|0)+l|0)|0;a[1044496]=n;a[1041660]=n;a[1106728]=n;a[1106720]=n;return}function m0(){var b=0;b=(c[348392]|0)+6|0;c[348392]=b;if((b|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}b=a[1041664]|0;a[1041666]=b;a[1106728]=b;a[1106720]=b;return}function m1(){var b=0;b=(c[348392]|0)+6|0;c[348392]=b;if((b|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}b=a[1041668]|0;a[1041666]=b;a[1106728]=b;a[1106720]=b;return}function m2(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;do{if(((d[1041666]|0)+(l&255)|0)>>>0>255){f=m+6|0;c[348392]=f;if((f|0)<(n|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);n=j0((e[520833]|0)+l|0)|0;a[1044496]=n;a[1041668]=n;a[1106728]=n;a[1106720]=n;return}function m3(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;do{if(((d[1041666]|0)+(l&255)|0)>>>0>255){f=m+6|0;c[348392]=f;if((f|0)<(n|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);n=j0((e[520833]|0)+l|0)|0;a[1044496]=n;a[1041660]=n;a[1106728]=n;a[1106720]=n;return}function m4(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;do{if(((d[1041668]|0)+(l&255)|0)>>>0>255){f=m+6|0;c[348392]=f;if((f|0)<(n|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);n=j0((e[520834]|0)+l|0)|0;a[1044496]=n;a[1041666]=n;a[1106728]=n;a[1106720]=n;return}function m5(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=a[f+(h+2)|0]|0;j=(d[f+(h+1)|0]|0)<<8|(d[f+h|0]|0)|(i&255)<<16;h=(c[348399]|0)+(c[348400]|0)+(c[348392]|0)|0;c[348392]=h;if((h|0)<(c[348406]|0)){k=g}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));k=b[520836]|0}a[1044496]=i;b[520836]=k+3&65535;k=j0((e[520833]|0)+j|0)|0;a[1044496]=k;a[1041660]=k;a[1106728]=k;a[1106720]=k;return}function m6(){var e=0,f=0,g=0,h=0,i=0;e=d[1041668]|0;f=b[520836]|0;g=a[(c[348396]|0)+(f&65535)|0]|0;a[1044496]=g;h=(c[348392]|0)+(c[348399]|0)|0;c[348392]=h;if((h|0)<(c[348406]|0)){i=f}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));i=b[520836]|0}b[520836]=i+1&65535;i=e-(g&255)&65535;a[1106736]=(i&65535)>>>15&255^1;g=i&255;a[1106728]=g;a[1106720]=g;return}function m7(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=b[520836]|0;g=a[(c[348396]|0)+(f&65535)|0]|0;a[1044496]=g;h=(c[348392]|0)+(c[348399]|0)|0;c[348392]=h;i=c[348406]|0;if((h|0)<(i|0)){j=f;k=h;l=i}else{do{j1();m=c[348392]|0;n=c[348406]|0;}while((m|0)>=(n|0));j=b[520836]|0;k=m;l=n}b[520836]=j+1&65535;j=b[520831]|0;n=j+(g&255)&65535;do{if((j&255)<<24>>24==0){o=k;p=l}else{g=k+6|0;c[348392]=g;if((g|0)<(l|0)){o=g;p=l;break}while(1){j1();g=c[348392]|0;m=c[348406]|0;if((g|0)<(m|0)){o=g;p=m;break}}}}while(0);l=(e[520833]|0)+(n&65535)|0;n=o+6|0;c[348392]=n;if((n|0)>=(p|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}p=j5(l&65535,16777215)|0;a[1044496]=(p&65535)>>>8&255;l=j0(c[276674]|p&65535)|0;a[1044496]=l;p=(d[1041660]|0)-(l&255)&65535;a[1106736]=(p&65535)>>>15&255^1;l=p&255;a[1106728]=l;a[1106720]=l;return}function m8(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}b[520836]=h+1&65535;h=~e;a[1041658]=a[1041658]&h;a[1106736]=a[1106736]&h;a[1106712]=a[1106712]&(h&255)>>>6;a[1106720]=a[1106720]&h;a[1106728]=a[1106728]|h&2^2;h=i+6|0;c[348392]=h;if((h|0)>=(j|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}j=b[520829]|0;if((j&256)==0){m=j&255;n=j}else{h=j|48;b[520829]=h;m=h&255;n=h}if((m&16)!=0){a[1041667|0]=0;a[1041669|0]=0}if((n&256)!=0){c[276688]=158776;c[276686]=159800;return}m=n&255;n=(m&16|0)!=0;if((m&32|0)==0){if(n){c[276688]=156728;c[276686]=160312;return}else{c[276688]=157752;c[276686]=160568;return}}else{if(n){c[276688]=154680;c[276686]=159800;return}else{c[276688]=155704;c[276686]=160056;return}}}function m9(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=b[520836]|0;f=a[(c[348396]|0)+(e&65535)|0]|0;a[1044496]=f;g=(c[348392]|0)+(c[348399]|0)|0;c[348392]=g;h=c[348406]|0;if((g|0)<(h|0)){i=e;j=g;k=h}else{do{j1();l=c[348392]|0;m=c[348406]|0;}while((l|0)>=(m|0));i=b[520836]|0;j=l;k=m}b[520836]=i+1&65535;i=(b[520832]|0)+(f&255)&65535;f=j+6|0;c[348392]=f;if((f|0)>=(k|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}k=j0(i&65535)|0;a[1044496]=k;i=(d[1041660]|0)-(k&255)&65535;a[1106736]=(i&65535)>>>15&255^1;k=i&255;a[1106728]=k;a[1106720]=k;return}function na(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=b[520836]|0;f=a[(c[348396]|0)+(e&65535)|0]|0;a[1044496]=f;g=(c[348392]|0)+(c[348399]|0)|0;c[348392]=g;h=c[348406]|0;if((g|0)<(h|0)){i=e;j=g;k=h}else{do{j1();l=c[348392]|0;m=c[348406]|0;}while((l|0)>=(m|0));i=b[520836]|0;j=l;k=m}b[520836]=i+1&65535;i=b[520831]|0;m=i+(f&255)&65535;do{if((i&255)<<24>>24!=0){f=j+6|0;c[348392]=f;if((f|0)<(k|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);k=j0(m&65535)|0;a[1044496]=k;m=(d[1041668]|0)-(k&255)&65535;a[1106736]=(m&65535)>>>15&255^1;k=m&255;a[1106728]=k;a[1106720]=k;return}function nb(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=b[520836]|0;f=a[(c[348396]|0)+(e&65535)|0]|0;a[1044496]=f;g=(c[348392]|0)+(c[348399]|0)|0;c[348392]=g;h=c[348406]|0;if((g|0)<(h|0)){i=e;j=g;k=h}else{do{j1();l=c[348392]|0;m=c[348406]|0;}while((l|0)>=(m|0));i=b[520836]|0;j=l;k=m}b[520836]=i+1&65535;i=b[520831]|0;m=i+(f&255)&65535;do{if((i&255)<<24>>24!=0){f=j+6|0;c[348392]=f;if((f|0)<(k|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);k=j0(m&65535)|0;a[1044496]=k;m=(d[1041660]|0)-(k&255)&65535;a[1106736]=(m&65535)>>>15&255^1;k=m&255;a[1106728]=k;a[1106720]=k;return}function nc(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}b[520836]=h+1&65535;h=b[520831]|0;l=h+(e&255)&65535;do{if((h&255)<<24>>24!=0){e=i+6|0;c[348392]=e;if((e|0)<(j|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j=l&65535;l=(j0(j)|0)-1&255;i=(c[348392]|0)+6|0;c[348392]=i;if((i|0)<(c[348406]|0)){j2(l,j);a[1044496]=l;a[1106728]=l;a[1106720]=l;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));j2(l,j);a[1044496]=l;a[1106728]=l;a[1106720]=l;return}function nd(){var b=0,c=0;b=j0(xb()|0)|0;a[1044496]=b;c=(d[1041660]|0)-(b&255)&65535;a[1106736]=(c&65535)>>>15&255^1;b=c&255;a[1106728]=b;a[1106720]=b;return}function ne(){var b=0;b=(c[348392]|0)+6|0;c[348392]=b;if((b|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}b=(a[1041668]|0)+1&255;a[1041668]=b;a[1106728]=b;a[1106720]=b;return}function nf(){var e=0,f=0,g=0,h=0,i=0;e=d[1041660]|0;f=b[520836]|0;g=a[(c[348396]|0)+(f&65535)|0]|0;a[1044496]=g;h=(c[348392]|0)+(c[348399]|0)|0;c[348392]=h;if((h|0)<(c[348406]|0)){i=f}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));i=b[520836]|0}b[520836]=i+1&65535;i=e-(g&255)&65535;a[1106736]=(i&65535)>>>15&255^1;g=i&255;a[1106728]=g;a[1106720]=g;return}function ng(){var b=0;b=(c[348392]|0)+6|0;c[348392]=b;if((b|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}b=(a[1041666]|0)-1&255;a[1041666]=b;a[1106728]=b;a[1106720]=b;return}function nh(){var d=0;a[1393628]=1;b[520836]=(b[520836]|0)-1&65535;d=(c[348392]|0)+12|0;c[348392]=d;if((d|0)<(c[348406]|0)){return}do{j1();}while((c[348392]|0)>=(c[348406]|0));return}function ni(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=c[276674]|0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[1044496]=i;i=(c[348392]|0)+(c[348400]|0)|0;c[348392]=i;if((i|0)<(c[348406]|0)){k=g}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));k=b[520836]|0}b[520836]=k+2&65535;k=j0(j&65535|e)|0;a[1044496]=k;e=(d[1041668]|0)-(k&255)&65535;a[1106736]=(e&65535)>>>15&255^1;k=e&255;a[1106728]=k;a[1106720]=k;return}function nj(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=c[276674]|0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[1044496]=i;i=(c[348392]|0)+(c[348400]|0)|0;c[348392]=i;if((i|0)<(c[348406]|0)){k=g}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));k=b[520836]|0}b[520836]=k+2&65535;k=j0(j&65535|e)|0;a[1044496]=k;e=(d[1041660]|0)-(k&255)&65535;a[1106736]=(e&65535)>>>15&255^1;k=e&255;a[1106728]=k;a[1106720]=k;return}function nk(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=c[276674]|0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[1044496]=i;i=(c[348392]|0)+(c[348400]|0)|0;c[348392]=i;if((i|0)<(c[348406]|0)){k=g}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));k=b[520836]|0}b[520836]=k+2&65535;k=j&65535|e;e=(j0(k)|0)-1&255;j=(c[348392]|0)+6|0;c[348392]=j;if((j|0)<(c[348406]|0)){j2(e,k);a[1044496]=e;a[1106728]=e;a[1106720]=e;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));j2(e,k);a[1044496]=e;a[1106728]=e;a[1106720]=e;return}function nl(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[348396]|0;f=b[520836]|0;g=f&65535;h=a[e+(g+2)|0]|0;i=(d[e+(g+1)|0]|0)<<8|(d[e+g|0]|0)|(h&255)<<16;g=(c[348399]|0)+(c[348400]|0)+(c[348392]|0)|0;c[348392]=g;if((g|0)<(c[348406]|0)){j=f}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));j=b[520836]|0}a[1044496]=h;b[520836]=j+3&65535;j=j0(i)|0;a[1044496]=j;i=(d[1041660]|0)-(j&255)&65535;a[1106736]=(i&65535)>>>15&255^1;j=i&255;a[1106728]=j;a[1106720]=j;return}function nm(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}l=h+1&65535;b[520836]=l;h=(l&65535)+(e<<24>>24)|0;e=h&65535;k=h&65535;if((a[1106728]|0)==0){return}g=i+6|0;c[348392]=g;if((g|0)<(j|0)){m=l}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));m=b[520836]|0}if(((m&65535^h)&61440|0)==0){b[520836]=k;return}else{j4((c[276676]|0)+e|0);return}}function nn(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=b[520836]|0;g=a[(c[348396]|0)+(f&65535)|0]|0;a[1044496]=g;h=(c[348392]|0)+(c[348399]|0)|0;c[348392]=h;i=c[348406]|0;if((h|0)<(i|0)){j=f;k=h;l=i}else{do{j1();m=c[348392]|0;n=c[348406]|0;}while((m|0)>=(n|0));j=b[520836]|0;k=m;l=n}b[520836]=j+1&65535;j=b[520831]|0;n=j+(g&255)&65535;do{if((j&255)<<24>>24!=0){g=k+6|0;c[348392]=g;if((g|0)<(l|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);l=j5(n&65535,16777215)|0;a[1044496]=(l&65535)>>>8&255;n=c[276674]|l&65535;do{if(((d[1041668]|0)+(n&255)|0)>>>0>255){l=(c[348392]|0)+6|0;c[348392]=l;if((l|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);l=j0((e[520834]|0)+n|0)|0;a[1044496]=l;n=(d[1041660]|0)-(l&255)&65535;a[1106736]=(n&65535)>>>15&255^1;l=n&255;a[1106728]=l;a[1106720]=l;return}function no(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=b[520836]|0;f=a[(c[348396]|0)+(e&65535)|0]|0;a[1044496]=f;g=(c[348392]|0)+(c[348399]|0)|0;c[348392]=g;h=c[348406]|0;if((g|0)<(h|0)){i=e;j=g;k=h}else{do{j1();l=c[348392]|0;m=c[348406]|0;}while((l|0)>=(m|0));i=b[520836]|0;j=l;k=m}b[520836]=i+1&65535;i=b[520831]|0;m=i+(f&255)&65535;do{if((i&255)<<24>>24!=0){f=j+6|0;c[348392]=f;if((f|0)<(k|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);k=j5(m&65535,16777215)|0;a[1044496]=(k&65535)>>>8&255;m=j0(c[276674]|k&65535)|0;a[1044496]=m;k=(d[1041660]|0)-(m&255)&65535;a[1106736]=(k&65535)>>>15&255^1;m=k&255;a[1106728]=m;a[1106720]=m;return}function np(){var f=0,g=0;f=j0(c[260418]|0)|0;a[1044496]=f;b[520836]=(b[520836]|0)+1&65535;g=(b[520832]|0)+(f&255)&65535;f=(c[348392]|0)+6|0;c[348392]=f;if((f|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}f=j5(g&65535,16777215)|0;a[1044496]=(f&65535)>>>8&255;g=(e[520834]|0)+(f&65535)+(c[276674]|0)&16777215;f=(c[348392]|0)+6|0;c[348392]=f;if((f|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}f=j0(g)|0;a[1044496]=f;g=(d[1041660]|0)-(f&255)&65535;a[1106736]=(g&65535)>>>15&255^1;f=g&255;a[1106728]=f;a[1106720]=f;return}function nq(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b[520836]|0;f=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=f;g=(c[348392]|0)+(c[348399]|0)|0;c[348392]=g;h=c[348406]|0;if((g|0)<(h|0)){i=d;j=g;k=h}else{do{j1();l=c[348392]|0;m=c[348406]|0;}while((l|0)>=(m|0));i=b[520836]|0;j=l;k=m}b[520836]=i+1&65535;i=b[520831]|0;m=i+(f&255)&65535;do{if((i&255)<<24>>24!=0){f=j+6|0;c[348392]=f;if((f|0)<(k|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);k=(j5(m&65535,16777215)|0)&65535;m=c[276674]|k;j3(m&65535,(e[520832]|0)-1|0,65535);b[520832]=(b[520832]|0)-2&65535;a[1044496]=m&255;return}function nr(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=b[520836]|0;g=a[(c[348396]|0)+(f&65535)|0]|0;a[1044496]=g;h=(c[348392]|0)+(c[348399]|0)|0;c[348392]=h;i=c[348406]|0;if((h|0)<(i|0)){j=f;k=h;l=i}else{do{j1();m=c[348392]|0;n=c[348406]|0;}while((m|0)>=(n|0));j=b[520836]|0;k=m;l=n}b[520836]=j+1&65535;j=b[520831]|0;n=j+(g&255)&65535;do{if((j&255)<<24>>24==0){o=k;p=l}else{g=k+6|0;c[348392]=g;if((g|0)<(l|0)){o=g;p=l;break}while(1){j1();g=c[348392]|0;m=c[348406]|0;if((g|0)<(m|0)){o=g;p=m;break}}}}while(0);l=(e[520833]|0)+(n&65535)|0;n=o+6|0;c[348392]=n;if((n|0)>=(p|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}p=j0(l&65535)|0;a[1044496]=p;l=(d[1041660]|0)-(p&255)&65535;a[1106736]=(l&65535)>>>15&255^1;p=l&255;a[1106728]=p;a[1106720]=p;return}function ns(){b[520836]=(b[520836]|0)-1&65535;c[348395]=c[348395]|4097;return}function nt(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=b[520836]|0;f=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=f;g=(c[348392]|0)+(c[348399]|0)|0;c[348392]=g;h=c[348406]|0;if((g|0)<(h|0)){i=d;j=g;k=h}else{do{j1();l=c[348392]|0;m=c[348406]|0;}while((l|0)>=(m|0));i=b[520836]|0;j=l;k=m}b[520836]=i+1&65535;i=b[520831]|0;m=i+(f&255)&65535;do{if((i&255)<<24>>24==0){n=j;o=k}else{f=j+6|0;c[348392]=f;if((f|0)<(k|0)){n=f;o=k;break}while(1){j1();f=c[348392]|0;l=c[348406]|0;if((f|0)<(l|0)){n=f;o=l;break}}}}while(0);k=(e[520833]|0)+(m&65535)|0;m=n+6|0;c[348392]=m;if((m|0)>=(o|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}o=k&65535;k=(j0(o)|0)-1&255;m=(c[348392]|0)+6|0;c[348392]=m;if((m|0)<(c[348406]|0)){j2(k,o);a[1044496]=k;a[1106728]=k;a[1106720]=k;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));j2(k,o);a[1044496]=k;a[1106728]=k;a[1106720]=k;return}function nu(){var b=0,c=0;b=xb()|0;c=j0((e[520834]|0)+b|0)|0;a[1044496]=c;b=(d[1041660]|0)-(c&255)&65535;a[1106736]=(b&65535)>>>15&255^1;c=b&255;a[1106728]=c;a[1106720]=c;return}function nv(){var b=0;a[1041658]=a[1041658]&-9;b=(c[348392]|0)+6|0;c[348392]=b;if((b|0)<(c[348406]|0)){return}do{j1();}while((c[348392]|0)>=(c[348406]|0));return}function nw(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;do{if(((d[1041668]|0)+(l&255)|0)>>>0>255){f=m+6|0;c[348392]=f;if((f|0)<(n|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);n=j0((e[520834]|0)+l|0)|0;a[1044496]=n;l=(d[1041660]|0)-(n&255)&65535;a[1106736]=(l&65535)>>>15&255^1;n=l&255;a[1106728]=n;a[1106720]=n;return}function nx(){var d=0,e=0;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}d=a[1041666]|0;e=b[520832]|0;b[520832]=e-1&65535;j2(d,e&65535);a[1044496]=a[1041666]|0;return}function ny(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[348396]|0;f=b[520836]|0;g=f&65535;h=a[e+(g+1)|0]|0;i=(h&255)<<8|(d[e+g|0]|0);a[1044496]=h;h=(c[348392]|0)+(c[348400]|0)|0;c[348392]=h;if((h|0)<(c[348406]|0)){j=f}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));j=b[520836]|0}b[520836]=j+2&65535;j=i&65535;i=j5(j,16777215)|0;a[1044496]=(i&65535)>>>8&255;f=j0(j+2|0)|0;a[1044496]=f;j4((f&255)<<16|i&65535);return}function nz(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;do{if(((d[1041666]|0)+(l&255)|0)>>>0>255){f=m+6|0;c[348392]=f;if((f|0)<(n|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);n=j0((e[520833]|0)+l|0)|0;a[1044496]=n;l=(d[1041660]|0)-(n&255)&65535;a[1106736]=(l&65535)>>>15&255^1;n=l&255;a[1106728]=n;a[1106720]=n;return}function nA(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;f=m+6|0;c[348392]=f;if((f|0)>=(n|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}n=(e[520833]|0)+l|0;l=(j0(n)|0)-1&255;f=(c[348392]|0)+6|0;c[348392]=f;if((f|0)<(c[348406]|0)){j2(l,n);a[1044496]=l;a[1106728]=l;a[1106720]=l;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));j2(l,n);a[1044496]=l;a[1106728]=l;a[1106720]=l;return}function nB(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=a[f+(h+2)|0]|0;j=(d[f+(h+1)|0]|0)<<8|(d[f+h|0]|0)|(i&255)<<16;h=(c[348399]|0)+(c[348400]|0)+(c[348392]|0)|0;c[348392]=h;if((h|0)<(c[348406]|0)){k=g}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));k=b[520836]|0}a[1044496]=i;b[520836]=k+3&65535;k=j0((e[520833]|0)+j|0)|0;a[1044496]=k;j=(d[1041660]|0)-(k&255)&65535;a[1106736]=(j&65535)>>>15&255^1;k=j&255;a[1106728]=k;a[1106720]=k;return}function nC(){var e=0,f=0,g=0,h=0,i=0;e=d[1041666]|0;f=b[520836]|0;g=a[(c[348396]|0)+(f&65535)|0]|0;a[1044496]=g;h=(c[348392]|0)+(c[348399]|0)|0;c[348392]=h;if((h|0)<(c[348406]|0)){i=f}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));i=b[520836]|0}b[520836]=i+1&65535;i=e-(g&255)&65535;a[1106736]=(i&65535)>>>15&255^1;g=i&255;a[1106728]=g;a[1106720]=g;return}function nD(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=b[520836]|0;g=a[(c[348396]|0)+(f&65535)|0]|0;a[1044496]=g;h=(c[348392]|0)+(c[348399]|0)|0;c[348392]=h;i=c[348406]|0;if((h|0)<(i|0)){j=f;k=h;l=i}else{do{j1();m=c[348392]|0;n=c[348406]|0;}while((m|0)>=(n|0));j=b[520836]|0;k=m;l=n}b[520836]=j+1&65535;j=b[520831]|0;n=j+(g&255)&65535;do{if((j&255)<<24>>24==0){o=k;p=l}else{g=k+6|0;c[348392]=g;if((g|0)<(l|0)){o=g;p=l;break}while(1){j1();g=c[348392]|0;m=c[348406]|0;if((g|0)<(m|0)){o=g;p=m;break}}}}while(0);l=(e[520833]|0)+(n&65535)|0;n=o+6|0;c[348392]=n;if((n|0)>=(p|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}p=j5(l&65535,16777215)|0;a[1044496]=(p&65535)>>>8&255;l=j0(c[276674]|p&65535)|0;a[1044496]=l;if((a[1041658]&8)==0){p=a[1041660]|0;n=((p&255)+~(l&255)&65535)+(d[1106736]|0)&65535;a[1106736]=(n&65535)>>>15&255^1;o=n&255;q=o;r=(o^p)&(p^l);s=(r&255)>>>7;a[1106712]=s;a[1041660]=q;a[1106728]=q;a[1106720]=q;return}p=b[520830]|0;o=p&255;n=((o&15)-(l&15)&255)-((a[1106736]|0)==0)&255;k=(p&240)-(l&-16&255)&65535;if((n&255)>15){t=n+10&15;u=k-16&65535}else{t=n;u=k}if((u&65535)>240){a[1106736]=0;v=u+160&255&-16}else{a[1106736]=1;v=u&255}u=v|t;q=u;r=(u^o)&(o^l);s=(r&255)>>>7;a[1106712]=s;a[1041660]=q;a[1106728]=q;a[1106720]=q;return}function nE(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}b[520836]=h+1&65535;a[1041658]=a[1041658]|e;a[1106736]=a[1106736]|e&1;a[1106712]=a[1106712]|(e&255)>>>6&1;a[1106720]=a[1106720]|e;if((e&2)!=0){a[1106728]=0}e=i+6|0;c[348392]=e;if((e|0)>=(j|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}j=b[520829]|0;if((j&256)==0){m=j&255;n=j}else{e=j|48;b[520829]=e;m=e&255;n=e}if((m&16)!=0){a[1041667|0]=0;a[1041669|0]=0}if((n&256)!=0){c[276688]=158776;c[276686]=159800;return}m=n&255;n=(m&16|0)!=0;if((m&32|0)==0){if(n){c[276688]=156728;c[276686]=160312;return}else{c[276688]=157752;c[276686]=160568;return}}else{if(n){c[276688]=154680;c[276686]=159800;return}else{c[276688]=155704;c[276686]=160056;return}}}function nF(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=b[520836]|0;f=a[(c[348396]|0)+(e&65535)|0]|0;a[1044496]=f;g=(c[348392]|0)+(c[348399]|0)|0;c[348392]=g;h=c[348406]|0;if((g|0)<(h|0)){i=e;j=g;k=h}else{do{j1();l=c[348392]|0;m=c[348406]|0;}while((l|0)>=(m|0));i=b[520836]|0;j=l;k=m}b[520836]=i+1&65535;i=(b[520832]|0)+(f&255)&65535;f=j+6|0;c[348392]=f;if((f|0)>=(k|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}k=j0(i&65535)|0;a[1044496]=k;if((a[1041658]&8)==0){i=a[1041660]|0;f=((i&255)+~(k&255)&65535)+(d[1106736]|0)&65535;a[1106736]=(f&65535)>>>15&255^1;j=f&255;n=j;o=(j^i)&(i^k);p=(o&255)>>>7;a[1106712]=p;a[1041660]=n;a[1106728]=n;a[1106720]=n;return}i=b[520830]|0;j=i&255;f=((j&15)-(k&15)&255)-((a[1106736]|0)==0)&255;m=(i&240)-(k&-16&255)&65535;if((f&255)>15){q=f+10&15;r=m-16&65535}else{q=f;r=m}if((r&65535)>240){a[1106736]=0;s=r+160&255&-16}else{a[1106736]=1;s=r&255}r=s|q;n=r;o=(r^j)&(j^k);p=(o&255)>>>7;a[1106712]=p;a[1041660]=n;a[1106728]=n;a[1106720]=n;return}function nG(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=b[520836]|0;f=a[(c[348396]|0)+(e&65535)|0]|0;a[1044496]=f;g=(c[348392]|0)+(c[348399]|0)|0;c[348392]=g;h=c[348406]|0;if((g|0)<(h|0)){i=e;j=g;k=h}else{do{j1();l=c[348392]|0;m=c[348406]|0;}while((l|0)>=(m|0));i=b[520836]|0;j=l;k=m}b[520836]=i+1&65535;i=b[520831]|0;m=i+(f&255)&65535;do{if((i&255)<<24>>24!=0){f=j+6|0;c[348392]=f;if((f|0)<(k|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);k=j0(m&65535)|0;a[1044496]=k;m=(d[1041666]|0)-(k&255)&65535;a[1106736]=(m&65535)>>>15&255^1;k=m&255;a[1106728]=k;a[1106720]=k;return}function nH(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=b[520836]|0;f=a[(c[348396]|0)+(e&65535)|0]|0;a[1044496]=f;g=(c[348392]|0)+(c[348399]|0)|0;c[348392]=g;h=c[348406]|0;if((g|0)<(h|0)){i=e;j=g;k=h}else{do{j1();l=c[348392]|0;m=c[348406]|0;}while((l|0)>=(m|0));i=b[520836]|0;j=l;k=m}b[520836]=i+1&65535;i=b[520831]|0;m=i+(f&255)&65535;do{if((i&255)<<24>>24!=0){f=j+6|0;c[348392]=f;if((f|0)<(k|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);k=j0(m&65535)|0;a[1044496]=k;if((a[1041658]&8)==0){m=a[1041660]|0;j=((m&255)+~(k&255)&65535)+(d[1106736]|0)&65535;a[1106736]=(j&65535)>>>15&255^1;i=j&255;n=i;o=(i^m)&(m^k);p=(o&255)>>>7;a[1106712]=p;a[1041660]=n;a[1106728]=n;a[1106720]=n;return}m=b[520830]|0;i=m&255;j=((i&15)-(k&15)&255)-((a[1106736]|0)==0)&255;f=(m&240)-(k&-16&255)&65535;if((j&255)>15){q=j+10&15;r=f-16&65535}else{q=j;r=f}if((r&65535)>240){a[1106736]=0;s=r+160&255&-16}else{a[1106736]=1;s=r&255}r=s|q;n=r;o=(r^i)&(i^k);p=(o&255)>>>7;a[1106712]=p;a[1041660]=n;a[1106728]=n;a[1106720]=n;return}function nI(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}b[520836]=h+1&65535;h=b[520831]|0;l=h+(e&255)&65535;do{if((h&255)<<24>>24!=0){e=i+6|0;c[348392]=e;if((e|0)<(j|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j=l&65535;l=(j0(j)|0)+1&255;i=(c[348392]|0)+6|0;c[348392]=i;if((i|0)<(c[348406]|0)){j2(l,j);a[1044496]=l;a[1106728]=l;a[1106720]=l;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));j2(l,j);a[1044496]=l;a[1106728]=l;a[1106720]=l;return}function nJ(){var c=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;c=j0(xb()|0)|0;a[1044496]=c;if((a[1041658]&8)==0){e=a[1041660]|0;f=((e&255)+~(c&255)&65535)+(d[1106736]|0)&65535;a[1106736]=(f&65535)>>>15&255^1;g=f&255;h=g;i=(g^e)&(e^c);j=(i&255)>>>7;a[1106712]=j;a[1041660]=h;a[1106728]=h;a[1106720]=h;return}e=b[520830]|0;g=e&255;f=((g&15)-(c&15)&255)-((a[1106736]|0)==0)&255;k=(e&240)-(c&-16&255)&65535;if((f&255)>15){l=f+10&15;m=k-16&65535}else{l=f;m=k}if((m&65535)>240){a[1106736]=0;n=m+160&255&-16}else{a[1106736]=1;n=m&255}m=n|l;h=m;i=(m^g)&(g^c);j=(i&255)>>>7;a[1106712]=j;a[1041660]=h;a[1106728]=h;a[1106720]=h;return}function nK(){var b=0;b=(c[348392]|0)+6|0;c[348392]=b;if((b|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}b=(a[1041666]|0)+1&255;a[1041666]=b;a[1106728]=b;a[1106720]=b;return}function nL(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=b[520836]|0;f=a[(c[348396]|0)+(e&65535)|0]|0;a[1044496]=f;g=(c[348392]|0)+(c[348399]|0)|0;c[348392]=g;if((g|0)<(c[348406]|0)){h=e}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));h=b[520836]|0}b[520836]=h+1&65535;if((a[1041658]&8)==0){h=a[1041660]|0;e=((h&255)+~(f&255)&65535)+(d[1106736]|0)&65535;a[1106736]=(e&65535)>>>15&255^1;g=e&255;i=g;j=(g^h)&(h^f);k=(j&255)>>>7;a[1106712]=k;a[1041660]=i;a[1106728]=i;a[1106720]=i;return}h=b[520830]|0;g=h&255;e=((g&15)-(f&15)&255)-((a[1106736]|0)==0)&255;l=(h&240)-(f&-16&255)&65535;if((e&255)>15){m=e+10&15;n=l-16&65535}else{m=e;n=l}if((n&65535)>240){a[1106736]=0;o=n+160&255&-16}else{a[1106736]=1;o=n&255}n=o|m;i=n;j=(n^g)&(g^f);k=(j&255)>>>7;a[1106712]=k;a[1041660]=i;a[1106728]=i;a[1106720]=i;return}function nM(){var a=0;a=(c[348392]|0)+6|0;c[348392]=a;if((a|0)<(c[348406]|0)){return}do{j1();}while((c[348392]|0)>=(c[348406]|0));return}function nN(){var b=0,d=0;b=a[1041660]|0;d=a[1041661|0]|0;a[1041660]=d;a[1041661|0]=b;a[1106728]=d;a[1106720]=d;d=(c[348392]|0)+12|0;c[348392]=d;if((d|0)<(c[348406]|0)){return}do{j1();}while((c[348392]|0)>=(c[348406]|0));return}function nO(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=c[276674]|0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[1044496]=i;i=(c[348392]|0)+(c[348400]|0)|0;c[348392]=i;if((i|0)<(c[348406]|0)){k=g}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));k=b[520836]|0}b[520836]=k+2&65535;k=j0(j&65535|e)|0;a[1044496]=k;e=(d[1041666]|0)-(k&255)&65535;a[1106736]=(e&65535)>>>15&255^1;k=e&255;a[1106728]=k;a[1106720]=k;return}function nP(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=c[276674]|0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|d[f+h|0];a[1044496]=i;i=(c[348392]|0)+(c[348400]|0)|0;c[348392]=i;if((i|0)<(c[348406]|0)){k=g}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));k=b[520836]|0}b[520836]=k+2&65535;k=j0(j&65535|e)|0;a[1044496]=k;if((a[1041658]&8)==0){e=a[1041660]|0;j=((e&255)+~(k&255)&65535)+(d[1106736]|0)&65535;a[1106736]=(j&65535)>>>15&255^1;g=j&255;l=g;m=(g^e)&(e^k);n=(m&255)>>>7;a[1106712]=n;a[1041660]=l;a[1106728]=l;a[1106720]=l;return}e=b[520830]|0;g=e&255;j=((g&15)-(k&15)&255)-((a[1106736]|0)==0)&255;i=(e&240)-(k&-16&255)&65535;if((j&255)>15){o=j+10&15;p=i-16&65535}else{o=j;p=i}if((p&65535)>240){a[1106736]=0;q=p+160&255&-16}else{a[1106736]=1;q=p&255}p=q|o;l=p;m=(p^g)&(g^k);n=(m&255)>>>7;a[1106712]=n;a[1041660]=l;a[1106728]=l;a[1106720]=l;return}function nQ(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=c[276674]|0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[1044496]=i;i=(c[348392]|0)+(c[348400]|0)|0;c[348392]=i;if((i|0)<(c[348406]|0)){k=g}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));k=b[520836]|0}b[520836]=k+2&65535;k=j&65535|e;e=(j0(k)|0)+1&255;j=(c[348392]|0)+6|0;c[348392]=j;if((j|0)<(c[348406]|0)){j2(e,k);a[1044496]=e;a[1106728]=e;a[1106720]=e;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));j2(e,k);a[1044496]=e;a[1106728]=e;a[1106720]=e;return}function nR(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=c[348396]|0;f=b[520836]|0;g=f&65535;h=a[e+(g+2)|0]|0;i=d[e+(g+1)|0]<<8|d[e+g|0]|(h&255)<<16;g=(c[348399]|0)+(c[348400]|0)+(c[348392]|0)|0;c[348392]=g;if((g|0)<(c[348406]|0)){j=f}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));j=b[520836]|0}a[1044496]=h;b[520836]=j+3&65535;j=j0(i)|0;a[1044496]=j;if((a[1041658]&8)==0){i=a[1041660]|0;h=((i&255)+~(j&255)&65535)+(d[1106736]|0)&65535;a[1106736]=(h&65535)>>>15&255^1;f=h&255;k=f;l=(f^i)&(i^j);m=(l&255)>>>7;a[1106712]=m;a[1041660]=k;a[1106728]=k;a[1106720]=k;return}i=b[520830]|0;f=i&255;h=((f&15)-(j&15)&255)-((a[1106736]|0)==0)&255;g=(i&240)-(j&-16&255)&65535;if((h&255)>15){n=h+10&15;o=g-16&65535}else{n=h;o=g}if((o&65535)>240){a[1106736]=0;p=o+160&255&-16}else{a[1106736]=1;p=o&255}o=p|n;k=o;l=(o^f)&(f^j);m=(l&255)>>>7;a[1106712]=m;a[1041660]=k;a[1106728]=k;a[1106720]=k;return}function nS(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}l=h+1&65535;b[520836]=l;h=(l&65535)+(e<<24>>24)|0;e=h&65535;k=h&65535;if((a[1106728]|0)!=0){return}g=i+6|0;c[348392]=g;if((g|0)<(j|0)){m=l}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));m=b[520836]|0}if(((m&65535^h)&61440|0)==0){b[520836]=k;return}else{j4((c[276676]|0)+e|0);return}}function nT(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=b[520836]|0;g=a[(c[348396]|0)+(f&65535)|0]|0;a[1044496]=g;h=(c[348392]|0)+(c[348399]|0)|0;c[348392]=h;i=c[348406]|0;if((h|0)<(i|0)){j=f;k=h;l=i}else{do{j1();m=c[348392]|0;n=c[348406]|0;}while((m|0)>=(n|0));j=b[520836]|0;k=m;l=n}b[520836]=j+1&65535;j=b[520831]|0;n=j+(g&255)&65535;do{if((j&255)<<24>>24!=0){g=k+6|0;c[348392]=g;if((g|0)<(l|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);l=j5(n&65535,16777215)|0;a[1044496]=(l&65535)>>>8&255;n=c[276674]|l&65535;do{if(((d[1041668]|0)+(n&255)|0)>>>0>255){l=(c[348392]|0)+6|0;c[348392]=l;if((l|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);l=j0((e[520834]|0)+n|0)|0;a[1044496]=l;if((a[1041658]&8)==0){n=a[1041660]|0;k=((n&255)+~(l&255)&65535)+(d[1106736]|0)&65535;a[1106736]=(k&65535)>>>15&255^1;j=k&255;o=j;p=(j^n)&(n^l);q=(p&255)>>>7;a[1106712]=q;a[1041660]=o;a[1106728]=o;a[1106720]=o;return}n=b[520830]|0;j=n&255;k=((j&15)-(l&15)&255)-((a[1106736]|0)==0)&255;g=(n&240)-(l&-16&255)&65535;if((k&255)>15){r=k+10&15;s=g-16&65535}else{r=k;s=g}if((s&65535)>240){a[1106736]=0;t=s+160&255&-16}else{a[1106736]=1;t=s&255}s=t|r;o=s;p=(s^j)&(j^l);q=(p&255)>>>7;a[1106712]=q;a[1041660]=o;a[1106728]=o;a[1106720]=o;return}function nU(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=b[520836]|0;f=a[(c[348396]|0)+(e&65535)|0]|0;a[1044496]=f;g=(c[348392]|0)+(c[348399]|0)|0;c[348392]=g;h=c[348406]|0;if((g|0)<(h|0)){i=e;j=g;k=h}else{do{j1();l=c[348392]|0;m=c[348406]|0;}while((l|0)>=(m|0));i=b[520836]|0;j=l;k=m}b[520836]=i+1&65535;i=b[520831]|0;m=i+(f&255)&65535;do{if((i&255)<<24>>24!=0){f=j+6|0;c[348392]=f;if((f|0)<(k|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);k=j5(m&65535,16777215)|0;a[1044496]=(k&65535)>>>8&255;m=j0(c[276674]|k&65535)|0;a[1044496]=m;if((a[1041658]&8)==0){k=a[1041660]|0;j=((k&255)+~(m&255)&65535)+(d[1106736]|0)&65535;a[1106736]=(j&65535)>>>15&255^1;i=j&255;n=i;o=(i^k)&(k^m);p=(o&255)>>>7;a[1106712]=p;a[1041660]=n;a[1106728]=n;a[1106720]=n;return}k=b[520830]|0;i=k&255;j=((i&15)-(m&15)&255)-((a[1106736]|0)==0)&255;f=(k&240)-(m&-16&255)&65535;if((j&255)>15){q=j+10&15;r=f-16&65535}else{q=j;r=f}if((r&65535)>240){a[1106736]=0;s=r+160&255&-16}else{a[1106736]=1;s=r&255}r=s|q;n=r;o=(r^i)&(i^m);p=(o&255)>>>7;a[1106712]=p;a[1041660]=n;a[1106728]=n;a[1106720]=n;return}function nV(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=j0(c[260418]|0)|0;a[1044496]=f;b[520836]=(b[520836]|0)+1&65535;g=(b[520832]|0)+(f&255)&65535;f=(c[348392]|0)+6|0;c[348392]=f;if((f|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}f=j5(g&65535,16777215)|0;a[1044496]=(f&65535)>>>8&255;g=(e[520834]|0)+(f&65535)+(c[276674]|0)&16777215;f=(c[348392]|0)+6|0;c[348392]=f;if((f|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}f=j0(g)|0;a[1044496]=f;if((a[1041658]&8)==0){g=a[1041660]|0;h=((g&255)+~(f&255)&65535)+(d[1106736]|0)&65535;a[1106736]=(h&65535)>>>15&255^1;i=h&255;j=i;k=(i^g)&(g^f);l=(k&255)>>>7;a[1106712]=l;a[1041660]=j;a[1106728]=j;a[1106720]=j;return}g=b[520830]|0;i=g&255;h=((i&15)-(f&15)&255)-((a[1106736]|0)==0)&255;m=(g&240)-(f&-16&255)&65535;if((h&255)>15){n=h+10&15;o=m-16&65535}else{n=h;o=m}if((o&65535)>240){a[1106736]=0;p=o+160&255&-16}else{a[1106736]=1;p=o&255}o=p|n;j=o;k=(o^i)&(i^f);l=(k&255)>>>7;a[1106712]=l;a[1041660]=j;a[1106728]=j;a[1106720]=j;return}function nW(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=(d[g+(i+1)|0]|0)<<8|(d[g+i|0]|0);i=(c[348392]|0)+(c[348400]|0)|0;c[348392]=i;if((i|0)<(c[348406]|0)){k=h}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));k=b[520836]|0}b[520836]=k+2&65535;k=j&65535|f;j3(k&65535,(e[520832]|0)-1|0,65535);b[520832]=(b[520832]|0)-2&65535;a[1044496]=k&255;return}function nX(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=b[520836]|0;g=a[(c[348396]|0)+(f&65535)|0]|0;a[1044496]=g;h=(c[348392]|0)+(c[348399]|0)|0;c[348392]=h;i=c[348406]|0;if((h|0)<(i|0)){j=f;k=h;l=i}else{do{j1();m=c[348392]|0;n=c[348406]|0;}while((m|0)>=(n|0));j=b[520836]|0;k=m;l=n}b[520836]=j+1&65535;j=b[520831]|0;n=j+(g&255)&65535;do{if((j&255)<<24>>24==0){o=k;p=l}else{g=k+6|0;c[348392]=g;if((g|0)<(l|0)){o=g;p=l;break}while(1){j1();g=c[348392]|0;m=c[348406]|0;if((g|0)<(m|0)){o=g;p=m;break}}}}while(0);l=(e[520833]|0)+(n&65535)|0;n=o+6|0;c[348392]=n;if((n|0)>=(p|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}p=j0(l&65535)|0;a[1044496]=p;if((a[1041658]&8)==0){l=a[1041660]|0;n=((l&255)+~(p&255)&65535)+(d[1106736]|0)&65535;a[1106736]=(n&65535)>>>15&255^1;o=n&255;q=o;r=(o^l)&(l^p);s=(r&255)>>>7;a[1106712]=s;a[1041660]=q;a[1106728]=q;a[1106720]=q;return}l=b[520830]|0;o=l&255;n=((o&15)-(p&15)&255)-((a[1106736]|0)==0)&255;k=(l&240)-(p&-16&255)&65535;if((n&255)>15){t=n+10&15;u=k-16&65535}else{t=n;u=k}if((u&65535)>240){a[1106736]=0;v=u+160&255&-16}else{a[1106736]=1;v=u&255}u=v|t;q=u;r=(u^o)&(o^p);s=(r&255)>>>7;a[1106712]=s;a[1041660]=q;a[1106728]=q;a[1106720]=q;return}function nY(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=b[520836]|0;f=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=f;g=(c[348392]|0)+(c[348399]|0)|0;c[348392]=g;h=c[348406]|0;if((g|0)<(h|0)){i=d;j=g;k=h}else{do{j1();l=c[348392]|0;m=c[348406]|0;}while((l|0)>=(m|0));i=b[520836]|0;j=l;k=m}b[520836]=i+1&65535;i=b[520831]|0;m=i+(f&255)&65535;do{if((i&255)<<24>>24==0){n=j;o=k}else{f=j+6|0;c[348392]=f;if((f|0)<(k|0)){n=f;o=k;break}while(1){j1();f=c[348392]|0;l=c[348406]|0;if((f|0)<(l|0)){n=f;o=l;break}}}}while(0);k=(e[520833]|0)+(m&65535)|0;m=n+6|0;c[348392]=m;if((m|0)>=(o|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}o=k&65535;k=(j0(o)|0)+1&255;m=(c[348392]|0)+6|0;c[348392]=m;if((m|0)<(c[348406]|0)){j2(k,o);a[1044496]=k;a[1106728]=k;a[1106720]=k;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));j2(k,o);a[1044496]=k;a[1106728]=k;a[1106720]=k;return}function nZ(){var c=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;c=xb()|0;f=j0((e[520834]|0)+c|0)|0;a[1044496]=f;if((a[1041658]&8)==0){c=a[1041660]|0;g=((c&255)+~(f&255)&65535)+(d[1106736]|0)&65535;a[1106736]=(g&65535)>>>15&255^1;h=g&255;i=h;j=(h^c)&(c^f);k=(j&255)>>>7;a[1106712]=k;a[1041660]=i;a[1106728]=i;a[1106720]=i;return}c=b[520830]|0;h=c&255;g=((h&15)-(f&15)&255)-((a[1106736]|0)==0)&255;l=(c&240)-(f&-16&255)&65535;if((g&255)>15){m=g+10&15;n=l-16&65535}else{m=g;n=l}if((n&65535)>240){a[1106736]=0;o=n+160&255&-16}else{a[1106736]=1;o=n&255}n=o|m;i=n;j=(n^h)&(h^f);k=(j&255)>>>7;a[1106712]=k;a[1041660]=i;a[1106728]=i;a[1106720]=i;return}function n_(){var b=0;a[1041658]=a[1041658]|8;b=(c[348392]|0)+6|0;c[348392]=b;if((b|0)<(c[348406]|0)){return}do{j1();}while((c[348392]|0)>=(c[348406]|0));return}function n$(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|d[g+i|0];a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;do{if(((d[1041668]|0)+(l&255)|0)>>>0>255){f=m+6|0;c[348392]=f;if((f|0)<(n|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);n=j0((e[520834]|0)+l|0)|0;a[1044496]=n;if((a[1041658]&8)==0){l=a[1041660]|0;m=((l&255)+~(n&255)&65535)+(d[1106736]|0)&65535;a[1106736]=(m&65535)>>>15&255^1;f=m&255;q=f;r=(f^l)&(l^n);s=(r&255)>>>7;a[1106712]=s;a[1041660]=q;a[1106728]=q;a[1106720]=q;return}l=b[520830]|0;f=l&255;m=((f&15)-(n&15)&255)-((a[1106736]|0)==0)&255;k=(l&240)-(n&-16&255)&65535;if((m&255)>15){t=m+10&15;u=k-16&65535}else{t=m;u=k}if((u&65535)>240){a[1106736]=0;v=u+160&255&-16}else{a[1106736]=1;v=u&255}u=v|t;q=u;r=(u^f)&(f^n);s=(r&255)>>>7;a[1106712]=s;a[1041660]=q;a[1106728]=q;a[1106720]=q;return}function n0(){var d=0,e=0;d=(c[348392]|0)+12|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}d=(b[520832]|0)+1&65535;b[520832]=d;e=j0(d&65535)|0;a[1041666]=e;a[1106728]=e;a[1106720]=e;a[1044496]=e;return}function n1(){var d=0,e=0,f=0,g=0;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}d=a[1106736]|0;a[1106736]=a[1041659|0]&1;a[1041659|0]=d;d=b[520829]|0;if((d&256)==0){e=d&255;f=d}else{g=d|48;b[520829]=g;a[1041665|0]=1;e=g&255;f=g}if((e&16)!=0){a[1041667|0]=0;a[1041669|0]=0}if((f&256)!=0){c[276688]=158776;c[276686]=159800;return}e=f&255;f=(e&16|0)!=0;if((e&32|0)==0){if(f){c[276688]=156728;c[276686]=160312;return}else{c[276688]=157752;c[276686]=160568;return}}else{if(f){c[276688]=154680;c[276686]=159800;return}else{c[276688]=155704;c[276686]=160056;return}}}function n2(){var d=0,f=0;d=j5(c[260418]|0,65535)|0;a[1044496]=(d&65535)>>>8&255;b[520836]=(b[520836]|0)+2&65535;f=j5((b[520833]|0)+d&65535|c[276676],65535)|0;a[1044496]=(f&65535)>>>8&255;j3((b[520836]|0)-1&65535,(e[520832]|0)-1|0,65535);b[520832]=(b[520832]|0)-2&65535;j4((c[276676]|0)+(f&65535)|0);return}function n3(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|d[g+i|0];a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;do{if(((d[1041666]|0)+(l&255)|0)>>>0>255){f=m+6|0;c[348392]=f;if((f|0)<(n|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);n=j0((e[520833]|0)+l|0)|0;a[1044496]=n;if((a[1041658]&8)==0){l=a[1041660]|0;m=((l&255)+~(n&255)&65535)+(d[1106736]|0)&65535;a[1106736]=(m&65535)>>>15&255^1;f=m&255;q=f;r=(f^l)&(l^n);s=(r&255)>>>7;a[1106712]=s;a[1041660]=q;a[1106728]=q;a[1106720]=q;return}l=b[520830]|0;f=l&255;m=((f&15)-(n&15)&255)-((a[1106736]|0)==0)&255;k=(l&240)-(n&-16&255)&65535;if((m&255)>15){t=m+10&15;u=k-16&65535}else{t=m;u=k}if((u&65535)>240){a[1106736]=0;v=u+160&255&-16}else{a[1106736]=1;v=u&255}u=v|t;q=u;r=(u^f)&(f^n);s=(r&255)>>>7;a[1106712]=s;a[1041660]=q;a[1106728]=q;a[1106720]=q;return}function n4(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;f=m+6|0;c[348392]=f;if((f|0)>=(n|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}n=(e[520833]|0)+l|0;l=(j0(n)|0)+1&255;f=(c[348392]|0)+6|0;c[348392]=f;if((f|0)<(c[348406]|0)){j2(l,n);a[1044496]=l;a[1106728]=l;a[1106720]=l;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));j2(l,n);a[1044496]=l;a[1106728]=l;a[1106720]=l;return}function n5(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=a[f+(h+2)|0]|0;j=d[f+(h+1)|0]<<8|d[f+h|0]|(i&255)<<16;h=(c[348399]|0)+(c[348400]|0)+(c[348392]|0)|0;c[348392]=h;if((h|0)<(c[348406]|0)){k=g}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));k=b[520836]|0}a[1044496]=i;b[520836]=k+3&65535;k=j0((e[520833]|0)+j|0)|0;a[1044496]=k;if((a[1041658]&8)==0){j=a[1041660]|0;i=((j&255)+~(k&255)&65535)+(d[1106736]|0)&65535;a[1106736]=(i&65535)>>>15&255^1;g=i&255;l=g;m=(g^j)&(j^k);n=(m&255)>>>7;a[1106712]=n;a[1041660]=l;a[1106728]=l;a[1106720]=l;return}j=b[520830]|0;g=j&255;i=((g&15)-(k&15)&255)-((a[1106736]|0)==0)&255;h=(j&240)-(k&-16&255)&65535;if((i&255)>15){o=i+10&15;p=h-16&65535}else{o=i;p=h}if((p&65535)>240){a[1106736]=0;q=p+160&255&-16}else{a[1106736]=1;q=p&255}p=q|o;l=p;m=(p^g)&(g^k);n=(m&255)>>>7;a[1106712]=n;a[1041660]=l;a[1106728]=l;a[1106720]=l;return}function n6(){var b=0,c=0;b=j0(xc(1)|0)|0;a[1044496]=b;c=a[1041660]|b;a[1041660]=c;a[1106728]=c;a[1106720]=c;return}function n7(){var b=0,d=0,f=0;b=a[1041658]&60|a[1106736]|a[1106720]&-128|((a[1106728]|0)==0)<<1|a[1106712]<<6;a[1041658]=b;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)<(c[348406]|0)){f=b}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));f=a[1041658]|0}j2(f,e[520832]|0);a[1041664]=(a[1041664]|0)-1&255;a[1044496]=a[1041658]|0;return}function n8(){var d=0;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}j3(b[520831]|0,(e[520832]|0)-1|0,65535);b[520832]=(b[520832]|0)-2&65535;a[1044496]=a[1041662]|0;a[1041665|0]=1;return}function n9(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}l=h+1&65535;b[520836]=l;h=l+(e<<24>>24)&65535;e=(h&65535)>>>8;if((a[1106720]|0)<0){return}k=i+6|0;c[348392]=k;if((k|0)<(j|0)){m=k;n=(l&65535)>>>8&255;o=j}else{do{j1();p=c[348392]|0;q=c[348406]|0;}while((p|0)>=(q|0));m=p;n=a[1041673|0]|0;o=q}do{if((n&255|0)!=(e&65535|0)){q=m+6|0;c[348392]=q;if((q|0)<(o|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);o=e<<8;e=o|h&255;if(((b[520836]^o)&65535)>4095){j4((c[276676]|0)+(e&65535)|0);return}else{b[520836]=e;return}}function oa(){var f=0,g=0,h=0,i=0;f=j0(c[260418]|0)|0;a[1044496]=f;b[520836]=(b[520836]|0)+1&65535;g=b[520831]|0;h=g+(f&255)&65535;f=g&255;do{if(f<<24>>24==0){i=0}else{g=(c[348392]|0)+6|0;c[348392]=g;if((g|0)<(c[348406]|0)){i=f;break}do{j1();}while((c[348392]|0)>=(c[348406]|0));i=a[1041662]|0}}while(0);f=j5(h&65535,i<<24>>24!=0?65535:255)|0;a[1044496]=(f&65535)>>>8&255;i=c[276674]|f&65535;do{if(((d[1041668]|0)+(i&255)|0)>>>0>255){f=(c[348392]|0)+6|0;c[348392]=f;if((f|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);f=j0((e[520834]|0)+i|0)|0;a[1044496]=f;i=a[1041660]|f;a[1041660]=i;a[1106728]=i;a[1106720]=i;return}function ob(){var d=0,e=0,f=0,g=0;d=j0(c[260418]|0)|0;a[1044496]=d;b[520836]=(b[520836]|0)+1&65535;e=b[520831]|0;f=e+(d&255)&65535;d=e&255;do{if(d<<24>>24==0){g=0}else{e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)<(c[348406]|0)){g=d;break}do{j1();}while((c[348392]|0)>=(c[348406]|0));g=a[1041662]|0}}while(0);d=j5(f&65535,g<<24>>24!=0?65535:255)|0;a[1044496]=(d&65535)>>>8&255;g=j0(c[276674]|d&65535)|0;a[1044496]=g;d=a[1041660]|g;a[1041660]=d;a[1106728]=d;a[1106720]=d;return}function oc(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;f=(a[1041662]|0)==0;g=b[520836]|0;h=a[(c[348396]|0)+(g&65535)|0]|0;a[1044496]=h;i=(c[348392]|0)+(c[348399]|0)|0;c[348392]=i;j=c[348406]|0;k=(i|0)<(j|0);if(f){if(k){l=g;m=i;n=j}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+1&65535;l=b[520831]|0;p=l+(h&255)&65535;do{if((l&255)<<24>>24==0){q=m;r=n}else{o=m+6|0;c[348392]=o;if((o|0)<(n|0)){q=o;r=n;break}while(1){j1();o=c[348392]|0;f=c[348406]|0;if((o|0)<(f|0)){q=o;r=f;break}}}}while(0);n=(d[1041666]|0)+p&65535;m=q+6|0;c[348392]=m;if((m|0)>=(r|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}s=(n&255|p&-256)&65535;t=j0(s)|0;a[1044496]=t;u=a[1041660]|0;v=u|t;a[1041660]=v;a[1106728]=v;a[1106720]=v;return}else{if(k){w=g;x=i;y=j}else{do{j1();z=c[348392]|0;A=c[348406]|0;}while((z|0)>=(A|0));w=b[520836]|0;x=z;y=A}b[520836]=w+1&65535;w=b[520831]|0;A=w+(h&255)&65535;do{if((w&255)<<24>>24==0){B=x;C=y}else{h=x+6|0;c[348392]=h;if((h|0)<(y|0)){B=h;C=y;break}while(1){j1();h=c[348392]|0;z=c[348406]|0;if((h|0)<(z|0)){B=h;C=z;break}}}}while(0);y=(e[520833]|0)+(A&65535)|0;A=B+6|0;c[348392]=A;if((A|0)>=(C|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}s=y&65535;t=j0(s)|0;a[1044496]=t;u=a[1041660]|0;v=u|t;a[1041660]=v;a[1106728]=v;a[1106720]=v;return}}function od(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;f=(a[1041662]|0)==0;g=b[520836]|0;h=a[(c[348396]|0)+(g&65535)|0]|0;a[1044496]=h;i=(c[348392]|0)+(c[348399]|0)|0;c[348392]=i;j=c[348406]|0;k=(i|0)<(j|0);if(f){if(k){l=g;m=i;n=j}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+1&65535;l=b[520831]|0;p=l+(h&255)&65535;do{if((l&255)<<24>>24==0){q=m;r=n}else{o=m+6|0;c[348392]=o;if((o|0)<(n|0)){q=o;r=n;break}while(1){j1();o=c[348392]|0;f=c[348406]|0;if((o|0)<(f|0)){q=o;r=f;break}}}}while(0);n=(d[1041666]|0)+p&65535;m=q+6|0;c[348392]=m;if((m|0)>=(r|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}s=(n&255|p&-256)&65535}else{if(k){t=g;u=i;v=j}else{do{j1();w=c[348392]|0;x=c[348406]|0;}while((w|0)>=(x|0));t=b[520836]|0;u=w;v=x}b[520836]=t+1&65535;t=b[520831]|0;x=t+(h&255)&65535;do{if((t&255)<<24>>24==0){y=u;z=v}else{h=u+6|0;c[348392]=h;if((h|0)<(v|0)){y=h;z=v;break}while(1){j1();h=c[348392]|0;w=c[348406]|0;if((h|0)<(w|0)){y=h;z=w;break}}}}while(0);v=(e[520833]|0)+(x&65535)|0;x=y+6|0;c[348392]=x;if((x|0)>=(z|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}s=v&65535}v=j0(s)|0;a[1106736]=(v&255)>>>7;z=v<<1;v=(c[348392]|0)+6|0;c[348392]=v;if((v|0)<(c[348406]|0)){j2(z,s);a[1044496]=z;a[1106728]=z;a[1106720]=z;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));j2(z,s);a[1044496]=z;a[1106728]=z;a[1106720]=z;return}function oe(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=(d[g+(i+1)|0]|0)<<8|(d[g+i|0]|0);i=(c[348392]|0)+(c[348400]|0)|0;c[348392]=i;g=c[348406]|0;if((i|0)<(g|0)){k=h;l=i;m=g}else{do{j1();n=c[348392]|0;o=c[348406]|0;}while((n|0)>=(o|0));k=b[520836]|0;l=n;m=o}o=k+2&65535;b[520836]=o;k=j&65535;j=l+6|0;c[348392]=j;if((j|0)<(m|0)){p=o}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));p=b[520836]|0}a[1041664]=(a[1041664]|0)-1&255;j3(p-1&65535,e[520832]|0,255);a[1041664]=(a[1041664]|0)-1&255;j4((c[276676]|0)+(k|f&65535)|0);return}function of(){var b=0,c=0;b=j0(xc(1)|0)|0;a[1044496]=b;c=a[1041660]&b;a[1041660]=c;a[1106728]=c;a[1106720]=c;return}function og(){var f=0,g=0,h=0,i=0,j=0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=(d[f+(h+1)|0]|0)<<8|(d[f+h|0]|0)|(d[f+(h+2)|0]|0)<<16;h=(c[348399]|0)+(c[348400]|0)+(c[348392]|0)|0;c[348392]=h;if((h|0)<(c[348406]|0)){j=g}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));j=b[520836]|0}b[520836]=j+3&65535;j=a[1041674|0]|0;g=b[520832]|0;b[520832]=g-1&65535;j2(j,g&65535);j3((b[520836]|0)-1&65535,(e[520832]|0)-1|0,65535);b[520832]=(b[520832]|0)-2&65535;a[1041665|0]=1;j4(i);return}function oh(){var d=0,f=0,g=0;d=(c[348392]|0)+12|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}a[1041664]=(a[1041664]|0)+1&255;d=j0(e[520832]|0)|0;a[1041658]=d;a[1044496]=d;d=b[520829]|0;f=d|48;b[520829]=f;g=f&255;a[1106728]=(g&255)>>>1&1^1;a[1106720]=g&-128;a[1106736]=g&1;a[1106712]=(g&255)>>>6&1;c[276688]=(d&256)==0?154680:158776;c[276686]=159800;return}function oi(){var d=0,f=0;d=(c[348392]|0)+12|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}d=j5((e[520832]|0)+1|0,65535)|0;b[520831]=d;b[520832]=(b[520832]|0)+2&65535;a[1106728]=d<<16>>16!=0|0;f=(d&65535)>>>8&255;a[1106720]=f;a[1044496]=f;a[1041665|0]=1;return}function oj(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}l=h+1&65535;b[520836]=l;h=l+(e<<24>>24)&65535;e=(h&65535)>>>8;if((a[1106720]|0)>=0){return}k=i+6|0;c[348392]=k;if((k|0)<(j|0)){m=k;n=(l&65535)>>>8&255;o=j}else{do{j1();p=c[348392]|0;q=c[348406]|0;}while((p|0)>=(q|0));m=p;n=a[1041673|0]|0;o=q}do{if((n&255|0)!=(e&65535|0)){q=m+6|0;c[348392]=q;if((q|0)<(o|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);o=e<<8;e=o|h&255;if(((b[520836]^o)&65535)>4095){j4((c[276676]|0)+(e&65535)|0);return}else{b[520836]=e;return}}function ok(){var f=0,g=0,h=0,i=0;f=j0(c[260418]|0)|0;a[1044496]=f;b[520836]=(b[520836]|0)+1&65535;g=b[520831]|0;h=g+(f&255)&65535;f=g&255;do{if(f<<24>>24==0){i=0}else{g=(c[348392]|0)+6|0;c[348392]=g;if((g|0)<(c[348406]|0)){i=f;break}do{j1();}while((c[348392]|0)>=(c[348406]|0));i=a[1041662]|0}}while(0);f=j5(h&65535,i<<24>>24!=0?65535:255)|0;a[1044496]=(f&65535)>>>8&255;i=c[276674]|f&65535;do{if(((d[1041668]|0)+(i&255)|0)>>>0>255){f=(c[348392]|0)+6|0;c[348392]=f;if((f|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);f=j0((e[520834]|0)+i|0)|0;a[1044496]=f;i=a[1041660]&f;a[1041660]=i;a[1106728]=i;a[1106720]=i;return}function ol(){var d=0,e=0,f=0,g=0;d=j0(c[260418]|0)|0;a[1044496]=d;b[520836]=(b[520836]|0)+1&65535;e=b[520831]|0;f=e+(d&255)&65535;d=e&255;do{if(d<<24>>24==0){g=0}else{e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)<(c[348406]|0)){g=d;break}do{j1();}while((c[348392]|0)>=(c[348406]|0));g=a[1041662]|0}}while(0);d=j5(f&65535,g<<24>>24!=0?65535:255)|0;a[1044496]=(d&65535)>>>8&255;g=j0(c[276674]|d&65535)|0;a[1044496]=g;d=a[1041660]&g;a[1041660]=d;a[1106728]=d;a[1106720]=d;return}function om(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;f=(a[1041662]|0)==0;g=b[520836]|0;h=a[(c[348396]|0)+(g&65535)|0]|0;a[1044496]=h;i=(c[348392]|0)+(c[348399]|0)|0;c[348392]=i;j=c[348406]|0;k=(i|0)<(j|0);if(f){if(k){l=g;m=i;n=j}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+1&65535;l=b[520831]|0;p=l+(h&255)&65535;do{if((l&255)<<24>>24==0){q=m;r=n}else{o=m+6|0;c[348392]=o;if((o|0)<(n|0)){q=o;r=n;break}while(1){j1();o=c[348392]|0;f=c[348406]|0;if((o|0)<(f|0)){q=o;r=f;break}}}}while(0);n=(d[1041666]|0)+p&65535;m=q+6|0;c[348392]=m;if((m|0)>=(r|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}s=(n&255|p&-256)&65535;t=j0(s)|0;a[1044496]=t;u=(t&255)>>>6;v=u&1;a[1106712]=v;a[1106720]=t;w=a[1041660]|0;x=w&t;a[1106728]=x;return}else{if(k){y=g;z=i;A=j}else{do{j1();B=c[348392]|0;C=c[348406]|0;}while((B|0)>=(C|0));y=b[520836]|0;z=B;A=C}b[520836]=y+1&65535;y=b[520831]|0;C=y+(h&255)&65535;do{if((y&255)<<24>>24==0){D=z;E=A}else{h=z+6|0;c[348392]=h;if((h|0)<(A|0)){D=h;E=A;break}while(1){j1();h=c[348392]|0;B=c[348406]|0;if((h|0)<(B|0)){D=h;E=B;break}}}}while(0);A=(e[520833]|0)+(C&65535)|0;C=D+6|0;c[348392]=C;if((C|0)>=(E|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}s=A&65535;t=j0(s)|0;a[1044496]=t;u=(t&255)>>>6;v=u&1;a[1106712]=v;a[1106720]=t;w=a[1041660]|0;x=w&t;a[1106728]=x;return}}function on(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;f=(a[1041662]|0)==0;g=b[520836]|0;h=a[(c[348396]|0)+(g&65535)|0]|0;a[1044496]=h;i=(c[348392]|0)+(c[348399]|0)|0;c[348392]=i;j=c[348406]|0;k=(i|0)<(j|0);if(f){if(k){l=g;m=i;n=j}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+1&65535;l=b[520831]|0;p=l+(h&255)&65535;do{if((l&255)<<24>>24==0){q=m;r=n}else{o=m+6|0;c[348392]=o;if((o|0)<(n|0)){q=o;r=n;break}while(1){j1();o=c[348392]|0;f=c[348406]|0;if((o|0)<(f|0)){q=o;r=f;break}}}}while(0);n=(d[1041666]|0)+p&65535;m=q+6|0;c[348392]=m;if((m|0)>=(r|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}s=(n&255|p&-256)&65535;t=j0(s)|0;a[1044496]=t;u=a[1041660]|0;v=u&t;a[1041660]=v;a[1106728]=v;a[1106720]=v;return}else{if(k){w=g;x=i;y=j}else{do{j1();z=c[348392]|0;A=c[348406]|0;}while((z|0)>=(A|0));w=b[520836]|0;x=z;y=A}b[520836]=w+1&65535;w=b[520831]|0;A=w+(h&255)&65535;do{if((w&255)<<24>>24==0){B=x;C=y}else{h=x+6|0;c[348392]=h;if((h|0)<(y|0)){B=h;C=y;break}while(1){j1();h=c[348392]|0;z=c[348406]|0;if((h|0)<(z|0)){B=h;C=z;break}}}}while(0);y=(e[520833]|0)+(A&65535)|0;A=B+6|0;c[348392]=A;if((A|0)>=(C|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}s=y&65535;t=j0(s)|0;a[1044496]=t;u=a[1041660]|0;v=u&t;a[1041660]=v;a[1106728]=v;a[1106720]=v;return}}function oo(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;f=(a[1041662]|0)==0;g=b[520836]|0;h=a[(c[348396]|0)+(g&65535)|0]|0;a[1044496]=h;i=(c[348392]|0)+(c[348399]|0)|0;c[348392]=i;j=c[348406]|0;k=(i|0)<(j|0);if(f){if(k){l=g;m=i;n=j}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+1&65535;l=b[520831]|0;p=l+(h&255)&65535;do{if((l&255)<<24>>24==0){q=m;r=n}else{o=m+6|0;c[348392]=o;if((o|0)<(n|0)){q=o;r=n;break}while(1){j1();o=c[348392]|0;f=c[348406]|0;if((o|0)<(f|0)){q=o;r=f;break}}}}while(0);n=(d[1041666]|0)+p&65535;m=q+6|0;c[348392]=m;if((m|0)>=(r|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}s=(n&255|p&-256)&65535}else{if(k){t=g;u=i;v=j}else{do{j1();w=c[348392]|0;x=c[348406]|0;}while((w|0)>=(x|0));t=b[520836]|0;u=w;v=x}b[520836]=t+1&65535;t=b[520831]|0;x=t+(h&255)&65535;do{if((t&255)<<24>>24==0){y=u;z=v}else{h=u+6|0;c[348392]=h;if((h|0)<(v|0)){y=h;z=v;break}while(1){j1();h=c[348392]|0;w=c[348406]|0;if((h|0)<(w|0)){y=h;z=w;break}}}}while(0);v=(e[520833]|0)+(x&65535)|0;x=y+6|0;c[348392]=x;if((x|0)>=(z|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}s=v&65535}v=((j0(s)|0)&255)<<1;z=v|d[1106736];a[1106736]=(z&65535)>255|0;v=(c[348392]|0)+6|0;c[348392]=v;if((v|0)<(c[348406]|0)){A=z&255;j2(A,s);a[1044496]=A;a[1106728]=A;a[1106720]=A;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));A=z&255;j2(A,s);a[1044496]=A;a[1106728]=A;a[1106720]=A;return}function op(){var b=0,c=0;b=j0(xc(1)|0)|0;a[1044496]=b;c=a[1041660]^b;a[1041660]=c;a[1106728]=c;a[1106720]=c;return}function oq(){var b=0;b=(c[348392]|0)+6|0;c[348392]=b;if((b|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}j2(a[1041660]|0,e[520832]|0);a[1041664]=(a[1041664]|0)-1&255;a[1044496]=a[1041660]|0;return}function or(){var b=0;b=(c[348392]|0)+6|0;c[348392]=b;if((b|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}j2(a[1041674|0]|0,e[520832]|0);a[1041664]=(a[1041664]|0)-1&255;a[1044496]=a[1041674|0]|0;return}function os(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}l=h+1&65535;b[520836]=l;h=l+(e<<24>>24)&65535;e=(h&65535)>>>8;if((a[1106712]|0)!=0){return}k=i+6|0;c[348392]=k;if((k|0)<(j|0)){m=k;n=(l&65535)>>>8&255;o=j}else{do{j1();p=c[348392]|0;q=c[348406]|0;}while((p|0)>=(q|0));m=p;n=a[1041673|0]|0;o=q}do{if((n&255|0)!=(e&65535|0)){q=m+6|0;c[348392]=q;if((q|0)<(o|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);o=e<<8;e=o|h&255;if(((b[520836]^o)&65535)>4095){j4((c[276676]|0)+(e&65535)|0);return}else{b[520836]=e;return}}function ot(){var f=0,g=0,h=0,i=0;f=j0(c[260418]|0)|0;a[1044496]=f;b[520836]=(b[520836]|0)+1&65535;g=b[520831]|0;h=g+(f&255)&65535;f=g&255;do{if(f<<24>>24==0){i=0}else{g=(c[348392]|0)+6|0;c[348392]=g;if((g|0)<(c[348406]|0)){i=f;break}do{j1();}while((c[348392]|0)>=(c[348406]|0));i=a[1041662]|0}}while(0);f=j5(h&65535,i<<24>>24!=0?65535:255)|0;a[1044496]=(f&65535)>>>8&255;i=c[276674]|f&65535;do{if(((d[1041668]|0)+(i&255)|0)>>>0>255){f=(c[348392]|0)+6|0;c[348392]=f;if((f|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);f=j0((e[520834]|0)+i|0)|0;a[1044496]=f;i=a[1041660]^f;a[1041660]=i;a[1106728]=i;a[1106720]=i;return}function ou(){var d=0,e=0,f=0,g=0;d=j0(c[260418]|0)|0;a[1044496]=d;b[520836]=(b[520836]|0)+1&65535;e=b[520831]|0;f=e+(d&255)&65535;d=e&255;do{if(d<<24>>24==0){g=0}else{e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)<(c[348406]|0)){g=d;break}do{j1();}while((c[348392]|0)>=(c[348406]|0));g=a[1041662]|0}}while(0);d=j5(f&65535,g<<24>>24!=0?65535:255)|0;a[1044496]=(d&65535)>>>8&255;g=j0(c[276674]|d&65535)|0;a[1044496]=g;d=a[1041660]^g;a[1041660]=d;a[1106728]=d;a[1106720]=d;return}function ov(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;f=(a[1041662]|0)==0;g=b[520836]|0;h=a[(c[348396]|0)+(g&65535)|0]|0;a[1044496]=h;i=(c[348392]|0)+(c[348399]|0)|0;c[348392]=i;j=c[348406]|0;k=(i|0)<(j|0);if(f){if(k){l=g;m=i;n=j}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+1&65535;l=b[520831]|0;p=l+(h&255)&65535;do{if((l&255)<<24>>24==0){q=m;r=n}else{o=m+6|0;c[348392]=o;if((o|0)<(n|0)){q=o;r=n;break}while(1){j1();o=c[348392]|0;f=c[348406]|0;if((o|0)<(f|0)){q=o;r=f;break}}}}while(0);n=(d[1041666]|0)+p&65535;m=q+6|0;c[348392]=m;if((m|0)>=(r|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}s=(n&255|p&-256)&65535;t=j0(s)|0;a[1044496]=t;u=a[1041660]|0;v=u^t;a[1041660]=v;a[1106728]=v;a[1106720]=v;return}else{if(k){w=g;x=i;y=j}else{do{j1();z=c[348392]|0;A=c[348406]|0;}while((z|0)>=(A|0));w=b[520836]|0;x=z;y=A}b[520836]=w+1&65535;w=b[520831]|0;A=w+(h&255)&65535;do{if((w&255)<<24>>24==0){B=x;C=y}else{h=x+6|0;c[348392]=h;if((h|0)<(y|0)){B=h;C=y;break}while(1){j1();h=c[348392]|0;z=c[348406]|0;if((h|0)<(z|0)){B=h;C=z;break}}}}while(0);y=(e[520833]|0)+(A&65535)|0;A=B+6|0;c[348392]=A;if((A|0)>=(C|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}s=y&65535;t=j0(s)|0;a[1044496]=t;u=a[1041660]|0;v=u^t;a[1041660]=v;a[1106728]=v;a[1106720]=v;return}}function ow(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;f=(a[1041662]|0)==0;g=b[520836]|0;h=a[(c[348396]|0)+(g&65535)|0]|0;a[1044496]=h;i=(c[348392]|0)+(c[348399]|0)|0;c[348392]=i;j=c[348406]|0;k=(i|0)<(j|0);if(f){if(k){l=g;m=i;n=j}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+1&65535;l=b[520831]|0;p=l+(h&255)&65535;do{if((l&255)<<24>>24==0){q=m;r=n}else{o=m+6|0;c[348392]=o;if((o|0)<(n|0)){q=o;r=n;break}while(1){j1();o=c[348392]|0;f=c[348406]|0;if((o|0)<(f|0)){q=o;r=f;break}}}}while(0);n=(d[1041666]|0)+p&65535;m=q+6|0;c[348392]=m;if((m|0)>=(r|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}s=(n&255|p&-256)&65535}else{if(k){t=g;u=i;v=j}else{do{j1();w=c[348392]|0;x=c[348406]|0;}while((w|0)>=(x|0));t=b[520836]|0;u=w;v=x}b[520836]=t+1&65535;t=b[520831]|0;x=t+(h&255)&65535;do{if((t&255)<<24>>24==0){y=u;z=v}else{h=u+6|0;c[348392]=h;if((h|0)<(v|0)){y=h;z=v;break}while(1){j1();h=c[348392]|0;w=c[348406]|0;if((h|0)<(w|0)){y=h;z=w;break}}}}while(0);v=(e[520833]|0)+(x&65535)|0;x=y+6|0;c[348392]=x;if((x|0)>=(z|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}s=v&65535}v=j0(s)|0;a[1106736]=v&1;z=(v&255)>>>1;v=(c[348392]|0)+6|0;c[348392]=v;if((v|0)<(c[348406]|0)){j2(z,s);a[1044496]=z;a[1106728]=z;a[1106720]=z;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));j2(z,s);a[1044496]=z;a[1106728]=z;a[1106720]=z;return}function ox(){var b=0;b=(c[348392]|0)+6|0;c[348392]=b;if((b|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}j2(a[1041668]|0,e[520832]|0);a[1041664]=(a[1041664]|0)-1&255;a[1044496]=a[1041668]|0;return}function oy(){var d=0,f=0,g=0,h=0,i=0;d=(c[348392]|0)+12|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}a[1041664]=(a[1041664]|0)+1&255;d=j5(e[520832]|0,255)|0;b[520836]=d;a[1041664]=(a[1041664]|0)+1&255;f=(c[348392]|0)+6|0;c[348392]=f;if((f|0)<(c[348406]|0)){g=d;h=g+1&65535;b[520836]=h;i=c[260418]|0;j4(i);return}do{j1();}while((c[348392]|0)>=(c[348406]|0));g=b[520836]|0;h=g+1&65535;b[520836]=h;i=c[260418]|0;j4(i);return}function oz(){var c=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=j0(xc(1)|0)|0;a[1044496]=c;if((a[1041658]&8)==0){e=a[1041660]|0;f=c&255;g=(e&255)+f+(d[1106736]|0)|0;a[1106736]=(g&65280)>>>0>255|0;h=g&255;i=((g^f)&((e^c)&255^128))>>>7&255;j=i&1;a[1106712]=j;a[1041660]=h;a[1106728]=h;a[1106720]=h;return}e=b[520830]|0;f=e&255;g=e&240;e=((a[1106736]|0)+(c&15)&255)+(f&15)&255;if((e&255)>9){k=e+6&15;l=g+16&65535}else{k=e;l=g}g=l+(c&-16&255)&65535;if((g&65535)>144){a[1106736]=1;m=g+96&255&-16}else{a[1106736]=0;m=g&255}g=m|k;h=g;i=((g^c)&(c^-128^f)&255)>>>7;j=i&1;a[1106712]=j;a[1041660]=h;a[1106728]=h;a[1106720]=h;return}function oA(){var f=0,g=0,h=0,i=0,j=0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=(d[f+(h+1)|0]|0)<<8|(d[f+h|0]|0);h=(c[348392]|0)+(c[348400]|0)|0;c[348392]=h;if((h|0)<(c[348406]|0)){j=g}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));j=b[520836]|0}g=j+2&65535;b[520836]=g;j=(g&65535)+(i&65535)|0;j3(j&65535,(e[520832]|0)-1|0,65535);b[520832]=(b[520832]|0)-2&65535;a[1044496]=j&255;a[1041665|0]=1;return}function oB(){var b=0;b=(c[348392]|0)+12|0;c[348392]=b;if((b|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}a[1041664]=(a[1041664]|0)+1&255;b=j0(e[520832]|0)|0;a[1041660]=b;a[1106728]=b;a[1106720]=b;a[1044496]=b;return}function oC(){var d=0;d=(c[348392]|0)+12|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}b[520836]=j5((e[520832]|0)+1|0,65535)|0;d=(b[520832]|0)+3&65535;b[520832]=d;a[1041674|0]=j0(d&65535)|0;a[1041665|0]=1;b[520836]=(b[520836]|0)+1&65535;j4(c[260418]|0);return}function oD(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}l=h+1&65535;b[520836]=l;h=l+(e<<24>>24)&65535;e=(h&65535)>>>8;if((a[1106712]|0)==0){return}k=i+6|0;c[348392]=k;if((k|0)<(j|0)){m=k;n=(l&65535)>>>8&255;o=j}else{do{j1();p=c[348392]|0;q=c[348406]|0;}while((p|0)>=(q|0));m=p;n=a[1041673|0]|0;o=q}do{if((n&255|0)!=(e&65535|0)){q=m+6|0;c[348392]=q;if((q|0)<(o|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);o=e<<8;e=o|h&255;if(((b[520836]^o)&65535)>4095){j4((c[276676]|0)+(e&65535)|0);return}else{b[520836]=e;return}}function oE(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=j0(c[260418]|0)|0;a[1044496]=f;b[520836]=(b[520836]|0)+1&65535;g=b[520831]|0;h=g+(f&255)&65535;f=g&255;do{if(f<<24>>24==0){i=0}else{g=(c[348392]|0)+6|0;c[348392]=g;if((g|0)<(c[348406]|0)){i=f;break}do{j1();}while((c[348392]|0)>=(c[348406]|0));i=a[1041662]|0}}while(0);f=j5(h&65535,i<<24>>24!=0?65535:255)|0;a[1044496]=(f&65535)>>>8&255;i=c[276674]|f&65535;do{if(((d[1041668]|0)+(i&255)|0)>>>0>255){f=(c[348392]|0)+6|0;c[348392]=f;if((f|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);f=j0((e[520834]|0)+i|0)|0;a[1044496]=f;if((a[1041658]&8)==0){i=a[1041660]|0;h=f&255;g=(i&255)+h+(d[1106736]|0)|0;a[1106736]=(g&65280)>>>0>255|0;j=g&255;k=((g^h)&((i^f)&255^128))>>>7&255;l=k&1;a[1106712]=l;a[1041660]=j;a[1106728]=j;a[1106720]=j;return}i=b[520830]|0;h=i&255;g=i&240;i=((a[1106736]|0)+(f&15)&255)+(h&15)&255;if((i&255)>9){m=i+6&15;n=g+16&65535}else{m=i;n=g}g=n+(f&-16&255)&65535;if((g&65535)>144){a[1106736]=1;o=g+96&255&-16}else{a[1106736]=0;o=g&255}g=o|m;j=g;k=((g^f)&(f^-128^h)&255)>>>7;l=k&1;a[1106712]=l;a[1041660]=j;a[1106728]=j;a[1106720]=j;return}function oF(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=j0(c[260418]|0)|0;a[1044496]=e;b[520836]=(b[520836]|0)+1&65535;f=b[520831]|0;g=f+(e&255)&65535;e=f&255;do{if(e<<24>>24==0){h=0}else{f=(c[348392]|0)+6|0;c[348392]=f;if((f|0)<(c[348406]|0)){h=e;break}do{j1();}while((c[348392]|0)>=(c[348406]|0));h=a[1041662]|0}}while(0);e=j5(g&65535,h<<24>>24!=0?65535:255)|0;a[1044496]=(e&65535)>>>8&255;h=j0(c[276674]|e&65535)|0;a[1044496]=h;if((a[1041658]&8)==0){e=a[1041660]|0;g=h&255;f=(e&255)+g+(d[1106736]|0)|0;a[1106736]=(f&65280)>>>0>255|0;i=f&255;j=((f^g)&((e^h)&255^128))>>>7&255;k=j&1;a[1106712]=k;a[1041660]=i;a[1106728]=i;a[1106720]=i;return}e=b[520830]|0;g=e&255;f=e&240;e=((a[1106736]|0)+(h&15)&255)+(g&15)&255;if((e&255)>9){l=e+6&15;m=f+16&65535}else{l=e;m=f}f=m+(h&-16&255)&65535;if((f&65535)>144){a[1106736]=1;n=f+96&255&-16}else{a[1106736]=0;n=f&255}f=n|l;i=f;j=((f^h)&(h^-128^g)&255)>>>7;k=j&1;a[1106712]=k;a[1041660]=i;a[1106728]=i;a[1106720]=i;return}function oG(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;f=(a[1041662]|0)==0;g=b[520836]|0;h=a[(c[348396]|0)+(g&65535)|0]|0;i=(c[348392]|0)+(c[348399]|0)|0;c[348392]=i;j=c[348406]|0;k=(i|0)<(j|0);if(f){if(k){l=g;m=i;n=j}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+1&65535;l=b[520831]|0;p=l+(h&255)&65535;do{if((l&255)<<24>>24==0){q=m;r=n}else{o=m+6|0;c[348392]=o;if((o|0)<(n|0)){q=o;r=n;break}while(1){j1();o=c[348392]|0;f=c[348406]|0;if((o|0)<(f|0)){q=o;r=f;break}}}}while(0);n=(d[1041666]|0)+p&65535;m=q+6|0;c[348392]=m;if((m|0)>=(r|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}s=(n&255|p&-256)&65535;j2(0,s);a[1044496]=0;return}else{if(k){t=g;u=i;v=j}else{do{j1();w=c[348392]|0;x=c[348406]|0;}while((w|0)>=(x|0));t=b[520836]|0;u=w;v=x}b[520836]=t+1&65535;t=b[520831]|0;x=t+(h&255)&65535;do{if((t&255)<<24>>24==0){y=u;z=v}else{h=u+6|0;c[348392]=h;if((h|0)<(v|0)){y=h;z=v;break}while(1){j1();h=c[348392]|0;w=c[348406]|0;if((h|0)<(w|0)){y=h;z=w;break}}}}while(0);v=(e[520833]|0)+(x&65535)|0;x=y+6|0;c[348392]=x;if((x|0)>=(z|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}s=v&65535;j2(0,s);a[1044496]=0;return}}function oH(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;f=(a[1041662]|0)==0;g=b[520836]|0;h=a[(c[348396]|0)+(g&65535)|0]|0;a[1044496]=h;i=(c[348392]|0)+(c[348399]|0)|0;c[348392]=i;j=c[348406]|0;k=(i|0)<(j|0);if(f){if(k){l=g;m=i;n=j}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+1&65535;l=b[520831]|0;p=l+(h&255)&65535;do{if((l&255)<<24>>24==0){q=m;r=n}else{o=m+6|0;c[348392]=o;if((o|0)<(n|0)){q=o;r=n;break}while(1){j1();o=c[348392]|0;f=c[348406]|0;if((o|0)<(f|0)){q=o;r=f;break}}}}while(0);n=(d[1041666]|0)+p&65535;m=q+6|0;c[348392]=m;if((m|0)>=(r|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}s=(n&255|p&-256)&65535}else{if(k){t=g;u=i;v=j}else{do{j1();w=c[348392]|0;x=c[348406]|0;}while((w|0)>=(x|0));t=b[520836]|0;u=w;v=x}b[520836]=t+1&65535;t=b[520831]|0;x=t+(h&255)&65535;do{if((t&255)<<24>>24==0){y=u;z=v}else{h=u+6|0;c[348392]=h;if((h|0)<(v|0)){y=h;z=v;break}while(1){j1();h=c[348392]|0;w=c[348406]|0;if((h|0)<(w|0)){y=h;z=w;break}}}}while(0);v=(e[520833]|0)+(x&65535)|0;x=y+6|0;c[348392]=x;if((x|0)>=(z|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}s=v&65535}v=j0(s)|0;a[1044496]=v;if((a[1041658]&8)==0){s=a[1041660]|0;z=v&255;x=(s&255)+z+(d[1106736]|0)|0;a[1106736]=(x&65280)>>>0>255|0;A=x&255;B=((x^z)&((s^v)&255^128))>>>7&255;C=B&1;a[1106712]=C;a[1041660]=A;a[1106728]=A;a[1106720]=A;return}s=b[520830]|0;z=s&255;x=s&240;s=((a[1106736]|0)+(v&15)&255)+(z&15)&255;if((s&255)>9){D=s+6&15;E=x+16&65535}else{D=s;E=x}x=E+(v&-16&255)&65535;if((x&65535)>144){a[1106736]=1;F=x+96&255&-16}else{a[1106736]=0;F=x&255}x=F|D;A=x;B=((x^v)&(v^-128^z)&255)>>>7;C=B&1;a[1106712]=C;a[1041660]=A;a[1106728]=A;a[1106720]=A;return}function oI(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;f=(a[1041662]|0)==0;g=b[520836]|0;h=a[(c[348396]|0)+(g&65535)|0]|0;a[1044496]=h;i=(c[348392]|0)+(c[348399]|0)|0;c[348392]=i;j=c[348406]|0;k=(i|0)<(j|0);if(f){if(k){l=g;m=i;n=j}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+1&65535;l=b[520831]|0;p=l+(h&255)&65535;do{if((l&255)<<24>>24==0){q=m;r=n}else{o=m+6|0;c[348392]=o;if((o|0)<(n|0)){q=o;r=n;break}while(1){j1();o=c[348392]|0;f=c[348406]|0;if((o|0)<(f|0)){q=o;r=f;break}}}}while(0);n=(d[1041666]|0)+p&65535;m=q+6|0;c[348392]=m;if((m|0)>=(r|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}s=(n&255|p&-256)&65535}else{if(k){t=g;u=i;v=j}else{do{j1();w=c[348392]|0;x=c[348406]|0;}while((w|0)>=(x|0));t=b[520836]|0;u=w;v=x}b[520836]=t+1&65535;t=b[520831]|0;x=t+(h&255)&65535;do{if((t&255)<<24>>24==0){y=u;z=v}else{h=u+6|0;c[348392]=h;if((h|0)<(v|0)){y=h;z=v;break}while(1){j1();h=c[348392]|0;w=c[348406]|0;if((h|0)<(w|0)){y=h;z=w;break}}}}while(0);v=(e[520833]|0)+(x&65535)|0;x=y+6|0;c[348392]=x;if((x|0)>=(z|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}s=v&65535}v=j0(s)|0;z=d[1106736]<<8|v&255;a[1106736]=v&1;v=(z&65535)>>>1;z=(c[348392]|0)+6|0;c[348392]=z;if((z|0)<(c[348406]|0)){A=v&255;j2(A,s);a[1044496]=A;a[1106728]=A;a[1106720]=A;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));A=v&255;j2(A,s);a[1044496]=A;a[1106728]=A;a[1106720]=A;return}function oJ(){var b=0;b=(c[348392]|0)+12|0;c[348392]=b;if((b|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}a[1041664]=(a[1041664]|0)+1&255;b=j0(e[520832]|0)|0;a[1041668]=b;a[1106728]=b;a[1106720]=b;a[1044496]=b;return}function oK(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}l=h+1&65535;b[520836]=l;h=l+(e<<24>>24)&65535;e=(h&65535)>>>8;k=i+6|0;c[348392]=k;if((k|0)<(j|0)){m=k;n=(l&65535)>>>8&255;o=j}else{do{j1();p=c[348392]|0;q=c[348406]|0;}while((p|0)>=(q|0));m=p;n=a[1041673|0]|0;o=q}do{if((n&255|0)!=(e&65535|0)){q=m+6|0;c[348392]=q;if((q|0)<(o|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);o=e<<8;e=o|h&255;if(((b[520836]^o)&65535)>4095){j4((c[276676]|0)+(e&65535)|0);return}else{b[520836]=e;return}}function oL(){var b=0;b=xc(2)|0;j2(a[1041660|0]|0,b);a[1044496]=a[1041660|0]|0;return}function oM(){var b=0;b=(c[348392]|0)+6|0;c[348392]=b;if((b|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}j2(a[1041656]|0,e[520832]|0);a[1041664]=(a[1041664]|0)-1&255;a[1044496]=a[1041656]|0;return}function oN(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}l=h+1&65535;b[520836]=l;h=l+(e<<24>>24)&65535;e=(h&65535)>>>8;if((a[1106736]|0)!=0){return}k=i+6|0;c[348392]=k;if((k|0)<(j|0)){m=k;n=(l&65535)>>>8&255;o=j}else{do{j1();p=c[348392]|0;q=c[348406]|0;}while((p|0)>=(q|0));m=p;n=a[1041673|0]|0;o=q}do{if((n&255|0)!=(e&65535|0)){q=m+6|0;c[348392]=q;if((q|0)<(o|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);o=e<<8;e=o|h&255;if(((b[520836]^o)&65535)>4095){j4((c[276676]|0)+(e&65535)|0);return}else{b[520836]=e;return}}function oO(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=j0(c[260418]|0)|0;a[1044496]=d;b[520836]=(b[520836]|0)+1&65535;e=b[520831]|0;f=e+(d&255)&65535;d=e&255;do{if(d<<24>>24==0){g=0}else{e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)<(c[348406]|0)){g=d;break}do{j1();}while((c[348392]|0)>=(c[348406]|0));g=a[1041662]|0}}while(0);d=(j5(f&65535,g<<24>>24!=0?65535:255)|0)&65535;g=c[276674]|d;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)<(c[348406]|0)){h=b[520834]|0;i=h&65535;j=i+g|0;k=a[1041660]|0;j2(k,j);l=a[1041660]|0;a[1044496]=l;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));h=b[520834]|0;i=h&65535;j=i+g|0;k=a[1041660]|0;j2(k,j);l=a[1041660]|0;a[1044496]=l;return}function oP(){var d=0,e=0,f=0,g=0;d=j0(c[260418]|0)|0;a[1044496]=d;b[520836]=(b[520836]|0)+1&65535;e=b[520831]|0;f=e+(d&255)&65535;d=e&255;do{if(d<<24>>24==0){g=0}else{e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)<(c[348406]|0)){g=d;break}do{j1();}while((c[348392]|0)>=(c[348406]|0));g=a[1041662]|0}}while(0);d=(j5(f&65535,g<<24>>24!=0?65535:255)|0)&65535;j2(a[1041660]|0,c[276674]|d);a[1044496]=a[1041660]|0;return}function oQ(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;f=(a[1041662]|0)==0;g=b[520836]|0;h=a[(c[348396]|0)+(g&65535)|0]|0;i=(c[348392]|0)+(c[348399]|0)|0;c[348392]=i;j=c[348406]|0;k=(i|0)<(j|0);if(f){if(k){l=g;m=i;n=j}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+1&65535;l=b[520831]|0;p=l+(h&255)&65535;do{if((l&255)<<24>>24==0){q=m;r=n}else{o=m+6|0;c[348392]=o;if((o|0)<(n|0)){q=o;r=n;break}while(1){j1();o=c[348392]|0;f=c[348406]|0;if((o|0)<(f|0)){q=o;r=f;break}}}}while(0);n=(d[1041666]|0)+p&65535;m=q+6|0;c[348392]=m;if((m|0)>=(r|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}s=(n&255|p&-256)&65535;t=a[1041668]|0;j2(t,s);u=a[1041668]|0;a[1044496]=u;return}else{if(k){v=g;w=i;x=j}else{do{j1();y=c[348392]|0;z=c[348406]|0;}while((y|0)>=(z|0));v=b[520836]|0;w=y;x=z}b[520836]=v+1&65535;v=b[520831]|0;z=v+(h&255)&65535;do{if((v&255)<<24>>24==0){A=w;B=x}else{h=w+6|0;c[348392]=h;if((h|0)<(x|0)){A=h;B=x;break}while(1){j1();h=c[348392]|0;y=c[348406]|0;if((h|0)<(y|0)){A=h;B=y;break}}}}while(0);x=(e[520833]|0)+(z&65535)|0;z=A+6|0;c[348392]=z;if((z|0)>=(B|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}s=x&65535;t=a[1041668]|0;j2(t,s);u=a[1041668]|0;a[1044496]=u;return}}function oR(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;f=(a[1041662]|0)==0;g=b[520836]|0;h=a[(c[348396]|0)+(g&65535)|0]|0;i=(c[348392]|0)+(c[348399]|0)|0;c[348392]=i;j=c[348406]|0;k=(i|0)<(j|0);if(f){if(k){l=g;m=i;n=j}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+1&65535;l=b[520831]|0;p=l+(h&255)&65535;do{if((l&255)<<24>>24==0){q=m;r=n}else{o=m+6|0;c[348392]=o;if((o|0)<(n|0)){q=o;r=n;break}while(1){j1();o=c[348392]|0;f=c[348406]|0;if((o|0)<(f|0)){q=o;r=f;break}}}}while(0);n=(d[1041666]|0)+p&65535;m=q+6|0;c[348392]=m;if((m|0)>=(r|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}s=(n&255|p&-256)&65535;t=a[1041660]|0;j2(t,s);u=a[1041660]|0;a[1044496]=u;return}else{if(k){v=g;w=i;x=j}else{do{j1();y=c[348392]|0;z=c[348406]|0;}while((y|0)>=(z|0));v=b[520836]|0;w=y;x=z}b[520836]=v+1&65535;v=b[520831]|0;z=v+(h&255)&65535;do{if((v&255)<<24>>24==0){A=w;B=x}else{h=w+6|0;c[348392]=h;if((h|0)<(x|0)){A=h;B=x;break}while(1){j1();h=c[348392]|0;y=c[348406]|0;if((h|0)<(y|0)){A=h;B=y;break}}}}while(0);x=(e[520833]|0)+(z&65535)|0;z=A+6|0;c[348392]=z;if((z|0)>=(B|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}s=x&65535;t=a[1041660]|0;j2(t,s);u=a[1041660]|0;a[1044496]=u;return}}function oS(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;f=(a[1041662]|0)==0;g=b[520836]|0;h=a[(c[348396]|0)+(g&65535)|0]|0;i=(c[348392]|0)+(c[348399]|0)|0;c[348392]=i;j=c[348406]|0;k=(i|0)<(j|0);if(f){if(k){l=g;m=i;n=j}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+1&65535;l=b[520831]|0;p=l+(h&255)&65535;do{if((l&255)<<24>>24==0){q=m;r=n}else{o=m+6|0;c[348392]=o;if((o|0)<(n|0)){q=o;r=n;break}while(1){j1();o=c[348392]|0;f=c[348406]|0;if((o|0)<(f|0)){q=o;r=f;break}}}}while(0);n=(d[1041668]|0)+p&65535;m=q+6|0;c[348392]=m;if((m|0)>=(r|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}s=(n&255|p&-256)&65535;t=a[1041666]|0;j2(t,s);u=a[1041666]|0;a[1044496]=u;return}else{if(k){v=g;w=i;x=j}else{do{j1();y=c[348392]|0;z=c[348406]|0;}while((y|0)>=(z|0));v=b[520836]|0;w=y;x=z}b[520836]=v+1&65535;v=b[520831]|0;z=v+(h&255)&65535;do{if((v&255)<<24>>24==0){A=w;B=x}else{h=w+6|0;c[348392]=h;if((h|0)<(x|0)){A=h;B=x;break}while(1){j1();h=c[348392]|0;y=c[348406]|0;if((h|0)<(y|0)){A=h;B=y;break}}}}while(0);x=(e[520834]|0)+(z&65535)|0;z=A+6|0;c[348392]=z;if((z|0)>=(B|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}s=x&65535;t=a[1041666]|0;j2(t,s);u=a[1041666]|0;a[1044496]=u;return}}function oT(){var b=0;b=j0(xc(1)|0)|0;a[1044496]=b;a[1041660|0]=b;a[1106728]=b;a[1106720]=b;return}function oU(){var b=0;b=(c[348392]|0)+12|0;c[348392]=b;if((b|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}a[1041664]=(a[1041664]|0)+1&255;b=j0(e[520832]|0)|0;a[1041656]=b;a[1106728]=b;a[1106720]=b;c[276674]=(b&255)<<16;a[1044496]=b;return}function oV(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}l=h+1&65535;b[520836]=l;h=l+(e<<24>>24)&65535;e=(h&65535)>>>8;if((a[1106736]|0)==0){return}k=i+6|0;c[348392]=k;if((k|0)<(j|0)){m=k;n=(l&65535)>>>8&255;o=j}else{do{j1();p=c[348392]|0;q=c[348406]|0;}while((p|0)>=(q|0));m=p;n=a[1041673|0]|0;o=q}do{if((n&255|0)!=(e&65535|0)){q=m+6|0;c[348392]=q;if((q|0)<(o|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);o=e<<8;e=o|h&255;if(((b[520836]^o)&65535)>4095){j4((c[276676]|0)+(e&65535)|0);return}else{b[520836]=e;return}}function oW(){var f=0,g=0,h=0,i=0;f=j0(c[260418]|0)|0;a[1044496]=f;b[520836]=(b[520836]|0)+1&65535;g=b[520831]|0;h=g+(f&255)&65535;f=g&255;do{if(f<<24>>24==0){i=0}else{g=(c[348392]|0)+6|0;c[348392]=g;if((g|0)<(c[348406]|0)){i=f;break}do{j1();}while((c[348392]|0)>=(c[348406]|0));i=a[1041662]|0}}while(0);f=j5(h&65535,i<<24>>24!=0?65535:255)|0;a[1044496]=(f&65535)>>>8&255;i=c[276674]|f&65535;do{if(((d[1041668]|0)+(i&255)|0)>>>0>255){f=(c[348392]|0)+6|0;c[348392]=f;if((f|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);f=j0((e[520834]|0)+i|0)|0;a[1044496]=f;a[1041660]=f;a[1106728]=f;a[1106720]=f;return}function oX(){var d=0,e=0,f=0,g=0;d=j0(c[260418]|0)|0;a[1044496]=d;b[520836]=(b[520836]|0)+1&65535;e=b[520831]|0;f=e+(d&255)&65535;d=e&255;do{if(d<<24>>24==0){g=0}else{e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)<(c[348406]|0)){g=d;break}do{j1();}while((c[348392]|0)>=(c[348406]|0));g=a[1041662]|0}}while(0);d=j5(f&65535,g<<24>>24!=0?65535:255)|0;a[1044496]=(d&65535)>>>8&255;g=j0(c[276674]|d&65535)|0;a[1044496]=g;a[1041660]=g;a[1106728]=g;a[1106720]=g;return}function oY(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;f=(a[1041662]|0)==0;g=b[520836]|0;h=a[(c[348396]|0)+(g&65535)|0]|0;a[1044496]=h;i=(c[348392]|0)+(c[348399]|0)|0;c[348392]=i;j=c[348406]|0;k=(i|0)<(j|0);if(f){if(k){l=g;m=i;n=j}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+1&65535;l=b[520831]|0;p=l+(h&255)&65535;do{if((l&255)<<24>>24==0){q=m;r=n}else{o=m+6|0;c[348392]=o;if((o|0)<(n|0)){q=o;r=n;break}while(1){j1();o=c[348392]|0;f=c[348406]|0;if((o|0)<(f|0)){q=o;r=f;break}}}}while(0);n=(d[1041666]|0)+p&65535;m=q+6|0;c[348392]=m;if((m|0)>=(r|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}s=(n&255|p&-256)&65535;t=j0(s)|0;a[1044496]=t;a[1041668]=t;a[1106728]=t;a[1106720]=t;return}else{if(k){u=g;v=i;w=j}else{do{j1();x=c[348392]|0;y=c[348406]|0;}while((x|0)>=(y|0));u=b[520836]|0;v=x;w=y}b[520836]=u+1&65535;u=b[520831]|0;y=u+(h&255)&65535;do{if((u&255)<<24>>24==0){z=v;A=w}else{h=v+6|0;c[348392]=h;if((h|0)<(w|0)){z=h;A=w;break}while(1){j1();h=c[348392]|0;x=c[348406]|0;if((h|0)<(x|0)){z=h;A=x;break}}}}while(0);w=(e[520833]|0)+(y&65535)|0;y=z+6|0;c[348392]=y;if((y|0)>=(A|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}s=w&65535;t=j0(s)|0;a[1044496]=t;a[1041668]=t;a[1106728]=t;a[1106720]=t;return}}function oZ(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;f=(a[1041662]|0)==0;g=b[520836]|0;h=a[(c[348396]|0)+(g&65535)|0]|0;a[1044496]=h;i=(c[348392]|0)+(c[348399]|0)|0;c[348392]=i;j=c[348406]|0;k=(i|0)<(j|0);if(f){if(k){l=g;m=i;n=j}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+1&65535;l=b[520831]|0;p=l+(h&255)&65535;do{if((l&255)<<24>>24==0){q=m;r=n}else{o=m+6|0;c[348392]=o;if((o|0)<(n|0)){q=o;r=n;break}while(1){j1();o=c[348392]|0;f=c[348406]|0;if((o|0)<(f|0)){q=o;r=f;break}}}}while(0);n=(d[1041666]|0)+p&65535;m=q+6|0;c[348392]=m;if((m|0)>=(r|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}s=(n&255|p&-256)&65535;t=j0(s)|0;a[1044496]=t;a[1041660]=t;a[1106728]=t;a[1106720]=t;return}else{if(k){u=g;v=i;w=j}else{do{j1();x=c[348392]|0;y=c[348406]|0;}while((x|0)>=(y|0));u=b[520836]|0;v=x;w=y}b[520836]=u+1&65535;u=b[520831]|0;y=u+(h&255)&65535;do{if((u&255)<<24>>24==0){z=v;A=w}else{h=v+6|0;c[348392]=h;if((h|0)<(w|0)){z=h;A=w;break}while(1){j1();h=c[348392]|0;x=c[348406]|0;if((h|0)<(x|0)){z=h;A=x;break}}}}while(0);w=(e[520833]|0)+(y&65535)|0;y=z+6|0;c[348392]=y;if((y|0)>=(A|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}s=w&65535;t=j0(s)|0;a[1044496]=t;a[1041660]=t;a[1106728]=t;a[1106720]=t;return}}function o_(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;f=(a[1041662]|0)==0;g=b[520836]|0;h=a[(c[348396]|0)+(g&65535)|0]|0;a[1044496]=h;i=(c[348392]|0)+(c[348399]|0)|0;c[348392]=i;j=c[348406]|0;k=(i|0)<(j|0);if(f){if(k){l=g;m=i;n=j}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+1&65535;l=b[520831]|0;p=l+(h&255)&65535;do{if((l&255)<<24>>24==0){q=m;r=n}else{o=m+6|0;c[348392]=o;if((o|0)<(n|0)){q=o;r=n;break}while(1){j1();o=c[348392]|0;f=c[348406]|0;if((o|0)<(f|0)){q=o;r=f;break}}}}while(0);n=(d[1041668]|0)+p&65535;m=q+6|0;c[348392]=m;if((m|0)>=(r|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}s=(n&255|p&-256)&65535;t=j0(s)|0;a[1044496]=t;a[1041666]=t;a[1106728]=t;a[1106720]=t;return}else{if(k){u=g;v=i;w=j}else{do{j1();x=c[348392]|0;y=c[348406]|0;}while((x|0)>=(y|0));u=b[520836]|0;v=x;w=y}b[520836]=u+1&65535;u=b[520831]|0;y=u+(h&255)&65535;do{if((u&255)<<24>>24==0){z=v;A=w}else{h=v+6|0;c[348392]=h;if((h|0)<(w|0)){z=h;A=w;break}while(1){j1();h=c[348392]|0;x=c[348406]|0;if((h|0)<(x|0)){z=h;A=x;break}}}}while(0);w=(e[520834]|0)+(y&65535)|0;y=z+6|0;c[348392]=y;if((y|0)>=(A|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}s=w&65535;t=j0(s)|0;a[1044496]=t;a[1041666]=t;a[1106728]=t;a[1106720]=t;return}}function o$(){var b=0,c=0;b=j0(xc(1)|0)|0;a[1044496]=b;c=(d[1041660]|0)-(b&255)&65535;a[1106736]=(c&65535)>>>15&255^1;b=c&255;a[1106728]=b;a[1106720]=b;return}function o0(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}l=h+1&65535;b[520836]=l;h=l+(e<<24>>24)&65535;e=(h&65535)>>>8;if((a[1106728]|0)==0){return}k=i+6|0;c[348392]=k;if((k|0)<(j|0)){m=k;n=(l&65535)>>>8&255;o=j}else{do{j1();p=c[348392]|0;q=c[348406]|0;}while((p|0)>=(q|0));m=p;n=a[1041673|0]|0;o=q}do{if((n&255|0)!=(e&65535|0)){q=m+6|0;c[348392]=q;if((q|0)<(o|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);o=e<<8;e=o|h&255;if(((b[520836]^o)&65535)>4095){j4((c[276676]|0)+(e&65535)|0);return}else{b[520836]=e;return}}function o1(){var f=0,g=0,h=0,i=0;f=j0(c[260418]|0)|0;a[1044496]=f;b[520836]=(b[520836]|0)+1&65535;g=b[520831]|0;h=g+(f&255)&65535;f=g&255;do{if(f<<24>>24==0){i=0}else{g=(c[348392]|0)+6|0;c[348392]=g;if((g|0)<(c[348406]|0)){i=f;break}do{j1();}while((c[348392]|0)>=(c[348406]|0));i=a[1041662]|0}}while(0);f=j5(h&65535,i<<24>>24!=0?65535:255)|0;a[1044496]=(f&65535)>>>8&255;i=c[276674]|f&65535;do{if(((d[1041668]|0)+(i&255)|0)>>>0>255){f=(c[348392]|0)+6|0;c[348392]=f;if((f|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);f=j0((e[520834]|0)+i|0)|0;a[1044496]=f;i=(d[1041660]|0)-(f&255)&65535;a[1106736]=(i&65535)>>>15&255^1;f=i&255;a[1106728]=f;a[1106720]=f;return}function o2(){var e=0,f=0,g=0,h=0;e=j0(c[260418]|0)|0;a[1044496]=e;b[520836]=(b[520836]|0)+1&65535;f=b[520831]|0;g=f+(e&255)&65535;e=f&255;do{if(e<<24>>24==0){h=0}else{f=(c[348392]|0)+6|0;c[348392]=f;if((f|0)<(c[348406]|0)){h=e;break}do{j1();}while((c[348392]|0)>=(c[348406]|0));h=a[1041662]|0}}while(0);e=j5(g&65535,h<<24>>24!=0?65535:255)|0;a[1044496]=(e&65535)>>>8&255;h=j0(c[276674]|e&65535)|0;a[1044496]=h;e=(d[1041660]|0)-(h&255)&65535;a[1106736]=(e&65535)>>>15&255^1;h=e&255;a[1106728]=h;a[1106720]=h;return}function o3(){var d=0,f=0,g=0,h=0;d=j0(c[260418]|0)|0;a[1044496]=d;b[520836]=(b[520836]|0)+1&65535;f=b[520831]|0;g=f+(d&255)&65535;d=f&255;do{if(d<<24>>24==0){h=0}else{f=(c[348392]|0)+6|0;c[348392]=f;if((f|0)<(c[348406]|0)){h=d;break}do{j1();}while((c[348392]|0)>=(c[348406]|0));h=a[1041662]|0}}while(0);d=(j5(g&65535,h<<24>>24!=0?65535:255)|0)&65535;h=c[276674]|d;j3(h&65535,(e[520832]|0)-1|0,65535);b[520832]=(b[520832]|0)-2&65535;a[1044496]=h&255;a[1041665|0]=1;return}function o4(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;f=(a[1041662]|0)==0;g=b[520836]|0;h=a[(c[348396]|0)+(g&65535)|0]|0;a[1044496]=h;i=(c[348392]|0)+(c[348399]|0)|0;c[348392]=i;j=c[348406]|0;k=(i|0)<(j|0);if(f){if(k){l=g;m=i;n=j}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+1&65535;l=b[520831]|0;p=l+(h&255)&65535;do{if((l&255)<<24>>24==0){q=m;r=n}else{o=m+6|0;c[348392]=o;if((o|0)<(n|0)){q=o;r=n;break}while(1){j1();o=c[348392]|0;f=c[348406]|0;if((o|0)<(f|0)){q=o;r=f;break}}}}while(0);n=(d[1041666]|0)+p&65535;m=q+6|0;c[348392]=m;if((m|0)>=(r|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}s=(n&255|p&-256)&65535;t=j0(s)|0;a[1044496]=t;u=a[1041660]|0;v=u&255;w=t&255;x=v-w&65535;y=(x&65535)>>>15;z=y&255;A=z^1;a[1106736]=A;B=x&255;a[1106728]=B;a[1106720]=B;return}else{if(k){C=g;D=i;E=j}else{do{j1();F=c[348392]|0;G=c[348406]|0;}while((F|0)>=(G|0));C=b[520836]|0;D=F;E=G}b[520836]=C+1&65535;C=b[520831]|0;G=C+(h&255)&65535;do{if((C&255)<<24>>24==0){H=D;I=E}else{h=D+6|0;c[348392]=h;if((h|0)<(E|0)){H=h;I=E;break}while(1){j1();h=c[348392]|0;F=c[348406]|0;if((h|0)<(F|0)){H=h;I=F;break}}}}while(0);E=(e[520833]|0)+(G&65535)|0;G=H+6|0;c[348392]=G;if((G|0)>=(I|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}s=E&65535;t=j0(s)|0;a[1044496]=t;u=a[1041660]|0;v=u&255;w=t&255;x=v-w&65535;y=(x&65535)>>>15;z=y&255;A=z^1;a[1106736]=A;B=x&255;a[1106728]=B;a[1106720]=B;return}}function o5(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;f=(a[1041662]|0)==0;g=b[520836]|0;h=a[(c[348396]|0)+(g&65535)|0]|0;a[1044496]=h;i=(c[348392]|0)+(c[348399]|0)|0;c[348392]=i;j=c[348406]|0;k=(i|0)<(j|0);if(f){if(k){l=g;m=i;n=j}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+1&65535;l=b[520831]|0;p=l+(h&255)&65535;do{if((l&255)<<24>>24==0){q=m;r=n}else{o=m+6|0;c[348392]=o;if((o|0)<(n|0)){q=o;r=n;break}while(1){j1();o=c[348392]|0;f=c[348406]|0;if((o|0)<(f|0)){q=o;r=f;break}}}}while(0);n=(d[1041666]|0)+p&65535;m=q+6|0;c[348392]=m;if((m|0)>=(r|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}s=(n&255|p&-256)&65535}else{if(k){t=g;u=i;v=j}else{do{j1();w=c[348392]|0;x=c[348406]|0;}while((w|0)>=(x|0));t=b[520836]|0;u=w;v=x}b[520836]=t+1&65535;t=b[520831]|0;x=t+(h&255)&65535;do{if((t&255)<<24>>24==0){y=u;z=v}else{h=u+6|0;c[348392]=h;if((h|0)<(v|0)){y=h;z=v;break}while(1){j1();h=c[348392]|0;w=c[348406]|0;if((h|0)<(w|0)){y=h;z=w;break}}}}while(0);v=(e[520833]|0)+(x&65535)|0;x=y+6|0;c[348392]=x;if((x|0)>=(z|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}s=v&65535}v=(j0(s)|0)-1&255;z=(c[348392]|0)+6|0;c[348392]=z;if((z|0)<(c[348406]|0)){j2(v,s);a[1044496]=v;a[1106728]=v;a[1106720]=v;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));j2(v,s);a[1044496]=v;a[1106728]=v;a[1106720]=v;return}function o6(){var b=0;b=(c[348392]|0)+6|0;c[348392]=b;if((b|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}j2(a[1041666]|0,e[520832]|0);a[1041664]=(a[1041664]|0)-1&255;a[1044496]=a[1041666]|0;return}function o7(){var c=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;c=j0(xc(1)|0)|0;a[1044496]=c;if((a[1041658]&8)==0){e=a[1041660]|0;f=((e&255)+~(c&255)&65535)+(d[1106736]|0)&65535;a[1106736]=(f&65535)>>>15&255^1;g=f&255;h=g;i=(g^e)&(e^c);j=(i&255)>>>7;a[1106712]=j;a[1041660]=h;a[1106728]=h;a[1106720]=h;return}e=b[520830]|0;g=e&255;f=((g&15)-(c&15)&255)-((a[1106736]|0)==0)&255;k=(e&240)-(c&-16&255)&65535;if((f&255)>15){l=f+10&15;m=k-16&65535}else{l=f;m=k}if((m&65535)>240){a[1106736]=0;n=m+160&255&-16}else{a[1106736]=1;n=m&255}m=n|l;h=m;i=(m^g)&(g^c);j=(i&255)>>>7;a[1106712]=j;a[1041660]=h;a[1106728]=h;a[1106720]=h;return}function o8(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}l=h+1&65535;b[520836]=l;h=l+(e<<24>>24)&65535;e=(h&65535)>>>8;if((a[1106728]|0)!=0){return}k=i+6|0;c[348392]=k;if((k|0)<(j|0)){m=k;n=(l&65535)>>>8&255;o=j}else{do{j1();p=c[348392]|0;q=c[348406]|0;}while((p|0)>=(q|0));m=p;n=a[1041673|0]|0;o=q}do{if((n&255|0)!=(e&65535|0)){q=m+6|0;c[348392]=q;if((q|0)<(o|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);o=e<<8;e=o|h&255;if(((b[520836]^o)&65535)>4095){j4((c[276676]|0)+(e&65535)|0);return}else{b[520836]=e;return}}function o9(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=j0(c[260418]|0)|0;a[1044496]=f;b[520836]=(b[520836]|0)+1&65535;g=b[520831]|0;h=g+(f&255)&65535;f=g&255;do{if(f<<24>>24==0){i=0}else{g=(c[348392]|0)+6|0;c[348392]=g;if((g|0)<(c[348406]|0)){i=f;break}do{j1();}while((c[348392]|0)>=(c[348406]|0));i=a[1041662]|0}}while(0);f=j5(h&65535,i<<24>>24!=0?65535:255)|0;a[1044496]=(f&65535)>>>8&255;i=c[276674]|f&65535;do{if(((d[1041668]|0)+(i&255)|0)>>>0>255){f=(c[348392]|0)+6|0;c[348392]=f;if((f|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);f=j0((e[520834]|0)+i|0)|0;a[1044496]=f;if((a[1041658]&8)==0){i=a[1041660]|0;h=((i&255)+~(f&255)&65535)+(d[1106736]|0)&65535;a[1106736]=(h&65535)>>>15&255^1;g=h&255;j=g;k=(g^i)&(i^f);l=(k&255)>>>7;a[1106712]=l;a[1041660]=j;a[1106728]=j;a[1106720]=j;return}i=b[520830]|0;g=i&255;h=((g&15)-(f&15)&255)-((a[1106736]|0)==0)&255;m=(i&240)-(f&-16&255)&65535;if((h&255)>15){n=h+10&15;o=m-16&65535}else{n=h;o=m}if((o&65535)>240){a[1106736]=0;p=o+160&255&-16}else{a[1106736]=1;p=o&255}o=p|n;j=o;k=(o^g)&(g^f);l=(k&255)>>>7;a[1106712]=l;a[1041660]=j;a[1106728]=j;a[1106720]=j;return}function pa(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=j0(c[260418]|0)|0;a[1044496]=e;b[520836]=(b[520836]|0)+1&65535;f=b[520831]|0;g=f+(e&255)&65535;e=f&255;do{if(e<<24>>24==0){h=0}else{f=(c[348392]|0)+6|0;c[348392]=f;if((f|0)<(c[348406]|0)){h=e;break}do{j1();}while((c[348392]|0)>=(c[348406]|0));h=a[1041662]|0}}while(0);e=j5(g&65535,h<<24>>24!=0?65535:255)|0;a[1044496]=(e&65535)>>>8&255;h=j0(c[276674]|e&65535)|0;a[1044496]=h;if((a[1041658]&8)==0){e=a[1041660]|0;g=((e&255)+~(h&255)&65535)+(d[1106736]|0)&65535;a[1106736]=(g&65535)>>>15&255^1;f=g&255;i=f;j=(f^e)&(e^h);k=(j&255)>>>7;a[1106712]=k;a[1041660]=i;a[1106728]=i;a[1106720]=i;return}e=b[520830]|0;f=e&255;g=((f&15)-(h&15)&255)-((a[1106736]|0)==0)&255;l=(e&240)-(h&-16&255)&65535;if((g&255)>15){m=g+10&15;n=l-16&65535}else{m=g;n=l}if((n&65535)>240){a[1106736]=0;o=n+160&255&-16}else{a[1106736]=1;o=n&255}n=o|m;i=n;j=(n^f)&(f^h);k=(j&255)>>>7;a[1106712]=k;a[1041660]=i;a[1106728]=i;a[1106720]=i;return}function pb(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=(d[g+(i+1)|0]|0)<<8|(d[g+i|0]|0);i=(c[348392]|0)+(c[348400]|0)|0;c[348392]=i;if((i|0)<(c[348406]|0)){k=h}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));k=b[520836]|0}b[520836]=k+2&65535;k=j&65535|f;j3(k&65535,(e[520832]|0)-1|0,65535);b[520832]=(b[520832]|0)-2&65535;a[1044496]=k&255;a[1041665|0]=1;return}function pc(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;f=(a[1041662]|0)==0;g=b[520836]|0;h=a[(c[348396]|0)+(g&65535)|0]|0;a[1044496]=h;i=(c[348392]|0)+(c[348399]|0)|0;c[348392]=i;j=c[348406]|0;k=(i|0)<(j|0);if(f){if(k){l=g;m=i;n=j}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+1&65535;l=b[520831]|0;p=l+(h&255)&65535;do{if((l&255)<<24>>24==0){q=m;r=n}else{o=m+6|0;c[348392]=o;if((o|0)<(n|0)){q=o;r=n;break}while(1){j1();o=c[348392]|0;f=c[348406]|0;if((o|0)<(f|0)){q=o;r=f;break}}}}while(0);n=(d[1041666]|0)+p&65535;m=q+6|0;c[348392]=m;if((m|0)>=(r|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}s=(n&255|p&-256)&65535}else{if(k){t=g;u=i;v=j}else{do{j1();w=c[348392]|0;x=c[348406]|0;}while((w|0)>=(x|0));t=b[520836]|0;u=w;v=x}b[520836]=t+1&65535;t=b[520831]|0;x=t+(h&255)&65535;do{if((t&255)<<24>>24==0){y=u;z=v}else{h=u+6|0;c[348392]=h;if((h|0)<(v|0)){y=h;z=v;break}while(1){j1();h=c[348392]|0;w=c[348406]|0;if((h|0)<(w|0)){y=h;z=w;break}}}}while(0);v=(e[520833]|0)+(x&65535)|0;x=y+6|0;c[348392]=x;if((x|0)>=(z|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}s=v&65535}v=j0(s)|0;a[1044496]=v;if((a[1041658]&8)==0){s=a[1041660]|0;z=((s&255)+~(v&255)&65535)+(d[1106736]|0)&65535;a[1106736]=(z&65535)>>>15&255^1;x=z&255;A=x;B=(x^s)&(s^v);C=(B&255)>>>7;a[1106712]=C;a[1041660]=A;a[1106728]=A;a[1106720]=A;return}s=b[520830]|0;x=s&255;z=((x&15)-(v&15)&255)-((a[1106736]|0)==0)&255;y=(s&240)-(v&-16&255)&65535;if((z&255)>15){D=z+10&15;E=y-16&65535}else{D=z;E=y}if((E&65535)>240){a[1106736]=0;F=E+160&255&-16}else{a[1106736]=1;F=E&255}E=F|D;A=E;B=(E^x)&(x^v);C=(B&255)>>>7;a[1106712]=C;a[1041660]=A;a[1106728]=A;a[1106720]=A;return}function pd(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;f=(a[1041662]|0)==0;g=b[520836]|0;h=a[(c[348396]|0)+(g&65535)|0]|0;a[1044496]=h;i=(c[348392]|0)+(c[348399]|0)|0;c[348392]=i;j=c[348406]|0;k=(i|0)<(j|0);if(f){if(k){l=g;m=i;n=j}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+1&65535;l=b[520831]|0;p=l+(h&255)&65535;do{if((l&255)<<24>>24==0){q=m;r=n}else{o=m+6|0;c[348392]=o;if((o|0)<(n|0)){q=o;r=n;break}while(1){j1();o=c[348392]|0;f=c[348406]|0;if((o|0)<(f|0)){q=o;r=f;break}}}}while(0);n=(d[1041666]|0)+p&65535;m=q+6|0;c[348392]=m;if((m|0)>=(r|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}s=(n&255|p&-256)&65535}else{if(k){t=g;u=i;v=j}else{do{j1();w=c[348392]|0;x=c[348406]|0;}while((w|0)>=(x|0));t=b[520836]|0;u=w;v=x}b[520836]=t+1&65535;t=b[520831]|0;x=t+(h&255)&65535;do{if((t&255)<<24>>24==0){y=u;z=v}else{h=u+6|0;c[348392]=h;if((h|0)<(v|0)){y=h;z=v;break}while(1){j1();h=c[348392]|0;w=c[348406]|0;if((h|0)<(w|0)){y=h;z=w;break}}}}while(0);v=(e[520833]|0)+(x&65535)|0;x=y+6|0;c[348392]=x;if((x|0)>=(z|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}s=v&65535}v=(j0(s)|0)+1&255;z=(c[348392]|0)+6|0;c[348392]=z;if((z|0)<(c[348406]|0)){j2(v,s);a[1044496]=v;a[1106728]=v;a[1106720]=v;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));j2(v,s);a[1044496]=v;a[1106728]=v;a[1106720]=v;return}function pe(){var b=0;b=(c[348392]|0)+12|0;c[348392]=b;if((b|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}a[1041664]=(a[1041664]|0)+1&255;b=j0(e[520832]|0)|0;a[1041666]=b;a[1106728]=b;a[1106720]=b;a[1044496]=b;return}function pf(){var d=0,f=0;d=j5(c[260418]|0,65535)|0;a[1044496]=(d&65535)>>>8&255;b[520836]=(b[520836]|0)+2&65535;f=j5((b[520833]|0)+d&65535|c[276676],65535)|0;a[1044496]=(f&65535)>>>8&255;j3((b[520836]|0)-1&65535,(e[520832]|0)-1|0,65535);b[520832]=(b[520832]|0)-2&65535;a[1041665|0]=1;j4((c[276676]|0)+(f&65535)|0);return}function pg(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}b[520836]=h+1&65535;h=b[520831]|0;l=h+(e&255)&65535;do{if((h&255)<<24>>24!=0){e=i+6|0;c[348392]=e;if((e|0)<(j|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j=j5(l&65535,16777215)|0;a[1044496]=(j&65535)>>>8&255;l=c[276674]|j&65535;j=(c[348392]|0)+6|0;c[348392]=j;if((j|0)<(c[348406]|0)){m=b[520834]|0;n=m&65535;o=n+l|0;p=j0(o)|0;a[1044496]=p;q=a[1041660]|0;r=q|p;a[1041660]=r;a[1106728]=r;a[1106720]=r;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));m=b[520834]|0;n=m&65535;o=n+l|0;p=j0(o)|0;a[1044496]=p;q=a[1041660]|0;r=q|p;a[1041660]=r;a[1106728]=r;a[1106720]=r;return}function ph(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;f=m+6|0;c[348392]=f;if((f|0)>=(n|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}n=j0((e[520834]|0)+l|0)|0;a[1044496]=n;l=a[1041660]|n;a[1041660]=l;a[1106728]=l;a[1106720]=l;return}function pi(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;f=m+6|0;c[348392]=f;if((f|0)>=(n|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}n=j0((e[520833]|0)+l|0)|0;a[1044496]=n;l=a[1041660]|n;a[1041660]=l;a[1106728]=l;a[1106720]=l;return}function pj(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;f=m+6|0;c[348392]=f;if((f|0)>=(n|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}n=(e[520833]|0)+l|0;l=j0(n)|0;a[1106736]=(l&255)>>>7;f=l<<1;l=(c[348392]|0)+6|0;c[348392]=l;if((l|0)<(c[348406]|0)){j2(f,n);a[1044496]=f;a[1106728]=f;a[1106720]=f;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));j2(f,n);a[1044496]=f;a[1106728]=f;a[1106720]=f;return}function pk(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}b[520836]=h+1&65535;h=b[520831]|0;l=h+(e&255)&65535;do{if((h&255)<<24>>24!=0){e=i+6|0;c[348392]=e;if((e|0)<(j|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j=j5(l&65535,16777215)|0;a[1044496]=(j&65535)>>>8&255;l=c[276674]|j&65535;j=(c[348392]|0)+6|0;c[348392]=j;if((j|0)<(c[348406]|0)){m=b[520834]|0;n=m&65535;o=n+l|0;p=j0(o)|0;a[1044496]=p;q=a[1041660]|0;r=q&p;a[1041660]=r;a[1106728]=r;a[1106720]=r;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));m=b[520834]|0;n=m&65535;o=n+l|0;p=j0(o)|0;a[1044496]=p;q=a[1041660]|0;r=q&p;a[1041660]=r;a[1106728]=r;a[1106720]=r;return}function pl(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;f=m+6|0;c[348392]=f;if((f|0)>=(n|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}n=j0((e[520834]|0)+l|0)|0;a[1044496]=n;l=a[1041660]&n;a[1041660]=l;a[1106728]=l;a[1106720]=l;return}function pm(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;f=m+6|0;c[348392]=f;if((f|0)>=(n|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}n=j0((e[520833]|0)+l|0)|0;a[1044496]=n;a[1106712]=(n&255)>>>6&1;a[1106720]=n;a[1106728]=a[1041660]&n;return}function pn(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;f=m+6|0;c[348392]=f;if((f|0)>=(n|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}n=j0((e[520833]|0)+l|0)|0;a[1044496]=n;l=a[1041660]&n;a[1041660]=l;a[1106728]=l;a[1106720]=l;return}function po(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;f=m+6|0;c[348392]=f;if((f|0)>=(n|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}n=(e[520833]|0)+l|0;l=((j0(n)|0)&255)<<1;f=l|(d[1106736]|0);a[1106736]=(f&65535)>255|0;l=(c[348392]|0)+6|0;c[348392]=l;if((l|0)<(c[348406]|0)){q=f&255;j2(q,n);a[1044496]=q;a[1106728]=q;a[1106720]=q;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));q=f&255;j2(q,n);a[1044496]=q;a[1106728]=q;a[1106720]=q;return}function pp(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=b[520836]|0;f=c[348396]|0;g=a[f+(d&65535)|0]|0;h=c[348399]|0;i=(c[348392]|0)+h|0;c[348392]=i;j=c[348406]|0;if((i|0)<(j|0)){k=d;l=f;m=h;n=i;o=j}else{do{j1();p=c[348392]|0;q=c[348406]|0;}while((p|0)>=(q|0));k=b[520836]|0;l=c[348396]|0;m=c[348399]|0;n=p;o=q}q=k+1&65535;b[520836]=q;a[1041656]=g;c[276674]=(g&255)<<16;g=a[l+(q&65535)|0]|0;l=m+n|0;c[348392]=l;if((l|0)<(o|0)){r=q}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));r=b[520836]|0}b[520836]=r+1&65535;a[1044496]=g;r=j0(e[520833]|0|(g&255)<<16)|0;a[1044496]=r;j2(r,(e[520834]|0)+(c[276674]|0)|0);b[520833]=(b[520833]|0)-1&65535;b[520834]=(b[520834]|0)-1&65535;r=b[520830]|0;b[520830]=r-1&65535;if(r<<16>>16!=0){b[520836]=(b[520836]|0)-3&65535}r=(c[348392]|0)+12|0;c[348392]=r;if((r|0)<(c[348406]|0)){return}do{j1();}while((c[348392]|0)>=(c[348406]|0));return}function pq(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}b[520836]=h+1&65535;h=b[520831]|0;l=h+(e&255)&65535;do{if((h&255)<<24>>24!=0){e=i+6|0;c[348392]=e;if((e|0)<(j|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j=j5(l&65535,16777215)|0;a[1044496]=(j&65535)>>>8&255;l=c[276674]|j&65535;j=(c[348392]|0)+6|0;c[348392]=j;if((j|0)<(c[348406]|0)){m=b[520834]|0;n=m&65535;o=n+l|0;p=j0(o)|0;a[1044496]=p;q=a[1041660]|0;r=q^p;a[1041660]=r;a[1106728]=r;a[1106720]=r;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));m=b[520834]|0;n=m&65535;o=n+l|0;p=j0(o)|0;a[1044496]=p;q=a[1041660]|0;r=q^p;a[1041660]=r;a[1106728]=r;a[1106720]=r;return}function pr(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=b[520836]|0;f=c[348396]|0;g=a[f+(d&65535)|0]|0;h=c[348399]|0;i=(c[348392]|0)+h|0;c[348392]=i;j=c[348406]|0;if((i|0)<(j|0)){k=d;l=f;m=h;n=i;o=j}else{do{j1();p=c[348392]|0;q=c[348406]|0;}while((p|0)>=(q|0));k=b[520836]|0;l=c[348396]|0;m=c[348399]|0;n=p;o=q}q=k+1&65535;b[520836]=q;a[1041656]=g;c[276674]=(g&255)<<16;g=a[l+(q&65535)|0]|0;l=m+n|0;c[348392]=l;if((l|0)<(o|0)){r=q}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));r=b[520836]|0}b[520836]=r+1&65535;a[1044496]=g;r=j0(e[520833]|0|(g&255)<<16)|0;a[1044496]=r;j2(r,(e[520834]|0)+(c[276674]|0)|0);b[520833]=(b[520833]|0)+1&65535;b[520834]=(b[520834]|0)+1&65535;r=b[520830]|0;b[520830]=r-1&65535;if(r<<16>>16!=0){b[520836]=(b[520836]|0)-3&65535}r=(c[348392]|0)+12|0;c[348392]=r;if((r|0)<(c[348406]|0)){return}do{j1();}while((c[348392]|0)>=(c[348406]|0));return}function ps(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;f=m+6|0;c[348392]=f;if((f|0)>=(n|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}n=j0((e[520834]|0)+l|0)|0;a[1044496]=n;l=a[1041660]^n;a[1041660]=l;a[1106728]=l;a[1106720]=l;return}function pt(){var d=0;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}j3(b[520834]|0,(e[520832]|0)-1|0,65535);b[520832]=(b[520832]|0)-2&65535;a[1044496]=a[1041668]|0;return}function pu(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;f=m+6|0;c[348392]=f;if((f|0)>=(n|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}n=j0((e[520833]|0)+l|0)|0;a[1044496]=n;l=a[1041660]^n;a[1041660]=l;a[1106728]=l;a[1106720]=l;return}function pv(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;f=m+6|0;c[348392]=f;if((f|0)>=(n|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}n=(e[520833]|0)+l|0;l=j0(n)|0;a[1106736]=l&1;f=(l&255)>>>1;l=(c[348392]|0)+6|0;c[348392]=l;if((l|0)<(c[348406]|0)){j2(f,n);a[1044496]=f;a[1106728]=f;a[1106720]=f;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));j2(f,n);a[1044496]=f;a[1106728]=f;a[1106720]=f;return}function pw(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=b[520836]|0;g=a[(c[348396]|0)+(f&65535)|0]|0;a[1044496]=g;h=(c[348392]|0)+(c[348399]|0)|0;c[348392]=h;i=c[348406]|0;if((h|0)<(i|0)){j=f;k=h;l=i}else{do{j1();m=c[348392]|0;n=c[348406]|0;}while((m|0)>=(n|0));j=b[520836]|0;k=m;l=n}b[520836]=j+1&65535;j=b[520831]|0;n=j+(g&255)&65535;do{if((j&255)<<24>>24!=0){g=k+6|0;c[348392]=g;if((g|0)<(l|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);l=j5(n&65535,16777215)|0;a[1044496]=(l&65535)>>>8&255;n=c[276674]|l&65535;l=(c[348392]|0)+6|0;c[348392]=l;if((l|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}l=j0((e[520834]|0)+n|0)|0;a[1044496]=l;if((a[1041658]&8)==0){n=a[1041660]|0;k=l&255;j=(n&255)+k+(d[1106736]|0)|0;a[1106736]=(j&65280)>>>0>255|0;o=j&255;p=((j^k)&((n^l)&255^128))>>>7&255;q=p&1;a[1106712]=q;a[1041660]=o;a[1106728]=o;a[1106720]=o;return}n=b[520830]|0;k=n&255;j=n&240;n=((a[1106736]|0)+(l&15)&255)+(k&15)&255;if((n&255)>9){r=n+6&15;s=j+16&65535}else{r=n;s=j}j=s+(l&-16&255)&65535;if((j&65535)>144){a[1106736]=1;t=j+96&255&-16}else{a[1106736]=0;t=j&255}j=t|r;o=j;p=((j^l)&(l^-128^k)&255)>>>7;q=p&1;a[1106712]=q;a[1041660]=o;a[1106728]=o;a[1106720]=o;return}function px(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;f=m+6|0;c[348392]=f;if((f|0)>=(n|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}n=j0((e[520834]|0)+l|0)|0;a[1044496]=n;if((a[1041658]&8)==0){l=a[1041660]|0;f=n&255;m=(l&255)+f+(d[1106736]|0)|0;a[1106736]=(m&65280)>>>0>255|0;q=m&255;r=((m^f)&((l^n)&255^128))>>>7&255;s=r&1;a[1106712]=s;a[1041660]=q;a[1106728]=q;a[1106720]=q;return}l=b[520830]|0;f=l&255;m=l&240;l=((a[1106736]|0)+(n&15)&255)+(f&15)&255;if((l&255)>9){t=l+6&15;u=m+16&65535}else{t=l;u=m}m=u+(n&-16&255)&65535;if((m&65535)>144){a[1106736]=1;v=m+96&255&-16}else{a[1106736]=0;v=m&255}m=v|t;q=m;r=((m^n)&(n^-128^f)&255)>>>7;s=r&1;a[1106712]=s;a[1041660]=q;a[1106728]=q;a[1106720]=q;return}function py(){var d=0,f=0;d=(c[348392]|0)+12|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}d=j5((e[520832]|0)+1|0,65535)|0;b[520834]=d;b[520832]=(b[520832]|0)+2&65535;a[1106728]=d<<16>>16!=0|0;f=(d&65535)>>>8&255;a[1106720]=f;a[1044496]=f;return}function pz(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;f=m+6|0;c[348392]=f;if((f|0)>=(n|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}n=j0((e[520833]|0)+l|0)|0;a[1044496]=n;if((a[1041658]&8)==0){l=a[1041660]|0;f=n&255;m=(l&255)+f+(d[1106736]|0)|0;a[1106736]=(m&65280)>>>0>255|0;q=m&255;r=((m^f)&((l^n)&255^128))>>>7&255;s=r&1;a[1106712]=s;a[1041660]=q;a[1106728]=q;a[1106720]=q;return}l=b[520830]|0;f=l&255;m=l&240;l=((a[1106736]|0)+(n&15)&255)+(f&15)&255;if((l&255)>9){t=l+6&15;u=m+16&65535}else{t=l;u=m}m=u+(n&-16&255)&65535;if((m&65535)>144){a[1106736]=1;v=m+96&255&-16}else{a[1106736]=0;v=m&255}m=v|t;q=m;r=((m^n)&(n^-128^f)&255)>>>7;s=r&1;a[1106712]=s;a[1041660]=q;a[1106728]=q;a[1106720]=q;return}function pA(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;f=m+6|0;c[348392]=f;if((f|0)>=(n|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}n=(e[520833]|0)+l|0;l=j0(n)|0;f=(d[1106736]|0)<<8|l&255;a[1106736]=l&1;l=(f&65535)>>>1;f=(c[348392]|0)+6|0;c[348392]=f;if((f|0)<(c[348406]|0)){q=l&255;j2(q,n);a[1044496]=q;a[1106728]=q;a[1106720]=q;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));q=l&255;j2(q,n);a[1044496]=q;a[1106728]=q;a[1106720]=q;return}function pB(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}b[520836]=h+1&65535;h=b[520831]|0;l=h+(e&255)&65535;do{if((h&255)<<24>>24!=0){e=i+6|0;c[348392]=e;if((e|0)<(j|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);w7(b[520834]|0,l&65535,65535);a[1044496]=a[1041669|0]|0;return}function pC(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}b[520836]=h+1&65535;h=b[520831]|0;l=h+(e&255)&65535;do{if((h&255)<<24>>24!=0){e=i+6|0;c[348392]=e;if((e|0)<(j|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);w7(b[520833]|0,l&65535,65535);a[1044496]=a[1041667|0]|0;return}function pD(){var d=0;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}d=(b[520834]|0)-1&65535;b[520834]=d;a[1106728]=d<<16>>16!=0|0;a[1106720]=(d&65535)>>>8&255;return}function pE(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[276674]|0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=(d[f+(h+1)|0]|0)<<8|(d[f+h|0]|0);h=(c[348392]|0)+(c[348400]|0)|0;c[348392]=h;if((h|0)<(c[348406]|0)){j=g}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));j=b[520836]|0}b[520836]=j+2&65535;w7(b[520834]|0,i&65535|e,65535);a[1044496]=a[1041669|0]|0;return}function pF(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[276674]|0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=(d[f+(h+1)|0]|0)<<8|(d[f+h|0]|0);h=(c[348392]|0)+(c[348400]|0)|0;c[348392]=h;if((h|0)<(c[348406]|0)){j=g}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));j=b[520836]|0}b[520836]=j+2&65535;w7(b[520833]|0,i&65535|e,65535);a[1044496]=a[1041667|0]|0;return}function pG(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}b[520836]=h+1&65535;h=b[520831]|0;l=h+(e&255)&65535;do{if((h&255)<<24>>24!=0){e=i+6|0;c[348392]=e;if((e|0)<(j|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j=(j5(l&65535,16777215)|0)&65535;l=c[276674]|j;j=(c[348392]|0)+6|0;c[348392]=j;if((j|0)<(c[348406]|0)){m=b[520834]|0;n=m&65535;o=n+l|0;p=a[1041660]|0;j2(p,o);q=a[1041660]|0;a[1044496]=q;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));m=b[520834]|0;n=m&65535;o=n+l|0;p=a[1041660]|0;j2(p,o);q=a[1041660]|0;a[1044496]=q;return}function pH(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=b[520836]|0;f=a[(c[348396]|0)+(d&65535)|0]|0;g=(c[348392]|0)+(c[348399]|0)|0;c[348392]=g;h=c[348406]|0;if((g|0)<(h|0)){i=d;j=g;k=h}else{do{j1();l=c[348392]|0;m=c[348406]|0;}while((l|0)>=(m|0));i=b[520836]|0;j=l;k=m}b[520836]=i+1&65535;i=b[520831]|0;m=i+(f&255)&65535;do{if((i&255)<<24>>24==0){n=j;o=k}else{f=j+6|0;c[348392]=f;if((f|0)<(k|0)){n=f;o=k;break}while(1){j1();f=c[348392]|0;l=c[348406]|0;if((f|0)<(l|0)){n=f;o=l;break}}}}while(0);k=(e[520833]|0)+(m&65535)|0;m=n+6|0;c[348392]=m;if((m|0)<(o|0)){p=k&65535;q=b[520834]|0;w7(q,p,65535);r=a[1041669|0]|0;a[1044496]=r;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));p=k&65535;q=b[520834]|0;w7(q,p,65535);r=a[1041669|0]|0;a[1044496]=r;return}function pI(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=b[520836]|0;f=a[(c[348396]|0)+(d&65535)|0]|0;g=(c[348392]|0)+(c[348399]|0)|0;c[348392]=g;h=c[348406]|0;if((g|0)<(h|0)){i=d;j=g;k=h}else{do{j1();l=c[348392]|0;m=c[348406]|0;}while((l|0)>=(m|0));i=b[520836]|0;j=l;k=m}b[520836]=i+1&65535;i=b[520831]|0;m=i+(f&255)&65535;do{if((i&255)<<24>>24==0){n=j;o=k}else{f=j+6|0;c[348392]=f;if((f|0)<(k|0)){n=f;o=k;break}while(1){j1();f=c[348392]|0;l=c[348406]|0;if((f|0)<(l|0)){n=f;o=l;break}}}}while(0);k=(e[520834]|0)+(m&65535)|0;m=n+6|0;c[348392]=m;if((m|0)<(o|0)){p=k&65535;q=b[520833]|0;w7(q,p,65535);r=a[1041667|0]|0;a[1044496]=r;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));p=k&65535;q=b[520833]|0;w7(q,p,65535);r=a[1041667|0]|0;a[1044496]=r;return}function pJ(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=c[276674]|0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=(d[f+(h+1)|0]|0)<<8|(d[f+h|0]|0);h=(c[348392]|0)+(c[348400]|0)|0;c[348392]=h;f=c[348406]|0;if((h|0)<(f|0)){j=g;k=h;l=f}else{do{j1();m=c[348392]|0;n=c[348406]|0;}while((m|0)>=(n|0));j=b[520836]|0;k=m;l=n}b[520836]=j+2&65535;j=i&65535|e;e=k+6|0;c[348392]=e;if((e|0)<(l|0)){o=b[520834]|0;p=o&65535;q=p+j|0;r=a[1041660]|0;j2(r,q);s=a[1041660]|0;a[1044496]=s;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));o=b[520834]|0;p=o&65535;q=p+j|0;r=a[1041660]|0;j2(r,q);s=a[1041660]|0;a[1044496]=s;return}function pK(){var d=0;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}d=b[520833]|0;b[520834]=d;a[1106728]=d<<16>>16!=0|0;a[1106720]=(d&65535)>>>8&255;return}function pL(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=c[276674]|0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=(d[f+(h+1)|0]|0)<<8|(d[f+h|0]|0);h=(c[348392]|0)+(c[348400]|0)|0;c[348392]=h;f=c[348406]|0;if((h|0)<(f|0)){j=g;k=h;l=f}else{do{j1();m=c[348392]|0;n=c[348406]|0;}while((m|0)>=(n|0));j=b[520836]|0;k=m;l=n}b[520836]=j+2&65535;j=i&65535|e;e=k+6|0;c[348392]=e;if((e|0)<(l|0)){o=b[520833]|0;p=o&65535;q=p+j|0;r=a[1041660]|0;j2(r,q);s=a[1041660]|0;a[1044496]=s;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));o=b[520833]|0;p=o&65535;q=p+j|0;r=a[1041660]|0;j2(r,q);s=a[1041660]|0;a[1044496]=s;return}function pM(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=c[276674]|0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=(d[f+(h+1)|0]|0)<<8|(d[f+h|0]|0);h=(c[348392]|0)+(c[348400]|0)|0;c[348392]=h;f=c[348406]|0;if((h|0)<(f|0)){j=g;k=h;l=f}else{do{j1();m=c[348392]|0;n=c[348406]|0;}while((m|0)>=(n|0));j=b[520836]|0;k=m;l=n}b[520836]=j+2&65535;j=i&65535|e;e=k+6|0;c[348392]=e;if((e|0)<(l|0)){o=b[520833]|0;p=o&65535;q=p+j|0;j2(0,q);a[1044496]=0;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));o=b[520833]|0;p=o&65535;q=p+j|0;j2(0,q);a[1044496]=0;return}function pN(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[348396]|0;f=b[520836]|0;g=f&65535;h=a[e+(g+1)|0]|0;i=(h&255)<<8|(d[e+g|0]|0);a[1044496]=h;g=(c[348392]|0)+(c[348400]|0)|0;c[348392]=g;if((g|0)<(c[348406]|0)){j=f}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));j=b[520836]|0}b[520836]=j+2&65535;b[520834]=i;a[1106728]=i<<16>>16!=0|0;a[1106720]=h;return}function pO(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[348396]|0;f=b[520836]|0;g=f&65535;h=a[e+(g+1)|0]|0;i=(h&255)<<8|(d[e+g|0]|0);a[1044496]=h;g=(c[348392]|0)+(c[348400]|0)|0;c[348392]=g;if((g|0)<(c[348406]|0)){j=f}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));j=b[520836]|0}b[520836]=j+2&65535;b[520833]=i;a[1106728]=i<<16>>16!=0|0;a[1106720]=h;return}function pP(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}b[520836]=h+1&65535;h=b[520831]|0;l=h+(e&255)&65535;do{if((h&255)<<24>>24!=0){e=i+6|0;c[348392]=e;if((e|0)<(j|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j=j5(l&65535,65535)|0;l=(j&65535)>>>8&255;a[1044496]=l;b[520834]=j;a[1106728]=j<<16>>16!=0|0;a[1106720]=l;return}function pQ(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}b[520836]=h+1&65535;h=b[520831]|0;l=h+(e&255)&65535;do{if((h&255)<<24>>24!=0){e=i+6|0;c[348392]=e;if((e|0)<(j|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j=j5(l&65535,65535)|0;l=(j&65535)>>>8&255;a[1044496]=l;b[520833]=j;a[1106728]=j<<16>>16!=0|0;a[1106720]=l;return}function pR(){var d=0;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}d=b[520830]|0;b[520834]=d;a[1106728]=d<<16>>16!=0|0;a[1106720]=(d&65535)>>>8&255;return}function pS(){var d=0;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}d=b[520830]|0;b[520833]=d;a[1106728]=d<<16>>16!=0|0;a[1106720]=(d&65535)>>>8&255;return}function pT(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=c[276674]|0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[1044496]=i;i=(c[348392]|0)+(c[348400]|0)|0;c[348392]=i;if((i|0)<(c[348406]|0)){k=g}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));k=b[520836]|0}b[520836]=k+2&65535;k=j5(j&65535|e,65535)|0;e=(k&65535)>>>8&255;a[1044496]=e;b[520834]=k;a[1106728]=k<<16>>16!=0|0;a[1106720]=e;return}function pU(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=c[276674]|0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[1044496]=i;i=(c[348392]|0)+(c[348400]|0)|0;c[348392]=i;if((i|0)<(c[348406]|0)){k=g}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));k=b[520836]|0}b[520836]=k+2&65535;k=j5(j&65535|e,65535)|0;e=(k&65535)>>>8&255;a[1044496]=e;b[520833]=k;a[1106728]=k<<16>>16!=0|0;a[1106720]=e;return}function pV(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}b[520836]=h+1&65535;h=b[520831]|0;l=h+(e&255)&65535;do{if((h&255)<<24>>24!=0){e=i+6|0;c[348392]=e;if((e|0)<(j|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j=j5(l&65535,16777215)|0;a[1044496]=(j&65535)>>>8&255;l=c[276674]|j&65535;j=(c[348392]|0)+6|0;c[348392]=j;if((j|0)<(c[348406]|0)){m=b[520834]|0;n=m&65535;o=n+l|0;p=j0(o)|0;a[1044496]=p;a[1041660]=p;a[1106728]=p;a[1106720]=p;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));m=b[520834]|0;n=m&65535;o=n+l|0;p=j0(o)|0;a[1044496]=p;a[1041660]=p;a[1106728]=p;a[1106720]=p;return}function pW(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;d=b[520836]|0;f=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=f;g=(c[348392]|0)+(c[348399]|0)|0;c[348392]=g;h=c[348406]|0;if((g|0)<(h|0)){i=d;j=g;k=h}else{do{j1();l=c[348392]|0;m=c[348406]|0;}while((l|0)>=(m|0));i=b[520836]|0;j=l;k=m}b[520836]=i+1&65535;i=b[520831]|0;m=i+(f&255)&65535;do{if((i&255)<<24>>24==0){n=j;o=k}else{f=j+6|0;c[348392]=f;if((f|0)<(k|0)){n=f;o=k;break}while(1){j1();f=c[348392]|0;l=c[348406]|0;if((f|0)<(l|0)){n=f;o=l;break}}}}while(0);k=(e[520833]|0)+(m&65535)|0;m=n+6|0;c[348392]=m;if((m|0)<(o|0)){p=k&65535;q=j5(p,65535)|0;r=(q&65535)>>>8;s=r&255;a[1044496]=s;b[520834]=q;t=q<<16>>16!=0;u=t&1;a[1106728]=u;a[1106720]=s;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));p=k&65535;q=j5(p,65535)|0;r=(q&65535)>>>8;s=r&255;a[1044496]=s;b[520834]=q;t=q<<16>>16!=0;u=t&1;a[1106728]=u;a[1106720]=s;return}function pX(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;d=b[520836]|0;f=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=f;g=(c[348392]|0)+(c[348399]|0)|0;c[348392]=g;h=c[348406]|0;if((g|0)<(h|0)){i=d;j=g;k=h}else{do{j1();l=c[348392]|0;m=c[348406]|0;}while((l|0)>=(m|0));i=b[520836]|0;j=l;k=m}b[520836]=i+1&65535;i=b[520831]|0;m=i+(f&255)&65535;do{if((i&255)<<24>>24==0){n=j;o=k}else{f=j+6|0;c[348392]=f;if((f|0)<(k|0)){n=f;o=k;break}while(1){j1();f=c[348392]|0;l=c[348406]|0;if((f|0)<(l|0)){n=f;o=l;break}}}}while(0);k=(e[520834]|0)+(m&65535)|0;m=n+6|0;c[348392]=m;if((m|0)<(o|0)){p=k&65535;q=j5(p,65535)|0;r=(q&65535)>>>8;s=r&255;a[1044496]=s;b[520833]=q;t=q<<16>>16!=0;u=t&1;a[1106728]=u;a[1106720]=s;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));p=k&65535;q=j5(p,65535)|0;r=(q&65535)>>>8;s=r&255;a[1044496]=s;b[520833]=q;t=q<<16>>16!=0;u=t&1;a[1106728]=u;a[1106720]=s;return}function pY(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=c[276674]|0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[1044496]=i;i=(c[348392]|0)+(c[348400]|0)|0;c[348392]=i;h=c[348406]|0;if((i|0)<(h|0)){k=g;l=i;m=h}else{do{j1();n=c[348392]|0;o=c[348406]|0;}while((n|0)>=(o|0));k=b[520836]|0;l=n;m=o}b[520836]=k+2&65535;k=j&65535|e;e=l+6|0;c[348392]=e;if((e|0)<(m|0)){p=b[520834]|0;q=p&65535;r=q+k|0;s=j0(r)|0;a[1044496]=s;a[1041660]=s;a[1106728]=s;a[1106720]=s;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));p=b[520834]|0;q=p&65535;r=q+k|0;s=j0(r)|0;a[1044496]=s;a[1041660]=s;a[1106728]=s;a[1106720]=s;return}function pZ(){var d=0;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}d=b[520832]|0;b[520833]=d;a[1106728]=d<<16>>16!=0|0;a[1106720]=(d&65535)>>>8&255;return}function p_(){var d=0;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}d=b[520834]|0;b[520833]=d;a[1106728]=d<<16>>16!=0|0;a[1106720]=(d&65535)>>>8&255;return}function p$(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;f=m+6|0;c[348392]=f;if((f|0)>=(n|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}n=j5((e[520833]|0)+l|0,65535)|0;l=(n&65535)>>>8&255;a[1044496]=l;b[520834]=n;a[1106728]=n<<16>>16!=0|0;a[1106720]=l;return}function p0(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=c[276674]|0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[1044496]=i;i=(c[348392]|0)+(c[348400]|0)|0;c[348392]=i;h=c[348406]|0;if((i|0)<(h|0)){k=g;l=i;m=h}else{do{j1();n=c[348392]|0;o=c[348406]|0;}while((n|0)>=(o|0));k=b[520836]|0;l=n;m=o}b[520836]=k+2&65535;k=j&65535|e;e=l+6|0;c[348392]=e;if((e|0)<(m|0)){p=b[520833]|0;q=p&65535;r=q+k|0;s=j0(r)|0;a[1044496]=s;a[1041660]=s;a[1106728]=s;a[1106720]=s;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));p=b[520833]|0;q=p&65535;r=q+k|0;s=j0(r)|0;a[1044496]=s;a[1041660]=s;a[1106728]=s;a[1106720]=s;return}function p1(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;f=m+6|0;c[348392]=f;if((f|0)>=(n|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}n=j5((e[520834]|0)+l|0,65535)|0;l=(n&65535)>>>8&255;a[1044496]=l;b[520833]=n;a[1106728]=n<<16>>16!=0|0;a[1106720]=l;return}function p2(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=e[520834]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;if((j|0)<(c[348406]|0)){l=h}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));l=b[520836]|0}b[520836]=l+2&65535;l=f-(k&65535)|0;a[1106736]=l>>>31&255^1;a[1106728]=(l&65535|0)!=0|0;a[1106720]=l>>>8&255;return}function p3(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b[520836]|0;f=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=f;g=(c[348392]|0)+(c[348399]|0)|0;c[348392]=g;h=c[348406]|0;if((g|0)<(h|0)){i=d;j=g;k=h}else{do{j1();l=c[348392]|0;m=c[348406]|0;}while((l|0)>=(m|0));i=b[520836]|0;j=l;k=m}b[520836]=i+1&65535;i=b[520831]|0;m=i+(f&255)&65535;do{if((i&255)<<24>>24!=0){f=j+6|0;c[348392]=f;if((f|0)<(k|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);k=j5(m&65535,65535)|0;a[1044496]=(k&65535)>>>8&255;m=(e[520834]|0)-(k&65535)|0;a[1106736]=m>>>31&255^1;a[1106728]=(m&65535|0)!=0|0;a[1106720]=m>>>8&255;return}function p4(){var d=0;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}d=(b[520834]|0)+1&65535;b[520834]=d;a[1106728]=d<<16>>16!=0|0;a[1106720]=(d&65535)>>>8&255;return}function p5(){var d=0;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}d=(b[520833]|0)-1&65535;b[520833]=d;a[1106728]=d<<16>>16!=0|0;a[1106720]=(d&65535)>>>8&255;return}function p6(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;if((j|0)<(c[348406]|0)){l=h}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));l=b[520836]|0}b[520836]=l+2&65535;l=j5(k&65535|f,16777215)|0;a[1044496]=(l&65535)>>>8&255;f=(e[520834]|0)-(l&65535)|0;a[1106736]=f>>>31&255^1;a[1106728]=(f&65535|0)!=0|0;a[1106720]=f>>>8&255;return}function p7(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=b[520836]|0;g=a[(c[348396]|0)+(f&65535)|0]|0;a[1044496]=g;h=(c[348392]|0)+(c[348399]|0)|0;c[348392]=h;i=c[348406]|0;if((h|0)<(i|0)){j=f;k=h;l=i}else{do{j1();m=c[348392]|0;n=c[348406]|0;}while((m|0)>=(n|0));j=b[520836]|0;k=m;l=n}b[520836]=j+1&65535;j=b[520831]|0;n=j+(g&255)&65535;do{if((j&255)<<24>>24!=0){g=k+6|0;c[348392]=g;if((g|0)<(l|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);l=j5(n&65535,16777215)|0;a[1044496]=(l&65535)>>>8&255;n=c[276674]|l&65535;l=(c[348392]|0)+6|0;c[348392]=l;if((l|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}l=j0((e[520834]|0)+n|0)|0;a[1044496]=l;n=(d[1041660]|0)-(l&255)&65535;a[1106736]=(n&65535)>>>15&255^1;l=n&255;a[1106728]=l;a[1106720]=l;return}function p8(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;f=m+6|0;c[348392]=f;if((f|0)>=(n|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}n=j0((e[520834]|0)+l|0)|0;a[1044496]=n;l=(d[1041660]|0)-(n&255)&65535;a[1106736]=(l&65535)>>>15&255^1;n=l&255;a[1106728]=n;a[1106720]=n;return}function p9(){var d=0;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}j3(b[520833]|0,(e[520832]|0)-1|0,65535);b[520832]=(b[520832]|0)-2&65535;a[1044496]=a[1041666]|0;return}function qa(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;f=m+6|0;c[348392]=f;if((f|0)>=(n|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}n=j0((e[520833]|0)+l|0)|0;a[1044496]=n;l=(d[1041660]|0)-(n&255)&65535;a[1106736]=(l&65535)>>>15&255^1;n=l&255;a[1106728]=n;a[1106720]=n;return}function qb(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;f=m+6|0;c[348392]=f;if((f|0)>=(n|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}n=(e[520833]|0)+l|0;l=(j0(n)|0)-1&255;f=(c[348392]|0)+6|0;c[348392]=f;if((f|0)<(c[348406]|0)){j2(l,n);a[1044496]=l;a[1106728]=l;a[1106720]=l;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));j2(l,n);a[1044496]=l;a[1106728]=l;a[1106720]=l;return}function qc(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=e[520833]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;if((j|0)<(c[348406]|0)){l=h}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));l=b[520836]|0}b[520836]=l+2&65535;l=f-(k&65535)|0;a[1106736]=l>>>31&255^1;a[1106728]=(l&65535|0)!=0|0;a[1106720]=l>>>8&255;return}function qd(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b[520836]|0;f=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=f;g=(c[348392]|0)+(c[348399]|0)|0;c[348392]=g;h=c[348406]|0;if((g|0)<(h|0)){i=d;j=g;k=h}else{do{j1();l=c[348392]|0;m=c[348406]|0;}while((l|0)>=(m|0));i=b[520836]|0;j=l;k=m}b[520836]=i+1&65535;i=b[520831]|0;m=i+(f&255)&65535;do{if((i&255)<<24>>24!=0){f=j+6|0;c[348392]=f;if((f|0)<(k|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);k=j5(m&65535,65535)|0;a[1044496]=(k&65535)>>>8&255;m=(e[520833]|0)-(k&65535)|0;a[1106736]=m>>>31&255^1;a[1106728]=(m&65535|0)!=0|0;a[1106720]=m>>>8&255;return}function qe(){var d=0;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}d=(b[520833]|0)+1&65535;b[520833]=d;a[1106728]=d<<16>>16!=0|0;a[1106720]=(d&65535)>>>8&255;return}function qf(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;if((j|0)<(c[348406]|0)){l=h}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));l=b[520836]|0}b[520836]=l+2&65535;l=j5(k&65535|f,16777215)|0;a[1044496]=(l&65535)>>>8&255;f=(e[520833]|0)-(l&65535)|0;a[1106736]=f>>>31&255^1;a[1106728]=(f&65535|0)!=0|0;a[1106720]=f>>>8&255;return}function qg(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=b[520836]|0;g=a[(c[348396]|0)+(f&65535)|0]|0;a[1044496]=g;h=(c[348392]|0)+(c[348399]|0)|0;c[348392]=h;i=c[348406]|0;if((h|0)<(i|0)){j=f;k=h;l=i}else{do{j1();m=c[348392]|0;n=c[348406]|0;}while((m|0)>=(n|0));j=b[520836]|0;k=m;l=n}b[520836]=j+1&65535;j=b[520831]|0;n=j+(g&255)&65535;do{if((j&255)<<24>>24!=0){g=k+6|0;c[348392]=g;if((g|0)<(l|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);l=j5(n&65535,16777215)|0;a[1044496]=(l&65535)>>>8&255;n=c[276674]|l&65535;l=(c[348392]|0)+6|0;c[348392]=l;if((l|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}l=j0((e[520834]|0)+n|0)|0;a[1044496]=l;if((a[1041658]&8)==0){n=a[1041660]|0;k=((n&255)+~(l&255)&65535)+(d[1106736]|0)&65535;a[1106736]=(k&65535)>>>15&255^1;j=k&255;o=j;p=(j^n)&(n^l);q=(p&255)>>>7;a[1106712]=q;a[1041660]=o;a[1106728]=o;a[1106720]=o;return}n=b[520830]|0;j=n&255;k=((j&15)-(l&15)&255)-((a[1106736]|0)==0)&255;g=(n&240)-(l&-16&255)&65535;if((k&255)>15){r=k+10&15;s=g-16&65535}else{r=k;s=g}if((s&65535)>240){a[1106736]=0;t=s+160&255&-16}else{a[1106736]=1;t=s&255}s=t|r;o=s;p=(s^j)&(j^l);q=(p&255)>>>7;a[1106712]=q;a[1041660]=o;a[1106728]=o;a[1106720]=o;return}function qh(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|d[g+i|0];a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;f=m+6|0;c[348392]=f;if((f|0)>=(n|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}n=j0((e[520834]|0)+l|0)|0;a[1044496]=n;if((a[1041658]&8)==0){l=a[1041660]|0;f=((l&255)+~(n&255)&65535)+(d[1106736]|0)&65535;a[1106736]=(f&65535)>>>15&255^1;m=f&255;q=m;r=(m^l)&(l^n);s=(r&255)>>>7;a[1106712]=s;a[1041660]=q;a[1106728]=q;a[1106720]=q;return}l=b[520830]|0;m=l&255;f=((m&15)-(n&15)&255)-((a[1106736]|0)==0)&255;k=(l&240)-(n&-16&255)&65535;if((f&255)>15){t=f+10&15;u=k-16&65535}else{t=f;u=k}if((u&65535)>240){a[1106736]=0;v=u+160&255&-16}else{a[1106736]=1;v=u&255}u=v|t;q=u;r=(u^m)&(m^n);s=(r&255)>>>7;a[1106712]=s;a[1041660]=q;a[1106728]=q;a[1106720]=q;return}function qi(){var d=0,f=0;d=(c[348392]|0)+12|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}d=j5((e[520832]|0)+1|0,65535)|0;b[520833]=d;b[520832]=(b[520832]|0)+2&65535;a[1106728]=d<<16>>16!=0|0;f=(d&65535)>>>8&255;a[1106720]=f;a[1044496]=f;return}function qj(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|d[g+i|0];a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;f=m+6|0;c[348392]=f;if((f|0)>=(n|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}n=j0((e[520833]|0)+l|0)|0;a[1044496]=n;if((a[1041658]&8)==0){l=a[1041660]|0;f=((l&255)+~(n&255)&65535)+(d[1106736]|0)&65535;a[1106736]=(f&65535)>>>15&255^1;m=f&255;q=m;r=(m^l)&(l^n);s=(r&255)>>>7;a[1106712]=s;a[1041660]=q;a[1106728]=q;a[1106720]=q;return}l=b[520830]|0;m=l&255;f=((m&15)-(n&15)&255)-((a[1106736]|0)==0)&255;k=(l&240)-(n&-16&255)&65535;if((f&255)>15){t=f+10&15;u=k-16&65535}else{t=f;u=k}if((u&65535)>240){a[1106736]=0;v=u+160&255&-16}else{a[1106736]=1;v=u&255}u=v|t;q=u;r=(u^m)&(m^n);s=(r&255)>>>7;a[1106712]=s;a[1041660]=q;a[1106728]=q;a[1106720]=q;return}function qk(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;f=m+6|0;c[348392]=f;if((f|0)>=(n|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}n=(e[520833]|0)+l|0;l=(j0(n)|0)+1&255;f=(c[348392]|0)+6|0;c[348392]=f;if((f|0)<(c[348406]|0)){j2(l,n);a[1044496]=l;a[1106728]=l;a[1106720]=l;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));j2(l,n);a[1044496]=l;a[1106728]=l;a[1106720]=l;return}function ql(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=b[520836]|0;f=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=f;g=(c[348392]|0)+(c[348399]|0)|0;c[348392]=g;h=c[348406]|0;if((g|0)<(h|0)){i=d;j=g;k=h}else{do{j1();l=c[348392]|0;m=c[348406]|0;}while((l|0)>=(m|0));i=b[520836]|0;j=l;k=m}b[520836]=i+1&65535;i=b[520831]|0;m=i+(f&255)&65535;do{if((i&255)<<24>>24==0){n=j;o=k}else{f=j+6|0;c[348392]=f;if((f|0)<(k|0)){n=f;o=k;break}while(1){j1();f=c[348392]|0;l=c[348406]|0;if((f|0)<(l|0)){n=f;o=l;break}}}}while(0);k=(e[520833]|0)+(m&65535)|0;m=n+6|0;c[348392]=m;if((m|0)>=(o|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}o=j5(k&65535,16777215)|0;a[1044496]=(o&65535)>>>8&255;k=j5(c[276674]|o&65535,16777215)|0;a[1044496]=(k&65535)>>>8&255;o=b[520830]|k;b[520830]=o;a[1106728]=o<<16>>16!=0|0;a[1106720]=(o&65535)>>>8&255;return}function qm(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}b[520836]=h+1&65535;h=(b[520832]|0)+(e&255)&65535;e=i+6|0;c[348392]=e;if((e|0)>=(j|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}j=j5(h&65535,16777215)|0;a[1044496]=(j&65535)>>>8&255;h=b[520830]|j;b[520830]=h;a[1106728]=h<<16>>16!=0|0;a[1106720]=(h&65535)>>>8&255;return}function qn(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}b[520836]=h+1&65535;h=b[520831]|0;l=h+(e&255)&65535;do{if((h&255)<<24>>24!=0){e=i+6|0;c[348392]=e;if((e|0)<(j|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j=l&65535;l=j5(j,65535)|0;i=b[520830]|0;a[1106728]=(i&l)<<16>>16!=0|0;h=i|l;l=(c[348392]|0)+6|0;c[348392]=l;if((l|0)<(c[348406]|0)){j3(h,j,65535);m=h&255;a[1044496]=m;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));j3(h,j,65535);m=h&255;a[1044496]=m;return}function qo(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}b[520836]=h+1&65535;h=b[520831]|0;l=h+(e&255)&65535;do{if((h&255)<<24>>24!=0){e=i+6|0;c[348392]=e;if((e|0)<(j|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j=j5(l&65535,65535)|0;a[1044496]=(j&65535)>>>8&255;l=b[520830]|j;b[520830]=l;a[1106728]=l<<16>>16!=0|0;a[1106720]=(l&65535)>>>8&255;return}function qp(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}b[520836]=h+1&65535;h=b[520831]|0;l=h+(e&255)&65535;do{if((h&255)<<24>>24!=0){e=i+6|0;c[348392]=e;if((e|0)<(j|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j=l&65535;l=j5(j,65535)|0;a[1106736]=(l&65535)>>>15&255;i=l<<1;h=(c[348392]|0)+6|0;c[348392]=h;if((h|0)<(c[348406]|0)){j3(i,j,65535);m=i&255;a[1044496]=m;n=i<<16>>16!=0;o=n&1;a[1106728]=o;p=(l&65535)>>>7;q=p&255;a[1106720]=q;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));j3(i,j,65535);m=i&255;a[1044496]=m;n=i<<16>>16!=0;o=n&1;a[1106728]=o;p=(l&65535)>>>7;q=p&255;a[1106720]=q;return}function qq(){var c=0,d=0;c=j5(xb()|0,16777215)|0;a[1044496]=(c&65535)>>>8&255;d=b[520830]|c;b[520830]=d;a[1106728]=d<<16>>16!=0|0;a[1106720]=(d&65535)>>>8&255;return}function qr(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[348396]|0;f=b[520836]|0;g=f&65535;h=a[e+(g+1)|0]|0;i=(h&255)<<8|(d[e+g|0]|0);a[1044496]=h;h=(c[348392]|0)+(c[348400]|0)|0;c[348392]=h;if((h|0)<(c[348406]|0)){j=f}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));j=b[520836]|0}b[520836]=j+2&65535;j=i|b[520830];b[520830]=j;a[1106728]=j<<16>>16!=0|0;a[1106720]=(j&65535)>>>8&255;return}function qs(){var e=0,f=0;e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}a[1106736]=(d[1041661|0]|0)>>>7;e=b[520830]|0;f=e<<1;b[520830]=f;a[1106728]=f<<16>>16!=0|0;a[1106720]=(e&65535)>>>7&255;return}function qt(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=c[276674]|0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[1044496]=i;i=(c[348392]|0)+(c[348400]|0)|0;c[348392]=i;if((i|0)<(c[348406]|0)){k=g}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));k=b[520836]|0}b[520836]=k+2&65535;k=j&65535|e;e=j5(k,65535)|0;j=b[520830]|0;a[1106728]=(j&e)<<16>>16!=0|0;g=j|e;e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)<(c[348406]|0)){j3(g,k,65535);l=g&255;a[1044496]=l;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));j3(g,k,65535);l=g&255;a[1044496]=l;return}function qu(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=c[276674]|0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[1044496]=i;i=(c[348392]|0)+(c[348400]|0)|0;c[348392]=i;if((i|0)<(c[348406]|0)){k=g}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));k=b[520836]|0}b[520836]=k+2&65535;k=j5(j&65535|e,16777215)|0;a[1044496]=(k&65535)>>>8&255;e=b[520830]|k;b[520830]=e;a[1106728]=e<<16>>16!=0|0;a[1106720]=(e&65535)>>>8&255;return}function qv(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=c[276674]|0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[1044496]=i;i=(c[348392]|0)+(c[348400]|0)|0;c[348392]=i;if((i|0)<(c[348406]|0)){k=g}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));k=b[520836]|0}b[520836]=k+2&65535;k=j&65535|e;e=j5(k,16777215)|0;a[1106736]=(e&65535)>>>15&255;j=e<<1;g=(c[348392]|0)+6|0;c[348392]=g;if((g|0)<(c[348406]|0)){j3(j,k,16777215);l=j&255;a[1044496]=l;m=j<<16>>16!=0;n=m&1;a[1106728]=n;o=(e&65535)>>>7;p=o&255;a[1106720]=p;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));j3(j,k,16777215);l=j&255;a[1044496]=l;m=j<<16>>16!=0;n=m&1;a[1106728]=n;o=(e&65535)>>>7;p=o&255;a[1106720]=p;return}function qw(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[348396]|0;f=b[520836]|0;g=f&65535;h=a[e+(g+2)|0]|0;i=(d[e+(g+1)|0]|0)<<8|(d[e+g|0]|0)|(h&255)<<16;g=(c[348399]|0)+(c[348400]|0)+(c[348392]|0)|0;c[348392]=g;if((g|0)<(c[348406]|0)){j=f}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));j=b[520836]|0}a[1044496]=h;b[520836]=j+3&65535;j=j5(i,16777215)|0;a[1044496]=(j&65535)>>>8&255;i=b[520830]|j;b[520830]=i;a[1106728]=i<<16>>16!=0|0;a[1106720]=(i&65535)>>>8&255;return}function qx(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b[520836]|0;f=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=f;g=(c[348392]|0)+(c[348399]|0)|0;c[348392]=g;h=c[348406]|0;if((g|0)<(h|0)){i=d;j=g;k=h}else{do{j1();l=c[348392]|0;m=c[348406]|0;}while((l|0)>=(m|0));i=b[520836]|0;j=l;k=m}b[520836]=i+1&65535;i=b[520831]|0;m=i+(f&255)&65535;do{if((i&255)<<24>>24!=0){f=j+6|0;c[348392]=f;if((f|0)<(k|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);k=j5(m&65535,16777215)|0;a[1044496]=(k&65535)>>>8&255;m=c[276674]|k&65535;k=(c[348392]|0)+6|0;c[348392]=k;if((k|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}k=j5((e[520834]|0)+m|0,16777215)|0;a[1044496]=(k&65535)>>>8&255;m=b[520830]|k;b[520830]=m;a[1106728]=m<<16>>16!=0|0;a[1106720]=(m&65535)>>>8&255;return}function qy(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}b[520836]=h+1&65535;h=b[520831]|0;l=h+(e&255)&65535;do{if((h&255)<<24>>24!=0){e=i+6|0;c[348392]=e;if((e|0)<(j|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j=j5(l&65535,16777215)|0;a[1044496]=(j&65535)>>>8&255;l=j5(c[276674]|j&65535,16777215)|0;a[1044496]=(l&65535)>>>8&255;j=b[520830]|l;b[520830]=j;a[1106728]=j<<16>>16!=0|0;a[1106720]=(j&65535)>>>8&255;return}function qz(){var d=0,f=0;d=j0(c[260418]|0)|0;a[1044496]=d;b[520836]=(b[520836]|0)+1&65535;f=(b[520832]|0)+(d&255)&65535;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}d=j5(f&65535,16777215)|0;a[1044496]=(d&65535)>>>8&255;f=(e[520834]|0)+(d&65535)+(c[276674]|0)&16777215;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}d=j5(f,16777215)|0;a[1044496]=(d&65535)>>>8&255;f=b[520830]|d;b[520830]=f;a[1106728]=f<<16>>16!=0|0;a[1106720]=(f&65535)>>>8&255;return}function qA(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}b[520836]=h+1&65535;h=b[520831]|0;l=h+(e&255)&65535;do{if((h&255)<<24>>24!=0){e=i+6|0;c[348392]=e;if((e|0)<(j|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j=l&65535;l=j5(j,65535)|0;i=b[520830]|0;a[1106728]=(i&l)<<16>>16!=0|0;h=l&~i;i=(c[348392]|0)+6|0;c[348392]=i;if((i|0)<(c[348406]|0)){j3(h,j,65535);m=h&255;a[1044496]=m;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));j3(h,j,65535);m=h&255;a[1044496]=m;return}function qB(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=b[520836]|0;f=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=f;g=(c[348392]|0)+(c[348399]|0)|0;c[348392]=g;h=c[348406]|0;if((g|0)<(h|0)){i=d;j=g;k=h}else{do{j1();l=c[348392]|0;m=c[348406]|0;}while((l|0)>=(m|0));i=b[520836]|0;j=l;k=m}b[520836]=i+1&65535;i=b[520831]|0;m=i+(f&255)&65535;do{if((i&255)<<24>>24==0){n=j;o=k}else{f=j+6|0;c[348392]=f;if((f|0)<(k|0)){n=f;o=k;break}while(1){j1();f=c[348392]|0;l=c[348406]|0;if((f|0)<(l|0)){n=f;o=l;break}}}}while(0);k=(e[520833]|0)+(m&65535)|0;m=n+6|0;c[348392]=m;if((m|0)>=(o|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}o=j5(k&65535,65535)|0;a[1044496]=(o&65535)>>>8&255;k=b[520830]|o;b[520830]=k;a[1106728]=k<<16>>16!=0|0;a[1106720]=(k&65535)>>>8&255;return}function qC(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=b[520836]|0;f=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=f;g=(c[348392]|0)+(c[348399]|0)|0;c[348392]=g;h=c[348406]|0;if((g|0)<(h|0)){i=d;j=g;k=h}else{do{j1();l=c[348392]|0;m=c[348406]|0;}while((l|0)>=(m|0));i=b[520836]|0;j=l;k=m}b[520836]=i+1&65535;i=b[520831]|0;m=i+(f&255)&65535;do{if((i&255)<<24>>24==0){n=j;o=k}else{f=j+6|0;c[348392]=f;if((f|0)<(k|0)){n=f;o=k;break}while(1){j1();f=c[348392]|0;l=c[348406]|0;if((f|0)<(l|0)){n=f;o=l;break}}}}while(0);k=(e[520833]|0)+(m&65535)|0;m=n+6|0;c[348392]=m;if((m|0)>=(o|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}o=k&65535;k=j5(o,65535)|0;a[1106736]=(k&65535)>>>15&255;m=k<<1;n=(c[348392]|0)+6|0;c[348392]=n;if((n|0)<(c[348406]|0)){j3(m,o,65535);p=m&255;a[1044496]=p;q=m<<16>>16!=0;r=q&1;a[1106728]=r;s=(k&65535)>>>7;t=s&255;a[1106720]=t;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));j3(m,o,65535);p=m&255;a[1044496]=p;q=m<<16>>16!=0;r=q&1;a[1106728]=r;s=(k&65535)>>>7;t=s&255;a[1106720]=t;return}function qD(){var c=0,d=0;c=xb()|0;d=j5((e[520834]|0)+c|0,16777215)|0;a[1044496]=(d&65535)>>>8&255;c=b[520830]|d;b[520830]=c;a[1106728]=c<<16>>16!=0|0;a[1106720]=(c&65535)>>>8&255;return}function qE(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;f=m+6|0;c[348392]=f;if((f|0)>=(n|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}n=j5((e[520834]|0)+l|0,16777215)|0;a[1044496]=(n&65535)>>>8&255;l=b[520830]|n;b[520830]=l;a[1106728]=l<<16>>16!=0|0;a[1106720]=(l&65535)>>>8&255;return}function qF(){var d=0;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}d=(b[520830]|0)+1&65535;b[520830]=d;a[1106728]=d<<16>>16!=0|0;a[1106720]=(d&65535)>>>8&255;return}function qG(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=c[276674]|0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[1044496]=i;i=(c[348392]|0)+(c[348400]|0)|0;c[348392]=i;if((i|0)<(c[348406]|0)){k=g}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));k=b[520836]|0}b[520836]=k+2&65535;k=j&65535|e;e=j5(k,65535)|0;j=b[520830]|0;a[1106728]=(j&e)<<16>>16!=0|0;g=e&~j;j=(c[348392]|0)+6|0;c[348392]=j;if((j|0)<(c[348406]|0)){j3(g,k,65535);l=g&255;a[1044496]=l;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));j3(g,k,65535);l=g&255;a[1044496]=l;return}function qH(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;f=m+6|0;c[348392]=f;if((f|0)>=(n|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}n=j5((e[520833]|0)+l|0,16777215)|0;a[1044496]=(n&65535)>>>8&255;l=b[520830]|n;b[520830]=l;a[1106728]=l<<16>>16!=0|0;a[1106720]=(l&65535)>>>8&255;return}function qI(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;f=m+6|0;c[348392]=f;if((f|0)>=(n|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}n=(e[520833]|0)+l|0;l=j5(n,16777215)|0;a[1106736]=(l&65535)>>>15&255;f=l<<1;m=(c[348392]|0)+6|0;c[348392]=m;if((m|0)<(c[348406]|0)){j3(f,n,16777215);q=f&255;a[1044496]=q;r=f<<16>>16!=0;s=r&1;a[1106728]=s;t=(l&65535)>>>7;u=t&255;a[1106720]=u;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));j3(f,n,16777215);q=f&255;a[1044496]=q;r=f<<16>>16!=0;s=r&1;a[1106728]=s;t=(l&65535)>>>7;u=t&255;a[1106720]=u;return}function qJ(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=a[f+(h+2)|0]|0;j=(d[f+(h+1)|0]|0)<<8|(d[f+h|0]|0)|(i&255)<<16;h=(c[348399]|0)+(c[348400]|0)+(c[348392]|0)|0;c[348392]=h;if((h|0)<(c[348406]|0)){k=g}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));k=b[520836]|0}a[1044496]=i;b[520836]=k+3&65535;k=j5((e[520833]|0)+j|0,16777215)|0;a[1044496]=(k&65535)>>>8&255;j=b[520830]|k;b[520830]=j;a[1106728]=j<<16>>16!=0|0;a[1106720]=(j&65535)>>>8&255;return}function qK(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=b[520836]|0;f=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=f;g=(c[348392]|0)+(c[348399]|0)|0;c[348392]=g;h=c[348406]|0;if((g|0)<(h|0)){i=d;j=g;k=h}else{do{j1();l=c[348392]|0;m=c[348406]|0;}while((l|0)>=(m|0));i=b[520836]|0;j=l;k=m}b[520836]=i+1&65535;i=b[520831]|0;m=i+(f&255)&65535;do{if((i&255)<<24>>24==0){n=j;o=k}else{f=j+6|0;c[348392]=f;if((f|0)<(k|0)){n=f;o=k;break}while(1){j1();f=c[348392]|0;l=c[348406]|0;if((f|0)<(l|0)){n=f;o=l;break}}}}while(0);k=(e[520833]|0)+(m&65535)|0;m=n+6|0;c[348392]=m;if((m|0)>=(o|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}o=j5(k&65535,16777215)|0;a[1044496]=(o&65535)>>>8&255;k=j5(c[276674]|o&65535,16777215)|0;a[1044496]=(k&65535)>>>8&255;o=b[520830]&k;b[520830]=o;a[1106728]=o<<16>>16!=0|0;a[1106720]=(o&65535)>>>8&255;return}function qL(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}b[520836]=h+1&65535;h=(b[520832]|0)+(e&255)&65535;e=i+6|0;c[348392]=e;if((e|0)>=(j|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}j=j5(h&65535,16777215)|0;a[1044496]=(j&65535)>>>8&255;h=b[520830]&j;b[520830]=h;a[1106728]=h<<16>>16!=0|0;a[1106720]=(h&65535)>>>8&255;return}function qM(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}b[520836]=h+1&65535;h=b[520831]|0;l=h+(e&255)&65535;do{if((h&255)<<24>>24!=0){e=i+6|0;c[348392]=e;if((e|0)<(j|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j=j5(l&65535,65535)|0;l=(j&65535)>>>8&255;a[1044496]=l;a[1106712]=(j&65535)>>>14&1;a[1106720]=l;a[1106728]=(b[520830]&j)<<16>>16!=0|0;return}function qN(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}b[520836]=h+1&65535;h=b[520831]|0;l=h+(e&255)&65535;do{if((h&255)<<24>>24!=0){e=i+6|0;c[348392]=e;if((e|0)<(j|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j=j5(l&65535,65535)|0;a[1044496]=(j&65535)>>>8&255;l=b[520830]&j;b[520830]=l;a[1106728]=l<<16>>16!=0|0;a[1106720]=(l&65535)>>>8&255;return}function qO(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=b[520836]|0;f=a[(c[348396]|0)+(e&65535)|0]|0;a[1044496]=f;g=(c[348392]|0)+(c[348399]|0)|0;c[348392]=g;h=c[348406]|0;if((g|0)<(h|0)){i=e;j=g;k=h}else{do{j1();l=c[348392]|0;m=c[348406]|0;}while((l|0)>=(m|0));i=b[520836]|0;j=l;k=m}b[520836]=i+1&65535;i=b[520831]|0;m=i+(f&255)&65535;do{if((i&255)<<24>>24!=0){f=j+6|0;c[348392]=f;if((f|0)<(k|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);k=m&65535;m=j5(k,65535)|0;j=(m&65535)<<1|(d[1106736]|0);a[1106736]=j>>>0>65535|0;i=(c[348392]|0)+6|0;c[348392]=i;if((i|0)<(c[348406]|0)){n=j&65535;j3(n,k,65535);o=j&255;a[1044496]=o;p=j&65535;q=(p|0)!=0;r=q&1;a[1106728]=r;s=(m&65535)>>>7;t=s&255;a[1106720]=t;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));n=j&65535;j3(n,k,65535);o=j&255;a[1044496]=o;p=j&65535;q=(p|0)!=0;r=q&1;a[1106728]=r;s=(m&65535)>>>7;t=s&255;a[1106720]=t;return}function qP(){var c=0,d=0;c=j5(xb()|0,16777215)|0;a[1044496]=(c&65535)>>>8&255;d=b[520830]&c;b[520830]=d;a[1106728]=d<<16>>16!=0|0;a[1106720]=(d&65535)>>>8&255;return}function qQ(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[348396]|0;f=b[520836]|0;g=f&65535;h=a[e+(g+1)|0]|0;i=(h&255)<<8|(d[e+g|0]|0);a[1044496]=h;h=(c[348392]|0)+(c[348400]|0)|0;c[348392]=h;if((h|0)<(c[348406]|0)){j=f}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));j=b[520836]|0}b[520836]=j+2&65535;j=b[520830]&i;b[520830]=j;a[1106728]=j<<16>>16!=0|0;a[1106720]=(j&65535)>>>8&255;return}function qR(){var f=0,g=0;f=(c[348392]|0)+6|0;c[348392]=f;if((f|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}f=(e[520830]|0)<<1|(d[1106736]|0);a[1106736]=f>>>0>65535|0;g=f&65535;b[520830]=g;a[1106728]=(f&65535|0)!=0|0;a[1106720]=(g&65535)>>>8&255;return}function qS(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=c[276674]|0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[1044496]=i;i=(c[348392]|0)+(c[348400]|0)|0;c[348392]=i;if((i|0)<(c[348406]|0)){k=g}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));k=b[520836]|0}b[520836]=k+2&65535;k=j5(j&65535|e,16777215)|0;e=(k&65535)>>>8&255;a[1044496]=e;a[1106712]=(k&65535)>>>14&1;a[1106720]=e;a[1106728]=(b[520830]&k)<<16>>16!=0|0;return}function qT(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=c[276674]|0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[1044496]=i;i=(c[348392]|0)+(c[348400]|0)|0;c[348392]=i;if((i|0)<(c[348406]|0)){k=g}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));k=b[520836]|0}b[520836]=k+2&65535;k=j5(j&65535|e,16777215)|0;a[1044496]=(k&65535)>>>8&255;e=b[520830]&k;b[520830]=e;a[1106728]=e<<16>>16!=0|0;a[1106720]=(e&65535)>>>8&255;return}function qU(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=c[276674]|0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[1044496]=i;i=(c[348392]|0)+(c[348400]|0)|0;c[348392]=i;if((i|0)<(c[348406]|0)){k=g}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));k=b[520836]|0}b[520836]=k+2&65535;k=j&65535|e;e=j5(k,16777215)|0;j=(e&65535)<<1|(d[1106736]|0);a[1106736]=j>>>0>65535|0;g=(c[348392]|0)+6|0;c[348392]=g;if((g|0)<(c[348406]|0)){l=j&65535;j3(l,k,16777215);m=j&255;a[1044496]=m;n=j&65535;o=(n|0)!=0;p=o&1;a[1106728]=p;q=(e&65535)>>>7;r=q&255;a[1106720]=r;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));l=j&65535;j3(l,k,16777215);m=j&255;a[1044496]=m;n=j&65535;o=(n|0)!=0;p=o&1;a[1106728]=p;q=(e&65535)>>>7;r=q&255;a[1106720]=r;return}function qV(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[348396]|0;f=b[520836]|0;g=f&65535;h=a[e+(g+2)|0]|0;i=(d[e+(g+1)|0]|0)<<8|(d[e+g|0]|0)|(h&255)<<16;g=(c[348399]|0)+(c[348400]|0)+(c[348392]|0)|0;c[348392]=g;if((g|0)<(c[348406]|0)){j=f}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));j=b[520836]|0}a[1044496]=h;b[520836]=j+3&65535;j=j5(i,16777215)|0;a[1044496]=(j&65535)>>>8&255;i=b[520830]&j;b[520830]=i;a[1106728]=i<<16>>16!=0|0;a[1106720]=(i&65535)>>>8&255;return}function qW(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b[520836]|0;f=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=f;g=(c[348392]|0)+(c[348399]|0)|0;c[348392]=g;h=c[348406]|0;if((g|0)<(h|0)){i=d;j=g;k=h}else{do{j1();l=c[348392]|0;m=c[348406]|0;}while((l|0)>=(m|0));i=b[520836]|0;j=l;k=m}b[520836]=i+1&65535;i=b[520831]|0;m=i+(f&255)&65535;do{if((i&255)<<24>>24!=0){f=j+6|0;c[348392]=f;if((f|0)<(k|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);k=j5(m&65535,16777215)|0;a[1044496]=(k&65535)>>>8&255;m=c[276674]|k&65535;k=(c[348392]|0)+6|0;c[348392]=k;if((k|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}k=j5((e[520834]|0)+m|0,16777215)|0;a[1044496]=(k&65535)>>>8&255;m=b[520830]&k;b[520830]=m;a[1106728]=m<<16>>16!=0|0;a[1106720]=(m&65535)>>>8&255;return}function qX(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}b[520836]=h+1&65535;h=b[520831]|0;l=h+(e&255)&65535;do{if((h&255)<<24>>24!=0){e=i+6|0;c[348392]=e;if((e|0)<(j|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j=j5(l&65535,16777215)|0;a[1044496]=(j&65535)>>>8&255;l=j5(c[276674]|j&65535,16777215)|0;a[1044496]=(l&65535)>>>8&255;j=b[520830]&l;b[520830]=j;a[1106728]=j<<16>>16!=0|0;a[1106720]=(j&65535)>>>8&255;return}function qY(){var d=0,f=0;d=j0(c[260418]|0)|0;a[1044496]=d;b[520836]=(b[520836]|0)+1&65535;f=(b[520832]|0)+(d&255)&65535;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}d=j5(f&65535,16777215)|0;a[1044496]=(d&65535)>>>8&255;f=(e[520834]|0)+(d&65535)+(c[276674]|0)&16777215;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}d=j5(f,16777215)|0;a[1044496]=(d&65535)>>>8&255;f=b[520830]&d;b[520830]=f;a[1106728]=f<<16>>16!=0|0;a[1106720]=(f&65535)>>>8&255;return}function qZ(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=b[520836]|0;f=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=f;g=(c[348392]|0)+(c[348399]|0)|0;c[348392]=g;h=c[348406]|0;if((g|0)<(h|0)){i=d;j=g;k=h}else{do{j1();l=c[348392]|0;m=c[348406]|0;}while((l|0)>=(m|0));i=b[520836]|0;j=l;k=m}b[520836]=i+1&65535;i=b[520831]|0;m=i+(f&255)&65535;do{if((i&255)<<24>>24==0){n=j;o=k}else{f=j+6|0;c[348392]=f;if((f|0)<(k|0)){n=f;o=k;break}while(1){j1();f=c[348392]|0;l=c[348406]|0;if((f|0)<(l|0)){n=f;o=l;break}}}}while(0);k=(e[520833]|0)+(m&65535)|0;m=n+6|0;c[348392]=m;if((m|0)>=(o|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}o=j5(k&65535,65535)|0;k=(o&65535)>>>8&255;a[1044496]=k;a[1106712]=(o&65535)>>>14&1;a[1106720]=k;a[1106728]=(b[520830]&o)<<16>>16!=0|0;return}function q_(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=b[520836]|0;f=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=f;g=(c[348392]|0)+(c[348399]|0)|0;c[348392]=g;h=c[348406]|0;if((g|0)<(h|0)){i=d;j=g;k=h}else{do{j1();l=c[348392]|0;m=c[348406]|0;}while((l|0)>=(m|0));i=b[520836]|0;j=l;k=m}b[520836]=i+1&65535;i=b[520831]|0;m=i+(f&255)&65535;do{if((i&255)<<24>>24==0){n=j;o=k}else{f=j+6|0;c[348392]=f;if((f|0)<(k|0)){n=f;o=k;break}while(1){j1();f=c[348392]|0;l=c[348406]|0;if((f|0)<(l|0)){n=f;o=l;break}}}}while(0);k=(e[520833]|0)+(m&65535)|0;m=n+6|0;c[348392]=m;if((m|0)>=(o|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}o=j5(k&65535,65535)|0;a[1044496]=(o&65535)>>>8&255;k=b[520830]&o;b[520830]=k;a[1106728]=k<<16>>16!=0|0;a[1106720]=(k&65535)>>>8&255;return}function q$(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=b[520836]|0;g=a[(c[348396]|0)+(f&65535)|0]|0;a[1044496]=g;h=(c[348392]|0)+(c[348399]|0)|0;c[348392]=h;i=c[348406]|0;if((h|0)<(i|0)){j=f;k=h;l=i}else{do{j1();m=c[348392]|0;n=c[348406]|0;}while((m|0)>=(n|0));j=b[520836]|0;k=m;l=n}b[520836]=j+1&65535;j=b[520831]|0;n=j+(g&255)&65535;do{if((j&255)<<24>>24==0){o=k;p=l}else{g=k+6|0;c[348392]=g;if((g|0)<(l|0)){o=g;p=l;break}while(1){j1();g=c[348392]|0;m=c[348406]|0;if((g|0)<(m|0)){o=g;p=m;break}}}}while(0);l=(e[520833]|0)+(n&65535)|0;n=o+6|0;c[348392]=n;if((n|0)>=(p|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}p=l&65535;l=j5(p,65535)|0;n=(l&65535)<<1|(d[1106736]|0);a[1106736]=n>>>0>65535|0;o=(c[348392]|0)+6|0;c[348392]=o;if((o|0)<(c[348406]|0)){q=n&65535;j3(q,p,65535);r=n&255;a[1044496]=r;s=n&65535;t=(s|0)!=0;u=t&1;a[1106728]=u;v=(l&65535)>>>7;w=v&255;a[1106720]=w;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));q=n&65535;j3(q,p,65535);r=n&255;a[1044496]=r;s=n&65535;t=(s|0)!=0;u=t&1;a[1106728]=u;v=(l&65535)>>>7;w=v&255;a[1106720]=w;return}function q0(){var c=0,d=0;c=xb()|0;d=j5((e[520834]|0)+c|0,16777215)|0;a[1044496]=(d&65535)>>>8&255;c=b[520830]&d;b[520830]=c;a[1106728]=c<<16>>16!=0|0;a[1106720]=(c&65535)>>>8&255;return}function q1(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;f=m+6|0;c[348392]=f;if((f|0)>=(n|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}n=j5((e[520834]|0)+l|0,16777215)|0;a[1044496]=(n&65535)>>>8&255;l=b[520830]&n;b[520830]=l;a[1106728]=l<<16>>16!=0|0;a[1106720]=(l&65535)>>>8&255;return}function q2(){var d=0;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}d=(b[520830]|0)-1&65535;b[520830]=d;a[1106728]=d<<16>>16!=0|0;a[1106720]=(d&65535)>>>8&255;return}function q3(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;f=m+6|0;c[348392]=f;if((f|0)>=(n|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}n=j5((e[520833]|0)+l|0,16777215)|0;l=(n&65535)>>>8&255;a[1044496]=l;a[1106712]=(n&65535)>>>14&1;a[1106720]=l;a[1106728]=(b[520830]&n)<<16>>16!=0|0;return}function q4(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;f=m+6|0;c[348392]=f;if((f|0)>=(n|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}n=j5((e[520833]|0)+l|0,16777215)|0;a[1044496]=(n&65535)>>>8&255;l=b[520830]&n;b[520830]=l;a[1106728]=l<<16>>16!=0|0;a[1106720]=(l&65535)>>>8&255;return}function q5(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;f=m+6|0;c[348392]=f;if((f|0)>=(n|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}n=(e[520833]|0)+l|0;l=j5(n,16777215)|0;f=(l&65535)<<1|(d[1106736]|0);a[1106736]=f>>>0>65535|0;m=(c[348392]|0)+6|0;c[348392]=m;if((m|0)<(c[348406]|0)){q=f&65535;j3(q,n,16777215);r=f&255;a[1044496]=r;s=f&65535;t=(s|0)!=0;u=t&1;a[1106728]=u;v=(l&65535)>>>7;w=v&255;a[1106720]=w;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));q=f&65535;j3(q,n,16777215);r=f&255;a[1044496]=r;s=f&65535;t=(s|0)!=0;u=t&1;a[1106728]=u;v=(l&65535)>>>7;w=v&255;a[1106720]=w;return}function q6(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=a[f+(h+2)|0]|0;j=(d[f+(h+1)|0]|0)<<8|(d[f+h|0]|0)|(i&255)<<16;h=(c[348399]|0)+(c[348400]|0)+(c[348392]|0)|0;c[348392]=h;if((h|0)<(c[348406]|0)){k=g}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));k=b[520836]|0}a[1044496]=i;b[520836]=k+3&65535;k=j5((e[520833]|0)+j|0,16777215)|0;a[1044496]=(k&65535)>>>8&255;j=b[520830]&k;b[520830]=j;a[1106728]=j<<16>>16!=0|0;a[1106720]=(j&65535)>>>8&255;return}function q7(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=b[520836]|0;f=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=f;g=(c[348392]|0)+(c[348399]|0)|0;c[348392]=g;h=c[348406]|0;if((g|0)<(h|0)){i=d;j=g;k=h}else{do{j1();l=c[348392]|0;m=c[348406]|0;}while((l|0)>=(m|0));i=b[520836]|0;j=l;k=m}b[520836]=i+1&65535;i=b[520831]|0;m=i+(f&255)&65535;do{if((i&255)<<24>>24==0){n=j;o=k}else{f=j+6|0;c[348392]=f;if((f|0)<(k|0)){n=f;o=k;break}while(1){j1();f=c[348392]|0;l=c[348406]|0;if((f|0)<(l|0)){n=f;o=l;break}}}}while(0);k=(e[520833]|0)+(m&65535)|0;m=n+6|0;c[348392]=m;if((m|0)>=(o|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}o=j5(k&65535,16777215)|0;a[1044496]=(o&65535)>>>8&255;k=j5(c[276674]|o&65535,16777215)|0;a[1044496]=(k&65535)>>>8&255;o=b[520830]|0;m=o^k;b[520830]=m;a[1106728]=o<<16>>16!=k<<16>>16|0;a[1106720]=(m&65535)>>>8&255;return}function q8(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}b[520836]=h+1&65535;h=(b[520832]|0)+(e&255)&65535;e=i+6|0;c[348392]=e;if((e|0)>=(j|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}j=j5(h&65535,16777215)|0;a[1044496]=(j&65535)>>>8&255;h=b[520830]|0;e=h^j;b[520830]=e;a[1106728]=h<<16>>16!=j<<16>>16|0;a[1106720]=(e&65535)>>>8&255;return}function q9(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}b[520836]=h+1&65535;h=b[520831]|0;l=h+(e&255)&65535;do{if((h&255)<<24>>24!=0){e=i+6|0;c[348392]=e;if((e|0)<(j|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j=j5(l&65535,65535)|0;a[1044496]=(j&65535)>>>8&255;l=b[520830]|0;i=l^j;b[520830]=i;a[1106728]=l<<16>>16!=j<<16>>16|0;a[1106720]=(i&65535)>>>8&255;return}function ra(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}b[520836]=h+1&65535;h=b[520831]|0;l=h+(e&255)&65535;do{if((h&255)<<24>>24!=0){e=i+6|0;c[348392]=e;if((e|0)<(j|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j=l&65535;l=j5(j,65535)|0;a[1106736]=l&1;i=(l&65535)>>>1;h=(c[348392]|0)+6|0;c[348392]=h;if((h|0)<(c[348406]|0)){j3(i,j,65535);m=i&255;a[1044496]=m;n=i<<16>>16!=0;o=n&1;a[1106728]=o;p=(l&65535)>>>9;q=p&255;a[1106720]=q;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));j3(i,j,65535);m=i&255;a[1044496]=m;n=i<<16>>16!=0;o=n&1;a[1106728]=o;p=(l&65535)>>>9;q=p&255;a[1106720]=q;return}function rb(){var c=0,d=0,e=0;c=j5(xb()|0,16777215)|0;a[1044496]=(c&65535)>>>8&255;d=b[520830]|0;e=d^c;b[520830]=e;a[1106728]=d<<16>>16!=c<<16>>16|0;a[1106720]=(e&65535)>>>8&255;return}function rc(){var d=0;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}j3(b[520830]|0,(e[520832]|0)-1|0,65535);b[520832]=(b[520832]|0)-2&65535;a[1044496]=a[1041660]|0;return}function rd(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[348396]|0;f=b[520836]|0;g=f&65535;h=a[e+(g+1)|0]|0;i=(h&255)<<8|(d[e+g|0]|0);a[1044496]=h;h=(c[348392]|0)+(c[348400]|0)|0;c[348392]=h;if((h|0)<(c[348406]|0)){j=f}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));j=b[520836]|0}b[520836]=j+2&65535;j=b[520830]|0;f=j^i;b[520830]=f;a[1106728]=j<<16>>16!=i<<16>>16|0;a[1106720]=(f&65535)>>>8&255;return}function re(){var d=0,e=0;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}d=b[520830]|0;a[1106736]=d&1;e=(d&65535)>>>1;b[520830]=e;a[1106728]=e<<16>>16!=0|0;a[1106720]=(d&65535)>>>9&255;return}function rf(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=c[276674]|0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[1044496]=i;i=(c[348392]|0)+(c[348400]|0)|0;c[348392]=i;if((i|0)<(c[348406]|0)){k=g}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));k=b[520836]|0}b[520836]=k+2&65535;k=j5(j&65535|e,16777215)|0;a[1044496]=(k&65535)>>>8&255;e=b[520830]|0;j=e^k;b[520830]=j;a[1106728]=e<<16>>16!=k<<16>>16|0;a[1106720]=(j&65535)>>>8&255;return}function rg(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=c[276674]|0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[1044496]=i;i=(c[348392]|0)+(c[348400]|0)|0;c[348392]=i;if((i|0)<(c[348406]|0)){k=g}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));k=b[520836]|0}b[520836]=k+2&65535;k=j&65535|e;e=j5(k,16777215)|0;a[1106736]=e&1;j=(e&65535)>>>1;g=(c[348392]|0)+6|0;c[348392]=g;if((g|0)<(c[348406]|0)){j3(j,k,16777215);l=j&255;a[1044496]=l;m=j<<16>>16!=0;n=m&1;a[1106728]=n;o=(e&65535)>>>9;p=o&255;a[1106720]=p;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));j3(j,k,16777215);l=j&255;a[1044496]=l;m=j<<16>>16!=0;n=m&1;a[1106728]=n;o=(e&65535)>>>9;p=o&255;a[1106720]=p;return}function rh(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[348396]|0;f=b[520836]|0;g=f&65535;h=a[e+(g+2)|0]|0;i=(d[e+(g+1)|0]|0)<<8|(d[e+g|0]|0)|(h&255)<<16;g=(c[348399]|0)+(c[348400]|0)+(c[348392]|0)|0;c[348392]=g;if((g|0)<(c[348406]|0)){j=f}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));j=b[520836]|0}a[1044496]=h;b[520836]=j+3&65535;j=j5(i,16777215)|0;a[1044496]=(j&65535)>>>8&255;i=b[520830]|0;h=i^j;b[520830]=h;a[1106728]=i<<16>>16!=j<<16>>16|0;a[1106720]=(h&65535)>>>8&255;return}function ri(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b[520836]|0;f=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=f;g=(c[348392]|0)+(c[348399]|0)|0;c[348392]=g;h=c[348406]|0;if((g|0)<(h|0)){i=d;j=g;k=h}else{do{j1();l=c[348392]|0;m=c[348406]|0;}while((l|0)>=(m|0));i=b[520836]|0;j=l;k=m}b[520836]=i+1&65535;i=b[520831]|0;m=i+(f&255)&65535;do{if((i&255)<<24>>24!=0){f=j+6|0;c[348392]=f;if((f|0)<(k|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);k=j5(m&65535,16777215)|0;a[1044496]=(k&65535)>>>8&255;m=c[276674]|k&65535;k=(c[348392]|0)+6|0;c[348392]=k;if((k|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}k=j5((e[520834]|0)+m|0,16777215)|0;a[1044496]=(k&65535)>>>8&255;m=b[520830]|0;j=m^k;b[520830]=j;a[1106728]=m<<16>>16!=k<<16>>16|0;a[1106720]=(j&65535)>>>8&255;return}function rj(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}b[520836]=h+1&65535;h=b[520831]|0;l=h+(e&255)&65535;do{if((h&255)<<24>>24!=0){e=i+6|0;c[348392]=e;if((e|0)<(j|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j=j5(l&65535,16777215)|0;a[1044496]=(j&65535)>>>8&255;l=j5(c[276674]|j&65535,16777215)|0;a[1044496]=(l&65535)>>>8&255;j=b[520830]|0;i=j^l;b[520830]=i;a[1106728]=j<<16>>16!=l<<16>>16|0;a[1106720]=(i&65535)>>>8&255;return}function rk(){var d=0,f=0,g=0;d=j0(c[260418]|0)|0;a[1044496]=d;b[520836]=(b[520836]|0)+1&65535;f=(b[520832]|0)+(d&255)&65535;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}d=j5(f&65535,16777215)|0;a[1044496]=(d&65535)>>>8&255;f=(e[520834]|0)+(d&65535)+(c[276674]|0)&16777215;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}d=j5(f,16777215)|0;a[1044496]=(d&65535)>>>8&255;f=b[520830]|0;g=f^d;b[520830]=g;a[1106728]=f<<16>>16!=d<<16>>16|0;a[1106720]=(g&65535)>>>8&255;return}function rl(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=b[520836]|0;f=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=f;g=(c[348392]|0)+(c[348399]|0)|0;c[348392]=g;h=c[348406]|0;if((g|0)<(h|0)){i=d;j=g;k=h}else{do{j1();l=c[348392]|0;m=c[348406]|0;}while((l|0)>=(m|0));i=b[520836]|0;j=l;k=m}b[520836]=i+1&65535;i=b[520831]|0;m=i+(f&255)&65535;do{if((i&255)<<24>>24==0){n=j;o=k}else{f=j+6|0;c[348392]=f;if((f|0)<(k|0)){n=f;o=k;break}while(1){j1();f=c[348392]|0;l=c[348406]|0;if((f|0)<(l|0)){n=f;o=l;break}}}}while(0);k=(e[520833]|0)+(m&65535)|0;m=n+6|0;c[348392]=m;if((m|0)>=(o|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}o=j5(k&65535,65535)|0;a[1044496]=(o&65535)>>>8&255;k=b[520830]|0;m=k^o;b[520830]=m;a[1106728]=k<<16>>16!=o<<16>>16|0;a[1106720]=(m&65535)>>>8&255;return}function rm(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=b[520836]|0;f=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=f;g=(c[348392]|0)+(c[348399]|0)|0;c[348392]=g;h=c[348406]|0;if((g|0)<(h|0)){i=d;j=g;k=h}else{do{j1();l=c[348392]|0;m=c[348406]|0;}while((l|0)>=(m|0));i=b[520836]|0;j=l;k=m}b[520836]=i+1&65535;i=b[520831]|0;m=i+(f&255)&65535;do{if((i&255)<<24>>24==0){n=j;o=k}else{f=j+6|0;c[348392]=f;if((f|0)<(k|0)){n=f;o=k;break}while(1){j1();f=c[348392]|0;l=c[348406]|0;if((f|0)<(l|0)){n=f;o=l;break}}}}while(0);k=(e[520833]|0)+(m&65535)|0;m=n+6|0;c[348392]=m;if((m|0)>=(o|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}o=k&65535;k=j5(o,65535)|0;a[1106736]=k&1;m=(k&65535)>>>1;n=(c[348392]|0)+6|0;c[348392]=n;if((n|0)<(c[348406]|0)){j3(m,o,65535);p=m&255;a[1044496]=p;q=m<<16>>16!=0;r=q&1;a[1106728]=r;s=(k&65535)>>>9;t=s&255;a[1106720]=t;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));j3(m,o,65535);p=m&255;a[1044496]=p;q=m<<16>>16!=0;r=q&1;a[1106728]=r;s=(k&65535)>>>9;t=s&255;a[1106720]=t;return}function rn(){var c=0,d=0,f=0;c=xb()|0;d=j5((e[520834]|0)+c|0,16777215)|0;a[1044496]=(d&65535)>>>8&255;c=b[520830]|0;f=c^d;b[520830]=f;a[1106728]=c<<16>>16!=d<<16>>16|0;a[1106720]=(f&65535)>>>8&255;return}function ro(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;f=m+6|0;c[348392]=f;if((f|0)>=(n|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}n=j5((e[520834]|0)+l|0,16777215)|0;a[1044496]=(n&65535)>>>8&255;l=b[520830]|0;f=l^n;b[520830]=f;a[1106728]=l<<16>>16!=n<<16>>16|0;a[1106720]=(f&65535)>>>8&255;return}function rp(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;f=m+6|0;c[348392]=f;if((f|0)>=(n|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}n=j5((e[520833]|0)+l|0,16777215)|0;a[1044496]=(n&65535)>>>8&255;l=b[520830]|0;f=l^n;b[520830]=f;a[1106728]=l<<16>>16!=n<<16>>16|0;a[1106720]=(f&65535)>>>8&255;return}function rq(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;f=m+6|0;c[348392]=f;if((f|0)>=(n|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}n=(e[520833]|0)+l|0;l=j5(n,16777215)|0;a[1106736]=l&1;f=(l&65535)>>>1;m=(c[348392]|0)+6|0;c[348392]=m;if((m|0)<(c[348406]|0)){j3(f,n,16777215);q=f&255;a[1044496]=q;r=f<<16>>16!=0;s=r&1;a[1106728]=s;t=(l&65535)>>>9;u=t&255;a[1106720]=u;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));j3(f,n,16777215);q=f&255;a[1044496]=q;r=f<<16>>16!=0;s=r&1;a[1106728]=s;t=(l&65535)>>>9;u=t&255;a[1106720]=u;return}function rr(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=a[f+(h+2)|0]|0;j=(d[f+(h+1)|0]|0)<<8|(d[f+h|0]|0)|(i&255)<<16;h=(c[348399]|0)+(c[348400]|0)+(c[348392]|0)|0;c[348392]=h;if((h|0)<(c[348406]|0)){k=g}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));k=b[520836]|0}a[1044496]=i;b[520836]=k+3&65535;k=j5((e[520833]|0)+j|0,16777215)|0;a[1044496]=(k&65535)>>>8&255;j=b[520830]|0;i=j^k;b[520830]=i;a[1106728]=j<<16>>16!=k<<16>>16|0;a[1106720]=(i&65535)>>>8&255;return}function rs(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;d=b[520836]|0;f=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=f;g=(c[348392]|0)+(c[348399]|0)|0;c[348392]=g;h=c[348406]|0;if((g|0)<(h|0)){i=d;j=g;k=h}else{do{j1();l=c[348392]|0;m=c[348406]|0;}while((l|0)>=(m|0));i=b[520836]|0;j=l;k=m}b[520836]=i+1&65535;i=b[520831]|0;m=i+(f&255)&65535;do{if((i&255)<<24>>24==0){n=j;o=k}else{f=j+6|0;c[348392]=f;if((f|0)<(k|0)){n=f;o=k;break}while(1){j1();f=c[348392]|0;l=c[348406]|0;if((f|0)<(l|0)){n=f;o=l;break}}}}while(0);k=(e[520833]|0)+(m&65535)|0;m=n+6|0;c[348392]=m;if((m|0)<(o|0)){p=k&65535;q=j5(p,16777215)|0;r=q&65535;s=(q&65535)>>>8;t=s&255;a[1044496]=t;u=c[276674]|0;v=u|r;w=j5(v,16777215)|0;x=(w&65535)>>>8;y=x&255;a[1044496]=y;w9(w);return}do{j1();}while((c[348392]|0)>=(c[348406]|0));p=k&65535;q=j5(p,16777215)|0;r=q&65535;s=(q&65535)>>>8;t=s&255;a[1044496]=t;u=c[276674]|0;v=u|r;w=j5(v,16777215)|0;x=(w&65535)>>>8;y=x&255;a[1044496]=y;w9(w);return}function rt(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}b[520836]=h+1&65535;h=(b[520832]|0)+(e&255)&65535;e=i+6|0;c[348392]=e;if((e|0)<(j|0)){m=h&65535;n=j5(m,16777215)|0;o=(n&65535)>>>8;p=o&255;a[1044496]=p;w9(n);return}do{j1();}while((c[348392]|0)>=(c[348406]|0));m=h&65535;n=j5(m,16777215)|0;o=(n&65535)>>>8;p=o&255;a[1044496]=p;w9(n);return}function ru(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}b[520836]=h+1&65535;h=b[520831]|0;l=h+(e&255)&65535;if((h&255)<<24>>24==0){m=l&65535;w7(0,m,65535);a[1044496]=0;return}h=i+6|0;c[348392]=h;if((h|0)<(j|0)){m=l&65535;w7(0,m,65535);a[1044496]=0;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));m=l&65535;w7(0,m,65535);a[1044496]=0;return}function rv(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}b[520836]=h+1&65535;h=b[520831]|0;l=h+(e&255)&65535;do{if((h&255)<<24>>24!=0){e=i+6|0;c[348392]=e;if((e|0)<(j|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j=j5(l&65535,65535)|0;a[1044496]=(j&65535)>>>8&255;w9(j);return}function rw(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=b[520836]|0;f=a[(c[348396]|0)+(e&65535)|0]|0;a[1044496]=f;g=(c[348392]|0)+(c[348399]|0)|0;c[348392]=g;h=c[348406]|0;if((g|0)<(h|0)){i=e;j=g;k=h}else{do{j1();l=c[348392]|0;m=c[348406]|0;}while((l|0)>=(m|0));i=b[520836]|0;j=l;k=m}b[520836]=i+1&65535;i=b[520831]|0;m=i+(f&255)&65535;do{if((i&255)<<24>>24!=0){f=j+6|0;c[348392]=f;if((f|0)<(k|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);k=m&65535;m=j5(k,65535)|0;j=(d[1106736]|0)<<16|m&65535;a[1106736]=m&1;m=j>>>1;i=(c[348392]|0)+6|0;c[348392]=i;if((i|0)<(c[348406]|0)){n=m&65535;j3(n,k,65535);o=m&255;a[1044496]=o;p=m&65535;q=(p|0)!=0;r=q&1;a[1106728]=r;s=j>>>9;t=s&255;a[1106720]=t;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));n=m&65535;j3(n,k,65535);o=m&255;a[1044496]=o;p=m&65535;q=(p|0)!=0;r=q&1;a[1106728]=r;s=j>>>9;t=s&255;a[1106720]=t;return}function rx(){var b=0;b=j5(xb()|0,16777215)|0;a[1044496]=(b&65535)>>>8&255;w9(b);return}function ry(){var d=0,f=0;d=(c[348392]|0)+12|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}d=j5((e[520832]|0)+1|0,65535)|0;b[520830]=d;b[520832]=(b[520832]|0)+2&65535;a[1106728]=d<<16>>16!=0|0;f=(d&65535)>>>8&255;a[1106720]=f;a[1044496]=f;return}function rz(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=c[348396]|0;f=b[520836]|0;g=f&65535;h=a[e+(g+1)|0]|0;i=(h&255)<<8|(d[e+g|0]|0);a[1044496]=h;h=(c[348392]|0)+(c[348400]|0)|0;c[348392]=h;if((h|0)<(c[348406]|0)){j=f;k=j+2&65535;b[520836]=k;w9(i);return}do{j1();}while((c[348392]|0)>=(c[348406]|0));j=b[520836]|0;k=j+2&65535;b[520836]=k;w9(i);return}function rA(){var e=0,f=0;e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}e=b[520830]|0;f=(d[1106736]|0)<<16|e&65535;a[1106736]=e&1;e=f>>>1;b[520830]=e&65535;a[1106728]=(e&65535|0)!=0|0;a[1106720]=f>>>9&255;return}function rB(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=c[276674]|0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[1044496]=i;i=(c[348392]|0)+(c[348400]|0)|0;c[348392]=i;if((i|0)<(c[348406]|0)){k=g}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));k=b[520836]|0}b[520836]=k+2&65535;k=j5(j&65535|e,16777215)|0;a[1044496]=(k&65535)>>>8&255;w9(k);return}function rC(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=c[276674]|0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[1044496]=i;i=(c[348392]|0)+(c[348400]|0)|0;c[348392]=i;if((i|0)<(c[348406]|0)){k=g}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));k=b[520836]|0}b[520836]=k+2&65535;k=j&65535|e;e=j5(k,16777215)|0;j=(d[1106736]|0)<<16|e&65535;a[1106736]=e&1;e=j>>>1;g=(c[348392]|0)+6|0;c[348392]=g;if((g|0)<(c[348406]|0)){l=e&65535;j3(l,k,16777215);m=e&255;a[1044496]=m;n=e&65535;o=(n|0)!=0;p=o&1;a[1106728]=p;q=j>>>9;r=q&255;a[1106720]=r;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));l=e&65535;j3(l,k,16777215);m=e&255;a[1044496]=m;n=e&65535;o=(n|0)!=0;p=o&1;a[1106728]=p;q=j>>>9;r=q&255;a[1106720]=r;return}function rD(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[348396]|0;f=b[520836]|0;g=f&65535;h=a[e+(g+2)|0]|0;i=(d[e+(g+1)|0]|0)<<8|(d[e+g|0]|0)|(h&255)<<16;g=(c[348399]|0)+(c[348400]|0)+(c[348392]|0)|0;c[348392]=g;if((g|0)<(c[348406]|0)){j=f}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));j=b[520836]|0}a[1044496]=h;b[520836]=j+3&65535;j=j5(i,16777215)|0;a[1044496]=(j&65535)>>>8&255;w9(j);return}function rE(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}b[520836]=h+1&65535;h=b[520831]|0;l=h+(e&255)&65535;do{if((h&255)<<24>>24!=0){e=i+6|0;c[348392]=e;if((e|0)<(j|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j=j5(l&65535,16777215)|0;a[1044496]=(j&65535)>>>8&255;l=c[276674]|j&65535;j=(c[348392]|0)+6|0;c[348392]=j;if((j|0)<(c[348406]|0)){m=b[520834]|0;n=m&65535;o=n+l|0;p=j5(o,16777215)|0;q=(p&65535)>>>8;r=q&255;a[1044496]=r;w9(p);return}do{j1();}while((c[348392]|0)>=(c[348406]|0));m=b[520834]|0;n=m&65535;o=n+l|0;p=j5(o,16777215)|0;q=(p&65535)>>>8;r=q&255;a[1044496]=r;w9(p);return}function rF(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}b[520836]=h+1&65535;h=b[520831]|0;l=h+(e&255)&65535;do{if((h&255)<<24>>24!=0){e=i+6|0;c[348392]=e;if((e|0)<(j|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j=j5(l&65535,16777215)|0;a[1044496]=(j&65535)>>>8&255;l=j5(c[276674]|j&65535,16777215)|0;a[1044496]=(l&65535)>>>8&255;w9(l);return}function rG(){var d=0,f=0,g=0,h=0,i=0;d=j0(c[260418]|0)|0;a[1044496]=d;b[520836]=(b[520836]|0)+1&65535;f=(b[520832]|0)+(d&255)&65535;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}d=j5(f&65535,16777215)|0;a[1044496]=(d&65535)>>>8&255;f=(e[520834]|0)+(d&65535)+(c[276674]|0)&16777215;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)<(c[348406]|0)){g=j5(f,16777215)|0;h=(g&65535)>>>8;i=h&255;a[1044496]=i;w9(g);return}do{j1();}while((c[348392]|0)>=(c[348406]|0));g=j5(f,16777215)|0;h=(g&65535)>>>8;i=h&255;a[1044496]=i;w9(g);return}function rH(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=b[520836]|0;f=a[(c[348396]|0)+(d&65535)|0]|0;g=(c[348392]|0)+(c[348399]|0)|0;c[348392]=g;h=c[348406]|0;if((g|0)<(h|0)){i=d;j=g;k=h}else{do{j1();l=c[348392]|0;m=c[348406]|0;}while((l|0)>=(m|0));i=b[520836]|0;j=l;k=m}b[520836]=i+1&65535;i=b[520831]|0;m=i+(f&255)&65535;do{if((i&255)<<24>>24==0){n=j;o=k}else{f=j+6|0;c[348392]=f;if((f|0)<(k|0)){n=f;o=k;break}while(1){j1();f=c[348392]|0;l=c[348406]|0;if((f|0)<(l|0)){n=f;o=l;break}}}}while(0);k=(e[520833]|0)+(m&65535)|0;m=n+6|0;c[348392]=m;if((m|0)<(o|0)){p=k&65535;w7(0,p,65535);a[1044496]=0;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));p=k&65535;w7(0,p,65535);a[1044496]=0;return}function rI(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=b[520836]|0;f=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=f;g=(c[348392]|0)+(c[348399]|0)|0;c[348392]=g;h=c[348406]|0;if((g|0)<(h|0)){i=d;j=g;k=h}else{do{j1();l=c[348392]|0;m=c[348406]|0;}while((l|0)>=(m|0));i=b[520836]|0;j=l;k=m}b[520836]=i+1&65535;i=b[520831]|0;m=i+(f&255)&65535;do{if((i&255)<<24>>24==0){n=j;o=k}else{f=j+6|0;c[348392]=f;if((f|0)<(k|0)){n=f;o=k;break}while(1){j1();f=c[348392]|0;l=c[348406]|0;if((f|0)<(l|0)){n=f;o=l;break}}}}while(0);k=(e[520833]|0)+(m&65535)|0;m=n+6|0;c[348392]=m;if((m|0)<(o|0)){p=k&65535;q=j5(p,65535)|0;r=(q&65535)>>>8;s=r&255;a[1044496]=s;w9(q);return}do{j1();}while((c[348392]|0)>=(c[348406]|0));p=k&65535;q=j5(p,65535)|0;r=(q&65535)>>>8;s=r&255;a[1044496]=s;w9(q);return}function rJ(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=b[520836]|0;g=a[(c[348396]|0)+(f&65535)|0]|0;a[1044496]=g;h=(c[348392]|0)+(c[348399]|0)|0;c[348392]=h;i=c[348406]|0;if((h|0)<(i|0)){j=f;k=h;l=i}else{do{j1();m=c[348392]|0;n=c[348406]|0;}while((m|0)>=(n|0));j=b[520836]|0;k=m;l=n}b[520836]=j+1&65535;j=b[520831]|0;n=j+(g&255)&65535;do{if((j&255)<<24>>24==0){o=k;p=l}else{g=k+6|0;c[348392]=g;if((g|0)<(l|0)){o=g;p=l;break}while(1){j1();g=c[348392]|0;m=c[348406]|0;if((g|0)<(m|0)){o=g;p=m;break}}}}while(0);l=(e[520833]|0)+(n&65535)|0;n=o+6|0;c[348392]=n;if((n|0)>=(p|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}p=l&65535;l=j5(p,65535)|0;n=(d[1106736]|0)<<16|l&65535;a[1106736]=l&1;l=n>>>1;o=(c[348392]|0)+6|0;c[348392]=o;if((o|0)<(c[348406]|0)){q=l&65535;j3(q,p,65535);r=l&255;a[1044496]=r;s=l&65535;t=(s|0)!=0;u=t&1;a[1106728]=u;v=n>>>9;w=v&255;a[1106720]=w;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));q=l&65535;j3(q,p,65535);r=l&255;a[1044496]=r;s=l&65535;t=(s|0)!=0;u=t&1;a[1106728]=u;v=n>>>9;w=v&255;a[1106720]=w;return}function rK(){var b=0,c=0;b=xb()|0;c=j5((e[520834]|0)+b|0,16777215)|0;a[1044496]=(c&65535)>>>8&255;w9(c);return}function rL(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=c[276674]|0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[1044496]=i;i=(c[348392]|0)+(c[348400]|0)|0;c[348392]=i;h=c[348406]|0;if((i|0)<(h|0)){k=g;l=i;m=h}else{do{j1();n=c[348392]|0;o=c[348406]|0;}while((n|0)>=(o|0));k=b[520836]|0;l=n;m=o}b[520836]=k+2&65535;k=j&65535|e;e=l+6|0;c[348392]=e;if((e|0)<(m|0)){p=b[520834]|0;q=p&65535;r=q+k|0;s=j5(r,16777215)|0;t=(s&65535)>>>8;u=t&255;a[1044496]=u;w9(s);return}do{j1();}while((c[348392]|0)>=(c[348406]|0));p=b[520834]|0;q=p&65535;r=q+k|0;s=j5(r,16777215)|0;t=(s&65535)>>>8;u=t&255;a[1044496]=u;w9(s);return}function rM(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=c[276674]|0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[1044496]=i;i=(c[348392]|0)+(c[348400]|0)|0;c[348392]=i;h=c[348406]|0;if((i|0)<(h|0)){k=g;l=i;m=h}else{do{j1();n=c[348392]|0;o=c[348406]|0;}while((n|0)>=(o|0));k=b[520836]|0;l=n;m=o}b[520836]=k+2&65535;k=j&65535|e;e=l+6|0;c[348392]=e;if((e|0)<(m|0)){p=b[520833]|0;q=p&65535;r=q+k|0;s=j5(r,16777215)|0;t=(s&65535)>>>8;u=t&255;a[1044496]=u;w9(s);return}do{j1();}while((c[348392]|0)>=(c[348406]|0));p=b[520833]|0;q=p&65535;r=q+k|0;s=j5(r,16777215)|0;t=(s&65535)>>>8;u=t&255;a[1044496]=u;w9(s);return}function rN(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;f=m+6|0;c[348392]=f;if((f|0)>=(n|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}n=(e[520833]|0)+l|0;l=j5(n,16777215)|0;f=(d[1106736]|0)<<16|l&65535;a[1106736]=l&1;l=f>>>1;m=(c[348392]|0)+6|0;c[348392]=m;if((m|0)<(c[348406]|0)){q=l&65535;j3(q,n,16777215);r=l&255;a[1044496]=r;s=l&65535;t=(s|0)!=0;u=t&1;a[1106728]=u;v=f>>>9;w=v&255;a[1106720]=w;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));q=l&65535;j3(q,n,16777215);r=l&255;a[1044496]=r;s=l&65535;t=(s|0)!=0;u=t&1;a[1106728]=u;v=f>>>9;w=v&255;a[1106720]=w;return}function rO(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=a[f+(h+2)|0]|0;j=(d[f+(h+1)|0]|0)<<8|(d[f+h|0]|0)|(i&255)<<16;h=(c[348399]|0)+(c[348400]|0)+(c[348392]|0)|0;c[348392]=h;if((h|0)<(c[348406]|0)){k=g}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));k=b[520836]|0}a[1044496]=i;b[520836]=k+3&65535;k=j5((e[520833]|0)+j|0,16777215)|0;a[1044496]=(k&65535)>>>8&255;w9(k);return}function rP(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=b[520836]|0;f=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=f;g=(c[348392]|0)+(c[348399]|0)|0;c[348392]=g;h=c[348406]|0;if((g|0)<(h|0)){i=d;j=g;k=h}else{do{j1();l=c[348392]|0;m=c[348406]|0;}while((l|0)>=(m|0));i=b[520836]|0;j=l;k=m}b[520836]=i+1&65535;i=b[520831]|0;m=i+(f&255)&65535;do{if((i&255)<<24>>24==0){n=j;o=k}else{f=j+6|0;c[348392]=f;if((f|0)<(k|0)){n=f;o=k;break}while(1){j1();f=c[348392]|0;l=c[348406]|0;if((f|0)<(l|0)){n=f;o=l;break}}}}while(0);k=(e[520833]|0)+(m&65535)|0;m=n+6|0;c[348392]=m;if((m|0)<(o|0)){p=k&65535;q=j5(p,16777215)|0;r=q&65535;s=c[276674]|0;t=s|r;u=b[520830]|0;w7(u,t,16777215);v=a[1041661|0]|0;a[1044496]=v;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));p=k&65535;q=j5(p,16777215)|0;r=q&65535;s=c[276674]|0;t=s|r;u=b[520830]|0;w7(u,t,16777215);v=a[1041661|0]|0;a[1044496]=v;return}function rQ(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}b[520836]=h+1&65535;h=(b[520832]|0)+(e&255)&65535;e=i+6|0;c[348392]=e;if((e|0)<(j|0)){m=h&65535;n=b[520830]|0;w7(n,m,16777215);o=a[1041661|0]|0;a[1044496]=o;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));m=h&65535;n=b[520830]|0;w7(n,m,16777215);o=a[1041661|0]|0;a[1044496]=o;return}function rR(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}b[520836]=h+1&65535;h=b[520831]|0;l=h+(e&255)&65535;do{if((h&255)<<24>>24!=0){e=i+6|0;c[348392]=e;if((e|0)<(j|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);w7(b[520830]|0,l&65535,65535);a[1044496]=a[1041661|0]|0;return}function rS(){var c=0;c=xb()|0;w7(b[520830]|0,c,16777215);a[1044496]=a[1041661|0]|0;return}function rT(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=b[520830]|0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[1044496]=i;i=(c[348392]|0)+(c[348400]|0)|0;c[348392]=i;if((i|0)<(c[348406]|0)){k=g;l=k+2&65535;b[520836]=l;m=j&e;n=m<<16>>16!=0;o=n&1;a[1106728]=o;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));k=b[520836]|0;l=k+2&65535;b[520836]=l;m=j&e;n=m<<16>>16!=0;o=n&1;a[1106728]=o;return}function rU(){var d=0;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}d=b[520833]|0;b[520830]=d;a[1106728]=d<<16>>16!=0|0;a[1106720]=(d&65535)>>>8&255;return}function rV(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[276674]|0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=(d[f+(h+1)|0]|0)<<8|(d[f+h|0]|0);h=(c[348392]|0)+(c[348400]|0)|0;c[348392]=h;if((h|0)<(c[348406]|0)){j=g}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));j=b[520836]|0}b[520836]=j+2&65535;w7(b[520830]|0,i&65535|e,16777215);a[1044496]=a[1041661|0]|0;return}function rW(){var e=0,f=0,g=0,h=0,i=0;e=c[348396]|0;f=b[520836]|0;g=f&65535;h=(d[e+(g+1)|0]|0)<<8|(d[e+g|0]|0)|(d[e+(g+2)|0]|0)<<16;g=(c[348399]|0)+(c[348400]|0)+(c[348392]|0)|0;c[348392]=g;if((g|0)<(c[348406]|0)){i=f}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));i=b[520836]|0}b[520836]=i+3&65535;w7(b[520830]|0,h,16777215);a[1044496]=a[1041661|0]|0;return}function rX(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}b[520836]=h+1&65535;h=b[520831]|0;l=h+(e&255)&65535;do{if((h&255)<<24>>24!=0){e=i+6|0;c[348392]=e;if((e|0)<(j|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j=(j5(l&65535,16777215)|0)&65535;l=c[276674]|j;j=(c[348392]|0)+6|0;c[348392]=j;if((j|0)<(c[348406]|0)){m=b[520834]|0;n=m&65535;o=n+l|0;p=b[520830]|0;w7(p,o,16777215);q=a[1041661|0]|0;a[1044496]=q;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));m=b[520834]|0;n=m&65535;o=n+l|0;p=b[520830]|0;w7(p,o,16777215);q=a[1041661|0]|0;a[1044496]=q;return}function rY(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}b[520836]=h+1&65535;h=b[520831]|0;l=h+(e&255)&65535;do{if((h&255)<<24>>24!=0){e=i+6|0;c[348392]=e;if((e|0)<(j|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j=(j5(l&65535,16777215)|0)&65535;w7(b[520830]|0,c[276674]|j,16777215);a[1044496]=a[1041661|0]|0;return}function rZ(){var d=0,f=0,g=0,h=0;d=j0(c[260418]|0)|0;a[1044496]=d;b[520836]=(b[520836]|0)+1&65535;f=(b[520832]|0)+(d&255)&65535;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}d=(j5(f&65535,16777215)|0)&65535;f=(e[520834]|0)+d+(c[276674]|0)&16777215;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)<(c[348406]|0)){g=b[520830]|0;w7(g,f,16777215);h=a[1041661|0]|0;a[1044496]=h;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));g=b[520830]|0;w7(g,f,16777215);h=a[1041661|0]|0;a[1044496]=h;return}function r_(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=b[520836]|0;f=a[(c[348396]|0)+(d&65535)|0]|0;g=(c[348392]|0)+(c[348399]|0)|0;c[348392]=g;h=c[348406]|0;if((g|0)<(h|0)){i=d;j=g;k=h}else{do{j1();l=c[348392]|0;m=c[348406]|0;}while((l|0)>=(m|0));i=b[520836]|0;j=l;k=m}b[520836]=i+1&65535;i=b[520831]|0;m=i+(f&255)&65535;do{if((i&255)<<24>>24==0){n=j;o=k}else{f=j+6|0;c[348392]=f;if((f|0)<(k|0)){n=f;o=k;break}while(1){j1();f=c[348392]|0;l=c[348406]|0;if((f|0)<(l|0)){n=f;o=l;break}}}}while(0);k=(e[520833]|0)+(m&65535)|0;m=n+6|0;c[348392]=m;if((m|0)<(o|0)){p=k&65535;q=b[520830]|0;w7(q,p,65535);r=a[1041661|0]|0;a[1044496]=r;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));p=k&65535;q=b[520830]|0;w7(q,p,65535);r=a[1041661|0]|0;a[1044496]=r;return}function r$(){var c=0;c=xb()|0;w7(b[520830]|0,(e[520834]|0)+c|0,16777215);a[1044496]=a[1041661|0]|0;return}function r0(){var d=0;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}d=b[520834]|0;b[520830]=d;a[1106728]=d<<16>>16!=0|0;a[1106720]=(d&65535)>>>8&255;return}function r1(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=c[276674]|0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=(d[f+(h+1)|0]|0)<<8|(d[f+h|0]|0);h=(c[348392]|0)+(c[348400]|0)|0;c[348392]=h;f=c[348406]|0;if((h|0)<(f|0)){j=g;k=h;l=f}else{do{j1();m=c[348392]|0;n=c[348406]|0;}while((m|0)>=(n|0));j=b[520836]|0;k=m;l=n}b[520836]=j+2&65535;j=i&65535|e;e=k+6|0;c[348392]=e;if((e|0)<(l|0)){o=b[520834]|0;p=o&65535;q=p+j|0;r=b[520830]|0;w7(r,q,16777215);s=a[1041661|0]|0;a[1044496]=s;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));o=b[520834]|0;p=o&65535;q=p+j|0;r=b[520830]|0;w7(r,q,16777215);s=a[1041661|0]|0;a[1044496]=s;return}function r2(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=c[276674]|0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=(d[f+(h+1)|0]|0)<<8|(d[f+h|0]|0);h=(c[348392]|0)+(c[348400]|0)|0;c[348392]=h;if((h|0)<(c[348406]|0)){j=g;k=j+2&65535;b[520836]=k;l=i&65535;m=l|e;w7(0,m,16777215);a[1044496]=0;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));j=b[520836]|0;k=j+2&65535;b[520836]=k;l=i&65535;m=l|e;w7(0,m,16777215);a[1044496]=0;return}function r3(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=c[276674]|0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=(d[f+(h+1)|0]|0)<<8|(d[f+h|0]|0);h=(c[348392]|0)+(c[348400]|0)|0;c[348392]=h;f=c[348406]|0;if((h|0)<(f|0)){j=g;k=h;l=f}else{do{j1();m=c[348392]|0;n=c[348406]|0;}while((m|0)>=(n|0));j=b[520836]|0;k=m;l=n}b[520836]=j+2&65535;j=i&65535|e;e=k+6|0;c[348392]=e;if((e|0)<(l|0)){o=b[520833]|0;p=o&65535;q=p+j|0;r=b[520830]|0;w7(r,q,16777215);s=a[1041661|0]|0;a[1044496]=s;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));o=b[520833]|0;p=o&65535;q=p+j|0;r=b[520830]|0;w7(r,q,16777215);s=a[1041661|0]|0;a[1044496]=s;return}function r4(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=c[276674]|0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=(d[f+(h+1)|0]|0)<<8|(d[f+h|0]|0);h=(c[348392]|0)+(c[348400]|0)|0;c[348392]=h;f=c[348406]|0;if((h|0)<(f|0)){j=g;k=h;l=f}else{do{j1();m=c[348392]|0;n=c[348406]|0;}while((m|0)>=(n|0));j=b[520836]|0;k=m;l=n}b[520836]=j+2&65535;j=i&65535|e;e=k+6|0;c[348392]=e;if((e|0)<(l|0)){o=b[520833]|0;p=o&65535;q=p+j|0;w7(0,q,16777215);a[1044496]=0;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));o=b[520833]|0;p=o&65535;q=p+j|0;w7(0,q,16777215);a[1044496]=0;return}function r5(){var f=0,g=0,h=0,i=0,j=0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=(d[f+(h+1)|0]|0)<<8|(d[f+h|0]|0)|(d[f+(h+2)|0]|0)<<16;h=(c[348399]|0)+(c[348400]|0)+(c[348392]|0)|0;c[348392]=h;if((h|0)<(c[348406]|0)){j=g}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));j=b[520836]|0}b[520836]=j+3&65535;w7(b[520830]|0,(e[520833]|0)+i|0,16777215);a[1044496]=a[1041661|0]|0;return}function r6(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=b[520836]|0;f=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=f;g=(c[348392]|0)+(c[348399]|0)|0;c[348392]=g;h=c[348406]|0;if((g|0)<(h|0)){i=d;j=g;k=h}else{do{j1();l=c[348392]|0;m=c[348406]|0;}while((l|0)>=(m|0));i=b[520836]|0;j=l;k=m}b[520836]=i+1&65535;i=b[520831]|0;m=i+(f&255)&65535;do{if((i&255)<<24>>24==0){n=j;o=k}else{f=j+6|0;c[348392]=f;if((f|0)<(k|0)){n=f;o=k;break}while(1){j1();f=c[348392]|0;l=c[348406]|0;if((f|0)<(l|0)){n=f;o=l;break}}}}while(0);k=(e[520833]|0)+(m&65535)|0;m=n+6|0;c[348392]=m;if((m|0)>=(o|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}o=j5(k&65535,16777215)|0;a[1044496]=(o&65535)>>>8&255;k=j5(c[276674]|o&65535,16777215)|0;o=(k&65535)>>>8&255;a[1044496]=o;b[520830]=k;a[1106728]=k<<16>>16!=0|0;a[1106720]=o;return}function r7(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}b[520836]=h+1&65535;h=(b[520832]|0)+(e&255)&65535;e=i+6|0;c[348392]=e;if((e|0)>=(j|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}j=j5(h&65535,16777215)|0;h=(j&65535)>>>8&255;a[1044496]=h;b[520830]=j;a[1106728]=j<<16>>16!=0|0;a[1106720]=h;return}function r8(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}b[520836]=h+1&65535;h=b[520831]|0;l=h+(e&255)&65535;do{if((h&255)<<24>>24!=0){e=i+6|0;c[348392]=e;if((e|0)<(j|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j=j5(l&65535,65535)|0;l=(j&65535)>>>8&255;a[1044496]=l;b[520830]=j;a[1106728]=j<<16>>16!=0|0;a[1106720]=l;return}function r9(){var c=0,d=0;c=j5(xb()|0,16777215)|0;d=(c&65535)>>>8&255;a[1044496]=d;b[520830]=c;a[1106728]=c<<16>>16!=0|0;a[1106720]=d;return}function sa(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[348396]|0;f=b[520836]|0;g=f&65535;h=a[e+(g+1)|0]|0;i=(h&255)<<8|(d[e+g|0]|0);a[1044496]=h;g=(c[348392]|0)+(c[348400]|0)|0;c[348392]=g;if((g|0)<(c[348406]|0)){j=f}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));j=b[520836]|0}b[520836]=j+2&65535;b[520830]=i;a[1106728]=i<<16>>16!=0|0;a[1106720]=h;return}function sb(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=c[276674]|0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[1044496]=i;i=(c[348392]|0)+(c[348400]|0)|0;c[348392]=i;if((i|0)<(c[348406]|0)){k=g}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));k=b[520836]|0}b[520836]=k+2&65535;k=j5(j&65535|e,16777215)|0;e=(k&65535)>>>8&255;a[1044496]=e;b[520830]=k;a[1106728]=k<<16>>16!=0|0;a[1106720]=e;return}function sc(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[348396]|0;f=b[520836]|0;g=f&65535;h=a[e+(g+2)|0]|0;i=(d[e+(g+1)|0]|0)<<8|(d[e+g|0]|0)|(h&255)<<16;g=(c[348399]|0)+(c[348400]|0)+(c[348392]|0)|0;c[348392]=g;if((g|0)<(c[348406]|0)){j=f}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));j=b[520836]|0}a[1044496]=h;b[520836]=j+3&65535;j=j5(i,16777215)|0;i=(j&65535)>>>8&255;a[1044496]=i;b[520830]=j;a[1106728]=j<<16>>16!=0|0;a[1106720]=i;return}function sd(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}b[520836]=h+1&65535;h=b[520831]|0;l=h+(e&255)&65535;do{if((h&255)<<24>>24!=0){e=i+6|0;c[348392]=e;if((e|0)<(j|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j=j5(l&65535,16777215)|0;a[1044496]=(j&65535)>>>8&255;l=c[276674]|j&65535;j=(c[348392]|0)+6|0;c[348392]=j;if((j|0)<(c[348406]|0)){m=b[520834]|0;n=m&65535;o=n+l|0;p=j5(o,16777215)|0;q=(p&65535)>>>8;r=q&255;a[1044496]=r;b[520830]=p;s=p<<16>>16!=0;t=s&1;a[1106728]=t;a[1106720]=r;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));m=b[520834]|0;n=m&65535;o=n+l|0;p=j5(o,16777215)|0;q=(p&65535)>>>8;r=q&255;a[1044496]=r;b[520830]=p;s=p<<16>>16!=0;t=s&1;a[1106728]=t;a[1106720]=r;return}function se(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}b[520836]=h+1&65535;h=b[520831]|0;l=h+(e&255)&65535;do{if((h&255)<<24>>24!=0){e=i+6|0;c[348392]=e;if((e|0)<(j|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j=j5(l&65535,16777215)|0;a[1044496]=(j&65535)>>>8&255;l=j5(c[276674]|j&65535,16777215)|0;j=(l&65535)>>>8&255;a[1044496]=j;b[520830]=l;a[1106728]=l<<16>>16!=0|0;a[1106720]=j;return}function sf(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0;d=j0(c[260418]|0)|0;a[1044496]=d;b[520836]=(b[520836]|0)+1&65535;f=(b[520832]|0)+(d&255)&65535;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}d=j5(f&65535,16777215)|0;a[1044496]=(d&65535)>>>8&255;f=(e[520834]|0)+(d&65535)+(c[276674]|0)&16777215;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)<(c[348406]|0)){g=j5(f,16777215)|0;h=(g&65535)>>>8;i=h&255;a[1044496]=i;b[520830]=g;j=g<<16>>16!=0;k=j&1;a[1106728]=k;a[1106720]=i;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));g=j5(f,16777215)|0;h=(g&65535)>>>8;i=h&255;a[1044496]=i;b[520830]=g;j=g<<16>>16!=0;k=j&1;a[1106728]=k;a[1106720]=i;return}function sg(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;d=b[520836]|0;f=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=f;g=(c[348392]|0)+(c[348399]|0)|0;c[348392]=g;h=c[348406]|0;if((g|0)<(h|0)){i=d;j=g;k=h}else{do{j1();l=c[348392]|0;m=c[348406]|0;}while((l|0)>=(m|0));i=b[520836]|0;j=l;k=m}b[520836]=i+1&65535;i=b[520831]|0;m=i+(f&255)&65535;do{if((i&255)<<24>>24==0){n=j;o=k}else{f=j+6|0;c[348392]=f;if((f|0)<(k|0)){n=f;o=k;break}while(1){j1();f=c[348392]|0;l=c[348406]|0;if((f|0)<(l|0)){n=f;o=l;break}}}}while(0);k=(e[520833]|0)+(m&65535)|0;m=n+6|0;c[348392]=m;if((m|0)<(o|0)){p=k&65535;q=j5(p,65535)|0;r=(q&65535)>>>8;s=r&255;a[1044496]=s;b[520830]=q;t=q<<16>>16!=0;u=t&1;a[1106728]=u;a[1106720]=s;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));p=k&65535;q=j5(p,65535)|0;r=(q&65535)>>>8;s=r&255;a[1044496]=s;b[520830]=q;t=q<<16>>16!=0;u=t&1;a[1106728]=u;a[1106720]=s;return}function sh(){var c=0,d=0;c=xb()|0;d=j5((e[520834]|0)+c|0,16777215)|0;c=(d&65535)>>>8&255;a[1044496]=c;b[520830]=d;a[1106728]=d<<16>>16!=0|0;a[1106720]=c;return}function si(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;f=m+6|0;c[348392]=f;if((f|0)>=(n|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}n=j5((e[520834]|0)+l|0,16777215)|0;l=(n&65535)>>>8&255;a[1044496]=l;b[520830]=n;a[1106728]=n<<16>>16!=0|0;a[1106720]=l;return}function sj(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;f=m+6|0;c[348392]=f;if((f|0)>=(n|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}n=j5((e[520833]|0)+l|0,16777215)|0;l=(n&65535)>>>8&255;a[1044496]=l;b[520830]=n;a[1106728]=n<<16>>16!=0|0;a[1106720]=l;return}function sk(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=a[f+(h+2)|0]|0;j=(d[f+(h+1)|0]|0)<<8|(d[f+h|0]|0)|(i&255)<<16;h=(c[348399]|0)+(c[348400]|0)+(c[348392]|0)|0;c[348392]=h;if((h|0)<(c[348406]|0)){k=g}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));k=b[520836]|0}a[1044496]=i;b[520836]=k+3&65535;k=j5((e[520833]|0)+j|0,16777215)|0;j=(k&65535)>>>8&255;a[1044496]=j;b[520830]=k;a[1106728]=k<<16>>16!=0|0;a[1106720]=j;return}function sl(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=b[520836]|0;f=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=f;g=(c[348392]|0)+(c[348399]|0)|0;c[348392]=g;h=c[348406]|0;if((g|0)<(h|0)){i=d;j=g;k=h}else{do{j1();l=c[348392]|0;m=c[348406]|0;}while((l|0)>=(m|0));i=b[520836]|0;j=l;k=m}b[520836]=i+1&65535;i=b[520831]|0;m=i+(f&255)&65535;do{if((i&255)<<24>>24==0){n=j;o=k}else{f=j+6|0;c[348392]=f;if((f|0)<(k|0)){n=f;o=k;break}while(1){j1();f=c[348392]|0;l=c[348406]|0;if((f|0)<(l|0)){n=f;o=l;break}}}}while(0);k=(e[520833]|0)+(m&65535)|0;m=n+6|0;c[348392]=m;if((m|0)>=(o|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}o=j5(k&65535,16777215)|0;a[1044496]=(o&65535)>>>8&255;k=j5(c[276674]|o&65535,16777215)|0;a[1044496]=(k&65535)>>>8&255;o=(e[520830]|0)-(k&65535)|0;a[1106736]=o>>>31&255^1;a[1106728]=(o&65535|0)!=0|0;a[1106720]=o>>>8&255;return}function sm(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b[520836]|0;f=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=f;g=(c[348392]|0)+(c[348399]|0)|0;c[348392]=g;h=c[348406]|0;if((g|0)<(h|0)){i=d;j=g;k=h}else{do{j1();l=c[348392]|0;m=c[348406]|0;}while((l|0)>=(m|0));i=b[520836]|0;j=l;k=m}b[520836]=i+1&65535;i=(b[520832]|0)+(f&255)&65535;f=j+6|0;c[348392]=f;if((f|0)>=(k|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}k=j5(i&65535,16777215)|0;a[1044496]=(k&65535)>>>8&255;i=(e[520830]|0)-(k&65535)|0;a[1106736]=i>>>31&255^1;a[1106728]=(i&65535|0)!=0|0;a[1106720]=i>>>8&255;return}function sn(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b[520836]|0;f=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=f;g=(c[348392]|0)+(c[348399]|0)|0;c[348392]=g;h=c[348406]|0;if((g|0)<(h|0)){i=d;j=g;k=h}else{do{j1();l=c[348392]|0;m=c[348406]|0;}while((l|0)>=(m|0));i=b[520836]|0;j=l;k=m}b[520836]=i+1&65535;i=b[520831]|0;m=i+(f&255)&65535;do{if((i&255)<<24>>24!=0){f=j+6|0;c[348392]=f;if((f|0)<(k|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);k=j5(m&65535,65535)|0;a[1044496]=(k&65535)>>>8&255;m=(e[520830]|0)-(k&65535)|0;a[1106736]=m>>>31&255^1;a[1106728]=(m&65535|0)!=0|0;a[1106720]=m>>>8&255;return}function so(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}b[520836]=h+1&65535;h=b[520831]|0;l=h+(e&255)&65535;do{if((h&255)<<24>>24!=0){e=i+6|0;c[348392]=e;if((e|0)<(j|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j=l&65535;l=(j5(j,65535)|0)-1&65535;i=(c[348392]|0)+6|0;c[348392]=i;if((i|0)<(c[348406]|0)){j3(l,j,65535);m=l&255;a[1044496]=m;n=l<<16>>16!=0;o=n&1;a[1106728]=o;p=(l&65535)>>>8;q=p&255;a[1106720]=q;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));j3(l,j,65535);m=l&255;a[1044496]=m;n=l<<16>>16!=0;o=n&1;a[1106728]=o;p=(l&65535)>>>8;q=p&255;a[1106720]=q;return}function sp(){var b=0,c=0;b=j5(xb()|0,16777215)|0;a[1044496]=(b&65535)>>>8&255;c=(e[520830]|0)-(b&65535)|0;a[1106736]=c>>>31&255^1;a[1106728]=(c&65535|0)!=0|0;a[1106720]=c>>>8&255;return}function sq(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=e[520830]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;if((j|0)<(c[348406]|0)){l=h}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));l=b[520836]|0}b[520836]=l+2&65535;l=f-(k&65535)|0;a[1106736]=l>>>31&255^1;a[1106728]=(l&65535|0)!=0|0;a[1106720]=l>>>8&255;return}function sr(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;if((j|0)<(c[348406]|0)){l=h}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));l=b[520836]|0}b[520836]=l+2&65535;l=j5(k&65535|f,16777215)|0;a[1044496]=(l&65535)>>>8&255;f=(e[520830]|0)-(l&65535)|0;a[1106736]=f>>>31&255^1;a[1106728]=(f&65535|0)!=0|0;a[1106720]=f>>>8&255;return}function ss(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=c[276674]|0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[1044496]=i;i=(c[348392]|0)+(c[348400]|0)|0;c[348392]=i;if((i|0)<(c[348406]|0)){k=g}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));k=b[520836]|0}b[520836]=k+2&65535;k=j&65535|e;e=(j5(k,16777215)|0)-1&65535;j=(c[348392]|0)+6|0;c[348392]=j;if((j|0)<(c[348406]|0)){j3(e,k,16777215);l=e&255;a[1044496]=l;m=e<<16>>16!=0;n=m&1;a[1106728]=n;o=(e&65535)>>>8;p=o&255;a[1106720]=p;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));j3(e,k,16777215);l=e&255;a[1044496]=l;m=e<<16>>16!=0;n=m&1;a[1106728]=n;o=(e&65535)>>>8;p=o&255;a[1106720]=p;return}function st(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=a[f+(h+2)|0]|0;j=(d[f+(h+1)|0]|0)<<8|(d[f+h|0]|0)|(i&255)<<16;h=(c[348399]|0)+(c[348400]|0)+(c[348392]|0)|0;c[348392]=h;if((h|0)<(c[348406]|0)){k=g}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));k=b[520836]|0}a[1044496]=i;b[520836]=k+3&65535;k=j5(j,16777215)|0;a[1044496]=(k&65535)>>>8&255;j=(e[520830]|0)-(k&65535)|0;a[1106736]=j>>>31&255^1;a[1106728]=(j&65535|0)!=0|0;a[1106720]=j>>>8&255;return}function su(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b[520836]|0;f=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=f;g=(c[348392]|0)+(c[348399]|0)|0;c[348392]=g;h=c[348406]|0;if((g|0)<(h|0)){i=d;j=g;k=h}else{do{j1();l=c[348392]|0;m=c[348406]|0;}while((l|0)>=(m|0));i=b[520836]|0;j=l;k=m}b[520836]=i+1&65535;i=b[520831]|0;m=i+(f&255)&65535;do{if((i&255)<<24>>24!=0){f=j+6|0;c[348392]=f;if((f|0)<(k|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);k=j5(m&65535,16777215)|0;a[1044496]=(k&65535)>>>8&255;m=c[276674]|k&65535;k=(c[348392]|0)+6|0;c[348392]=k;if((k|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}k=j5((e[520834]|0)+m|0,16777215)|0;a[1044496]=(k&65535)>>>8&255;m=(e[520830]|0)-(k&65535)|0;a[1106736]=m>>>31&255^1;a[1106728]=(m&65535|0)!=0|0;a[1106720]=m>>>8&255;return}function sv(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b[520836]|0;f=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=f;g=(c[348392]|0)+(c[348399]|0)|0;c[348392]=g;h=c[348406]|0;if((g|0)<(h|0)){i=d;j=g;k=h}else{do{j1();l=c[348392]|0;m=c[348406]|0;}while((l|0)>=(m|0));i=b[520836]|0;j=l;k=m}b[520836]=i+1&65535;i=b[520831]|0;m=i+(f&255)&65535;do{if((i&255)<<24>>24!=0){f=j+6|0;c[348392]=f;if((f|0)<(k|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);k=j5(m&65535,16777215)|0;a[1044496]=(k&65535)>>>8&255;m=j5(c[276674]|k&65535,16777215)|0;a[1044496]=(m&65535)>>>8&255;k=(e[520830]|0)-(m&65535)|0;a[1106736]=k>>>31&255^1;a[1106728]=(k&65535|0)!=0|0;a[1106720]=k>>>8&255;return}function sw(){var d=0,f=0;d=j0(c[260418]|0)|0;a[1044496]=d;b[520836]=(b[520836]|0)+1&65535;f=(b[520832]|0)+(d&255)&65535;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}d=j5(f&65535,16777215)|0;a[1044496]=(d&65535)>>>8&255;f=(e[520834]|0)+(d&65535)+(c[276674]|0)&16777215;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}d=j5(f,16777215)|0;a[1044496]=(d&65535)>>>8&255;f=(e[520830]|0)-(d&65535)|0;a[1106736]=f>>>31&255^1;a[1106728]=(f&65535|0)!=0|0;a[1106720]=f>>>8&255;return}function sx(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=b[520836]|0;f=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=f;g=(c[348392]|0)+(c[348399]|0)|0;c[348392]=g;h=c[348406]|0;if((g|0)<(h|0)){i=d;j=g;k=h}else{do{j1();l=c[348392]|0;m=c[348406]|0;}while((l|0)>=(m|0));i=b[520836]|0;j=l;k=m}b[520836]=i+1&65535;i=b[520831]|0;m=i+(f&255)&65535;do{if((i&255)<<24>>24==0){n=j;o=k}else{f=j+6|0;c[348392]=f;if((f|0)<(k|0)){n=f;o=k;break}while(1){j1();f=c[348392]|0;l=c[348406]|0;if((f|0)<(l|0)){n=f;o=l;break}}}}while(0);k=(e[520833]|0)+(m&65535)|0;m=n+6|0;c[348392]=m;if((m|0)>=(o|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}o=j5(k&65535,65535)|0;a[1044496]=(o&65535)>>>8&255;k=(e[520830]|0)-(o&65535)|0;a[1106736]=k>>>31&255^1;a[1106728]=(k&65535|0)!=0|0;a[1106720]=k>>>8&255;return}function sy(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=b[520836]|0;f=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=f;g=(c[348392]|0)+(c[348399]|0)|0;c[348392]=g;h=c[348406]|0;if((g|0)<(h|0)){i=d;j=g;k=h}else{do{j1();l=c[348392]|0;m=c[348406]|0;}while((l|0)>=(m|0));i=b[520836]|0;j=l;k=m}b[520836]=i+1&65535;i=b[520831]|0;m=i+(f&255)&65535;do{if((i&255)<<24>>24==0){n=j;o=k}else{f=j+6|0;c[348392]=f;if((f|0)<(k|0)){n=f;o=k;break}while(1){j1();f=c[348392]|0;l=c[348406]|0;if((f|0)<(l|0)){n=f;o=l;break}}}}while(0);k=(e[520833]|0)+(m&65535)|0;m=n+6|0;c[348392]=m;if((m|0)>=(o|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}o=k&65535;k=(j5(o,65535)|0)-1&65535;m=(c[348392]|0)+6|0;c[348392]=m;if((m|0)<(c[348406]|0)){j3(k,o,65535);p=k&255;a[1044496]=p;q=k<<16>>16!=0;r=q&1;a[1106728]=r;s=(k&65535)>>>8;t=s&255;a[1106720]=t;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));j3(k,o,65535);p=k&255;a[1044496]=p;q=k<<16>>16!=0;r=q&1;a[1106728]=r;s=(k&65535)>>>8;t=s&255;a[1106720]=t;return}function sz(){var b=0,c=0;b=xb()|0;c=j5((e[520834]|0)+b|0,16777215)|0;a[1044496]=(c&65535)>>>8&255;b=(e[520830]|0)-(c&65535)|0;a[1106736]=b>>>31&255^1;a[1106728]=(b&65535|0)!=0|0;a[1106720]=b>>>8&255;return}function sA(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;f=m+6|0;c[348392]=f;if((f|0)>=(n|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}n=j5((e[520834]|0)+l|0,16777215)|0;a[1044496]=(n&65535)>>>8&255;l=(e[520830]|0)-(n&65535)|0;a[1106736]=l>>>31&255^1;a[1106728]=(l&65535|0)!=0|0;a[1106720]=l>>>8&255;return}function sB(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;f=m+6|0;c[348392]=f;if((f|0)>=(n|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}n=j5((e[520833]|0)+l|0,16777215)|0;a[1044496]=(n&65535)>>>8&255;l=(e[520830]|0)-(n&65535)|0;a[1106736]=l>>>31&255^1;a[1106728]=(l&65535|0)!=0|0;a[1106720]=l>>>8&255;return}function sC(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;f=m+6|0;c[348392]=f;if((f|0)>=(n|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}n=(e[520833]|0)+l|0;l=(j5(n,16777215)|0)-1&65535;f=(c[348392]|0)+6|0;c[348392]=f;if((f|0)<(c[348406]|0)){j3(l,n,16777215);q=l&255;a[1044496]=q;r=l<<16>>16!=0;s=r&1;a[1106728]=s;t=(l&65535)>>>8;u=t&255;a[1106720]=u;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));j3(l,n,16777215);q=l&255;a[1044496]=q;r=l<<16>>16!=0;s=r&1;a[1106728]=s;t=(l&65535)>>>8;u=t&255;a[1106720]=u;return}function sD(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=a[f+(h+2)|0]|0;j=(d[f+(h+1)|0]|0)<<8|(d[f+h|0]|0)|(i&255)<<16;h=(c[348399]|0)+(c[348400]|0)+(c[348392]|0)|0;c[348392]=h;if((h|0)<(c[348406]|0)){k=g}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));k=b[520836]|0}a[1044496]=i;b[520836]=k+3&65535;k=j5((e[520833]|0)+j|0,16777215)|0;a[1044496]=(k&65535)>>>8&255;j=(e[520830]|0)-(k&65535)|0;a[1106736]=j>>>31&255^1;a[1106728]=(j&65535|0)!=0|0;a[1106720]=j>>>8&255;return}function sE(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;d=b[520836]|0;f=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=f;g=(c[348392]|0)+(c[348399]|0)|0;c[348392]=g;h=c[348406]|0;if((g|0)<(h|0)){i=d;j=g;k=h}else{do{j1();l=c[348392]|0;m=c[348406]|0;}while((l|0)>=(m|0));i=b[520836]|0;j=l;k=m}b[520836]=i+1&65535;i=b[520831]|0;m=i+(f&255)&65535;do{if((i&255)<<24>>24==0){n=j;o=k}else{f=j+6|0;c[348392]=f;if((f|0)<(k|0)){n=f;o=k;break}while(1){j1();f=c[348392]|0;l=c[348406]|0;if((f|0)<(l|0)){n=f;o=l;break}}}}while(0);k=(e[520833]|0)+(m&65535)|0;m=n+6|0;c[348392]=m;if((m|0)<(o|0)){p=k&65535;q=j5(p,16777215)|0;r=q&65535;s=(q&65535)>>>8;t=s&255;a[1044496]=t;u=c[276674]|0;v=u|r;w=j5(v,16777215)|0;x=(w&65535)>>>8;y=x&255;a[1044496]=y;w6(w);return}do{j1();}while((c[348392]|0)>=(c[348406]|0));p=k&65535;q=j5(p,16777215)|0;r=q&65535;s=(q&65535)>>>8;t=s&255;a[1044496]=t;u=c[276674]|0;v=u|r;w=j5(v,16777215)|0;x=(w&65535)>>>8;y=x&255;a[1044496]=y;w6(w);return}function sF(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}b[520836]=h+1&65535;h=(b[520832]|0)+(e&255)&65535;e=i+6|0;c[348392]=e;if((e|0)<(j|0)){m=h&65535;n=j5(m,16777215)|0;o=(n&65535)>>>8;p=o&255;a[1044496]=p;w6(n);return}do{j1();}while((c[348392]|0)>=(c[348406]|0));m=h&65535;n=j5(m,16777215)|0;o=(n&65535)>>>8;p=o&255;a[1044496]=p;w6(n);return}function sG(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}b[520836]=h+1&65535;h=b[520831]|0;l=h+(e&255)&65535;do{if((h&255)<<24>>24!=0){e=i+6|0;c[348392]=e;if((e|0)<(j|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j=j5(l&65535,65535)|0;a[1044496]=(j&65535)>>>8&255;w6(j);return}function sH(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}b[520836]=h+1&65535;h=b[520831]|0;l=h+(e&255)&65535;do{if((h&255)<<24>>24!=0){e=i+6|0;c[348392]=e;if((e|0)<(j|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j=l&65535;l=(j5(j,65535)|0)+1&65535;i=(c[348392]|0)+6|0;c[348392]=i;if((i|0)<(c[348406]|0)){j3(l,j,65535);m=l&255;a[1044496]=m;n=l<<16>>16!=0;o=n&1;a[1106728]=o;p=(l&65535)>>>8;q=p&255;a[1106720]=q;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));j3(l,j,65535);m=l&255;a[1044496]=m;n=l<<16>>16!=0;o=n&1;a[1106728]=o;p=(l&65535)>>>8;q=p&255;a[1106720]=q;return}function sI(){var b=0;b=j5(xb()|0,16777215)|0;a[1044496]=(b&65535)>>>8&255;w6(b);return}function sJ(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=c[348396]|0;f=b[520836]|0;g=f&65535;h=a[e+(g+1)|0]|0;i=(h&255)<<8|(d[e+g|0]|0);a[1044496]=h;h=(c[348392]|0)+(c[348400]|0)|0;c[348392]=h;if((h|0)<(c[348406]|0)){j=f;k=j+2&65535;b[520836]=k;w6(i);return}do{j1();}while((c[348392]|0)>=(c[348406]|0));j=b[520836]|0;k=j+2&65535;b[520836]=k;w6(i);return}function sK(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=c[276674]|0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[1044496]=i;i=(c[348392]|0)+(c[348400]|0)|0;c[348392]=i;if((i|0)<(c[348406]|0)){k=g}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));k=b[520836]|0}b[520836]=k+2&65535;k=j5(j&65535|e,16777215)|0;a[1044496]=(k&65535)>>>8&255;w6(k);return}function sL(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=c[276674]|0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[1044496]=i;i=(c[348392]|0)+(c[348400]|0)|0;c[348392]=i;if((i|0)<(c[348406]|0)){k=g}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));k=b[520836]|0}b[520836]=k+2&65535;k=j&65535|e;e=(j5(k,16777215)|0)+1&65535;j=(c[348392]|0)+6|0;c[348392]=j;if((j|0)<(c[348406]|0)){j3(e,k,16777215);l=e&255;a[1044496]=l;m=e<<16>>16!=0;n=m&1;a[1106728]=n;o=(e&65535)>>>8;p=o&255;a[1106720]=p;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));j3(e,k,16777215);l=e&255;a[1044496]=l;m=e<<16>>16!=0;n=m&1;a[1106728]=n;o=(e&65535)>>>8;p=o&255;a[1106720]=p;return}function sM(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[348396]|0;f=b[520836]|0;g=f&65535;h=a[e+(g+2)|0]|0;i=(d[e+(g+1)|0]|0)<<8|(d[e+g|0]|0)|(h&255)<<16;g=(c[348399]|0)+(c[348400]|0)+(c[348392]|0)|0;c[348392]=g;if((g|0)<(c[348406]|0)){j=f}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));j=b[520836]|0}a[1044496]=h;b[520836]=j+3&65535;j=j5(i,16777215)|0;a[1044496]=(j&65535)>>>8&255;w6(j);return}function sN(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}b[520836]=h+1&65535;h=b[520831]|0;l=h+(e&255)&65535;do{if((h&255)<<24>>24!=0){e=i+6|0;c[348392]=e;if((e|0)<(j|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j=j5(l&65535,16777215)|0;a[1044496]=(j&65535)>>>8&255;l=c[276674]|j&65535;j=(c[348392]|0)+6|0;c[348392]=j;if((j|0)<(c[348406]|0)){m=b[520834]|0;n=m&65535;o=n+l|0;p=j5(o,16777215)|0;q=(p&65535)>>>8;r=q&255;a[1044496]=r;w6(p);return}do{j1();}while((c[348392]|0)>=(c[348406]|0));m=b[520834]|0;n=m&65535;o=n+l|0;p=j5(o,16777215)|0;q=(p&65535)>>>8;r=q&255;a[1044496]=r;w6(p);return}function sO(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}b[520836]=h+1&65535;h=b[520831]|0;l=h+(e&255)&65535;do{if((h&255)<<24>>24!=0){e=i+6|0;c[348392]=e;if((e|0)<(j|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j=j5(l&65535,16777215)|0;a[1044496]=(j&65535)>>>8&255;l=j5(c[276674]|j&65535,16777215)|0;a[1044496]=(l&65535)>>>8&255;w6(l);return}function sP(){var d=0,f=0,g=0,h=0,i=0;d=j0(c[260418]|0)|0;a[1044496]=d;b[520836]=(b[520836]|0)+1&65535;f=(b[520832]|0)+(d&255)&65535;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}d=j5(f&65535,16777215)|0;a[1044496]=(d&65535)>>>8&255;f=(e[520834]|0)+(d&65535)+(c[276674]|0)&16777215;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)<(c[348406]|0)){g=j5(f,16777215)|0;h=(g&65535)>>>8;i=h&255;a[1044496]=i;w6(g);return}do{j1();}while((c[348392]|0)>=(c[348406]|0));g=j5(f,16777215)|0;h=(g&65535)>>>8;i=h&255;a[1044496]=i;w6(g);return}function sQ(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=b[520836]|0;f=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=f;g=(c[348392]|0)+(c[348399]|0)|0;c[348392]=g;h=c[348406]|0;if((g|0)<(h|0)){i=d;j=g;k=h}else{do{j1();l=c[348392]|0;m=c[348406]|0;}while((l|0)>=(m|0));i=b[520836]|0;j=l;k=m}b[520836]=i+1&65535;i=b[520831]|0;m=i+(f&255)&65535;do{if((i&255)<<24>>24==0){n=j;o=k}else{f=j+6|0;c[348392]=f;if((f|0)<(k|0)){n=f;o=k;break}while(1){j1();f=c[348392]|0;l=c[348406]|0;if((f|0)<(l|0)){n=f;o=l;break}}}}while(0);k=(e[520833]|0)+(m&65535)|0;m=n+6|0;c[348392]=m;if((m|0)<(o|0)){p=k&65535;q=j5(p,65535)|0;r=(q&65535)>>>8;s=r&255;a[1044496]=s;w6(q);return}do{j1();}while((c[348392]|0)>=(c[348406]|0));p=k&65535;q=j5(p,65535)|0;r=(q&65535)>>>8;s=r&255;a[1044496]=s;w6(q);return}function sR(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;d=b[520836]|0;f=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=f;g=(c[348392]|0)+(c[348399]|0)|0;c[348392]=g;h=c[348406]|0;if((g|0)<(h|0)){i=d;j=g;k=h}else{do{j1();l=c[348392]|0;m=c[348406]|0;}while((l|0)>=(m|0));i=b[520836]|0;j=l;k=m}b[520836]=i+1&65535;i=b[520831]|0;m=i+(f&255)&65535;do{if((i&255)<<24>>24==0){n=j;o=k}else{f=j+6|0;c[348392]=f;if((f|0)<(k|0)){n=f;o=k;break}while(1){j1();f=c[348392]|0;l=c[348406]|0;if((f|0)<(l|0)){n=f;o=l;break}}}}while(0);k=(e[520833]|0)+(m&65535)|0;m=n+6|0;c[348392]=m;if((m|0)>=(o|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}o=k&65535;k=(j5(o,65535)|0)+1&65535;m=(c[348392]|0)+6|0;c[348392]=m;if((m|0)<(c[348406]|0)){j3(k,o,65535);p=k&255;a[1044496]=p;q=k<<16>>16!=0;r=q&1;a[1106728]=r;s=(k&65535)>>>8;t=s&255;a[1106720]=t;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));j3(k,o,65535);p=k&255;a[1044496]=p;q=k<<16>>16!=0;r=q&1;a[1106728]=r;s=(k&65535)>>>8;t=s&255;a[1106720]=t;return}function sS(){var b=0,c=0;b=xb()|0;c=j5((e[520834]|0)+b|0,16777215)|0;a[1044496]=(c&65535)>>>8&255;w6(c);return}function sT(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=c[276674]|0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[1044496]=i;i=(c[348392]|0)+(c[348400]|0)|0;c[348392]=i;h=c[348406]|0;if((i|0)<(h|0)){k=g;l=i;m=h}else{do{j1();n=c[348392]|0;o=c[348406]|0;}while((n|0)>=(o|0));k=b[520836]|0;l=n;m=o}b[520836]=k+2&65535;k=j&65535|e;e=l+6|0;c[348392]=e;if((e|0)<(m|0)){p=b[520834]|0;q=p&65535;r=q+k|0;s=j5(r,16777215)|0;t=(s&65535)>>>8;u=t&255;a[1044496]=u;w6(s);return}do{j1();}while((c[348392]|0)>=(c[348406]|0));p=b[520834]|0;q=p&65535;r=q+k|0;s=j5(r,16777215)|0;t=(s&65535)>>>8;u=t&255;a[1044496]=u;w6(s);return}function sU(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;e=c[276674]|0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[1044496]=i;i=(c[348392]|0)+(c[348400]|0)|0;c[348392]=i;h=c[348406]|0;if((i|0)<(h|0)){k=g;l=i;m=h}else{do{j1();n=c[348392]|0;o=c[348406]|0;}while((n|0)>=(o|0));k=b[520836]|0;l=n;m=o}b[520836]=k+2&65535;k=j&65535|e;e=l+6|0;c[348392]=e;if((e|0)<(m|0)){p=b[520833]|0;q=p&65535;r=q+k|0;s=j5(r,16777215)|0;t=(s&65535)>>>8;u=t&255;a[1044496]=u;w6(s);return}do{j1();}while((c[348392]|0)>=(c[348406]|0));p=b[520833]|0;q=p&65535;r=q+k|0;s=j5(r,16777215)|0;t=(s&65535)>>>8;u=t&255;a[1044496]=u;w6(s);return}function sV(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;f=m+6|0;c[348392]=f;if((f|0)>=(n|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}n=(e[520833]|0)+l|0;l=(j5(n,16777215)|0)+1&65535;f=(c[348392]|0)+6|0;c[348392]=f;if((f|0)<(c[348406]|0)){j3(l,n,16777215);q=l&255;a[1044496]=q;r=l<<16>>16!=0;s=r&1;a[1106728]=s;t=(l&65535)>>>8;u=t&255;a[1106720]=u;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));j3(l,n,16777215);q=l&255;a[1044496]=q;r=l<<16>>16!=0;s=r&1;a[1106728]=s;t=(l&65535)>>>8;u=t&255;a[1106720]=u;return}function sW(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=a[f+(h+2)|0]|0;j=(d[f+(h+1)|0]|0)<<8|(d[f+h|0]|0)|(i&255)<<16;h=(c[348399]|0)+(c[348400]|0)+(c[348392]|0)|0;c[348392]=h;if((h|0)<(c[348406]|0)){k=g}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));k=b[520836]|0}a[1044496]=i;b[520836]=k+3&65535;k=j5((e[520833]|0)+j|0,16777215)|0;a[1044496]=(k&65535)>>>8&255;w6(k);return}function sX(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=b[520836]|0;g=a[(c[348396]|0)+(f&65535)|0]|0;a[1044496]=g;h=(c[348392]|0)+(c[348399]|0)|0;c[348392]=h;i=c[348406]|0;if((h|0)<(i|0)){j=f;k=h;l=i}else{do{j1();m=c[348392]|0;n=c[348406]|0;}while((m|0)>=(n|0));j=b[520836]|0;k=m;l=n}b[520836]=j+1&65535;j=b[520831]|0;n=j+(g&255)&65535;do{if((j&255)<<24>>24!=0){g=k+6|0;c[348392]=g;if((g|0)<(l|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);l=j5(n&65535,16777215)|0;a[1044496]=(l&65535)>>>8&255;n=c[276674]|l&65535;do{if(((d[1041668]|0)+(n&255)|0)>>>0>255){l=(c[348392]|0)+6|0;c[348392]=l;if((l|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);l=j5((e[520834]|0)+n|0,16777215)|0;a[1044496]=(l&65535)>>>8&255;n=b[520830]|l;b[520830]=n;a[1106728]=n<<16>>16!=0|0;a[1106720]=(n&65535)>>>8&255;return}function sY(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;do{if(((d[1041668]|0)+(l&255)|0)>>>0>255){f=m+6|0;c[348392]=f;if((f|0)<(n|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);n=j5((e[520834]|0)+l|0,16777215)|0;a[1044496]=(n&65535)>>>8&255;l=b[520830]|n;b[520830]=l;a[1106728]=l<<16>>16!=0|0;a[1106720]=(l&65535)>>>8&255;return}function sZ(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;do{if(((d[1041666]|0)+(l&255)|0)>>>0>255){f=m+6|0;c[348392]=f;if((f|0)<(n|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);n=j5((e[520833]|0)+l|0,16777215)|0;a[1044496]=(n&65535)>>>8&255;l=b[520830]|n;b[520830]=l;a[1106728]=l<<16>>16!=0|0;a[1106720]=(l&65535)>>>8&255;return}function s_(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;f=m+6|0;c[348392]=f;if((f|0)>=(n|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}n=(e[520833]|0)+l|0;l=j5(n,16777215)|0;a[1106736]=(l&65535)>>>15&255;f=l<<1;m=(c[348392]|0)+6|0;c[348392]=m;if((m|0)<(c[348406]|0)){j3(f,n,16777215);q=f&255;a[1044496]=q;r=f<<16>>16!=0;s=r&1;a[1106728]=s;t=(l&65535)>>>7;u=t&255;a[1106720]=u;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));j3(f,n,16777215);q=f&255;a[1044496]=q;r=f<<16>>16!=0;s=r&1;a[1106728]=s;t=(l&65535)>>>7;u=t&255;a[1106720]=u;return}function s$(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=b[520836]|0;g=a[(c[348396]|0)+(f&65535)|0]|0;a[1044496]=g;h=(c[348392]|0)+(c[348399]|0)|0;c[348392]=h;i=c[348406]|0;if((h|0)<(i|0)){j=f;k=h;l=i}else{do{j1();m=c[348392]|0;n=c[348406]|0;}while((m|0)>=(n|0));j=b[520836]|0;k=m;l=n}b[520836]=j+1&65535;j=b[520831]|0;n=j+(g&255)&65535;do{if((j&255)<<24>>24!=0){g=k+6|0;c[348392]=g;if((g|0)<(l|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);l=j5(n&65535,16777215)|0;a[1044496]=(l&65535)>>>8&255;n=c[276674]|l&65535;do{if(((d[1041668]|0)+(n&255)|0)>>>0>255){l=(c[348392]|0)+6|0;c[348392]=l;if((l|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);l=j5((e[520834]|0)+n|0,16777215)|0;a[1044496]=(l&65535)>>>8&255;n=b[520830]&l;b[520830]=n;a[1106728]=n<<16>>16!=0|0;a[1106720]=(n&65535)>>>8&255;return}function s0(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;do{if(((d[1041668]|0)+(l&255)|0)>>>0>255){f=m+6|0;c[348392]=f;if((f|0)<(n|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);n=j5((e[520834]|0)+l|0,16777215)|0;a[1044496]=(n&65535)>>>8&255;l=b[520830]&n;b[520830]=l;a[1106728]=l<<16>>16!=0|0;a[1106720]=(l&65535)>>>8&255;return}function s1(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;do{if(((d[1041666]|0)+(l&255)|0)>>>0>255){f=m+6|0;c[348392]=f;if((f|0)<(n|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);n=j5((e[520833]|0)+l|0,16777215)|0;l=(n&65535)>>>8&255;a[1044496]=l;a[1106712]=(n&65535)>>>14&1;a[1106720]=l;a[1106728]=(b[520830]&n)<<16>>16!=0|0;return}function s2(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;do{if(((d[1041666]|0)+(l&255)|0)>>>0>255){f=m+6|0;c[348392]=f;if((f|0)<(n|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);n=j5((e[520833]|0)+l|0,16777215)|0;a[1044496]=(n&65535)>>>8&255;l=b[520830]&n;b[520830]=l;a[1106728]=l<<16>>16!=0|0;a[1106720]=(l&65535)>>>8&255;return}function s3(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;f=m+6|0;c[348392]=f;if((f|0)>=(n|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}n=(e[520833]|0)+l|0;l=j5(n,16777215)|0;f=(l&65535)<<1|(d[1106736]|0);a[1106736]=f>>>0>65535|0;m=(c[348392]|0)+6|0;c[348392]=m;if((m|0)<(c[348406]|0)){q=f&65535;j3(q,n,16777215);r=f&255;a[1044496]=r;s=f&65535;t=(s|0)!=0;u=t&1;a[1106728]=u;v=(l&65535)>>>7;w=v&255;a[1106720]=w;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));q=f&65535;j3(q,n,16777215);r=f&255;a[1044496]=r;s=f&65535;t=(s|0)!=0;u=t&1;a[1106728]=u;v=(l&65535)>>>7;w=v&255;a[1106720]=w;return}function s4(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=b[520836]|0;g=a[(c[348396]|0)+(f&65535)|0]|0;a[1044496]=g;h=(c[348392]|0)+(c[348399]|0)|0;c[348392]=h;i=c[348406]|0;if((h|0)<(i|0)){j=f;k=h;l=i}else{do{j1();m=c[348392]|0;n=c[348406]|0;}while((m|0)>=(n|0));j=b[520836]|0;k=m;l=n}b[520836]=j+1&65535;j=b[520831]|0;n=j+(g&255)&65535;do{if((j&255)<<24>>24!=0){g=k+6|0;c[348392]=g;if((g|0)<(l|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);l=j5(n&65535,16777215)|0;a[1044496]=(l&65535)>>>8&255;n=c[276674]|l&65535;do{if(((d[1041668]|0)+(n&255)|0)>>>0>255){l=(c[348392]|0)+6|0;c[348392]=l;if((l|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);l=j5((e[520834]|0)+n|0,16777215)|0;a[1044496]=(l&65535)>>>8&255;n=b[520830]|0;k=n^l;b[520830]=k;a[1106728]=n<<16>>16!=l<<16>>16|0;a[1106720]=(k&65535)>>>8&255;return}function s5(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;do{if(((d[1041668]|0)+(l&255)|0)>>>0>255){f=m+6|0;c[348392]=f;if((f|0)<(n|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);n=j5((e[520834]|0)+l|0,16777215)|0;a[1044496]=(n&65535)>>>8&255;l=b[520830]|0;m=l^n;b[520830]=m;a[1106728]=l<<16>>16!=n<<16>>16|0;a[1106720]=(m&65535)>>>8&255;return}function s6(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;do{if(((d[1041666]|0)+(l&255)|0)>>>0>255){f=m+6|0;c[348392]=f;if((f|0)<(n|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);n=j5((e[520833]|0)+l|0,16777215)|0;a[1044496]=(n&65535)>>>8&255;l=b[520830]|0;m=l^n;b[520830]=m;a[1106728]=l<<16>>16!=n<<16>>16|0;a[1106720]=(m&65535)>>>8&255;return}function s7(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;f=m+6|0;c[348392]=f;if((f|0)>=(n|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}n=(e[520833]|0)+l|0;l=j5(n,16777215)|0;a[1106736]=l&1;f=(l&65535)>>>1;m=(c[348392]|0)+6|0;c[348392]=m;if((m|0)<(c[348406]|0)){j3(f,n,16777215);q=f&255;a[1044496]=q;r=f<<16>>16!=0;s=r&1;a[1106728]=s;t=(l&65535)>>>9;u=t&255;a[1106720]=u;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));j3(f,n,16777215);q=f&255;a[1044496]=q;r=f<<16>>16!=0;s=r&1;a[1106728]=s;t=(l&65535)>>>9;u=t&255;a[1106720]=u;return}function s8(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=b[520836]|0;g=a[(c[348396]|0)+(f&65535)|0]|0;a[1044496]=g;h=(c[348392]|0)+(c[348399]|0)|0;c[348392]=h;i=c[348406]|0;if((h|0)<(i|0)){j=f;k=h;l=i}else{do{j1();m=c[348392]|0;n=c[348406]|0;}while((m|0)>=(n|0));j=b[520836]|0;k=m;l=n}b[520836]=j+1&65535;j=b[520831]|0;n=j+(g&255)&65535;do{if((j&255)<<24>>24!=0){g=k+6|0;c[348392]=g;if((g|0)<(l|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);l=j5(n&65535,16777215)|0;a[1044496]=(l&65535)>>>8&255;n=c[276674]|l&65535;do{if(((d[1041668]|0)+(n&255)|0)>>>0>255){l=(c[348392]|0)+6|0;c[348392]=l;if((l|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);l=j5((e[520834]|0)+n|0,16777215)|0;a[1044496]=(l&65535)>>>8&255;w9(l);return}function s9(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;do{if(((d[1041668]|0)+(l&255)|0)>>>0>255){f=m+6|0;c[348392]=f;if((f|0)<(n|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);n=j5((e[520834]|0)+l|0,16777215)|0;a[1044496]=(n&65535)>>>8&255;w9(n);return}function ta(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;do{if(((d[1041666]|0)+(l&255)|0)>>>0>255){f=m+6|0;c[348392]=f;if((f|0)<(n|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);n=j5((e[520833]|0)+l|0,16777215)|0;a[1044496]=(n&65535)>>>8&255;w9(n);return}function tb(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;f=m+6|0;c[348392]=f;if((f|0)>=(n|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}n=(e[520833]|0)+l|0;l=j5(n,16777215)|0;f=(d[1106736]|0)<<16|l&65535;a[1106736]=l&1;l=f>>>1;m=(c[348392]|0)+6|0;c[348392]=m;if((m|0)<(c[348406]|0)){q=l&65535;j3(q,n,16777215);r=l&255;a[1044496]=r;s=l&65535;t=(s|0)!=0;u=t&1;a[1106728]=u;v=f>>>9;w=v&255;a[1106720]=w;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));q=l&65535;j3(q,n,16777215);r=l&255;a[1044496]=r;s=l&65535;t=(s|0)!=0;u=t&1;a[1106728]=u;v=f>>>9;w=v&255;a[1106720]=w;return}function tc(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}b[520836]=h+1&65535;h=b[520831]|0;l=h+(e&255)&65535;do{if((h&255)<<24>>24!=0){e=i+6|0;c[348392]=e;if((e|0)<(j|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j=(j5(l&65535,16777215)|0)&65535;l=c[276674]|j;j=(c[348392]|0)+6|0;c[348392]=j;if((j|0)<(c[348406]|0)){m=b[520834]|0;n=m&65535;o=n+l|0;p=b[520830]|0;w7(p,o,16777215);q=a[1041661|0]|0;a[1044496]=q;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));m=b[520834]|0;n=m&65535;o=n+l|0;p=b[520830]|0;w7(p,o,16777215);q=a[1041661|0]|0;a[1044496]=q;return}function td(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=c[276674]|0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=(d[f+(h+1)|0]|0)<<8|(d[f+h|0]|0);h=(c[348392]|0)+(c[348400]|0)|0;c[348392]=h;f=c[348406]|0;if((h|0)<(f|0)){j=g;k=h;l=f}else{do{j1();m=c[348392]|0;n=c[348406]|0;}while((m|0)>=(n|0));j=b[520836]|0;k=m;l=n}b[520836]=j+2&65535;j=i&65535|e;e=k+6|0;c[348392]=e;if((e|0)<(l|0)){o=b[520834]|0;p=o&65535;q=p+j|0;r=b[520830]|0;w7(r,q,16777215);s=a[1041661|0]|0;a[1044496]=s;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));o=b[520834]|0;p=o&65535;q=p+j|0;r=b[520830]|0;w7(r,q,16777215);s=a[1041661|0]|0;a[1044496]=s;return}function te(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=c[276674]|0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=(d[f+(h+1)|0]|0)<<8|(d[f+h|0]|0);h=(c[348392]|0)+(c[348400]|0)|0;c[348392]=h;f=c[348406]|0;if((h|0)<(f|0)){j=g;k=h;l=f}else{do{j1();m=c[348392]|0;n=c[348406]|0;}while((m|0)>=(n|0));j=b[520836]|0;k=m;l=n}b[520836]=j+2&65535;j=i&65535|e;e=k+6|0;c[348392]=e;if((e|0)<(l|0)){o=b[520833]|0;p=o&65535;q=p+j|0;r=b[520830]|0;w7(r,q,16777215);s=a[1041661|0]|0;a[1044496]=s;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));o=b[520833]|0;p=o&65535;q=p+j|0;r=b[520830]|0;w7(r,q,16777215);s=a[1041661|0]|0;a[1044496]=s;return}function tf(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=c[276674]|0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=(d[f+(h+1)|0]|0)<<8|(d[f+h|0]|0);h=(c[348392]|0)+(c[348400]|0)|0;c[348392]=h;f=c[348406]|0;if((h|0)<(f|0)){j=g;k=h;l=f}else{do{j1();m=c[348392]|0;n=c[348406]|0;}while((m|0)>=(n|0));j=b[520836]|0;k=m;l=n}b[520836]=j+2&65535;j=i&65535|e;e=k+6|0;c[348392]=e;if((e|0)<(l|0)){o=b[520833]|0;p=o&65535;q=p+j|0;w7(0,q,16777215);a[1044496]=0;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));o=b[520833]|0;p=o&65535;q=p+j|0;w7(0,q,16777215);a[1044496]=0;return}function tg(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=b[520836]|0;g=a[(c[348396]|0)+(f&65535)|0]|0;a[1044496]=g;h=(c[348392]|0)+(c[348399]|0)|0;c[348392]=h;i=c[348406]|0;if((h|0)<(i|0)){j=f;k=h;l=i}else{do{j1();m=c[348392]|0;n=c[348406]|0;}while((m|0)>=(n|0));j=b[520836]|0;k=m;l=n}b[520836]=j+1&65535;j=b[520831]|0;n=j+(g&255)&65535;do{if((j&255)<<24>>24!=0){g=k+6|0;c[348392]=g;if((g|0)<(l|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);l=j5(n&65535,16777215)|0;a[1044496]=(l&65535)>>>8&255;n=c[276674]|l&65535;do{if(((d[1041668]|0)+(n&255)|0)>>>0>255){l=(c[348392]|0)+6|0;c[348392]=l;if((l|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);l=j5((e[520834]|0)+n|0,16777215)|0;n=(l&65535)>>>8&255;a[1044496]=n;b[520830]=l;a[1106728]=l<<16>>16!=0|0;a[1106720]=n;return}function th(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;do{if(((d[1041668]|0)+(l&255)|0)>>>0>255){f=m+6|0;c[348392]=f;if((f|0)<(n|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);n=j5((e[520834]|0)+l|0,16777215)|0;l=(n&65535)>>>8&255;a[1044496]=l;b[520830]=n;a[1106728]=n<<16>>16!=0|0;a[1106720]=l;return}function ti(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;do{if(((d[1041666]|0)+(l&255)|0)>>>0>255){f=m+6|0;c[348392]=f;if((f|0)<(n|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);n=j5((e[520833]|0)+l|0,16777215)|0;l=(n&65535)>>>8&255;a[1044496]=l;b[520830]=n;a[1106728]=n<<16>>16!=0|0;a[1106720]=l;return}function tj(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=b[520836]|0;g=a[(c[348396]|0)+(f&65535)|0]|0;a[1044496]=g;h=(c[348392]|0)+(c[348399]|0)|0;c[348392]=h;i=c[348406]|0;if((h|0)<(i|0)){j=f;k=h;l=i}else{do{j1();m=c[348392]|0;n=c[348406]|0;}while((m|0)>=(n|0));j=b[520836]|0;k=m;l=n}b[520836]=j+1&65535;j=b[520831]|0;n=j+(g&255)&65535;do{if((j&255)<<24>>24!=0){g=k+6|0;c[348392]=g;if((g|0)<(l|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);l=j5(n&65535,16777215)|0;a[1044496]=(l&65535)>>>8&255;n=c[276674]|l&65535;do{if(((d[1041668]|0)+(n&255)|0)>>>0>255){l=(c[348392]|0)+6|0;c[348392]=l;if((l|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);l=j5((e[520834]|0)+n|0,16777215)|0;a[1044496]=(l&65535)>>>8&255;n=(e[520830]|0)-(l&65535)|0;a[1106736]=n>>>31&255^1;a[1106728]=(n&65535|0)!=0|0;a[1106720]=n>>>8&255;return}function tk(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;do{if(((d[1041668]|0)+(l&255)|0)>>>0>255){f=m+6|0;c[348392]=f;if((f|0)<(n|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);n=j5((e[520834]|0)+l|0,16777215)|0;a[1044496]=(n&65535)>>>8&255;l=(e[520830]|0)-(n&65535)|0;a[1106736]=l>>>31&255^1;a[1106728]=(l&65535|0)!=0|0;a[1106720]=l>>>8&255;return}function tl(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;do{if(((d[1041666]|0)+(l&255)|0)>>>0>255){f=m+6|0;c[348392]=f;if((f|0)<(n|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);n=j5((e[520833]|0)+l|0,16777215)|0;a[1044496]=(n&65535)>>>8&255;l=(e[520830]|0)-(n&65535)|0;a[1106736]=l>>>31&255^1;a[1106728]=(l&65535|0)!=0|0;a[1106720]=l>>>8&255;return}function tm(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;f=m+6|0;c[348392]=f;if((f|0)>=(n|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}n=(e[520833]|0)+l|0;l=(j5(n,16777215)|0)-1&65535;f=(c[348392]|0)+6|0;c[348392]=f;if((f|0)<(c[348406]|0)){j3(l,n,16777215);q=l&255;a[1044496]=q;r=l<<16>>16!=0;s=r&1;a[1106728]=s;t=(l&65535)>>>8;u=t&255;a[1106720]=u;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));j3(l,n,16777215);q=l&255;a[1044496]=q;r=l<<16>>16!=0;s=r&1;a[1106728]=s;t=(l&65535)>>>8;u=t&255;a[1106720]=u;return}function tn(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=b[520836]|0;g=a[(c[348396]|0)+(f&65535)|0]|0;a[1044496]=g;h=(c[348392]|0)+(c[348399]|0)|0;c[348392]=h;i=c[348406]|0;if((h|0)<(i|0)){j=f;k=h;l=i}else{do{j1();m=c[348392]|0;n=c[348406]|0;}while((m|0)>=(n|0));j=b[520836]|0;k=m;l=n}b[520836]=j+1&65535;j=b[520831]|0;n=j+(g&255)&65535;do{if((j&255)<<24>>24!=0){g=k+6|0;c[348392]=g;if((g|0)<(l|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);l=j5(n&65535,16777215)|0;a[1044496]=(l&65535)>>>8&255;n=c[276674]|l&65535;do{if(((d[1041668]|0)+(n&255)|0)>>>0>255){l=(c[348392]|0)+6|0;c[348392]=l;if((l|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);l=j5((e[520834]|0)+n|0,16777215)|0;a[1044496]=(l&65535)>>>8&255;w6(l);return}function to(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;do{if(((d[1041668]|0)+(l&255)|0)>>>0>255){f=m+6|0;c[348392]=f;if((f|0)<(n|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);n=j5((e[520834]|0)+l|0,16777215)|0;a[1044496]=(n&65535)>>>8&255;w6(n);return}function tp(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;do{if(((d[1041666]|0)+(l&255)|0)>>>0>255){f=m+6|0;c[348392]=f;if((f|0)<(n|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);n=j5((e[520833]|0)+l|0,16777215)|0;a[1044496]=(n&65535)>>>8&255;w6(n);return}function tq(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;f=m+6|0;c[348392]=f;if((f|0)>=(n|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}n=(e[520833]|0)+l|0;l=(j5(n,16777215)|0)+1&65535;f=(c[348392]|0)+6|0;c[348392]=f;if((f|0)<(c[348406]|0)){j3(l,n,16777215);q=l&255;a[1044496]=q;r=l<<16>>16!=0;s=r&1;a[1106728]=s;t=(l&65535)>>>8;u=t&255;a[1106720]=u;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));j3(l,n,16777215);q=l&255;a[1044496]=q;r=l<<16>>16!=0;s=r&1;a[1106728]=s;t=(l&65535)>>>8;u=t&255;a[1106720]=u;return}function tr(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=(a[1041658]&32)==0;e=j0(c[260418]|0)|0;a[1044496]=e;b[520836]=(b[520836]|0)+1&65535;f=b[520831]|0;g=f+(e&255)&65535;do{if((f&255)<<24>>24!=0){e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);f=g&255;e=(g&65535)>>>8;h=e&255;i=b[520829]|0;do{if((i&256)==0){j=2925}else{if((a[1041662]|0)!=0){j=2925;break}k=(a[1041666]|0)+f&255;l=h}}while(0);if((j|0)==2925){j=(b[520833]|0)+(e<<8|g&255)&65535;k=j&255;l=(j&65535)>>>8&255}j=(c[348392]|0)+6|0;c[348392]=j;if((j|0)<(c[348406]|0)){m=i}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));m=b[520829]|0}if((m&256)==0){n=65535}else{n=(a[1041662]|0)!=0?65535:255}m=j5(((l&255)<<8|k&255)&65535,n)|0;a[1044496]=(m&65535)>>>8&255;n=c[276674]|m&65535;if(d){d=j5(n,16777215)|0;a[1044496]=(d&65535)>>>8&255;m=b[520830]|d;b[520830]=m;a[1106728]=m<<16>>16!=0|0;o=(m&65535)>>>8&255;a[1106720]=o;return}else{m=j0(n)|0;a[1044496]=m;n=a[1041660]|m;a[1041660]=n;a[1106728]=n;o=n;a[1106720]=o;return}}function ts(){var d=0,e=0,f=0,g=0;d=(a[1041658]&32)==0;e=j0(c[260418]|0)|0;a[1044496]=e;b[520836]=(b[520836]|0)+1&65535;f=(b[520832]|0)+(e&255)&65535;e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}e=f&65535;if(d){d=j5(e,16777215)|0;a[1044496]=(d&65535)>>>8&255;f=b[520830]|d;b[520830]=f;a[1106728]=f<<16>>16!=0|0;g=(f&65535)>>>8&255;a[1106720]=g;return}else{f=j0(e)|0;a[1044496]=f;e=a[1041660]|f;a[1041660]=e;a[1106728]=e;g=e;a[1106720]=g;return}}function tt(){var d=0,e=0,f=0,g=0,h=0;d=(a[1041658]&32)==0;e=j0(c[260418]|0)|0;a[1044496]=e;b[520836]=(b[520836]|0)+1&65535;f=b[520831]|0;g=f+(e&255)&65535;do{if((f&255)<<24>>24!=0){e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);f=g&65535;if(d){d=j5(f,65535)|0;g=b[520830]|0;a[1106728]=(g&d)<<16>>16!=0|0;e=g|d;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}j3(e,f,65535);h=e&255;a[1044496]=h;return}else{e=j0(f)|0;d=a[1041660]|0;a[1106728]=d&e;g=d|e;e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}j2(g,f);h=g;a[1044496]=h;return}}function tu(){var d=0,e=0,f=0,g=0,h=0;d=(a[1041658]&32)==0;e=j0(c[260418]|0)|0;a[1044496]=e;b[520836]=(b[520836]|0)+1&65535;f=b[520831]|0;g=f+(e&255)&65535;do{if((f&255)<<24>>24!=0){e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);f=g&65535;if(d){d=j5(f,65535)|0;a[1044496]=(d&65535)>>>8&255;g=b[520830]|d;b[520830]=g;a[1106728]=g<<16>>16!=0|0;h=(g&65535)>>>8&255;a[1106720]=h;return}else{g=j0(f)|0;a[1044496]=g;f=a[1041660]|g;a[1041660]=f;a[1106728]=f;h=f;a[1106720]=h;return}}function tv(){var d=0,e=0,f=0,g=0,h=0;d=(a[1041658]&32)==0;e=j0(c[260418]|0)|0;a[1044496]=e;b[520836]=(b[520836]|0)+1&65535;f=b[520831]|0;g=f+(e&255)&65535;do{if((f&255)<<24>>24!=0){e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);f=g&65535;if(d){d=j5(f,65535)|0;a[1106736]=(d&65535)>>>15&255;g=d<<1;e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}j3(g,f,65535);a[1044496]=g&255;a[1106728]=g<<16>>16!=0|0;h=(d&65535)>>>7&255;a[1106720]=h;return}else{d=j0(f)|0;a[1106736]=(d&255)>>>7;g=d<<1;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}j2(g,f);a[1044496]=g;a[1106728]=g;h=g;a[1106720]=h;return}}function tw(){var d=0,e=0,f=0,g=0,h=0;d=(a[1041658]&32)==0;e=j0(c[260418]|0)|0;a[1044496]=e;b[520836]=(b[520836]|0)+1&65535;f=b[520831]|0;g=f+(e&255)&65535;do{if((f&255)<<24>>24!=0){e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);f=g&65535;g=j5(f,16777215)|0;a[1044496]=(g&65535)>>>8&255;e=j0(f+2|0)|0;a[1044496]=e;f=(e&255)<<16|g&65535;if(d){d=j5(f,16777215)|0;a[1044496]=(d&65535)>>>8&255;g=b[520830]|d;b[520830]=g;a[1106728]=g<<16>>16!=0|0;h=(g&65535)>>>8&255;a[1106720]=h;return}else{g=j0(f)|0;a[1044496]=g;f=a[1041660]|g;a[1041660]=f;a[1106728]=f;h=f;a[1106720]=h;return}}function tx(){var d=0,e=0,f=0,g=0;a[1041658]=a[1041658]&60|a[1106736]|a[1106720]&-128|((a[1106728]|0)==0)<<1|a[1106712]<<6;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}d=b[520829]|0;e=d&255;f=b[520832]|0;if((d&256)==0){b[520832]=f-1&65535;j2(e,f&65535);g=a[1041658]|0;a[1044496]=g;return}else{j2(e,f&65535);a[1041664]=(a[1041664]|0)-1&255;g=a[1041658]|0;a[1044496]=g;return}}function ty(){var d=0,e=0,f=0,g=0;d=c[260418]|0;if((a[1041658]&32)==0){e=j5(d,65535)|0;a[1044496]=(e&65535)>>>8&255;b[520836]=(b[520836]|0)+2&65535;f=b[520830]|e;b[520830]=f;a[1106728]=f<<16>>16!=0|0;g=(f&65535)>>>8&255;a[1106720]=g;return}else{f=j0(d)|0;a[1044496]=f;b[520836]=(b[520836]|0)+1&65535;d=a[1041660]|f;a[1041660]=d;a[1106728]=d;g=d;a[1106720]=g;return}}function tz(){var e=0,f=0,g=0;e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}if((a[1041658]&32)==0){a[1106736]=(d[1041661|0]|0)>>>7;e=b[520830]|0;f=e<<1;b[520830]=f;a[1106728]=f<<16>>16!=0|0;g=(e&65535)>>>7&255;a[1106720]=g;return}else{e=a[1041660]|0;a[1106736]=(e&255)>>>7;f=e<<1;a[1041660]=f;a[1106728]=f;g=f;a[1106720]=g;return}}function tA(){var d=0;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}j3(b[520831]|0,(e[520832]|0)-1|0,65535);b[520832]=(b[520832]|0)-2&65535;a[1044496]=a[1041662]|0;if((b[520829]&256)==0){return}a[1041665|0]=1;return}function tB(){var d=0,e=0,f=0,g=0,h=0;d=(a[1041658]&32)==0;e=c[276674]|0;f=j5(c[260418]|0,65535)|0;a[1044496]=(f&65535)>>>8&255;b[520836]=(b[520836]|0)+2&65535;g=f&65535|e;if(d){d=j5(g,65535)|0;e=b[520830]|0;a[1106728]=(e&d)<<16>>16!=0|0;f=e|d;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}j3(f,g,65535);h=f&255;a[1044496]=h;return}else{f=j0(g)|0;d=a[1041660]|0;a[1106728]=d&f;e=d|f;f=(c[348392]|0)+6|0;c[348392]=f;if((f|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}j2(e,g);h=e;a[1044496]=h;return}}function tC(){var d=0,e=0,f=0,g=0,h=0;d=(a[1041658]&32)==0;e=c[276674]|0;f=j5(c[260418]|0,65535)|0;a[1044496]=(f&65535)>>>8&255;b[520836]=(b[520836]|0)+2&65535;g=f&65535|e;if(d){d=j5(g,16777215)|0;a[1044496]=(d&65535)>>>8&255;e=b[520830]|d;b[520830]=e;a[1106728]=e<<16>>16!=0|0;h=(e&65535)>>>8&255;a[1106720]=h;return}else{e=j0(g)|0;a[1044496]=e;g=a[1041660]|e;a[1041660]=g;a[1106728]=g;h=g;a[1106720]=h;return}}function tD(){var d=0,e=0,f=0,g=0,h=0;d=(a[1041658]&32)==0;e=c[276674]|0;f=j5(c[260418]|0,65535)|0;a[1044496]=(f&65535)>>>8&255;b[520836]=(b[520836]|0)+2&65535;g=f&65535|e;if(d){d=j5(g,16777215)|0;a[1106736]=(d&65535)>>>15&255;e=d<<1;f=(c[348392]|0)+6|0;c[348392]=f;if((f|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}j3(e,g,16777215);a[1044496]=e&255;a[1106728]=e<<16>>16!=0|0;h=(d&65535)>>>7&255;a[1106720]=h;return}else{d=j0(g)|0;a[1106736]=(d&255)>>>7;e=d<<1;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}j2(e,g);a[1044496]=e;a[1106728]=e;h=e;a[1106720]=h;return}}function tE(){var d=0,e=0,f=0,g=0,h=0;d=(a[1041658]&32)==0;e=j5(c[260418]|0,65535)|0;a[1044496]=(e&65535)>>>8&255;b[520836]=(b[520836]|0)+2&65535;f=j0(c[260418]|0)|0;a[1044496]=f;b[520836]=(b[520836]|0)+1&65535;g=(f&255)<<16|e&65535;if(d){d=j5(g,16777215)|0;a[1044496]=(d&65535)>>>8&255;e=b[520830]|d;b[520830]=e;a[1106728]=e<<16>>16!=0|0;h=(e&65535)>>>8&255;a[1106720]=h;return}else{e=j0(g)|0;a[1044496]=e;g=a[1041660]|e;a[1041660]=g;a[1106728]=g;h=g;a[1106720]=h;return}}function tF(){var e=0,f=0,g=0,h=0,i=0,j=0;e=j0(c[260418]|0)|0;a[1044496]=e;f=(b[520836]|0)+1&65535;b[520836]=f;g=f+(e<<24>>24)&65535;e=(g&65535)>>>8;if((a[1106720]|0)<0){return}f=(c[348392]|0)+6|0;c[348392]=f;h=c[348406]|0;if((f|0)<(h|0)){i=f;j=h}else{while(1){j1();h=c[348392]|0;f=c[348406]|0;if((h|0)<(f|0)){i=h;j=f;break}}}do{if((b[520829]&256)!=0){if((d[1041673|0]|0)==(e&65535|0)){break}f=i+6|0;c[348392]=f;if((f|0)<(j|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j=e<<8;e=j|g&255;if(((b[520836]^j)&65535)>4095){j4((c[276676]|0)+(e&65535)|0);return}else{b[520836]=e;return}}function tG(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=(a[1041658]&32)==0;g=j0(c[260418]|0)|0;a[1044496]=g;b[520836]=(b[520836]|0)+1&65535;h=b[520831]|0;i=h+(g&255)&65535;do{if((h&255)<<24>>24!=0){g=(c[348392]|0)+6|0;c[348392]=g;if((g|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);if((b[520829]&256)==0){j=65535}else{j=(a[1041662]|0)!=0?65535:255}h=j5(i&65535,j)|0;a[1044496]=(h&65535)>>>8&255;j=c[276674]|h&65535;if((a[1041658]&16)==0){k=3072}else{if(((d[1041668]|0)+(j&255)|0)>>>0>255){k=3072}}do{if((k|0)==3072){h=(c[348392]|0)+6|0;c[348392]=h;if((h|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);k=(e[520834]|0)+j|0;if(f){f=j5(k,16777215)|0;a[1044496]=(f&65535)>>>8&255;j=b[520830]|f;b[520830]=j;a[1106728]=j<<16>>16!=0|0;l=(j&65535)>>>8&255;a[1106720]=l;return}else{j=j0(k)|0;a[1044496]=j;k=a[1041660]|j;a[1041660]=k;a[1106728]=k;l=k;a[1106720]=l;return}}function tH(){var d=0,e=0,f=0,g=0,h=0,i=0;d=(a[1041658]&32)==0;e=j0(c[260418]|0)|0;a[1044496]=e;b[520836]=(b[520836]|0)+1&65535;f=b[520831]|0;g=f+(e&255)&65535;do{if((f&255)<<24>>24!=0){e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);if((b[520829]&256)==0){h=65535}else{h=(a[1041662]|0)!=0?65535:255}f=j5(g&65535,h)|0;a[1044496]=(f&65535)>>>8&255;h=c[276674]|f&65535;if(d){d=j5(h,16777215)|0;a[1044496]=(d&65535)>>>8&255;f=b[520830]|d;b[520830]=f;a[1106728]=f<<16>>16!=0|0;i=(f&65535)>>>8&255;a[1106720]=i;return}else{f=j0(h)|0;a[1044496]=f;h=a[1041660]|f;a[1041660]=h;a[1106728]=h;i=h;a[1106720]=i;return}}function tI(){var d=0,f=0,g=0,h=0;d=(a[1041658]&32)==0;f=j0(c[260418]|0)|0;a[1044496]=f;b[520836]=(b[520836]|0)+1&65535;g=(b[520832]|0)+(f&255)&65535;f=(c[348392]|0)+6|0;c[348392]=f;if((f|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}f=j5(g&65535,16777215)|0;a[1044496]=(f&65535)>>>8&255;g=(e[520834]|0)+(f&65535)+(c[276674]|0)&16777215;f=(c[348392]|0)+6|0;c[348392]=f;if((f|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}if(d){d=j5(g,16777215)|0;a[1044496]=(d&65535)>>>8&255;f=b[520830]|d;b[520830]=f;a[1106728]=f<<16>>16!=0|0;h=(f&65535)>>>8&255;a[1106720]=h;return}else{f=j0(g)|0;a[1044496]=f;g=a[1041660]|f;a[1041660]=g;a[1106728]=g;h=g;a[1106720]=h;return}}function tJ(){var d=0,e=0,f=0,g=0,h=0;d=(a[1041658]&32)==0;e=j0(c[260418]|0)|0;a[1044496]=e;b[520836]=(b[520836]|0)+1&65535;f=b[520831]|0;g=f+(e&255)&65535;do{if((f&255)<<24>>24!=0){e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);f=g&65535;if(d){d=j5(f,65535)|0;g=b[520830]|0;a[1106728]=(g&d)<<16>>16!=0|0;e=d&~g;g=(c[348392]|0)+6|0;c[348392]=g;if((g|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}j3(e,f,65535);h=e&255;a[1044496]=h;return}else{e=j0(f)|0;g=a[1041660]|0;a[1106728]=g&e;d=e&~g;g=(c[348392]|0)+6|0;c[348392]=g;if((g|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}j2(d,f);h=d;a[1044496]=h;return}}function tK(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=(a[1041658]&32)==0;e=j0(c[260418]|0)|0;a[1044496]=e;b[520836]=(b[520836]|0)+1&65535;f=b[520831]|0;g=f+(e&255)&65535;do{if((f&255)<<24>>24!=0){e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);f=g&255;e=(g&65535)>>>8;h=e&255;do{if((b[520829]&256)==0){i=3119}else{if((a[1041662]|0)!=0){i=3119;break}j=(a[1041666]|0)+f&255;k=h}}while(0);if((i|0)==3119){i=(b[520833]|0)+(e<<8|g&255)&65535;j=i&255;k=(i&65535)>>>8&255}i=(c[348392]|0)+6|0;c[348392]=i;if((i|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}i=((k&255)<<8|j&255)&65535;if(d){d=j5(i,65535)|0;a[1044496]=(d&65535)>>>8&255;j=b[520830]|d;b[520830]=j;a[1106728]=j<<16>>16!=0|0;l=(j&65535)>>>8&255;a[1106720]=l;return}else{j=j0(i)|0;a[1044496]=j;i=a[1041660]|j;a[1041660]=i;a[1106728]=i;l=i;a[1106720]=l;return}}function tL(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=(a[1041658]&32)==0;e=j0(c[260418]|0)|0;a[1044496]=e;b[520836]=(b[520836]|0)+1&65535;f=b[520831]|0;g=f+(e&255)&65535;do{if((f&255)<<24>>24!=0){e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);f=g&255;e=(g&65535)>>>8;h=e&255;do{if((b[520829]&256)==0){i=3134}else{if((a[1041662]|0)!=0){i=3134;break}j=(a[1041666]|0)+f&255;k=h}}while(0);if((i|0)==3134){i=(b[520833]|0)+(e<<8|g&255)&65535;j=i&255;k=(i&65535)>>>8&255}i=(c[348392]|0)+6|0;c[348392]=i;if((i|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}i=((k&255)<<8|j&255)&65535;if(d){d=j5(i,65535)|0;a[1106736]=(d&65535)>>>15&255;j=d<<1;k=(c[348392]|0)+6|0;c[348392]=k;if((k|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}j3(j,i,65535);a[1044496]=j&255;a[1106728]=j<<16>>16!=0|0;l=(d&65535)>>>7&255;a[1106720]=l;return}else{d=j0(i)|0;a[1106736]=(d&255)>>>7;j=d<<1;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}j2(j,i);a[1044496]=j;a[1106728]=j;l=j;a[1106720]=l;return}}function tM(){var d=0,f=0,g=0,h=0,i=0;d=(a[1041658]&32)==0;f=j0(c[260418]|0)|0;a[1044496]=f;b[520836]=(b[520836]|0)+1&65535;g=b[520831]|0;h=g+(f&255)&65535;do{if((g&255)<<24>>24!=0){f=(c[348392]|0)+6|0;c[348392]=f;if((f|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);g=h&65535;h=j5(g,16777215)|0;a[1044496]=(h&65535)>>>8&255;f=j0(g+2|0)|0;a[1044496]=f;g=((f&255)<<16|h&65535)+(e[520834]|0)|0;if(d){d=j5(g,16777215)|0;a[1044496]=(d&65535)>>>8&255;h=b[520830]|d;b[520830]=h;a[1106728]=h<<16>>16!=0|0;i=(h&65535)>>>8&255;a[1106720]=i;return}else{h=j0(g)|0;a[1044496]=h;g=a[1041660]|h;a[1041660]=g;a[1106728]=g;i=g;a[1106720]=i;return}}function tN(){var f=0,g=0,h=0,i=0,j=0,k=0;f=(a[1041658]&32)==0;g=c[276674]|0;h=j5(c[260418]|0,65535)|0;a[1044496]=(h&65535)>>>8&255;b[520836]=(b[520836]|0)+2&65535;i=h&65535|g;if((a[1041658]&16)==0){j=3159}else{if(((d[1041668]|0)+(i&255)|0)>>>0>255){j=3159}}do{if((j|0)==3159){g=(c[348392]|0)+6|0;c[348392]=g;if((g|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j=(e[520834]|0)+i|0;if(f){f=j5(j,16777215)|0;a[1044496]=(f&65535)>>>8&255;i=b[520830]|f;b[520830]=i;a[1106728]=i<<16>>16!=0|0;k=(i&65535)>>>8&255;a[1106720]=k;return}else{i=j0(j)|0;a[1044496]=i;j=a[1041660]|i;a[1041660]=j;a[1106728]=j;k=j;a[1106720]=k;return}}function tO(){var d=0,e=0;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}if((a[1041658]&32)==0){d=(b[520830]|0)+1&65535;b[520830]=d;a[1106728]=d<<16>>16!=0|0;e=(d&65535)>>>8&255;a[1106720]=e;return}else{d=(a[1041660]|0)+1&255;a[1041660]=d;a[1106728]=d;e=d;a[1106720]=e;return}}function tP(){var d=0,e=0,f=0,g=0,h=0;d=(a[1041658]&32)==0;e=c[276674]|0;f=j5(c[260418]|0,65535)|0;a[1044496]=(f&65535)>>>8&255;b[520836]=(b[520836]|0)+2&65535;g=f&65535|e;if(d){d=j5(g,65535)|0;e=b[520830]|0;a[1106728]=(e&d)<<16>>16!=0|0;f=d&~e;e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}j3(f,g,65535);h=f&255;a[1044496]=h;return}else{f=j0(g)|0;e=a[1041660]|0;a[1106728]=e&f;d=f&~e;e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}j2(d,g);h=d;a[1044496]=h;return}}function tQ(){var f=0,g=0,h=0,i=0,j=0,k=0;f=(a[1041658]&32)==0;g=c[276674]|0;h=j5(c[260418]|0,65535)|0;a[1044496]=(h&65535)>>>8&255;b[520836]=(b[520836]|0)+2&65535;i=h&65535|g;if((a[1041658]&16)==0){j=3187}else{if(((d[1041666]|0)+(i&255)|0)>>>0>255){j=3187}}do{if((j|0)==3187){g=(c[348392]|0)+6|0;c[348392]=g;if((g|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j=(e[520833]|0)+i|0;if(f){f=j5(j,16777215)|0;a[1044496]=(f&65535)>>>8&255;i=b[520830]|f;b[520830]=i;a[1106728]=i<<16>>16!=0|0;k=(i&65535)>>>8&255;a[1106720]=k;return}else{i=j0(j)|0;a[1044496]=i;j=a[1041660]|i;a[1041660]=j;a[1106728]=j;k=j;a[1106720]=k;return}}function tR(){var d=0,f=0,g=0,h=0,i=0;d=(a[1041658]&32)==0;f=c[276674]|0;g=j5(c[260418]|0,65535)|0;a[1044496]=(g&65535)>>>8&255;b[520836]=(b[520836]|0)+2&65535;h=g&65535|f;f=(c[348392]|0)+6|0;c[348392]=f;if((f|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}f=(e[520833]|0)+h|0;if(d){d=j5(f,16777215)|0;a[1106736]=(d&65535)>>>15&255;h=d<<1;g=(c[348392]|0)+6|0;c[348392]=g;if((g|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}j3(h,f,16777215);a[1044496]=h&255;a[1106728]=h<<16>>16!=0|0;i=(d&65535)>>>7&255;a[1106720]=i;return}else{d=j0(f)|0;a[1106736]=(d&255)>>>7;h=d<<1;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}j2(h,f);a[1044496]=h;a[1106728]=h;i=h;a[1106720]=i;return}}function tS(){var d=0,f=0,g=0,h=0,i=0;d=(a[1041658]&32)==0;f=j5(c[260418]|0,65535)|0;a[1044496]=(f&65535)>>>8&255;b[520836]=(b[520836]|0)+2&65535;g=j0(c[260418]|0)|0;a[1044496]=g;b[520836]=(b[520836]|0)+1&65535;h=(e[520833]|0)+((g&255)<<16|f&65535)|0;if(d){d=j5(h,16777215)|0;a[1044496]=(d&65535)>>>8&255;f=b[520830]|d;b[520830]=f;a[1106728]=f<<16>>16!=0|0;i=(f&65535)>>>8&255;a[1106720]=i;return}else{f=j0(h)|0;a[1044496]=f;h=a[1041660]|f;a[1041660]=h;a[1106728]=h;i=h;a[1106720]=i;return}}function tT(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0;d=c[276674]|0;f=j5(c[260418]|0,65535)|0;b[520836]=(b[520836]|0)+2&65535;g=f&65535;f=(c[348392]|0)+6|0;c[348392]=f;if((f|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}if((b[520829]&256)==0){j3((b[520836]|0)-1&65535,(e[520832]|0)-1|0,65535);b[520832]=(b[520832]|0)-2&65535;h=c[276676]|0;i=d&65535;j=g|i;k=h+j|0;j4(k);return}else{a[1041664]=(a[1041664]|0)-1&255;j3((b[520836]|0)-1&65535,e[520832]|0,255);a[1041664]=(a[1041664]|0)-1&255;h=c[276676]|0;i=d&65535;j=g|i;k=h+j|0;j4(k);return}}function tU(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=(a[1041658]&32)==0;e=j0(c[260418]|0)|0;a[1044496]=e;b[520836]=(b[520836]|0)+1&65535;f=b[520831]|0;g=f+(e&255)&65535;do{if((f&255)<<24>>24!=0){e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);f=g&255;e=(g&65535)>>>8;h=e&255;i=b[520829]|0;do{if((i&256)==0){j=3226}else{if((a[1041662]|0)!=0){j=3226;break}k=(a[1041666]|0)+f&255;l=h}}while(0);if((j|0)==3226){j=(b[520833]|0)+(e<<8|g&255)&65535;k=j&255;l=(j&65535)>>>8&255}j=(c[348392]|0)+6|0;c[348392]=j;if((j|0)<(c[348406]|0)){m=i}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));m=b[520829]|0}if((m&256)==0){n=65535}else{n=(a[1041662]|0)!=0?65535:255}m=j5(((l&255)<<8|k&255)&65535,n)|0;a[1044496]=(m&65535)>>>8&255;n=c[276674]|m&65535;if(d){d=j5(n,16777215)|0;a[1044496]=(d&65535)>>>8&255;m=b[520830]&d;b[520830]=m;a[1106728]=m<<16>>16!=0|0;o=(m&65535)>>>8&255;a[1106720]=o;return}else{m=j0(n)|0;a[1044496]=m;n=a[1041660]&m;a[1041660]=n;a[1106728]=n;o=n;a[1106720]=o;return}}function tV(){var d=0,f=0,g=0;d=j5(c[260418]|0,65535)|0;b[520836]=(b[520836]|0)+2&65535;a[1044496]=a[1041674|0]|0;f=j0(c[260418]|0)|0;b[520836]=(b[520836]|0)+1&65535;g=(f&255)<<16|d&65535;d=a[1041674|0]|0;f=b[520832]|0;b[520832]=f-1&65535;j2(d,f&65535);j3((b[520836]|0)-1&65535,(e[520832]|0)-1|0,65535);b[520832]=(b[520832]|0)-2&65535;if((b[520829]&256)==0){j4(g);return}a[1041665|0]=1;j4(g);return}function tW(){var d=0,e=0,f=0,g=0;d=(a[1041658]&32)==0;e=j0(c[260418]|0)|0;a[1044496]=e;b[520836]=(b[520836]|0)+1&65535;f=(b[520832]|0)+(e&255)&65535;e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}e=f&65535;if(d){d=j5(e,16777215)|0;a[1044496]=(d&65535)>>>8&255;f=b[520830]&d;b[520830]=f;a[1106728]=f<<16>>16!=0|0;g=(f&65535)>>>8&255;a[1106720]=g;return}else{f=j0(e)|0;a[1044496]=f;e=a[1041660]&f;a[1041660]=e;a[1106728]=e;g=e;a[1106720]=g;return}}function tX(){var d=0,e=0,f=0,g=0,h=0;d=(a[1041658]&32)==0;e=j0(c[260418]|0)|0;a[1044496]=e;b[520836]=(b[520836]|0)+1&65535;f=b[520831]|0;g=f+(e&255)&65535;do{if((f&255)<<24>>24!=0){e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);f=g&65535;if(d){d=j5(f,65535)|0;g=(d&65535)>>>8&255;a[1044496]=g;a[1106712]=(d&65535)>>>14&1;a[1106720]=g;h=(b[520830]&d)<<16>>16!=0|0;a[1106728]=h;return}else{d=j0(f)|0;a[1044496]=d;a[1106712]=(d&255)>>>6&1;a[1106720]=d;h=a[1041660]&d;a[1106728]=h;return}}function tY(){var d=0,e=0,f=0,g=0,h=0;d=(a[1041658]&32)==0;e=j0(c[260418]|0)|0;a[1044496]=e;b[520836]=(b[520836]|0)+1&65535;f=b[520831]|0;g=f+(e&255)&65535;do{if((f&255)<<24>>24!=0){e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);f=g&65535;if(d){d=j5(f,65535)|0;a[1044496]=(d&65535)>>>8&255;g=b[520830]&d;b[520830]=g;a[1106728]=g<<16>>16!=0|0;h=(g&65535)>>>8&255;a[1106720]=h;return}else{g=j0(f)|0;a[1044496]=g;f=a[1041660]&g;a[1041660]=f;a[1106728]=f;h=f;a[1106720]=h;return}}function tZ(){var e=0,f=0,g=0,h=0,i=0;e=(a[1041658]&32)==0;f=j0(c[260418]|0)|0;a[1044496]=f;b[520836]=(b[520836]|0)+1&65535;g=b[520831]|0;h=g+(f&255)&65535;do{if((g&255)<<24>>24!=0){f=(c[348392]|0)+6|0;c[348392]=f;if((f|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);g=h&65535;if(e){e=j5(g,65535)|0;h=(e&65535)<<1|(d[1106736]|0);a[1106736]=h>>>0>65535|0;f=(c[348392]|0)+6|0;c[348392]=f;if((f|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}j3(h&65535,g,65535);a[1044496]=h&255;a[1106728]=(h&65535|0)!=0|0;i=(e&65535)>>>7&255;a[1106720]=i;return}else{e=((j0(g)|0)&255)<<1;h=e|(d[1106736]|0);a[1106736]=(h&65535)>255|0;e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}e=h&255;j2(e,g);a[1044496]=e;a[1106728]=e;i=e;a[1106720]=i;return}}function t_(){var d=0,e=0,f=0,g=0,h=0;d=(a[1041658]&32)==0;e=j0(c[260418]|0)|0;a[1044496]=e;b[520836]=(b[520836]|0)+1&65535;f=b[520831]|0;g=f+(e&255)&65535;do{if((f&255)<<24>>24!=0){e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);f=g&65535;g=j5(f,16777215)|0;a[1044496]=(g&65535)>>>8&255;e=j0(f+2|0)|0;a[1044496]=e;f=(e&255)<<16|g&65535;if(d){d=j5(f,16777215)|0;a[1044496]=(d&65535)>>>8&255;g=b[520830]&d;b[520830]=g;a[1106728]=g<<16>>16!=0|0;h=(g&65535)>>>8&255;a[1106720]=h;return}else{g=j0(f)|0;a[1044496]=g;f=a[1041660]&g;a[1041660]=f;a[1106728]=f;h=f;a[1106720]=h;return}}function t$(){var d=0,f=0,g=0;d=(c[348392]|0)+12|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}if((b[520829]&256)==0){d=(b[520832]|0)+1&65535;b[520832]=d;f=j0(d&65535)|0;a[1041658]=f;a[1044496]=f;g=f}else{a[1041664]=(a[1041664]|0)+1&255;f=j0(e[520832]|0)|0;a[1041658]=f;a[1044496]=f;f=b[520829]|48;b[520829]=f;g=f&255}a[1106728]=(g&255)>>>1&1^1;a[1106720]=g&-128;a[1106736]=g&1;a[1106712]=(g&255)>>>6&1;if((g&16)!=0){a[1041667|0]=0;a[1041669|0]=0}g=b[520829]|0;if((g&256)!=0){c[276688]=158776;c[276686]=159800;return}f=g&255;g=(f&16|0)!=0;if((f&32|0)==0){if(g){c[276688]=156728;c[276686]=160312;return}else{c[276688]=157752;c[276686]=160568;return}}else{if(g){c[276688]=154680;c[276686]=159800;return}else{c[276688]=155704;c[276686]=160056;return}}}function t0(){var d=0,e=0,f=0,g=0;d=c[260418]|0;if((a[1041658]&32)==0){e=j5(d,65535)|0;a[1044496]=(e&65535)>>>8&255;b[520836]=(b[520836]|0)+2&65535;f=b[520830]&e;b[520830]=f;a[1106728]=f<<16>>16!=0|0;g=(f&65535)>>>8&255;a[1106720]=g;return}else{f=j0(d)|0;a[1044496]=f;b[520836]=(b[520836]|0)+1&65535;d=a[1041660]&f;a[1041660]=d;a[1106728]=d;g=d;a[1106720]=g;return}}function t1(){var f=0,g=0,h=0;f=(c[348392]|0)+6|0;c[348392]=f;if((f|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}if((a[1041658]&32)==0){f=(e[520830]|0)<<1|(d[1106736]|0);a[1106736]=f>>>0>65535|0;g=f&65535;b[520830]=g;a[1106728]=(f&65535|0)!=0|0;h=(g&65535)>>>8&255;a[1106720]=h;return}else{g=(d[1041660]|0)<<1;f=g|(d[1106736]|0);a[1106736]=(g&65535)>255|0;g=f&255;a[1041660]=g;a[1106728]=g;h=g;a[1106720]=h;return}}function t2(){var d=0,f=0;d=(c[348392]|0)+12|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}d=j5((e[520832]|0)+1|0,65535)|0;b[520831]=d;b[520832]=(b[520832]|0)+2&65535;a[1106728]=d<<16>>16!=0|0;f=(d&65535)>>>8&255;a[1106720]=f;a[1044496]=f;if((b[520829]&256)==0){return}a[1041665|0]=1;return}function t3(){var d=0,e=0,f=0,g=0,h=0;d=(a[1041658]&32)==0;e=c[276674]|0;f=j5(c[260418]|0,65535)|0;a[1044496]=(f&65535)>>>8&255;b[520836]=(b[520836]|0)+2&65535;g=f&65535|e;if(d){d=j5(g,16777215)|0;e=(d&65535)>>>8&255;a[1044496]=e;a[1106712]=(d&65535)>>>14&1;a[1106720]=e;h=(b[520830]&d)<<16>>16!=0|0;a[1106728]=h;return}else{d=j0(g)|0;a[1044496]=d;a[1106712]=(d&255)>>>6&1;a[1106720]=d;h=a[1041660]&d;a[1106728]=h;return}}function t4(){var d=0,e=0,f=0,g=0,h=0;d=(a[1041658]&32)==0;e=c[276674]|0;f=j5(c[260418]|0,65535)|0;a[1044496]=(f&65535)>>>8&255;b[520836]=(b[520836]|0)+2&65535;g=f&65535|e;if(d){d=j5(g,16777215)|0;a[1044496]=(d&65535)>>>8&255;e=b[520830]&d;b[520830]=e;a[1106728]=e<<16>>16!=0|0;h=(e&65535)>>>8&255;a[1106720]=h;return}else{e=j0(g)|0;a[1044496]=e;g=a[1041660]&e;a[1041660]=g;a[1106728]=g;h=g;a[1106720]=h;return}}function t5(){var e=0,f=0,g=0,h=0,i=0;e=(a[1041658]&32)==0;f=c[276674]|0;g=j5(c[260418]|0,65535)|0;a[1044496]=(g&65535)>>>8&255;b[520836]=(b[520836]|0)+2&65535;h=g&65535|f;if(e){e=j5(h,16777215)|0;f=(e&65535)<<1|(d[1106736]|0);a[1106736]=f>>>0>65535|0;g=(c[348392]|0)+6|0;c[348392]=g;if((g|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}j3(f&65535,h,16777215);a[1044496]=f&255;a[1106728]=(f&65535|0)!=0|0;i=(e&65535)>>>7&255;a[1106720]=i;return}else{e=((j0(h)|0)&255)<<1;f=e|(d[1106736]|0);a[1106736]=(f&65535)>255|0;e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}e=f&255;j2(e,h);a[1044496]=e;a[1106728]=e;i=e;a[1106720]=i;return}}function t6(){var d=0,e=0,f=0,g=0,h=0;d=(a[1041658]&32)==0;e=j5(c[260418]|0,65535)|0;a[1044496]=(e&65535)>>>8&255;b[520836]=(b[520836]|0)+2&65535;f=j0(c[260418]|0)|0;a[1044496]=f;b[520836]=(b[520836]|0)+1&65535;g=(f&255)<<16|e&65535;if(d){d=j5(g,16777215)|0;a[1044496]=(d&65535)>>>8&255;e=b[520830]&d;b[520830]=e;a[1106728]=e<<16>>16!=0|0;h=(e&65535)>>>8&255;a[1106720]=h;return}else{e=j0(g)|0;a[1044496]=e;g=a[1041660]&e;a[1041660]=g;a[1106728]=g;h=g;a[1106720]=h;return}}function t7(){var e=0,f=0,g=0,h=0,i=0,j=0;e=j0(c[260418]|0)|0;a[1044496]=e;f=(b[520836]|0)+1&65535;b[520836]=f;g=f+(e<<24>>24)&65535;e=(g&65535)>>>8;if((a[1106720]|0)>=0){return}f=(c[348392]|0)+6|0;c[348392]=f;h=c[348406]|0;if((f|0)<(h|0)){i=f;j=h}else{while(1){j1();h=c[348392]|0;f=c[348406]|0;if((h|0)<(f|0)){i=h;j=f;break}}}do{if((b[520829]&256)!=0){if((d[1041673|0]|0)==(e&65535|0)){break}f=i+6|0;c[348392]=f;if((f|0)<(j|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j=e<<8;e=j|g&255;if(((b[520836]^j)&65535)>4095){j4((c[276676]|0)+(e&65535)|0);return}else{b[520836]=e;return}}function t8(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=(a[1041658]&32)==0;g=j0(c[260418]|0)|0;a[1044496]=g;b[520836]=(b[520836]|0)+1&65535;h=b[520831]|0;i=h+(g&255)&65535;do{if((h&255)<<24>>24!=0){g=(c[348392]|0)+6|0;c[348392]=g;if((g|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);if((b[520829]&256)==0){j=65535}else{j=(a[1041662]|0)!=0?65535:255}h=j5(i&65535,j)|0;a[1044496]=(h&65535)>>>8&255;j=c[276674]|h&65535;if((a[1041658]&16)==0){k=3384}else{if(((d[1041668]|0)+(j&255)|0)>>>0>255){k=3384}}do{if((k|0)==3384){h=(c[348392]|0)+6|0;c[348392]=h;if((h|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);k=(e[520834]|0)+j|0;if(f){f=j5(k,16777215)|0;a[1044496]=(f&65535)>>>8&255;j=b[520830]&f;b[520830]=j;a[1106728]=j<<16>>16!=0|0;l=(j&65535)>>>8&255;a[1106720]=l;return}else{j=j0(k)|0;a[1044496]=j;k=a[1041660]&j;a[1041660]=k;a[1106728]=k;l=k;a[1106720]=l;return}}function t9(){var d=0,e=0,f=0,g=0,h=0,i=0;d=(a[1041658]&32)==0;e=j0(c[260418]|0)|0;a[1044496]=e;b[520836]=(b[520836]|0)+1&65535;f=b[520831]|0;g=f+(e&255)&65535;do{if((f&255)<<24>>24!=0){e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);if((b[520829]&256)==0){h=65535}else{h=(a[1041662]|0)!=0?65535:255}f=j5(g&65535,h)|0;a[1044496]=(f&65535)>>>8&255;h=c[276674]|f&65535;if(d){d=j5(h,16777215)|0;a[1044496]=(d&65535)>>>8&255;f=b[520830]&d;b[520830]=f;a[1106728]=f<<16>>16!=0|0;i=(f&65535)>>>8&255;a[1106720]=i;return}else{f=j0(h)|0;a[1044496]=f;h=a[1041660]&f;a[1041660]=h;a[1106728]=h;i=h;a[1106720]=i;return}}function ua(){var d=0,f=0,g=0,h=0;d=(a[1041658]&32)==0;f=j0(c[260418]|0)|0;a[1044496]=f;b[520836]=(b[520836]|0)+1&65535;g=(b[520832]|0)+(f&255)&65535;f=(c[348392]|0)+6|0;c[348392]=f;if((f|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}f=j5(g&65535,16777215)|0;a[1044496]=(f&65535)>>>8&255;g=(e[520834]|0)+(f&65535)+(c[276674]|0)&16777215;f=(c[348392]|0)+6|0;c[348392]=f;if((f|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}if(d){d=j5(g,16777215)|0;a[1044496]=(d&65535)>>>8&255;f=b[520830]&d;b[520830]=f;a[1106728]=f<<16>>16!=0|0;h=(f&65535)>>>8&255;a[1106720]=h;return}else{f=j0(g)|0;a[1044496]=f;g=a[1041660]&f;a[1041660]=g;a[1106728]=g;h=g;a[1106720]=h;return}}function ub(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=(a[1041658]&32)==0;e=j0(c[260418]|0)|0;a[1044496]=e;b[520836]=(b[520836]|0)+1&65535;f=b[520831]|0;g=f+(e&255)&65535;do{if((f&255)<<24>>24!=0){e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);f=g&255;e=(g&65535)>>>8;h=e&255;do{if((b[520829]&256)==0){i=3418}else{if((a[1041662]|0)!=0){i=3418;break}j=(a[1041666]|0)+f&255;k=h}}while(0);if((i|0)==3418){i=(b[520833]|0)+(e<<8|g&255)&65535;j=i&255;k=(i&65535)>>>8&255}i=(c[348392]|0)+6|0;c[348392]=i;if((i|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}i=((k&255)<<8|j&255)&65535;if(d){d=j5(i,65535)|0;j=(d&65535)>>>8&255;a[1044496]=j;a[1106712]=(d&65535)>>>14&1;a[1106720]=j;l=(b[520830]&d)<<16>>16!=0|0;a[1106728]=l;return}else{d=j0(i)|0;a[1044496]=d;a[1106712]=(d&255)>>>6&1;a[1106720]=d;l=a[1041660]&d;a[1106728]=l;return}}function uc(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=(a[1041658]&32)==0;e=j0(c[260418]|0)|0;a[1044496]=e;b[520836]=(b[520836]|0)+1&65535;f=b[520831]|0;g=f+(e&255)&65535;do{if((f&255)<<24>>24!=0){e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);f=g&255;e=(g&65535)>>>8;h=e&255;do{if((b[520829]&256)==0){i=3433}else{if((a[1041662]|0)!=0){i=3433;break}j=(a[1041666]|0)+f&255;k=h}}while(0);if((i|0)==3433){i=(b[520833]|0)+(e<<8|g&255)&65535;j=i&255;k=(i&65535)>>>8&255}i=(c[348392]|0)+6|0;c[348392]=i;if((i|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}i=((k&255)<<8|j&255)&65535;if(d){d=j5(i,65535)|0;a[1044496]=(d&65535)>>>8&255;j=b[520830]&d;b[520830]=j;a[1106728]=j<<16>>16!=0|0;l=(j&65535)>>>8&255;a[1106720]=l;return}else{j=j0(i)|0;a[1044496]=j;i=a[1041660]&j;a[1041660]=i;a[1106728]=i;l=i;a[1106720]=l;return}}function ud(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=(a[1041658]&32)==0;f=j0(c[260418]|0)|0;a[1044496]=f;b[520836]=(b[520836]|0)+1&65535;g=b[520831]|0;h=g+(f&255)&65535;do{if((g&255)<<24>>24!=0){f=(c[348392]|0)+6|0;c[348392]=f;if((f|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);g=h&255;f=(h&65535)>>>8;i=f&255;do{if((b[520829]&256)==0){j=3448}else{if((a[1041662]|0)!=0){j=3448;break}k=(a[1041666]|0)+g&255;l=i}}while(0);if((j|0)==3448){j=(b[520833]|0)+(f<<8|h&255)&65535;k=j&255;l=(j&65535)>>>8&255}j=(c[348392]|0)+6|0;c[348392]=j;if((j|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}j=((l&255)<<8|k&255)&65535;if(e){e=j5(j,65535)|0;k=(e&65535)<<1|d[1106736];a[1106736]=k>>>0>65535|0;l=(c[348392]|0)+6|0;c[348392]=l;if((l|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}j3(k&65535,j,65535);a[1044496]=k&255;a[1106728]=(k&65535|0)!=0|0;m=(e&65535)>>>7&255;a[1106720]=m;return}else{e=((j0(j)|0)&255)<<1;k=e|d[1106736];a[1106736]=(k&65535)>255|0;e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}e=k&255;j2(e,j);a[1044496]=e;a[1106728]=e;m=e;a[1106720]=m;return}}function ue(){var d=0,f=0,g=0,h=0,i=0;d=(a[1041658]&32)==0;f=j0(c[260418]|0)|0;a[1044496]=f;b[520836]=(b[520836]|0)+1&65535;g=b[520831]|0;h=g+(f&255)&65535;do{if((g&255)<<24>>24!=0){f=(c[348392]|0)+6|0;c[348392]=f;if((f|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);g=h&65535;h=j5(g,16777215)|0;a[1044496]=(h&65535)>>>8&255;f=j0(g+2|0)|0;a[1044496]=f;g=((f&255)<<16|h&65535)+(e[520834]|0)|0;if(d){d=j5(g,16777215)|0;a[1044496]=(d&65535)>>>8&255;h=b[520830]&d;b[520830]=h;a[1106728]=h<<16>>16!=0|0;i=(h&65535)>>>8&255;a[1106720]=i;return}else{h=j0(g)|0;a[1044496]=h;g=a[1041660]&h;a[1041660]=g;a[1106728]=g;i=g;a[1106720]=i;return}}function uf(){var f=0,g=0,h=0,i=0,j=0,k=0;f=(a[1041658]&32)==0;g=c[276674]|0;h=j5(c[260418]|0,65535)|0;a[1044496]=(h&65535)>>>8&255;b[520836]=(b[520836]|0)+2&65535;i=h&65535|g;if((a[1041658]&16)==0){j=3473}else{if(((d[1041668]|0)+(i&255)|0)>>>0>255){j=3473}}do{if((j|0)==3473){g=(c[348392]|0)+6|0;c[348392]=g;if((g|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j=(e[520834]|0)+i|0;if(f){f=j5(j,16777215)|0;a[1044496]=(f&65535)>>>8&255;i=b[520830]&f;b[520830]=i;a[1106728]=i<<16>>16!=0|0;k=(i&65535)>>>8&255;a[1106720]=k;return}else{i=j0(j)|0;a[1044496]=i;j=a[1041660]&i;a[1041660]=j;a[1106728]=j;k=j;a[1106720]=k;return}}function ug(){var d=0,e=0;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}if((a[1041658]&32)==0){d=(b[520830]|0)-1&65535;b[520830]=d;a[1106728]=d<<16>>16!=0|0;e=(d&65535)>>>8&255;a[1106720]=e;return}else{d=(a[1041660]|0)-1&255;a[1041660]=d;a[1106728]=d;e=d;a[1106720]=e;return}}function uh(){var f=0,g=0,h=0,i=0,j=0,k=0;f=(a[1041658]&32)==0;g=c[276674]|0;h=j5(c[260418]|0,65535)|0;a[1044496]=(h&65535)>>>8&255;b[520836]=(b[520836]|0)+2&65535;i=h&65535|g;if((a[1041658]&16)==0){j=3491}else{if(((d[1041666]|0)+(i&255)|0)>>>0>255){j=3491}}do{if((j|0)==3491){g=(c[348392]|0)+6|0;c[348392]=g;if((g|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j=(e[520833]|0)+i|0;if(f){f=j5(j,16777215)|0;i=(f&65535)>>>8&255;a[1044496]=i;a[1106712]=(f&65535)>>>14&1;a[1106720]=i;k=(b[520830]&f)<<16>>16!=0|0;a[1106728]=k;return}else{f=j0(j)|0;a[1044496]=f;a[1106712]=(f&255)>>>6&1;a[1106720]=f;k=a[1041660]&f;a[1106728]=k;return}}function ui(){var f=0,g=0,h=0,i=0,j=0,k=0;f=(a[1041658]&32)==0;g=c[276674]|0;h=j5(c[260418]|0,65535)|0;a[1044496]=(h&65535)>>>8&255;b[520836]=(b[520836]|0)+2&65535;i=h&65535|g;if((a[1041658]&16)==0){j=3501}else{if(((d[1041666]|0)+(i&255)|0)>>>0>255){j=3501}}do{if((j|0)==3501){g=(c[348392]|0)+6|0;c[348392]=g;if((g|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j=(e[520833]|0)+i|0;if(f){f=j5(j,16777215)|0;a[1044496]=(f&65535)>>>8&255;i=b[520830]&f;b[520830]=i;a[1106728]=i<<16>>16!=0|0;k=(i&65535)>>>8&255;a[1106720]=k;return}else{i=j0(j)|0;a[1044496]=i;j=a[1041660]&i;a[1041660]=j;a[1106728]=j;k=j;a[1106720]=k;return}}function uj(){var f=0,g=0,h=0,i=0,j=0;f=(a[1041658]&32)==0;g=c[276674]|0;h=j5(c[260418]|0,65535)|0;a[1044496]=(h&65535)>>>8&255;b[520836]=(b[520836]|0)+2&65535;i=h&65535|g;g=(c[348392]|0)+6|0;c[348392]=g;if((g|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}g=(e[520833]|0)+i|0;if(f){f=j5(g,16777215)|0;i=(f&65535)<<1|(d[1106736]|0);a[1106736]=i>>>0>65535|0;h=(c[348392]|0)+6|0;c[348392]=h;if((h|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}j3(i&65535,g,16777215);a[1044496]=i&255;a[1106728]=(i&65535|0)!=0|0;j=(f&65535)>>>7&255;a[1106720]=j;return}else{f=((j0(g)|0)&255)<<1;i=f|(d[1106736]|0);a[1106736]=(i&65535)>255|0;f=(c[348392]|0)+6|0;c[348392]=f;if((f|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}f=i&255;j2(f,g);a[1044496]=f;a[1106728]=f;j=f;a[1106720]=j;return}}function uk(){var d=0,f=0,g=0,h=0,i=0;d=(a[1041658]&32)==0;f=j5(c[260418]|0,65535)|0;a[1044496]=(f&65535)>>>8&255;b[520836]=(b[520836]|0)+2&65535;g=j0(c[260418]|0)|0;a[1044496]=g;b[520836]=(b[520836]|0)+1&65535;h=(e[520833]|0)+((g&255)<<16|f&65535)|0;if(d){d=j5(h,16777215)|0;a[1044496]=(d&65535)>>>8&255;f=b[520830]&d;b[520830]=f;a[1106728]=f<<16>>16!=0|0;i=(f&65535)>>>8&255;a[1106720]=i;return}else{f=j0(h)|0;a[1044496]=f;h=a[1041660]&f;a[1041660]=h;a[1106728]=h;i=h;a[1106720]=i;return}}function ul(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=(a[1041658]&32)==0;e=j0(c[260418]|0)|0;a[1044496]=e;b[520836]=(b[520836]|0)+1&65535;f=b[520831]|0;g=f+(e&255)&65535;do{if((f&255)<<24>>24!=0){e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);f=g&255;e=(g&65535)>>>8;h=e&255;i=b[520829]|0;do{if((i&256)==0){j=3532}else{if((a[1041662]|0)!=0){j=3532;break}k=(a[1041666]|0)+f&255;l=h}}while(0);if((j|0)==3532){j=(b[520833]|0)+(e<<8|g&255)&65535;k=j&255;l=(j&65535)>>>8&255}j=(c[348392]|0)+6|0;c[348392]=j;if((j|0)<(c[348406]|0)){m=i}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));m=b[520829]|0}if((m&256)==0){n=65535}else{n=(a[1041662]|0)!=0?65535:255}m=j5(((l&255)<<8|k&255)&65535,n)|0;a[1044496]=(m&65535)>>>8&255;n=c[276674]|m&65535;if(d){d=j5(n,16777215)|0;a[1044496]=(d&65535)>>>8&255;m=b[520830]|0;k=m^d;b[520830]=k;a[1106728]=m<<16>>16!=d<<16>>16|0;o=(k&65535)>>>8&255;a[1106720]=o;return}else{k=j0(n)|0;a[1044496]=k;n=a[1041660]^k;a[1041660]=n;a[1106728]=n;o=n;a[1106720]=o;return}}function um(){var d=0,e=0,f=0,g=0,h=0;d=(a[1041658]&32)==0;e=j0(c[260418]|0)|0;a[1044496]=e;b[520836]=(b[520836]|0)+1&65535;f=(b[520832]|0)+(e&255)&65535;e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}e=f&65535;if(d){d=j5(e,16777215)|0;a[1044496]=(d&65535)>>>8&255;f=b[520830]|0;g=f^d;b[520830]=g;a[1106728]=f<<16>>16!=d<<16>>16|0;h=(g&65535)>>>8&255;a[1106720]=h;return}else{g=j0(e)|0;a[1044496]=g;e=a[1041660]^g;a[1041660]=e;a[1106728]=e;h=e;a[1106720]=h;return}}function un(){var d=0,f=0;d=j0(c[260418]|0)|0;b[520836]=(b[520836]|0)+1&65535;a[1041656]=d;a[1044496]=d;c[276674]=(d&255)<<16;d=j0(c[260418]|0)|0;b[520836]=(b[520836]|0)+1&65535;a[1044496]=d;f=j0(e[520833]|0|(d&255)<<16)|0;a[1044496]=f;j2(f,(e[520834]|0)+(c[276674]|0)|0);if((a[1041658]&16)==0){b[520833]=(b[520833]|0)-1&65535;b[520834]=(b[520834]|0)-1&65535}else{a[1041666]=(a[1041666]|0)-1&255;a[1041668]=(a[1041668]|0)-1&255}f=b[520830]|0;b[520830]=f-1&65535;if(f<<16>>16!=0){b[520836]=(b[520836]|0)-3&65535}f=(c[348392]|0)+12|0;c[348392]=f;if((f|0)<(c[348406]|0)){return}do{j1();}while((c[348392]|0)>=(c[348406]|0));return}function uo(){var d=0,e=0,f=0,g=0,h=0;d=(a[1041658]&32)==0;e=j0(c[260418]|0)|0;a[1044496]=e;b[520836]=(b[520836]|0)+1&65535;f=b[520831]|0;g=f+(e&255)&65535;do{if((f&255)<<24>>24!=0){e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);f=g&65535;if(d){d=j5(f,65535)|0;a[1044496]=(d&65535)>>>8&255;g=b[520830]|0;e=g^d;b[520830]=e;a[1106728]=g<<16>>16!=d<<16>>16|0;h=(e&65535)>>>8&255;a[1106720]=h;return}else{e=j0(f)|0;a[1044496]=e;f=a[1041660]^e;a[1041660]=f;a[1106728]=f;h=f;a[1106720]=h;return}}function up(){var d=0,e=0,f=0,g=0,h=0;d=(a[1041658]&32)==0;e=j0(c[260418]|0)|0;a[1044496]=e;b[520836]=(b[520836]|0)+1&65535;f=b[520831]|0;g=f+(e&255)&65535;do{if((f&255)<<24>>24!=0){e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);f=g&65535;if(d){d=j5(f,65535)|0;a[1106736]=d&1;g=(d&65535)>>>1;e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}j3(g,f,65535);a[1044496]=g&255;a[1106728]=g<<16>>16!=0|0;h=(d&65535)>>>9&255;a[1106720]=h;return}else{d=j0(f)|0;a[1106736]=d&1;g=(d&255)>>>1;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}j2(g,f);a[1044496]=g;a[1106728]=g;h=g;a[1106720]=h;return}}function uq(){var d=0,e=0,f=0,g=0,h=0;d=(a[1041658]&32)==0;e=j0(c[260418]|0)|0;a[1044496]=e;b[520836]=(b[520836]|0)+1&65535;f=b[520831]|0;g=f+(e&255)&65535;do{if((f&255)<<24>>24!=0){e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);f=g&65535;g=j5(f,16777215)|0;a[1044496]=(g&65535)>>>8&255;e=j0(f+2|0)|0;a[1044496]=e;f=(e&255)<<16|g&65535;if(d){d=j5(f,16777215)|0;a[1044496]=(d&65535)>>>8&255;g=b[520830]|0;e=g^d;b[520830]=e;a[1106728]=g<<16>>16!=d<<16>>16|0;h=(e&65535)>>>8&255;a[1106720]=h;return}else{e=j0(f)|0;a[1044496]=e;f=a[1041660]^e;a[1041660]=f;a[1106728]=f;h=f;a[1106720]=h;return}}function ur(){var d=0,f=0,g=0;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}d=b[520829]|0;if((d&256)!=0){j2(a[1041660]|0,e[520832]|0);a[1041664]=(a[1041664]|0)-1&255;f=a[1041660]|0;a[1044496]=f;return}if((d&32)==0){j3(b[520830]|0,(e[520832]|0)-1|0,65535);b[520832]=(b[520832]|0)-2&65535;f=a[1041660]|0;a[1044496]=f;return}else{d=a[1041660]|0;g=b[520832]|0;b[520832]=g-1&65535;j2(d,g&65535);f=a[1041660]|0;a[1044496]=f;return}}function us(){var d=0,e=0,f=0,g=0,h=0;d=c[260418]|0;if((a[1041658]&32)==0){e=j5(d,65535)|0;a[1044496]=(e&65535)>>>8&255;b[520836]=(b[520836]|0)+2&65535;f=b[520830]|0;g=f^e;b[520830]=g;a[1106728]=f<<16>>16!=e<<16>>16|0;h=(g&65535)>>>8&255;a[1106720]=h;return}else{g=j0(d)|0;a[1044496]=g;b[520836]=(b[520836]|0)+1&65535;d=a[1041660]^g;a[1041660]=d;a[1106728]=d;h=d;a[1106720]=h;return}}function ut(){var d=0,e=0,f=0;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}if((a[1041658]&32)==0){d=b[520830]|0;a[1106736]=d&1;e=(d&65535)>>>1;b[520830]=e;a[1106728]=e<<16>>16!=0|0;f=(d&65535)>>>9&255;a[1106720]=f;return}else{d=a[1041660]|0;a[1106736]=d&1;e=(d&255)>>>1;a[1041660]=e;a[1106728]=e;f=e;a[1106720]=f;return}}function uu(){var d=0,e=0,f=0;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}d=a[1041674|0]|0;e=b[520832]|0;if((b[520829]&256)==0){b[520832]=e-1&65535;j2(d,e&65535);f=a[1041674|0]|0;a[1044496]=f;return}else{j2(d,e&65535);a[1041664]=(a[1041664]|0)-1&255;f=a[1041674|0]|0;a[1044496]=f;return}}function uv(){var d=0,e=0,f=0;d=c[276676]|0;e=c[276674]|0;f=j5(c[260418]|0,65535)|0;a[1044496]=(f&65535)>>>8&255;b[520836]=(b[520836]|0)+2&65535;j4((f&65535|e&65535)+d|0);return}function uw(){var d=0,e=0,f=0,g=0,h=0;d=(a[1041658]&32)==0;e=c[276674]|0;f=j5(c[260418]|0,65535)|0;a[1044496]=(f&65535)>>>8&255;b[520836]=(b[520836]|0)+2&65535;g=f&65535|e;if(d){d=j5(g,16777215)|0;a[1044496]=(d&65535)>>>8&255;e=b[520830]|0;f=e^d;b[520830]=f;a[1106728]=e<<16>>16!=d<<16>>16|0;h=(f&65535)>>>8&255;a[1106720]=h;return}else{f=j0(g)|0;a[1044496]=f;g=a[1041660]^f;a[1041660]=g;a[1106728]=g;h=g;a[1106720]=h;return}}function ux(){var d=0,e=0,f=0,g=0,h=0;d=(a[1041658]&32)==0;e=c[276674]|0;f=j5(c[260418]|0,65535)|0;a[1044496]=(f&65535)>>>8&255;b[520836]=(b[520836]|0)+2&65535;g=f&65535|e;if(d){d=j5(g,16777215)|0;a[1106736]=d&1;e=(d&65535)>>>1;f=(c[348392]|0)+6|0;c[348392]=f;if((f|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}j3(e,g,16777215);a[1044496]=e&255;a[1106728]=e<<16>>16!=0|0;h=(d&65535)>>>9&255;a[1106720]=h;return}else{d=j0(g)|0;a[1106736]=d&1;e=(d&255)>>>1;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}j2(e,g);a[1044496]=e;a[1106728]=e;h=e;a[1106720]=h;return}}function uy(){var d=0,e=0,f=0,g=0,h=0;d=(a[1041658]&32)==0;e=j5(c[260418]|0,65535)|0;a[1044496]=(e&65535)>>>8&255;b[520836]=(b[520836]|0)+2&65535;f=j0(c[260418]|0)|0;a[1044496]=f;b[520836]=(b[520836]|0)+1&65535;g=(f&255)<<16|e&65535;if(d){d=j5(g,16777215)|0;a[1044496]=(d&65535)>>>8&255;e=b[520830]|0;f=e^d;b[520830]=f;a[1106728]=e<<16>>16!=d<<16>>16|0;h=(f&65535)>>>8&255;a[1106720]=h;return}else{f=j0(g)|0;a[1044496]=f;g=a[1041660]^f;a[1041660]=g;a[1106728]=g;h=g;a[1106720]=h;return}}function uz(){var e=0,f=0,g=0,h=0,i=0,j=0;e=j0(c[260418]|0)|0;a[1044496]=e;f=(b[520836]|0)+1&65535;b[520836]=f;g=f+(e<<24>>24)&65535;e=(g&65535)>>>8;if((a[1106712]|0)!=0){return}f=(c[348392]|0)+6|0;c[348392]=f;h=c[348406]|0;if((f|0)<(h|0)){i=f;j=h}else{while(1){j1();h=c[348392]|0;f=c[348406]|0;if((h|0)<(f|0)){i=h;j=f;break}}}do{if((b[520829]&256)!=0){if((d[1041673|0]|0)==(e&65535|0)){break}f=i+6|0;c[348392]=f;if((f|0)<(j|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j=e<<8;e=j|g&255;if(((b[520836]^j)&65535)>4095){j4((c[276676]|0)+(e&65535)|0);return}else{b[520836]=e;return}}function uA(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=(a[1041658]&32)==0;g=j0(c[260418]|0)|0;a[1044496]=g;b[520836]=(b[520836]|0)+1&65535;h=b[520831]|0;i=h+(g&255)&65535;do{if((h&255)<<24>>24!=0){g=(c[348392]|0)+6|0;c[348392]=g;if((g|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);if((b[520829]&256)==0){j=65535}else{j=(a[1041662]|0)!=0?65535:255}h=j5(i&65535,j)|0;a[1044496]=(h&65535)>>>8&255;j=c[276674]|h&65535;if((a[1041658]&16)==0){k=3671}else{if(((d[1041668]|0)+(j&255)|0)>>>0>255){k=3671}}do{if((k|0)==3671){h=(c[348392]|0)+6|0;c[348392]=h;if((h|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);k=(e[520834]|0)+j|0;if(f){f=j5(k,16777215)|0;a[1044496]=(f&65535)>>>8&255;j=b[520830]|0;h=j^f;b[520830]=h;a[1106728]=j<<16>>16!=f<<16>>16|0;l=(h&65535)>>>8&255;a[1106720]=l;return}else{h=j0(k)|0;a[1044496]=h;k=a[1041660]^h;a[1041660]=k;a[1106728]=k;l=k;a[1106720]=l;return}}function uB(){var d=0,e=0,f=0,g=0,h=0,i=0;d=(a[1041658]&32)==0;e=j0(c[260418]|0)|0;a[1044496]=e;b[520836]=(b[520836]|0)+1&65535;f=b[520831]|0;g=f+(e&255)&65535;do{if((f&255)<<24>>24!=0){e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);if((b[520829]&256)==0){h=65535}else{h=(a[1041662]|0)!=0?65535:255}f=j5(g&65535,h)|0;a[1044496]=(f&65535)>>>8&255;h=c[276674]|f&65535;if(d){d=j5(h,16777215)|0;a[1044496]=(d&65535)>>>8&255;f=b[520830]|0;g=f^d;b[520830]=g;a[1106728]=f<<16>>16!=d<<16>>16|0;i=(g&65535)>>>8&255;a[1106720]=i;return}else{g=j0(h)|0;a[1044496]=g;h=a[1041660]^g;a[1041660]=h;a[1106728]=h;i=h;a[1106720]=i;return}}function uC(){var d=0,f=0,g=0,h=0,i=0;d=(a[1041658]&32)==0;f=j0(c[260418]|0)|0;a[1044496]=f;b[520836]=(b[520836]|0)+1&65535;g=(b[520832]|0)+(f&255)&65535;f=(c[348392]|0)+6|0;c[348392]=f;if((f|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}f=j5(g&65535,16777215)|0;a[1044496]=(f&65535)>>>8&255;g=(e[520834]|0)+(f&65535)+(c[276674]|0)&16777215;f=(c[348392]|0)+6|0;c[348392]=f;if((f|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}if(d){d=j5(g,16777215)|0;a[1044496]=(d&65535)>>>8&255;f=b[520830]|0;h=f^d;b[520830]=h;a[1106728]=f<<16>>16!=d<<16>>16|0;i=(h&65535)>>>8&255;a[1106720]=i;return}else{h=j0(g)|0;a[1044496]=h;g=a[1041660]^h;a[1041660]=g;a[1106728]=g;i=g;a[1106720]=i;return}}function uD(){var d=0,f=0;d=j0(c[260418]|0)|0;b[520836]=(b[520836]|0)+1&65535;a[1041656]=d;a[1044496]=d;c[276674]=(d&255)<<16;d=j0(c[260418]|0)|0;b[520836]=(b[520836]|0)+1&65535;a[1044496]=d;f=j0(e[520833]|0|(d&255)<<16)|0;a[1044496]=f;j2(f,(e[520834]|0)+(c[276674]|0)|0);if((a[1041658]&16)==0){b[520833]=(b[520833]|0)+1&65535;b[520834]=(b[520834]|0)+1&65535}else{a[1041666]=(a[1041666]|0)+1&255;a[1041668]=(a[1041668]|0)+1&255}f=b[520830]|0;b[520830]=f-1&65535;if(f<<16>>16!=0){b[520836]=(b[520836]|0)-3&65535}f=(c[348392]|0)+12|0;c[348392]=f;if((f|0)<(c[348406]|0)){return}do{j1();}while((c[348392]|0)>=(c[348406]|0));return}function uE(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=(a[1041658]&32)==0;e=j0(c[260418]|0)|0;a[1044496]=e;b[520836]=(b[520836]|0)+1&65535;f=b[520831]|0;g=f+(e&255)&65535;do{if((f&255)<<24>>24!=0){e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);f=g&255;e=(g&65535)>>>8;h=e&255;do{if((b[520829]&256)==0){i=3715}else{if((a[1041662]|0)!=0){i=3715;break}j=(a[1041666]|0)+f&255;k=h}}while(0);if((i|0)==3715){i=(b[520833]|0)+(e<<8|g&255)&65535;j=i&255;k=(i&65535)>>>8&255}i=(c[348392]|0)+6|0;c[348392]=i;if((i|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}i=((k&255)<<8|j&255)&65535;if(d){d=j5(i,65535)|0;a[1044496]=(d&65535)>>>8&255;j=b[520830]|0;k=j^d;b[520830]=k;a[1106728]=j<<16>>16!=d<<16>>16|0;l=(k&65535)>>>8&255;a[1106720]=l;return}else{k=j0(i)|0;a[1044496]=k;i=a[1041660]^k;a[1041660]=i;a[1106728]=i;l=i;a[1106720]=l;return}}function uF(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=(a[1041658]&32)==0;e=j0(c[260418]|0)|0;a[1044496]=e;b[520836]=(b[520836]|0)+1&65535;f=b[520831]|0;g=f+(e&255)&65535;do{if((f&255)<<24>>24!=0){e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);f=g&255;e=(g&65535)>>>8;h=e&255;do{if((b[520829]&256)==0){i=3730}else{if((a[1041662]|0)!=0){i=3730;break}j=(a[1041666]|0)+f&255;k=h}}while(0);if((i|0)==3730){i=(b[520833]|0)+(e<<8|g&255)&65535;j=i&255;k=(i&65535)>>>8&255}i=(c[348392]|0)+6|0;c[348392]=i;if((i|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}i=((k&255)<<8|j&255)&65535;if(d){d=j5(i,65535)|0;a[1106736]=d&1;j=(d&65535)>>>1;k=(c[348392]|0)+6|0;c[348392]=k;if((k|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}j3(j,i,65535);a[1044496]=j&255;a[1106728]=j<<16>>16!=0|0;l=(d&65535)>>>9&255;a[1106720]=l;return}else{d=j0(i)|0;a[1106736]=d&1;j=(d&255)>>>1;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}j2(j,i);a[1044496]=j;a[1106728]=j;l=j;a[1106720]=l;return}}function uG(){var d=0,f=0,g=0,h=0,i=0;d=(a[1041658]&32)==0;f=j0(c[260418]|0)|0;a[1044496]=f;b[520836]=(b[520836]|0)+1&65535;g=b[520831]|0;h=g+(f&255)&65535;do{if((g&255)<<24>>24!=0){f=(c[348392]|0)+6|0;c[348392]=f;if((f|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);g=h&65535;h=j5(g,16777215)|0;a[1044496]=(h&65535)>>>8&255;f=j0(g+2|0)|0;a[1044496]=f;g=((f&255)<<16|h&65535)+(e[520834]|0)|0;if(d){d=j5(g,16777215)|0;a[1044496]=(d&65535)>>>8&255;h=b[520830]|0;f=h^d;b[520830]=f;a[1106728]=h<<16>>16!=d<<16>>16|0;i=(f&65535)>>>8&255;a[1106720]=i;return}else{f=j0(g)|0;a[1044496]=f;g=a[1041660]^f;a[1041660]=g;a[1106728]=g;i=g;a[1106720]=i;return}}function uH(){var f=0,g=0,h=0,i=0,j=0,k=0;f=(a[1041658]&32)==0;g=c[276674]|0;h=j5(c[260418]|0,65535)|0;a[1044496]=(h&65535)>>>8&255;b[520836]=(b[520836]|0)+2&65535;i=h&65535|g;if((a[1041658]&16)==0){j=3755}else{if(((d[1041668]|0)+(i&255)|0)>>>0>255){j=3755}}do{if((j|0)==3755){g=(c[348392]|0)+6|0;c[348392]=g;if((g|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j=(e[520834]|0)+i|0;if(f){f=j5(j,16777215)|0;a[1044496]=(f&65535)>>>8&255;i=b[520830]|0;g=i^f;b[520830]=g;a[1106728]=i<<16>>16!=f<<16>>16|0;k=(g&65535)>>>8&255;a[1106720]=k;return}else{g=j0(j)|0;a[1044496]=g;j=a[1041660]^g;a[1041660]=j;a[1106728]=j;k=j;a[1106720]=k;return}}function uI(){var d=0,f=0,g=0;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}d=b[520829]|0;if((d&256)!=0){j2(a[1041668]|0,e[520832]|0);a[1041664]=(a[1041664]|0)-1&255;f=a[1041668]|0;a[1044496]=f;return}if((d&16)==0){j3(b[520834]|0,(e[520832]|0)-1|0,65535);b[520832]=(b[520832]|0)-2&65535;f=a[1041668]|0;a[1044496]=f;return}else{d=a[1041668]|0;g=b[520832]|0;b[520832]=g-1&65535;j2(d,g&65535);f=a[1041668]|0;a[1044496]=f;return}}function uJ(){var d=0,e=0;d=j5(c[260418]|0,65535)|0;a[1044496]=(d&65535)>>>8&255;b[520836]=(b[520836]|0)+2&65535;e=j0(c[260418]|0)|0;a[1044496]=e;b[520836]=(b[520836]|0)+1&65535;j4((e&255)<<16|d&65535);return}function uK(){var f=0,g=0,h=0,i=0,j=0,k=0;f=(a[1041658]&32)==0;g=c[276674]|0;h=j5(c[260418]|0,65535)|0;a[1044496]=(h&65535)>>>8&255;b[520836]=(b[520836]|0)+2&65535;i=h&65535|g;if((a[1041658]&16)==0){j=3777}else{if(((d[1041666]|0)+(i&255)|0)>>>0>255){j=3777}}do{if((j|0)==3777){g=(c[348392]|0)+6|0;c[348392]=g;if((g|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j=(e[520833]|0)+i|0;if(f){f=j5(j,16777215)|0;a[1044496]=(f&65535)>>>8&255;i=b[520830]|0;g=i^f;b[520830]=g;a[1106728]=i<<16>>16!=f<<16>>16|0;k=(g&65535)>>>8&255;a[1106720]=k;return}else{g=j0(j)|0;a[1044496]=g;j=a[1041660]^g;a[1041660]=j;a[1106728]=j;k=j;a[1106720]=k;return}}function uL(){var d=0,f=0,g=0,h=0,i=0;d=(a[1041658]&32)==0;f=c[276674]|0;g=j5(c[260418]|0,65535)|0;a[1044496]=(g&65535)>>>8&255;b[520836]=(b[520836]|0)+2&65535;h=g&65535|f;f=(c[348392]|0)+6|0;c[348392]=f;if((f|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}f=(e[520833]|0)+h|0;if(d){d=j5(f,16777215)|0;a[1106736]=d&1;h=(d&65535)>>>1;g=(c[348392]|0)+6|0;c[348392]=g;if((g|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}j3(h,f,16777215);a[1044496]=h&255;a[1106728]=h<<16>>16!=0|0;i=(d&65535)>>>9&255;a[1106720]=i;return}else{d=j0(f)|0;a[1106736]=d&1;h=(d&255)>>>1;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}j2(h,f);a[1044496]=h;a[1106728]=h;i=h;a[1106720]=i;return}}function uM(){var d=0,f=0,g=0,h=0,i=0;d=(a[1041658]&32)==0;f=j5(c[260418]|0,65535)|0;a[1044496]=(f&65535)>>>8&255;b[520836]=(b[520836]|0)+2&65535;g=j0(c[260418]|0)|0;a[1044496]=g;b[520836]=(b[520836]|0)+1&65535;h=(e[520833]|0)+((g&255)<<16|f&65535)|0;if(d){d=j5(h,16777215)|0;a[1044496]=(d&65535)>>>8&255;f=b[520830]|0;g=f^d;b[520830]=g;a[1106728]=f<<16>>16!=d<<16>>16|0;i=(g&65535)>>>8&255;a[1106720]=i;return}else{g=j0(h)|0;a[1044496]=g;h=a[1041660]^g;a[1041660]=h;a[1106728]=h;i=h;a[1106720]=i;return}}function uN(){var d=0,f=0,g=0,h=0,i=0;d=(c[348392]|0)+12|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}if((b[520829]&256)==0){d=j5((e[520832]|0)+1|0,65535)|0;b[520836]=d;b[520832]=(b[520832]|0)+2&65535;f=d}else{a[1041664]=(a[1041664]|0)+1&255;d=j5(e[520832]|0,255)|0;b[520836]=d;a[1041664]=(a[1041664]|0)+1&255;f=d}d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)<(c[348406]|0)){g=f;h=g+1&65535;b[520836]=h;i=c[260418]|0;j4(i);return}do{j1();}while((c[348392]|0)>=(c[348406]|0));g=b[520836]|0;h=g+1&65535;b[520836]=h;i=c[260418]|0;j4(i);return}function uO(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=(a[1041658]&32)==0;f=j0(c[260418]|0)|0;a[1044496]=f;b[520836]=(b[520836]|0)+1&65535;g=b[520831]|0;h=g+(f&255)&65535;do{if((g&255)<<24>>24!=0){f=(c[348392]|0)+6|0;c[348392]=f;if((f|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);g=h&255;f=(h&65535)>>>8;i=f&255;j=b[520829]|0;do{if((j&256)==0){k=3819}else{if((a[1041662]|0)!=0){k=3819;break}l=(a[1041666]|0)+g&255;m=i}}while(0);if((k|0)==3819){k=(b[520833]|0)+(f<<8|h&255)&65535;l=k&255;m=(k&65535)>>>8&255}k=(c[348392]|0)+6|0;c[348392]=k;if((k|0)<(c[348406]|0)){n=j}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));n=b[520829]|0}if((n&256)==0){o=65535}else{o=(a[1041662]|0)!=0?65535:255}n=j5(((m&255)<<8|l&255)&65535,o)|0;a[1044496]=(n&65535)>>>8&255;o=c[276674]|n&65535;if(e){e=j5(o,16777215)|0;a[1044496]=(e&65535)>>>8&255;w9(e);return}e=j0(o)|0;a[1044496]=e;if((a[1041658]&8)==0){o=a[1041660]|0;n=e&255;l=(o&255)+n+(d[1106736]|0)|0;a[1106736]=(l&65280)>>>0>255|0;p=l&255;q=((l^n)&((o^e)&255^128))>>>7&255}else{o=b[520830]|0;n=o&255;l=o&240;o=((a[1106736]|0)+(e&15)&255)+(n&15)&255;if((o&255)>9){r=o+6&15;s=l+16&65535}else{r=o;s=l}l=s+(e&-16&255)&65535;if((l&65535)>144){a[1106736]=1;t=l+96&255&-16}else{a[1106736]=0;t=l&255}l=t|r;p=l;q=((l^e)&(e^-128^n)&255)>>>7}a[1106712]=q&1;a[1041660]=p;a[1106728]=p;a[1106720]=p;return}function uP(){var d=0,f=0,g=0;d=j5(c[260418]|0,65535)|0;f=(b[520836]|0)+2&65535;b[520836]=f;g=(f&65535)+(d&65535)|0;j3(g&65535,(e[520832]|0)-1|0,65535);b[520832]=(b[520832]|0)-2&65535;a[1044496]=g&255;if((b[520829]&256)==0){return}a[1041665|0]=1;return}function uQ(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=(a[1041658]&32)==0;f=j0(c[260418]|0)|0;a[1044496]=f;b[520836]=(b[520836]|0)+1&65535;g=(b[520832]|0)+(f&255)&65535;f=(c[348392]|0)+6|0;c[348392]=f;if((f|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}f=g&65535;if(e){e=j5(f,16777215)|0;a[1044496]=(e&65535)>>>8&255;w9(e);return}e=j0(f)|0;a[1044496]=e;if((a[1041658]&8)==0){f=a[1041660]|0;g=e&255;h=(f&255)+g+(d[1106736]|0)|0;a[1106736]=(h&65280)>>>0>255|0;i=h&255;j=((h^g)&((f^e)&255^128))>>>7&255}else{f=b[520830]|0;g=f&255;h=f&240;f=((a[1106736]|0)+(e&15)&255)+(g&15)&255;if((f&255)>9){k=f+6&15;l=h+16&65535}else{k=f;l=h}h=l+(e&-16&255)&65535;if((h&65535)>144){a[1106736]=1;m=h+96&255&-16}else{a[1106736]=0;m=h&255}h=m|k;i=h;j=((h^e)&(e^-128^g)&255)>>>7}a[1106712]=j&1;a[1041660]=i;a[1106728]=i;a[1106720]=i;return}function uR(){var d=0,e=0,f=0,g=0;d=(a[1041658]&32)==0;e=j0(c[260418]|0)|0;b[520836]=(b[520836]|0)+1&65535;f=b[520831]|0;g=f+(e&255)&65535;do{if((f&255)<<24>>24!=0){e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);f=g&65535;if(d){w7(0,f,65535);a[1044496]=0;return}else{j2(0,f);a[1044496]=0;return}}function uS(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=(a[1041658]&32)==0;f=j0(c[260418]|0)|0;a[1044496]=f;b[520836]=(b[520836]|0)+1&65535;g=b[520831]|0;h=g+(f&255)&65535;do{if((g&255)<<24>>24!=0){f=(c[348392]|0)+6|0;c[348392]=f;if((f|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);g=h&65535;if(e){e=j5(g,65535)|0;a[1044496]=(e&65535)>>>8&255;w9(e);return}e=j0(g)|0;a[1044496]=e;if((a[1041658]&8)==0){g=a[1041660]|0;h=e&255;f=(g&255)+h+(d[1106736]|0)|0;a[1106736]=(f&65280)>>>0>255|0;i=f&255;j=((f^h)&((g^e)&255^128))>>>7&255}else{g=b[520830]|0;h=g&255;f=g&240;g=((a[1106736]|0)+(e&15)&255)+(h&15)&255;if((g&255)>9){k=g+6&15;l=f+16&65535}else{k=g;l=f}f=l+(e&-16&255)&65535;if((f&65535)>144){a[1106736]=1;m=f+96&255&-16}else{a[1106736]=0;m=f&255}f=m|k;i=f;j=((f^e)&(e^-128^h)&255)>>>7}a[1106712]=j&1;a[1041660]=i;a[1106728]=i;a[1106720]=i;return}function uT(){var e=0,f=0,g=0,h=0,i=0;e=(a[1041658]&32)==0;f=j0(c[260418]|0)|0;a[1044496]=f;b[520836]=(b[520836]|0)+1&65535;g=b[520831]|0;h=g+(f&255)&65535;do{if((g&255)<<24>>24!=0){f=(c[348392]|0)+6|0;c[348392]=f;if((f|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);g=h&65535;if(e){e=j5(g,65535)|0;h=(d[1106736]|0)<<16|e&65535;a[1106736]=e&1;e=h>>>1;f=(c[348392]|0)+6|0;c[348392]=f;if((f|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}j3(e&65535,g,65535);a[1044496]=e&255;a[1106728]=(e&65535|0)!=0|0;i=h>>>9&255;a[1106720]=i;return}else{h=j0(g)|0;e=(d[1106736]|0)<<8|h&255;a[1106736]=h&1;h=(e&65535)>>>1;e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}e=h&255;j2(e,g);a[1044496]=e;a[1106728]=e;i=e;a[1106720]=i;return}}function uU(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=(a[1041658]&32)==0;f=j0(c[260418]|0)|0;a[1044496]=f;b[520836]=(b[520836]|0)+1&65535;g=b[520831]|0;h=g+(f&255)&65535;do{if((g&255)<<24>>24!=0){f=(c[348392]|0)+6|0;c[348392]=f;if((f|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);g=h&65535;h=j5(g,16777215)|0;a[1044496]=(h&65535)>>>8&255;f=j0(g+2|0)|0;a[1044496]=f;g=(f&255)<<16|h&65535;if(e){e=j5(g,16777215)|0;a[1044496]=(e&65535)>>>8&255;w9(e);return}e=j0(g)|0;a[1044496]=e;if((a[1041658]&8)==0){g=a[1041660]|0;h=e&255;f=(g&255)+h+(d[1106736]|0)|0;a[1106736]=(f&65280)>>>0>255|0;i=f&255;j=((f^h)&((g^e)&255^128))>>>7&255}else{g=b[520830]|0;h=g&255;f=g&240;g=((a[1106736]|0)+(e&15)&255)+(h&15)&255;if((g&255)>9){k=g+6&15;l=f+16&65535}else{k=g;l=f}f=l+(e&-16&255)&65535;if((f&65535)>144){a[1106736]=1;m=f+96&255&-16}else{a[1106736]=0;m=f&255}f=m|k;i=f;j=((f^e)&(e^-128^h)&255)>>>7}a[1106712]=j&1;a[1041660]=i;a[1106728]=i;a[1106720]=i;return}function uV(){var d=0,f=0,g=0;d=(c[348392]|0)+12|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}d=b[520829]|0;if((d&256)!=0){a[1041664]=(a[1041664]|0)+1&255;f=j0(e[520832]|0)|0;a[1041660]=f;a[1106728]=f;a[1106720]=f;a[1044496]=f;return}f=b[520832]|0;if((d&32)==0){d=j5((f&65535)+1|0,65535)|0;b[520830]=d;b[520832]=(b[520832]|0)+2&65535;a[1106728]=d<<16>>16!=0|0;g=(d&65535)>>>8&255;a[1106720]=g;a[1044496]=g;return}else{g=f+1&65535;b[520832]=g;f=j0(g&65535)|0;a[1041660]=f;a[1106728]=f;a[1106720]=f;a[1044496]=f;return}}function uW(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=c[260418]|0;if((a[1041658]&32)==0){f=j5(e,65535)|0;a[1044496]=(f&65535)>>>8&255;b[520836]=(b[520836]|0)+2&65535;w9(f);return}f=j0(e)|0;a[1044496]=f;b[520836]=(b[520836]|0)+1&65535;if((a[1041658]&8)==0){e=a[1041660]|0;g=f&255;h=(e&255)+g+(d[1106736]|0)|0;a[1106736]=(h&65280)>>>0>255|0;i=h&255;j=((h^g)&((e^f)&255^128))>>>7&255}else{e=b[520830]|0;g=e&255;h=e&240;e=((a[1106736]|0)+(f&15)&255)+(g&15)&255;if((e&255)>9){k=e+6&15;l=h+16&65535}else{k=e;l=h}h=l+(f&-16&255)&65535;if((h&65535)>144){a[1106736]=1;m=h+96&255&-16}else{a[1106736]=0;m=h&255}h=m|k;i=h;j=((h^f)&(f^-128^g)&255)>>>7}a[1106712]=j&1;a[1041660]=i;a[1106728]=i;a[1106720]=i;return}function uX(){var e=0,f=0,g=0;e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}if((a[1041658]&32)==0){e=b[520830]|0;f=(d[1106736]|0)<<16|e&65535;a[1106736]=e&1;e=f>>>1;b[520830]=e&65535;a[1106728]=(e&65535|0)!=0|0;g=f>>>9&255;a[1106720]=g;return}else{f=a[1041660]|0;e=(d[1106736]|0)<<8|f&255;a[1106736]=f&1;f=(e&65535)>>>1&255;a[1041660]=f;a[1106728]=f;g=f;a[1106720]=g;return}}function uY(){var d=0,f=0,g=0,h=0;d=(c[348392]|0)+12|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}b[520836]=j5((e[520832]|0)+1|0,65535)|0;d=(b[520832]|0)+3&65535;b[520832]=d;a[1041674|0]=j0(d&65535)|0;if((b[520829]&256)==0){f=b[520836]|0;g=f+1&65535;b[520836]=g;h=c[260418]|0;j4(h);return}a[1041665|0]=1;f=b[520836]|0;g=f+1&65535;b[520836]=g;h=c[260418]|0;j4(h);return}function uZ(){var d=0,e=0,f=0;d=c[276676]|0;e=j5(c[260418]|0,65535)|0;a[1044496]=(e&65535)>>>8&255;b[520836]=(b[520836]|0)+2&65535;f=j5(e&65535,16777215)|0;a[1044496]=(f&65535)>>>8&255;j4((f&65535)+d|0);return}function u_(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=(a[1041658]&32)==0;f=c[276674]|0;g=j5(c[260418]|0,65535)|0;a[1044496]=(g&65535)>>>8&255;b[520836]=(b[520836]|0)+2&65535;h=g&65535|f;if(e){e=j5(h,16777215)|0;a[1044496]=(e&65535)>>>8&255;w9(e);return}e=j0(h)|0;a[1044496]=e;if((a[1041658]&8)==0){h=a[1041660]|0;f=e&255;g=(h&255)+f+(d[1106736]|0)|0;a[1106736]=(g&65280)>>>0>255|0;i=g&255;j=((g^f)&((h^e)&255^128))>>>7&255}else{h=b[520830]|0;f=h&255;g=h&240;h=((a[1106736]|0)+(e&15)&255)+(f&15)&255;if((h&255)>9){k=h+6&15;l=g+16&65535}else{k=h;l=g}g=l+(e&-16&255)&65535;if((g&65535)>144){a[1106736]=1;m=g+96&255&-16}else{a[1106736]=0;m=g&255}g=m|k;i=g;j=((g^e)&(e^-128^f)&255)>>>7}a[1106712]=j&1;a[1041660]=i;a[1106728]=i;a[1106720]=i;return}function u$(){var e=0,f=0,g=0,h=0,i=0;e=(a[1041658]&32)==0;f=c[276674]|0;g=j5(c[260418]|0,65535)|0;a[1044496]=(g&65535)>>>8&255;b[520836]=(b[520836]|0)+2&65535;h=g&65535|f;if(e){e=j5(h,16777215)|0;f=(d[1106736]|0)<<16|e&65535;a[1106736]=e&1;e=f>>>1;g=(c[348392]|0)+6|0;c[348392]=g;if((g|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}j3(e&65535,h,16777215);a[1044496]=e&255;a[1106728]=(e&65535|0)!=0|0;i=f>>>9&255;a[1106720]=i;return}else{f=j0(h)|0;e=(d[1106736]|0)<<8|f&255;a[1106736]=f&1;f=(e&65535)>>>1;e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}e=f&255;j2(e,h);a[1044496]=e;a[1106728]=e;i=e;a[1106720]=i;return}}function u0(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=(a[1041658]&32)==0;f=j5(c[260418]|0,65535)|0;a[1044496]=(f&65535)>>>8&255;b[520836]=(b[520836]|0)+2&65535;g=j0(c[260418]|0)|0;a[1044496]=g;b[520836]=(b[520836]|0)+1&65535;h=(g&255)<<16|f&65535;if(e){e=j5(h,16777215)|0;a[1044496]=(e&65535)>>>8&255;w9(e);return}e=j0(h)|0;a[1044496]=e;if((a[1041658]&8)==0){h=a[1041660]|0;f=e&255;g=(h&255)+f+(d[1106736]|0)|0;a[1106736]=(g&65280)>>>0>255|0;i=g&255;j=((g^f)&((h^e)&255^128))>>>7&255}else{h=b[520830]|0;f=h&255;g=h&240;h=((a[1106736]|0)+(e&15)&255)+(f&15)&255;if((h&255)>9){k=h+6&15;l=g+16&65535}else{k=h;l=g}g=l+(e&-16&255)&65535;if((g&65535)>144){a[1106736]=1;m=g+96&255&-16}else{a[1106736]=0;m=g&255}g=m|k;i=g;j=((g^e)&(e^-128^f)&255)>>>7}a[1106712]=j&1;a[1041660]=i;a[1106728]=i;a[1106720]=i;return}function u1(){var e=0,f=0,g=0,h=0,i=0,j=0;e=j0(c[260418]|0)|0;a[1044496]=e;f=(b[520836]|0)+1&65535;b[520836]=f;g=f+(e<<24>>24)&65535;e=(g&65535)>>>8;if((a[1106712]|0)==0){return}f=(c[348392]|0)+6|0;c[348392]=f;h=c[348406]|0;if((f|0)<(h|0)){i=f;j=h}else{while(1){j1();h=c[348392]|0;f=c[348406]|0;if((h|0)<(f|0)){i=h;j=f;break}}}do{if((b[520829]&256)!=0){if((d[1041673|0]|0)==(e&65535|0)){break}f=i+6|0;c[348392]=f;if((f|0)<(j|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j=e<<8;e=j|g&255;if(((b[520836]^j)&65535)>4095){j4((c[276676]|0)+(e&65535)|0);return}else{b[520836]=e;return}}function u2(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=(a[1041658]&32)==0;g=j0(c[260418]|0)|0;a[1044496]=g;b[520836]=(b[520836]|0)+1&65535;h=b[520831]|0;i=h+(g&255)&65535;do{if((h&255)<<24>>24!=0){g=(c[348392]|0)+6|0;c[348392]=g;if((g|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);if((b[520829]&256)==0){j=65535}else{j=(a[1041662]|0)!=0?65535:255}h=j5(i&65535,j)|0;a[1044496]=(h&65535)>>>8&255;j=c[276674]|h&65535;if((a[1041658]&16)==0){k=4017}else{if(((d[1041668]|0)+(j&255)|0)>>>0>255){k=4017}}do{if((k|0)==4017){h=(c[348392]|0)+6|0;c[348392]=h;if((h|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);k=(e[520834]|0)+j|0;if(f){f=j5(k,16777215)|0;a[1044496]=(f&65535)>>>8&255;w9(f);return}f=j0(k)|0;a[1044496]=f;if((a[1041658]&8)==0){k=a[1041660]|0;j=f&255;h=(k&255)+j+(d[1106736]|0)|0;a[1106736]=(h&65280)>>>0>255|0;l=h&255;m=((h^j)&((k^f)&255^128))>>>7&255}else{k=b[520830]|0;j=k&255;h=k&240;k=((a[1106736]|0)+(f&15)&255)+(j&15)&255;if((k&255)>9){n=k+6&15;o=h+16&65535}else{n=k;o=h}h=o+(f&-16&255)&65535;if((h&65535)>144){a[1106736]=1;p=h+96&255&-16}else{a[1106736]=0;p=h&255}h=p|n;l=h;m=((h^f)&(f^-128^j)&255)>>>7}a[1106712]=m&1;a[1041660]=l;a[1106728]=l;a[1106720]=l;return}function u3(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=(a[1041658]&32)==0;f=j0(c[260418]|0)|0;a[1044496]=f;b[520836]=(b[520836]|0)+1&65535;g=b[520831]|0;h=g+(f&255)&65535;do{if((g&255)<<24>>24!=0){f=(c[348392]|0)+6|0;c[348392]=f;if((f|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);if((b[520829]&256)==0){i=65535}else{i=(a[1041662]|0)!=0?65535:255}g=j5(h&65535,i)|0;a[1044496]=(g&65535)>>>8&255;i=c[276674]|g&65535;if(e){e=j5(i,16777215)|0;a[1044496]=(e&65535)>>>8&255;w9(e);return}e=j0(i)|0;a[1044496]=e;if((a[1041658]&8)==0){i=a[1041660]|0;g=e&255;h=(i&255)+g+(d[1106736]|0)|0;a[1106736]=(h&65280)>>>0>255|0;j=h&255;k=((h^g)&((i^e)&255^128))>>>7&255}else{i=b[520830]|0;g=i&255;h=i&240;i=((a[1106736]|0)+(e&15)&255)+(g&15)&255;if((i&255)>9){l=i+6&15;m=h+16&65535}else{l=i;m=h}h=m+(e&-16&255)&65535;if((h&65535)>144){a[1106736]=1;n=h+96&255&-16}else{a[1106736]=0;n=h&255}h=n|l;j=h;k=((h^e)&(e^-128^g)&255)>>>7}a[1106712]=k&1;a[1041660]=j;a[1106728]=j;a[1106720]=j;return}function u4(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=(a[1041658]&32)==0;g=j0(c[260418]|0)|0;a[1044496]=g;b[520836]=(b[520836]|0)+1&65535;h=(b[520832]|0)+(g&255)&65535;g=(c[348392]|0)+6|0;c[348392]=g;if((g|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}g=j5(h&65535,16777215)|0;a[1044496]=(g&65535)>>>8&255;h=(e[520834]|0)+(g&65535)+(c[276674]|0)&16777215;g=(c[348392]|0)+6|0;c[348392]=g;if((g|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}if(f){f=j5(h,16777215)|0;a[1044496]=(f&65535)>>>8&255;w9(f);return}f=j0(h)|0;a[1044496]=f;if((a[1041658]&8)==0){h=a[1041660]|0;g=f&255;i=(h&255)+g+(d[1106736]|0)|0;a[1106736]=(i&65280)>>>0>255|0;j=i&255;k=((i^g)&((h^f)&255^128))>>>7&255}else{h=b[520830]|0;g=h&255;i=h&240;h=((a[1106736]|0)+(f&15)&255)+(g&15)&255;if((h&255)>9){l=h+6&15;m=i+16&65535}else{l=h;m=i}i=m+(f&-16&255)&65535;if((i&65535)>144){a[1106736]=1;n=i+96&255&-16}else{a[1106736]=0;n=i&255}i=n|l;j=i;k=((i^f)&(f^-128^g)&255)>>>7}a[1106712]=k&1;a[1041660]=j;a[1106728]=j;a[1106720]=j;return}function u5(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=(a[1041658]&32)==0;e=j0(c[260418]|0)|0;b[520836]=(b[520836]|0)+1&65535;f=b[520831]|0;g=f+(e&255)&65535;do{if((f&255)<<24>>24!=0){e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);f=g&255;e=(g&65535)>>>8;h=e&255;do{if((b[520829]&256)==0){i=4075}else{if((a[1041662]|0)!=0){i=4075;break}j=(a[1041666]|0)+f&255;k=h}}while(0);if((i|0)==4075){i=(b[520833]|0)+(e<<8|g&255)&65535;j=i&255;k=(i&65535)>>>8&255}i=(c[348392]|0)+6|0;c[348392]=i;if((i|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}i=((k&255)<<8|j&255)&65535;if(d){w7(0,i,65535);a[1044496]=0;return}else{j2(0,i);a[1044496]=0;return}}function u6(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=(a[1041658]&32)==0;f=j0(c[260418]|0)|0;a[1044496]=f;b[520836]=(b[520836]|0)+1&65535;g=b[520831]|0;h=g+(f&255)&65535;do{if((g&255)<<24>>24!=0){f=(c[348392]|0)+6|0;c[348392]=f;if((f|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);g=h&255;f=(h&65535)>>>8;i=f&255;do{if((b[520829]&256)==0){j=4090}else{if((a[1041662]|0)!=0){j=4090;break}k=(a[1041666]|0)+g&255;l=i}}while(0);if((j|0)==4090){j=(b[520833]|0)+(f<<8|h&255)&65535;k=j&255;l=(j&65535)>>>8&255}j=(c[348392]|0)+6|0;c[348392]=j;if((j|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}j=((l&255)<<8|k&255)&65535;if(e){e=j5(j,65535)|0;a[1044496]=(e&65535)>>>8&255;w9(e);return}e=j0(j)|0;a[1044496]=e;if((a[1041658]&8)==0){j=a[1041660]|0;k=e&255;l=(j&255)+k+(d[1106736]|0)|0;a[1106736]=(l&65280)>>>0>255|0;m=l&255;n=((l^k)&((j^e)&255^128))>>>7&255}else{j=b[520830]|0;k=j&255;l=j&240;j=((a[1106736]|0)+(e&15)&255)+(k&15)&255;if((j&255)>9){o=j+6&15;p=l+16&65535}else{o=j;p=l}l=p+(e&-16&255)&65535;if((l&65535)>144){a[1106736]=1;q=l+96&255&-16}else{a[1106736]=0;q=l&255}l=q|o;m=l;n=((l^e)&(e^-128^k)&255)>>>7}a[1106712]=n&1;a[1041660]=m;a[1106728]=m;a[1106720]=m;return}function u7(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=(a[1041658]&32)==0;f=j0(c[260418]|0)|0;a[1044496]=f;b[520836]=(b[520836]|0)+1&65535;g=b[520831]|0;h=g+(f&255)&65535;do{if((g&255)<<24>>24!=0){f=(c[348392]|0)+6|0;c[348392]=f;if((f|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);g=h&255;f=(h&65535)>>>8;i=f&255;do{if((b[520829]&256)==0){j=4113}else{if((a[1041662]|0)!=0){j=4113;break}k=(a[1041666]|0)+g&255;l=i}}while(0);if((j|0)==4113){j=(b[520833]|0)+(f<<8|h&255)&65535;k=j&255;l=(j&65535)>>>8&255}j=(c[348392]|0)+6|0;c[348392]=j;if((j|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}j=((l&255)<<8|k&255)&65535;if(e){e=j5(j,65535)|0;k=d[1106736]<<16|e&65535;a[1106736]=e&1;e=k>>>1;l=(c[348392]|0)+6|0;c[348392]=l;if((l|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}j3(e&65535,j,65535);a[1044496]=e&255;a[1106728]=(e&65535|0)!=0|0;m=k>>>9&255;a[1106720]=m;return}else{k=j0(j)|0;e=d[1106736]<<8|k&255;a[1106736]=k&1;k=(e&65535)>>>1;e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}e=k&255;j2(e,j);a[1044496]=e;a[1106728]=e;m=e;a[1106720]=m;return}}function u8(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=(a[1041658]&32)==0;g=j0(c[260418]|0)|0;a[1044496]=g;b[520836]=(b[520836]|0)+1&65535;h=b[520831]|0;i=h+(g&255)&65535;do{if((h&255)<<24>>24!=0){g=(c[348392]|0)+6|0;c[348392]=g;if((g|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);h=i&65535;i=j5(h,16777215)|0;a[1044496]=(i&65535)>>>8&255;g=j0(h+2|0)|0;a[1044496]=g;h=((g&255)<<16|i&65535)+(e[520834]|0)|0;if(f){f=j5(h,16777215)|0;a[1044496]=(f&65535)>>>8&255;w9(f);return}f=j0(h)|0;a[1044496]=f;if((a[1041658]&8)==0){h=a[1041660]|0;i=f&255;g=(h&255)+i+(d[1106736]|0)|0;a[1106736]=(g&65280)>>>0>255|0;j=g&255;k=((g^i)&((h^f)&255^128))>>>7&255}else{h=b[520830]|0;i=h&255;g=h&240;h=((a[1106736]|0)+(f&15)&255)+(i&15)&255;if((h&255)>9){l=h+6&15;m=g+16&65535}else{l=h;m=g}g=m+(f&-16&255)&65535;if((g&65535)>144){a[1106736]=1;n=g+96&255&-16}else{a[1106736]=0;n=g&255}g=n|l;j=g;k=((g^f)&(f^-128^i)&255)>>>7}a[1106712]=k&1;a[1041660]=j;a[1106728]=j;a[1106720]=j;return}function u9(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=(a[1041658]&32)==0;g=c[276674]|0;h=j5(c[260418]|0,65535)|0;a[1044496]=(h&65535)>>>8&255;b[520836]=(b[520836]|0)+2&65535;i=h&65535|g;if((a[1041658]&16)==0){j=4146}else{if(((d[1041668]|0)+(i&255)|0)>>>0>255){j=4146}}do{if((j|0)==4146){g=(c[348392]|0)+6|0;c[348392]=g;if((g|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j=(e[520834]|0)+i|0;if(f){f=j5(j,16777215)|0;a[1044496]=(f&65535)>>>8&255;w9(f);return}f=j0(j)|0;a[1044496]=f;if((a[1041658]&8)==0){j=a[1041660]|0;i=f&255;g=(j&255)+i+(d[1106736]|0)|0;a[1106736]=(g&65280)>>>0>255|0;k=g&255;l=((g^i)&((j^f)&255^128))>>>7&255}else{j=b[520830]|0;i=j&255;g=j&240;j=((a[1106736]|0)+(f&15)&255)+(i&15)&255;if((j&255)>9){m=j+6&15;n=g+16&65535}else{m=j;n=g}g=n+(f&-16&255)&65535;if((g&65535)>144){a[1106736]=1;o=g+96&255&-16}else{a[1106736]=0;o=g&255}g=o|m;k=g;l=((g^f)&(f^-128^i)&255)>>>7}a[1106712]=l&1;a[1041660]=k;a[1106728]=k;a[1106720]=k;return}function va(){var d=0,f=0,g=0;d=(c[348392]|0)+12|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}d=b[520829]|0;if((d&256)!=0){a[1041664]=(a[1041664]|0)+1&255;f=j0(e[520832]|0)|0;a[1041668]=f;a[1106728]=f;a[1106720]=f;a[1044496]=f;return}f=b[520832]|0;if((d&16)==0){d=j5((f&65535)+1|0,65535)|0;b[520834]=d;b[520832]=(b[520832]|0)+2&65535;a[1106728]=d<<16>>16!=0|0;g=(d&65535)>>>8&255;a[1106720]=g;a[1044496]=g;return}else{g=f+1&65535;b[520832]=g;f=j0(g&65535)|0;a[1041668]=f;a[1106728]=f;a[1106720]=f;a[1044496]=f;return}}function vb(){var d=0,e=0,f=0;d=c[276676]|0;e=j5(c[260418]|0,65535)|0;a[1044496]=(e&65535)>>>8&255;b[520836]=(b[520836]|0)+2&65535;f=(c[348392]|0)+6|0;c[348392]=f;if((f|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}f=j5((b[520833]|0)+e&65535|c[276676],65535)|0;a[1044496]=(f&65535)>>>8&255;j4((f&65535)+d|0);return}function vc(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=(a[1041658]&32)==0;g=c[276674]|0;h=j5(c[260418]|0,65535)|0;a[1044496]=(h&65535)>>>8&255;b[520836]=(b[520836]|0)+2&65535;i=h&65535|g;if((a[1041658]&16)==0){j=4178}else{if(((d[1041666]|0)+(i&255)|0)>>>0>255){j=4178}}do{if((j|0)==4178){g=(c[348392]|0)+6|0;c[348392]=g;if((g|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j=(e[520833]|0)+i|0;if(f){f=j5(j,16777215)|0;a[1044496]=(f&65535)>>>8&255;w9(f);return}f=j0(j)|0;a[1044496]=f;if((a[1041658]&8)==0){j=a[1041660]|0;i=f&255;g=(j&255)+i+(d[1106736]|0)|0;a[1106736]=(g&65280)>>>0>255|0;k=g&255;l=((g^i)&((j^f)&255^128))>>>7&255}else{j=b[520830]|0;i=j&255;g=j&240;j=((a[1106736]|0)+(f&15)&255)+(i&15)&255;if((j&255)>9){m=j+6&15;n=g+16&65535}else{m=j;n=g}g=n+(f&-16&255)&65535;if((g&65535)>144){a[1106736]=1;o=g+96&255&-16}else{a[1106736]=0;o=g&255}g=o|m;k=g;l=((g^f)&(f^-128^i)&255)>>>7}a[1106712]=l&1;a[1041660]=k;a[1106728]=k;a[1106720]=k;return}function vd(){var f=0,g=0,h=0,i=0,j=0;f=(a[1041658]&32)==0;g=c[276674]|0;h=j5(c[260418]|0,65535)|0;a[1044496]=(h&65535)>>>8&255;b[520836]=(b[520836]|0)+2&65535;i=h&65535|g;g=(c[348392]|0)+6|0;c[348392]=g;if((g|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}g=(e[520833]|0)+i|0;if(f){f=j5(g,16777215)|0;i=(d[1106736]|0)<<16|f&65535;a[1106736]=f&1;f=i>>>1;h=(c[348392]|0)+6|0;c[348392]=h;if((h|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}j3(f&65535,g,16777215);a[1044496]=f&255;a[1106728]=(f&65535|0)!=0|0;j=i>>>9&255;a[1106720]=j;return}else{i=j0(g)|0;f=(d[1106736]|0)<<8|i&255;a[1106736]=i&1;i=(f&65535)>>>1;f=(c[348392]|0)+6|0;c[348392]=f;if((f|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}f=i&255;j2(f,g);a[1044496]=f;a[1106728]=f;j=f;a[1106720]=j;return}}function ve(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=(a[1041658]&32)==0;g=j5(c[260418]|0,65535)|0;a[1044496]=(g&65535)>>>8&255;b[520836]=(b[520836]|0)+2&65535;h=j0(c[260418]|0)|0;a[1044496]=h;b[520836]=(b[520836]|0)+1&65535;i=(e[520833]|0)+((h&255)<<16|g&65535)|0;if(f){f=j5(i,16777215)|0;a[1044496]=(f&65535)>>>8&255;w9(f);return}f=j0(i)|0;a[1044496]=f;if((a[1041658]&8)==0){i=a[1041660]|0;g=f&255;h=(i&255)+g+(d[1106736]|0)|0;a[1106736]=(h&65280)>>>0>255|0;j=h&255;k=((h^g)&((i^f)&255^128))>>>7&255}else{i=b[520830]|0;g=i&255;h=i&240;i=((a[1106736]|0)+(f&15)&255)+(g&15)&255;if((i&255)>9){l=i+6&15;m=h+16&65535}else{l=i;m=h}h=m+(f&-16&255)&65535;if((h&65535)>144){a[1106736]=1;n=h+96&255&-16}else{a[1106736]=0;n=h&255}h=n|l;j=h;k=((h^f)&(f^-128^g)&255)>>>7}a[1106712]=k&1;a[1041660]=j;a[1106728]=j;a[1106720]=j;return}function vf(){var e=0,f=0,g=0,h=0,i=0,j=0;e=j0(c[260418]|0)|0;a[1044496]=e;f=(b[520836]|0)+1&65535;b[520836]=f;g=f+(e<<24>>24)&65535;e=(g&65535)>>>8;f=(c[348392]|0)+6|0;c[348392]=f;h=c[348406]|0;if((f|0)<(h|0)){i=f;j=h}else{while(1){j1();h=c[348392]|0;f=c[348406]|0;if((h|0)<(f|0)){i=h;j=f;break}}}do{if((b[520829]&256)!=0){if((d[1041673|0]|0|0)==(e&65535|0)){break}f=i+6|0;c[348392]=f;if((f|0)<(j|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j=e<<8;e=j|g&255;if(((b[520836]^j)&65535)>4095){j4((c[276676]|0)+(e&65535)|0);return}else{b[520836]=e;return}}function vg(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=(a[1041658]&32)==0;e=j0(c[260418]|0)|0;a[1044496]=e;b[520836]=(b[520836]|0)+1&65535;f=b[520831]|0;g=f+(e&255)&65535;do{if((f&255)<<24>>24!=0){e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);f=g&255;e=(g&65535)>>>8;h=e&255;i=b[520829]|0;do{if((i&256)==0){j=4237}else{if((a[1041662]|0)!=0){j=4237;break}k=(a[1041666]|0)+f&255;l=h}}while(0);if((j|0)==4237){j=(b[520833]|0)+(e<<8|g&255)&65535;k=j&255;l=(j&65535)>>>8&255}j=(c[348392]|0)+6|0;c[348392]=j;if((j|0)<(c[348406]|0)){m=i}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));m=b[520829]|0}if((m&256)==0){n=65535}else{n=(a[1041662]|0)!=0?65535:255}m=(j5(((l&255)<<8|k&255)&65535,n)|0)&65535;n=c[276674]|m;if(d){w7(b[520830]|0,n,16777215);o=1041661|0;p=a[o]|0;a[1044496]=p;return}else{j2(a[1041660]|0,n);o=1041660;p=a[o]|0;a[1044496]=p;return}}function vh(){var d=0,e=0,f=0;d=c[276676]|0;e=j5(c[260418]|0,65535)|0;a[1044496]=(e&65535)>>>8&255;f=(b[520836]|0)+2&65535;b[520836]=f;j4(((f&65535)+(e&65535)&65535)+d|0);return}function vi(){var d=0,e=0,f=0,g=0,h=0;d=(a[1041658]&32)==0;e=j0(c[260418]|0)|0;b[520836]=(b[520836]|0)+1&65535;f=(b[520832]|0)+(e&255)&65535;e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}e=f&65535;if(d){w7(b[520830]|0,e,16777215);g=1041661|0;h=a[g]|0;a[1044496]=h;return}else{j2(a[1041660]|0,e);g=1041660;h=a[g]|0;a[1044496]=h;return}}function vj(){var d=0,e=0,f=0,g=0,h=0,i=0;d=(a[1041658]&16)==0;e=j0(c[260418]|0)|0;b[520836]=(b[520836]|0)+1&65535;f=b[520831]|0;g=f+(e&255)&65535;do{if((f&255)<<24>>24!=0){e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);f=g&65535;if(d){w7(b[520834]|0,f,65535);h=1041669|0;i=a[h]|0;a[1044496]=i;return}else{j2(a[1041668]|0,f);h=1041668;i=a[h]|0;a[1044496]=i;return}}function vk(){var d=0,e=0,f=0,g=0,h=0,i=0;d=(a[1041658]&32)==0;e=j0(c[260418]|0)|0;b[520836]=(b[520836]|0)+1&65535;f=b[520831]|0;g=f+(e&255)&65535;do{if((f&255)<<24>>24!=0){e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);f=g&65535;if(d){w7(b[520830]|0,f,65535);h=1041661|0;i=a[h]|0;a[1044496]=i;return}else{j2(a[1041660]|0,f);h=1041660;i=a[h]|0;a[1044496]=i;return}}function vl(){var d=0,e=0,f=0,g=0,h=0,i=0;d=(a[1041658]&16)==0;e=j0(c[260418]|0)|0;b[520836]=(b[520836]|0)+1&65535;f=b[520831]|0;g=f+(e&255)&65535;do{if((f&255)<<24>>24!=0){e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);f=g&65535;if(d){w7(b[520833]|0,f,65535);h=1041667|0;i=a[h]|0;a[1044496]=i;return}else{j2(a[1041666]|0,f);h=1041666;i=a[h]|0;a[1044496]=i;return}}function vm(){var d=0,e=0,f=0,g=0,h=0,i=0;d=(a[1041658]&32)==0;e=j0(c[260418]|0)|0;a[1044496]=e;b[520836]=(b[520836]|0)+1&65535;f=b[520831]|0;g=f+(e&255)&65535;do{if((f&255)<<24>>24!=0){e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);f=g&65535;g=j5(f,16777215)|0;a[1044496]=(g&65535)>>>8&255;e=j0(f+2|0)|0;a[1044496]=e;f=(e&255)<<16|g&65535;if(d){w7(b[520830]|0,f,16777215);h=1041661|0;i=a[h]|0;a[1044496]=i;return}else{j2(a[1041660]|0,f);h=1041660;i=a[h]|0;a[1044496]=i;return}}function vn(){var d=0,e=0;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}if((a[1041658]&16)==0){d=(b[520834]|0)-1&65535;b[520834]=d;a[1106728]=d<<16>>16!=0|0;e=(d&65535)>>>8&255;a[1106720]=e;return}else{d=(a[1041668]|0)-1&255;a[1041668]=d;a[1106728]=d;e=d;a[1106720]=e;return}}function vo(){var d=0,e=0,f=0;if((a[1041658]&32)==0){d=b[520830]|0;e=j5(c[260418]|0,65535)|0;a[1044496]=(e&65535)>>>8&255;b[520836]=(b[520836]|0)+2&65535;f=(e&d)<<16>>16!=0|0;a[1106728]=f;return}else{d=a[1041660]|0;e=j0(c[260418]|0)|0;a[1044496]=e;b[520836]=(b[520836]|0)+1&65535;f=e&d;a[1106728]=f;return}}function vp(){var d=0,e=0;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}if((a[1041658]&32)==0){d=b[520833]|0;b[520830]=d;a[1106728]=d<<16>>16!=0|0;e=(d&65535)>>>8&255;a[1106720]=e;return}else{d=a[1041666]|0;a[1041660]=d;a[1106728]=d;e=d;a[1106720]=e;return}}function vq(){var d=0,e=0,f=0;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}d=a[1041656]|0;e=b[520832]|0;if((b[520829]&256)==0){b[520832]=e-1&65535;j2(d,e&65535);f=a[1041656]|0;a[1044496]=f;return}else{j2(d,e&65535);a[1041664]=(a[1041664]|0)-1&255;f=a[1041656]|0;a[1044496]=f;return}}function vr(){var d=0,e=0,f=0,g=0,h=0,i=0;d=(a[1041658]&16)==0;e=c[276674]|0;f=j5(c[260418]|0,65535)|0;b[520836]=(b[520836]|0)+2&65535;g=f&65535|e;if(d){w7(b[520834]|0,g,65535);h=1041669|0;i=a[h]|0;a[1044496]=i;return}else{j2(a[1041668]|0,g);h=1041668;i=a[h]|0;a[1044496]=i;return}}function vs(){var d=0,e=0,f=0,g=0,h=0,i=0;d=(a[1041658]&32)==0;e=c[276674]|0;f=j5(c[260418]|0,65535)|0;b[520836]=(b[520836]|0)+2&65535;g=f&65535|e;if(d){w7(b[520830]|0,g,16777215);h=1041661|0;i=a[h]|0;a[1044496]=i;return}else{j2(a[1041660]|0,g);h=1041660;i=a[h]|0;a[1044496]=i;return}}function vt(){var d=0,e=0,f=0,g=0,h=0,i=0;d=(a[1041658]&16)==0;e=c[276674]|0;f=j5(c[260418]|0,65535)|0;b[520836]=(b[520836]|0)+2&65535;g=f&65535|e;if(d){w7(b[520833]|0,g,65535);h=1041667|0;i=a[h]|0;a[1044496]=i;return}else{j2(a[1041666]|0,g);h=1041666;i=a[h]|0;a[1044496]=i;return}}function vu(){var d=0,e=0,f=0,g=0,h=0,i=0;d=(a[1041658]&32)==0;e=j5(c[260418]|0,65535)|0;a[1044496]=(e&65535)>>>8&255;b[520836]=(b[520836]|0)+2&65535;f=j0(c[260418]|0)|0;b[520836]=(b[520836]|0)+1&65535;g=(f&255)<<16|e&65535;if(d){w7(b[520830]|0,g,16777215);h=1041661|0;i=a[h]|0;a[1044496]=i;return}else{j2(a[1041660]|0,g);h=1041660;i=a[h]|0;a[1044496]=i;return}}function vv(){var e=0,f=0,g=0,h=0,i=0,j=0;e=j0(c[260418]|0)|0;a[1044496]=e;f=(b[520836]|0)+1&65535;b[520836]=f;g=f+(e<<24>>24)&65535;e=(g&65535)>>>8;if((a[1106736]|0)!=0){return}f=(c[348392]|0)+6|0;c[348392]=f;h=c[348406]|0;if((f|0)<(h|0)){i=f;j=h}else{while(1){j1();h=c[348392]|0;f=c[348406]|0;if((h|0)<(f|0)){i=h;j=f;break}}}do{if((b[520829]&256)!=0){if((d[1041673|0]|0)==(e&65535|0)){break}f=i+6|0;c[348392]=f;if((f|0)<(j|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j=e<<8;e=j|g&255;if(((b[520836]^j)&65535)>4095){j4((c[276676]|0)+(e&65535)|0);return}else{b[520836]=e;return}}function vw(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0;d=(a[1041658]&32)==0;f=j0(c[260418]|0)|0;a[1044496]=f;b[520836]=(b[520836]|0)+1&65535;g=b[520831]|0;h=g+(f&255)&65535;do{if((g&255)<<24>>24!=0){f=(c[348392]|0)+6|0;c[348392]=f;if((f|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);if((b[520829]&256)==0){i=65535}else{i=(a[1041662]|0)!=0?65535:255}g=(j5(h&65535,i)|0)&65535;i=c[276674]|g;g=(c[348392]|0)+6|0;c[348392]=g;if((g|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}g=(e[520834]|0)+i|0;if(d){w7(b[520830]|0,g,16777215);j=1041661|0;k=a[j]|0;a[1044496]=k;return}else{j2(a[1041660]|0,g);j=1041660;k=a[j]|0;a[1044496]=k;return}}function vx(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=(a[1041658]&32)==0;e=j0(c[260418]|0)|0;a[1044496]=e;b[520836]=(b[520836]|0)+1&65535;f=b[520831]|0;g=f+(e&255)&65535;do{if((f&255)<<24>>24!=0){e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);if((b[520829]&256)==0){h=65535}else{h=(a[1041662]|0)!=0?65535:255}f=(j5(g&65535,h)|0)&65535;h=c[276674]|f;if(d){w7(b[520830]|0,h,16777215);i=1041661|0;j=a[i]|0;a[1044496]=j;return}else{j2(a[1041660]|0,h);i=1041660;j=a[i]|0;a[1044496]=j;return}}function vy(){var d=0,f=0,g=0,h=0,i=0;d=(a[1041658]&32)==0;f=j0(c[260418]|0)|0;a[1044496]=f;b[520836]=(b[520836]|0)+1&65535;g=(b[520832]|0)+(f&255)&65535;f=(c[348392]|0)+6|0;c[348392]=f;if((f|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}f=(j5(g&65535,16777215)|0)&65535;g=(e[520834]|0)+f+(c[276674]|0)&16777215;f=(c[348392]|0)+6|0;c[348392]=f;if((f|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}if(d){w7(b[520830]|0,g,16777215);h=1041661|0;i=a[h]|0;a[1044496]=i;return}else{j2(a[1041660]|0,g);h=1041660;i=a[h]|0;a[1044496]=i;return}}function vz(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=(a[1041658]&16)==0;e=j0(c[260418]|0)|0;b[520836]=(b[520836]|0)+1&65535;f=b[520831]|0;g=f+(e&255)&65535;do{if((f&255)<<24>>24!=0){e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);f=g&255;e=(g&65535)>>>8;h=e&255;do{if((b[520829]&256)==0){i=4402}else{if((a[1041662]|0)!=0){i=4402;break}j=(a[1041666]|0)+f&255;k=h}}while(0);if((i|0)==4402){i=(b[520833]|0)+(e<<8|g&255)&65535;j=i&255;k=(i&65535)>>>8&255}i=(c[348392]|0)+6|0;c[348392]=i;if((i|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}i=((k&255)<<8|j&255)&65535;if(d){w7(b[520834]|0,i,65535);l=1041669|0;m=a[l]|0;a[1044496]=m;return}else{j2(a[1041668]|0,i);l=1041668;m=a[l]|0;a[1044496]=m;return}}function vA(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=(a[1041658]&32)==0;e=j0(c[260418]|0)|0;b[520836]=(b[520836]|0)+1&65535;f=b[520831]|0;g=f+(e&255)&65535;do{if((f&255)<<24>>24!=0){e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);f=g&255;e=(g&65535)>>>8;h=e&255;do{if((b[520829]&256)==0){i=4417}else{if((a[1041662]|0)!=0){i=4417;break}j=(a[1041666]|0)+f&255;k=h}}while(0);if((i|0)==4417){i=(b[520833]|0)+(e<<8|g&255)&65535;j=i&255;k=(i&65535)>>>8&255}i=(c[348392]|0)+6|0;c[348392]=i;if((i|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}i=((k&255)<<8|j&255)&65535;if(d){w7(b[520830]|0,i,65535);l=1041661|0;m=a[l]|0;a[1044496]=m;return}else{j2(a[1041660]|0,i);l=1041660;m=a[l]|0;a[1044496]=m;return}}function vB(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=(a[1041658]&16)==0;e=j0(c[260418]|0)|0;b[520836]=(b[520836]|0)+1&65535;f=b[520831]|0;g=f+(e&255)&65535;do{if((f&255)<<24>>24!=0){e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);f=g&255;e=(g&65535)>>>8;h=e&255;do{if((b[520829]&256)==0){i=4432}else{if((a[1041662]|0)!=0){i=4432;break}j=(a[1041668]|0)+f&255;k=h}}while(0);if((i|0)==4432){i=(b[520834]|0)+(e<<8|g&255)&65535;j=i&255;k=(i&65535)>>>8&255}i=(c[348392]|0)+6|0;c[348392]=i;if((i|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}i=((k&255)<<8|j&255)&65535;if(d){w7(b[520833]|0,i,65535);l=1041667|0;m=a[l]|0;a[1044496]=m;return}else{j2(a[1041666]|0,i);l=1041666;m=a[l]|0;a[1044496]=m;return}}function vC(){var d=0,f=0,g=0,h=0,i=0,j=0;d=(a[1041658]&32)==0;f=j0(c[260418]|0)|0;a[1044496]=f;b[520836]=(b[520836]|0)+1&65535;g=b[520831]|0;h=g+(f&255)&65535;do{if((g&255)<<24>>24!=0){f=(c[348392]|0)+6|0;c[348392]=f;if((f|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);g=h&65535;h=j5(g,16777215)|0;a[1044496]=(h&65535)>>>8&255;f=j0(g+2|0)|0;a[1044496]=f;g=((f&255)<<16|h&65535)+(e[520834]|0)|0;if(d){w7(b[520830]|0,g,16777215);i=1041661|0;j=a[i]|0;a[1044496]=j;return}else{j2(a[1041660]|0,g);i=1041660;j=a[i]|0;a[1044496]=j;return}}function vD(){var d=0,e=0;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}if((a[1041658]&32)==0){d=b[520834]|0;b[520830]=d;a[1106728]=d<<16>>16!=0|0;e=(d&65535)>>>8&255;a[1106720]=e;return}else{d=a[1041668]|0;a[1041660]=d;a[1106728]=d;e=d;a[1106720]=e;return}}function vE(){var d=0,f=0,g=0,h=0,i=0,j=0;d=(a[1041658]&32)==0;f=c[276674]|0;g=j5(c[260418]|0,65535)|0;b[520836]=(b[520836]|0)+2&65535;h=g&65535|f;f=(c[348392]|0)+6|0;c[348392]=f;if((f|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}f=(e[520834]|0)+h|0;if(d){w7(b[520830]|0,f,16777215);i=1041661|0;j=a[i]|0;a[1044496]=j;return}else{j2(a[1041660]|0,f);i=1041660;j=a[i]|0;a[1044496]=j;return}}function vF(){var d=0,e=0;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}if((a[1041658]&16)==0){d=b[520833]|0;b[520834]=d;a[1106728]=d<<16>>16!=0|0;e=(d&65535)>>>8&255;a[1106720]=e;return}else{d=a[1041666]|0;a[1041668]=d;a[1106728]=d;e=d;a[1106720]=e;return}}function vG(){var d=0,e=0,f=0,g=0;d=(a[1041658]&32)==0;e=c[276674]|0;f=j5(c[260418]|0,65535)|0;b[520836]=(b[520836]|0)+2&65535;g=f&65535|e;if(d){w7(0,g,16777215);a[1044496]=0;return}else{j2(0,g);a[1044496]=0;return}}function vH(){var d=0,f=0,g=0,h=0,i=0,j=0;d=(a[1041658]&32)==0;f=c[276674]|0;g=j5(c[260418]|0,65535)|0;b[520836]=(b[520836]|0)+2&65535;h=g&65535|f;f=(c[348392]|0)+6|0;c[348392]=f;if((f|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}f=(e[520833]|0)+h|0;if(d){w7(b[520830]|0,f,16777215);i=1041661|0;j=a[i]|0;a[1044496]=j;return}else{j2(a[1041660]|0,f);i=1041660;j=a[i]|0;a[1044496]=j;return}}function vI(){var d=0,f=0,g=0,h=0;d=(a[1041658]&32)==0;f=c[276674]|0;g=j5(c[260418]|0,65535)|0;b[520836]=(b[520836]|0)+2&65535;h=g&65535|f;f=(c[348392]|0)+6|0;c[348392]=f;if((f|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}f=(e[520833]|0)+h|0;if(d){w7(0,f,16777215);a[1044496]=0;return}else{j2(0,f);a[1044496]=0;return}}function vJ(){var d=0,f=0,g=0,h=0,i=0,j=0;d=(a[1041658]&32)==0;f=j5(c[260418]|0,65535)|0;a[1044496]=(f&65535)>>>8&255;b[520836]=(b[520836]|0)+2&65535;g=j0(c[260418]|0)|0;b[520836]=(b[520836]|0)+1&65535;h=(e[520833]|0)+((g&255)<<16|f&65535)|0;if(d){w7(b[520830]|0,h,16777215);i=1041661|0;j=a[i]|0;a[1044496]=j;return}else{j2(a[1041660]|0,h);i=1041660;j=a[i]|0;a[1044496]=j;return}}function vK(){var d=0,e=0,f=0,g=0,h=0;d=c[260418]|0;if((a[1041658]&16)==0){e=j5(d,65535)|0;f=(e&65535)>>>8&255;a[1044496]=f;b[520836]=(b[520836]|0)+2&65535;b[520834]=e;g=f;h=e<<16>>16!=0|0;a[1106728]=h;a[1106720]=g;return}else{e=j0(d)|0;a[1044496]=e;b[520836]=(b[520836]|0)+1&65535;a[1041668]=e;g=e;h=e;a[1106728]=h;a[1106720]=g;return}}function vL(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=(a[1041658]&32)==0;e=j0(c[260418]|0)|0;a[1044496]=e;b[520836]=(b[520836]|0)+1&65535;f=b[520831]|0;g=f+(e&255)&65535;do{if((f&255)<<24>>24!=0){e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);f=g&255;e=(g&65535)>>>8;h=e&255;i=b[520829]|0;do{if((i&256)==0){j=4514}else{if((a[1041662]|0)!=0){j=4514;break}k=(a[1041666]|0)+f&255;l=h}}while(0);if((j|0)==4514){j=(b[520833]|0)+(e<<8|g&255)&65535;k=j&255;l=(j&65535)>>>8&255}j=(c[348392]|0)+6|0;c[348392]=j;if((j|0)<(c[348406]|0)){m=i}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));m=b[520829]|0}if((m&256)==0){n=65535}else{n=(a[1041662]|0)!=0?65535:255}m=j5(((l&255)<<8|k&255)&65535,n)|0;a[1044496]=(m&65535)>>>8&255;n=c[276674]|m&65535;if(d){d=j5(n,16777215)|0;m=(d&65535)>>>8&255;a[1044496]=m;b[520830]=d;o=m;p=d<<16>>16!=0|0;a[1106728]=p;a[1106720]=o;return}else{d=j0(n)|0;a[1044496]=d;a[1041660]=d;o=d;p=d;a[1106728]=p;a[1106720]=o;return}}function vM(){var d=0,e=0,f=0,g=0,h=0;d=c[260418]|0;if((a[1041658]&16)==0){e=j5(d,65535)|0;f=(e&65535)>>>8&255;a[1044496]=f;b[520836]=(b[520836]|0)+2&65535;b[520833]=e;g=f;h=e<<16>>16!=0|0;a[1106728]=h;a[1106720]=g;return}else{e=j0(d)|0;a[1044496]=e;b[520836]=(b[520836]|0)+1&65535;a[1041666]=e;g=e;h=e;a[1106728]=h;a[1106720]=g;return}}function vN(){var d=0,e=0,f=0,g=0,h=0;d=(a[1041658]&32)==0;e=j0(c[260418]|0)|0;a[1044496]=e;b[520836]=(b[520836]|0)+1&65535;f=(b[520832]|0)+(e&255)&65535;e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}e=f&65535;if(d){d=j5(e,16777215)|0;f=(d&65535)>>>8&255;a[1044496]=f;b[520830]=d;g=f;h=d<<16>>16!=0|0;a[1106728]=h;a[1106720]=g;return}else{d=j0(e)|0;a[1044496]=d;a[1041660]=d;g=d;h=d;a[1106728]=h;a[1106720]=g;return}}function vO(){var d=0,e=0,f=0,g=0,h=0,i=0;d=(a[1041658]&16)==0;e=j0(c[260418]|0)|0;a[1044496]=e;b[520836]=(b[520836]|0)+1&65535;f=b[520831]|0;g=f+(e&255)&65535;do{if((f&255)<<24>>24!=0){e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);f=g&65535;if(d){d=j5(f,65535)|0;g=(d&65535)>>>8&255;a[1044496]=g;b[520834]=d;h=g;i=d<<16>>16!=0|0;a[1106728]=i;a[1106720]=h;return}else{d=j0(f)|0;a[1044496]=d;a[1041668]=d;h=d;i=d;a[1106728]=i;a[1106720]=h;return}}function vP(){var d=0,e=0,f=0,g=0,h=0,i=0;d=(a[1041658]&32)==0;e=j0(c[260418]|0)|0;a[1044496]=e;b[520836]=(b[520836]|0)+1&65535;f=b[520831]|0;g=f+(e&255)&65535;do{if((f&255)<<24>>24!=0){e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);f=g&65535;if(d){d=j5(f,65535)|0;g=(d&65535)>>>8&255;a[1044496]=g;b[520830]=d;h=g;i=d<<16>>16!=0|0;a[1106728]=i;a[1106720]=h;return}else{d=j0(f)|0;a[1044496]=d;a[1041660]=d;h=d;i=d;a[1106728]=i;a[1106720]=h;return}}function vQ(){var d=0,e=0,f=0,g=0,h=0,i=0;d=(a[1041658]&16)==0;e=j0(c[260418]|0)|0;a[1044496]=e;b[520836]=(b[520836]|0)+1&65535;f=b[520831]|0;g=f+(e&255)&65535;do{if((f&255)<<24>>24!=0){e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);f=g&65535;if(d){d=j5(f,65535)|0;g=(d&65535)>>>8&255;a[1044496]=g;b[520833]=d;h=g;i=d<<16>>16!=0|0;a[1106728]=i;a[1106720]=h;return}else{d=j0(f)|0;a[1044496]=d;a[1041666]=d;h=d;i=d;a[1106728]=i;a[1106720]=h;return}}function vR(){var d=0,e=0,f=0,g=0,h=0,i=0;d=(a[1041658]&32)==0;e=j0(c[260418]|0)|0;a[1044496]=e;b[520836]=(b[520836]|0)+1&65535;f=b[520831]|0;g=f+(e&255)&65535;do{if((f&255)<<24>>24!=0){e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);f=g&65535;g=j5(f,16777215)|0;a[1044496]=(g&65535)>>>8&255;e=j0(f+2|0)|0;a[1044496]=e;f=(e&255)<<16|g&65535;if(d){d=j5(f,16777215)|0;g=(d&65535)>>>8&255;a[1044496]=g;b[520830]=d;h=g;i=d<<16>>16!=0|0;a[1106728]=i;a[1106720]=h;return}else{d=j0(f)|0;a[1044496]=d;a[1041660]=d;h=d;i=d;a[1106728]=i;a[1106720]=h;return}}function vS(){var d=0,e=0;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}if((a[1041658]&16)==0){d=b[520830]|0;b[520834]=d;a[1106728]=d<<16>>16!=0|0;e=(d&65535)>>>8&255;a[1106720]=e;return}else{d=a[1041660]|0;a[1041668]=d;a[1106728]=d;e=d;a[1106720]=e;return}}function vT(){var d=0,e=0,f=0,g=0,h=0;d=c[260418]|0;if((a[1041658]&32)==0){e=j5(d,65535)|0;f=(e&65535)>>>8&255;a[1044496]=f;b[520836]=(b[520836]|0)+2&65535;b[520830]=e;g=f;h=e<<16>>16!=0|0;a[1106728]=h;a[1106720]=g;return}else{e=j0(d)|0;a[1044496]=e;b[520836]=(b[520836]|0)+1&65535;a[1041660]=e;g=e;h=e;a[1106728]=h;a[1106720]=g;return}}function vU(){var d=0,e=0;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}if((a[1041658]&16)==0){d=b[520830]|0;b[520833]=d;a[1106728]=d<<16>>16!=0|0;e=(d&65535)>>>8&255;a[1106720]=e;return}else{d=a[1041660]|0;a[1041666]=d;a[1106728]=d;e=d;a[1106720]=e;return}}function vV(){var d=0,f=0;d=(c[348392]|0)+12|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}if((b[520829]&256)==0){d=(b[520832]|0)+1&65535;b[520832]=d;f=j0(d&65535)|0}else{a[1041664]=(a[1041664]|0)+1&255;f=j0(e[520832]|0)|0}a[1041656]=f;a[1106728]=f;a[1106720]=f;c[276674]=(f&255)<<16;a[1044496]=f;return}function vW(){var d=0,e=0,f=0,g=0,h=0,i=0;d=(a[1041658]&16)==0;e=c[276674]|0;f=j5(c[260418]|0,65535)|0;a[1044496]=(f&65535)>>>8&255;b[520836]=(b[520836]|0)+2&65535;g=f&65535|e;if(d){d=j5(g,65535)|0;e=(d&65535)>>>8&255;a[1044496]=e;b[520834]=d;h=e;i=d<<16>>16!=0|0;a[1106728]=i;a[1106720]=h;return}else{d=j0(g)|0;a[1044496]=d;a[1041668]=d;h=d;i=d;a[1106728]=i;a[1106720]=h;return}}function vX(){var d=0,e=0,f=0,g=0,h=0,i=0;d=(a[1041658]&32)==0;e=c[276674]|0;f=j5(c[260418]|0,65535)|0;a[1044496]=(f&65535)>>>8&255;b[520836]=(b[520836]|0)+2&65535;g=f&65535|e;if(d){d=j5(g,16777215)|0;e=(d&65535)>>>8&255;a[1044496]=e;b[520830]=d;h=e;i=d<<16>>16!=0|0;a[1106728]=i;a[1106720]=h;return}else{d=j0(g)|0;a[1044496]=d;a[1041660]=d;h=d;i=d;a[1106728]=i;a[1106720]=h;return}}function vY(){var d=0,e=0,f=0,g=0,h=0,i=0;d=(a[1041658]&16)==0;e=c[276674]|0;f=j5(c[260418]|0,65535)|0;a[1044496]=(f&65535)>>>8&255;b[520836]=(b[520836]|0)+2&65535;g=f&65535|e;if(d){d=j5(g,65535)|0;e=(d&65535)>>>8&255;a[1044496]=e;b[520833]=d;h=e;i=d<<16>>16!=0|0;a[1106728]=i;a[1106720]=h;return}else{d=j0(g)|0;a[1044496]=d;a[1041666]=d;h=d;i=d;a[1106728]=i;a[1106720]=h;return}}function vZ(){var d=0,e=0,f=0,g=0,h=0,i=0;d=(a[1041658]&32)==0;e=j5(c[260418]|0,65535)|0;a[1044496]=(e&65535)>>>8&255;b[520836]=(b[520836]|0)+2&65535;f=j0(c[260418]|0)|0;a[1044496]=f;b[520836]=(b[520836]|0)+1&65535;g=(f&255)<<16|e&65535;if(d){d=j5(g,16777215)|0;e=(d&65535)>>>8&255;a[1044496]=e;b[520830]=d;h=e;i=d<<16>>16!=0|0;a[1106728]=i;a[1106720]=h;return}else{d=j0(g)|0;a[1044496]=d;a[1041660]=d;h=d;i=d;a[1106728]=i;a[1106720]=h;return}}function v_(){var e=0,f=0,g=0,h=0,i=0,j=0;e=j0(c[260418]|0)|0;a[1044496]=e;f=(b[520836]|0)+1&65535;b[520836]=f;g=f+(e<<24>>24)&65535;e=(g&65535)>>>8;if((a[1106736]|0)==0){return}f=(c[348392]|0)+6|0;c[348392]=f;h=c[348406]|0;if((f|0)<(h|0)){i=f;j=h}else{while(1){j1();h=c[348392]|0;f=c[348406]|0;if((h|0)<(f|0)){i=h;j=f;break}}}do{if((b[520829]&256)!=0){if((d[1041673|0]|0)==(e&65535|0)){break}f=i+6|0;c[348392]=f;if((f|0)<(j|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j=e<<8;e=j|g&255;if(((b[520836]^j)&65535)>4095){j4((c[276676]|0)+(e&65535)|0);return}else{b[520836]=e;return}}function v$(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=(a[1041658]&32)==0;g=j0(c[260418]|0)|0;a[1044496]=g;b[520836]=(b[520836]|0)+1&65535;h=b[520831]|0;i=h+(g&255)&65535;do{if((h&255)<<24>>24!=0){g=(c[348392]|0)+6|0;c[348392]=g;if((g|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);if((b[520829]&256)==0){j=65535}else{j=(a[1041662]|0)!=0?65535:255}h=j5(i&65535,j)|0;a[1044496]=(h&65535)>>>8&255;j=c[276674]|h&65535;if((a[1041658]&16)==0){k=4650}else{if(((d[1041668]|0)+(j&255)|0)>>>0>255){k=4650}}do{if((k|0)==4650){h=(c[348392]|0)+6|0;c[348392]=h;if((h|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);k=(e[520834]|0)+j|0;if(f){f=j5(k,16777215)|0;j=(f&65535)>>>8&255;a[1044496]=j;b[520830]=f;l=j;m=f<<16>>16!=0|0;a[1106728]=m;a[1106720]=l;return}else{f=j0(k)|0;a[1044496]=f;a[1041660]=f;l=f;m=f;a[1106728]=m;a[1106720]=l;return}}function v0(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=(a[1041658]&32)==0;e=j0(c[260418]|0)|0;a[1044496]=e;b[520836]=(b[520836]|0)+1&65535;f=b[520831]|0;g=f+(e&255)&65535;do{if((f&255)<<24>>24!=0){e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);if((b[520829]&256)==0){h=65535}else{h=(a[1041662]|0)!=0?65535:255}f=j5(g&65535,h)|0;a[1044496]=(f&65535)>>>8&255;h=c[276674]|f&65535;if(d){d=j5(h,16777215)|0;f=(d&65535)>>>8&255;a[1044496]=f;b[520830]=d;i=f;j=d<<16>>16!=0|0;a[1106728]=j;a[1106720]=i;return}else{d=j0(h)|0;a[1044496]=d;a[1041660]=d;i=d;j=d;a[1106728]=j;a[1106720]=i;return}}function v1(){var d=0,f=0,g=0,h=0,i=0;d=(a[1041658]&32)==0;f=j0(c[260418]|0)|0;a[1044496]=f;b[520836]=(b[520836]|0)+1&65535;g=(b[520832]|0)+(f&255)&65535;f=(c[348392]|0)+6|0;c[348392]=f;if((f|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}f=j5(g&65535,16777215)|0;a[1044496]=(f&65535)>>>8&255;g=(e[520834]|0)+(f&65535)+(c[276674]|0)&16777215;f=(c[348392]|0)+6|0;c[348392]=f;if((f|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}if(d){d=j5(g,16777215)|0;f=(d&65535)>>>8&255;a[1044496]=f;b[520830]=d;h=f;i=d<<16>>16!=0|0;a[1106728]=i;a[1106720]=h;return}else{d=j0(g)|0;a[1044496]=d;a[1041660]=d;h=d;i=d;a[1106728]=i;a[1106720]=h;return}}function v2(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=(a[1041658]&16)==0;e=j0(c[260418]|0)|0;a[1044496]=e;b[520836]=(b[520836]|0)+1&65535;f=b[520831]|0;g=f+(e&255)&65535;do{if((f&255)<<24>>24!=0){e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);f=g&255;e=(g&65535)>>>8;h=e&255;do{if((b[520829]&256)==0){i=4684}else{if((a[1041662]|0)!=0){i=4684;break}j=(a[1041666]|0)+f&255;k=h}}while(0);if((i|0)==4684){i=(b[520833]|0)+(e<<8|g&255)&65535;j=i&255;k=(i&65535)>>>8&255}i=(c[348392]|0)+6|0;c[348392]=i;if((i|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}i=((k&255)<<8|j&255)&65535;if(d){d=j5(i,65535)|0;j=(d&65535)>>>8&255;a[1044496]=j;b[520834]=d;l=j;m=d<<16>>16!=0|0;a[1106728]=m;a[1106720]=l;return}else{d=j0(i)|0;a[1044496]=d;a[1041668]=d;l=d;m=d;a[1106728]=m;a[1106720]=l;return}}function v3(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=(a[1041658]&32)==0;e=j0(c[260418]|0)|0;a[1044496]=e;b[520836]=(b[520836]|0)+1&65535;f=b[520831]|0;g=f+(e&255)&65535;do{if((f&255)<<24>>24!=0){e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);f=g&255;e=(g&65535)>>>8;h=e&255;do{if((b[520829]&256)==0){i=4699}else{if((a[1041662]|0)!=0){i=4699;break}j=(a[1041666]|0)+f&255;k=h}}while(0);if((i|0)==4699){i=(b[520833]|0)+(e<<8|g&255)&65535;j=i&255;k=(i&65535)>>>8&255}i=(c[348392]|0)+6|0;c[348392]=i;if((i|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}i=((k&255)<<8|j&255)&65535;if(d){d=j5(i,65535)|0;j=(d&65535)>>>8&255;a[1044496]=j;b[520830]=d;l=j;m=d<<16>>16!=0|0;a[1106728]=m;a[1106720]=l;return}else{d=j0(i)|0;a[1044496]=d;a[1041660]=d;l=d;m=d;a[1106728]=m;a[1106720]=l;return}}function v4(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=(a[1041658]&16)==0;e=j0(c[260418]|0)|0;a[1044496]=e;b[520836]=(b[520836]|0)+1&65535;f=b[520831]|0;g=f+(e&255)&65535;do{if((f&255)<<24>>24!=0){e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);f=g&255;e=(g&65535)>>>8;h=e&255;do{if((b[520829]&256)==0){i=4714}else{if((a[1041662]|0)!=0){i=4714;break}j=(a[1041668]|0)+f&255;k=h}}while(0);if((i|0)==4714){i=(b[520834]|0)+(e<<8|g&255)&65535;j=i&255;k=(i&65535)>>>8&255}i=(c[348392]|0)+6|0;c[348392]=i;if((i|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}i=((k&255)<<8|j&255)&65535;if(d){d=j5(i,65535)|0;j=(d&65535)>>>8&255;a[1044496]=j;b[520833]=d;l=j;m=d<<16>>16!=0|0;a[1106728]=m;a[1106720]=l;return}else{d=j0(i)|0;a[1044496]=d;a[1041666]=d;l=d;m=d;a[1106728]=m;a[1106720]=l;return}}function v5(){var d=0,f=0,g=0,h=0,i=0,j=0;d=(a[1041658]&32)==0;f=j0(c[260418]|0)|0;a[1044496]=f;b[520836]=(b[520836]|0)+1&65535;g=b[520831]|0;h=g+(f&255)&65535;do{if((g&255)<<24>>24!=0){f=(c[348392]|0)+6|0;c[348392]=f;if((f|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);g=h&65535;h=j5(g,16777215)|0;a[1044496]=(h&65535)>>>8&255;f=j0(g+2|0)|0;a[1044496]=f;g=((f&255)<<16|h&65535)+(e[520834]|0)|0;if(d){d=j5(g,16777215)|0;h=(d&65535)>>>8&255;a[1044496]=h;b[520830]=d;i=h;j=d<<16>>16!=0|0;a[1106728]=j;a[1106720]=i;return}else{d=j0(g)|0;a[1044496]=d;a[1041660]=d;i=d;j=d;a[1106728]=j;a[1106720]=i;return}}function v6(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=(a[1041658]&32)==0;g=c[276674]|0;h=j5(c[260418]|0,65535)|0;a[1044496]=(h&65535)>>>8&255;b[520836]=(b[520836]|0)+2&65535;i=h&65535|g;if((a[1041658]&16)==0){j=4735}else{if(((d[1041668]|0)+(i&255)|0)>>>0>255){j=4735}}do{if((j|0)==4735){g=(c[348392]|0)+6|0;c[348392]=g;if((g|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j=(e[520834]|0)+i|0;if(f){f=j5(j,16777215)|0;i=(f&65535)>>>8&255;a[1044496]=i;b[520830]=f;k=i;l=f<<16>>16!=0|0;a[1106728]=l;a[1106720]=k;return}else{f=j0(j)|0;a[1044496]=f;a[1041660]=f;k=f;l=f;a[1106728]=l;a[1106720]=k;return}}function v7(){var d=0,e=0;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}if((a[1041658]&16)==0){d=b[520832]|0;b[520833]=d;a[1106728]=d<<16>>16!=0|0;e=(d&65535)>>>8&255;a[1106720]=e;return}else{d=a[1041664]|0;a[1041666]=d;a[1106728]=d;e=d;a[1106720]=e;return}}function v8(){var d=0,e=0;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}if((a[1041658]&16)==0){d=b[520834]|0;b[520833]=d;a[1106728]=d<<16>>16!=0|0;e=(d&65535)>>>8&255;a[1106720]=e;return}else{d=a[1041668]|0;a[1041666]=d;a[1106728]=d;e=d;a[1106720]=e;return}}function v9(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=(a[1041658]&16)==0;g=c[276674]|0;h=j5(c[260418]|0,65535)|0;a[1044496]=(h&65535)>>>8&255;b[520836]=(b[520836]|0)+2&65535;i=h&65535|g;if((a[1041658]&16)==0){j=4761}else{if(((d[1041666]|0)+(i&255)|0)>>>0>255){j=4761}}do{if((j|0)==4761){g=(c[348392]|0)+6|0;c[348392]=g;if((g|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j=(e[520833]|0)+i|0;if(f){f=j5(j,65535)|0;i=(f&65535)>>>8&255;a[1044496]=i;b[520834]=f;k=i;l=f<<16>>16!=0|0;a[1106728]=l;a[1106720]=k;return}else{f=j0(j)|0;a[1044496]=f;a[1041668]=f;k=f;l=f;a[1106728]=l;a[1106720]=k;return}}function wa(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=(a[1041658]&32)==0;g=c[276674]|0;h=j5(c[260418]|0,65535)|0;a[1044496]=(h&65535)>>>8&255;b[520836]=(b[520836]|0)+2&65535;i=h&65535|g;if((a[1041658]&16)==0){j=4771}else{if(((d[1041666]|0)+(i&255)|0)>>>0>255){j=4771}}do{if((j|0)==4771){g=(c[348392]|0)+6|0;c[348392]=g;if((g|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j=(e[520833]|0)+i|0;if(f){f=j5(j,16777215)|0;i=(f&65535)>>>8&255;a[1044496]=i;b[520830]=f;k=i;l=f<<16>>16!=0|0;a[1106728]=l;a[1106720]=k;return}else{f=j0(j)|0;a[1044496]=f;a[1041660]=f;k=f;l=f;a[1106728]=l;a[1106720]=k;return}}function wb(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=(a[1041658]&16)==0;g=c[276674]|0;h=j5(c[260418]|0,65535)|0;a[1044496]=(h&65535)>>>8&255;b[520836]=(b[520836]|0)+2&65535;i=h&65535|g;if((a[1041658]&16)==0){j=4781}else{if(((d[1041668]|0)+(i&255)|0)>>>0>255){j=4781}}do{if((j|0)==4781){g=(c[348392]|0)+6|0;c[348392]=g;if((g|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j=(e[520834]|0)+i|0;if(f){f=j5(j,65535)|0;i=(f&65535)>>>8&255;a[1044496]=i;b[520833]=f;k=i;l=f<<16>>16!=0|0;a[1106728]=l;a[1106720]=k;return}else{f=j0(j)|0;a[1044496]=f;a[1041666]=f;k=f;l=f;a[1106728]=l;a[1106720]=k;return}}function wc(){var d=0,f=0,g=0,h=0,i=0,j=0;d=(a[1041658]&32)==0;f=j5(c[260418]|0,65535)|0;a[1044496]=(f&65535)>>>8&255;b[520836]=(b[520836]|0)+2&65535;g=j0(c[260418]|0)|0;a[1044496]=g;b[520836]=(b[520836]|0)+1&65535;h=(e[520833]|0)+((g&255)<<16|f&65535)|0;if(d){d=j5(h,16777215)|0;f=(d&65535)>>>8&255;a[1044496]=f;b[520830]=d;i=f;j=d<<16>>16!=0|0;a[1106728]=j;a[1106720]=i;return}else{d=j0(h)|0;a[1044496]=d;a[1041660]=d;i=d;j=d;a[1106728]=j;a[1106720]=i;return}}function wd(){var f=0,g=0,h=0,i=0;if((a[1041658]&16)==0){f=e[520834]|0;g=j5(c[260418]|0,65535)|0;a[1044496]=(g&65535)>>>8&255;b[520836]=(b[520836]|0)+2&65535;h=f-(g&65535)|0;a[1106736]=h>>>31&255^1;a[1106728]=(h&65535|0)!=0|0;i=h>>>8&255;a[1106720]=i;return}else{h=d[1041668]|0;g=j0(c[260418]|0)|0;a[1044496]=g;b[520836]=(b[520836]|0)+1&65535;f=h-(g&255)&65535;a[1106736]=(f&65535)>>>15&255^1;g=f&255;a[1106728]=g;i=g;a[1106720]=i;return}}function we(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=(a[1041658]&32)==0;g=j0(c[260418]|0)|0;a[1044496]=g;b[520836]=(b[520836]|0)+1&65535;h=b[520831]|0;i=h+(g&255)&65535;do{if((h&255)<<24>>24!=0){g=(c[348392]|0)+6|0;c[348392]=g;if((g|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);h=i&255;g=(i&65535)>>>8;j=g&255;k=b[520829]|0;do{if((k&256)==0){l=4806}else{if((a[1041662]|0)!=0){l=4806;break}m=(a[1041666]|0)+h&255;n=j}}while(0);if((l|0)==4806){l=(b[520833]|0)+(g<<8|i&255)&65535;m=l&255;n=(l&65535)>>>8&255}l=(c[348392]|0)+6|0;c[348392]=l;if((l|0)<(c[348406]|0)){o=k}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));o=b[520829]|0}if((o&256)==0){p=65535}else{p=(a[1041662]|0)!=0?65535:255}o=j5(((n&255)<<8|m&255)&65535,p)|0;a[1044496]=(o&65535)>>>8&255;p=c[276674]|o&65535;if(f){f=j5(p,16777215)|0;a[1044496]=(f&65535)>>>8&255;o=(e[520830]|0)-(f&65535)|0;a[1106736]=o>>>31&255^1;a[1106728]=(o&65535|0)!=0|0;q=o>>>8&255;a[1106720]=q;return}else{o=j0(p)|0;a[1044496]=o;p=(d[1041660]|0)-(o&255)&65535;a[1106736]=(p&65535)>>>15&255^1;o=p&255;a[1106728]=o;q=o;a[1106720]=q;return}}function wf(){var d=0,e=0,f=0,g=0;d=j0(c[260418]|0)|0;a[1044496]=d;b[520836]=(b[520836]|0)+1&65535;e=~d;a[1041658]=a[1041658]&e;a[1106736]=a[1106736]&e;a[1106712]=a[1106712]&(e&255)>>>6;a[1106720]=a[1106720]&e;a[1106728]=a[1106728]|e&2^2;e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}e=b[520829]|0;if((e&256)==0){f=e&255;g=e}else{d=e|48;b[520829]=d;f=d&255;g=d}if((f&16)!=0){a[1041667|0]=0;a[1041669|0]=0}if((g&256)!=0){c[276688]=158776;c[276686]=159800;return}f=g&255;g=(f&16|0)!=0;if((f&32|0)==0){if(g){c[276688]=156728;c[276686]=160312;return}else{c[276688]=157752;c[276686]=160568;return}}else{if(g){c[276688]=154680;c[276686]=159800;return}else{c[276688]=155704;c[276686]=160056;return}}}function wg(){var f=0,g=0,h=0,i=0;f=(a[1041658]&32)==0;g=j0(c[260418]|0)|0;a[1044496]=g;b[520836]=(b[520836]|0)+1&65535;h=(b[520832]|0)+(g&255)&65535;g=(c[348392]|0)+6|0;c[348392]=g;if((g|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}g=h&65535;if(f){f=j5(g,16777215)|0;a[1044496]=(f&65535)>>>8&255;h=(e[520830]|0)-(f&65535)|0;a[1106736]=h>>>31&255^1;a[1106728]=(h&65535|0)!=0|0;i=h>>>8&255;a[1106720]=i;return}else{h=j0(g)|0;a[1044496]=h;g=(d[1041660]|0)-(h&255)&65535;a[1106736]=(g&65535)>>>15&255^1;h=g&255;a[1106728]=h;i=h;a[1106720]=i;return}}function wh(){var f=0,g=0,h=0,i=0,j=0;f=(a[1041658]&16)==0;g=j0(c[260418]|0)|0;a[1044496]=g;b[520836]=(b[520836]|0)+1&65535;h=b[520831]|0;i=h+(g&255)&65535;do{if((h&255)<<24>>24!=0){g=(c[348392]|0)+6|0;c[348392]=g;if((g|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);h=i&65535;if(f){f=j5(h,65535)|0;a[1044496]=(f&65535)>>>8&255;i=(e[520834]|0)-(f&65535)|0;a[1106736]=i>>>31&255^1;a[1106728]=(i&65535|0)!=0|0;j=i>>>8&255;a[1106720]=j;return}else{i=j0(h)|0;a[1044496]=i;h=(d[1041668]|0)-(i&255)&65535;a[1106736]=(h&65535)>>>15&255^1;i=h&255;a[1106728]=i;j=i;a[1106720]=j;return}}function wi(){var f=0,g=0,h=0,i=0,j=0;f=(a[1041658]&32)==0;g=j0(c[260418]|0)|0;a[1044496]=g;b[520836]=(b[520836]|0)+1&65535;h=b[520831]|0;i=h+(g&255)&65535;do{if((h&255)<<24>>24!=0){g=(c[348392]|0)+6|0;c[348392]=g;if((g|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);h=i&65535;if(f){f=j5(h,65535)|0;a[1044496]=(f&65535)>>>8&255;i=(e[520830]|0)-(f&65535)|0;a[1106736]=i>>>31&255^1;a[1106728]=(i&65535|0)!=0|0;j=i>>>8&255;a[1106720]=j;return}else{i=j0(h)|0;a[1044496]=i;h=(d[1041660]|0)-(i&255)&65535;a[1106736]=(h&65535)>>>15&255^1;i=h&255;a[1106728]=i;j=i;a[1106720]=j;return}}function wj(){var d=0,e=0,f=0,g=0,h=0;d=(a[1041658]&32)==0;e=j0(c[260418]|0)|0;a[1044496]=e;b[520836]=(b[520836]|0)+1&65535;f=b[520831]|0;g=f+(e&255)&65535;do{if((f&255)<<24>>24!=0){e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);f=g&65535;if(d){d=(j5(f,65535)|0)-1&65535;g=(c[348392]|0)+6|0;c[348392]=g;if((g|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}j3(d,f,65535);a[1044496]=d&255;a[1106728]=d<<16>>16!=0|0;h=(d&65535)>>>8&255;a[1106720]=h;return}else{d=(j0(f)|0)-1&255;g=(c[348392]|0)+6|0;c[348392]=g;if((g|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}j2(d,f);a[1044496]=d;a[1106728]=d;h=d;a[1106720]=h;return}}function wk(){var f=0,g=0,h=0,i=0,j=0;f=(a[1041658]&32)==0;g=j0(c[260418]|0)|0;a[1044496]=g;b[520836]=(b[520836]|0)+1&65535;h=b[520831]|0;i=h+(g&255)&65535;do{if((h&255)<<24>>24!=0){g=(c[348392]|0)+6|0;c[348392]=g;if((g|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);h=i&65535;i=j5(h,16777215)|0;a[1044496]=(i&65535)>>>8&255;g=j0(h+2|0)|0;a[1044496]=g;h=(g&255)<<16|i&65535;if(f){f=j5(h,16777215)|0;a[1044496]=(f&65535)>>>8&255;i=(e[520830]|0)-(f&65535)|0;a[1106736]=i>>>31&255^1;a[1106728]=(i&65535|0)!=0|0;j=i>>>8&255;a[1106720]=j;return}else{i=j0(h)|0;a[1044496]=i;h=(d[1041660]|0)-(i&255)&65535;a[1106736]=(h&65535)>>>15&255^1;i=h&255;a[1106728]=i;j=i;a[1106720]=j;return}}function wl(){var d=0,e=0;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}if((a[1041658]&16)==0){d=(b[520834]|0)-1&65535;b[520834]=d;a[1106728]=d<<16>>16!=0|0;e=(d&65535)>>>8&255;a[1106720]=e;return}else{d=(a[1041668]|0)-1&255;a[1041668]=d;a[1106728]=d;e=d;a[1106720]=e;return}}function wm(){var f=0,g=0,h=0,i=0;if((a[1041658]&32)==0){f=e[520830]|0;g=j5(c[260418]|0,65535)|0;a[1044496]=(g&65535)>>>8&255;b[520836]=(b[520836]|0)+2&65535;h=f-(g&65535)|0;a[1106736]=h>>>31&255^1;a[1106728]=(h&65535|0)!=0|0;i=h>>>8&255;a[1106720]=i;return}else{h=d[1041660]|0;g=j0(c[260418]|0)|0;a[1044496]=g;b[520836]=(b[520836]|0)+1&65535;f=h-(g&255)&65535;a[1106736]=(f&65535)>>>15&255^1;g=f&255;a[1106728]=g;i=g;a[1106720]=i;return}}function wn(){var d=0,e=0;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}if((a[1041658]&16)==0){d=(b[520833]|0)-1&65535;b[520833]=d;a[1106728]=d<<16>>16!=0|0;e=(d&65535)>>>8&255;a[1106720]=e;return}else{d=(a[1041666]|0)-1&255;a[1041666]=d;a[1106728]=d;e=d;a[1106720]=e;return}}function wo(){var f=0,g=0,h=0,i=0,j=0;f=(a[1041658]&16)==0;g=c[276674]|0;h=j5(c[260418]|0,65535)|0;a[1044496]=(h&65535)>>>8&255;b[520836]=(b[520836]|0)+2&65535;i=h&65535|g;if(f){f=j5(i,16777215)|0;a[1044496]=(f&65535)>>>8&255;g=(e[520834]|0)-(f&65535)|0;a[1106736]=g>>>31&255^1;a[1106728]=(g&65535|0)!=0|0;j=g>>>8&255;a[1106720]=j;return}else{g=j0(i)|0;a[1044496]=g;i=(d[1041668]|0)-(g&255)&65535;a[1106736]=(i&65535)>>>15&255^1;g=i&255;a[1106728]=g;j=g;a[1106720]=j;return}}function wp(){var f=0,g=0,h=0,i=0,j=0;f=(a[1041658]&32)==0;g=c[276674]|0;h=j5(c[260418]|0,65535)|0;a[1044496]=(h&65535)>>>8&255;b[520836]=(b[520836]|0)+2&65535;i=h&65535|g;if(f){f=j5(i,16777215)|0;a[1044496]=(f&65535)>>>8&255;g=(e[520830]|0)-(f&65535)|0;a[1106736]=g>>>31&255^1;a[1106728]=(g&65535|0)!=0|0;j=g>>>8&255;a[1106720]=j;return}else{g=j0(i)|0;a[1044496]=g;i=(d[1041660]|0)-(g&255)&65535;a[1106736]=(i&65535)>>>15&255^1;g=i&255;a[1106728]=g;j=g;a[1106720]=j;return}}function wq(){var d=0,e=0,f=0,g=0,h=0;d=(a[1041658]&32)==0;e=c[276674]|0;f=j5(c[260418]|0,65535)|0;a[1044496]=(f&65535)>>>8&255;b[520836]=(b[520836]|0)+2&65535;g=f&65535|e;if(d){d=(j5(g,16777215)|0)-1&65535;e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}j3(d,g,16777215);a[1044496]=d&255;a[1106728]=d<<16>>16!=0|0;h=(d&65535)>>>8&255;a[1106720]=h;return}else{d=(j0(g)|0)-1&255;e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}j2(d,g);a[1044496]=d;a[1106728]=d;h=d;a[1106720]=h;return}}function wr(){var f=0,g=0,h=0,i=0,j=0;f=(a[1041658]&32)==0;g=j5(c[260418]|0,65535)|0;a[1044496]=(g&65535)>>>8&255;b[520836]=(b[520836]|0)+2&65535;h=j0(c[260418]|0)|0;a[1044496]=h;b[520836]=(b[520836]|0)+1&65535;i=(h&255)<<16|g&65535;if(f){f=j5(i,16777215)|0;a[1044496]=(f&65535)>>>8&255;g=(e[520830]|0)-(f&65535)|0;a[1106736]=g>>>31&255^1;a[1106728]=(g&65535|0)!=0|0;j=g>>>8&255;a[1106720]=j;return}else{g=j0(i)|0;a[1044496]=g;i=(d[1041660]|0)-(g&255)&65535;a[1106736]=(i&65535)>>>15&255^1;g=i&255;a[1106728]=g;j=g;a[1106720]=j;return}}function ws(){var e=0,f=0,g=0,h=0,i=0,j=0;e=j0(c[260418]|0)|0;a[1044496]=e;f=(b[520836]|0)+1&65535;b[520836]=f;g=f+(e<<24>>24)&65535;e=(g&65535)>>>8;if((a[1106728]|0)==0){return}f=(c[348392]|0)+6|0;c[348392]=f;h=c[348406]|0;if((f|0)<(h|0)){i=f;j=h}else{while(1){j1();h=c[348392]|0;f=c[348406]|0;if((h|0)<(f|0)){i=h;j=f;break}}}do{if((b[520829]&256)!=0){if((d[1041673|0]|0)==(e&65535|0)){break}f=i+6|0;c[348392]=f;if((f|0)<(j|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j=e<<8;e=j|g&255;if(((b[520836]^j)&65535)>4095){j4((c[276676]|0)+(e&65535)|0);return}else{b[520836]=e;return}}function wt(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0;f=(a[1041658]&32)==0;g=j0(c[260418]|0)|0;a[1044496]=g;b[520836]=(b[520836]|0)+1&65535;h=b[520831]|0;i=h+(g&255)&65535;do{if((h&255)<<24>>24!=0){g=(c[348392]|0)+6|0;c[348392]=g;if((g|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);if((b[520829]&256)==0){j=65535}else{j=(a[1041662]|0)!=0?65535:255}h=j5(i&65535,j)|0;a[1044496]=(h&65535)>>>8&255;j=c[276674]|h&65535;if((a[1041658]&16)==0){k=4959}else{if(((d[1041668]|0)+(j&255)|0)>>>0>255){k=4959}}do{if((k|0)==4959){h=(c[348392]|0)+6|0;c[348392]=h;if((h|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);k=(e[520834]|0)+j|0;if(f){f=j5(k,16777215)|0;a[1044496]=(f&65535)>>>8&255;j=(e[520830]|0)-(f&65535)|0;a[1106736]=j>>>31&255^1;a[1106728]=(j&65535|0)!=0|0;l=j>>>8&255;a[1106720]=l;return}else{j=j0(k)|0;a[1044496]=j;k=(d[1041660]|0)-(j&255)&65535;a[1106736]=(k&65535)>>>15&255^1;j=k&255;a[1106728]=j;l=j;a[1106720]=l;return}}function wu(){var f=0,g=0,h=0,i=0,j=0,k=0;f=(a[1041658]&32)==0;g=j0(c[260418]|0)|0;a[1044496]=g;b[520836]=(b[520836]|0)+1&65535;h=b[520831]|0;i=h+(g&255)&65535;do{if((h&255)<<24>>24!=0){g=(c[348392]|0)+6|0;c[348392]=g;if((g|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);if((b[520829]&256)==0){j=65535}else{j=(a[1041662]|0)!=0?65535:255}h=j5(i&65535,j)|0;a[1044496]=(h&65535)>>>8&255;j=c[276674]|h&65535;if(f){f=j5(j,16777215)|0;a[1044496]=(f&65535)>>>8&255;h=(e[520830]|0)-(f&65535)|0;a[1106736]=h>>>31&255^1;a[1106728]=(h&65535|0)!=0|0;k=h>>>8&255;a[1106720]=k;return}else{h=j0(j)|0;a[1044496]=h;j=(d[1041660]|0)-(h&255)&65535;a[1106736]=(j&65535)>>>15&255^1;h=j&255;a[1106728]=h;k=h;a[1106720]=k;return}}function wv(){var f=0,g=0,h=0,i=0;f=(a[1041658]&32)==0;g=j0(c[260418]|0)|0;a[1044496]=g;b[520836]=(b[520836]|0)+1&65535;h=(b[520832]|0)+(g&255)&65535;g=(c[348392]|0)+6|0;c[348392]=g;if((g|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}g=j5(h&65535,16777215)|0;a[1044496]=(g&65535)>>>8&255;h=(e[520834]|0)+(g&65535)+(c[276674]|0)&16777215;g=(c[348392]|0)+6|0;c[348392]=g;if((g|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}if(f){f=j5(h,16777215)|0;a[1044496]=(f&65535)>>>8&255;g=(e[520830]|0)-(f&65535)|0;a[1106736]=g>>>31&255^1;a[1106728]=(g&65535|0)!=0|0;i=g>>>8&255;a[1106720]=i;return}else{g=j0(h)|0;a[1044496]=g;h=(d[1041660]|0)-(g&255)&65535;a[1106736]=(h&65535)>>>15&255^1;g=h&255;a[1106728]=g;i=g;a[1106720]=i;return}}function ww(){var d=0,f=0,g=0,h=0;d=j0(c[260418]|0)|0;a[1044496]=d;b[520836]=(b[520836]|0)+1&65535;f=b[520831]|0;g=f+(d&255)&65535;do{if((f&255)<<24>>24!=0){d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);if((b[520829]&256)==0){h=65535}else{h=(a[1041662]|0)!=0?65535:255}f=(j5(g&65535,h)|0)&65535;h=c[276674]|f;j3(h&65535,(e[520832]|0)-1|0,65535);b[520832]=(b[520832]|0)-2&65535;a[1044496]=h&255;if((b[520829]&256)==0){return}a[1041665|0]=1;return}function wx(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=(a[1041658]&32)==0;g=j0(c[260418]|0)|0;a[1044496]=g;b[520836]=(b[520836]|0)+1&65535;h=b[520831]|0;i=h+(g&255)&65535;do{if((h&255)<<24>>24!=0){g=(c[348392]|0)+6|0;c[348392]=g;if((g|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);h=i&255;g=(i&65535)>>>8;j=g&255;do{if((b[520829]&256)==0){k=5003}else{if((a[1041662]|0)!=0){k=5003;break}l=(a[1041666]|0)+h&255;m=j}}while(0);if((k|0)==5003){k=(b[520833]|0)+(g<<8|i&255)&65535;l=k&255;m=(k&65535)>>>8&255}k=(c[348392]|0)+6|0;c[348392]=k;if((k|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}k=((m&255)<<8|l&255)&65535;if(f){f=j5(k,65535)|0;a[1044496]=(f&65535)>>>8&255;l=(e[520830]|0)-(f&65535)|0;a[1106736]=l>>>31&255^1;a[1106728]=(l&65535|0)!=0|0;n=l>>>8&255;a[1106720]=n;return}else{l=j0(k)|0;a[1044496]=l;k=(d[1041660]|0)-(l&255)&65535;a[1106736]=(k&65535)>>>15&255^1;l=k&255;a[1106728]=l;n=l;a[1106720]=n;return}}function wy(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=(a[1041658]&32)==0;e=j0(c[260418]|0)|0;a[1044496]=e;b[520836]=(b[520836]|0)+1&65535;f=b[520831]|0;g=f+(e&255)&65535;do{if((f&255)<<24>>24!=0){e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);f=g&255;e=(g&65535)>>>8;h=e&255;do{if((b[520829]&256)==0){i=5018}else{if((a[1041662]|0)!=0){i=5018;break}j=(a[1041666]|0)+f&255;k=h}}while(0);if((i|0)==5018){i=(b[520833]|0)+(e<<8|g&255)&65535;j=i&255;k=(i&65535)>>>8&255}i=(c[348392]|0)+6|0;c[348392]=i;if((i|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}i=((k&255)<<8|j&255)&65535;if(d){d=(j5(i,65535)|0)-1&65535;j=(c[348392]|0)+6|0;c[348392]=j;if((j|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}j3(d,i,65535);a[1044496]=d&255;a[1106728]=d<<16>>16!=0|0;l=(d&65535)>>>8&255;a[1106720]=l;return}else{d=(j0(i)|0)-1&255;j=(c[348392]|0)+6|0;c[348392]=j;if((j|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}j2(d,i);a[1044496]=d;a[1106728]=d;l=d;a[1106720]=l;return}}function wz(){var f=0,g=0,h=0,i=0,j=0;f=(a[1041658]&32)==0;g=j0(c[260418]|0)|0;a[1044496]=g;b[520836]=(b[520836]|0)+1&65535;h=b[520831]|0;i=h+(g&255)&65535;do{if((h&255)<<24>>24!=0){g=(c[348392]|0)+6|0;c[348392]=g;if((g|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);h=i&65535;i=j5(h,16777215)|0;a[1044496]=(i&65535)>>>8&255;g=j0(h+2|0)|0;a[1044496]=g;h=((g&255)<<16|i&65535)+(e[520834]|0)|0;if(f){f=j5(h,16777215)|0;a[1044496]=(f&65535)>>>8&255;i=(e[520830]|0)-(f&65535)|0;a[1106736]=i>>>31&255^1;a[1106728]=(i&65535|0)!=0|0;j=i>>>8&255;a[1106720]=j;return}else{i=j0(h)|0;a[1044496]=i;h=(d[1041660]|0)-(i&255)&65535;a[1106736]=(h&65535)>>>15&255^1;i=h&255;a[1106728]=i;j=i;a[1106720]=j;return}}function wA(){var f=0,g=0,h=0,i=0,j=0,k=0;f=(a[1041658]&32)==0;g=c[276674]|0;h=j5(c[260418]|0,65535)|0;a[1044496]=(h&65535)>>>8&255;b[520836]=(b[520836]|0)+2&65535;i=h&65535|g;if((a[1041658]&16)==0){j=5043}else{if(((d[1041668]|0)+(i&255)|0)>>>0>255){j=5043}}do{if((j|0)==5043){g=(c[348392]|0)+6|0;c[348392]=g;if((g|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j=(e[520834]|0)+i|0;if(f){f=j5(j,16777215)|0;a[1044496]=(f&65535)>>>8&255;i=(e[520830]|0)-(f&65535)|0;a[1106736]=i>>>31&255^1;a[1106728]=(i&65535|0)!=0|0;k=i>>>8&255;a[1106720]=k;return}else{i=j0(j)|0;a[1044496]=i;j=(d[1041660]|0)-(i&255)&65535;a[1106736]=(j&65535)>>>15&255^1;i=j&255;a[1106728]=i;k=i;a[1106720]=k;return}}function wB(){var d=0,f=0,g=0;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}d=b[520829]|0;if((d&256)!=0){j2(a[1041666]|0,e[520832]|0);a[1041664]=(a[1041664]|0)-1&255;f=a[1041666]|0;a[1044496]=f;return}if((d&16)==0){j3(b[520833]|0,(e[520832]|0)-1|0,65535);b[520832]=(b[520832]|0)-2&65535;f=a[1041666]|0;a[1044496]=f;return}else{d=a[1041666]|0;g=b[520832]|0;b[520832]=g-1&65535;j2(d,g&65535);f=a[1041666]|0;a[1044496]=f;return}}function wC(){var d=0,e=0,f=0;d=j5(c[260418]|0,65535)|0;a[1044496]=(d&65535)>>>8&255;b[520836]=(b[520836]|0)+2&65535;e=d&65535;d=j5(e,16777215)|0;a[1044496]=(d&65535)>>>8&255;f=j0(e+2|0)|0;a[1044496]=f;j4((f&255)<<16|d&65535);return}function wD(){var f=0,g=0,h=0,i=0,j=0,k=0;f=(a[1041658]&32)==0;g=c[276674]|0;h=j5(c[260418]|0,65535)|0;a[1044496]=(h&65535)>>>8&255;b[520836]=(b[520836]|0)+2&65535;i=h&65535|g;if((a[1041658]&16)==0){j=5065}else{if(((d[1041666]|0)+(i&255)|0)>>>0>255){j=5065}}do{if((j|0)==5065){g=(c[348392]|0)+6|0;c[348392]=g;if((g|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j=(e[520833]|0)+i|0;if(f){f=j5(j,16777215)|0;a[1044496]=(f&65535)>>>8&255;i=(e[520830]|0)-(f&65535)|0;a[1106736]=i>>>31&255^1;a[1106728]=(i&65535|0)!=0|0;k=i>>>8&255;a[1106720]=k;return}else{i=j0(j)|0;a[1044496]=i;j=(d[1041660]|0)-(i&255)&65535;a[1106736]=(j&65535)>>>15&255^1;i=j&255;a[1106728]=i;k=i;a[1106720]=k;return}}function wE(){var d=0,f=0,g=0,h=0,i=0;d=(a[1041658]&32)==0;f=c[276674]|0;g=j5(c[260418]|0,65535)|0;a[1044496]=(g&65535)>>>8&255;b[520836]=(b[520836]|0)+2&65535;h=g&65535|f;f=(c[348392]|0)+6|0;c[348392]=f;if((f|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}f=(e[520833]|0)+h|0;if(d){d=(j5(f,16777215)|0)-1&65535;h=(c[348392]|0)+6|0;c[348392]=h;if((h|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}j3(d,f,16777215);a[1044496]=d&255;a[1106728]=d<<16>>16!=0|0;i=(d&65535)>>>8&255;a[1106720]=i;return}else{d=(j0(f)|0)-1&255;h=(c[348392]|0)+6|0;c[348392]=h;if((h|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}j2(d,f);a[1044496]=d;a[1106728]=d;i=d;a[1106720]=i;return}}function wF(){var f=0,g=0,h=0,i=0,j=0;f=(a[1041658]&32)==0;g=j5(c[260418]|0,65535)|0;a[1044496]=(g&65535)>>>8&255;b[520836]=(b[520836]|0)+2&65535;h=j0(c[260418]|0)|0;a[1044496]=h;b[520836]=(b[520836]|0)+1&65535;i=(e[520833]|0)+((h&255)<<16|g&65535)|0;if(f){f=j5(i,16777215)|0;a[1044496]=(f&65535)>>>8&255;g=(e[520830]|0)-(f&65535)|0;a[1106736]=g>>>31&255^1;a[1106728]=(g&65535|0)!=0|0;j=g>>>8&255;a[1106720]=j;return}else{g=j0(i)|0;a[1044496]=g;i=(d[1041660]|0)-(g&255)&65535;a[1106736]=(i&65535)>>>15&255^1;g=i&255;a[1106728]=g;j=g;a[1106720]=j;return}}function wG(){var f=0,g=0,h=0,i=0;if((a[1041658]&16)==0){f=e[520833]|0;g=j5(c[260418]|0,65535)|0;a[1044496]=(g&65535)>>>8&255;b[520836]=(b[520836]|0)+2&65535;h=f-(g&65535)|0;a[1106736]=h>>>31&255^1;a[1106728]=(h&65535|0)!=0|0;i=h>>>8&255;a[1106720]=i;return}else{h=d[1041666]|0;g=j0(c[260418]|0)|0;a[1044496]=g;b[520836]=(b[520836]|0)+1&65535;f=h-(g&255)&65535;a[1106736]=(f&65535)>>>15&255^1;g=f&255;a[1106728]=g;i=g;a[1106720]=i;return}}function wH(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=(a[1041658]&32)==0;f=j0(c[260418]|0)|0;a[1044496]=f;b[520836]=(b[520836]|0)+1&65535;g=b[520831]|0;h=g+(f&255)&65535;do{if((g&255)<<24>>24!=0){f=(c[348392]|0)+6|0;c[348392]=f;if((f|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);g=h&255;f=(h&65535)>>>8;i=f&255;j=b[520829]|0;do{if((j&256)==0){k=5102}else{if((a[1041662]|0)!=0){k=5102;break}l=(a[1041666]|0)+g&255;m=i}}while(0);if((k|0)==5102){k=(b[520833]|0)+(f<<8|h&255)&65535;l=k&255;m=(k&65535)>>>8&255}k=(c[348392]|0)+6|0;c[348392]=k;if((k|0)<(c[348406]|0)){n=j}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));n=b[520829]|0}if((n&256)==0){o=65535}else{o=(a[1041662]|0)!=0?65535:255}n=j5(((m&255)<<8|l&255)&65535,o)|0;a[1044496]=(n&65535)>>>8&255;o=c[276674]|n&65535;if(e){e=j5(o,16777215)|0;a[1044496]=(e&65535)>>>8&255;w6(e);return}e=j0(o)|0;a[1044496]=e;if((a[1041658]&8)==0){o=a[1041660]|0;n=((o&255)+~(e&255)&65535)+(d[1106736]|0)&65535;a[1106736]=(n&65535)>>>15&255^1;l=n&255;p=l;q=(l^o)&(o^e)}else{o=b[520830]|0;l=o&255;n=((l&15)-(e&15)&255)-((a[1106736]|0)==0)&255;m=(o&240)-(e&-16&255)&65535;if((n&255)>15){r=n+10&15;s=m-16&65535}else{r=n;s=m}if((s&65535)>240){a[1106736]=0;t=s+160&255&-16}else{a[1106736]=1;t=s&255}s=t|r;p=s;q=(s^l)&(l^e)}a[1106712]=(q&255)>>>7;a[1041660]=p;a[1106728]=p;a[1106720]=p;return}function wI(){var d=0,e=0,f=0,g=0;d=j0(c[260418]|0)|0;a[1044496]=d;b[520836]=(b[520836]|0)+1&65535;a[1041658]=a[1041658]|d;a[1106736]=a[1106736]|d&1;a[1106712]=a[1106712]|(d&255)>>>6&1;a[1106720]=a[1106720]|d;if((d&2)!=0){a[1106728]=0}d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}d=b[520829]|0;if((d&256)==0){e=d&255;f=d}else{g=d|48;b[520829]=g;e=g&255;f=g}if((e&16)!=0){a[1041667|0]=0;a[1041669|0]=0}if((f&256)!=0){c[276688]=158776;c[276686]=159800;return}e=f&255;f=(e&16|0)!=0;if((e&32|0)==0){if(f){c[276688]=156728;c[276686]=160312;return}else{c[276688]=157752;c[276686]=160568;return}}else{if(f){c[276688]=154680;c[276686]=159800;return}else{c[276688]=155704;c[276686]=160056;return}}}function wJ(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=(a[1041658]&32)==0;f=j0(c[260418]|0)|0;a[1044496]=f;b[520836]=(b[520836]|0)+1&65535;g=(b[520832]|0)+(f&255)&65535;f=(c[348392]|0)+6|0;c[348392]=f;if((f|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}f=g&65535;if(e){e=j5(f,16777215)|0;a[1044496]=(e&65535)>>>8&255;w6(e);return}e=j0(f)|0;a[1044496]=e;if((a[1041658]&8)==0){f=a[1041660]|0;g=((f&255)+~(e&255)&65535)+(d[1106736]|0)&65535;a[1106736]=(g&65535)>>>15&255^1;h=g&255;i=h;j=(h^f)&(f^e)}else{f=b[520830]|0;h=f&255;g=((h&15)-(e&15)&255)-((a[1106736]|0)==0)&255;k=(f&240)-(e&-16&255)&65535;if((g&255)>15){l=g+10&15;m=k-16&65535}else{l=g;m=k}if((m&65535)>240){a[1106736]=0;n=m+160&255&-16}else{a[1106736]=1;n=m&255}m=n|l;i=m;j=(m^h)&(h^e)}a[1106712]=(j&255)>>>7;a[1041660]=i;a[1106728]=i;a[1106720]=i;return}function wK(){var f=0,g=0,h=0,i=0,j=0;f=(a[1041658]&16)==0;g=j0(c[260418]|0)|0;a[1044496]=g;b[520836]=(b[520836]|0)+1&65535;h=b[520831]|0;i=h+(g&255)&65535;do{if((h&255)<<24>>24!=0){g=(c[348392]|0)+6|0;c[348392]=g;if((g|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);h=i&65535;if(f){f=j5(h,65535)|0;a[1044496]=(f&65535)>>>8&255;i=(e[520833]|0)-(f&65535)|0;a[1106736]=i>>>31&255^1;a[1106728]=(i&65535|0)!=0|0;j=i>>>8&255;a[1106720]=j;return}else{i=j0(h)|0;a[1044496]=i;h=(d[1041666]|0)-(i&255)&65535;a[1106736]=(h&65535)>>>15&255^1;i=h&255;a[1106728]=i;j=i;a[1106720]=j;return}}function wL(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=(a[1041658]&32)==0;f=j0(c[260418]|0)|0;a[1044496]=f;b[520836]=(b[520836]|0)+1&65535;g=b[520831]|0;h=g+(f&255)&65535;do{if((g&255)<<24>>24!=0){f=(c[348392]|0)+6|0;c[348392]=f;if((f|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);g=h&65535;if(e){e=j5(g,65535)|0;a[1044496]=(e&65535)>>>8&255;w6(e);return}e=j0(g)|0;a[1044496]=e;if((a[1041658]&8)==0){g=a[1041660]|0;h=((g&255)+~(e&255)&65535)+(d[1106736]|0)&65535;a[1106736]=(h&65535)>>>15&255^1;f=h&255;i=f;j=(f^g)&(g^e)}else{g=b[520830]|0;f=g&255;h=((f&15)-(e&15)&255)-((a[1106736]|0)==0)&255;k=(g&240)-(e&-16&255)&65535;if((h&255)>15){l=h+10&15;m=k-16&65535}else{l=h;m=k}if((m&65535)>240){a[1106736]=0;n=m+160&255&-16}else{a[1106736]=1;n=m&255}m=n|l;i=m;j=(m^f)&(f^e)}a[1106712]=(j&255)>>>7;a[1041660]=i;a[1106728]=i;a[1106720]=i;return}function wM(){var d=0,e=0,f=0,g=0,h=0;d=(a[1041658]&32)==0;e=j0(c[260418]|0)|0;a[1044496]=e;b[520836]=(b[520836]|0)+1&65535;f=b[520831]|0;g=f+(e&255)&65535;do{if((f&255)<<24>>24!=0){e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);f=g&65535;if(d){d=(j5(f,65535)|0)+1&65535;g=(c[348392]|0)+6|0;c[348392]=g;if((g|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}j3(d,f,65535);a[1044496]=d&255;a[1106728]=d<<16>>16!=0|0;h=(d&65535)>>>8&255;a[1106720]=h;return}else{d=(j0(f)|0)+1&255;g=(c[348392]|0)+6|0;c[348392]=g;if((g|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}j2(d,f);a[1044496]=d;a[1106728]=d;h=d;a[1106720]=h;return}}function wN(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=(a[1041658]&32)==0;f=j0(c[260418]|0)|0;a[1044496]=f;b[520836]=(b[520836]|0)+1&65535;g=b[520831]|0;h=g+(f&255)&65535;do{if((g&255)<<24>>24!=0){f=(c[348392]|0)+6|0;c[348392]=f;if((f|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);g=h&65535;h=j5(g,16777215)|0;a[1044496]=(h&65535)>>>8&255;f=j0(g+2|0)|0;a[1044496]=f;g=(f&255)<<16|h&65535;if(e){e=j5(g,16777215)|0;a[1044496]=(e&65535)>>>8&255;w6(e);return}e=j0(g)|0;a[1044496]=e;if((a[1041658]&8)==0){g=a[1041660]|0;h=((g&255)+~(e&255)&65535)+(d[1106736]|0)&65535;a[1106736]=(h&65535)>>>15&255^1;f=h&255;i=f;j=(f^g)&(g^e)}else{g=b[520830]|0;f=g&255;h=((f&15)-(e&15)&255)-((a[1106736]|0)==0)&255;k=(g&240)-(e&-16&255)&65535;if((h&255)>15){l=h+10&15;m=k-16&65535}else{l=h;m=k}if((m&65535)>240){a[1106736]=0;n=m+160&255&-16}else{a[1106736]=1;n=m&255}m=n|l;i=m;j=(m^f)&(f^e)}a[1106712]=(j&255)>>>7;a[1041660]=i;a[1106728]=i;a[1106720]=i;return}function wO(){var d=0,e=0;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}if((a[1041658]&16)==0){d=(b[520833]|0)+1&65535;b[520833]=d;a[1106728]=d<<16>>16!=0|0;e=(d&65535)>>>8&255;a[1106720]=e;return}else{d=(a[1041666]|0)+1&255;a[1041666]=d;a[1106728]=d;e=d;a[1106720]=e;return}}function wP(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=c[260418]|0;if((a[1041658]&32)==0){f=j5(e,65535)|0;a[1044496]=(f&65535)>>>8&255;b[520836]=(b[520836]|0)+2&65535;w6(f);return}f=j0(e)|0;a[1044496]=f;b[520836]=(b[520836]|0)+1&65535;if((a[1041658]&8)==0){e=a[1041660]|0;g=((e&255)+~(f&255)&65535)+(d[1106736]|0)&65535;a[1106736]=(g&65535)>>>15&255^1;h=g&255;i=h;j=(h^e)&(e^f)}else{e=b[520830]|0;h=e&255;g=((h&15)-(f&15)&255)-((a[1106736]|0)==0)&255;k=(e&240)-(f&-16&255)&65535;if((g&255)>15){l=g+10&15;m=k-16&65535}else{l=g;m=k}if((m&65535)>240){a[1106736]=0;n=m+160&255&-16}else{a[1106736]=1;n=m&255}m=n|l;i=m;j=(m^h)&(h^f)}a[1106712]=(j&255)>>>7;a[1041660]=i;a[1106728]=i;a[1106720]=i;return}function wQ(){var f=0,g=0,h=0,i=0,j=0;f=(a[1041658]&16)==0;g=c[276674]|0;h=j5(c[260418]|0,65535)|0;a[1044496]=(h&65535)>>>8&255;b[520836]=(b[520836]|0)+2&65535;i=h&65535|g;if(f){f=j5(i,16777215)|0;a[1044496]=(f&65535)>>>8&255;g=(e[520833]|0)-(f&65535)|0;a[1106736]=g>>>31&255^1;a[1106728]=(g&65535|0)!=0|0;j=g>>>8&255;a[1106720]=j;return}else{g=j0(i)|0;a[1044496]=g;i=(d[1041666]|0)-(g&255)&65535;a[1106736]=(i&65535)>>>15&255^1;g=i&255;a[1106728]=g;j=g;a[1106720]=j;return}}function wR(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=(a[1041658]&32)==0;f=c[276674]|0;g=j5(c[260418]|0,65535)|0;a[1044496]=(g&65535)>>>8&255;b[520836]=(b[520836]|0)+2&65535;h=g&65535|f;if(e){e=j5(h,16777215)|0;a[1044496]=(e&65535)>>>8&255;w6(e);return}e=j0(h)|0;a[1044496]=e;if((a[1041658]&8)==0){h=a[1041660]|0;f=((h&255)+~(e&255)&65535)+(d[1106736]|0)&65535;a[1106736]=(f&65535)>>>15&255^1;g=f&255;i=g;j=(g^h)&(h^e)}else{h=b[520830]|0;g=h&255;f=((g&15)-(e&15)&255)-((a[1106736]|0)==0)&255;k=(h&240)-(e&-16&255)&65535;if((f&255)>15){l=f+10&15;m=k-16&65535}else{l=f;m=k}if((m&65535)>240){a[1106736]=0;n=m+160&255&-16}else{a[1106736]=1;n=m&255}m=n|l;i=m;j=(m^g)&(g^e)}a[1106712]=(j&255)>>>7;a[1041660]=i;a[1106728]=i;a[1106720]=i;return}function wS(){var d=0,e=0,f=0,g=0,h=0;d=(a[1041658]&32)==0;e=c[276674]|0;f=j5(c[260418]|0,65535)|0;a[1044496]=(f&65535)>>>8&255;b[520836]=(b[520836]|0)+2&65535;g=f&65535|e;if(d){d=(j5(g,16777215)|0)+1&65535;e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}j3(d,g,16777215);a[1044496]=d&255;a[1106728]=d<<16>>16!=0|0;h=(d&65535)>>>8&255;a[1106720]=h;return}else{d=(j0(g)|0)+1&255;e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}j2(d,g);a[1044496]=d;a[1106728]=d;h=d;a[1106720]=h;return}}function wT(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=(a[1041658]&32)==0;f=j5(c[260418]|0,65535)|0;a[1044496]=(f&65535)>>>8&255;b[520836]=(b[520836]|0)+2&65535;g=j0(c[260418]|0)|0;a[1044496]=g;b[520836]=(b[520836]|0)+1&65535;h=(g&255)<<16|f&65535;if(e){e=j5(h,16777215)|0;a[1044496]=(e&65535)>>>8&255;w6(e);return}e=j0(h)|0;a[1044496]=e;if((a[1041658]&8)==0){h=a[1041660]|0;f=((h&255)+~(e&255)&65535)+(d[1106736]|0)&65535;a[1106736]=(f&65535)>>>15&255^1;g=f&255;i=g;j=(g^h)&(h^e)}else{h=b[520830]|0;g=h&255;f=((g&15)-(e&15)&255)-((a[1106736]|0)==0)&255;k=(h&240)-(e&-16&255)&65535;if((f&255)>15){l=f+10&15;m=k-16&65535}else{l=f;m=k}if((m&65535)>240){a[1106736]=0;n=m+160&255&-16}else{a[1106736]=1;n=m&255}m=n|l;i=m;j=(m^g)&(g^e)}a[1106712]=(j&255)>>>7;a[1041660]=i;a[1106728]=i;a[1106720]=i;return}function wU(){var e=0,f=0,g=0,h=0,i=0,j=0;e=j0(c[260418]|0)|0;a[1044496]=e;f=(b[520836]|0)+1&65535;b[520836]=f;g=f+(e<<24>>24)&65535;e=(g&65535)>>>8;if((a[1106728]|0)!=0){return}f=(c[348392]|0)+6|0;c[348392]=f;h=c[348406]|0;if((f|0)<(h|0)){i=f;j=h}else{while(1){j1();h=c[348392]|0;f=c[348406]|0;if((h|0)<(f|0)){i=h;j=f;break}}}do{if((b[520829]&256)!=0){if((d[1041673|0]|0)==(e&65535|0)){break}f=i+6|0;c[348392]=f;if((f|0)<(j|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j=e<<8;e=j|g&255;if(((b[520836]^j)&65535)>4095){j4((c[276676]|0)+(e&65535)|0);return}else{b[520836]=e;return}}function wV(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=(a[1041658]&32)==0;g=j0(c[260418]|0)|0;a[1044496]=g;b[520836]=(b[520836]|0)+1&65535;h=b[520831]|0;i=h+(g&255)&65535;do{if((h&255)<<24>>24!=0){g=(c[348392]|0)+6|0;c[348392]=g;if((g|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);if((b[520829]&256)==0){j=65535}else{j=(a[1041662]|0)!=0?65535:255}h=j5(i&65535,j)|0;a[1044496]=(h&65535)>>>8&255;j=c[276674]|h&65535;if((a[1041658]&16)==0){k=5305}else{if(((d[1041668]|0)+(j&255)|0)>>>0>255){k=5305}}do{if((k|0)==5305){h=(c[348392]|0)+6|0;c[348392]=h;if((h|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);k=(e[520834]|0)+j|0;if(f){f=j5(k,16777215)|0;a[1044496]=(f&65535)>>>8&255;w6(f);return}f=j0(k)|0;a[1044496]=f;if((a[1041658]&8)==0){k=a[1041660]|0;j=((k&255)+~(f&255)&65535)+(d[1106736]|0)&65535;a[1106736]=(j&65535)>>>15&255^1;h=j&255;l=h;m=(h^k)&(k^f)}else{k=b[520830]|0;h=k&255;j=((h&15)-(f&15)&255)-((a[1106736]|0)==0)&255;i=(k&240)-(f&-16&255)&65535;if((j&255)>15){n=j+10&15;o=i-16&65535}else{n=j;o=i}if((o&65535)>240){a[1106736]=0;p=o+160&255&-16}else{a[1106736]=1;p=o&255}o=p|n;l=o;m=(o^h)&(h^f)}a[1106712]=(m&255)>>>7;a[1041660]=l;a[1106728]=l;a[1106720]=l;return}function wW(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=(a[1041658]&32)==0;f=j0(c[260418]|0)|0;a[1044496]=f;b[520836]=(b[520836]|0)+1&65535;g=b[520831]|0;h=g+(f&255)&65535;do{if((g&255)<<24>>24!=0){f=(c[348392]|0)+6|0;c[348392]=f;if((f|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);if((b[520829]&256)==0){i=65535}else{i=(a[1041662]|0)!=0?65535:255}g=j5(h&65535,i)|0;a[1044496]=(g&65535)>>>8&255;i=c[276674]|g&65535;if(e){e=j5(i,16777215)|0;a[1044496]=(e&65535)>>>8&255;w6(e);return}e=j0(i)|0;a[1044496]=e;if((a[1041658]&8)==0){i=a[1041660]|0;g=((i&255)+~(e&255)&65535)+(d[1106736]|0)&65535;a[1106736]=(g&65535)>>>15&255^1;h=g&255;j=h;k=(h^i)&(i^e)}else{i=b[520830]|0;h=i&255;g=((h&15)-(e&15)&255)-((a[1106736]|0)==0)&255;f=(i&240)-(e&-16&255)&65535;if((g&255)>15){l=g+10&15;m=f-16&65535}else{l=g;m=f}if((m&65535)>240){a[1106736]=0;n=m+160&255&-16}else{a[1106736]=1;n=m&255}m=n|l;j=m;k=(m^h)&(h^e)}a[1106712]=(k&255)>>>7;a[1041660]=j;a[1106728]=j;a[1106720]=j;return}function wX(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=(a[1041658]&32)==0;g=j0(c[260418]|0)|0;a[1044496]=g;b[520836]=(b[520836]|0)+1&65535;h=(b[520832]|0)+(g&255)&65535;g=(c[348392]|0)+6|0;c[348392]=g;if((g|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}g=j5(h&65535,16777215)|0;a[1044496]=(g&65535)>>>8&255;h=(e[520834]|0)+(g&65535)+(c[276674]|0)&16777215;g=(c[348392]|0)+6|0;c[348392]=g;if((g|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}if(f){f=j5(h,16777215)|0;a[1044496]=(f&65535)>>>8&255;w6(f);return}f=j0(h)|0;a[1044496]=f;if((a[1041658]&8)==0){h=a[1041660]|0;g=((h&255)+~(f&255)&65535)+(d[1106736]|0)&65535;a[1106736]=(g&65535)>>>15&255^1;i=g&255;j=i;k=(i^h)&(h^f)}else{h=b[520830]|0;i=h&255;g=((i&15)-(f&15)&255)-((a[1106736]|0)==0)&255;l=(h&240)-(f&-16&255)&65535;if((g&255)>15){m=g+10&15;n=l-16&65535}else{m=g;n=l}if((n&65535)>240){a[1106736]=0;o=n+160&255&-16}else{a[1106736]=1;o=n&255}n=o|m;j=n;k=(n^i)&(i^f)}a[1106712]=(k&255)>>>7;a[1041660]=j;a[1106728]=j;a[1106720]=j;return}function wY(){var d=0,f=0,g=0;d=c[276674]|0;f=j5(c[260418]|0,65535)|0;b[520836]=(b[520836]|0)+2&65535;g=f&65535|d;j3(g&65535,(e[520832]|0)-1|0,65535);b[520832]=(b[520832]|0)-2&65535;a[1044496]=g&255;if((b[520829]&256)==0){return}a[1041665|0]=1;return}function wZ(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=(a[1041658]&32)==0;f=j0(c[260418]|0)|0;a[1044496]=f;b[520836]=(b[520836]|0)+1&65535;g=b[520831]|0;h=g+(f&255)&65535;do{if((g&255)<<24>>24!=0){f=(c[348392]|0)+6|0;c[348392]=f;if((f|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);g=h&255;f=(h&65535)>>>8;i=f&255;do{if((b[520829]&256)==0){j=5368}else{if((a[1041662]|0)!=0){j=5368;break}k=(a[1041666]|0)+g&255;l=i}}while(0);if((j|0)==5368){j=(b[520833]|0)+(f<<8|h&255)&65535;k=j&255;l=(j&65535)>>>8&255}j=(c[348392]|0)+6|0;c[348392]=j;if((j|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}j=((l&255)<<8|k&255)&65535;if(e){e=j5(j,65535)|0;a[1044496]=(e&65535)>>>8&255;w6(e);return}e=j0(j)|0;a[1044496]=e;if((a[1041658]&8)==0){j=a[1041660]|0;k=((j&255)+~(e&255)&65535)+(d[1106736]|0)&65535;a[1106736]=(k&65535)>>>15&255^1;l=k&255;m=l;n=(l^j)&(j^e)}else{j=b[520830]|0;l=j&255;k=((l&15)-(e&15)&255)-((a[1106736]|0)==0)&255;h=(j&240)-(e&-16&255)&65535;if((k&255)>15){o=k+10&15;p=h-16&65535}else{o=k;p=h}if((p&65535)>240){a[1106736]=0;q=p+160&255&-16}else{a[1106736]=1;q=p&255}p=q|o;m=p;n=(p^l)&(l^e)}a[1106712]=(n&255)>>>7;a[1041660]=m;a[1106728]=m;a[1106720]=m;return}function w_(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=(a[1041658]&32)==0;e=j0(c[260418]|0)|0;a[1044496]=e;b[520836]=(b[520836]|0)+1&65535;f=b[520831]|0;g=f+(e&255)&65535;do{if((f&255)<<24>>24!=0){e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);f=g&255;e=(g&65535)>>>8;h=e&255;do{if((b[520829]&256)==0){i=5391}else{if((a[1041662]|0)!=0){i=5391;break}j=(a[1041666]|0)+f&255;k=h}}while(0);if((i|0)==5391){i=(b[520833]|0)+(e<<8|g&255)&65535;j=i&255;k=(i&65535)>>>8&255}i=(c[348392]|0)+6|0;c[348392]=i;if((i|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}i=((k&255)<<8|j&255)&65535;if(d){d=(j5(i,65535)|0)+1&65535;j=(c[348392]|0)+6|0;c[348392]=j;if((j|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}j3(d,i,65535);a[1044496]=d&255;a[1106728]=d<<16>>16!=0|0;l=(d&65535)>>>8&255;a[1106720]=l;return}else{d=(j0(i)|0)+1&255;j=(c[348392]|0)+6|0;c[348392]=j;if((j|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}j2(d,i);a[1044496]=d;a[1106728]=d;l=d;a[1106720]=l;return}}function w$(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=(a[1041658]&32)==0;g=j0(c[260418]|0)|0;a[1044496]=g;b[520836]=(b[520836]|0)+1&65535;h=b[520831]|0;i=h+(g&255)&65535;do{if((h&255)<<24>>24!=0){g=(c[348392]|0)+6|0;c[348392]=g;if((g|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);h=i&65535;i=j5(h,16777215)|0;a[1044496]=(i&65535)>>>8&255;g=j0(h+2|0)|0;a[1044496]=g;h=((g&255)<<16|i&65535)+(e[520834]|0)|0;if(f){f=j5(h,16777215)|0;a[1044496]=(f&65535)>>>8&255;w6(f);return}f=j0(h)|0;a[1044496]=f;if((a[1041658]&8)==0){h=a[1041660]|0;i=((h&255)+~(f&255)&65535)+(d[1106736]|0)&65535;a[1106736]=(i&65535)>>>15&255^1;g=i&255;j=g;k=(g^h)&(h^f)}else{h=b[520830]|0;g=h&255;i=((g&15)-(f&15)&255)-((a[1106736]|0)==0)&255;l=(h&240)-(f&-16&255)&65535;if((i&255)>15){m=i+10&15;n=l-16&65535}else{m=i;n=l}if((n&65535)>240){a[1106736]=0;o=n+160&255&-16}else{a[1106736]=1;o=n&255}n=o|m;j=n;k=(n^g)&(g^f)}a[1106712]=(k&255)>>>7;a[1041660]=j;a[1106728]=j;a[1106720]=j;return}function w0(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=(a[1041658]&32)==0;g=c[276674]|0;h=j5(c[260418]|0,65535)|0;a[1044496]=(h&65535)>>>8&255;b[520836]=(b[520836]|0)+2&65535;i=h&65535|g;if((a[1041658]&16)==0){j=5424}else{if(((d[1041668]|0)+(i&255)|0)>>>0>255){j=5424}}do{if((j|0)==5424){g=(c[348392]|0)+6|0;c[348392]=g;if((g|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j=(e[520834]|0)+i|0;if(f){f=j5(j,16777215)|0;a[1044496]=(f&65535)>>>8&255;w6(f);return}f=j0(j)|0;a[1044496]=f;if((a[1041658]&8)==0){j=a[1041660]|0;i=((j&255)+~(f&255)&65535)+(d[1106736]|0)&65535;a[1106736]=(i&65535)>>>15&255^1;g=i&255;k=g;l=(g^j)&(j^f)}else{j=b[520830]|0;g=j&255;i=((g&15)-(f&15)&255)-((a[1106736]|0)==0)&255;h=(j&240)-(f&-16&255)&65535;if((i&255)>15){m=i+10&15;n=h-16&65535}else{m=i;n=h}if((n&65535)>240){a[1106736]=0;o=n+160&255&-16}else{a[1106736]=1;o=n&255}n=o|m;k=n;l=(n^g)&(g^f)}a[1106712]=(l&255)>>>7;a[1041660]=k;a[1106728]=k;a[1106720]=k;return}function w1(){var d=0,f=0,g=0;d=(c[348392]|0)+12|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}d=b[520829]|0;if((d&256)!=0){a[1041664]=(a[1041664]|0)+1&255;f=j0(e[520832]|0)|0;a[1041666]=f;a[1106728]=f;a[1106720]=f;a[1044496]=f;return}f=b[520832]|0;if((d&16)==0){d=j5((f&65535)+1|0,65535)|0;b[520833]=d;b[520832]=(b[520832]|0)+2&65535;a[1106728]=d<<16>>16!=0|0;g=(d&65535)>>>8&255;a[1106720]=g;a[1044496]=g;return}else{g=f+1&65535;b[520832]=g;f=j0(g&65535)|0;a[1041666]=f;a[1106728]=f;a[1106720]=f;a[1044496]=f;return}}function w2(){var d=0,f=0,g=0,h=0,i=0;a[1044496]=((j5(c[260418]|0,65535)|0)&65535)>>>8&255;b[520836]=(b[520836]|0)+2&65535;d=j0(c[260418]|0)|0;f=(b[520836]|0)+1&65535;b[520836]=f;a[1044496]=f&255;f=j0(c[260418]|0)|0;a[1044496]=f;b[520836]=(b[520836]|0)+1&65535;g=(f&255)<<8|d&255;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}d=j5((b[520833]|0)+g&65535|c[276676],65535)|0;g=d&65535;a[1044496]=(d&65535)>>>8&255;j3((b[520836]|0)-1&65535,(e[520832]|0)-1|0,65535);b[520832]=(b[520832]|0)-2&65535;if((b[520829]&256)==0){h=c[276676]|0;i=h+g|0;j4(i);return}a[1041665|0]=1;h=c[276676]|0;i=h+g|0;j4(i);return}function w3(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=(a[1041658]&32)==0;g=c[276674]|0;h=j5(c[260418]|0,65535)|0;a[1044496]=(h&65535)>>>8&255;b[520836]=(b[520836]|0)+2&65535;i=h&65535|g;if((a[1041658]&16)==0){j=5460}else{if(((d[1041666]|0)+(i&255)|0)>>>0>255){j=5460}}do{if((j|0)==5460){g=(c[348392]|0)+6|0;c[348392]=g;if((g|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j=(e[520833]|0)+i|0;if(f){f=j5(j,16777215)|0;a[1044496]=(f&65535)>>>8&255;w6(f);return}f=j0(j)|0;a[1044496]=f;if((a[1041658]&8)==0){j=a[1041660]|0;i=((j&255)+~(f&255)&65535)+(d[1106736]|0)&65535;a[1106736]=(i&65535)>>>15&255^1;g=i&255;k=g;l=(g^j)&(j^f)}else{j=b[520830]|0;g=j&255;i=((g&15)-(f&15)&255)-((a[1106736]|0)==0)&255;h=(j&240)-(f&-16&255)&65535;if((i&255)>15){m=i+10&15;n=h-16&65535}else{m=i;n=h}if((n&65535)>240){a[1106736]=0;o=n+160&255&-16}else{a[1106736]=1;o=n&255}n=o|m;k=n;l=(n^g)&(g^f)}a[1106712]=(l&255)>>>7;a[1041660]=k;a[1106728]=k;a[1106720]=k;return}function w4(){var d=0,f=0,g=0,h=0,i=0;d=(a[1041658]&32)==0;f=c[276674]|0;g=j5(c[260418]|0,65535)|0;a[1044496]=(g&65535)>>>8&255;b[520836]=(b[520836]|0)+2&65535;h=g&65535|f;f=(c[348392]|0)+6|0;c[348392]=f;if((f|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}f=(e[520833]|0)+h|0;if(d){d=(j5(f,16777215)|0)+1&65535;h=(c[348392]|0)+6|0;c[348392]=h;if((h|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}j3(d,f,16777215);a[1044496]=d&255;a[1106728]=d<<16>>16!=0|0;i=(d&65535)>>>8&255;a[1106720]=i;return}else{d=(j0(f)|0)+1&255;h=(c[348392]|0)+6|0;c[348392]=h;if((h|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}j2(d,f);a[1044496]=d;a[1106728]=d;i=d;a[1106720]=i;return}}function w5(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=(a[1041658]&32)==0;g=j5(c[260418]|0,65535)|0;a[1044496]=(g&65535)>>>8&255;b[520836]=(b[520836]|0)+2&65535;h=j0(c[260418]|0)|0;a[1044496]=h;b[520836]=(b[520836]|0)+1&65535;i=(e[520833]|0)+((h&255)<<16|g&65535)|0;if(f){f=j5(i,16777215)|0;a[1044496]=(f&65535)>>>8&255;w6(f);return}f=j0(i)|0;a[1044496]=f;if((a[1041658]&8)==0){i=a[1041660]|0;g=((i&255)+~(f&255)&65535)+(d[1106736]|0)&65535;a[1106736]=(g&65535)>>>15&255^1;h=g&255;j=h;k=(h^i)&(i^f)}else{i=b[520830]|0;h=i&255;g=((h&15)-(f&15)&255)-((a[1106736]|0)==0)&255;l=(i&240)-(f&-16&255)&65535;if((g&255)>15){m=g+10&15;n=l-16&65535}else{m=g;n=l}if((n&65535)>240){a[1106736]=0;o=n+160&255&-16}else{a[1106736]=1;o=n&255}n=o|m;j=n;k=(n^h)&(h^f)}a[1106712]=(k&255)>>>7;a[1041660]=j;a[1106728]=j;a[1106720]=j;return}function w6(c){c=c|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;e=b[520830]|0;f=e&65535;if((a[1041658]&8)==0){g=(d[1106736]|0)+(f-(c&65535))|0;h=g+65535|0;a[1106736]=(g|0)>0|0;i=h&65535;j=(h^f)&((e^c)&65535);k=j>>>15;l=k&255;m=l&1;a[1106712]=m;b[520830]=i;n=i<<16>>16!=0;o=n&1;a[1106728]=o;p=(i&65535)>>>8;q=p&255;a[1106720]=q;return}h=((e&15)-(c&15)&65535)-((a[1106736]|0)==0)&65535;g=(e&240)-(c&240)&65535;r=(e&3840)-(c&3840)&65535;s=(f&61440)-(c&-4096&65535)|0;if((h&65535)>15){t=h+10&15;u=g-16&65535}else{t=h;u=g}if((u&65535)>240){v=u+160&240;w=r-256&65535}else{v=u;w=r}if((w&65535)>3840){x=w+2560&3840;y=s-4096|0}else{x=w;y=s}if(y>>>0>61440){z=y+40960&61440;A=0}else{z=y;A=1}a[1106736]=A;A=z|(v|t|x)&65535;i=A&65535;j=(A^f)&((e^c)&65535);k=j>>>15;l=k&255;m=l&1;a[1106712]=m;b[520830]=i;n=i<<16>>16!=0;o=n&1;a[1106728]=o;p=(i&65535)>>>8;q=p&255;a[1106720]=q;return}function w7(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=e&4095;if((f&d|0)==(f|0)){j2(b&255,d);if((e|0)==255){g=((d&255)+1&255|d&65535&-256)&65535|d&-65536}else if((e|0)==65535){g=(d&65535)+1&65535|d&-65536}else{g=d+1|0}j2((b&65535)>>>8&255,g);return}g=c[1069188+((d>>>12&4095)<<2)>>2]|0;do{if((d&4227072|0)==0){if((d+24576&16384|0)!=0){h=8;break}h=(d+16384&32256|0)==0?12:6}else{h=(d&8388608|0)==0?8:c[348401]|0}}while(0);if(g>>>0>=19){e=d&65535;a[g+e|0]=b&255;a[g+(e+1)|0]=(b&65535)>>>8&255;if((a[1393610]|0)!=0){return}e=(c[348392]|0)+(h<<1)|0;c[348392]=e;if((e|0)<(c[348406]|0)){return}do{j1();}while((c[348392]|0)>=(c[348406]|0));return}switch(g|0){case 1:{if((a[1393610]|0)!=0){if((d&65280|0)!=8448){HB(b&255,d&65535)}g=d+1|0;if((g&65280|0)==8448){return}HB((b&65535)>>>8&255,g&65535);return}HB(b&255,d&65535);do{if((a[1393610]|0)==0){g=(c[348392]|0)+h|0;c[348392]=g;if((g|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);HB((b&65535)>>>8&255,d+1&65535);if((a[1393610]|0)!=0){return}g=(c[348392]|0)+h|0;c[348392]=g;if((g|0)<(c[348406]|0)){return}do{j1();}while((c[348392]|0)>=(c[348406]|0));return};case 0:{HH(b&255,d&65535);do{if((a[1393610]|0)==0){g=(c[348392]|0)+h|0;c[348392]=g;if((g|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);HH((b&65535)>>>8&255,d+1&65535);if((a[1393610]|0)!=0){return}g=(c[348392]|0)+h|0;c[348392]=g;if((g|0)<(c[348406]|0)){return}do{j1();}while((c[348392]|0)>=(c[348406]|0));return};case 2:{g=c[274485]|0;do{if((g|0)!=0){e=d>>>1&8355840|d&32767;a[(c[263193]|0)+(g&e)|0]=b&255;f=(b&65535)>>>8&255;i=c[263193]|0;if(g>>>0>4094){a[i+((c[274485]&e)+1)|0]=f;break}else{e=d+1|0;a[i+(c[274485]&(e>>>1&8355840|e&32767))|0]=f;break}}}while(0);if((a[1393610]|0)!=0){return}g=(c[348392]|0)+(h<<1)|0;c[348392]=g;if((g|0)<(c[348406]|0)){return}do{j1();}while((c[348392]|0)>=(c[348406]|0));return};case 3:{g=c[261136]|0;do{if((g|0)!=0){f=d>>>1&8355840|d&32767;a[(c[261140]|0)+(g&f)|0]=b&255;e=(b&65535)>>>8&255;i=c[261140]|0;if(g>>>0>4094){a[i+((c[261136]&f)+1)|0]=e;break}else{f=d+1|0;a[i+(c[261136]&(f>>>1&8355840|f&32767))|0]=e;break}}}while(0);if((a[1393610]|0)!=0){return}g=(c[348392]|0)+(h<<1)|0;c[348392]=g;if((g|0)<(c[348406]|0)){return}do{j1();}while((c[348392]|0)>=(c[348406]|0));return};case 4:{g=c[274485]|0;do{if((g|0)!=0){e=(d&32767)-24576+(d>>>3&122880)|0;a[(c[263193]|0)+(g&e)|0]=b&255;f=(b&65535)>>>8&255;i=c[263193]|0;if(g>>>0>4094){a[i+((c[274485]&e)+1)|0]=f;break}else{e=d+1|0;a[i+(c[274485]&(e&32767)-24576+(e>>>3&122880))|0]=f;break}}}while(0);if((a[1393610]|0)!=0){return}g=(c[348392]|0)+(h<<1)|0;c[348392]=g;if((g|0)<(c[348406]|0)){return}do{j1();}while((c[348392]|0)>=(c[348406]|0));return};case 7:{g=d&32767;a[(c[263196]|0)+(g-24576)|0]=b&255;a[(c[263196]|0)+(g-24575)|0]=(b&65535)>>>8&255;if((a[1393610]|0)!=0){return}g=(c[348392]|0)+(h<<1)|0;c[348392]=g;if((g|0)<(c[348406]|0)){return}do{j1();}while((c[348392]|0)>=(c[348406]|0));return};case 6:{g=d&65535;a[(c[263193]|0)+g|0]=b&255;a[(c[263193]|0)+(g+1)|0]=(b&65535)>>>8&255;if((a[1393610]|0)!=0){return}g=(c[348392]|0)+(h<<1)|0;c[348392]=g;if((g|0)<(c[348406]|0)){return}do{j1();}while((c[348392]|0)>=(c[348406]|0));return};case 5:{fc[c[201852]&127](b&255,d&65535);do{if((a[1393610]|0)==0){g=(c[348392]|0)+h|0;c[348392]=g;if((g|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);fc[c[201852]&127]((b&65535)>>>8&255,d+1&65535);if((a[1393610]|0)!=0){return}g=(c[348392]|0)+h|0;c[348392]=g;if((g|0)<(c[348406]|0)){return}do{j1();}while((c[348392]|0)>=(c[348406]|0));return};case 13:{jQ(b&255,d&65535);do{if((a[1393610]|0)==0){g=(c[348392]|0)+h|0;c[348392]=g;if((g|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);jQ((b&65535)>>>8&255,d+1&65535);if((a[1393610]|0)!=0){return}g=(c[348392]|0)+h|0;c[348392]=g;if((g|0)<(c[348406]|0)){return}do{j1();}while((c[348392]|0)>=(c[348406]|0));return};case 14:{Hu(b&255,d&65535);do{if((a[1393610]|0)==0){g=(c[348392]|0)+h|0;c[348392]=g;if((g|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);Hu((b&65535)>>>8&255,d+1&65535);if((a[1393610]|0)!=0){return}g=(c[348392]|0)+h|0;c[348392]=g;if((g|0)<(c[348406]|0)){return}do{j1();}while((c[348392]|0)>=(c[348406]|0));return};case 15:{fc[c[36646]&127](d,b&255);do{if((a[1393610]|0)==0){g=(c[348392]|0)+h|0;c[348392]=g;if((g|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);fc[c[36646]&127](d+1|0,(b&65535)>>>8&255);if((a[1393610]|0)!=0){return}g=(c[348392]|0)+h|0;c[348392]=g;if((g|0)<(c[348406]|0)){return}do{j1();}while((c[348392]|0)>=(c[348406]|0));return};case 16:{TZ(b&255,d);do{if((a[1393610]|0)==0){g=(c[348392]|0)+h|0;c[348392]=g;if((g|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);TZ((b&65535)>>>8&255,d+1|0);if((a[1393610]|0)!=0){return}g=(c[348392]|0)+h|0;c[348392]=g;if((g|0)<(c[348406]|0)){return}do{j1();}while((c[348392]|0)>=(c[348406]|0));return};case 17:{jM(b&255,d);do{if((a[1393610]|0)==0){g=(c[348392]|0)+h|0;c[348392]=g;if((g|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);jM((b&65535)>>>8&255,d+1|0);if((a[1393610]|0)!=0){return}d=(c[348392]|0)+h|0;c[348392]=d;if((d|0)<(c[348406]|0)){return}do{j1();}while((c[348392]|0)>=(c[348406]|0));return};default:{if((a[1393610]|0)!=0){return}d=(c[348392]|0)+(h<<1)|0;c[348392]=d;if((d|0)<(c[348406]|0)){return}do{j1();}while((c[348392]|0)>=(c[348406]|0));return}}}function w8(){b[565464]=128;b[565465]=132;c[201850]=1702;return}function w9(c){c=c|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;e=b[520830]|0;f=e&65535;if((a[1041658]&8)==0){g=c&65535;h=f+g+(d[1106736]|0)|0;a[1106736]=h>>>0>65535|0;i=h&65535;j=(h^g)&((e^c)&65535^32768);k=j>>>15;l=k&255;m=l&1;a[1106712]=m;b[520830]=i;n=i<<16>>16!=0;o=n&1;a[1106728]=o;p=(i&65535)>>>8;q=p&255;a[1106720]=q;return}g=e&240;h=e&3840;r=f&61440;f=((e&15)+(c&15)&65535)+(d[1106736]|0)&65535;if((f&65535)>9){s=f+6&15;t=g+16&65535}else{s=f;t=g}g=t+(c&240)&65535;if((g&65535)>144){u=g+96&240;v=h+256&65535}else{u=g;v=h}h=v+(c&3840)&65535;if((h&65535)>2304){w=h+1536&3840;x=r+4096|0}else{w=h;x=r}r=x+(c&-4096&65535)|0;if(r>>>0>36864){y=r+24576&61440;z=1}else{y=r;z=0}a[1106736]=z;z=y|(u|s|w)&65535;i=z&65535;j=(z^c&65535)&((e^c)&65535^32768);k=j>>>15;l=k&255;m=l&1;a[1106712]=m;b[520830]=i;n=i<<16>>16!=0;o=n&1;a[1106728]=o;p=(i&65535)>>>8;q=p&255;a[1106720]=q;return}function xa(a){a=a|0;var b=0,d=0,e=0;b=c[1052804+((a>>>12&4095)<<2)>>2]|0;if(b>>>0>=19){d=b+(a&65535)|0;return d|0}switch(b|0){case 2:{b=c[274485]|0;if((b&4095|0)!=4095){d=0;return d|0}d=(c[263193]|0)+(b&(a>>>1&8355840|a&32767))|0;return d|0};case 3:{b=c[261136]|0;if((b&4095|0)!=4095){d=0;return d|0}d=(c[261140]|0)+(b&(a>>>1&8355840|a&32767))|0;return d|0};case 7:{d=(c[263196]|0)+((a&32767)-24576)|0;return d|0};case 10:{b=a&15728640;if((b|0)==15728640){e=c[198890]|0}else if((b|0)==13631488){e=c[198898]|0}else if((b|0)==14680064){e=c[198894]|0}else{e=0}d=(c[263192]|0)+((a&1048575)+e)|0;return d|0};case 4:{e=c[274485]|0;if((e&4095|0)!=4095){d=0;return d|0}d=(c[263193]|0)+(e&(a&32767)-24576+(a>>>3&122880))|0;return d|0};case 6:{d=(c[263193]|0)+(a&65535)|0;return d|0};case 14:{if(((a&65535)-32752&65535)<7){d=0;return d|0}d=(c[263198]|0)+((a&65535)-24576)|0;return d|0};case 13:{if(((a&65535)-32576&65535)<31){d=0;return d|0}d=(c[263197]|0)+((a&65535)-24576)|0;return d|0};default:{d=0;return d|0}}return 0}function xb(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}b[520836]=h+1&65535;h=b[520831]|0;l=h+(e&255)&65535;do{if((h&255)<<24>>24!=0){e=i+6|0;c[348392]=e;if((e|0)<(j|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j=l&65535;l=j5(j,16777215)|0;a[1044496]=(l&65535)>>>8&255;i=j0(j+2|0)|0;a[1044496]=i;return(i&255)<<16|l&65535|0}function xc(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;g=(a[1041662]|0)==0;h=b[520836]|0;i=a[(c[348396]|0)+(h&65535)|0]|0;a[1044496]=i;j=(c[348392]|0)+(c[348399]|0)|0;c[348392]=j;k=c[348406]|0;l=(j|0)<(k|0);if(g){if(l){m=h;n=j;o=k}else{do{j1();p=c[348392]|0;q=c[348406]|0;}while((p|0)>=(q|0));m=b[520836]|0;n=p;o=q}b[520836]=m+1&65535;m=b[520831]|0;q=m+(i&255)&65535;do{if((m&255)<<24>>24==0){r=n;s=o}else{p=n+6|0;c[348392]=p;if((p|0)<(o|0)){r=p;s=o;break}while(1){j1();p=c[348392]|0;g=c[348406]|0;if((p|0)<(g|0)){r=p;s=g;break}}}}while(0);o=(d[1041666]|0)+q&65535;n=r+6|0;c[348392]=n;if((n|0)>=(s|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}t=(o&255|q&-256)&65535}else{if(l){u=h;v=j;w=k}else{do{j1();x=c[348392]|0;y=c[348406]|0;}while((x|0)>=(y|0));u=b[520836]|0;v=x;w=y}b[520836]=u+1&65535;u=b[520831]|0;y=u+(i&255)&65535;do{if((u&255)<<24>>24==0){z=v;A=w}else{i=v+6|0;c[348392]=i;if((i|0)<(w|0)){z=i;A=w;break}while(1){j1();i=c[348392]|0;x=c[348406]|0;if((i|0)<(x|0)){z=i;A=x;break}}}}while(0);w=(e[520833]|0)+(y&65535)|0;y=z+6|0;c[348392]=y;if((y|0)>=(A|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}t=w&65535}w=j5(t,(a[1041662]|0)!=0?65535:255)|0;t=w&65535;if((f&1|0)==0){B=c[276674]|0;C=B|t;return C|0}a[1044496]=(w&65535)>>>8&255;B=c[276674]|0;C=B|t;return C|0}function xd(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;g=1183786+(f*22|0)|0;h=1183792+(f*22|0)|0;i=j0(d[g]<<16|e[h>>1])|0;j=c[348392]|0;c[348392]=j+8;k=1183795+(f*22|0)|0;a[k]=-128;if((i<<24>>24|0)==(-128|0)){a[1183794+(f*22|0)|0]=1}else if((i<<24>>24|0)==0){a[1183794+(f*22|0)|0]=0;if((a[1183777+(f*22|0)|0]|0)==0){l=b[h>>1]|0}else{if((d[1044491]&254<<f|0)==0){m=j+16|0;n=b[h>>1]|0}else{o=(b[h>>1]|0)+1&65535;b[h>>1]=o;m=j+24|0;n=o}c[348392]=m;b[1183788+(f*22|0)>>1]=j5(d[g]<<16|n&65535,16777215)|0;n=(b[h>>1]|0)+1&65535;b[h>>1]=n;l=n}b[h>>1]=l+1&65535;c[1106760+(f<<2)>>2]=0;p=0;return p|0}else{a[1183794+(f*22|0)|0]=(i&255)>>>7^1;a[k]=i&127}i=(b[h>>1]|0)+1&65535;b[h>>1]=i;a[1183797+(f*22|0)|0]=1;if((a[1183777+(f*22|0)|0]|0)==0){c[1106760+(f<<2)>>2]=xa(d[g]<<16|i&65535)|0;p=1;return p|0}else{c[348392]=j+24;j=j5(d[g]<<16|i&65535,16777215)|0;b[1183788+(f*22|0)>>1]=j;b[h>>1]=(b[h>>1]|0)+2&65535;c[1106760+(f<<2)>>2]=xa(d[1183790+(f*22|0)|0]<<16|j&65535)|0;p=1;return p|0}return 0}
function xe(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0,cf=0,cg=0,ch=0,ci=0,cj=0,ck=0,cl=0,cm=0,cn=0,co=0,cp=0,cq=0,cr=0,cs=0,ct=0,cu=0,cv=0,cw=0,cx=0,cy=0,cz=0,cA=0,cB=0,cC=0,cD=0,cE=0,cF=0,cG=0,cH=0,cI=0,cJ=0,cK=0,cL=0,cM=0,cN=0,cO=0,cP=0,cQ=0,cR=0,cS=0,cT=0,cU=0,cV=0,cW=0,cX=0,cY=0,cZ=0,c_=0,c$=0,c0=0,c1=0,c2=0,c3=0,c4=0,c5=0,c6=0,c7=0,c8=0,c9=0,da=0,db=0,dc=0,dd=0,de=0,df=0,dg=0,dh=0,di=0,dj=0,dk=0,dl=0,dm=0,dn=0,dp=0,dq=0,dr=0,ds=0;h=i;i=i+96|0;j=h|0;k=h+8|0;l=h+16|0;m=h+24|0;n=h+32|0;o=h+40|0;p=h+48|0;q=h+56|0;r=h+64|0;s=h+72|0;t=h+80|0;u=h+88|0;if((g&65535)>>>0>=(c[295940]|0)>>>0){i=h;return}g=a[1182306]|0;if(g<<24>>24==10){v=c[295579]|0;if((v|0)!=0){w=v;x=5766}}else{v=c[295579]|0;if(g<<24>>24==26&(v|0)!=0){w=v;x=5766}}if((x|0)==5766){c[295579]=w-1;c[295580]=(c[295580]|0)+1;i=h;return}if((a[1182304]|0)==0){a[1182324+(c[295578]|0)|0]=f;a[1182305]=0;c[295578]=(c[295578]|0)+1;y=a[1182304]|0;z=0}else{a[1182306]=f;c[295578]=0;a[1182304]=0;a[1182305]=1;switch(f&255|0){case 24:{c[295577]=4;A=0;B=8;break};case 19:{c[295577]=3;A=0;B=6;break};case 35:{c[295577]=3;A=0;B=6;break};case 32:{c[295577]=2;A=0;B=4;break};case 39:case 47:{c[295577]=1;A=0;B=2;break};case 23:case 55:case 63:{a[1182306]=31;x=5800;break};case 0:{c[295577]=2;A=0;B=4;break};case 37:case 33:{c[295577]=4;A=0;B=8;break};case 9:case 57:case 61:case 13:{c[295577]=3;A=0;B=6;break};case 8:{c[295577]=3;A=0;B=6;break};case 27:{c[295577]=3;A=0;B=6;break};case 43:{c[295577]=3;A=0;B=6;break};case 5:case 53:case 49:case 1:{c[295577]=4;A=0;B=8;break};case 56:{c[295577]=4;A=0;B=8;break};case 48:case 16:{c[295577]=2;A=0;B=4;break};case 25:case 29:{c[295577]=3;A=0;B=6;break};case 52:case 20:{c[295577]=6;A=0;B=12;break};case 7:case 15:{c[295577]=1;A=0;B=2;break};case 59:case 11:{c[295577]=3;A=0;B=6;break};case 36:case 4:{c[295577]=2;A=0;B=4;break};case 40:{c[295577]=3;A=0;B=6;break};case 30:case 46:case 62:case 14:{c[295577]=2;A=0;B=4;break};case 31:{x=5800;break};case 22:case 38:case 54:case 6:{c[295577]=3;A=0;B=6;break};case 41:case 45:{c[295577]=3;A=0;B=6;break};case 44:case 12:{c[295577]=3;A=0;B=6;break};case 60:case 28:{c[295577]=6;A=0;B=12;break};case 21:case 17:{c[295577]=4;A=0;B=8;break};case 58:case 42:case 26:{a[1182306]=26;c[295577]=1;A=0;B=2;break};case 10:{c[295577]=1;A=0;B=2;break};case 51:case 3:{c[295577]=3;A=0;B=6;break};case 50:case 34:case 18:case 2:{c[295577]=7;A=0;B=14;break};default:{c[295577]=0;a[1182304]=1;a[1182305]=1;A=1;B=0}}if((x|0)==5800){c[295577]=1;A=0;B=2}c[295577]=B;y=A;z=1}do{if(y<<24>>24==0){A=z<<24>>24!=0;if(A&f<<24>>24==-128){break}B=c[295577]|0;if(A|(B|0)==0){i=h;return}A=B-1|0;c[295577]=A;if((A|0)!=0){i=h;return}a[1182304]=1;c[295580]=0;switch(d[1182306]|0){case 48:case 16:{A=d[1182325]<<8|d[1182324];b[591731]=A;B=d[1182327]<<8|d[1182326];b[591732]=B;if(A<<16>>16==0){b[591733]=32767;C=47;D=127;E=-1}else{if(A<<16>>16<0){F=A<<16>>16==-32768?32767:-A&65535;G=-1}else{F=A;G=1}if(F<<16>>16<16384){A=B;w=F;while(1){v=w<<1;g=A-1&65535;if(v<<16>>16<16384){A=g;w=v}else{H=g;I=v;break}}}else{H=B;I=F}w=I<<16>>16;do{if(I<<16>>16==16384){if(G<<16>>16==1){b[591733]=32767;J=H;K=127;L=-1;break}else{b[591733]=-16384;J=H-1&65535;K=-64;L=0;break}}else{A=b[165240+((w-16384>>7)+101<<1)>>1]|0;v=((ab((ab(A,w)|0)>>15,-A|0)|0)>>>15)+A<<17>>16;A=ab(((ab((ab(v,w)|0)>>15,-v|0)|0)>>>15)+v<<17>>16,G<<16>>16)|0;v=A&65535;b[591733]=v;J=H;K=(v&65535)>>>8&255;L=A&255}}while(0);C=1-J&65535;D=K;E=L}b[591734]=C;c[295579]=4;a[1182836]=E;a[1182837]=D;a[1182838]=C&255;a[1182839]=(C&65535)>>>8&255;i=h;return};case 60:case 28:{w=d[1182325]<<8|d[1182324];b[591845]=w;B=d[1182327]<<8|d[1182326];b[591844]=B;A=d[1182329]<<8|d[1182328];b[591843]=A;v=d[1182331]<<8|d[1182330];b[591846]=v;g=d[1182333]<<8|d[1182332];b[591847]=g;M=d[1182335]<<8|d[1182334];b[591848]=M;N=g<<16>>16;g=(xX(w)|0)<<16>>16;O=(ab(g,N)|0)>>>15;P=v<<16>>16;v=w<<16>>16<0;do{if(v){if(w<<16>>16==-32768){Q=O+((P*-32768|0)>>>15)&65535;b[591852]=Q;R=-32768;S=Q;break}else{T=-w&65535;x=5853;break}}else{T=w;x=5853}}while(0);do{if((x|0)==5853){Q=T<<16>>16;U=Q>>8;V=b[164184+(U+64<<1)>>1]|0;W=V-((ab(b[164184+(U<<1)>>1]|0,b[164728+((Q&255)<<1)>>1]|0)|0)>>15)|0;Q=((ab((W|0)<-32768?-32767:W<<16>>16,P)|0)>>>15)+O&65535;b[591852]=Q;if(v){if(w<<16>>16==-32768){R=-32768;S=Q;break}X=-w&65535}else{X=w}W=X<<16>>16;U=W>>8;V=b[164184+(U+64<<1)>>1]|0;Y=V-((ab(b[164184+(U<<1)>>1]|0,b[164728+((W&255)<<1)>>1]|0)|0)>>15)|0;R=(Y|0)<-32768?-32767:Y<<16>>16;S=Q}}while(0);w=((ab(R,N)|0)>>>15)-((ab(g,P)|0)>>>15)&65535;b[591853]=w;b[591846]=S;b[591847]=w;v=S<<16>>16;O=(xX(B)|0)<<16>>16;Q=(ab(O,v)|0)>>>15;Y=M<<16>>16;W=B<<16>>16<0;do{if(W){if(B<<16>>16==-32768){U=Q+((Y*-32768|0)>>>15)&65535;b[591854]=U;Z=-32768;_=U;break}else{$=-B&65535;x=5861;break}}else{$=B;x=5861}}while(0);do{if((x|0)==5861){M=$<<16>>16;P=M>>8;g=b[164184+(P+64<<1)>>1]|0;N=g-((ab(b[164184+(P<<1)>>1]|0,b[164728+((M&255)<<1)>>1]|0)|0)>>15)|0;M=((ab((N|0)<-32768?-32767:N<<16>>16,Y)|0)>>>15)+Q&65535;b[591854]=M;if(W){if(B<<16>>16==-32768){Z=-32768;_=M;break}aa=-B&65535}else{aa=B}N=aa<<16>>16;P=N>>8;g=b[164184+(P+64<<1)>>1]|0;U=g-((ab(b[164184+(P<<1)>>1]|0,b[164728+((N&255)<<1)>>1]|0)|0)>>15)|0;Z=(U|0)<-32768?-32767:U<<16>>16;_=M}}while(0);B=((ab(Z,v)|0)>>>15)-((ab(O,Y)|0)>>>15)|0;W=B&65535;b[591852]=W;b[591849]=W;b[591848]=_;Q=_<<16>>16;M=(xX(A)|0)<<16>>16;U=(ab(M,Q)|0)>>>15;N=w<<16>>16;P=A<<16>>16<0;do{if(P){if(A<<16>>16==-32768){g=U+((N*-32768|0)>>>15)&65535;b[591853]=g;ac=-32768;ad=g;break}else{ae=-A&65535;x=5869;break}}else{ae=A;x=5869}}while(0);do{if((x|0)==5869){w=ae<<16>>16;Y=w>>8;O=b[164184+(Y+64<<1)>>1]|0;v=O-((ab(b[164184+(Y<<1)>>1]|0,b[164728+((w&255)<<1)>>1]|0)|0)>>15)|0;w=((ab((v|0)<-32768?-32767:v<<16>>16,N)|0)>>>15)+U&65535;b[591853]=w;if(P){if(A<<16>>16==-32768){ac=-32768;ad=w;break}af=-A&65535}else{af=A}v=af<<16>>16;Y=v>>8;O=b[164184+(Y+64<<1)>>1]|0;g=O-((ab(b[164184+(Y<<1)>>1]|0,b[164728+((v&255)<<1)>>1]|0)|0)>>15)|0;ac=(g|0)<-32768?-32767:g<<16>>16;ad=w}}while(0);A=((ab(ac,Q)|0)>>>15)-((ab(M,N)|0)>>>15)|0;P=A&65535;b[591854]=P;b[591850]=ad;b[591851]=P;c[295579]=6;a[1182836]=B&255;a[1182837]=(W&65535)>>>8&255;a[1182838]=ad&255;a[1182839]=(ad&65535)>>>8&255;a[1182840]=A&255;a[1182841]=(P&65535)>>>8&255;i=h;return};case 36:case 4:{P=d[1182325]<<8|d[1182324];b[591735]=P;A=d[1182327]<<8|d[1182326];b[591736]=A;U=A<<16>>16;A=ab(U,(xX(P)|0)<<16>>16)|0;w=A>>>15;b[591737]=w&65535;do{if(P<<16>>16<0){if(P<<16>>16==-32768){ag=-32768;break}ah=-P&65535;x=5829}else{ah=P;x=5829}}while(0);if((x|0)==5829){P=ah<<16>>16;W=P>>8;B=b[164184+(W+64<<1)>>1]|0;N=B-((ab(b[164184+(W<<1)>>1]|0,b[164728+((P&255)<<1)>>1]|0)|0)>>15)|0;ag=(N|0)<-32768?-32767:N<<16>>16}N=ab(ag,U)|0;P=N>>>15;b[591738]=P&65535;c[295579]=4;a[1182836]=w&255;a[1182837]=A>>>23&255;a[1182838]=P&255;a[1182839]=N>>>23&255;i=h;return};case 31:{c[295579]=2048;i=h;return};case 0:{N=d[1182325]<<8|d[1182324];b[591725]=N;P=d[1182327]<<8|d[1182326];b[591726]=P;W=ab(P<<16>>16,N<<16>>16)|0;N=W>>>15;b[591727]=N&65535;c[295579]=2;a[1182836]=N&255;a[1182837]=W>>>23&255;i=h;return};case 32:{W=d[1182325]<<8|d[1182324];b[591728]=W;N=d[1182327]<<8|d[1182326];b[591729]=N;P=((ab(N<<16>>16,W<<16>>16)|0)>>>15&65535)+1&65535;b[591730]=P;c[295579]=2;a[1182836]=P&255;a[1182837]=(P&65535)>>>8&255;i=h;return};case 44:case 12:{P=d[1182325]<<8|d[1182324];b[591739]=P;W=d[1182327]<<8|d[1182326];b[591740]=W;N=d[1182329]<<8|d[1182328];b[591741]=N;B=N<<16>>16;N=(xX(P)|0)<<16>>16;M=(ab(B,N)|0)>>>15;Q=W<<16>>16;W=P<<16>>16<0;do{if(W){if(P<<16>>16==-32768){g=M+((Q*-32768|0)>>>15)|0;v=g&65535;b[591742]=v;ai=-32768;aj=(v&65535)>>>8&255;ak=g&255;break}else{al=-P&65535;x=5843;break}}else{al=P;x=5843}}while(0);do{if((x|0)==5843){A=al<<16>>16;w=A>>8;U=b[164184+(w+64<<1)>>1]|0;g=U-((ab(b[164184+(w<<1)>>1]|0,b[164728+((A&255)<<1)>>1]|0)|0)>>15)|0;A=((ab((g|0)<-32768?-32767:g<<16>>16,Q)|0)>>>15)+M|0;g=A&65535;b[591742]=g;if(W){w=A&255;U=(g&65535)>>>8&255;if(P<<16>>16==-32768){ai=-32768;aj=U;ak=w;break}am=-P&65535;an=w;ao=U}else{am=P;an=A&255;ao=(g&65535)>>>8&255}g=am<<16>>16;A=g>>8;U=b[164184+(A+64<<1)>>1]|0;w=U-((ab(b[164184+(A<<1)>>1]|0,b[164728+((g&255)<<1)>>1]|0)|0)>>15)|0;ai=(w|0)<-32768?-32767:w<<16>>16;aj=ao;ak=an}}while(0);P=((ab(ai,B)|0)>>>15)-((ab(Q,N)|0)>>>15)|0;W=P&65535;b[591743]=W;c[295579]=4;a[1182836]=ak;a[1182837]=aj;a[1182838]=P&255;a[1182839]=(W&65535)>>>8&255;i=h;return};case 50:case 34:case 18:case 2:{W=d[1182325]<<8|d[1182324];b[591744]=W;P=d[1182327]<<8|d[1182326];b[591745]=P;M=d[1182329]<<8|d[1182328];b[591746]=M;w=d[1182331]<<8|d[1182330];b[591747]=w;g=d[1182333]<<8|d[1182332];b[591748]=g;A=d[1182335]<<8|d[1182334];b[591749]=A;U=d[1182337]<<8|d[1182336];b[591750]=U;v=xX(A)|0;b[591679]=v;do{if(A<<16>>16<0){if(A<<16>>16==-32768){ap=-32768;break}aq=-A&65535;x=5877}else{aq=A;x=5877}}while(0);if((x|0)==5877){A=aq<<16>>16;N=A>>8;Q=b[164184+(N+64<<1)>>1]|0;B=Q-((ab(b[164184+(N<<1)>>1]|0,b[164728+((A&255)<<1)>>1]|0)|0)>>15)|0;ap=(B|0)<-32768?-32767:B&65535}b[591680]=ap;B=xX(U)|0;b[591681]=B;A=U<<16>>16<0;do{if(A){if(U<<16>>16==-32768){ar=-32768;break}as=-U&65535;x=5881}else{as=U;x=5881}}while(0);if((x|0)==5881){N=as<<16>>16;Q=N>>8;Y=b[164184+(Q+64<<1)>>1]|0;O=Y-((ab(b[164184+(Q<<1)>>1]|0,b[164728+((N&255)<<1)>>1]|0)|0)>>15)|0;ar=(O|0)<-32768?-32767:O&65535}b[591682]=ar;O=B<<16>>16;N=v<<16>>16;Q=(ab(O,-N|0)|0)>>>15&65535;b[591689]=Q;Y=ap<<16>>16;V=(ab(O,Y)|0)>>>15&65535;b[591690]=V;O=((ar<<16>>16)*32767|0)>>>15&65535;b[591691]=O;at=w<<16>>16;au=Q<<16>>16;Q=(ab(au,at)|0)>>>15;av=V<<16>>16;V=(ab(av,at)|0)>>>15;aw=O<<16>>16;O=(ab(aw,at)|0)>>>15;at=Q+(W&65535)|0;b[591674]=at&65535;Q=V+(P&65535)|0;b[591675]=Q&65535;V=O+(M&65535)|0;O=V&65535;ax=g<<16>>16;ay=(ab(au,ax)|0)>>>15;au=(ab(av,ax)|0)>>>15;av=(ab(aw,ax)|0)>>>15;b[591692]=at-ay&65535;b[591693]=Q-au&65535;b[591694]=V-av&65535;b[591696]=0;av=(ax&16384|0)==0;do{if(g<<16>>16<0){if(av){az=g;aA=0;break}else{aB=16384;aC=0}while(1){V=aC+1&65535;au=aB>>>1<<16>>16;if((au&ax|0)==0|(au|0)==0){aD=V;x=5887;break}else{aB=au;aC=V}}}else{if(av){aE=16384;aF=0}else{az=g;aA=0;break}while(1){V=aF+1&65535;au=aE>>>1<<16>>16;if((au&ax|0)!=0|(au|0)==0){aD=V;x=5887;break}else{aE=au;aF=V}}}}while(0);do{if((x|0)==5887){if(aD<<16>>16<=0){az=g;aA=aD;break}az=ab(g<<1,b[165240+((aD<<16>>16)+33<<1)>>1]|0)|0;aA=aD}}while(0);b[591695]=az;b[591696]=-aA&65535;b[591697]=g;av=O<<16>>16;M=(av&16384|0)==0;do{if(O<<16>>16<0){if(M){aG=O;aH=0;break}else{aI=16384;aJ=0}while(1){P=aJ+1&65535;W=aI>>>1<<16>>16;if((W&av|0)==0|(W|0)==0){aK=P;x=5894;break}else{aI=W;aJ=P}}}else{if(M){aL=16384;aM=0}else{aG=O;aH=0;break}while(1){P=aM+1&65535;W=aL>>>1<<16>>16;if((W&av|0)!=0|(W|0)==0){aK=P;x=5894;break}else{aL=W;aM=P}}}}while(0);do{if((x|0)==5894){if(aK<<16>>16<=0){aG=O;aH=aK;break}aG=ab(O<<1,b[165240+((aK<<16>>16)+33<<1)>>1]|0)|0;aH=aK}}while(0);O=-aH&65535;b[591677]=aG;b[591678]=O;av=b[164696+(-(O<<16>>16)<<1)>>1]|0;do{if(A){M=-av&65535;g=(M<<16>>16)+1|0;if((U<<16>>16|0)>=(g|0)){aN=U;aO=M;break}aN=g&65535;aO=M}else{aN=av<<16>>16<U<<16>>16?av:U;aO=av}}while(0);av=xX(aN)|0;b[591683]=av;do{if(aN<<16>>16<0){if(aN<<16>>16==-32768){b[591684]=-32768;aP=-32768;x=5907;break}else{aQ=-aN&65535;x=5904;break}}else{aQ=aN;x=5904}}while(0);do{if((x|0)==5904){A=aQ<<16>>16;M=A>>8;g=b[164184+(M+64<<1)>>1]|0;P=g-((ab(b[164184+(M<<1)>>1]|0,b[164728+((A&255)<<1)>>1]|0)|0)>>15)|0;A=(P|0)<-32768?-32767:P&65535;b[591684]=A;if(A<<16>>16==0){b[591685]=32767;aR=47;aS=32767;aT=0;break}else{if(A<<16>>16<0){aP=A;x=5907;break}else{aU=A;aV=1;aW=A;x=5908;break}}}}while(0);if((x|0)==5907){aU=aP<<16>>16==-32768?32767:-aP&65535;aV=-1;aW=aP;x=5908}if((x|0)==5908){if(aU<<16>>16<16384){A=0;P=aU;while(1){M=P<<1;g=A-1&65535;if(M<<16>>16<16384){A=g;P=M}else{aX=g;aY=M;break}}}else{aX=0;aY=aU}P=aY<<16>>16;do{if(aY<<16>>16==16384){if(aV<<16>>16==1){b[591685]=32767;aZ=aX;a_=32767;break}else{b[591685]=-16384;aZ=aX-1&65535;a_=-16384;break}}else{A=b[165240+((P-16384>>7)+101<<1)>>1]|0;M=((ab((ab(A,P)|0)>>15,-A|0)|0)>>>15)+A<<17>>16;A=(ab(((ab((ab(M,P)|0)>>15,-M|0)|0)>>>15)+M<<17>>16,aV<<16>>16)|0)&65535;b[591685]=A;aZ=aX;a_=A}}while(0);aR=1-aZ&65535;aS=a_;aT=aW}b[591686]=aR;P=(ab(aS<<16>>16,aG<<16>>16)|0)>>>15;A=P&65535;M=A<<16>>16;g=(M&16384|0)==0;do{if(A<<16>>16<0){if(g){a$=A;a0=0;break}else{a1=16384;a2=0}while(1){W=a2+1&65535;w=a1>>>1<<16>>16;if((w&M|0)==0|(w|0)==0){a3=W;x=5921;break}else{a1=w;a2=W}}}else{if(g){a4=16384;a5=0}else{a$=A;a0=0;break}while(1){W=a5+1&65535;w=a4>>>1<<16>>16;if((w&M|0)!=0|(w|0)==0){a3=W;x=5921;break}else{a4=w;a5=W}}}}while(0);do{if((x|0)==5921){if(a3<<16>>16<=0){a$=A;a0=a3;break}a$=ab(b[165240+((a3<<16>>16)+33<<1)>>1]|0,P<<1&65535)|0;a0=a3}}while(0);P=(O-a0&65535)+aR&65535;A=P<<16>>16;do{if(P<<16>>16>0){if(a$<<16>>16>0){a6=32767;break}if(a$<<16>>16<0){a6=-32767}else{x=5928}}else{if(P<<16>>16>=0){x=5928;break}a6=(ab(e[165240+(A+49<<1)>>1]|0,a$<<16>>16)|0)>>>15&65535}}while(0);if((x|0)==5928){a6=a$}A=(ab(a6<<16>>16,av<<16>>16)|0)>>>15<<16>>16;P=((ab(A,N)|0)>>>15)+at|0;O=P&65535;b[591674]=O;M=Q-((ab(A,Y)|0)>>>15)|0;A=M&65535;b[591675]=A;b[591753]=O;b[591754]=A;b[591751]=0;if(aN<<16>>16!=U<<16>>16|aO<<16>>16==U<<16>>16){g=(U<<16>>16==-32768?-32767:U)-aO&65535;W=~(((g<<16>>16>>15^16383)+g&65535)<<2)<<16>>16;g=-((ab((ab(((ab((W*5292|0)>>>15<<16>>16,W)|0)>>>15<<16)+1686634496>>16,W)|0)>>15,ax)|0)>>>15)|0;w=g&65535;b[591751]=w;v=(ab(W,W)|0)>>>15<<16>>16;W=aT<<16>>16;B=((ab(W,(ab(((v*2598|0)>>>15<<16)+662306816>>16,v)|0)>>15)|0)>>>15)+W&65535;b[591684]=B;a7=B;a8=(w&65535)>>>8&255;a9=g&255}else{a7=aT;a8=0;a9=0}g=(ab(a7<<16>>16,ax)|0)>>>15;w=g&65535;b[591676]=w;if(av<<16>>16==0){ba=47;bb=32767}else{if(av<<16>>16<0){bc=av<<16>>16==-32768?32767:-av&65535;bd=-1}else{bc=av;bd=1}if(bc<<16>>16<16384){B=0;W=bc;while(1){v=W<<1;V=B-1&65535;if(v<<16>>16<16384){B=V;W=v}else{be=V;bf=v;break}}}else{be=0;bf=bc}W=bf<<16>>16;if(bf<<16>>16==16384){B=bd<<16>>16==1;bg=be+((B^1)<<31>>31)&65535;bh=B?32767:-16384}else{B=b[165240+((W-16384>>7)+101<<1)>>1]|0;av=((ab((ab(B,W)|0)>>15,-B|0)|0)>>>15)+B<<17>>16;bg=be;bh=(ab(((ab((ab(av,W)|0)>>15,-av|0)|0)>>>15)+av<<17>>16,bd<<16>>16)|0)&65535}ba=1-bg&65535;bb=bh}av=w<<16>>16;W=(av&16384|0)==0;do{if(w<<16>>16<0){if(W){bi=w;bj=0;break}else{bk=16384;bl=0}while(1){B=bl+1&65535;ax=bk>>>1<<16>>16;if((ax&av|0)==0|(ax|0)==0){bm=B;x=5945;break}else{bk=ax;bl=B}}}else{if(W){bn=16384;bo=0}else{bi=w;bj=0;break}while(1){B=bo+1&65535;ax=bn>>>1<<16>>16;if((ax&av|0)!=0|(ax|0)==0){bm=B;x=5945;break}else{bn=ax;bo=B}}}}while(0);do{if((x|0)==5945){if(bm<<16>>16<=0){bi=w;bj=bm;break}bi=ab(b[165240+((bm<<16>>16)+33<<1)>>1]|0,g<<1&65535)|0;bj=bm}}while(0);g=ba-bj&65535;w=(ab(bi<<16>>16,bb<<16>>16)|0)>>>15;av=w&65535;W=av<<16>>16;B=(W&16384|0)==0;do{if(av<<16>>16<0){if(B){bp=av;bq=0;x=5954;break}else{br=16384;bs=0}while(1){ax=bs+1&65535;U=br>>>1<<16>>16;if((U&W|0)==0|(U|0)==0){bt=ax;x=5952;break}else{br=U;bs=ax}}}else{if(B){bu=16384;bv=0}else{bw=g;bx=av;break}while(1){ax=bv+1&65535;U=bu>>>1<<16>>16;if((U&W|0)!=0|(U|0)==0){bt=ax;x=5952;break}else{bu=U;bv=ax}}}}while(0);do{if((x|0)==5952){if(bt<<16>>16<=0){bp=av;bq=bt;x=5954;break}bp=ab(b[165240+((bt<<16>>16)+33<<1)>>1]|0,w<<1&65535)|0;bq=bt;x=5954}}while(0);do{if((x|0)==5954){w=g-bq&65535;if(bp<<16>>16!=-32768){bw=w;bx=bp;break}bw=w+1&65535;bx=-16384}}while(0);g=-bx&65535;w=bw<<16>>16;do{if(bw<<16>>16>0){if(g<<16>>16>0){by=32767;break}if(g<<16>>16<0){by=-32767}else{x=5961}}else{if(bw<<16>>16>=0){x=5961;break}by=(ab(e[165240+(w+49<<1)>>1]|0,g<<16>>16)|0)>>>15&65535}}while(0);if((x|0)==5961){by=g}b[591752]=by;if(a7<<16>>16==0){b[591687]=32767;bz=47}else{if(a7<<16>>16<0){bA=a7<<16>>16==-32768?32767:-a7&65535;bB=-1}else{bA=a7;bB=1}if(bA<<16>>16<16384){w=0;av=bA;while(1){W=av<<1;B=w-1&65535;if(W<<16>>16<16384){w=B;av=W}else{bC=B;bD=W;break}}}else{bC=0;bD=bA}av=bD<<16>>16;do{if(bD<<16>>16==16384){if(bB<<16>>16==1){b[591687]=32767;bE=bC;break}else{b[591687]=-16384;bE=bC-1&65535;break}}else{w=b[165240+((av-16384>>7)+101<<1)>>1]|0;g=((ab((ab(w,av)|0)>>15,-w|0)|0)>>>15)+w<<17>>16;b[591687]=(ab(((ab((ab(g,av)|0)>>15,-g|0)|0)>>>15)+g<<17>>16,bB<<16>>16)|0)&65535;bE=bC}}while(0);bz=1-bE&65535}b[591688]=bz;c[295579]=8;a[1182836]=a9;a[1182837]=a8;a[1182838]=by&255;a[1182839]=(by&65535)>>>8&255;a[1182840]=P&255;a[1182841]=(O&65535)>>>8&255;a[1182842]=M&255;a[1182843]=(A&65535)>>>8&255;i=h;return};case 8:{av=d[1182325]<<8|d[1182324];b[591862]=av;g=d[1182327]<<8|d[1182326];b[591863]=g;w=d[1182329]<<8|d[1182328];b[591864]=w;W=av<<16>>16;av=ab(W,W)|0;W=g<<16>>16;g=(ab(W,W)|0)+av|0;av=w<<16>>16;w=g+(ab(av,av)|0)|0;av=w<<1;b[591865]=av&65535;g=w>>>15;b[591866]=g&65535;c[295579]=4;a[1182836]=av&255;a[1182837]=w>>>7&255;a[1182838]=g&255;a[1182839]=w>>>23&255;i=h;return};case 24:{w=d[1182325]<<8|d[1182324];b[591867]=w;g=d[1182327]<<8|d[1182326];b[591868]=g;av=d[1182329]<<8|d[1182328];b[591869]=av;W=d[1182331]<<8|d[1182330];b[591870]=W;B=w<<16>>16;w=ab(B,B)|0;B=g<<16>>16;g=(ab(B,B)|0)+w|0;w=av<<16>>16;av=g+(ab(w,w)|0)|0;w=W<<16>>16;W=av-(ab(w,w)|0)|0;w=W>>>15;b[591871]=w&65535;c[295579]=2;a[1182836]=w&255;a[1182837]=W>>>23&255;i=h;return};case 56:{W=d[1182325]<<8|d[1182324];b[591872]=W;w=d[1182327]<<8|d[1182326];b[591873]=w;av=d[1182329]<<8|d[1182328];b[591874]=av;g=d[1182331]<<8|d[1182330];b[591875]=g;B=W<<16>>16;W=ab(B,B)|0;B=w<<16>>16;w=(ab(B,B)|0)+W|0;W=av<<16>>16;av=w+(ab(W,W)|0)|0;W=g<<16>>16;g=((av-(ab(W,W)|0)|0)>>>15&65535)+1&65535;b[591876]=g;c[295579]=2;a[1182836]=g&255;a[1182837]=(g&65535)>>>8&255;i=h;return};case 40:{g=d[1182325]<<8|d[1182324];b[591839]=g;W=d[1182327]<<8|d[1182326];b[591840]=W;av=d[1182329]<<8|d[1182328];b[591841]=av;w=g<<16>>16;g=ab(w,w)|0;w=W<<16>>16;W=(ab(w,w)|0)+g|0;g=av<<16>>16;av=W+(ab(g,g)|0)|0;if((av|0)==0){bF=0}else{xV(av,r,s);av=b[s>>1]|0;g=b[r>>1]|0;if((av&1)==0){bG=g}else{W=g<<16>>16>>>1&65535;b[r>>1]=W;bG=W}W=bG<<16>>16;g=W>>>9<<16>>16;w=b[165240+(g+213<<1)>>1]|0;B=((ab((b[165240+(g+214<<1)>>1]|0)-w|0,W&511)|0)>>>9)+w&65535;b[591842]=B;bF=B<<16>>16>>(av<<16>>16>>1)&65535}b[591842]=bF;c[295579]=2;a[1182836]=bF&255;a[1182837]=(bF&65535)>>>8&255;i=h;return};case 58:case 42:case 26:case 10:{b[591755]=d[1182325]<<8|d[1182324];xg();c[295579]=8;av=b[591756]|0;a[1182836]=av&255;a[1182837]=(av&65535)>>>8&255;av=b[591757]|0;a[1182838]=av&255;a[1182839]=(av&65535)>>>8&255;av=b[591758]|0;a[1182840]=av&255;a[1182841]=(av&65535)>>>8&255;av=b[591759]|0;a[1182842]=av&255;a[1182843]=(av&65535)>>>8&255;c[295578]=0;i=h;return};case 22:case 38:case 54:case 6:{av=d[1182325]<<8|d[1182324];b[591760]=av;B=d[1182327]<<8|d[1182326];b[591761]=B;w=d[1182329]<<8|d[1182328];b[591762]=w;b[j>>1]=0;b[k>>1]=0;b[l>>1]=0;b[m>>1]=0;xV((av<<16>>16)-(b[591692]|0)|0,o,m);xV((B<<16>>16)-(b[591693]|0)|0,p,j);xV((w<<16>>16)-(b[591694]|0)|0,q,l);w=(b[o>>1]|0)>>>1;B=(b[m>>1]|0)-1&65535;b[m>>1]=B;av=(b[p>>1]|0)>>>1;W=(b[j>>1]|0)-1&65535;b[j>>1]=W;g=(b[q>>1]|0)>>>1;ax=(b[l>>1]|0)-1&65535;b[l>>1]=ax;U=W<<16>>16<ax<<16>>16?W:ax;Y=U<<16>>16<B<<16>>16?U:B;U=(ab(e[165240+(((B-Y&65535)<<16>>16)+49<<1)>>1]|0,w<<16>>16)|0)>>>15&65535;b[o>>1]=U;w=(ab(e[165240+(((W-Y&65535)<<16>>16)+49<<1)>>1]|0,av<<16>>16)|0)>>>15&65535;b[p>>1]=w;av=(ab(e[165240+(((ax-Y&65535)<<16>>16)+49<<1)>>1]|0,g<<16>>16)|0)>>>15&65535;b[q>>1]=av;g=U<<16>>16;U=(ab(g,b[591689]|0)|0)>>>15;ax=w<<16>>16;w=(ab(ax,b[591690]|0)|0)>>>15;W=av<<16>>16;av=-(U+w+((ab(W,b[591691]|0)|0)>>>15)|0)<<16>>16;w=16-Y&65535;Y=w<<16>>16;if(w<<16>>16>-1){bH=av<<Y}else{bH=av>>-Y}xV((e[591697]|0)+((bH|0)==-1?0:bH>>1)|0,n,k);Y=15-(b[k>>1]|0)&65535;b[k>>1]=Y;av=b[n>>1]|0;if(av<<16>>16==0){bI=47;bJ=32767}else{if(av<<16>>16<0){bK=av<<16>>16==-32768?32767:-av&65535;bL=-1}else{bK=av;bL=1}if(bK<<16>>16<16384){av=0;U=bK;while(1){B=U<<1;Q=av-1&65535;if(B<<16>>16<16384){av=Q;U=B}else{bM=Q;bN=B;break}}}else{bM=0;bN=bK}U=bN<<16>>16;if(bN<<16>>16==16384){av=bL<<16>>16==1;bO=bM+((av^1)<<31>>31)&65535;bP=av?32767:-16384}else{av=b[165240+((U-16384>>7)+101<<1)>>1]|0;A=((ab((ab(av,U)|0)>>15,-av|0)|0)>>>15)+av<<17>>16;bO=bM;bP=(ab(((ab((ab(A,U)|0)>>15,-A|0)|0)>>>15)+A<<17>>16,bL<<16>>16)|0)&65535}bI=1-bO&65535;bJ=bP}b[m>>1]=bI;A=(ab(b[591695]|0,bJ<<16>>16)|0)>>>15;U=A&65535;av=b[591680]|0;M=(ab((av*32767|0)>>15,g)|0)>>>15;O=b[591679]|0;P=U<<16>>16;B=(ab(((ab((O*32767|0)>>15,ax)|0)>>>15)+M<<16>>16,P)|0)>>>15;M=B&65535;Q=M<<16>>16;at=(Q&16384|0)==0;do{if(M<<16>>16<0){if(at){bQ=M;bR=0;break}else{bS=16384;bT=0}while(1){N=bT+1&65535;v=bS>>>1<<16>>16;if((v&Q|0)==0|(v|0)==0){bU=N;x=5993;break}else{bS=v;bT=N}}}else{if(at){bV=16384;bW=0}else{bQ=M;bR=0;break}while(1){N=bW+1&65535;v=bV>>>1<<16>>16;if((v&Q|0)!=0|(v|0)==0){bU=N;x=5993;break}else{bV=v;bW=N}}}}while(0);do{if((x|0)==5993){if(bU<<16>>16<=0){bQ=M;bR=bU;break}bQ=ab(b[165240+((bU<<16>>16)+33<<1)>>1]|0,B<<1&65535)|0;bR=bU}}while(0);B=b[591696]|0;M=w-Y&65535;Q=B+(M-bR&65535)&65535;at=Q<<16>>16;do{if(Q<<16>>16>0){if(bQ<<16>>16>0){bX=32767;break}if(bQ<<16>>16<0){bX=-32767}else{x=6e3}}else{if(Q<<16>>16>=0){x=6e3;break}bX=(ab(e[165240+(at+49<<1)>>1]|0,bQ<<16>>16)|0)>>>15&65535}}while(0);if((x|0)==6e3){bX=bQ}b[591763]=bX;at=b[591682]|0;Q=(ab((ab(at,-O|0)|0)>>15,g)|0)>>>15;w=(ab((ab(at,av)|0)>>15,ax)|0)>>>15;at=(ab(w+Q+((ab(((b[591681]|0)*-32767|0)>>15,W)|0)>>>15)<<16>>16,P)|0)>>>15;Q=at&65535;w=Q<<16>>16;N=(w&16384|0)==0;do{if(Q<<16>>16<0){if(N){bY=Q;bZ=0;break}else{b_=16384;b$=0}while(1){v=b$+1&65535;V=b_>>>1<<16>>16;if((V&w|0)==0|(V|0)==0){b0=v;x=6006;break}else{b_=V;b$=v}}}else{if(N){b1=16384;b2=0}else{bY=Q;bZ=0;break}while(1){v=b2+1&65535;V=b1>>>1<<16>>16;if((V&w|0)!=0|(V|0)==0){b0=v;x=6006;break}else{b1=V;b2=v}}}}while(0);do{if((x|0)==6006){if(b0<<16>>16<=0){bY=Q;bZ=b0;break}bY=ab(b[165240+((b0<<16>>16)+33<<1)>>1]|0,at<<1&65535)|0;bZ=b0}}while(0);at=(B+M&65535)-bZ&65535;Q=at<<16>>16;do{if(at<<16>>16>0){if(bY<<16>>16>0){b3=32767;break}if(bY<<16>>16<0){b3=-32767}else{x=6013}}else{if(at<<16>>16>=0){x=6013;break}b3=(ab(e[165240+(Q+49<<1)>>1]|0,bY<<16>>16)|0)>>>15&65535}}while(0);if((x|0)==6013){b3=bY}b[591764]=b3;Q=(P&16384|0)==0;do{if(U<<16>>16<0){if(Q){b4=U;b5=0;break}else{b6=16384;b7=0}while(1){at=b7+1&65535;M=b6>>>1<<16>>16;if((M&P|0)==0|(M|0)==0){b8=at;x=6019;break}else{b6=M;b7=at}}}else{if(Q){b9=16384;ca=0}else{b4=U;b5=0;break}while(1){at=ca+1&65535;M=b9>>>1<<16>>16;if((M&P|0)!=0|(M|0)==0){b8=at;x=6019;break}else{b9=M;ca=at}}}}while(0);do{if((x|0)==6019){if(b8<<16>>16<=0){b4=U;b5=b8;break}b4=ab(b[165240+((b8<<16>>16)+33<<1)>>1]|0,A<<1&65535)|0;b5=b8}}while(0);A=bI-b5&65535;b[m>>1]=A;U=((-7-Y&65535)+B&65535)+A&65535;A=U<<16>>16;do{if(U<<16>>16>0){if(b4<<16>>16>0){cb=32767;break}if(b4<<16>>16<0){cb=-32767}else{x=6026}}else{if(U<<16>>16>=0){x=6026;break}cb=(ab(e[165240+(A+49<<1)>>1]|0,b4<<16>>16)|0)>>>15&65535}}while(0);if((x|0)==6026){cb=b4}b[591765]=cb;c[295579]=6;a[1182836]=bX&255;a[1182837]=(bX&65535)>>>8&255;a[1182838]=b3&255;a[1182839]=(b3&65535)>>>8&255;a[1182840]=cb&255;a[1182841]=(cb&65535)>>>8&255;i=h;return};case 30:case 46:case 62:case 14:{A=d[1182324]|0;b[591823]=d[1182325]<<8|A;U=d[1182326]|0;B=d[1182327]<<8|U;b[591824]=B;Y=(ab(B<<16>>16,b[591681]|0)|0)>>>15;B=Y+(e[591676]|0)&65535;if(B<<16>>16==0){cc=47;cd=32767}else{if(B<<16>>16<0){ce=B<<16>>16==-32768?32767:-B&65535;cf=-1}else{ce=B;cf=1}if(ce<<16>>16<16384){B=8;Y=ce;while(1){P=Y<<1;Q=B-1&65535;if(P<<16>>16<16384){B=Q;Y=P}else{cg=Q;ch=P;break}}}else{cg=8;ch=ce}Y=ch<<16>>16;if(ch<<16>>16==16384){B=cf<<16>>16==1;ci=cg+((B^1)<<31>>31)&65535;cj=B?32767:-16384}else{B=b[165240+((Y-16384>>7)+101<<1)>>1]|0;P=((ab((ab(B,Y)|0)>>15,-B|0)|0)>>>15)+B<<17>>16;ci=cg;cj=(ab(((ab((ab(P,Y)|0)>>15,-P|0)|0)>>>15)+P<<17>>16,cf<<16>>16)|0)&65535}cc=1-ci&65535;cd=cj}P=(b[591678]|0)+cc&65535;Y=(ab(b[591677]|0,cd<<16>>16)|0)>>>15;B=Y&65535;Q=(b[591686]|0)+P&65535;at=A<<8;M=B<<16>>16;w=(M&16384|0)==0;do{if(B<<16>>16<0){if(w){ck=B;cl=0;break}else{cm=16384;cn=0}while(1){N=cn+1&65535;W=cm>>>1<<16>>16;if((W&M|0)==0|(W|0)==0){co=N;x=6042;break}else{cm=W;cn=N}}}else{if(w){cp=16384;cq=0}else{ck=B;cl=0;break}while(1){N=cq+1&65535;W=cp>>>1<<16>>16;if((W&M|0)!=0|(W|0)==0){co=N;x=6042;break}else{cp=W;cq=N}}}}while(0);do{if((x|0)==6042){if(co<<16>>16<=0){ck=B;cl=co;break}ck=ab(b[165240+((co<<16>>16)+33<<1)>>1]|0,Y<<1&65535)|0;cl=co}}while(0);Y=P-cl&65535;B=Y<<16>>16;do{if(Y<<16>>16>0){if(ck<<16>>16>0){cr=32767;break}if(ck<<16>>16<0){cr=-32767}else{x=6049}}else{if(Y<<16>>16>=0){x=6049;break}cr=(ab(e[165240+(B+49<<1)>>1]|0,ck<<16>>16)|0)>>>15&65535}}while(0);if((x|0)==6049){cr=ck}B=(ab(cr<<16>>16,at<<16>>16)|0)>>>15;Y=e[591674]|0;P=B<<16>>16;B=b[591680]|0;w=((ab(P,B)|0)>>>15)+Y|0;b[591825]=w&65535;Y=e[591675]|0;A=b[591679]|0;N=Y-((ab(P,A)|0)>>>15)|0;b[591826]=N&65535;P=U<<8;Y=(ab(b[591685]|0,M)|0)>>>15;W=Y&65535;ax=W<<16>>16;av=(ax&16384|0)==0;do{if(W<<16>>16<0){if(av){cs=W;ct=0;break}else{cu=16384;cv=0}while(1){g=cv+1&65535;O=cu>>>1<<16>>16;if((O&ax|0)==0|(O|0)==0){cw=g;x=6055;break}else{cu=O;cv=g}}}else{if(av){cx=16384;cy=0}else{cs=W;ct=0;break}while(1){g=cy+1&65535;O=cx>>>1<<16>>16;if((O&ax|0)!=0|(O|0)==0){cw=g;x=6055;break}else{cx=O;cy=g}}}}while(0);do{if((x|0)==6055){if(cw<<16>>16<=0){cs=W;ct=cw;break}cs=ab(b[165240+((cw<<16>>16)+33<<1)>>1]|0,Y<<1&65535)|0;ct=cw}}while(0);Y=Q-ct&65535;W=Y<<16>>16;do{if(Y<<16>>16>0){if(cs<<16>>16>0){cz=32767;break}if(cs<<16>>16<0){cz=-32767}else{x=6062}}else{if(Y<<16>>16>=0){x=6062;break}cz=(ab(e[165240+(W+49<<1)>>1]|0,cs<<16>>16)|0)>>>15&65535}}while(0);if((x|0)==6062){cz=cs}W=(ab(cz<<16>>16,P<<16>>16)|0)>>>15<<16>>16;Y=((ab(W,-A|0)|0)>>>15)+w|0;Q=Y&65535;b[591825]=Q;ax=((ab(W,B)|0)>>>15)+N|0;W=ax&65535;b[591826]=W;c[295579]=4;a[1182836]=Y&255;a[1182837]=(Q&65535)>>>8&255;a[1182838]=ax&255;a[1182839]=(W&65535)>>>8&255;i=h;return};case 5:case 53:case 49:case 1:{W=d[1182325]<<8|d[1182324];b[591766]=W;ax=d[1182327]<<8|d[1182326];b[591767]=ax;Q=d[1182329]<<8|d[1182328];b[591769]=Q;Y=d[1182331]<<8|d[1182330];b[591768]=Y;av=xX(ax)|0;do{if(ax<<16>>16<0){if(ax<<16>>16==-32768){cA=-32768;break}cB=-ax&65535;x=6067}else{cB=ax;x=6067}}while(0);if((x|0)==6067){ax=cB<<16>>16;N=ax>>8;B=b[164184+(N+64<<1)>>1]|0;w=B-((ab(b[164184+(N<<1)>>1]|0,b[164728+((ax&255)<<1)>>1]|0)|0)>>15)|0;cA=(w|0)<-32768?-32767:w<<16>>16}w=xX(Q)|0;do{if(Q<<16>>16<0){if(Q<<16>>16==-32768){cC=-32768;break}cD=-Q&65535;x=6071}else{cD=Q;x=6071}}while(0);if((x|0)==6071){Q=cD<<16>>16;ax=Q>>8;N=b[164184+(ax+64<<1)>>1]|0;B=N-((ab(b[164184+(ax<<1)>>1]|0,b[164728+((Q&255)<<1)>>1]|0)|0)>>15)|0;cC=(B|0)<-32768?-32767:B<<16>>16}B=xX(Y)|0;do{if(Y<<16>>16<0){if(Y<<16>>16==-32768){cE=-32768;break}cF=-Y&65535;x=6075}else{cF=Y;x=6075}}while(0);if((x|0)==6075){Y=cF<<16>>16;Q=Y>>8;ax=b[164184+(Q+64<<1)>>1]|0;N=ax-((ab(b[164184+(Q<<1)>>1]|0,b[164728+((Y&255)<<1)>>1]|0)|0)>>15)|0;cE=(N|0)<-32768?-32767:N<<16>>16}N=W<<16>>16>>>1&65535;b[591766]=N;Y=N<<16>>16;N=(ab(cA,Y)|0)>>15;b[591698]=(ab(cC,N)|0)>>>15&65535;Q=(ab(av<<16>>16,Y)|0)>>15;b[591699]=-((ab(cC,Q)|0)>>>15)&65535;ax=w<<16>>16;b[591700]=(ab(ax,Y)|0)>>>15&65535;A=ab(cE,Q)|0;P=B<<16>>16;M=ab(P,N)|0;b[591701]=(A>>>15)+((ab(M>>15,ax)|0)>>>15)&65535;U=ab(cE,N)|0;N=ab(P,Q)|0;b[591702]=(U>>>15)-((ab(N>>15,ax)|0)>>>15)&65535;b[591703]=-((ab((ab(P,Y)|0)>>15,cC)|0)>>>15)&65535;b[591704]=(N>>>15)-((ab(U>>15,ax)|0)>>>15)&65535;b[591705]=((ab(A>>15,ax)|0)>>>15)+(M>>>15)&65535;b[591706]=(ab((ab(cE,Y)|0)>>15,cC)|0)>>>15&65535;i=h;return};case 21:case 17:{Y=d[1182325]<<8|d[1182324];b[591770]=Y;M=d[1182327]<<8|d[1182326];b[591771]=M;ax=d[1182329]<<8|d[1182328];b[591773]=ax;A=d[1182331]|0;U=(A<<8|A)&65535;b[591772]=U;A=xX(M)|0;do{if(M<<16>>16<0){if(M<<16>>16==-32768){cG=-32768;break}cH=-M&65535;x=6080}else{cH=M;x=6080}}while(0);if((x|0)==6080){M=cH<<16>>16;B=M>>8;w=b[164184+(B+64<<1)>>1]|0;av=w-((ab(b[164184+(B<<1)>>1]|0,b[164728+((M&255)<<1)>>1]|0)|0)>>15)|0;cG=(av|0)<-32768?-32767:av<<16>>16}av=xX(ax)|0;do{if(ax<<16>>16<0){if(ax<<16>>16==-32768){cI=-32768;break}cJ=-ax&65535;x=6084}else{cJ=ax;x=6084}}while(0);if((x|0)==6084){ax=cJ<<16>>16;M=ax>>8;B=b[164184+(M+64<<1)>>1]|0;w=B-((ab(b[164184+(M<<1)>>1]|0,b[164728+((ax&255)<<1)>>1]|0)|0)>>15)|0;cI=(w|0)<-32768?-32767:w<<16>>16}w=xX(U)|0;do{if(U<<16>>16<0){if(U<<16>>16==-32768){cK=-32768;break}cL=-U&65535;x=6088}else{cL=U;x=6088}}while(0);if((x|0)==6088){U=cL<<16>>16;ax=U>>8;M=b[164184+(ax+64<<1)>>1]|0;B=M-((ab(b[164184+(ax<<1)>>1]|0,b[164728+((U&255)<<1)>>1]|0)|0)>>15)|0;cK=(B|0)<-32768?-32767:B<<16>>16}B=Y<<16>>16>>>1&65535;b[591770]=B;U=B<<16>>16;B=(ab(cG,U)|0)>>15;b[591707]=(ab(cI,B)|0)>>>15&65535;ax=(ab(U,A<<16>>16)|0)>>15;b[591708]=-((ab(cI,ax)|0)>>>15)&65535;M=av<<16>>16;b[591709]=(ab(M,U)|0)>>>15&65535;W=ab(cK,ax)|0;N=w<<16>>16;P=ab(N,B)|0;b[591710]=(W>>>15)+((ab(P>>15,M)|0)>>>15)&65535;Q=ab(cK,B)|0;B=ab(N,ax)|0;b[591711]=(Q>>>15)-((ab(B>>15,M)|0)>>>15)&65535;b[591712]=-((ab((ab(N,U)|0)>>15,cI)|0)>>>15)&65535;b[591713]=(B>>>15)-((ab(Q>>15,M)|0)>>>15)&65535;b[591714]=((ab(W>>15,M)|0)>>>15)+(P>>>15)&65535;b[591715]=(ab((ab(cK,U)|0)>>15,cI)|0)>>>15&65535;i=h;return};case 37:case 33:{U=d[1182325]<<8|d[1182324];b[591774]=U;P=d[1182327]<<8|d[1182326];b[591775]=P;M=d[1182329]<<8|d[1182328];b[591777]=M;W=d[1182331]<<8|d[1182330];b[591776]=W;Q=xX(P)|0;do{if(P<<16>>16<0){if(P<<16>>16==-32768){cM=-32768;break}cN=-P&65535;x=6093}else{cN=P;x=6093}}while(0);if((x|0)==6093){P=cN<<16>>16;w=P>>8;av=b[164184+(w+64<<1)>>1]|0;A=av-((ab(b[164184+(w<<1)>>1]|0,b[164728+((P&255)<<1)>>1]|0)|0)>>15)|0;cM=(A|0)<-32768?-32767:A<<16>>16}A=xX(M)|0;do{if(M<<16>>16<0){if(M<<16>>16==-32768){cO=-32768;break}cP=-M&65535;x=6097}else{cP=M;x=6097}}while(0);if((x|0)==6097){M=cP<<16>>16;P=M>>8;w=b[164184+(P+64<<1)>>1]|0;av=w-((ab(b[164184+(P<<1)>>1]|0,b[164728+((M&255)<<1)>>1]|0)|0)>>15)|0;cO=(av|0)<-32768?-32767:av<<16>>16}av=xX(W)|0;do{if(W<<16>>16<0){if(W<<16>>16==-32768){cQ=-32768;break}cR=-W&65535;x=6101}else{cR=W;x=6101}}while(0);if((x|0)==6101){W=cR<<16>>16;M=W>>8;P=b[164184+(M+64<<1)>>1]|0;w=P-((ab(b[164184+(M<<1)>>1]|0,b[164728+((W&255)<<1)>>1]|0)|0)>>15)|0;cQ=(w|0)<-32768?-32767:w<<16>>16}w=U<<16>>16>>>1&65535;b[591774]=w;W=w<<16>>16;w=(ab(cM,W)|0)>>15;b[591716]=(ab(cO,w)|0)>>>15&65535;M=(ab(Q<<16>>16,W)|0)>>15;b[591717]=-((ab(cO,M)|0)>>>15)&65535;P=A<<16>>16;b[591718]=(ab(P,W)|0)>>>15&65535;Y=ab(cQ,M)|0;B=av<<16>>16;N=ab(B,w)|0;b[591719]=(Y>>>15)+((ab(N>>15,P)|0)>>>15)&65535;ax=ab(cQ,w)|0;w=ab(B,M)|0;b[591720]=(ax>>>15)-((ab(w>>15,P)|0)>>>15)&65535;b[591721]=-((ab((ab(B,W)|0)>>15,cO)|0)>>>15)&65535;b[591722]=(w>>>15)-((ab(ax>>15,P)|0)>>>15)&65535;b[591723]=((ab(Y>>15,P)|0)>>>15)+(N>>>15)&65535;b[591724]=(ab((ab(cQ,W)|0)>>15,cO)|0)>>>15&65535;i=h;return};case 9:case 57:case 61:case 13:{W=d[1182325]<<8|d[1182324];b[591778]=W;N=d[1182327]<<8|d[1182326];b[591779]=N;P=d[1182329]<<8|d[1182328];b[591780]=P;Y=W<<16>>16;W=(ab(b[591698]|0,Y)|0)>>>15;ax=N<<16>>16;N=((ab(b[591699]|0,ax)|0)>>>15)+W|0;W=P<<16>>16;P=N+((ab(b[591700]|0,W)|0)>>>15)|0;N=P&65535;b[591781]=N;w=(ab(b[591701]|0,Y)|0)>>>15;B=((ab(b[591702]|0,ax)|0)>>>15)+w|0;w=B+((ab(b[591703]|0,W)|0)>>>15)|0;B=w&65535;b[591782]=B;M=(ab(b[591704]|0,Y)|0)>>>15;Y=((ab(b[591705]|0,ax)|0)>>>15)+M|0;M=Y+((ab(b[591706]|0,W)|0)>>>15)|0;W=M&65535;b[591783]=W;c[295579]=6;a[1182836]=P&255;a[1182837]=(N&65535)>>>8&255;a[1182838]=w&255;a[1182839]=(B&65535)>>>8&255;a[1182840]=M&255;a[1182841]=(W&65535)>>>8&255;i=h;return};case 25:case 29:{W=d[1182325]<<8|d[1182324];b[591784]=W;M=d[1182327]<<8|d[1182326];b[591785]=M;B=d[1182329]<<8|d[1182328];b[591786]=B;w=W<<16>>16;W=(ab(b[591707]|0,w)|0)>>>15;N=M<<16>>16;M=((ab(b[591708]|0,N)|0)>>>15)+W|0;W=B<<16>>16;B=M+((ab(b[591709]|0,W)|0)>>>15)|0;M=B&65535;b[591787]=M;P=(ab(b[591710]|0,w)|0)>>>15;Y=((ab(b[591711]|0,N)|0)>>>15)+P|0;P=Y+((ab(b[591712]|0,W)|0)>>>15)|0;Y=P&65535;b[591788]=Y;ax=(ab(b[591713]|0,w)|0)>>>15;w=((ab(b[591714]|0,N)|0)>>>15)+ax|0;ax=w+((ab(b[591715]|0,W)|0)>>>15)|0;W=ax&65535;b[591789]=W;c[295579]=6;a[1182836]=B&255;a[1182837]=(M&65535)>>>8&255;a[1182838]=P&255;a[1182839]=(Y&65535)>>>8&255;a[1182840]=ax&255;a[1182841]=(W&65535)>>>8&255;i=h;return};case 41:case 45:{W=d[1182325]<<8|d[1182324];b[591790]=W;ax=d[1182327]<<8|d[1182326];b[591791]=ax;Y=d[1182329]<<8|d[1182328];b[591792]=Y;P=W<<16>>16;W=(ab(b[591716]|0,P)|0)>>>15;M=ax<<16>>16;ax=((ab(b[591717]|0,M)|0)>>>15)+W|0;W=Y<<16>>16;Y=ax+((ab(b[591718]|0,W)|0)>>>15)|0;ax=Y&65535;b[591793]=ax;B=(ab(b[591719]|0,P)|0)>>>15;w=((ab(b[591720]|0,M)|0)>>>15)+B|0;B=w+((ab(b[591721]|0,W)|0)>>>15)|0;w=B&65535;b[591794]=w;N=(ab(b[591722]|0,P)|0)>>>15;P=((ab(b[591723]|0,M)|0)>>>15)+N|0;N=P+((ab(b[591724]|0,W)|0)>>>15)|0;W=N&65535;b[591795]=W;c[295579]=6;a[1182836]=Y&255;a[1182837]=(ax&65535)>>>8&255;a[1182838]=B&255;a[1182839]=(w&65535)>>>8&255;a[1182840]=N&255;a[1182841]=(W&65535)>>>8&255;i=h;return};case 51:case 3:{W=d[1182325]<<8|d[1182324];b[591796]=W;N=d[1182327]<<8|d[1182326];b[591797]=N;w=d[1182329]<<8|d[1182328];b[591798]=w;B=W<<16>>16;W=(ab(b[591698]|0,B)|0)>>>15;ax=N<<16>>16;N=((ab(b[591701]|0,ax)|0)>>>15)+W|0;W=w<<16>>16;w=N+((ab(b[591704]|0,W)|0)>>>15)|0;N=w&65535;b[591799]=N;Y=(ab(b[591699]|0,B)|0)>>>15;P=((ab(b[591702]|0,ax)|0)>>>15)+Y|0;Y=P+((ab(b[591705]|0,W)|0)>>>15)|0;P=Y&65535;b[591800]=P;M=(ab(b[591700]|0,B)|0)>>>15;B=((ab(b[591703]|0,ax)|0)>>>15)+M|0;M=B+((ab(b[591706]|0,W)|0)>>>15)|0;W=M&65535;b[591801]=W;c[295579]=6;a[1182836]=w&255;a[1182837]=(N&65535)>>>8&255;a[1182838]=Y&255;a[1182839]=(P&65535)>>>8&255;a[1182840]=M&255;a[1182841]=(W&65535)>>>8&255;i=h;return};case 19:{W=d[1182325]<<8|d[1182324];b[591802]=W;M=d[1182327]<<8|d[1182326];b[591803]=M;P=d[1182329]<<8|d[1182328];b[591804]=P;Y=W<<16>>16;W=(ab(b[591707]|0,Y)|0)>>>15;N=M<<16>>16;M=((ab(b[591710]|0,N)|0)>>>15)+W|0;W=P<<16>>16;P=M+((ab(b[591713]|0,W)|0)>>>15)|0;M=P&65535;b[591805]=M;w=(ab(b[591708]|0,Y)|0)>>>15;B=((ab(b[591711]|0,N)|0)>>>15)+w|0;w=B+((ab(b[591714]|0,W)|0)>>>15)|0;B=w&65535;b[591806]=B;ax=(ab(b[591709]|0,Y)|0)>>>15;Y=((ab(b[591712]|0,N)|0)>>>15)+ax|0;ax=Y+((ab(b[591715]|0,W)|0)>>>15)|0;W=ax&65535;b[591807]=W;c[295579]=6;a[1182836]=P&255;a[1182837]=(M&65535)>>>8&255;a[1182838]=w&255;a[1182839]=(B&65535)>>>8&255;a[1182840]=ax&255;a[1182841]=(W&65535)>>>8&255;i=h;return};case 35:{W=d[1182325]<<8|d[1182324];b[591808]=W;ax=d[1182327]<<8|d[1182326];b[591809]=ax;B=d[1182329]<<8|d[1182328];b[591810]=B;w=W<<16>>16;W=(ab(b[591716]|0,w)|0)>>>15;M=ax<<16>>16;ax=((ab(b[591719]|0,M)|0)>>>15)+W|0;W=B<<16>>16;B=ax+((ab(b[591722]|0,W)|0)>>>15)|0;ax=B&65535;b[591811]=ax;P=(ab(b[591717]|0,w)|0)>>>15;Y=((ab(b[591720]|0,M)|0)>>>15)+P|0;P=Y+((ab(b[591723]|0,W)|0)>>>15)|0;Y=P&65535;b[591812]=Y;N=(ab(b[591718]|0,w)|0)>>>15;w=((ab(b[591721]|0,M)|0)>>>15)+N|0;N=w+((ab(b[591724]|0,W)|0)>>>15)|0;W=N&65535;b[591813]=W;c[295579]=6;a[1182836]=B&255;a[1182837]=(ax&65535)>>>8&255;a[1182838]=P&255;a[1182839]=(Y&65535)>>>8&255;a[1182840]=N&255;a[1182841]=(W&65535)>>>8&255;i=h;return};case 59:case 11:{W=d[1182325]<<8|d[1182324];b[591827]=W;N=d[1182327]<<8|d[1182326];b[591828]=N;Y=d[1182329]<<8|d[1182328];b[591829]=Y;P=ab(b[591698]|0,W<<16>>16)|0;W=(ab(b[591699]|0,N<<16>>16)|0)+P|0;P=W+(ab(b[591700]|0,Y<<16>>16)|0)|0;Y=P>>>15;b[591830]=Y&65535;c[295579]=2;a[1182836]=Y&255;a[1182837]=P>>>23&255;i=h;return};case 27:{P=d[1182325]<<8|d[1182324];b[591831]=P;Y=d[1182327]<<8|d[1182326];b[591832]=Y;W=d[1182329]<<8|d[1182328];b[591833]=W;N=ab(b[591707]|0,P<<16>>16)|0;P=(ab(b[591708]|0,Y<<16>>16)|0)+N|0;N=P+(ab(b[591709]|0,W<<16>>16)|0)|0;W=N>>>15;b[591834]=W&65535;c[295579]=2;a[1182836]=W&255;a[1182837]=N>>>23&255;i=h;return};case 43:{N=d[1182325]<<8|d[1182324];b[591835]=N;W=d[1182327]<<8|d[1182326];b[591836]=W;P=d[1182329]<<8|d[1182328];b[591837]=P;Y=ab(b[591716]|0,N<<16>>16)|0;N=(ab(b[591717]|0,W<<16>>16)|0)+Y|0;Y=N+(ab(b[591718]|0,P<<16>>16)|0)|0;P=Y>>>15;b[591838]=P&65535;c[295579]=2;a[1182836]=P&255;a[1182837]=Y>>>23&255;i=h;return};case 52:case 20:{b[591814]=d[1182325]<<8|d[1182324];Y=d[1182327]<<8|d[1182326];b[591815]=Y;P=d[1182329]<<8|d[1182328];b[591816]=P;N=d[1182331]<<8|d[1182330];b[591817]=N;W=d[1182333]<<8|d[1182332];b[591818]=W;b[591819]=d[1182335]<<8|d[1182334];do{if(Y<<16>>16<0){if(Y<<16>>16==-32768){cS=-32768;x=6117;break}cT=-Y&65535;x=6115}else{cT=Y;x=6115}}while(0);do{if((x|0)==6115){Y=cT<<16>>16;av=Y>>8;A=b[164184+(av+64<<1)>>1]|0;Q=A-((ab(b[164184+(av<<1)>>1]|0,b[164728+((Y&255)<<1)>>1]|0)|0)>>15)|0;Y=(Q|0)<-32768?-32767:Q&65535;if(Y<<16>>16==0){cU=47;cV=32767;break}if(Y<<16>>16<0){cS=Y;x=6117}else{cW=Y;cX=1;x=6118}}}while(0);if((x|0)==6117){cW=cS<<16>>16==-32768?32767:-cS&65535;cX=-1;x=6118}if((x|0)==6118){if(cW<<16>>16<16384){Y=0;Q=cW;while(1){av=Q<<1;A=Y-1&65535;if(av<<16>>16<16384){Y=A;Q=av}else{cY=A;cZ=av;break}}}else{cY=0;cZ=cW}Q=cZ<<16>>16;if(cZ<<16>>16==16384){Y=cX<<16>>16==1;c_=cY+((Y^1)<<31>>31)&65535;c$=Y?32767:-16384}else{Y=b[165240+((Q-16384>>7)+101<<1)>>1]|0;av=((ab((ab(Y,Q)|0)>>15,-Y|0)|0)>>>15)+Y<<17>>16;c_=cY;c$=(ab(((ab((ab(av,Q)|0)>>15,-av|0)|0)>>>15)+av<<17>>16,cX<<16>>16)|0)&65535}cU=1-c_&65535;cV=c$}av=N<<16>>16;do{if(P<<16>>16<0){if(P<<16>>16==-32768){c0=-32768;break}c1=-P&65535;x=6127}else{c1=P;x=6127}}while(0);if((x|0)==6127){N=c1<<16>>16;Q=N>>8;Y=b[164184+(Q+64<<1)>>1]|0;A=Y-((ab(b[164184+(Q<<1)>>1]|0,b[164728+((N&255)<<1)>>1]|0)|0)>>15)|0;c0=(A|0)<-32768?-32767:A<<16>>16}A=ab(c0,av)|0;xV(A-(ab((xX(P)|0)<<16>>16,W<<16>>16)|0)|0,t,u);A=cU-(b[u>>1]|0)&65535;b[u>>1]=A;N=cV<<16>>16;Q=(ab(b[t>>1]|0,N)|0)>>>15;Y=Q&65535;U=Y<<16>>16;ax=(U&16384|0)==0;do{if(Y<<16>>16<0){if(ax){c2=Y;c3=0;break}else{c4=16384;c5=0}while(1){B=c5+1&65535;w=c4>>>1<<16>>16;if((w&U|0)==0|(w|0)==0){c6=B;x=6133;break}else{c4=w;c5=B}}}else{if(ax){c7=16384;c8=0}else{c2=Y;c3=0;break}while(1){B=c8+1&65535;w=c7>>>1<<16>>16;if((w&U|0)!=0|(w|0)==0){c6=B;x=6133;break}else{c7=w;c8=B}}}}while(0);do{if((x|0)==6133){if(c6<<16>>16<=0){c2=Y;c3=c6;break}c2=ab(b[165240+((c6<<16>>16)+33<<1)>>1]|0,Q<<1&65535)|0;c3=c6}}while(0);b[t>>1]=c2;Q=A-c3&65535;b[u>>1]=Q;Y=b[591814]|0;U=Q<<16>>16;do{if(Q<<16>>16>0){if(c2<<16>>16>0){c9=32767;break}if(c2<<16>>16<0){c9=-32767}else{x=6140}}else{if(Q<<16>>16>=0){x=6140;break}c9=(ab(e[165240+(U+49<<1)>>1]|0,c2<<16>>16)|0)>>>15&65535}}while(0);if((x|0)==6140){c9=c2}b[591820]=c9+Y&65535;U=e[591815]|0;Q=b[591817]|0;A=b[591816]|0;ax=(xX(A)|0)<<16>>16;W=((ab(ax,Q)|0)>>>15)+U|0;U=b[591818]|0;P=A<<16>>16<0;do{if(P){if(A<<16>>16==-32768){b[591821]=W+((U*-32768|0)>>>15)&65535;da=-32768;break}else{db=-A&65535;x=6145;break}}else{db=A;x=6145}}while(0);do{if((x|0)==6145){Y=db<<16>>16;av=Y>>8;B=b[164184+(av+64<<1)>>1]|0;w=B-((ab(b[164184+(av<<1)>>1]|0,b[164728+((Y&255)<<1)>>1]|0)|0)>>15)|0;b[591821]=((ab((w|0)<-32768?-32767:w<<16>>16,U)|0)>>>15)+W&65535;if(P){if(A<<16>>16==-32768){da=-32768;break}dc=-A&65535}else{dc=A}w=dc<<16>>16;Y=w>>8;av=b[164184+(Y+64<<1)>>1]|0;B=av-((ab(b[164184+(Y<<1)>>1]|0,b[164728+((w&255)<<1)>>1]|0)|0)>>15)|0;da=(B|0)<-32768?-32767:B<<16>>16}}while(0);A=ab(da,Q)|0;xV(A+(ab(U,ax)|0)|0,t,u);A=cU-(b[u>>1]|0)&65535;b[u>>1]=A;P=xX(b[591815]|0)|0;W=P<<16>>16;B=(W&16384|0)==0;do{if(P<<16>>16<0){if(B){dd=P;de=0;break}else{df=16384;dg=0}while(1){w=dg+1&65535;Y=df>>>1<<16>>16;if((Y&W|0)==0|(Y|0)==0){dh=w;x=6154;break}else{df=Y;dg=w}}}else{if(B){di=16384;dj=0}else{dd=P;de=0;break}while(1){w=dj+1&65535;Y=di>>>1<<16>>16;if((Y&W|0)!=0|(Y|0)==0){dh=w;x=6154;break}else{di=Y;dj=w}}}}while(0);do{if((x|0)==6154){if(dh<<16>>16<=0){dd=P;de=dh;break}dd=ab(P<<1,b[165240+((dh<<16>>16)+33<<1)>>1]|0)|0;de=dh}}while(0);P=A-de&65535;b[u>>1]=P;W=(ab(dd<<16>>16,N)|0)>>>15;B=-((ab(W<<16>>16,b[t>>1]|0)|0)>>>15)&65535;W=B<<16>>16;ax=(W&16384|0)==0;do{if(B<<16>>16<0){if(ax){dk=B;dl=0;break}else{dm=16384;dn=0}while(1){U=dn+1&65535;Q=dm>>>1<<16>>16;if((Q&W|0)==0|(Q|0)==0){dp=U;x=6161;break}else{dm=Q;dn=U}}}else{if(ax){dq=16384;dr=0}else{dk=B;dl=0;break}while(1){U=dr+1&65535;Q=dq>>>1<<16>>16;if((Q&W|0)!=0|(Q|0)==0){dp=U;x=6161;break}else{dq=Q;dr=U}}}}while(0);do{if((x|0)==6161){if(dp<<16>>16<=0){dk=B;dl=dp;break}dk=ab(B<<1,b[165240+((dp<<16>>16)+33<<1)>>1]|0)|0;dl=dp}}while(0);b[t>>1]=dk;B=P-dl&65535;b[u>>1]=B;W=b[591816]|0;ax=B<<16>>16;do{if(B<<16>>16>0){if(dk<<16>>16>0){ds=32767;break}if(dk<<16>>16<0){ds=-32767}else{x=6168}}else{if(B<<16>>16>=0){x=6168;break}ds=(ab(e[165240+(ax+49<<1)>>1]|0,dk<<16>>16)|0)>>>15&65535}}while(0);if((x|0)==6168){ds=dk}ax=(ds+W&65535)+(b[591819]|0)&65535;b[591822]=ax;c[295579]=6;B=b[591820]|0;a[1182836]=B&255;a[1182837]=(B&65535)>>>8&255;B=b[591821]|0;a[1182838]=B&255;a[1182839]=(B&65535)>>>8&255;a[1182840]=ax&255;a[1182841]=(ax&65535)>>>8&255;i=h;return};case 39:case 47:{b[591860]=d[1182325]<<8|d[1182324];b[591861]=256;c[295579]=2;a[1182836]=0;a[1182837]=1;i=h;return};case 7:case 15:{b[591858]=d[1182325]<<8|d[1182324];b[591859]=0;c[295579]=2;a[1182836]=0;a[1182837]=0;i=h;return};default:{i=h;return}}}}while(0);a[1182304]=1;a[1182305]=0;i=h;return}function xf(){var a=0;a=b[565464]|0;if((a&65535)>=64){return}switch(a&65535|0){case 7:{c[201850]=1066;return};case 3:{c[201850]=1070;break};case 31:{c[201850]=3730;break};case 6:{c[201850]=1068;break};case 15:{c[201850]=2744;break};case 16:{c[201850]=676;break};case 12:{c[201850]=1324;break};case 24:{c[201850]=3494;break};case 2:{c[201850]=2850;break};case 56:{c[201850]=2152;break};case 28:{c[201850]=3418;break};case 62:{c[201850]=2708;break};case 30:{c[201850]=618;break};default:{return}}b[565465]=128;b[565475]=0;return}function xg(){var a=0,c=0,d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;a=b[591755]|0;c=(ab(b[591681]|0,a<<16>>16)|0)>>>15;d=c+(e[591676]|0)&65535;if(d<<16>>16==0){f=47;g=32767}else{if(d<<16>>16<0){h=d<<16>>16==-32768?32767:-d&65535;i=-1}else{h=d;i=1}if(h<<16>>16<16384){d=7;c=h;while(1){j=c<<1;k=d-1&65535;if(j<<16>>16<16384){d=k;c=j}else{l=k;m=j;break}}}else{l=7;m=h}h=m<<16>>16;if(m<<16>>16==16384){m=i<<16>>16==1;n=l+((m^1)<<31>>31)&65535;o=m?32767:-16384}else{m=b[165240+((h-16384>>7)+101<<1)>>1]|0;c=((ab((ab(m,h)|0)>>15,-m|0)|0)>>>15)+m<<17>>16;n=l;o=(ab(((ab((ab(c,h)|0)>>15,-c|0)|0)>>>15)+c<<17>>16,i<<16>>16)|0)&65535}f=1-n&65535;g=o}o=(b[591678]|0)+f&65535;f=(ab(b[591677]|0,g<<16>>16)|0)>>>15;g=f&65535;n=(b[591688]|0)+o&65535;i=g<<16>>16;c=(i&16384|0)==0;do{if(g<<16>>16<0){if(c){p=g;q=0;break}else{r=16384;s=0}while(1){h=s+1&65535;l=r>>>1<<16>>16;if((l&i|0)==0|(l|0)==0){t=h;u=6244;break}else{r=l;s=h}}}else{if(c){v=16384;w=0}else{p=g;q=0;break}while(1){h=w+1&65535;l=v>>>1<<16>>16;if((l&i|0)!=0|(l|0)==0){t=h;u=6244;break}else{v=l;w=h}}}}while(0);do{if((u|0)==6244){if(t<<16>>16<=0){p=g;q=t;break}p=ab(b[165240+((t<<16>>16)+33<<1)>>1]|0,f<<1&65535)|0;q=t}}while(0);t=o-q&65535;q=t<<16>>16;do{if(t<<16>>16>0){if(p<<16>>16>0){x=32767;break}if(p<<16>>16<0){x=-32767}else{u=6251}}else{if(t<<16>>16>=0){u=6251;break}x=(ab(e[165240+(q+49<<1)>>1]|0,p<<16>>16)|0)>>>15&65535}}while(0);if((u|0)==6251){x=p}p=x<<16>>16;x=b[591680]|0;b[591756]=(ab(x,p)|0)>>>15&65535;q=b[591679]|0;b[591758]=(ab(q,p)|0)>>>15&65535;p=(ab(b[591687]|0,i)|0)>>>15;i=p&65535;t=i<<16>>16;o=(t&16384|0)==0;do{if(i<<16>>16<0){if(o){y=i;z=0;break}else{A=16384;B=0}while(1){f=B+1&65535;g=A>>>1<<16>>16;if((g&t|0)==0|(g|0)==0){C=f;u=6257;break}else{A=g;B=f}}}else{if(o){D=16384;E=0}else{y=i;z=0;break}while(1){f=E+1&65535;g=D>>>1<<16>>16;if((g&t|0)!=0|(g|0)==0){C=f;u=6257;break}else{D=g;E=f}}}}while(0);do{if((u|0)==6257){if(C<<16>>16<=0){y=i;z=C;break}y=ab(b[165240+((C<<16>>16)+33<<1)>>1]|0,p<<1&65535)|0;z=C}}while(0);C=n-z&65535;z=C<<16>>16;do{if(C<<16>>16>0){if(y<<16>>16>0){F=32767;break}if(y<<16>>16<0){F=-32767}else{u=6264}}else{if(C<<16>>16>=0){u=6264;break}F=(ab(e[165240+(z+49<<1)>>1]|0,y<<16>>16)|0)>>>15&65535}}while(0);if((u|0)==6264){F=y}y=F<<16>>16;b[591757]=(ab(y,-q|0)|0)>>>15&65535;b[591759]=(ab(y,x)|0)>>>15&65535;b[591755]=a+1&65535;return}function xh(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;g=i;i=i+512|0;h=g|0;do{if((f&-4096)<<16>>16!=24576){if(f<<16>>16<0&(f&65535)<49152){break}i=g;return}}while(0);L8820:do{if((a[1181224]|0)==0){a[1181244+(c[295308]|0)|0]=e;f=(c[295308]|0)+1|0;c[295308]=f;if((c[295307]|0)==(f|0)){j=a[1181225]|0;break}else{i=g;return}}else{a[1181225]=e;c[295308]=0;a[1181224]=0;switch(e&255|0){case 6:{c[295307]=1;i=g;return};case 9:{c[295307]=4;i=g;return};case 1:{c[295307]=32;i=g;return};case 5:{c[295307]=1;i=g;return};case 13:{c[295307]=2;i=g;return};case 3:{c[295307]=1;i=g;return};default:{c[295307]=0;j=e;break L8820}}}}while(0);a[1181224]=1;c[295310]=0;switch(j&255|0){case 9:{c[295309]=4;j=d[1181245]<<8|d[1181244];b[591142]=j;f=d[1181247]<<8|d[1181246];b[591143]=f;k=ab(f&65535,j&65535)|0;a[1181756]=k&255;a[1181757]=k>>>8&255;a[1181758]=k>>>16&255;a[1181759]=k>>>24&255;i=g;return};case 13:{if((a[1182288]|0)==0){k=d[1181244]|0;c[295574]=k;c[295573]=d[1181245]|0;c[295308]=0;c[295307]=(k+1|0)>>>1;a[1182288]=1;if(e<<24>>24==0){i=g;return}a[1181224]=0;i=g;return}a[1182288]=0;k=c[295573]|0;c[295309]=k;j=c[295574]|0;if((j|0)>(k|0)){f=k<<1;l=(j<<17|0)/(f|1|0)|0;m=f}else{l=65536;m=k<<1}if((m|0)>0){f=0;j=0;while(1){n=a[1181244+(f>>>17)|0]|0;if((f&65536|0)==0){a[h+j|0]=(n&255)>>>4}else{a[h+j|0]=n&15}n=j+1|0;if((n|0)<(m|0)){f=f+l|0;j=n}else{break}}}if((k|0)>0){o=0}else{i=g;return}do{k=o<<1;a[1181756+o|0]=a[h+k|0]<<4|a[h+(k|1)|0];o=o+1|0;}while((o|0)<(c[295573]|0));i=g;return};case 6:{if((a[1182277]|0)==0){o=d[1181244]|0;c[295570]=o;c[295308]=0;c[295307]=o;a[1182277]=1;if(e<<24>>24==0){i=g;return}a[1181224]=0;i=g;return}else{a[1182277]=0;o=c[295570]|0;c[295309]=o;if((o|0)>0){p=0;q=o}else{i=g;return}do{q=q-1|0;o=a[1181244+p|0]|0;a[1181756+q|0]=o<<4|(o&255)>>>4;p=p+1|0;}while((p|0)<(c[295570]|0));i=g;return}break};case 1:{c[295309]=32;p=0;q=1181244;o=1181756;h=1181772;while(1){k=a[q]|0;j=a[q+1|0]|0;l=a[q+2|0]|0;f=a[q+3|0]|0;m=k<<3;n=j<<1;r=(l&255)>>>1;s=(f&255)>>>3;a[o]=m&-128|k<<6&64|n&32|j<<4&16|r&8|l<<2&4|f&1|s&2;a[o+1|0]=k<<2&-128|k<<5&64|j&32|j<<3&16|(l&255)>>>2&8|l<<1&4|(f&255)>>>4&2|(f&255)>>>1&1;a[h]=k<<1&-128|k<<4&64|(j&255)>>>1&32|j<<2&16|l&4|(l&255)>>>3&8|(f&255)>>>5&2|(f&255)>>>2&1;a[h+1|0]=m&64|k&-128|(j&255)>>>2&32|n&16|(l&255)>>>4&8|r&4|(f&255)>>>6&2|s&1;s=p+1|0;if((s|0)<8){p=s;q=q+4|0;o=o+2|0;h=h+2|0}else{break}}i=g;return};case 3:{a[1182276]=a[1181244]|0;i=g;return};case 5:{if((a[1182268]|0)==0){h=d[1181244]|0;c[295568]=h;c[295308]=0;c[295307]=h<<1;a[1182268]=1;if(e<<24>>24==0){i=g;return}a[1181224]=0;i=g;return}a[1182268]=0;e=c[295568]|0;c[295309]=e;if((e|0)<=0){i=g;return}h=a[1182276]&15;o=0;q=1181244;p=1181244+e|0;e=1181756;while(1){s=a[q]|0;f=a[p]|0;r=f&255;a[e]=((r>>>4|0)==(h|0)?s:f)&-16|((r&15|0)==(h|0)?s:f)&15;f=o+1|0;if((f|0)<(c[295568]|0)){o=f;q=q+1|0;p=p+1|0;e=e+1|0}else{break}}i=g;return};default:{i=g;return}}}function xi(b){b=b|0;var d=0,e=0,f=0,g=0;do{if((b&-4096)<<16>>16!=24576){if(b<<16>>16<0&(b&65535)<49152){break}else{d=-128}return d|0}}while(0);b=c[295309]|0;if((b|0)==0){d=-1;return d|0}e=c[295310]|0;f=a[1181756+e|0]|0;g=e+1|0;c[295310]=g;if((b|0)!=(g|0)){d=f;return d|0}c[295309]=0;d=f;return d|0}function xj(d){d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if((d&65535)>>>0>=(c[295940]|0)>>>0){e=-128;return e|0}d=c[295579]|0;if((d|0)==0){e=-1;return e|0}f=c[295580]|0;g=a[1182836+f|0]|0;h=f+1|0;c[295580]=h;f=d-1|0;c[295579]=f;do{if((f|0)==0){d=a[1182306]|0;if((d<<24>>24|0)==26|(d<<24>>24|0)==10){xg();c[295579]=8;c[295580]=0;i=b[591756]|0;a[1182836]=i&255;a[1182837]=(i&65535)>>>8&255;i=b[591757]|0;a[1182838]=i&255;a[1182839]=(i&65535)>>>8&255;i=b[591758]|0;a[1182840]=i&255;a[1182841]=(i&65535)>>>8&255;i=b[591759]|0;a[1182842]=i&255;a[1182843]=(i&65535)>>>8&255;j=a[1182306]|0;k=0}else{j=d;k=h}if(j<<24>>24!=31){l=g;break}d=b[165240+(k>>>1<<1)>>1]|0;if((k&1|0)==0){l=(d&65535)>>>8&255;break}else{l=d&255;break}}else{l=g}}while(0);a[1182304]=1;e=l;return e|0}function xk(a,d){a=a|0;d=d|0;var e=0;if((d&65535)>>>0>=(c[295940]|0)>>>0){return}d=b[565465]|0;if((d&4)!=0){b[565464]=b[565464]&-256|a&255;fz[c[201850]&8191]();return}e=d^16;b[565465]=e;d=b[565464]|0;if((e&16)==0){b[565464]=d&255|(a&255)<<8;fz[c[201850]&8191]();return}else{b[565464]=d&-256|a&255;return}}function xl(a){a=a|0;var d=0,e=0;d=b[565465]|0;if((a&65535)>>>0>=(c[295940]|0)>>>0){e=d&255;return e|0}if((d&4)!=0){a=b[565464]&255;fz[c[201850]&8191]();e=a;return e|0}a=d^16;b[565465]=a;d=b[565464]|0;if((a&16)==0){fz[c[201850]&8191]();e=(d&65535)>>>8&255;return e|0}else{e=d&255;return e|0}return 0}function xm(d,e){d=d|0;e=e|0;if((e&65535)>>>0>=(c[295940]|0)>>>0){return}a[1130668|0]=d;b[565335]=e;xn();return}function xn(){var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0;f=i;i=i+40|0;g=f|0;h=f+8|0;j=f+16|0;k=f+24|0;l=f+32|0;m=c[282410]|0;if(m>>>0<(c[282409]|0)>>>0){c[282410]=m+1;i=f;return}m=a[1129624]|0;L8970:do{if(m<<24>>24==0){a[1129644+(c[282408]|0)|0]=a[1130668]|0;c[282408]=(c[282408]|0)+1;n=a[1129624]|0;o=6408}else{p=d[1130668]|0;if((a[1129625]|0)==0){b[564813]=p;a[1129625]=1;n=m;o=6408;break}q=b[564813]|p<<8;b[564813]=q;c[282408]=0;a[1129624]=0;a[1129625]=0;c[282409]=0;c[282410]=0;a[1130672]=0;switch(q&65535|0){case 3:{c[282407]=0;r=q;break L8970;break};case 9:{c[282407]=14;i=f;return};case 6:{c[282407]=0;r=q;break L8970;break};case 7:{c[282407]=34;i=f;return};case 8:{c[282407]=90;i=f;return};case 5:{c[282407]=0;r=q;break L8970;break};case 1:{c[282407]=44;i=f;return};case 14:{c[282407]=0;r=q;break L8970;break};case 15:{c[282407]=46;i=f;return};case 13:{c[282407]=42;i=f;return};case 10:{c[282407]=6;i=f;return};case 17:{c[282407]=8;i=f;return};case 11:{c[282407]=6;i=f;return};case 16:{c[282407]=36;i=f;return};case 0:{c[282407]=4;i=f;return};default:{a[1129624]=1;i=f;return}}}}while(0);do{if((o|0)==6408){if(n<<24>>24!=0){i=f;return}if((c[282407]|0)==(c[282408]|0)){r=b[564813]|0;break}else{i=f;return}}}while(0);a[1129624]=1;c[282410]=0;c[282408]=0;switch(r&65535|0){case 1:{a[1129624]=0;r=a[1130672]|0;if((r|0)==3){n=d[1129645]<<8|d[1129644];b[565351]=n;m=d[1129647]<<8|d[1129646];b[565350]=m;q=d[1129649]<<8|d[1129648];c[282408]=6;b[565365]=q;c[282676]=0;s=c[282671]|0;t=0;u=b[565338]|0;v=b[565366]|0;w=c[282672]|0;x=b[565354]|0;y=b[565400]|0;z=b[565392]|0;A=m;B=n;C=q}else if((r|0)==2){q=d[1129645]<<8|d[1129644];b[565338]=q;n=d[1129647]<<8|d[1129646];m=d[1129649]<<8|d[1129648];b[565367]=m;p=(ab(n<<16>>16,q<<16>>16)|0)>>>15;b[565355]=p+(e[565355]|0)&65535;b[565361]=p+(e[565361]|0)&65535;b[565366]=m+n&65535;c[282407]=2;c[282408]=0;a[1130672]=1;i=f;return}else if((r|0)==1){r=d[1129645]<<8|d[1129644];c[282408]=2;b[565338]=r;if(r<<16>>16==-32768){a[1129624]=1;i=f;return}c[282407]=6;c[282408]=0;if(r<<16>>16==-32767){a[1130672]=2;i=f;return}else{a[1130672]=3;i=f;return}}else{r=d[1129645]<<8|d[1129644]|d[1129646]<<16|d[1129647]<<24;c[282672]=r;n=d[1129649]<<8|d[1129648];b[565400]=n;b[565396]=d[1129651]<<8|d[1129650];b[565406]=d[1129653]<<8|d[1129652];b[565373]=d[1129655]<<8|d[1129654];m=d[1129657]<<8|d[1129656]|d[1129658]<<16|d[1129659]<<24;c[282671]=m;b[565404]=d[1129661]<<8|d[1129660];b[565388]=d[1129663]<<8|d[1129662];p=d[1129665]<<8|d[1129664];b[565354]=p;c[282674]=d[1129667]<<8|d[1129666]|d[1129668]<<16|d[1129669]<<24;c[282673]=d[1129671]<<8|d[1129670]|d[1129672]<<16|d[1129673]<<24;q=d[1129675]<<8|d[1129674];b[565338]=q;D=d[1129679]<<8|d[1129678]|d[1129680]<<16|d[1129681]<<24;c[282676]=D;E=d[1129683]<<8|d[1129682];b[565351]=E;F=d[1129685]<<8|d[1129684];b[565350]=F;G=d[1129687]<<8|d[1129686];c[282408]=44;b[565365]=G;b[565355]=(D+m|0)>>>16&65535;b[565356]=r>>>16&65535;b[565361]=m>>>16&65535;b[565362]=p;b[565366]=0;b[565367]=0;b[565392]=n;s=m;t=D;u=q;v=0;w=r;x=p;y=n;z=n;A=F;B=E;C=G}G=s+t|0;E=u<<16>>16;u=((ab(G>>16,E)|0)>>>15)+((ab(E,v<<16>>16)|0)>>>15)|0;F=u&65535;b[565357]=F;n=ab(E,w>>16)|0;p=n>>>15;r=p&65535;b[565358]=r;b[565363]=F;q=((ab(E,x<<16>>16)|0)>>>15)+(y&65535)-p&65535;b[565364]=q;c[282410]=0;a[1130156]=G>>>16&255;a[1130157]=G>>>24&255;a[1130158]=u&255;a[1130159]=(F&65535)>>>8&255;a[1130160]=w>>>16&255;a[1130161]=w>>>24&255;a[1130162]=p&255;a[1130163]=n>>>23&255;c[282409]=8;n=z-r&65535;b[565340]=n;if(r<<16>>16<z<<16>>16){b[565392]=r;H=n}else{b[565340]=0;H=0}n=b[565396]|0;do{if(r<<16>>16<n<<16>>16){b[565340]=0;z=b[565356]|0;if(z<<16>>16<n<<16>>16){I=0;break}p=z-n&65535;b[565340]=p;I=p}else{I=H}}while(0);a[1130164]=I&255;a[1130165]=(I&65535)>>>8&255;c[282409]=10;do{if(I<<16>>16==0){J=F;K=r;L=F;M=q;N=A;O=B;P=t;Q=s;R=w;S=v}else{H=b[565361]|0;n=I<<16>>16<0?0:I;p=b[161960+((n<<16>>16>63?63:n<<16>>16)<<1)>>1]<<1;n=ab(p,(F<<16>>16)-(H<<16>>16)|0)|0;z=b[565362]|0;u=ab((q<<16>>16)-(z<<16>>16)|0,p)|0;p=b[565404]|0;G=b[565373]|0;y=b[565406]|0;b[565337]=0;if(I<<16>>16<=0){J=F;K=r;L=F;M=q;N=A;O=B;P=t;Q=s;R=w;S=v;break}E=(p+H&65535)<<16;H=((((C-x&65535)+z&65535)-G&65535)+y&65535)<<16;y=b[565388]&255;G=10;while(1){a[1130156+G|0]=y;a[(c[282409]|0)+1130157|0]=(e[565388]|0)>>>8&255;z=(c[282409]|0)+2|0;c[282409]=z;p=H+32768|0;a[1130156+z|0]=p>>>16&255;a[(c[282409]|0)+1130157|0]=p>>>24&255;p=(c[282409]|0)+2|0;c[282409]=p;z=E+32768|0;a[1130156+p|0]=z>>>16&255;a[(c[282409]|0)+1130157|0]=z>>>24&255;z=(c[282409]|0)+2|0;c[282409]=z;p=(b[565388]|0)-4&65535;b[565388]=p;D=(b[565337]|0)+1&65535;b[565337]=D;if(D<<16>>16<(b[565340]|0)){E=E+n|0;H=H+u|0;y=p&255;G=z}else{break}}J=b[565357]|0;K=b[565358]|0;L=b[565363]|0;M=b[565364]|0;N=b[565350]|0;O=b[565351]|0;P=c[282676]|0;Q=c[282671]|0;R=c[282672]|0;S=b[565366]|0}}while(0);b[565355]=J;b[565356]=K;b[565361]=L;b[565362]=M;M=(c[282673]|0)+(N<<16>>16<<8)|0;c[282673]=M;N=(c[282674]|0)+(O<<16>>16<<8)|0;c[282674]=N;c[282671]=P+Q+M;c[282672]=N+R;b[565366]=(b[565367]|0)+S&65535;c[282407]=2;c[282408]=0;a[1130672]=1;i=f;return};case 7:{a[1129624]=0;S=a[1130672]|0;if((S|0)==1){R=d[1129645]<<8|d[1129644];c[282408]=2;b[565338]=R;if(R<<16>>16==-32768){a[1129624]=1;i=f;return}else{c[282407]=10;c[282408]=0;a[1130672]=2;i=f;return}}else if((S|0)==2){S=d[1129645]<<8|d[1129644];b[565358]=S;R=b[565338]|0;N=R<<16>>16;M=(ab((d[1129647]<<8|d[1129646])<<16>>16,N)|0)>>>15&65535;b[565360]=M;Q=d[1129649]<<8|d[1129648];b[565357]=Q;P=(ab((d[1129651]<<8|d[1129650])<<16>>16,N)|0)>>>15&65535;b[565359]=P;N=d[1129653]<<8|d[1129652];c[282408]=10;b[565365]=N;T=P;U=Q;V=M;W=S;X=b[565354]|0;Y=R;Z=b[565400]|0;_=b[565356]|0;$=b[565392]|0;aa=N}else{N=d[1129645]<<8|d[1129644]|d[1129646]<<16|d[1129647]<<24;c[282672]=N;R=d[1129649]<<8|d[1129648];b[565400]=R;b[565396]=d[1129651]<<8|d[1129650];b[565406]=d[1129653]<<8|d[1129652];b[565373]=d[1129655]<<8|d[1129654];S=d[1129657]<<8|d[1129656]|d[1129658]<<16|d[1129659]<<24;c[282671]=S;b[565404]=d[1129661]<<8|d[1129660];b[565388]=d[1129663]<<8|d[1129662];M=d[1129665]<<8|d[1129664];b[565354]=M;Q=d[1129667]<<8|d[1129666];b[565338]=Q;P=d[1129669]<<8|d[1129668];b[565358]=P;O=Q<<16>>16;L=(ab((d[1129671]<<8|d[1129670])<<16>>16,O)|0)>>>15&65535;b[565360]=L;K=d[1129673]<<8|d[1129672];b[565357]=K;J=(ab((d[1129675]<<8|d[1129674])<<16>>16,O)|0)>>>15&65535;b[565359]=J;O=d[1129677]<<8|d[1129676];c[282408]=34;b[565365]=O;x=S>>>16&65535;b[565355]=x;S=N>>>16&65535;b[565356]=S;b[565361]=x;b[565362]=M;b[565392]=R;T=J;U=K;V=L;W=P;X=M;Y=Q;Z=R;_=S;$=R;aa=O}O=T+U&65535;b[565357]=O;U=V+W&65535;b[565358]=U;b[565363]=O;W=((ab(X<<16>>16,Y<<16>>16)|0)>>>15)+(Z&65535)-(U&65535)&65535;b[565364]=W;c[282410]=0;a[1130156]=O&255;a[1130157]=(O&65535)>>>8&255;a[1130158]=U&255;a[1130159]=(U&65535)>>>8&255;c[282409]=4;Z=_-U&65535;b[565340]=Z;if(U<<16>>16<$<<16>>16){b[565392]=U;ac=Z}else{b[565340]=0;ac=0}Z=b[565396]|0;do{if(U<<16>>16<Z<<16>>16){b[565340]=0;if(_<<16>>16<Z<<16>>16){ad=0;break}$=_-Z&65535;b[565340]=$;ad=$}else{ad=ac}}while(0);a[1130160]=ad&255;a[1130161]=(ad&65535)>>>8&255;c[282409]=6;do{if(ad<<16>>16==0){ae=O;af=U;ag=O;ah=W}else{ac=b[565361]|0;Z=ad<<16>>16<0?0:ad;_=b[161960+((Z<<16>>16>63?63:Z<<16>>16)<<1)>>1]<<1;Z=ab(_,(O<<16>>16)-(ac<<16>>16)|0)|0;$=b[565362]|0;Y=ab((W<<16>>16)-($<<16>>16)|0,_)|0;_=b[565404]|0;V=b[565373]|0;T=b[565406]|0;b[565337]=0;if(ad<<16>>16<=0){ae=O;af=U;ag=O;ah=W;break}R=(_+ac&65535)<<16;ac=((((aa-X&65535)+$&65535)-V&65535)+T&65535)<<16;T=b[565388]&255;V=6;while(1){a[1130156+V|0]=T;a[(c[282409]|0)+1130157|0]=(e[565388]|0)>>>8&255;$=(c[282409]|0)+2|0;c[282409]=$;_=ac+32768|0;a[1130156+$|0]=_>>>16&255;a[(c[282409]|0)+1130157|0]=_>>>24&255;_=(c[282409]|0)+2|0;c[282409]=_;$=R+32768|0;a[1130156+_|0]=$>>>16&255;a[(c[282409]|0)+1130157|0]=$>>>24&255;$=(c[282409]|0)+2|0;c[282409]=$;_=(b[565388]|0)-4&65535;b[565388]=_;S=(b[565337]|0)+1&65535;b[565337]=S;if(S<<16>>16<(b[565340]|0)){R=R+Z|0;ac=ac+Y|0;T=_&255;V=$}else{break}}ae=b[565357]|0;af=b[565358]|0;ag=b[565363]|0;ah=b[565364]|0}}while(0);b[565355]=ae;b[565356]=af;b[565361]=ag;b[565362]=ah;c[282407]=2;c[282408]=0;a[1130672]=1;i=f;return};case 3:{b[565430]=33;X2(1130862,0,64);i=f;return};case 14:{b[565430]=16;X2(1130862,0,64);i=f;return};case 15:{a[1129624]=0;ah=a[1130672]|0;do{if((ah|0)==1){ag=d[1129645]<<8|d[1129644];af=d[1129646]|0;ae=d[1129647]<<8|af;c[282408]=4;X=ae<<16>>16;ae=ag<<16>>16;ag=(ab(af&31,ae)|0)>>>15;af=(ab(X>>>5&31,ae)|0)>>>15;aa=af<<5;af=aa&768|(ab(X>>>10&31,ae)|0)>>>15<<10&31744;c[282410]=0;a[1130156]=(aa|ag&31)&255;a[1130157]=af>>>8&255;c[282409]=2;af=(b[565337]|0)+1&65535;b[565337]=af;if(af<<16>>16<4){o=6538;break}af=b[565363]|0;ag=b[565361]|0;aa=b[565340]|0;ae=aa<<16>>16<0?0:aa;X=b[161960+((ae<<16>>16>63?63:ae<<16>>16)<<1)>>1]|0;ae=ab((af<<16>>16)-(ag<<16>>16)<<1,X)|0;W=b[565364]|0;O=b[565362]|0;U=ab(X<<1,(W<<16>>16)-(O<<16>>16)|0)|0;X=b[565404]|0;ad=b[565373]|0;V=b[565365]|0;T=b[565406]|0;Y=b[565354]|0;b[565337]=0;if(aa<<16>>16>0){aa=((((O-ad&65535)+V&65535)+T&65535)-Y&65535)<<16;Y=(X+ag&65535)<<16;ag=b[565388]&255;X=2;while(1){a[1130156+X|0]=ag;a[(c[282409]|0)+1130157|0]=(e[565388]|0)>>>8&255;T=(c[282409]|0)+2|0;c[282409]=T;V=aa+32768|0;a[1130156+T|0]=V>>>16&255;a[(c[282409]|0)+1130157|0]=V>>>24&255;V=(c[282409]|0)+2|0;c[282409]=V;T=Y+32768|0;a[1130156+V|0]=T>>>16&255;a[(c[282409]|0)+1130157|0]=T>>>24&255;T=(c[282409]|0)+2|0;c[282409]=T;V=(b[565388]|0)-4&65535;b[565388]=V;ad=(b[565337]|0)+1&65535;b[565337]=ad;if(ad<<16>>16<(b[565340]|0)){aa=aa+U|0;Y=Y+ae|0;ag=V&255;X=T}else{break}}ai=b[565363]|0;aj=b[565364]|0}else{ai=af;aj=W}ak=b[565357]|0;al=b[565358]|0;am=ai;an=aj;ao=b[565350]|0;ap=b[565351]|0;aq=c[282676]|0;ar=c[282671]|0;as=c[282672]|0;o=6544}else if((ah|0)==2){X=d[1129645]<<8|d[1129644];c[282408]=2;b[565338]=X;if(X<<16>>16==-32768){a[1129624]=1;i=f;return}c[282407]=6;c[282408]=0;if(X<<16>>16==-32767){a[1130672]=3;i=f;return}else{a[1130672]=4;i=f;return}}else if((ah|0)==3){X=d[1129645]<<8|d[1129644];b[565338]=X;ag=d[1129647]<<8|d[1129646];ae=d[1129649]<<8|d[1129648];b[565367]=ae;Y=(ab(ag<<16>>16,X<<16>>16)|0)>>>15;b[565355]=Y+(e[565355]|0)&65535;b[565361]=Y+(e[565361]|0)&65535;b[565366]=ae+ag&65535;c[282407]=2;c[282408]=0;a[1130672]=2;i=f;return}else if((ah|0)==4){ag=d[1129645]<<8|d[1129644];b[565351]=ag;ae=d[1129647]<<8|d[1129646];b[565350]=ae;Y=d[1129649]<<8|d[1129648];c[282408]=6;b[565365]=Y;c[282676]=0;at=c[282671]|0;au=0;av=b[565338]|0;aw=c[282672]|0;ax=b[565354]|0;ay=b[565400]|0;az=b[565392]|0;aA=ae;aB=ag;o=6529}else{ag=d[1129647]<<8|d[1129646]|d[1129648]<<16|d[1129649]<<24;c[282672]=ag;ae=d[1129651]<<8|d[1129650];b[565400]=ae;b[565396]=d[1129653]<<8|d[1129652];b[565406]=d[1129655]<<8|d[1129654];b[565373]=d[1129657]<<8|d[1129656];Y=d[1129659]<<8|d[1129658]|d[1129660]<<16|d[1129661]<<24;c[282671]=Y;b[565404]=d[1129663]<<8|d[1129662];b[565388]=d[1129665]<<8|d[1129664];X=d[1129667]<<8|d[1129666];b[565354]=X;c[282674]=d[1129669]<<8|d[1129668]|d[1129670]<<16|d[1129671]<<24;c[282673]=d[1129673]<<8|d[1129672]|d[1129674]<<16|d[1129675]<<24;U=d[1129677]<<8|d[1129676];b[565338]=U;aa=d[1129681]<<8|d[1129680]|d[1129682]<<16|d[1129683]<<24;c[282676]=aa;T=d[1129685]<<8|d[1129684];b[565351]=T;V=d[1129687]<<8|d[1129686];b[565350]=V;ad=d[1129689]<<8|d[1129688];c[282408]=46;b[565365]=ad;b[565355]=(aa+Y|0)>>>16&65535;b[565356]=ag>>>16&65535;b[565361]=Y>>>16&65535;b[565362]=X;b[565366]=0;b[565367]=0;b[565392]=ae;at=Y;au=aa;av=U;aw=ag;ax=X;ay=ae;az=ae;aA=V;aB=T;o=6529}}while(0);do{if((o|0)==6529){ah=at+au|0;aj=av<<16>>16;ai=ab(ah>>16,aj)|0;T=ai>>>15;V=T&65535;b[565357]=V;ae=ab(aj,aw>>16)|0;X=ae>>>15;ag=X&65535;b[565358]=ag;b[565363]=V;U=((ab(aj,ax<<16>>16)|0)>>>15)+(ay&65535)-X&65535;b[565364]=U;c[282410]=0;a[1130156]=ah>>>16&255;a[1130157]=ah>>>24&255;a[1130158]=T&255;a[1130159]=ai>>>23&255;a[1130160]=aw>>>16&255;a[1130161]=aw>>>24&255;a[1130162]=X&255;a[1130163]=ae>>>23&255;c[282409]=8;ae=az-ag&65535;b[565340]=ae;if(ag<<16>>16<az<<16>>16){b[565392]=ag;aC=ae}else{b[565340]=0;aC=0}ae=b[565396]|0;do{if(ag<<16>>16<ae<<16>>16){b[565340]=0;X=b[565356]|0;if(X<<16>>16<ae<<16>>16){aD=0;break}ai=X-ae&65535;b[565340]=ai;aD=ai}else{aD=aC}}while(0);a[1130164]=aD&255;a[1130165]=(aD&65535)>>>8&255;c[282409]=10;if(aD<<16>>16==0){ak=V;al=ag;am=V;an=U;ao=aA;ap=aB;aq=au;ar=at;as=aw;o=6544;break}b[565337]=0;o=6538}}while(0);if((o|0)==6538){c[282407]=4;c[282408]=0;a[1130672]=1;i=f;return}else if((o|0)==6544){b[565355]=ak;b[565356]=al;b[565361]=am;b[565362]=an;an=(c[282673]|0)+(ao<<16>>16<<8)|0;c[282673]=an;ao=(c[282674]|0)+(ap<<16>>16<<8)|0;c[282674]=ao;c[282671]=aq+ar+an;c[282672]=ao+as;b[565366]=(b[565366]|0)+(b[565367]|0)&65535;c[282407]=2;c[282408]=0;a[1130672]=2;i=f;return}break};case 8:{a[1129624]=0;as=a[1130672]|0;L9120:do{if((as|0)==2){b[g>>1]=d[1129645]<<8|d[1129644];ao=d[1129647]<<8|d[1129646];b[h>>1]=ao;b[g+2>>1]=d[1129649]<<8|d[1129648];b[h+2>>1]=d[1129651]<<8|d[1129650];b[j>>1]=d[1129653]<<8|d[1129652];b[j+2>>1]=d[1129655]<<8|d[1129654];b[j+4>>1]=d[1129657]<<8|d[1129656];an=d[1129659]<<8|d[1129658];c[282408]=16;b[j+6>>1]=an;c[282409]=0;c[282410]=0;an=0;ar=0;aq=ao;while(1){ao=1130784+(ar<<2)|0;ap=(b[ao>>1]|0)-aq&65535;b[565340]=ap;if(ap<<16>>16>0){b[ao>>1]=aq;b[1130786+(ar<<2)>>1]=aq}else{b[565340]=0}ao=1130792+(ar<<2)|0;do{if(aq<<16>>16<(b[ao>>1]|0)){b[565340]=0;ap=b[ao>>1]|0;if(aq<<16>>16<ap<<16>>16){aE=0;break}am=aq-ap&65535;b[565340]=am;aE=am&255}else{aE=b[565340]&255}}while(0);a[1130156+(c[282409]|0)|0]=aE;a[(c[282409]|0)+1130157|0]=(e[565340]|0)>>>8&255;c[282409]=(c[282409]|0)+2;ao=b[565340]|0;do{if(ao<<16>>16==0){aF=b[g+(an<<16>>16<<1)>>1]|0}else{am=b[j+(ar<<2)>>1]|0;ap=b[j+(ar<<2)+2>>1]|0;if(am<<16>>16==-16383){aG=1}else{aG=ap<<16>>16==16383?1:an<<16>>16}al=am<<16>>16;am=b[1130820+(aG<<1)>>1]|0;ak=(ab(am,al)|0)>>>15;aw=b[565338]|0;at=aw<<16>>16;au=(ab(at,al)|0)>>>15;al=b[g+(aG<<1)>>1]|0;aB=al&65535;aA=ak<<16>>16;ak=b[1130816+(aG<<1)>>1]|0;aD=ak&65535;aC=ao<<16>>16<0?0:ao;az=b[161960+((aC<<16>>16>63?63:aC<<16>>16)<<1)>>1]<<1;aC=ab((aD+au<<16>>16)-(aA+aB<<16>>16)|0,az)|0;au=ao<<16>>16==1;ay=au?-aC|0:aC;aC=ap<<16>>16;ap=(ab(am,aC)|0)>>>15;am=ap<<16>>16;ap=ab((((ab(at,aC)|0)>>>15)+aD<<16>>16)-(am+aB<<16>>16)|0,az)|0;az=au?-ap|0:ap;ap=b[1130808+(ar<<2)>>1]|0;au=ak<<16>>16;ak=b[1130810+(ar<<2)>>1]|0;b[1130820+(ar<<1)>>1]=aw;b[565337]=0;if((b[565340]|0)<=0){aF=al;break}aw=1130760+(ar<<2)|0;aB=1130768+(ar<<2)|0;aD=1130762+(ar<<2)|0;aC=1130770+(ar<<2)|0;at=1130776+(ar<<2)|0;ax=1130778+(ar<<2)|0;av=aA-au+(ap&65535)<<16;ap=am-au+(ak&65535)<<16;ak=b[at>>1]&255;while(1){au=av+ay|0;am=ap+az|0;aA=au>>>16&65535;ae=am>>>16&65535;W=b[aw>>1]|0;af=aA<<16>>16<W<<16>>16?W:aA;aA=b[aB>>1]|0;W=b[aD>>1]|0;ai=ae<<16>>16<W<<16>>16?W:ae;ae=b[aC>>1]|0;a[1130156+(c[282409]|0)|0]=ak;a[(c[282409]|0)+1130157|0]=(e[at>>1]|0)>>>8&255;W=(c[282409]|0)+2|0;c[282409]=W;a[1130156+W|0]=(af<<16>>16>aA<<16>>16?aA:af)&255;a[(c[282409]|0)+1130157|0]=0;af=(c[282409]|0)+1|0;c[282409]=af;a[1130156+af|0]=(ai<<16>>16>ae<<16>>16?ae:ai)&255;a[(c[282409]|0)+1130157|0]=0;c[282409]=(c[282409]|0)+1;ai=(b[at>>1]|0)-4&65535;b[at>>1]=ai;b[ax>>1]=(b[ax>>1]|0)-4&65535;ae=(b[565337]|0)+1&65535;b[565337]=ae;if(ae<<16>>16<(b[565340]|0)){av=au;ap=am;ak=ai&255}else{aF=al;break}}}}while(0);b[1130816+(ar<<1)>>1]=aF;ao=an+1&65535;al=ao<<16>>16;if(ao<<16>>16>=2){break L9120}an=ao;ar=al;aq=b[h+(al<<1)>>1]|0}}else if((as|0)==1){aq=d[1129645]<<8|d[1129644];c[282408]=2;b[565338]=aq;if(aq<<16>>16==-32768){c[282410]=0;a[1130156]=0;a[1130157]=0;c[282409]=2;a[1129624]=1;i=f;return}else{c[282407]=16;c[282408]=0;a[1130672]=2;i=f;return}}else{aq=d[1129644]|0;ar=d[1129645]<<8|aq;b[565384]=ar;an=d[1129646]|0;U=d[1129647]<<8|an;b[565385]=U;b[565386]=d[1129649]<<8|d[1129648];b[565387]=d[1129651]<<8|d[1129650];V=d[1129653]<<8|d[1129652];b[565380]=V;ag=d[1129655]<<8|d[1129654];b[565381]=ag;b[565382]=d[1129657]<<8|d[1129656];b[565383]=d[1129659]<<8|d[1129658];al=d[1129677]<<8|d[1129676];b[565404]=al;ao=d[1129679]<<8|d[1129678];b[565405]=ao;b[565406]=d[1129681]<<8|d[1129680];b[565407]=d[1129683]<<8|d[1129682];b[565388]=d[1129685]<<8|d[1129684];b[565389]=d[1129687]<<8|d[1129686];b[565390]=d[1129689]<<8|d[1129688];b[565391]=d[1129691]<<8|d[1129690];b[565400]=d[1129693]<<8|d[1129692];b[565401]=d[1129695]<<8|d[1129694];b[565402]=d[1129697]<<8|d[1129696];b[565403]=d[1129699]<<8|d[1129698];b[565396]=d[1129701]<<8|d[1129700];b[565397]=d[1129703]<<8|d[1129702];b[565398]=d[1129705]<<8|d[1129704];b[565399]=d[1129707]<<8|d[1129706];ak=d[1129717]<<8|d[1129716];b[565338]=ak;ap=d[1129719]<<8|d[1129718];b[g>>1]=ap;av=d[1129721]<<8|d[1129720];b[h>>1]=av;ax=d[1129723]<<8|d[1129722];b[g+2>>1]=ax;at=d[1129725]<<8|d[1129724];b[h+2>>1]=at;aC=d[1129727]<<8|d[1129726];b[j>>1]=aC;aD=d[1129729]<<8|d[1129728];b[j+2>>1]=aD;b[j+4>>1]=d[1129731]<<8|d[1129730];aB=d[1129733]<<8|d[1129732];c[282408]=90;b[j+6>>1]=aB;b[565408]=ap;b[565409]=ax;b[565392]=av;b[565393]=av;b[565394]=at;b[565395]=at;b[565410]=ak;b[565411]=ak;ak=aC+(al-ap&65535)&65535;al=aD+(ao-ap&65535)&65535;ap=ak<<16>>16<V<<16>>16?V:ak;ak=al<<16>>16<ag<<16>>16?ag:al;c[282410]=0;a[1130156]=(ap<<16>>16>ar<<16>>16?aq:ap)&255;a[1130157]=(ak<<16>>16>U<<16>>16?an:ak)&255;a[1130158]=0;c[282409]=2}}while(0);c[282407]=2;c[282408]=0;a[1130672]=1;i=f;return};case 16:{a[1129624]=0;j=a[1130672]|0;do{if((j|0)==1){h=d[1129645]<<8|d[1129644];g=d[1129646]|0;as=d[1129647]<<8|g;c[282408]=4;aF=as<<16>>16;as=h<<16>>16;h=(ab(g&31,as)|0)>>>15;g=(ab(aF>>>5&31,as)|0)>>>15;aG=g<<5;g=aG&768|(ab(aF>>>10&31,as)|0)>>>15<<10&31744;c[282410]=0;a[1130156]=(aG|h&31)&255;a[1130157]=g>>>8&255;c[282409]=2;g=(b[565337]|0)+1&65535;b[565337]=g;if(g<<16>>16<4){o=6563;break}g=b[565340]|0;if(g<<16>>16==0){o=6568;break}h=b[565361]|0;aG=g<<16>>16<0?0:g;as=b[161960+((aG<<16>>16>63?63:aG<<16>>16)<<1)>>1]<<1;aG=ab(as,(b[565363]|0)-(h<<16>>16)|0)|0;aF=b[565362]|0;aE=ab((b[565364]|0)-(aF<<16>>16)|0,as)|0;as=b[565404]|0;ak=b[565373]|0;an=b[565365]|0;U=b[565406]|0;ap=b[565354]|0;b[565337]=0;if(g<<16>>16<=0){o=6568;break}g=(as+h&65535)<<16;h=((((aF-ak&65535)+an&65535)+U&65535)-ap&65535)<<16;ap=b[565388]&255;U=2;while(1){a[1130156+U|0]=ap;a[(c[282409]|0)+1130157|0]=(e[565388]|0)>>>8&255;an=(c[282409]|0)+2|0;c[282409]=an;ak=h+32768|0;a[1130156+an|0]=ak>>>16&255;a[(c[282409]|0)+1130157|0]=ak>>>24&255;ak=(c[282409]|0)+2|0;c[282409]=ak;an=g+32768|0;a[1130156+ak|0]=an>>>16&255;a[(c[282409]|0)+1130157|0]=an>>>24&255;an=(c[282409]|0)+2|0;c[282409]=an;ak=(b[565388]|0)-4&65535;b[565388]=ak;aF=(b[565337]|0)+1&65535;b[565337]=aF;if(aF<<16>>16<(b[565340]|0)){g=g+aG|0;h=h+aE|0;ap=ak&255;U=an}else{o=6568;break}}}else if((j|0)==2){U=d[1129645]<<8|d[1129644];c[282408]=2;b[565338]=U;if(U<<16>>16==-32768){a[1129624]=1;i=f;return}else{c[282407]=10;c[282408]=0;a[1130672]=3;i=f;return}}else if((j|0)==3){U=d[1129645]<<8|d[1129644];b[565358]=U;ap=b[565338]|0;aE=ap<<16>>16;h=(ab((d[1129647]<<8|d[1129646])<<16>>16,aE)|0)>>>15&65535;b[565360]=h;aG=d[1129649]<<8|d[1129648];b[565357]=aG;g=d[1129651]<<8|d[1129650];c[282408]=8;an=(ab(g<<16>>16,aE)|0)>>>15&65535;b[565359]=an;aH=an;aI=aG;aJ=h;aK=U;aL=b[565354]|0;aM=ap;aN=b[565400]|0;aO=b[565356]|0;aP=b[565392]|0;o=6554}else{ap=d[1129647]<<8|d[1129646]|d[1129648]<<16|d[1129649]<<24;c[282672]=ap;U=d[1129651]<<8|d[1129650];b[565400]=U;b[565396]=d[1129653]<<8|d[1129652];b[565406]=d[1129655]<<8|d[1129654];b[565373]=d[1129657]<<8|d[1129656];h=d[1129659]<<8|d[1129658]|d[1129660]<<16|d[1129661]<<24;c[282671]=h;b[565404]=d[1129663]<<8|d[1129662];b[565388]=d[1129665]<<8|d[1129664];aG=d[1129667]<<8|d[1129666];b[565354]=aG;an=d[1129669]<<8|d[1129668];b[565338]=an;aE=d[1129671]<<8|d[1129670];b[565358]=aE;g=an<<16>>16;ak=(ab((d[1129673]<<8|d[1129672])<<16>>16,g)|0)>>>15&65535;b[565360]=ak;aF=d[1129675]<<8|d[1129674];b[565357]=aF;as=(ab((d[1129677]<<8|d[1129676])<<16>>16,g)|0)>>>15&65535;b[565359]=as;g=d[1129679]<<8|d[1129678];c[282408]=36;b[565365]=g;g=h>>>16&65535;b[565355]=g;h=ap>>>16&65535;b[565356]=h;b[565361]=g;b[565362]=aG;b[565392]=U;aH=as;aI=aF;aJ=ak;aK=aE;aL=aG;aM=an;aN=U;aO=h;aP=U;o=6554}}while(0);do{if((o|0)==6554){j=aH+aI&65535;b[565357]=j;U=aJ+aK&65535;b[565358]=U;b[565363]=j;b[565364]=((ab(aL<<16>>16,aM<<16>>16)|0)>>>15)+(aN&65535)-(U&65535)&65535;c[282410]=0;a[1130156]=j&255;a[1130157]=(j&65535)>>>8&255;a[1130158]=U&255;a[1130159]=(U&65535)>>>8&255;c[282409]=4;j=aO-U&65535;b[565340]=j;if(U<<16>>16<aP<<16>>16){b[565392]=U;aQ=j}else{b[565340]=0;aQ=0}j=b[565396]|0;do{if(U<<16>>16<j<<16>>16){b[565340]=0;if(aO<<16>>16<j<<16>>16){aR=0;break}h=aO-j&65535;b[565340]=h;aR=h}else{aR=aQ}}while(0);a[1130160]=aR&255;a[1130161]=(aR&65535)>>>8&255;c[282409]=6;if(aR<<16>>16==0){o=6568;break}b[565337]=0;o=6563}}while(0);if((o|0)==6563){c[282407]=4;c[282408]=0;a[1130672]=1;i=f;return}else if((o|0)==6568){b[565355]=b[565357]|0;b[565356]=b[565358]|0;b[565361]=b[565363]|0;b[565362]=b[565364]|0;c[282407]=2;c[282408]=0;a[1130672]=2;i=f;return}break};case 17:{aR=d[1129645]<<8|d[1129644];aQ=d[1129647]<<8|d[1129646];aO=d[1129649]<<8|d[1129648];aP=d[1129651]<<8|d[1129650];c[282408]=8;c[282410]=0;a[1130156]=(((aQ<<16>>16)*341|0)>>>10&240|((aR<<16>>16)*341|0)>>>14&15)&255;a[1130157]=((((aP<<16>>16)*341|0)>>>2&61440|((aO<<16>>16)*341|0)>>>6&3840)&65535)>>>8&255;c[282409]=2;i=f;return};case 0:{aO=d[1129645]<<8|d[1129644];aP=d[1129647]<<8|d[1129646];c[282408]=4;aR=(ab(aO<<16>>16<<1,aP<<16>>16)|0)>>1;c[282410]=0;a[1130156]=aR&255;a[1130157]=aR>>>8&255;a[1130158]=aR>>>16&255;a[1130159]=aR>>>24&255;c[282409]=4;i=f;return};case 10:{aR=d[1129647]<<8|d[1129646];c[282408]=6;aP=aR<<16>>16;aR=b[161928+((aP&15)<<1)>>1]|0;aO=b[161928+((aP>>>4&15)<<1)>>1]|0;aQ=b[161928+((aP>>>8&15)<<1)>>1]|0;aN=b[161928+((aP>>>12&15)<<1)>>1]|0;c[282410]=0;a[1130156]=aQ&255;a[1130157]=(aQ&65535)>>>8&255;a[1130158]=aN&255;a[1130159]=(aN&65535)>>>8&255;a[1130160]=aR&255;a[1130161]=(aR&65535)>>>8&255;a[1130162]=aO&255;a[1130163]=(aO&65535)>>>8&255;c[282409]=8;i=f;return};case 11:{aO=d[1129645]<<8|d[1129644];aR=d[1129647]<<8|d[1129646];aN=d[1129649]<<8|d[1129648];c[282408]=6;a[l]=1;c[282409]=0;c[282410]=0;xA(l,aO,aR,aN,0,1);i=f;return};case 13:{a[1129624]=0;aN=a[1130672]|0;if((aN|0)==1){aR=d[1129645]<<8|d[1129644];c[282408]=2;b[565338]=aR;if(aR<<16>>16==-32768){a[1129624]=1;i=f;return}else{c[282407]=6;c[282408]=0;a[1130672]=2;i=f;return}}else if((aN|0)==2){aN=d[1129645]<<8|d[1129644];b[565351]=aN;aR=d[1129647]<<8|d[1129646];b[565350]=aR;aO=d[1129649]<<8|d[1129648];c[282408]=6;b[565365]=aO;c[282676]=0;aS=c[282671]|0;aT=0;aU=b[565338]|0;aV=c[282672]|0;aW=b[565354]|0;aX=b[565400]|0;aY=b[565356]|0;aZ=b[565392]|0;a_=aR;a$=aN;a0=aO}else{aO=d[1129645]<<8|d[1129644]|d[1129646]<<16|d[1129647]<<24;c[282672]=aO;aN=d[1129649]<<8|d[1129648];b[565400]=aN;b[565396]=d[1129651]<<8|d[1129650];b[565406]=d[1129653]<<8|d[1129652];b[565373]=d[1129655]<<8|d[1129654];aR=d[1129657]<<8|d[1129656]|d[1129658]<<16|d[1129659]<<24;c[282671]=aR;b[565404]=d[1129661]<<8|d[1129660];b[565388]=d[1129663]<<8|d[1129662];l=d[1129665]<<8|d[1129664];b[565354]=l;c[282674]=d[1129667]<<8|d[1129666]|d[1129668]<<16|d[1129669]<<24;c[282673]=d[1129671]<<8|d[1129670]|d[1129672]<<16|d[1129673]<<24;aQ=d[1129675]<<8|d[1129674];b[565338]=aQ;aP=(d[1129679]<<8|d[1129678])<<16>>16<<8;c[282676]=aP;aM=d[1129681]<<8|d[1129680];b[565351]=aM;aL=d[1129683]<<8|d[1129682];b[565350]=aL;aK=d[1129685]<<8|d[1129684];c[282408]=42;b[565365]=aK;b[565355]=(aP+aR|0)>>>16&65535;aJ=aO>>>16&65535;b[565356]=aJ;b[565361]=aR>>>16&65535;b[565362]=l;b[565392]=aN;aS=aR;aT=aP;aU=aQ;aV=aO;aW=l;aX=aN;aY=aJ;aZ=aN;a_=aL;a$=aM;a0=aK}aK=aS+aT|0;aM=aU<<16>>16;aU=(ab(aK>>16,aM)|0)>>>15;aL=((ab(b[565366]|0,aM)|0)>>>15)+aU|0;aU=aL&65535;b[565357]=aU;aN=ab(aM,aV>>16)|0;aJ=aN>>>15;l=aJ&65535;b[565358]=l;b[565363]=aU;aO=((ab(aM,aW<<16>>16)|0)>>>15)+(aX&65535)-aJ&65535;b[565364]=aO;c[282410]=0;a[1130156]=aK>>>16&255;a[1130157]=aK>>>24&255;a[1130158]=aL&255;a[1130159]=(aU&65535)>>>8&255;a[1130160]=aV>>>16&255;a[1130161]=aV>>>24&255;a[1130162]=aJ&255;a[1130163]=aN>>>23&255;c[282409]=8;aN=aY-l&65535;b[565340]=aN;if(l<<16>>16<aZ<<16>>16){b[565392]=l;a1=aN}else{b[565340]=0;a1=0}aN=b[565396]|0;do{if(l<<16>>16<aN<<16>>16){b[565340]=0;if(aY<<16>>16<aN<<16>>16){a2=0;break}aZ=aY-aN&65535;b[565340]=aZ;a2=aZ}else{a2=a1}}while(0);a[1130164]=a2&255;a[1130165]=(a2&65535)>>>8&255;c[282409]=10;do{if(a2<<16>>16==0){a3=aU;a4=l;a5=aU;a6=aO;a7=a_;a8=a$;a9=aT;ba=aS;bb=aV}else{a1=b[565361]|0;aN=a2<<16>>16<0?0:a2;aY=b[161960+((aN<<16>>16>63?63:aN<<16>>16)<<1)>>1]<<1;aN=ab(aY,(aU<<16>>16)-(a1<<16>>16)|0)|0;aZ=b[565362]|0;aJ=ab((aO<<16>>16)-(aZ<<16>>16)|0,aY)|0;aY=b[565404]|0;aL=b[565373]|0;aK=b[565406]|0;b[565337]=0;if(a2<<16>>16<=0){a3=aU;a4=l;a5=aU;a6=aO;a7=a_;a8=a$;a9=aT;ba=aS;bb=aV;break}aX=(aY+a1&65535)<<16;a1=((((a0-aW&65535)+aZ&65535)-aL&65535)+aK&65535)<<16;aK=b[565388]&255;aL=10;while(1){a[1130156+aL|0]=aK;a[(c[282409]|0)+1130157|0]=(e[565388]|0)>>>8&255;aZ=(c[282409]|0)+2|0;c[282409]=aZ;aY=a1+32768|0;a[1130156+aZ|0]=aY>>>16&255;a[(c[282409]|0)+1130157|0]=aY>>>24&255;aY=(c[282409]|0)+2|0;c[282409]=aY;aZ=aX+32768|0;a[1130156+aY|0]=aZ>>>16&255;a[(c[282409]|0)+1130157|0]=aZ>>>24&255;aZ=(c[282409]|0)+2|0;c[282409]=aZ;aY=(b[565388]|0)-4&65535;b[565388]=aY;aM=(b[565337]|0)+1&65535;b[565337]=aM;if(aM<<16>>16<(b[565340]|0)){aX=aX+aN|0;a1=a1+aJ|0;aK=aY&255;aL=aZ}else{break}}a3=b[565357]|0;a4=b[565358]|0;a5=b[565363]|0;a6=b[565364]|0;a7=b[565350]|0;a8=b[565351]|0;a9=c[282676]|0;ba=c[282671]|0;bb=c[282672]|0}}while(0);b[565355]=a3;b[565356]=a4;b[565361]=a5;b[565362]=a6;a6=(c[282673]|0)+(a7<<16>>16<<8)|0;c[282673]=a6;a7=(c[282674]|0)+(a8<<16>>16<<8)|0;c[282674]=a7;c[282671]=a9+ba+a6;c[282672]=a7+bb;c[282407]=2;c[282408]=0;a[1130672]=1;i=f;return};case 9:{a[1129624]=0;L9222:do{switch(a[1130672]|0){case 1:{bb=d[1129645]<<8|d[1129644];c[282408]=2;b[565339]=bb;if(bb<<16>>16<(b[565392]|0)){b[565378]=((b[565373]|0)+bb&65535)-(b[565400]|0)&65535;b[565392]=bb}bb=d[1129647]<<8|d[1129646];c[282408]=4;b[565338]=bb;if((bb<<16>>16|0)==(-28672|0)){c[282407]=14;c[282408]=0;a[1130672]=2;i=f;return}else if((bb<<16>>16|0)==(-32768|0)){o=6505;break L9222}else if((bb<<16>>16|0)==0){o=6480;break L9222}else{c[282407]=10;c[282408]=0;a[1130672]=4;i=f;return}break};case 5:{a[k]=1;bb=d[1129645]|0;a7=bb<<8|d[1129644];c[282408]=2;b[565339]=a7;if(a7<<16>>16==-32768){o=6505;break L9222}a6=(a[1130754]|0)!=0;if(!(a7<<16>>16!=0|a6)){o=6480;break L9222}if(a7<<16>>16==0){a[1130754]=a6&1^1;break L9222}switch(bb<<16>>16){case 32:case 46:case 64:case 96:case 160:case 192:case 224:{break};default:{o=6480;break L9222}}c[282407]=4;c[282408]=0;a[1130672]=6;i=f;return};case 6:{a[k]=1;bb=b[565339]|0;a6=d[1129645]<<8|d[1129644];a7=d[1129647]<<8|d[1129646];c[282408]=4;ba=a7+(b[565374]|0)&65535;a7=(b[565375]|0)+a6&65535;a6=(b[565376]|0)+bb&65535;bb=a[1130754]|0;c[282409]=0;c[282410]=0;a9=b[565378]|0;a8=a9<<16>>16;a5=bb<<24>>24!=0?15:7;a4=a7<<16>>16;a3=ba<<16>>16;do{if(!((a8-a5|0)>(a4|0)|a7<<16>>16>a9<<16>>16)){if((a3|0)<((b[565370]|0)-a5|0)|ba<<16>>16>(b[565371]|0)){break}if((a8|0)<((b[565372]|0)-a5|0)|a9<<16>>16>(b[565373]|0)){break}xA(k,ba,a9,238,bb,0)}}while(0);do{if(!((a3|0)<((b[565370]|0)-a5|0)|ba<<16>>16>(b[565371]|0))){if((a4|0)<((b[565372]|0)-a5|0)|a7<<16>>16>(b[565373]|0)|a7<<16>>16>(b[565378]|0)){break}xA(k,ba,a7,a6,a[1130754]|0,0)}}while(0);xA(k,0,256,0,0,1);break};case 2:{a6=d[1129645]<<8|d[1129644];a7=d[1129647]<<8|d[1129646];ba=d[1129649]<<8|d[1129648];a5=d[1129651]<<8|d[1129650];a4=d[1129653]<<8|d[1129652];a3=d[1129655]<<8|d[1129654];b[565338]=a3;bb=a6&65535;a6=((d[1129657]<<8|d[1129656])-a4&65535)-((ab((a5<<16>>16)-(a4<<16>>16)|0,bb)|0)>>>16)|0;a4=ba<<16>>16;ba=a4-((ab(a4-(a7<<16>>16)|0,bb)|0)>>>16)|0;bb=a6<<16>>16;a7=a3<<16>>16;a3=(ab(bb,a7)|0)>>>15;a4=(ab(a7,ba<<16>>16)|0)>>>15;b[565374]=a3+(e[565368]|0)&65535;b[565375]=a4+(e[565373]|0)-(e[565400]|0)&65535;c[282410]=0;a[1130156]=a6&255;a[1130157]=bb>>>8&255;c[282409]=2;c[282407]=4;c[282408]=0;a[1130672]=3;i=f;return};case 3:{bb=d[1129645]<<8|d[1129644];c[282408]=2;bc=bb+(b[565375]|0)&65535;bd=2;o=6489;break};case 4:{bb=d[1129645]<<8|d[1129644];b[565404]=bb;b[565393]=d[1129647]<<8|d[1129646];a6=d[1129649]<<8|d[1129648];a4=d[1129651]<<8|d[1129650];c[282408]=8;a3=(b[565400]|0)-(b[565339]|0)&65535;b[565340]=a3;ba=b[565338]|0;a7=(ab(ba,a6<<16>>16)|0)>>>15;a6=(ab(a4<<16>>16,ba)|0)>>>15;b[565374]=(e[565368]|0)-(bb&65535)+a7&65535;bc=a6-(a3&65535)+(e[565373]|0)&65535;bd=8;o=6489;break};default:{b[565368]=d[1129645]<<8|d[1129644];a3=d[1129647]<<8|d[1129646];b[565369]=a3;b[565370]=d[1129651]<<8|d[1129650];b[565371]=d[1129653]<<8|d[1129652];b[565372]=d[1129655]<<8|d[1129654];a6=d[1129657]<<8|d[1129656];c[282408]=14;b[565373]=a6;b[565400]=a6-a3&65535;b[565392]=256;o=6480}}}while(0);if((o|0)==6505){a[1129624]=1;i=f;return}else if((o|0)==6480){c[282407]=4;c[282408]=0;a[1130672]=1;i=f;return}else if((o|0)==6489){b[565375]=bc;a[1130754]=1;bc=d[1129644+(bd|1)|0]<<8|d[1129644+bd|0];c[282408]=bd+2;b[565376]=bc}c[282407]=2;c[282408]=0;a[1130672]=5;i=f;return};case 5:{b[565379]=0;X2(1130824,0,36);i=f;return};case 6:{c[282410]=0;X5(1130156,1130824,32)|0;c[282409]=32;i=f;return};default:{i=f;return}}}function xo(){b[565464]=0;c[201850]=822;return}function xp(){b[565464]=0;c[201850]=822;return}function xq(){c[201850]=3388;return}function xr(){c[201850]=268;b[565466]=1;b[565464]=-32768;return}function xs(){b[566021]=b[565464]|0;b[566019]=0;c[201850]=2062;return}function xt(){b[565471]=b[565464]|0;c[201850]=1896;return}function xu(){b[565472]=b[565464]|0;c[201850]=3672;b[565474]=0;b[565988]=0;b[565473]=0;b[565475]=0;b[565991]=-1;b[565465]=192;return}function xv(){var a=0;a=(b[565475]|0)+1&65535;b[565475]=a;switch(a&65535|0){case 6:{b[565464]=b[566009]|0;return};case 5:{b[566010]=b[565464]|0;b[565464]=1;return};case 4:{b[566009]=b[565464]|0;return};case 7:{b[565464]=b[566010]|0;b[565475]=0;return};case 3:{if((b[565464]|0)!=-1){return}b[565464]=128;b[565465]=132;c[201850]=1702;return};default:{return}}}function xw(){var a=0;a=b[565464]|0;b[565464]=((ab((a&65535)>>>8<<1,b[565467]|0)|0)+(a<<1&510)&65535)<<16>>16>>>1&65535;c[201850]=822;return}function xx(){var a=0;a=b[565464]|0;b[565467]=a&255;b[565468]=(a&65535)>>>8;b[565464]=128;b[565465]=132;c[201850]=1702;return}function xy(){var a=0;a=b[565464]|0;if(a<<16>>16==-1){b[565464]=128;b[565465]=132;c[201850]=1702;return}else{b[565464]=a;return}}function xz(d){d=d|0;var e=0,f=0,g=0,h=0;if((d&65535)>>>0>=(c[295940]|0)>>>0){e=-128;return e|0}b[565335]=d;d=c[282409]|0;if((d|0)==0){a[1130668|0]=-1;e=-1;return e|0}f=c[282410]|0;g=a[1130156+(f&511)|0]|0;a[1130668|0]=g;h=f+1|0;c[282410]=h;if((d|0)!=(h|0)){e=g;return e|0}c[282409]=0;e=g;return e|0}function xA(d,f,g,h,i,j){d=d|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0;k=g<<16>>16;l=k>>>3;m=l&31;n=l+1&31;do{if(g<<16>>16>=0){if((k&511)>>>0<235){break}a[d]=0}}while(0);k=i<<24>>24!=0;l=1130862+(m<<1)|0;m=b[l>>1]|0;do{if(k){o=b[565430]|0;if(((m<<16>>16)+1|0)<(o<<16>>16|0)){p=o}else{a[d]=0;p=b[565430]|0}if(((b[1130862+((n&65535)<<1)>>1]|0)+1|0)<(p<<16>>16|0)){break}a[d]=0}else{if(m<<16>>16<(b[565430]|0)){break}a[d]=0}}while(0);do{if((b[565379]|0)>127){a[d]=0}else{if((a[d]|0)==0){break}m=b[l>>1]|0;if(k){b[l>>1]=m+2&65535;p=1130862+((n&65535)<<1)|0;b[p>>1]=(b[p>>1]|0)+2&65535}else{b[l>>1]=m+1&65535}a[1130156+(c[282409]|0)|0]=1;a[(c[282409]|0)+1130157|0]=0;m=(c[282409]|0)+2|0;c[282409]=m;a[1130156+m|0]=f&255;a[(c[282409]|0)+1130157|0]=0;m=(c[282409]|0)+1|0;c[282409]=m;a[1130156+m|0]=g&255;a[(c[282409]|0)+1130157|0]=0;m=(c[282409]|0)+1|0;c[282409]=m;a[1130156+m|0]=h&255;a[(c[282409]|0)+1130157|0]=(h&65535)>>>8&255;c[282409]=(c[282409]|0)+2;b[565379]=(b[565379]|0)+1&65535;if(f<<16>>16<0){q=1}else{q=f<<16>>16>255|0}m=1130824+(b[565428]<<1)|0;b[m>>1]=(e[m>>1]|q<<b[565429])&65535;m=(b[565429]|0)+1&65535;b[565429]=m;p=1130824+(b[565428]<<1)|0;b[p>>1]=(e[p>>1]|(i&255)<<(m<<16>>16))&65535;m=(b[565429]|0)+1&65535;b[565429]=m;if(m<<16>>16!=16){return}b[565429]=0;b[565428]=(b[565428]|0)+1&65535;return}}while(0);if(j<<24>>24==0){return}a[1130156+(c[282409]|0)|0]=0;a[(c[282409]|0)+1130157|0]=0;c[282409]=(c[282409]|0)+2;return}function xB(){var a=0;a=((e[565464]|0)<<1)+946&1022;b[565470]=b[162136+(a<<1)>>1]|0;b[565469]=b[162136+((a|1)<<1)>>1]|0;c[201850]=2682;b[565465]=128;return}function xC(){var a=0,d=0,f=0;a=b[565464]|0;b[566022]=a&255;d=(a&65535)>>>8;b[566023]=d;f=((ab(d<<1,b[565467]|0)|0)+(a<<1&510)&65535)<<16>>16>>>1;b[565464]=f&65535;c[201850]=822;b[1132048+((f&65535)<<1)>>1]=0;b[1148432+((e[565464]|0)<<1)>>1]=255;b[1164816+((e[565464]|0)<<1)>>1]=0;b[590607]=0;b[590608]=0;return}function xD(){var a=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;a=b[565464]|0;c=a&255;b[590605]=c;d=(a&65535)>>>8;b[590606]=d;if(c<<16>>16==0){b[590605]=1;e=1}else{e=c}c=b[590607]|0;if(c<<16>>16<e<<16>>16){f=e}else{e=c+1&65535;b[590605]=e;f=e}if(d<<16>>16>c<<16>>16){b[590607]=d}b[590609]=f;b[590610]=f;b[590611]=6;b[590601]=0;d=b[566022]|0;b[590603]=d;c=b[566023]|0;b[590604]=c;if(f<<16>>16<=0){xJ();return}e=b[565467]|0;a=b[565468]|0;g=f<<16>>16;f=0;h=d;d=c;while(1){c=h&255;i=(d&255)-1&65535;j=c-(c<<16>>16<e<<16>>16?0:e)&65535;if(i<<16>>16<0){k=i+a&65535}else{k=i-(i<<16>>16<a<<16>>16?0:a)&65535}i=f+1|0;if((i|0)<(g|0)){f=i;h=j;d=k}else{break}}b[565470]=k;b[565469]=j;b[590603]=j;b[590604]=k;xJ();return}function xE(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;b[565990]=b[565464]|0;b[565474]=(b[565474]|0)+16&65535;L9368:while(1){a=b[565991]|0;if(a<<16>>16==-1){d=b[565988]|0;if(d<<16>>16==0){b[565988]=2;b[565989]=0;e=2}else{e=d}d=b[565474]|0;f=e;do{if(d<<16>>16==0){g=6721;break L9368}h=b[565989]<<1;b[565989]=h;i=b[565990]|0;if(i<<16>>16<0){j=h|1;b[565989]=j;k=j}else{k=h}b[565990]=i<<1;d=d-1&65535;b[565474]=d;f=f-1&65535;b[565988]=f;}while(f<<16>>16!=0);b[565991]=k;l=k}else{l=a}f=l&65535;if((f|0)==0){d=b[565988]|0;if(d<<16>>16==0){b[565988]=9;b[565989]=0;m=9}else{m=d}d=b[565474]|0;i=m;do{if(d<<16>>16==0){g=6731;break L9368}h=b[565989]<<1;b[565989]=h;j=b[565990]|0;if(j<<16>>16<0){n=h|1;b[565989]=n;o=n}else{o=h}b[565990]=j<<1;d=d-1&65535;b[565474]=d;i=i-1&65535;b[565988]=i;}while(i<<16>>16!=0);b[565473]=o}else if((f|0)==1){b[565473]=(b[565473]|0)+1&65535}else if((f|0)==2){i=b[565988]|0;if(i<<16>>16==0){b[565988]=1;b[565989]=0;p=1}else{p=i}i=b[565474]|0;d=p;do{if(i<<16>>16==0){g=6741;break L9368}a=b[565989]<<1;b[565989]=a;j=b[565990]|0;if(j<<16>>16<0){h=a|1;b[565989]=h;q=h}else{q=a}b[565990]=j<<1;i=i-1&65535;b[565474]=i;d=d-1&65535;b[565988]=d;}while(d<<16>>16!=0);b[565473]=(q+2&65535)+(b[565473]|0)&65535}else if((f|0)==3){d=b[565988]|0;if(d<<16>>16==0){b[565988]=4;b[565989]=0;r=4}else{r=d}d=b[565474]|0;i=r;do{if(d<<16>>16==0){g=6750;break L9368}j=b[565989]<<1;b[565989]=j;a=b[565990]|0;if(a<<16>>16<0){h=j|1;b[565989]=h;s=h}else{s=j}b[565990]=a<<1;d=d-1&65535;b[565474]=d;i=i-1&65535;b[565988]=i;}while(i<<16>>16!=0);b[565473]=(s+4&65535)+(b[565473]|0)&65535}b[565991]=-1;i=b[565473]|0;d=b[565475]|0;b[565475]=d+1&65535;b[1130952+((d&65535)<<1)>>1]=i;i=(b[565471]|0)-1&65535;b[565471]=i;if(i<<16>>16==0){g=6756;break}}if((g|0)==6721){b[565465]=192;return}else if((g|0)==6756){b[565475]=0;b[565473]=0;b[565993]=0;c[201850]=722;if((b[565474]|0)==0){return}xF();return}else if((g|0)==6731){b[565465]=192;return}else if((g|0)==6741){b[565465]=192;return}else if((g|0)==6750){b[565465]=192;return}}function xF(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=b[565474]|0;if(d<<16>>16==0){b[565990]=b[565464]|0;b[565474]=16;f=16}else{f=d}do{if((b[565993]|0)==0){d=b[565988]|0;if(d<<16>>16==0){b[565988]=1;b[565989]=0;g=f;h=1}else{g=f;h=d}while(1){if(g<<16>>16==0){i=6771;break}d=b[565989]<<1;b[565989]=d;j=b[565990]|0;if(j<<16>>16<0){k=d|1;b[565989]=k;l=k}else{l=d}b[565990]=j<<1;j=g-1&65535;b[565474]=j;d=h-1&65535;b[565988]=d;if(d<<16>>16==0){m=l;break}else{g=j;h=d}}if((i|0)==6771){b[565465]=192;m=b[565989]|0}if(m<<16>>16==0){a[1131984]=2;b[565993]=4;break}else{a[1131984]=3;b[565993]=8;break}}}while(0);L9453:do{m=b[565988]|0;if(m<<16>>16==0){b[565988]=3;b[565989]=0;n=3}else{n=m}m=b[565474]|0;h=n;do{if(m<<16>>16==0){i=6782;break L9453}g=b[565989]<<1;b[565989]=g;l=b[565990]|0;if(l<<16>>16<0){f=g|1;b[565989]=f;o=f}else{o=g}b[565990]=l<<1;m=m-1&65535;b[565474]=m;h=h-1&65535;b[565988]=h;}while(h<<16>>16!=0);h=o+1&65535;b[565989]=h;a[1131990+(e[565475]|0)|0]=h&255;b[1131998+(e[565475]<<1)>>1]=b[565473]|0;b[565475]=(b[565475]|0)+1&65535;b[565473]=(e[565473]|0)+(1<<e[565989])&65535;h=(b[565993]|0)-1&65535;b[565993]=h;}while(h<<16>>16!=0);if((i|0)==6782){b[565465]=192;return}i=b[565474]|0;b[565994]=-1;b[566007]=0;c[201850]=3718;if(i<<16>>16==0){return}xH();return}function xG(){b[565465]=132;c[201850]=1086;return}function xH(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;f=b[565474]|0;do{if(f<<16>>16==0){if((b[565465]&64)!=0){b[565990]=b[565464]|0;b[565474]=16;g=16;break}b[565465]=192;return}else{g=f}}while(0);f=b[566007]|0;do{if((f<<16>>16|0)==1){h=b[565988]|0;if(h<<16>>16==0){b[565988]=1;b[565989]=0;i=g;j=1}else{i=g;j=h}while(1){if(i<<16>>16==0){break}h=b[565989]<<1;b[565989]=h;k=b[565990]|0;if(k<<16>>16<0){l=h|1;b[565989]=l;m=l}else{m=h}b[565990]=k<<1;n=i-1&65535;b[565474]=n;k=j-1&65535;b[565988]=k;if(k<<16>>16==0){o=6806;break}else{i=n;j=k}}if((o|0)==6806){k=m<<16>>16==0?8:12;a[1132016]=k;b[566007]=2;p=n;q=k;o=6809;break}b[565465]=192;return}else if((f<<16>>16|0)==2){k=b[565988]|0;if(k<<16>>16!=0){r=g;s=k;break}p=g;q=a[1132016]|0;o=6809}else{k=b[565994]|0;h=b[565988]|0;l=h<<16>>16==0;do{if(k<<16>>16==-1){if(l){t=d[1131984]|0;b[565988]=t;b[565989]=0;u=g;v=t}else{u=g;v=h}while(1){if(u<<16>>16==0){break}t=b[565989]<<1;b[565989]=t;w=b[565990]|0;if(w<<16>>16<0){x=t|1;b[565989]=x;y=x}else{y=t}b[565990]=w<<1;z=u-1&65535;b[565474]=z;w=v-1&65535;b[565988]=w;if(w<<16>>16==0){o=6826;break}else{u=z;v=w}}if((o|0)==6826){b[565994]=y;A=z;B=y;o=6828;break}b[565465]=192;return}else{if(l){A=g;B=k;o=6828}else{C=h;D=g;E=k}}}while(0);if((o|0)==6828){k=d[1131990+(B&65535)|0]|0;b[565988]=k;b[565989]=0;C=k;D=A;E=B}k=D;h=C;do{if(k<<16>>16==0){o=6831;break}l=b[565989]<<1;b[565989]=l;w=b[565990]|0;if(w<<16>>16<0){t=l|1;b[565989]=t;F=t}else{F=l}b[565990]=w<<1;k=k-1&65535;b[565474]=k;h=h-1&65535;b[565988]=h;}while(h<<16>>16!=0);if((o|0)==6831){b[565465]=192;return}h=b[1130952+((e[1131998+((E&65535)<<1)>>1]|0)+(F&65535)<<1)>>1]|0;b[565473]=h;b[565994]=-1;do{if((h&65535)<256){k=(b[565472]|0)-1&65535;b[565472]=k;if(k<<16>>16!=0){G=h;break}c[201850]=822;G=h}else{k=h+32514&65535;b[565473]=k;b[566007]=f+1&65535;G=k}}while(0);b[565465]=128;b[565464]=G;return}}while(0);if((o|0)==6809){G=q&255;b[565988]=G;b[565989]=0;r=p;s=G}do{if(r<<16>>16==0){o=6811;break}G=b[565989]<<1;b[565989]=G;p=b[565990]|0;if(p<<16>>16<0){q=G|1;b[565989]=q;H=q}else{H=G}b[565990]=p<<1;r=r-1&65535;b[565474]=r;s=s-1&65535;b[565988]=s;}while(s<<16>>16!=0);if((o|0)==6811){b[565465]=192;return}b[566007]=0;o=(b[565472]|0)-1&65535;b[565472]=o;if(o<<16>>16==0){c[201850]=822}b[565465]=128;b[565464]=H;return}function xI(){var a=0,d=0;a=b[565466]|0;d=a+1&65535;b[565466]=d;b[565464]=b[162136+((a&65535)<<1)>>1]|0;if(d<<16>>16!=1024){return}c[201850]=822;return}function xJ(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;a=b[590609]|0;do{if((b[590610]|0)==0){d=a+1&65535;b[590609]=d;b[590610]=d;e=b[566022]|0;b[590603]=e;f=b[566023]|0;b[590604]=f;if(d<<16>>16<=0){g=d;break}h=(b[590601]<<1)+946&1022;i=b[162136+(h<<1)>>1]|0;j=b[162136+((h|1)<<1)>>1]|0;h=b[565467]|0;k=b[565468]|0;l=d<<16>>16;m=j&1;n=0;o=e;e=f;while(1){f=(o&255)+j&65535;p=((e&255)+i&65535)+((o&1)==0?0:m)&65535;if(f<<16>>16<0){q=f+h&65535}else{q=f-(f<<16>>16<h<<16>>16?0:h)&65535}if(p<<16>>16<0){r=p+k&65535}else{r=p-(p<<16>>16<k<<16>>16?0:k)&65535}p=n+1|0;if((p|0)<(l|0)){n=p;o=q;e=r}else{break}}b[565470]=r;b[565469]=q;b[590603]=q;b[590604]=r;g=d}else{g=a}}while(0);do{if(g<<16>>16>(b[590606]|0)){a=(b[590601]|0)+1&65535;b[590601]=a;r=(b[590611]|0)-1&65535;b[590611]=r;q=b[590605]|0;b[590609]=q;b[590610]=q;e=b[566022]|0;b[590603]=e;o=b[566023]|0;b[590604]=o;if(q<<16>>16<=0){s=r;break}n=(a<<16>>16<<1)+946&1022;a=b[162136+(n<<1)>>1]|0;l=b[162136+((n|1)<<1)>>1]|0;n=b[565467]|0;k=b[565468]|0;h=q<<16>>16;q=l&1;m=0;i=e;e=o;while(1){o=(i&255)+l&65535;j=((e&255)+a&65535)+((i&1)==0?0:q)&65535;if(o<<16>>16<0){t=o+n&65535}else{t=o-(o<<16>>16<n<<16>>16?0:n)&65535}if(j<<16>>16<0){u=j+k&65535}else{u=j-(j<<16>>16<k<<16>>16?0:k)&65535}j=m+1|0;if((j|0)<(h|0)){m=j;i=t;e=u}else{break}}b[565470]=u;b[565469]=t;b[590603]=t;b[590604]=u;s=r}else{s=b[590611]|0}}while(0);if(s<<16>>16==0){b[565464]=-1;v=1372;b[565465]=128;c[201850]=v;return}else{s=b[590603]|0;u=((ab(b[590604]<<1&510,b[565467]|0)|0)+(s<<1&510)&65535)<<16>>16>>>1&65535;b[565464]=u;c[201850]=822;b[590600]=u;v=4118;b[565465]=128;c[201850]=v;return}}function xK(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;b[590603]=b[566022]|0;a=b[566023]|0;b[590604]=a;b[590609]=1;b[590602]=0;if((b[590606]|0)>1){d=1;e=a}else{c[201850]=252;return}while(1){b[590604]=e-1&65535;b[590611]=6;b[590601]=5;a=d;f=5;g=6;while(1){b[590610]=a;if(a<<16>>16==0){h=f;i=g;j=0}else{k=f;l=a;while(1){m=b[590603]|0;n=(m&1)==0;o=k<<16>>16;p=b[162104+((n?o:o+8|0)<<1)>>1]|0;b[565470]=p;q=b[162088+(o<<1)>>1]|0;b[565469]=q;o=b[590604]&255;if(n){r=o}else{r=o+(q&1)&65535}o=q+(m&255)&65535;b[565469]=o;n=r+p&65535;b[565470]=n;b[590603]=o;b[590604]=n;p=b[565468]|0;do{if(n<<16>>16>-1&n<<16>>16<p<<16>>16){s=b[565467]|0;if(!(o<<16>>16>-1&o<<16>>16<s<<16>>16)){t=l;u=k;break}v=q+m&65535;w=v&255;x=((ab(s,n<<1&510)|0)+(o<<1&510)&65535)<<16>>16>>>1&65535;b[565464]=x;c[201850]=822;b[590600]=x;y=x<<16>>16;x=1148432+(y<<1)|0;if((b[x>>1]|0)>=128){t=l;u=k;break}if((b[1132048+(y<<1)>>1]|0)>=64){t=l;u=k;break}z=n&255;if((v&1)==0){v=255;A=6;while(1){B=A<<16>>16;C=b[162104+(B<<1)>>1]|0;D=b[162088+(B<<1)>>1]|0;B=D+w&65535;b[565469]=B;E=C+z&65535;b[565470]=E;C=((ab(E<<1&510,s)|0)+((D+o&65535)<<1&510)&65535)<<16>>16>>>1&65535;b[565464]=C;do{if(E<<16>>16>-1&E<<16>>16<p<<16>>16){if(!(B<<16>>16>-1&B<<16>>16<s<<16>>16)){F=v;break}D=C<<16>>16;G=b[1164816+(D<<1)>>1]|0;if((b[1132048+(D<<1)>>1]|0)<128){H=G}else{if(G<<16>>16==0){H=0}else{F=v;break}}F=H<<16>>16<v<<16>>16?H:v}else{F=v}}while(0);C=A-1&65535;if(C<<16>>16==0){I=F;break}else{v=F;A=C}}}else{A=255;v=6;while(1){C=v<<16>>16;B=b[162104+(C+8<<1)>>1]|0;E=b[162088+(C<<1)>>1]|0;C=E+w&65535;b[565469]=C;G=(B+z&65535)+(E&1)&65535;b[565470]=G;B=((ab(G<<1&510,s)|0)+((E+o&65535)<<1&510)&65535)<<16>>16>>>1&65535;b[565464]=B;do{if(G<<16>>16>-1&G<<16>>16<p<<16>>16){if(!(C<<16>>16>-1&C<<16>>16<s<<16>>16)){J=A;break}E=B<<16>>16;D=b[1164816+(E<<1)>>1]|0;if((b[1132048+(E<<1)>>1]|0)<128){K=D}else{if(D<<16>>16==0){K=0}else{J=A;break}}J=K<<16>>16<A<<16>>16?K:A}else{J=A}}while(0);B=v-1&65535;if(B<<16>>16==0){I=J;break}else{A=J;v=B}}}c[201850]=822;if(I<<16>>16==255){t=l;u=k;break}b[1164816+(y<<1)>>1]=(b[x>>1]|0)+I&65535;t=b[590610]|0;u=b[590601]|0}else{t=l;u=k}}while(0);p=t-1&65535;b[590610]=p;if(p<<16>>16==0){break}else{k=u;l=p}}h=u;i=b[590611]|0;j=b[590609]|0}l=h-1&65535;k=l<<16>>16==0?6:l;b[590601]=k;l=i-1&65535;b[590611]=l;if(l<<16>>16==0){break}else{a=j;f=k;g=l}}g=b[590606]|0;f=j+1&65535;b[590609]=f;if(f<<16>>16>=g<<16>>16){break}d=f;e=b[590604]|0}c[201850]=252;return}function xL(){b[1132048+(b[590600]<<1)>>1]=b[565464]&255;b[565465]=132;c[201850]=3546;return}function xM(){var a=0,c=0,d=0,e=0,f=0,g=0,h=0;b[1148432+(b[590600]<<1)>>1]=b[565464]&255;a=b[590600]|0;do{if((b[590609]|0)==1){if((b[1132048+(a<<1)>>1]&1)==0){b[1164816+(a<<1)>>1]=b[1148432+(a<<1)>>1]|0;break}else{b[1164816+(a<<1)>>1]=255;break}}else{b[1164816+(a<<1)>>1]=255}}while(0);a=(((b[590601]|0)+2&65535)<<16>>16<<1)+946&1022;c=b[162136+(a<<1)>>1]|0;b[565470]=c;d=b[162136+((a|1)<<1)>>1]|0;b[565469]=d;a=b[590603]|0;e=b[590604]&255;if((a&1)==0){f=e}else{f=e+(d&1)&65535}e=(a&255)+d&65535;b[565469]=e;d=f+c&65535;b[565470]=d;c=b[565467]|0;do{if(e<<16>>16<0){f=c+e&65535;b[565469]=f;g=f}else{if(e<<16>>16<c<<16>>16){g=e;break}f=e-c&65535;b[565469]=f;g=f}}while(0);c=b[565468]|0;do{if(d<<16>>16<0){e=c+d&65535;b[565470]=e;h=e}else{if(d<<16>>16<c<<16>>16){h=d;break}e=d-c&65535;b[565470]=e;h=e}}while(0);b[590603]=g;b[590604]=h;b[590610]=(b[590610]|0)-1&65535;b[565465]=128;xJ();return}function xN(){c[201850]=3592;return}function xO(){b[565464]=0;c[201850]=1396;return}function xP(){b[565464]=0;c[201850]=822;return}function xQ(){var a=0,d=0,e=0,f=0,g=0,h=0;a=b[565464]|0;d=(a&65535)>>>8;e=b[565469]|0;if((a&1)==0){f=d}else{f=(e&1)+d&65535}d=e+(a&255)&65535;b[565469]=d;a=(b[565470]|0)+f&65535;b[565470]=a;f=b[565467]|0;do{if(d<<16>>16<0){e=f+d&65535;b[565469]=e;g=e}else{if(d<<16>>16<f<<16>>16){g=d;break}e=d-f&65535;b[565469]=e;g=e}}while(0);f=b[565468]|0;do{if(a<<16>>16<0){d=f+a&65535;b[565470]=d;h=d}else{if(a<<16>>16<f<<16>>16){h=a;break}d=a-f&65535;b[565470]=d;h=d}}while(0);f=h<<16>>16;b[565464]=(f<<8|g&65535|f>>>8&255)&65535;c[201850]=2684;return}function xR(){var a=0;a=ab(b[565470]|0,b[565467]|0)|0;b[565464]=((b[565469]|0)+a&65535)<<1<<16>>16>>>1&65535;c[201850]=822;return}function xS(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;a=b[590609]|0;do{if((b[590610]|0)==0){d=a+1&65535;b[590609]=d;b[590610]=d;e=b[566022]|0;b[590603]=e;f=b[566023]|0;b[590604]=f;if(d<<16>>16<=0){g=d;break}h=(b[590601]<<1)+946&1022;i=b[162136+(h<<1)>>1]|0;j=b[162136+((h|1)<<1)>>1]|0;h=b[565467]|0;k=b[565468]|0;l=d<<16>>16;m=j&1;n=0;o=e;e=f;while(1){f=(o&255)+j&65535;p=((e&255)+i&65535)+((o&1)==0?0:m)&65535;if(f<<16>>16<0){q=f+h&65535}else{q=f-(f<<16>>16<h<<16>>16?0:h)&65535}if(p<<16>>16<0){r=p+k&65535}else{r=p-(p<<16>>16<k<<16>>16?0:k)&65535}p=n+1|0;if((p|0)<(l|0)){n=p;o=q;e=r}else{break}}b[565470]=r;b[565469]=q;b[590603]=q;b[590604]=r;g=d}else{g=a}}while(0);do{if(g<<16>>16>(b[590606]|0)){a=(b[590601]|0)+1&65535;b[590601]=a;r=(b[590611]|0)-1&65535;b[590611]=r;q=b[590605]|0;b[590609]=q;b[590610]=q;e=b[566022]|0;b[590603]=e;o=b[566023]|0;b[590604]=o;if(q<<16>>16<=0){s=r;break}n=(a<<16>>16<<1)+946&1022;a=b[162136+(n<<1)>>1]|0;l=b[162136+((n|1)<<1)>>1]|0;n=b[565467]|0;k=b[565468]|0;h=q<<16>>16;q=l&1;m=0;i=e;e=o;while(1){o=(i&255)+l&65535;j=((e&255)+a&65535)+((i&1)==0?0:q)&65535;if(o<<16>>16<0){t=o+n&65535}else{t=o-(o<<16>>16<n<<16>>16?0:n)&65535}if(j<<16>>16<0){u=j+k&65535}else{u=j-(j<<16>>16<k<<16>>16?0:k)&65535}j=m+1|0;if((j|0)<(h|0)){m=j;i=t;e=u}else{break}}b[565470]=u;b[565469]=t;b[590603]=t;b[590604]=u;s=r}else{s=b[590611]|0}}while(0);if(s<<16>>16==0){b[565464]=-1;v=822;b[565465]=128;c[201850]=v;return}else{s=b[590603]|0;u=((ab(b[590604]<<1&510,b[565467]|0)|0)+(s<<1&510)&65535)<<16>>16>>>1&65535;b[565464]=u;c[201850]=822;b[590600]=u;v=2208;b[565465]=128;c[201850]=v;return}}function xT(){var a=0,d=0,e=0,f=0,g=0,h=0,i=0;b[565464]=b[1164816+(b[590600]<<1)>>1]|0;a=(((b[590601]|0)+2&65535)<<16>>16<<1)+946&1022;d=b[162136+(a<<1)>>1]|0;b[565470]=d;e=b[162136+((a|1)<<1)>>1]|0;b[565469]=e;a=b[590603]|0;f=b[590604]&255;if((a&1)==0){g=f}else{g=f+(e&1)&65535}f=(a&255)+e&65535;b[565469]=f;e=g+d&65535;b[565470]=e;d=b[565467]|0;do{if(f<<16>>16<0){g=d+f&65535;b[565469]=g;h=g}else{if(f<<16>>16<d<<16>>16){h=f;break}g=f-d&65535;b[565469]=g;h=g}}while(0);d=b[565468]|0;do{if(e<<16>>16<0){f=d+e&65535;b[565470]=f;i=f}else{if(e<<16>>16<d<<16>>16){i=e;break}f=e-d&65535;b[565470]=f;i=f}}while(0);b[590603]=h;b[590604]=i;b[590610]=(b[590610]|0)-1&65535;b[565465]=132;c[201850]=3786;return}function xU(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=b[566019]|0;do{if((f&65535)<8){g=b[565464]&255;b[566019]=f+1&65535;a[1132022+(f&65535)|0]=g;g=(e[565464]|0)>>>8&255;h=b[566019]|0;b[566019]=h+1&65535;a[1132022+(h&65535)|0]=g;if((b[566019]|0)!=8){return}g=0;h=a[1132030]|0;i=a[1132031]|0;j=a[1132032]|0;k=a[1132033]|0;l=a[1132034]|0;m=a[1132035]|0;n=a[1132036]|0;o=a[1132037]|0;do{p=1132022+g|0;q=h<<1;a[1132030]=q;h=a[p]&1|q;a[1132030]=h;q=i<<1;a[1132031]=q;i=(d[p]|0)>>>1&1|q;a[1132031]=i;q=j<<1;a[1132032]=q;j=(d[p]|0)>>>2&1|q;a[1132032]=j;q=k<<1;a[1132033]=q;k=(d[p]|0)>>>3&1|q;a[1132033]=k;q=l<<1;a[1132034]=q;l=(d[p]|0)>>>4&1|q;a[1132034]=l;q=m<<1;a[1132035]=q;m=(d[p]|0)>>>5&1|q;a[1132035]=m;q=n<<1;a[1132036]=q;n=(d[p]|0)>>>6&1|q;a[1132036]=n;q=o<<1;a[1132037]=q;o=(d[p]|0)>>>7|q;a[1132037]=o;g=g+1|0;}while((g|0)<8);b[566020]=0;b[566021]=(b[566021]|0)-1&65535;r=0}else{if(f<<16>>16!=8){return}g=b[566020]|0;if(g<<16>>16!=8){r=g;break}if((b[566021]|0)==0){b[565464]=128;b[565465]=132;c[201850]=1702}b[566019]=0;return}}while(0);f=r+1&65535;b[566020]=f;g=d[1132030+(r&65535)|0]|0;b[565464]=g;b[566020]=r+2&65535;b[565464]=d[1132030+(f&65535)|0]<<8|g;return}function xV(a,c,d){a=a|0;c=c|0;d=d|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;f=a&65535;g=f&32767;h=a>>>15;a=h&65535;i=a<<16>>16;j=a<<16>>16<0;k=(i&16384|0)==0;do{if(j){if(k){l=0;break}else{m=16384;n=0}while(1){o=n+1&65535;p=m>>>1<<16>>16;if((p&i|0)==0|(p|0)==0){q=o;r=7007;break}else{m=p;n=o}}}else{if(k){s=16384;t=0}else{l=0;break}while(1){o=t+1&65535;p=s>>>1<<16>>16;if((p&i|0)!=0|(p|0)==0){q=o;r=7007;break}else{s=p;t=o}}}}while(0);do{if((r|0)==7007){t=q<<16>>16;if(q<<16>>16<=0){l=q;break}s=ab(b[165240+(t+33<<1)>>1]|0,h<<1&65535)|0;b[c>>1]=s;i=g&65535;if(q<<16>>16<15){b[c>>1]=((ab(e[165240+(64-t<<1)>>1]|0,i)|0)>>>15)+(s&65535)&65535;u=q;b[d>>1]=u;return}t=(i&16384|0)==0;do{if(j){if(t){v=q;break}else{w=16384;x=q}while(1){k=x+1&65535;n=w>>>1<<16>>16;if((n&i|0)==0|(n|0)==0){v=k;break}else{w=n;x=k}}}else{if(t){y=16384;z=q}else{v=q;break}while(1){k=z+1&65535;n=y>>>1<<16>>16;if((n&i|0)!=0|(n|0)==0){v=k;break}else{y=n;z=k}}}}while(0);if(v<<16>>16>15){b[c>>1]=ab(f<<1,b[165240+((v<<16>>16)+18<<1)>>1]|0)|0;u=v;b[d>>1]=u;return}else{b[c>>1]=s+g&65535;u=v;b[d>>1]=u;return}}}while(0);b[c>>1]=a;u=l;b[d>>1]=u;return}function xW(){var a=0,c=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;a=b[565464]|0;c=a&255;b[590605]=c;d=(a&65535)>>>8;b[590606]=d;if(c<<16>>16==0){b[590605]=1;e=1}else{e=c}c=b[590608]|0;if(c<<16>>16<e<<16>>16){f=e}else{e=c+1&65535;b[590605]=e;f=e}if(d<<16>>16>c<<16>>16){b[590608]=d}b[590609]=f;b[590610]=f;b[590611]=6;b[590601]=0;d=b[566022]|0;b[590603]=d;c=b[566023]|0;b[590604]=c;if(f<<16>>16<=0){xS();return}e=b[565467]|0;a=b[565468]|0;g=f<<16>>16;f=0;h=d;d=c;while(1){c=h&255;i=(d&255)-1&65535;j=c-(c<<16>>16<e<<16>>16?0:e)&65535;if(i<<16>>16<0){k=i+a&65535}else{k=i-(i<<16>>16<a<<16>>16?0:a)&65535}i=f+1|0;if((i|0)<(g|0)){f=i;h=j;d=k}else{break}}b[565470]=k;b[565469]=j;b[590603]=j;b[590604]=k;xS();return}function xX(a){a=a|0;var c=0,d=0,e=0,f=0,g=0;c=a<<16>>16;if(a<<16>>16>=0){d=c>>8;e=b[164184+(d<<1)>>1]|0;f=((ab(b[164184+(d+64<<1)>>1]|0,b[164728+((c&255)<<1)>>1]|0)|0)>>15)+e|0;g=(f|0)>32767?32767:f&65535;return g|0}if(a<<16>>16==-32768){g=0;return g|0}else{return-(xX(-a&65535)|0)&65535|0}return 0}function xY(){var b=0,d=0,e=0,f=0;c[199758]=~~(+g[201849]*(1.0/((a[799146]|0)==0?60.0:50.0)/+(c[199743]|0)));a[101712]=0;X2(1106800,0,2044);c[276725]=1106800;c[276726]=1106800;b=c[199766]|0;c[276738]=b;c[276739]=a[101720]|0?2:0;c[276740]=c[199764];d=c[199762]|0;c[276741]=d;c[276742]=c[199760];c[276812]=-1;c[276744]=-1;if(d>>>0>32){c[276741]=32}X2(b|0,0,768);a[(c[276738]|0)+59|0]=0;b=0;do{d=b&127;e=c[276741]|0;if(d>>>0>63){if(e>>>0>1){f=(d>>>0)%(e>>>0)|0}else{f=b&1}c[1107284+(b<<2)>>2]=(c[276742]|0)+(f<<16)}else{c[1107284+(b<<2)>>2]=(c[276742]|0)+((((d>>>0)%(e<<1>>>0)|0)<<16)+2097152)}b=b+1|0;}while((b|0)<256);b=c[276740]|0;c[276817]=b;c[276933]=b;f=c[276739]|0;e=b+((1%(f>>>0)|0)<<16)|0;c[276818]=e;c[276934]=e;e=b+((2%(f>>>0)|0)<<16)|0;c[276819]=e;c[276935]=e;e=b+((3%(f>>>0)|0)<<16)|0;c[276820]=e;c[276936]=e;a[1106909]=1;c[277078]=(c[276738]|0)+256;yk();return}function xZ(){c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function x_(){var b=0,d=0;b=c[276715]|0;d=b&65520;if(!((c[276722]|0)==(d|0)&(a[1108308]|0)!=0)){c[276723]=0;c[276722]=d;a[1108308]=1}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=b+1;return}function x$(){var a=0;a=c[276718]|0;if((a&4096|0)!=0){c[276700]=c[c[276726]>>2];c[276718]=a&-4865;c[276726]=1106800}c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function x0(){var a=0,b=0;a=c[276718]|0;if((a&4096|0)==0){b=1106804}else{c[276701]=c[c[276726]>>2];c[276718]=a&-4865;c[276726]=1106800;b=1106800}c[276725]=b;c[276715]=(c[276715]|0)+1;return}function x1(){var a=0,b=0;a=c[276718]|0;if((a&4096|0)==0){b=1106808}else{c[276702]=c[c[276726]>>2];c[276718]=a&-4865;c[276726]=1106800;b=1106800}c[276725]=b;c[276715]=(c[276715]|0)+1;return}function x2(){var a=0,b=0;a=c[276718]|0;if((a&4096|0)==0){b=1106812}else{c[276703]=c[c[276726]>>2];c[276718]=a&-4865;c[276726]=1106800;b=1106800}c[276725]=b;c[276715]=(c[276715]|0)+1;return}function x3(){var a=0,b=0;a=c[276718]|0;if((a&4096|0)==0){b=1106816}else{c[276704]=c[c[276726]>>2];c[276718]=a&-4865;c[276726]=1106800;b=1106800}c[276725]=b;c[276715]=(c[276715]|0)+1;return}function x4(){var a=0,b=0;a=c[276718]|0;if((a&4096|0)==0){b=1106820}else{c[276705]=c[c[276726]>>2];c[276718]=a&-4865;c[276726]=1106800;b=1106800}c[276725]=b;c[276715]=(c[276715]|0)+1;return}function x5(){var b=0,d=0,e=0;b=c[276718]&-33;c[276718]=b;c[277207]=0;c[277208]=0;if((a[(c[276738]|0)+55|0]|0)<0){d=b}else{e=b|32768;c[276718]=e;d=e}c[276717]=0;a[1106909]=1;c[276718]=d&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function x6(){var b=0,d=0;b=c[276726]|0;c[276731]=c[b>>2]&1;d=(c[b>>2]|0)>>>1&32767;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=d;c[276729]=d;c[276730]=d;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function x7(){var b=0,d=0;b=c[c[276726]>>2]|0;d=(b<<1)+(c[276731]|0)&65535;c[276731]=b>>>15&1;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=d;c[276729]=d;c[276730]=d;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function x8(){var b=0,d=0;b=a[1106909|0]|0;d=(c[276715]|0)+1|0;c[276715]=d;a[1106909|0]=a[(c[276816]|0)+(d&65535)|0]|0;c[276715]=d+(b<<24>>24);return}function x9(){var b=0,d=0,e=0,f=0,g=0,h=0;b=a[1106909|0]|0;d=c[276715]|0;e=d+1|0;c[276715]=e;a[1106909|0]=a[(c[276816]|0)+(e&65535)|0]|0;f=c[276732]|0;if((f|0)>32767){g=1}else{g=(f|0)<-32768|0}if(((c[276729]|0)>>>15&1|0)==(g|0)){h=e+(b<<24>>24)|0;c[276715]=h;return}else{h=d+2|0;c[276715]=h;return}}function ya(){var b=0,d=0,e=0,f=0,g=0,h=0;b=a[1106909|0]|0;d=c[276715]|0;e=d+1|0;c[276715]=e;a[1106909|0]=a[(c[276816]|0)+(e&65535)|0]|0;f=c[276732]|0;if((f|0)>32767){g=1}else{g=(f|0)<-32768|0}if(((c[276729]|0)>>>15&1|0)==(g|0)){h=d+2|0;c[276715]=h;return}else{h=e+(b<<24>>24)|0;c[276715]=h;return}}function yb(){var b=0,d=0;b=a[1106909]|0;d=(c[276715]|0)+1|0;c[276715]=d;a[1106909]=a[(c[276816]|0)+(d&65535)|0]|0;c[276715]=((c[276730]&65535|0)==0?1:b<<24>>24)+d;return}function yc(){var b=0,d=0,e=0,f=0;b=a[1106909]|0;d=c[276715]|0;e=d+1|0;c[276715]=e;a[1106909]=a[(c[276816]|0)+(e&65535)|0]|0;if((c[276730]&65535|0)==0){f=e+(b<<24>>24)|0;c[276715]=f;return}else{f=d+2|0;c[276715]=f;return}}function yd(){var b=0,d=0,e=0,f=0;b=a[1106909]|0;d=c[276715]|0;e=d+1|0;c[276715]=e;a[1106909]=a[(c[276816]|0)+(e&65535)|0]|0;if((c[276729]&32768|0)==0){f=e+(b<<24>>24)|0;c[276715]=f;return}else{f=d+2|0;c[276715]=f;return}}function ye(){var b=0,d=0,e=0,f=0;b=a[1106909]|0;d=c[276715]|0;e=d+1|0;c[276715]=e;a[1106909]=a[(c[276816]|0)+(e&65535)|0]|0;if((c[276729]&32768|0)==0){f=d+2|0;c[276715]=f;return}else{f=e+(b<<24>>24)|0;c[276715]=f;return}}function yf(){var b=0,d=0,e=0,f=0;b=a[1106909]|0;d=c[276715]|0;e=d+1|0;c[276715]=e;a[1106909]=a[(c[276816]|0)+(e&65535)|0]|0;if((c[276731]&1|0)==0){f=e+(b<<24>>24)|0;c[276715]=f;return}else{f=d+2|0;c[276715]=f;return}}function yg(){var b=0,d=0,e=0,f=0;b=a[1106909]|0;d=c[276715]|0;e=d+1|0;c[276715]=e;a[1106909]=a[(c[276816]|0)+(e&65535)|0]|0;if((c[276731]&1|0)==0){f=d+2|0;c[276715]=f;return}else{f=e+(b<<24>>24)|0;c[276715]=f;return}}function yh(){var b=0,d=0;b=a[1106909|0]|0;d=(c[276715]|0)+1|0;c[276715]=d;a[1106909|0]=a[(c[276816]|0)+(d&65535)|0]|0;c[276715]=(((c[276732]|0)+32768|0)>>>0>65535?1:b<<24>>24)+d;return}function yi(){var b=0,d=0,e=0,f=0;b=a[1106909|0]|0;d=c[276715]|0;e=d+1|0;c[276715]=e;a[1106909|0]=a[(c[276816]|0)+(e&65535)|0]|0;if(((c[276732]|0)+32768|0)>>>0>65535){f=e+(b<<24>>24)|0;c[276715]=f;return}else{f=d+2|0;c[276715]=f;return}}function yj(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=c[199758]<<(a[(c[263195]|0)+12345|0]&1);yk();do{if((a[1108308]|0)==0){f=7147}else{g=c[276715]|0;h=c[276722]|0;if(!(g>>>0>=h>>>0&g>>>0<(h+512|0)>>>0)){f=7147;break}i=c[276718]|0;f=7152}}while(0);do{if((f|0)==7147){h=c[276719]|0;if(h>>>0>95){j=h>>>0<112|0}else{j=0}g=c[276738]|0;k=a[g+58|0]|0;if((h-112|0)>>>0<4){l=((k&255)>>>3&1^1)&255}else{l=0}m=c[276718]|0;if((j|h>>>0>115|((k&255)>>>4&1^1)&255|l|0)==0){i=m;f=7152;break}c[276718]=m&-33;n=0;o=g}}while(0);if((f|0)==7152){f=i&-32769;c[276718]=f;c[277207]=e;a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;L9934:do{if((i&32|0)!=0){c[277207]=e-1;if((e|0)==0){break}else{p=f}do{l=d[1106909]|0;a[1106909]=a[(c[276816]|0)+(c[276715]&65535)|0]|0;fz[c[10968+((l|p&768)<<2)>>2]&8191]();p=c[276718]|0;if((p&32|0)==0){break L9934}l=c[277207]|0;c[277207]=l-1;}while((l|0)!=0)}}while(0);n=0;o=c[276738]|0}while(1){p=1106800+(n<<2)|0;a[o]=c[p>>2]&255;a[o+1|0]=(c[p>>2]|0)>>>8&255;p=n+1|0;if((p|0)<16){n=p;o=o+2|0}else{break}}o=c[276718]|0;n=(c[276730]&65535|0)==0?o|2:o&-3;o=(c[276729]&32768|0)==0?n&-9:n|8;n=((c[276732]|0)+32768|0)>>>0>65535?o|16:o&-17;o=(c[276731]|0)==0?n&-5:n|4;c[276718]=o;n=c[276738]|0;a[n+48|0]=o&255;a[n+49|0]=(c[276718]|0)>>>8&255;a[n+52|0]=c[276719]&255;a[n+54|0]=c[276720]&255;a[n+60|0]=c[276721]&255;a[n+62|0]=c[276722]&255;a[n+63|0]=(c[276722]|0)>>>8&255;n=c[263195]|0;if(((d[n+12337|0]<<8|d[n+12336|0])&-32736)<<16>>16!=-32768){return}a[1393588]=a[1393588]|4;c[348398]=c[199754];c[348395]=c[348395]|2048;if((a[1393628]|0)==0){return}a[1393628]=0;b[520836]=(b[520836]|0)+1&65535;return}function yk(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;b=0;e=c[276738]|0;while(1){f=d[e]|0;g=1106800+(b<<2)|0;c[g>>2]=f;c[g>>2]=(d[e+1|0]|0)<<8|f;f=b+1|0;if((f|0)<16){b=f;e=e+2|0}else{break}}e=c[276738]|0;b=d[e+48|0]|0;c[276718]=b;c[276718]=(d[e+49|0]|0)<<8|b;f=d[e+52|0]|0;c[276719]=f;g=d[e+54|0]|0;c[276720]=g;h=a[e+60|0]&3;c[276721]=h;i=d[e+62|0]|0;c[276722]=i;c[276722]=(d[e+63|0]|0)<<8|i;c[276730]=b>>>1&1^1;c[276729]=b<<12&32768;c[276732]=b<<16&1048576;c[276731]=b>>>2&1;c[276814]=c[1107268+(h<<2)>>2];c[276815]=c[1107284+(g<<2)>>2];c[276816]=c[1107284+(f<<2)>>2];f=(d[e+56|0]|0)<<10;g=c[276740]|0;c[276745]=g+f;h=e+58|0;e=d[h]|0;b=e>>>5<<1&2|e>>>2&1;e=c[10912+(b<<2)>>2]|0;c[276811]=e;c[276810]=e;i=a[h]&3;c[276743]=i;if((b|0)==3){j=32768}else{j=ab(e>>>3<<5,c[10896+(i<<2)>>2]|0)|0}c[276813]=j;if((c[276717]&16|0)==0){k=e}else{c[276810]=256;k=256}e=c[276739]<<16;if((j+f|0)>(e|0)){c[276745]=g+(e-j)}j=c[10928+(i<<2)>>2]|0;c[2818]=j;e=c[10928+(i+5<<2)>>2]|0;c[3074]=e;c[3330]=j;c[3586]=e;do{if((i|0)==(c[276744]|0)){if((c[276812]|0)!=(k|0)|(c[277209]|0)!=0){break}return}}while(0);Hg();return}function yl(){var a=0,b=0;a=c[276718]|0;if((a&4096|0)==0){b=1106824}else{c[276706]=c[c[276726]>>2];c[276718]=a&-4865;c[276726]=1106800;b=1106800}c[276725]=b;c[276715]=(c[276715]|0)+1;return}function ym(){var a=0,b=0;a=c[276718]|0;if((a&4096|0)==0){b=1106828}else{c[276707]=c[c[276726]>>2];c[276718]=a&-4865;c[276726]=1106800;b=1106800}c[276725]=b;c[276715]=(c[276715]|0)+1;return}function yn(){var a=0,b=0;a=c[276718]|0;if((a&4096|0)==0){b=1106832}else{c[276708]=c[c[276726]>>2];c[276718]=a&-4865;c[276726]=1106800;b=1106800}c[276725]=b;c[276715]=(c[276715]|0)+1;return}function yo(){var a=0,b=0;a=c[276718]|0;if((a&4096|0)==0){b=1106836}else{c[276709]=c[c[276726]>>2];c[276718]=a&-4865;c[276726]=1106800;b=1106800}c[276725]=b;c[276715]=(c[276715]|0)+1;return}function yp(){var a=0,b=0;a=c[276718]|0;if((a&4096|0)==0){b=1106840}else{c[276710]=c[c[276726]>>2];c[276718]=a&-4865;c[276726]=1106800;b=1106800}c[276725]=b;c[276715]=(c[276715]|0)+1;return}function yq(){var a=0,b=0;a=c[276718]|0;if((a&4096|0)==0){b=1106844}else{c[276711]=c[c[276726]>>2];c[276718]=a&-4865;c[276726]=1106800;b=1106800}c[276725]=b;c[276715]=(c[276715]|0)+1;return}function yr(){var a=0,b=0;a=c[276718]|0;if((a&4096|0)==0){b=1106848}else{c[276712]=c[c[276726]>>2];c[276718]=a&-4865;c[276726]=1106800;b=1106800}c[276725]=b;c[276715]=(c[276715]|0)+1;return}function ys(){var a=0,b=0;a=c[276718]|0;if((a&4096|0)==0){b=1106852}else{c[276713]=c[c[276726]>>2];c[276718]=a&-4865;c[276726]=1106800;b=1106800}c[276725]=b;c[276715]=(c[276715]|0)+1;return}function yt(){var a=0;a=c[276718]|0;if((a&4096|0)==0){c[276725]=1106860;c[276715]=(c[276715]|0)+1;return}else{c[276715]=c[c[276726]>>2];c[276718]=a&-4865;c[276726]=1106800;c[276725]=1106800;return}}function yu(){c[276718]=c[276718]|4096;c[276725]=1106800;c[276726]=1106800;c[276715]=(c[276715]|0)+1;return}function yv(){c[276718]=c[276718]|4096;c[276725]=1106804;c[276726]=1106804;c[276715]=(c[276715]|0)+1;return}function yw(){c[276718]=c[276718]|4096;c[276725]=1106808;c[276726]=1106808;c[276715]=(c[276715]|0)+1;return}function yx(){c[276718]=c[276718]|4096;c[276725]=1106812;c[276726]=1106812;c[276715]=(c[276715]|0)+1;return}function yy(){c[276718]=c[276718]|4096;c[276725]=1106816;c[276726]=1106816;c[276715]=(c[276715]|0)+1;return}function yz(){c[276718]=c[276718]|4096;c[276725]=1106820;c[276726]=1106820;c[276715]=(c[276715]|0)+1;return}function yA(){c[276718]=c[276718]|4096;c[276725]=1106824;c[276726]=1106824;c[276715]=(c[276715]|0)+1;return}function yB(){c[276718]=c[276718]|4096;c[276725]=1106828;c[276726]=1106828;c[276715]=(c[276715]|0)+1;return}function yC(){c[276718]=c[276718]|4096;c[276725]=1106832;c[276726]=1106832;c[276715]=(c[276715]|0)+1;return}function yD(){c[276718]=c[276718]|4096;c[276725]=1106836;c[276726]=1106836;c[276715]=(c[276715]|0)+1;return}function yE(){c[276718]=c[276718]|4096;c[276725]=1106840;c[276726]=1106840;c[276715]=(c[276715]|0)+1;return}function yF(){c[276718]=c[276718]|4096;c[276725]=1106844;c[276726]=1106844;c[276715]=(c[276715]|0)+1;return}function yG(){c[276718]=c[276718]|4096;c[276725]=1106848;c[276726]=1106848;c[276715]=(c[276715]|0)+1;return}function yH(){c[276718]=c[276718]|4096;c[276725]=1106852;c[276726]=1106852;c[276715]=(c[276715]|0)+1;return}function yI(){c[276718]=c[276718]|4096;c[276725]=1106856;c[276726]=1106856;c[276715]=(c[276715]|0)+1;return}function yJ(){c[276718]=c[276718]|4096;c[276725]=1106860;c[276726]=1106860;c[276715]=(c[276715]|0)+1;return}function yK(){var a=0,b=0;a=(c[276712]|0)-1|0;c[276712]=a;c[276730]=a;c[276729]=a;if((a&65535|0)==0){b=(c[276715]|0)+1|0}else{b=c[276713]|0}c[276715]=b;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function yL(){c[276718]=c[276718]&-4353|256;c[276715]=(c[276715]|0)+1;return}function yM(){c[276718]=c[276718]&-4609|512;c[276715]=(c[276715]|0)+1;return}function yN(){c[276718]=c[276718]&-4865|768;c[276715]=(c[276715]|0)+1;return}function yO(){var b=0,d=0,e=0,f=0;b=c[276718]|0;if((b&4096|0)==0){c[276725]=1106856;d=c[276715]|0;e=d+1|0;c[276715]=e;return}else{f=c[c[276726]>>2]|0;c[276714]=f;c[276718]=b&-4865;c[276726]=1106800;c[276725]=1106800;a[1106908]=a[(c[276815]|0)+(f&65535)|0]|0;d=c[276715]|0;e=d+1|0;c[276715]=e;return}}function yP(){var b=0;b=c[276700]|0;c[276724]=b;a[(c[276814]|0)+(b&65535)|0]=c[c[276726]>>2]&255;a[(c[276814]|0)+(c[276700]&65535^1)|0]=(c[c[276726]>>2]|0)>>>8&255;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function yQ(){var b=0;b=c[276701]|0;c[276724]=b;a[(c[276814]|0)+(b&65535)|0]=c[c[276726]>>2]&255;a[(c[276814]|0)+(c[276701]&65535^1)|0]=(c[c[276726]>>2]|0)>>>8&255;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function yR(){var b=0;b=c[276702]|0;c[276724]=b;a[(c[276814]|0)+(b&65535)|0]=c[c[276726]>>2]&255;a[(c[276814]|0)+(c[276702]&65535^1)|0]=(c[c[276726]>>2]|0)>>>8&255;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function yS(){var b=0;b=c[276703]|0;c[276724]=b;a[(c[276814]|0)+(b&65535)|0]=c[c[276726]>>2]&255;a[(c[276814]|0)+(c[276703]&65535^1)|0]=(c[c[276726]>>2]|0)>>>8&255;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function yT(){var b=0;b=c[276704]|0;c[276724]=b;a[(c[276814]|0)+(b&65535)|0]=c[c[276726]>>2]&255;a[(c[276814]|0)+(c[276704]&65535^1)|0]=(c[c[276726]>>2]|0)>>>8&255;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function yU(){var b=0;b=c[276705]|0;c[276724]=b;a[(c[276814]|0)+(b&65535)|0]=c[c[276726]>>2]&255;a[(c[276814]|0)+(c[276705]&65535^1)|0]=(c[c[276726]>>2]|0)>>>8&255;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function yV(){var b=0;b=c[276706]|0;c[276724]=b;a[(c[276814]|0)+(b&65535)|0]=c[c[276726]>>2]&255;a[(c[276814]|0)+(c[276706]&65535^1)|0]=(c[c[276726]>>2]|0)>>>8&255;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function yW(){var b=0;b=c[276707]|0;c[276724]=b;a[(c[276814]|0)+(b&65535)|0]=c[c[276726]>>2]&255;a[(c[276814]|0)+(c[276707]&65535^1)|0]=(c[c[276726]>>2]|0)>>>8&255;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function yX(){var b=0;b=c[276708]|0;c[276724]=b;a[(c[276814]|0)+(b&65535)|0]=c[c[276726]>>2]&255;a[(c[276814]|0)+(c[276708]&65535^1)|0]=(c[c[276726]>>2]|0)>>>8&255;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function yY(){var b=0;b=c[276709]|0;c[276724]=b;a[(c[276814]|0)+(b&65535)|0]=c[c[276726]>>2]&255;a[(c[276814]|0)+(c[276709]&65535^1)|0]=(c[c[276726]>>2]|0)>>>8&255;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function yZ(){var b=0;b=c[276710]|0;c[276724]=b;a[(c[276814]|0)+(b&65535)|0]=c[c[276726]>>2]&255;a[(c[276814]|0)+(c[276710]&65535^1)|0]=(c[c[276726]>>2]|0)>>>8&255;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function y_(){var b=0;b=c[276711]|0;c[276724]=b;a[(c[276814]|0)+(b&65535)|0]=c[c[276726]>>2]&255;a[(c[276814]|0)+(c[276711]&65535^1)|0]=(c[c[276726]>>2]|0)>>>8&255;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function y$(){var b=0,e=0,f=0;b=c[276700]|0;c[276724]=b;e=b&65535;b=c[276814]|0;f=(d[b+(e^1)|0]|0)<<8|(d[b+e|0]|0);c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=f;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function y0(){var b=0,e=0,f=0;b=c[276701]|0;c[276724]=b;e=b&65535;b=c[276814]|0;f=(d[b+(e^1)|0]|0)<<8|(d[b+e|0]|0);c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=f;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function y1(){var b=0,e=0,f=0;b=c[276702]|0;c[276724]=b;e=b&65535;b=c[276814]|0;f=(d[b+(e^1)|0]|0)<<8|(d[b+e|0]|0);c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=f;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function y2(){var b=0,e=0,f=0;b=c[276703]|0;c[276724]=b;e=b&65535;b=c[276814]|0;f=(d[b+(e^1)|0]|0)<<8|(d[b+e|0]|0);c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=f;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function y3(){var a=0,b=0,d=0,e=0;a=c[c[276726]>>2]|0;b=c[276717]|0;if((b&4|0)==0){d=a&255}else{d=(a>>>4&15|a&240)&255}if((b&8|0)==0){e=d&255}else{e=c[276716]&240|d&15}c[276716]=e;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function y4(){var b=0,e=0,f=0;b=c[276704]|0;c[276724]=b;e=b&65535;b=c[276814]|0;f=(d[b+(e^1)|0]|0)<<8|(d[b+e|0]|0);c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=f;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function y5(){var b=0,e=0,f=0;b=c[276705]|0;c[276724]=b;e=b&65535;b=c[276814]|0;f=(d[b+(e^1)|0]|0)<<8|(d[b+e|0]|0);c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=f;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function y6(){var b=0,e=0,f=0;b=c[276706]|0;c[276724]=b;e=b&65535;b=c[276814]|0;f=(d[b+(e^1)|0]|0)<<8|(d[b+e|0]|0);c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=f;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function y7(){var b=0,e=0,f=0;b=c[276707]|0;c[276724]=b;e=b&65535;b=c[276814]|0;f=(d[b+(e^1)|0]|0)<<8|(d[b+e|0]|0);c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=f;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function y8(){var b=0,e=0,f=0;b=c[276708]|0;c[276724]=b;e=b&65535;b=c[276814]|0;f=(d[b+(e^1)|0]|0)<<8|(d[b+e|0]|0);c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=f;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function y9(){var b=0,e=0,f=0;b=c[276709]|0;c[276724]=b;e=b&65535;b=c[276814]|0;f=(d[b+(e^1)|0]|0)<<8|(d[b+e|0]|0);c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=f;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function za(){var b=0,e=0,f=0;b=c[276710]|0;c[276724]=b;e=b&65535;b=c[276814]|0;f=(d[b+(e^1)|0]|0)<<8|(d[b+e|0]|0);c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=f;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function zb(){var b=0,e=0,f=0;b=c[276711]|0;c[276724]=b;e=b&65535;b=c[276814]|0;f=(d[b+(e^1)|0]|0)<<8|(d[b+e|0]|0);c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=f;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function zc(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[276701]|0;e=c[276702]|0;c[276715]=(c[276715]|0)+1;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276701]=b+1;f=c[276717]|0;if((f&2|0)==0){g=c[276716]|0}else{h=c[276716]|0;g=((e^b)&1|0)!=0?h>>>4:h}h=g&255;do{if((f&1|0)==0){if((h&15)!=0){break}return}}while(0);f=c[1106984+((e>>>3&31)<<2)>>2]|0;g=(c[1107112+((b>>>3&31)<<2)>>2]|0)+(e<<1&14)|0;e=f+g|0;i=128>>>((b&7)>>>0);b=h&255;if((b&1|0)==0){j=(d[e]|0)&(i^255)}else{j=d[e]|0|i}a[e]=j&255;if((b&2|0)==0){b=f+(g+1)|0;a[b]=(d[b]|0)&(i^255)&255;return}else{b=f+(g+1)|0;a[b]=(d[b]|0|i)&255;return}}function zd(){var b=0,d=0;b=c[c[276726]>>2]|0;d=b<<8&65280|b>>>8&255;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=d;c[276729]=d;c[276730]=d;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function ze(){var b=0;b=~c[c[276726]>>2];c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function zf(){var b=0,d=0,e=0,f=0,g=0;b=c[276726]|0;d=c[276700]|0;e=(d&65535)+(c[b>>2]&65535)|0;c[276731]=(e|0)>65535;c[276732]=(d^32768^c[b>>2])&32768&(e^d);c[276729]=e;c[276730]=e;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)!=1106856){f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}function zg(){var b=0,d=0,e=0,f=0,g=0;b=c[276726]|0;d=c[276701]|0;e=(d&65535)+(c[b>>2]&65535)|0;c[276731]=(e|0)>65535;c[276732]=(d^32768^c[b>>2])&32768&(e^d);c[276729]=e;c[276730]=e;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)!=1106856){f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}function zh(){var b=0,d=0,e=0,f=0,g=0;b=c[276726]|0;d=c[276702]|0;e=(d&65535)+(c[b>>2]&65535)|0;c[276731]=(e|0)>65535;c[276732]=(d^32768^c[b>>2])&32768&(e^d);c[276729]=e;c[276730]=e;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)!=1106856){f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}function zi(){var b=0,d=0,e=0,f=0,g=0;b=c[276726]|0;d=c[276703]|0;e=(d&65535)+(c[b>>2]&65535)|0;c[276731]=(e|0)>65535;c[276732]=(d^32768^c[b>>2])&32768&(e^d);c[276729]=e;c[276730]=e;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)!=1106856){f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}function zj(){var b=0,d=0,e=0,f=0,g=0;b=c[276726]|0;d=c[276704]|0;e=(d&65535)+(c[b>>2]&65535)|0;c[276731]=(e|0)>65535;c[276732]=(d^32768^c[b>>2])&32768&(e^d);c[276729]=e;c[276730]=e;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)!=1106856){f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}function zk(){var b=0,d=0,e=0,f=0,g=0;b=c[276726]|0;d=c[276705]|0;e=(d&65535)+(c[b>>2]&65535)|0;c[276731]=(e|0)>65535;c[276732]=(d^32768^c[b>>2])&32768&(e^d);c[276729]=e;c[276730]=e;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)!=1106856){f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}function zl(){var b=0,d=0,e=0,f=0,g=0;b=c[276726]|0;d=c[276706]|0;e=(d&65535)+(c[b>>2]&65535)|0;c[276731]=(e|0)>65535;c[276732]=(d^32768^c[b>>2])&32768&(e^d);c[276729]=e;c[276730]=e;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)!=1106856){f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}function zm(){var b=0,d=0,e=0,f=0,g=0;b=c[276726]|0;d=c[276707]|0;e=(d&65535)+(c[b>>2]&65535)|0;c[276731]=(e|0)>65535;c[276732]=(d^32768^c[b>>2])&32768&(e^d);c[276729]=e;c[276730]=e;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)!=1106856){f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}function zn(){var b=0,d=0,e=0,f=0,g=0;b=c[276726]|0;d=c[276708]|0;e=(d&65535)+(c[b>>2]&65535)|0;c[276731]=(e|0)>65535;c[276732]=(d^32768^c[b>>2])&32768&(e^d);c[276729]=e;c[276730]=e;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)!=1106856){f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}function zo(){var b=0,d=0,e=0,f=0,g=0;b=c[276726]|0;d=c[276709]|0;e=(d&65535)+(c[b>>2]&65535)|0;c[276731]=(e|0)>65535;c[276732]=(d^32768^c[b>>2])&32768&(e^d);c[276729]=e;c[276730]=e;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)!=1106856){f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}function zp(){var b=0,d=0,e=0,f=0,g=0;b=c[276726]|0;d=c[276710]|0;e=(d&65535)+(c[b>>2]&65535)|0;c[276731]=(e|0)>65535;c[276732]=(d^32768^c[b>>2])&32768&(e^d);c[276729]=e;c[276730]=e;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)!=1106856){f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}function zq(){var b=0,d=0,e=0,f=0,g=0;b=c[276726]|0;d=c[276711]|0;e=(d&65535)+(c[b>>2]&65535)|0;c[276731]=(e|0)>65535;c[276732]=(d^32768^c[b>>2])&32768&(e^d);c[276729]=e;c[276730]=e;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)!=1106856){f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}function zr(){var b=0,d=0,e=0,f=0,g=0;b=c[276726]|0;d=c[276712]|0;e=(d&65535)+(c[b>>2]&65535)|0;c[276731]=(e|0)>65535;c[276732]=(d^32768^c[b>>2])&32768&(e^d);c[276729]=e;c[276730]=e;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)!=1106856){f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}function zs(){var b=0,d=0,e=0,f=0,g=0;b=c[276726]|0;d=c[276713]|0;e=(d&65535)+(c[b>>2]&65535)|0;c[276731]=(e|0)>65535;c[276732]=(d^32768^c[b>>2])&32768&(e^d);c[276729]=e;c[276730]=e;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)!=1106856){f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}function zt(){var b=0,d=0,e=0,f=0,g=0;b=c[276726]|0;d=c[276714]|0;e=(d&65535)+(c[b>>2]&65535)|0;c[276731]=(e|0)>65535;c[276732]=(d^32768^c[b>>2])&32768&(e^d);c[276729]=e;c[276730]=e;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)!=1106856){f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}function zu(){var b=0,d=0,e=0,f=0,g=0;b=c[276726]|0;d=c[276715]|0;e=(d&65535)+(c[b>>2]&65535)|0;c[276731]=(e|0)>65535;c[276732]=(d^32768^c[b>>2])&32768&(e^d);c[276729]=e;c[276730]=e;c[276715]=d+1;c[c[276725]>>2]=e;if((c[276725]|0)!=1106856){f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}function zv(){var b=0,d=0,e=0,f=0,g=0,h=0;b=c[276726]|0;d=c[276700]|0;e=(c[b>>2]&65535)-(d&65535)|0;c[276731]=e>>>31^1;f=c[b>>2]|0;c[276732]=(f^d)&32768&(e^f);c[276729]=e;c[276730]=e;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)!=1106856){g=c[276718]|0;h=g&-4865;c[276718]=h;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;g=c[276718]|0;h=g&-4865;c[276718]=h;c[276726]=1106800;c[276725]=1106800;return}function zw(){var b=0,d=0,e=0,f=0,g=0,h=0;b=c[276726]|0;d=c[276701]|0;e=(c[b>>2]&65535)-(d&65535)|0;c[276731]=e>>>31^1;f=c[b>>2]|0;c[276732]=(f^d)&32768&(e^f);c[276729]=e;c[276730]=e;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)!=1106856){g=c[276718]|0;h=g&-4865;c[276718]=h;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;g=c[276718]|0;h=g&-4865;c[276718]=h;c[276726]=1106800;c[276725]=1106800;return}function zx(){var b=0,d=0,e=0,f=0,g=0,h=0;b=c[276726]|0;d=c[276702]|0;e=(c[b>>2]&65535)-(d&65535)|0;c[276731]=e>>>31^1;f=c[b>>2]|0;c[276732]=(f^d)&32768&(e^f);c[276729]=e;c[276730]=e;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)!=1106856){g=c[276718]|0;h=g&-4865;c[276718]=h;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;g=c[276718]|0;h=g&-4865;c[276718]=h;c[276726]=1106800;c[276725]=1106800;return}function zy(){var b=0,d=0,e=0,f=0,g=0,h=0;b=c[276726]|0;d=c[276703]|0;e=(c[b>>2]&65535)-(d&65535)|0;c[276731]=e>>>31^1;f=c[b>>2]|0;c[276732]=(f^d)&32768&(e^f);c[276729]=e;c[276730]=e;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)!=1106856){g=c[276718]|0;h=g&-4865;c[276718]=h;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;g=c[276718]|0;h=g&-4865;c[276718]=h;c[276726]=1106800;c[276725]=1106800;return}function zz(){var b=0,d=0,e=0,f=0,g=0,h=0;b=c[276726]|0;d=c[276704]|0;e=(c[b>>2]&65535)-(d&65535)|0;c[276731]=e>>>31^1;f=c[b>>2]|0;c[276732]=(f^d)&32768&(e^f);c[276729]=e;c[276730]=e;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)!=1106856){g=c[276718]|0;h=g&-4865;c[276718]=h;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;g=c[276718]|0;h=g&-4865;c[276718]=h;c[276726]=1106800;c[276725]=1106800;return}function zA(){var b=0,d=0,e=0,f=0,g=0,h=0;b=c[276726]|0;d=c[276705]|0;e=(c[b>>2]&65535)-(d&65535)|0;c[276731]=e>>>31^1;f=c[b>>2]|0;c[276732]=(f^d)&32768&(e^f);c[276729]=e;c[276730]=e;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)!=1106856){g=c[276718]|0;h=g&-4865;c[276718]=h;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;g=c[276718]|0;h=g&-4865;c[276718]=h;c[276726]=1106800;c[276725]=1106800;return}function zB(){var b=0,d=0,e=0,f=0,g=0,h=0;b=c[276726]|0;d=c[276706]|0;e=(c[b>>2]&65535)-(d&65535)|0;c[276731]=e>>>31^1;f=c[b>>2]|0;c[276732]=(f^d)&32768&(e^f);c[276729]=e;c[276730]=e;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)!=1106856){g=c[276718]|0;h=g&-4865;c[276718]=h;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;g=c[276718]|0;h=g&-4865;c[276718]=h;c[276726]=1106800;c[276725]=1106800;return}function zC(){var b=0,d=0,e=0,f=0,g=0,h=0;b=c[276726]|0;d=c[276707]|0;e=(c[b>>2]&65535)-(d&65535)|0;c[276731]=e>>>31^1;f=c[b>>2]|0;c[276732]=(f^d)&32768&(e^f);c[276729]=e;c[276730]=e;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)!=1106856){g=c[276718]|0;h=g&-4865;c[276718]=h;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;g=c[276718]|0;h=g&-4865;c[276718]=h;c[276726]=1106800;c[276725]=1106800;return}function zD(){var b=0,d=0,e=0,f=0,g=0,h=0;b=c[276726]|0;d=c[276708]|0;e=(c[b>>2]&65535)-(d&65535)|0;c[276731]=e>>>31^1;f=c[b>>2]|0;c[276732]=(f^d)&32768&(e^f);c[276729]=e;c[276730]=e;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)!=1106856){g=c[276718]|0;h=g&-4865;c[276718]=h;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;g=c[276718]|0;h=g&-4865;c[276718]=h;c[276726]=1106800;c[276725]=1106800;return}function zE(){var b=0,d=0,e=0,f=0,g=0,h=0;b=c[276726]|0;d=c[276709]|0;e=(c[b>>2]&65535)-(d&65535)|0;c[276731]=e>>>31^1;f=c[b>>2]|0;c[276732]=(f^d)&32768&(e^f);c[276729]=e;c[276730]=e;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)!=1106856){g=c[276718]|0;h=g&-4865;c[276718]=h;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;g=c[276718]|0;h=g&-4865;c[276718]=h;c[276726]=1106800;c[276725]=1106800;return}function zF(){var b=0,d=0,e=0,f=0,g=0,h=0;b=c[276726]|0;d=c[276710]|0;e=(c[b>>2]&65535)-(d&65535)|0;c[276731]=e>>>31^1;f=c[b>>2]|0;c[276732]=(f^d)&32768&(e^f);c[276729]=e;c[276730]=e;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)!=1106856){g=c[276718]|0;h=g&-4865;c[276718]=h;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;g=c[276718]|0;h=g&-4865;c[276718]=h;c[276726]=1106800;c[276725]=1106800;return}function zG(){var b=0,d=0,e=0,f=0,g=0,h=0;b=c[276726]|0;d=c[276711]|0;e=(c[b>>2]&65535)-(d&65535)|0;c[276731]=e>>>31^1;f=c[b>>2]|0;c[276732]=(f^d)&32768&(e^f);c[276729]=e;c[276730]=e;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)!=1106856){g=c[276718]|0;h=g&-4865;c[276718]=h;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;g=c[276718]|0;h=g&-4865;c[276718]=h;c[276726]=1106800;c[276725]=1106800;return}function zH(){var b=0,d=0,e=0,f=0,g=0,h=0;b=c[276726]|0;d=c[276712]|0;e=(c[b>>2]&65535)-(d&65535)|0;c[276731]=e>>>31^1;f=c[b>>2]|0;c[276732]=(f^d)&32768&(e^f);c[276729]=e;c[276730]=e;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)!=1106856){g=c[276718]|0;h=g&-4865;c[276718]=h;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;g=c[276718]|0;h=g&-4865;c[276718]=h;c[276726]=1106800;c[276725]=1106800;return}function zI(){var b=0,d=0,e=0,f=0,g=0,h=0;b=c[276726]|0;d=c[276713]|0;e=(c[b>>2]&65535)-(d&65535)|0;c[276731]=e>>>31^1;f=c[b>>2]|0;c[276732]=(f^d)&32768&(e^f);c[276729]=e;c[276730]=e;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)!=1106856){g=c[276718]|0;h=g&-4865;c[276718]=h;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;g=c[276718]|0;h=g&-4865;c[276718]=h;c[276726]=1106800;c[276725]=1106800;return}function zJ(){var b=0,d=0,e=0,f=0,g=0,h=0;b=c[276726]|0;d=c[276714]|0;e=(c[b>>2]&65535)-(d&65535)|0;c[276731]=e>>>31^1;f=c[b>>2]|0;c[276732]=(f^d)&32768&(e^f);c[276729]=e;c[276730]=e;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)!=1106856){g=c[276718]|0;h=g&-4865;c[276718]=h;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;g=c[276718]|0;h=g&-4865;c[276718]=h;c[276726]=1106800;c[276725]=1106800;return}function zK(){var b=0,d=0,e=0,f=0,g=0,h=0;b=c[276726]|0;d=c[276715]|0;e=(c[b>>2]&65535)-(d&65535)|0;c[276731]=e>>>31^1;f=c[b>>2]|0;c[276732]=(f^d)&32768&(e^f);c[276729]=e;c[276730]=e;c[276715]=d+1;c[c[276725]>>2]=e;if((c[276725]|0)!=1106856){g=c[276718]|0;h=g&-4865;c[276718]=h;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;g=c[276718]|0;h=g&-4865;c[276718]=h;c[276726]=1106800;c[276725]=1106800;return}function zL(){var b=0,d=0,e=0,f=0,g=0;b=c[276707]|0;d=(c[276708]|0)>>>8&255;e=d|b&65280;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;c[276732]=e<<16&-1061158912;c[276730]=(e&61680|0)==0;c[276729]=(d<<8|b)&32768;c[276731]=(e&57568|0)!=0;if((c[276725]|0)!=1106856){f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}function zM(){var b=0;b=c[276701]&c[c[276726]>>2];c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function zN(){var b=0;b=c[276702]&c[c[276726]>>2];c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function zO(){var b=0;b=c[276703]&c[c[276726]>>2];c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function zP(){var b=0;b=c[276704]&c[c[276726]>>2];c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function zQ(){var b=0;b=c[276705]&c[c[276726]>>2];c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function zR(){var b=0;b=c[276706]&c[c[276726]>>2];c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function zS(){var b=0;b=c[276707]&c[c[276726]>>2];c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function zT(){var b=0;b=c[276708]&c[c[276726]>>2];c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function zU(){var b=0;b=c[276709]&c[c[276726]>>2];c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function zV(){var b=0;b=c[276710]&c[c[276726]>>2];c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function zW(){var b=0;b=c[276711]&c[c[276726]>>2];c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function zX(){var b=0;b=c[276712]&c[c[276726]>>2];c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function zY(){var b=0;b=c[276713]&c[c[276726]>>2];c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function zZ(){var b=0;b=c[276714]&c[c[276726]>>2];c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function z_(){var b=0,d=0;b=c[276715]|0;d=b&c[c[276726]>>2];c[276715]=b+1;c[c[276725]>>2]=d;c[276729]=d;c[276730]=d;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function z$(){var b=0;b=ab(c[276700]<<24>>24,c[c[276726]>>2]<<24>>24)|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function z0(){var b=0;b=ab(c[276701]<<24>>24,c[c[276726]>>2]<<24>>24)|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function z1(){var b=0;b=ab(c[276702]<<24>>24,c[c[276726]>>2]<<24>>24)|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function z2(){var b=0;b=ab(c[276703]<<24>>24,c[c[276726]>>2]<<24>>24)|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function z3(){var b=0;b=ab(c[276704]<<24>>24,c[c[276726]>>2]<<24>>24)|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function z4(){var b=0;b=ab(c[276705]<<24>>24,c[c[276726]>>2]<<24>>24)|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function z5(){var b=0;b=ab(c[276706]<<24>>24,c[c[276726]>>2]<<24>>24)|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function z6(){var b=0;b=ab(c[276707]<<24>>24,c[c[276726]>>2]<<24>>24)|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function z7(){var b=0;b=ab(c[276708]<<24>>24,c[c[276726]>>2]<<24>>24)|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function z8(){var b=0;b=ab(c[276709]<<24>>24,c[c[276726]>>2]<<24>>24)|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function z9(){var b=0;b=ab(c[276710]<<24>>24,c[c[276726]>>2]<<24>>24)|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Aa(){var b=0;b=ab(c[276711]<<24>>24,c[c[276726]>>2]<<24>>24)|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Ab(){var a=0;a=(c[276715]|0)+1|0;c[276711]=a;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=a;return}function Ac(){var a=0;a=c[276715]|0;c[276711]=a+2;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=a+1;return}function Ad(){var a=0;a=c[276715]|0;c[276711]=a+3;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=a+1;return}function Ae(){var a=0;a=c[276715]|0;c[276711]=a+4;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=a+1;return}function Af(){c[276715]=c[276708];c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Ag(){c[276715]=c[276709];c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Ah(){c[276715]=c[276710];c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Ai(){c[276715]=c[276711];c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Aj(){c[276715]=c[276712];c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Ak(){c[276715]=c[276713];c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Al(){var b=0;b=ab(c[276712]<<24>>24,c[c[276726]>>2]<<24>>24)|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Am(){var b=0;b=ab(c[276713]<<24>>24,c[c[276726]>>2]<<24>>24)|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function An(){var b=0;b=ab(c[276714]<<24>>24,c[c[276726]>>2]<<24>>24)|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Ao(){var b=0,d=0;b=c[276715]|0;d=ab(b<<24>>24,c[c[276726]>>2]<<24>>24)|0;c[276715]=b+1;c[c[276725]>>2]=d;c[276729]=d;c[276730]=d;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Ap(){a[(c[276814]|0)+(c[276724]&65535)|0]=c[c[276726]>>2]&255;a[(c[276814]|0)+(c[276724]&65535^1)|0]=(c[c[276726]>>2]|0)>>>8&255;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function Aq(){var b=0;b=c[c[276726]>>2]<<24>>24;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Ar(){var b=0,d=0;b=c[276726]|0;c[276731]=c[b>>2]&1;d=c[b>>2]<<16>>17;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=d;c[276729]=d;c[276730]=d;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function As(){var b=0,d=0;b=c[c[276726]>>2]|0;d=b>>>1&32767|c[276731]<<15;c[276731]=b&1;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=d;c[276729]=d;c[276730]=d;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function At(){var b=0,d=0;b=c[c[276726]>>2]&255;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;d=b<<8;c[276729]=d;c[276730]=d;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Au(){var b=0,d=0;b=ab(c[276706]<<16>>16,c[c[276726]>>2]<<16>>16)|0;d=b>>>16;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=d;c[276729]=d;c[276730]=d;c[276731]=b>>>15&1;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Av(){var b=0,d=0,e=0;b=a[1106909]|0;d=c[276715]|0;e=d+1|0;c[276715]=e;a[1106909]=a[(c[276816]|0)+(e&65535)|0]|0;c[276715]=d+2;c[276700]=b<<24>>24;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Aw(){var b=0,d=0,e=0;b=a[1106909]|0;d=c[276715]|0;e=d+1|0;c[276715]=e;a[1106909]=a[(c[276816]|0)+(e&65535)|0]|0;c[276715]=d+2;c[276701]=b<<24>>24;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Ax(){var b=0,d=0,e=0;b=a[1106909]|0;d=c[276715]|0;e=d+1|0;c[276715]=e;a[1106909]=a[(c[276816]|0)+(e&65535)|0]|0;c[276715]=d+2;c[276702]=b<<24>>24;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Ay(){var b=0,d=0,e=0;b=a[1106909]|0;d=c[276715]|0;e=d+1|0;c[276715]=e;a[1106909]=a[(c[276816]|0)+(e&65535)|0]|0;c[276715]=d+2;c[276703]=b<<24>>24;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Az(){var b=0,d=0,e=0;b=a[1106909]|0;d=c[276715]|0;e=d+1|0;c[276715]=e;a[1106909]=a[(c[276816]|0)+(e&65535)|0]|0;c[276715]=d+2;c[276704]=b<<24>>24;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function AA(){var b=0,d=0,e=0;b=a[1106909]|0;d=c[276715]|0;e=d+1|0;c[276715]=e;a[1106909]=a[(c[276816]|0)+(e&65535)|0]|0;c[276715]=d+2;c[276705]=b<<24>>24;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function AB(){var b=0,d=0,e=0;b=a[1106909]|0;d=c[276715]|0;e=d+1|0;c[276715]=e;a[1106909]=a[(c[276816]|0)+(e&65535)|0]|0;c[276715]=d+2;c[276706]=b<<24>>24;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function AC(){var b=0,d=0,e=0;b=a[1106909]|0;d=c[276715]|0;e=d+1|0;c[276715]=e;a[1106909]=a[(c[276816]|0)+(e&65535)|0]|0;c[276715]=d+2;c[276707]=b<<24>>24;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function AD(){var b=0,d=0,e=0;b=a[1106909]|0;d=c[276715]|0;e=d+1|0;c[276715]=e;a[1106909]=a[(c[276816]|0)+(e&65535)|0]|0;c[276715]=d+2;c[276708]=b<<24>>24;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function AE(){var b=0,d=0,e=0;b=a[1106909]|0;d=c[276715]|0;e=d+1|0;c[276715]=e;a[1106909]=a[(c[276816]|0)+(e&65535)|0]|0;c[276715]=d+2;c[276709]=b<<24>>24;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function AF(){var b=0,d=0,e=0;b=a[1106909]|0;d=c[276715]|0;e=d+1|0;c[276715]=e;a[1106909]=a[(c[276816]|0)+(e&65535)|0]|0;c[276715]=d+2;c[276710]=b<<24>>24;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function AG(){var b=0,d=0,e=0;b=a[1106909]|0;d=c[276715]|0;e=d+1|0;c[276715]=e;a[1106909]=a[(c[276816]|0)+(e&65535)|0]|0;c[276715]=d+2;c[276711]=b<<24>>24;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function AH(){var b=0,d=0,e=0;b=a[1106909]|0;d=c[276715]|0;e=d+1|0;c[276715]=e;a[1106909]=a[(c[276816]|0)+(e&65535)|0]|0;c[276715]=d+2;c[276712]=b<<24>>24;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function AI(){var b=0,d=0,e=0;b=a[1106909]|0;d=c[276715]|0;e=d+1|0;c[276715]=e;a[1106909]=a[(c[276816]|0)+(e&65535)|0]|0;c[276715]=d+2;c[276713]=b<<24>>24;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function AJ(){var b=0,d=0,e=0;b=a[1106909]|0;d=c[276715]|0;e=d+1|0;c[276715]=e;a[1106909]=a[(c[276816]|0)+(e&65535)|0]|0;c[276715]=d+2;d=b<<24>>24;c[276714]=d;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;a[1106908]=a[(c[276815]|0)+(d&65535)|0]|0;return}function AK(){var b=0,d=0;b=a[1106909]|0;d=(c[276715]|0)+1|0;c[276715]=d;a[1106909]=a[(c[276816]|0)+(d&65535)|0]|0;c[276715]=b<<24>>24;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function AL(){var b=0;if((c[276718]&4096|0)==0){c[276726]=1106800;c[276715]=(c[276715]|0)+1;return}b=c[276700]|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276732]=b<<16&8388608;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function AM(){var b=0;if((c[276718]&4096|0)==0){c[276726]=1106804;c[276715]=(c[276715]|0)+1;return}b=c[276701]|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276732]=b<<16&8388608;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function AN(){var b=0;if((c[276718]&4096|0)==0){c[276726]=1106808;c[276715]=(c[276715]|0)+1;return}b=c[276702]|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276732]=b<<16&8388608;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function AO(){var b=0;if((c[276718]&4096|0)==0){c[276726]=1106812;c[276715]=(c[276715]|0)+1;return}b=c[276703]|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276732]=b<<16&8388608;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function AP(){var b=0;if((c[276718]&4096|0)==0){c[276726]=1106816;c[276715]=(c[276715]|0)+1;return}b=c[276704]|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276732]=b<<16&8388608;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function AQ(){var b=0;if((c[276718]&4096|0)==0){c[276726]=1106820;c[276715]=(c[276715]|0)+1;return}b=c[276705]|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276732]=b<<16&8388608;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function AR(){var b=0;if((c[276718]&4096|0)==0){c[276726]=1106824;c[276715]=(c[276715]|0)+1;return}b=c[276706]|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276732]=b<<16&8388608;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function AS(){var b=0;if((c[276718]&4096|0)==0){c[276726]=1106828;c[276715]=(c[276715]|0)+1;return}b=c[276707]|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276732]=b<<16&8388608;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function AT(){var b=0;if((c[276718]&4096|0)==0){c[276726]=1106832;c[276715]=(c[276715]|0)+1;return}b=c[276708]|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276732]=b<<16&8388608;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function AU(){var b=0;if((c[276718]&4096|0)==0){c[276726]=1106836;c[276715]=(c[276715]|0)+1;return}b=c[276709]|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276732]=b<<16&8388608;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function AV(){var b=0;if((c[276718]&4096|0)==0){c[276726]=1106840;c[276715]=(c[276715]|0)+1;return}b=c[276710]|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276732]=b<<16&8388608;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function AW(){var b=0;if((c[276718]&4096|0)==0){c[276726]=1106844;c[276715]=(c[276715]|0)+1;return}b=c[276711]|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276732]=b<<16&8388608;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function AX(){var b=0;if((c[276718]&4096|0)==0){c[276726]=1106848;c[276715]=(c[276715]|0)+1;return}b=c[276712]|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276732]=b<<16&8388608;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function AY(){var b=0;if((c[276718]&4096|0)==0){c[276726]=1106852;c[276715]=(c[276715]|0)+1;return}b=c[276713]|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276732]=b<<16&8388608;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function AZ(){var b=0;if((c[276718]&4096|0)==0){c[276726]=1106856;c[276715]=(c[276715]|0)+1;return}b=c[276714]|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276732]=b<<16&8388608;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function A_(){var b=0;if((c[276718]&4096|0)==0){c[276726]=1106860;c[276715]=(c[276715]|0)+1;return}b=c[276715]|0;c[276715]=b+1;c[c[276725]>>2]=b;c[276732]=b<<16&8388608;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function A$(){var b=0,d=0;b=(c[c[276726]>>2]|0)>>>8&255;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;d=b<<8;c[276729]=d;c[276730]=d;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function A0(){var b=0;b=c[276701]|c[c[276726]>>2];c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function A1(){var b=0;b=c[276702]|c[c[276726]>>2];c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function A2(){var b=0;b=c[276703]|c[c[276726]>>2];c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function A3(){var b=0;b=c[276704]|c[c[276726]>>2];c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function A4(){var b=0;b=c[276705]|c[c[276726]>>2];c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function A5(){var b=0;b=c[276706]|c[c[276726]>>2];c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function A6(){var b=0;b=c[276707]|c[c[276726]>>2];c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function A7(){var b=0;b=c[276708]|c[c[276726]>>2];c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function A8(){var b=0;b=c[276709]|c[c[276726]>>2];c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function A9(){var b=0;b=c[276710]|c[c[276726]>>2];c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Ba(){var a=0;a=(c[276700]|0)+1|0;c[276700]=a;c[276729]=a;c[276730]=a;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function Bb(){var a=0;a=(c[276701]|0)+1|0;c[276701]=a;c[276729]=a;c[276730]=a;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function Bc(){var a=0;a=(c[276702]|0)+1|0;c[276702]=a;c[276729]=a;c[276730]=a;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function Bd(){var a=0;a=(c[276703]|0)+1|0;c[276703]=a;c[276729]=a;c[276730]=a;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function Be(){var a=0;a=(c[276704]|0)+1|0;c[276704]=a;c[276729]=a;c[276730]=a;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function Bf(){var a=0;a=(c[276705]|0)+1|0;c[276705]=a;c[276729]=a;c[276730]=a;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function Bg(){var a=0;a=(c[276706]|0)+1|0;c[276706]=a;c[276729]=a;c[276730]=a;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function Bh(){var a=0;a=(c[276707]|0)+1|0;c[276707]=a;c[276729]=a;c[276730]=a;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function Bi(){var a=0;a=(c[276708]|0)+1|0;c[276708]=a;c[276729]=a;c[276730]=a;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function Bj(){var a=0;a=(c[276709]|0)+1|0;c[276709]=a;c[276729]=a;c[276730]=a;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function Bk(){var a=0;a=(c[276710]|0)+1|0;c[276710]=a;c[276729]=a;c[276730]=a;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function Bl(){var a=0;a=(c[276711]|0)+1|0;c[276711]=a;c[276729]=a;c[276730]=a;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function Bm(){var a=0;a=(c[276712]|0)+1|0;c[276712]=a;c[276729]=a;c[276730]=a;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function Bn(){var a=0;a=(c[276713]|0)+1|0;c[276713]=a;c[276729]=a;c[276730]=a;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function Bo(){var b=0,d=0,e=0,f=0;b=a[1106908]|0;d=c[276717]|0;if((d&4|0)==0){e=b}else{e=b&-16|(b&255)>>>4}if((d&8|0)==0){f=e&255}else{f=c[276716]&240|e&15}c[276716]=f;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function Bp(){var a=0;a=(c[276700]|0)-1|0;c[276700]=a;c[276729]=a;c[276730]=a;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function Bq(){var a=0;a=(c[276701]|0)-1|0;c[276701]=a;c[276729]=a;c[276730]=a;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function Br(){var a=0;a=(c[276702]|0)-1|0;c[276702]=a;c[276729]=a;c[276730]=a;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function Bs(){var a=0;a=(c[276703]|0)-1|0;c[276703]=a;c[276729]=a;c[276730]=a;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function Bt(){var a=0;a=(c[276704]|0)-1|0;c[276704]=a;c[276729]=a;c[276730]=a;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function Bu(){var a=0;a=(c[276705]|0)-1|0;c[276705]=a;c[276729]=a;c[276730]=a;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function Bv(){var a=0;a=(c[276706]|0)-1|0;c[276706]=a;c[276729]=a;c[276730]=a;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function Bw(){var a=0;a=(c[276707]|0)-1|0;c[276707]=a;c[276729]=a;c[276730]=a;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function Bx(){var a=0;a=(c[276708]|0)-1|0;c[276708]=a;c[276729]=a;c[276730]=a;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function By(){var a=0;a=(c[276709]|0)-1|0;c[276709]=a;c[276729]=a;c[276730]=a;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function Bz(){var a=0;a=(c[276710]|0)-1|0;c[276710]=a;c[276729]=a;c[276730]=a;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function BA(){var a=0;a=(c[276711]|0)-1|0;c[276711]=a;c[276729]=a;c[276730]=a;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function BB(){var a=0;a=(c[276712]|0)-1|0;c[276712]=a;c[276729]=a;c[276730]=a;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function BC(){var a=0;a=(c[276713]|0)-1|0;c[276713]=a;c[276729]=a;c[276730]=a;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function BD(){var b=0;b=c[276711]|c[c[276726]>>2];c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function BE(){var b=0;b=c[276712]|c[c[276726]>>2];c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function BF(){var b=0;b=c[276713]|c[c[276726]>>2];c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function BG(){var b=0;b=c[276714]|c[c[276726]>>2];c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function BH(){var b=0,d=0;b=c[276715]|0;d=b|c[c[276726]>>2];c[276715]=b+1;c[c[276725]>>2]=d;c[276729]=d;c[276730]=d;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function BI(){var b=0;b=(c[276714]|0)+1|0;c[276714]=b;c[276729]=b;c[276730]=b;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;a[1106908]=a[(c[276815]|0)+(b&65535)|0]|0;return}function BJ(){var b=0;b=(c[276714]|0)-1|0;c[276714]=b;c[276729]=b;c[276730]=b;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;a[1106908]=a[(c[276815]|0)+(b&65535)|0]|0;return}function BK(){var b=0;b=d[1106908]|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function BL(){var b=0,e=0,f=0,g=0,h=0;b=d[1106909]|0;e=c[276715]|0;f=e+1|0;c[276715]=f;g=c[276816]|0;h=a[g+(f&65535)|0]|0;a[1106909]=h;f=e+2|0;c[276715]=f;a[1106909]=a[g+(f&65535)|0]|0;c[276715]=e+3;c[276700]=(h&255)<<8|b;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function BM(){var b=0,e=0,f=0,g=0,h=0;b=d[1106909]|0;e=c[276715]|0;f=e+1|0;c[276715]=f;g=c[276816]|0;h=a[g+(f&65535)|0]|0;a[1106909]=h;f=e+2|0;c[276715]=f;a[1106909]=a[g+(f&65535)|0]|0;c[276715]=e+3;c[276701]=(h&255)<<8|b;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function BN(){var b=0,e=0,f=0,g=0,h=0;b=d[1106909]|0;e=c[276715]|0;f=e+1|0;c[276715]=f;g=c[276816]|0;h=a[g+(f&65535)|0]|0;a[1106909]=h;f=e+2|0;c[276715]=f;a[1106909]=a[g+(f&65535)|0]|0;c[276715]=e+3;c[276702]=(h&255)<<8|b;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function BO(){var b=0,e=0,f=0,g=0,h=0;b=d[1106909]|0;e=c[276715]|0;f=e+1|0;c[276715]=f;g=c[276816]|0;h=a[g+(f&65535)|0]|0;a[1106909]=h;f=e+2|0;c[276715]=f;a[1106909]=a[g+(f&65535)|0]|0;c[276715]=e+3;c[276703]=(h&255)<<8|b;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function BP(){var b=0,e=0,f=0,g=0,h=0;b=d[1106909]|0;e=c[276715]|0;f=e+1|0;c[276715]=f;g=c[276816]|0;h=a[g+(f&65535)|0]|0;a[1106909]=h;f=e+2|0;c[276715]=f;a[1106909]=a[g+(f&65535)|0]|0;c[276715]=e+3;c[276704]=(h&255)<<8|b;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function BQ(){var b=0,e=0,f=0,g=0,h=0;b=d[1106909]|0;e=c[276715]|0;f=e+1|0;c[276715]=f;g=c[276816]|0;h=a[g+(f&65535)|0]|0;a[1106909]=h;f=e+2|0;c[276715]=f;a[1106909]=a[g+(f&65535)|0]|0;c[276715]=e+3;c[276705]=(h&255)<<8|b;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function BR(){var b=0,e=0,f=0,g=0,h=0;b=d[1106909]|0;e=c[276715]|0;f=e+1|0;c[276715]=f;g=c[276816]|0;h=a[g+(f&65535)|0]|0;a[1106909]=h;f=e+2|0;c[276715]=f;a[1106909]=a[g+(f&65535)|0]|0;c[276715]=e+3;c[276706]=(h&255)<<8|b;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function BS(){var b=0,e=0,f=0,g=0,h=0;b=d[1106909]|0;e=c[276715]|0;f=e+1|0;c[276715]=f;g=c[276816]|0;h=a[g+(f&65535)|0]|0;a[1106909]=h;f=e+2|0;c[276715]=f;a[1106909]=a[g+(f&65535)|0]|0;c[276715]=e+3;c[276707]=(h&255)<<8|b;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function BT(){var b=0,e=0,f=0,g=0,h=0;b=d[1106909]|0;e=c[276715]|0;f=e+1|0;c[276715]=f;g=c[276816]|0;h=a[g+(f&65535)|0]|0;a[1106909]=h;f=e+2|0;c[276715]=f;a[1106909]=a[g+(f&65535)|0]|0;c[276715]=e+3;c[276708]=(h&255)<<8|b;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function BU(){var b=0,e=0,f=0,g=0,h=0;b=d[1106909]|0;e=c[276715]|0;f=e+1|0;c[276715]=f;g=c[276816]|0;h=a[g+(f&65535)|0]|0;a[1106909]=h;f=e+2|0;c[276715]=f;a[1106909]=a[g+(f&65535)|0]|0;c[276715]=e+3;c[276709]=(h&255)<<8|b;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function BV(){var b=0,e=0,f=0,g=0,h=0;b=d[1106909]|0;e=c[276715]|0;f=e+1|0;c[276715]=f;g=c[276816]|0;h=a[g+(f&65535)|0]|0;a[1106909]=h;f=e+2|0;c[276715]=f;a[1106909]=a[g+(f&65535)|0]|0;c[276715]=e+3;c[276710]=(h&255)<<8|b;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function BW(){var b=0,e=0,f=0,g=0,h=0;b=d[1106909]|0;e=c[276715]|0;f=e+1|0;c[276715]=f;g=c[276816]|0;h=a[g+(f&65535)|0]|0;a[1106909]=h;f=e+2|0;c[276715]=f;a[1106909]=a[g+(f&65535)|0]|0;c[276715]=e+3;c[276711]=(h&255)<<8|b;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function BX(){var b=0,e=0,f=0,g=0,h=0;b=d[1106909]|0;e=c[276715]|0;f=e+1|0;c[276715]=f;g=c[276816]|0;h=a[g+(f&65535)|0]|0;a[1106909]=h;f=e+2|0;c[276715]=f;a[1106909]=a[g+(f&65535)|0]|0;c[276715]=e+3;c[276712]=(h&255)<<8|b;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function BY(){var b=0,e=0,f=0,g=0,h=0;b=d[1106909]|0;e=c[276715]|0;f=e+1|0;c[276715]=f;g=c[276816]|0;h=a[g+(f&65535)|0]|0;a[1106909]=h;f=e+2|0;c[276715]=f;a[1106909]=a[g+(f&65535)|0]|0;c[276715]=e+3;c[276713]=(h&255)<<8|b;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function BZ(){var b=0,e=0,f=0,g=0,h=0,i=0;b=d[1106909]|0;e=c[276715]|0;f=e+1|0;c[276715]=f;g=c[276816]|0;h=a[g+(f&65535)|0]|0;a[1106909]=h;f=e+2|0;c[276715]=f;i=(h&255)<<8|b;a[1106909]=a[g+(f&65535)|0]|0;c[276715]=e+3;c[276714]=i;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;a[1106908]=a[(c[276815]|0)+i|0]|0;return}function B_(){var b=0,e=0,f=0,g=0,h=0;b=d[1106909]|0;e=c[276715]|0;f=e+1|0;c[276715]=f;g=c[276816]|0;h=a[g+(f&65535)|0]|0;a[1106909]=h;f=e+2|0;c[276715]=f;a[1106909]=a[g+(f&65535)|0]|0;c[276715]=(h&255)<<8|b;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function B$(){var b=0;b=c[276700]|0;c[276724]=b;a[(c[276814]|0)+(b&65535)|0]=c[c[276726]>>2]&255;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function B0(){var b=0;b=c[276701]|0;c[276724]=b;a[(c[276814]|0)+(b&65535)|0]=c[c[276726]>>2]&255;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function B1(){var b=0;b=c[276702]|0;c[276724]=b;a[(c[276814]|0)+(b&65535)|0]=c[c[276726]>>2]&255;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function B2(){var b=0;b=c[276703]|0;c[276724]=b;a[(c[276814]|0)+(b&65535)|0]=c[c[276726]>>2]&255;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function B3(){var b=0;b=c[276704]|0;c[276724]=b;a[(c[276814]|0)+(b&65535)|0]=c[c[276726]>>2]&255;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function B4(){var b=0;b=c[276705]|0;c[276724]=b;a[(c[276814]|0)+(b&65535)|0]=c[c[276726]>>2]&255;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function B5(){var b=0;b=c[276706]|0;c[276724]=b;a[(c[276814]|0)+(b&65535)|0]=c[c[276726]>>2]&255;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function B6(){var b=0;b=c[276707]|0;c[276724]=b;a[(c[276814]|0)+(b&65535)|0]=c[c[276726]>>2]&255;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function B7(){var b=0;b=c[276708]|0;c[276724]=b;a[(c[276814]|0)+(b&65535)|0]=c[c[276726]>>2]&255;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function B8(){var b=0;b=c[276709]|0;c[276724]=b;a[(c[276814]|0)+(b&65535)|0]=c[c[276726]>>2]&255;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function B9(){var b=0;b=c[276710]|0;c[276724]=b;a[(c[276814]|0)+(b&65535)|0]=c[c[276726]>>2]&255;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function Ca(){var b=0;b=c[276711]|0;c[276724]=b;a[(c[276814]|0)+(b&65535)|0]=c[c[276726]>>2]&255;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function Cb(){var b=0,e=0;b=c[276700]|0;c[276724]=b;e=d[(c[276814]|0)+(b&65535)|0]|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Cc(){var b=0,e=0;b=c[276701]|0;c[276724]=b;e=d[(c[276814]|0)+(b&65535)|0]|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Cd(){var b=0,e=0;b=c[276702]|0;c[276724]=b;e=d[(c[276814]|0)+(b&65535)|0]|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Ce(){var b=0,e=0;b=c[276703]|0;c[276724]=b;e=d[(c[276814]|0)+(b&65535)|0]|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Cf(){var b=0,e=0;b=c[276704]|0;c[276724]=b;e=d[(c[276814]|0)+(b&65535)|0]|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Cg(){var b=0,e=0;b=c[276705]|0;c[276724]=b;e=d[(c[276814]|0)+(b&65535)|0]|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Ch(){var b=0,e=0;b=c[276706]|0;c[276724]=b;e=d[(c[276814]|0)+(b&65535)|0]|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Ci(){var b=0,e=0;b=c[276707]|0;c[276724]=b;e=d[(c[276814]|0)+(b&65535)|0]|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Cj(){var b=0,e=0;b=c[276708]|0;c[276724]=b;e=d[(c[276814]|0)+(b&65535)|0]|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Ck(){var b=0,e=0;b=c[276709]|0;c[276724]=b;e=d[(c[276814]|0)+(b&65535)|0]|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Cl(){var b=0,e=0;b=c[276710]|0;c[276724]=b;e=d[(c[276814]|0)+(b&65535)|0]|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Cm(){var b=0,e=0;b=c[276711]|0;c[276724]=b;e=d[(c[276814]|0)+(b&65535)|0]|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Cn(){var a=0,b=0,e=0,f=0;a=c[276701]|0;b=c[276702]|0;c[276715]=(c[276715]|0)+1;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;e=c[1106984+((b>>>3&31)<<2)>>2]|0;f=(c[1107112+((a>>>3&31)<<2)>>2]|0)+(b<<1&14)|0;c[276700]=0;b=128>>>((a&7)>>>0)&255;a=((d[e+f|0]|0)&b|0)!=0|0;c[276700]=a;c[276700]=(((d[e+(f+1)|0]|0)&b|0)!=0)<<1|a;return}function Co(){var b=0,d=0,e=0,f=0,g=0;b=c[276726]|0;d=c[276700]|0;e=(d&65535)+(c[b>>2]&65535)+(c[276731]<<16>>16)|0;c[276731]=(e|0)>65535;c[276732]=(d^32768^c[b>>2])&32768&(e^d);c[276729]=e;c[276730]=e;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)!=1106856){f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}function Cp(){var a=0,b=0,d=0;a=c[c[276726]>>2]|0;c[276717]=a;b=(a&16|0)==0?c[276811]|0:256;c[276810]=b;if((c[276743]|0)==(c[276744]|0)){if((c[276812]|0)!=(b|0)|(c[277209]|0)!=0){d=7901}}else{d=7901}if((d|0)==7901){Hg()}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function Cq(){var b=0,d=0,e=0,f=0,g=0;b=c[276726]|0;d=c[276701]|0;e=(d&65535)+(c[b>>2]&65535)+(c[276731]<<16>>16)|0;c[276731]=(e|0)>65535;c[276732]=(d^32768^c[b>>2])&32768&(e^d);c[276729]=e;c[276730]=e;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)!=1106856){f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}function Cr(){var b=0,d=0,e=0,f=0,g=0;b=c[276726]|0;d=c[276702]|0;e=(d&65535)+(c[b>>2]&65535)+(c[276731]<<16>>16)|0;c[276731]=(e|0)>65535;c[276732]=(d^32768^c[b>>2])&32768&(e^d);c[276729]=e;c[276730]=e;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)!=1106856){f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}function Cs(){var b=0,d=0,e=0,f=0,g=0;b=c[276726]|0;d=c[276703]|0;e=(d&65535)+(c[b>>2]&65535)+(c[276731]<<16>>16)|0;c[276731]=(e|0)>65535;c[276732]=(d^32768^c[b>>2])&32768&(e^d);c[276729]=e;c[276730]=e;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)!=1106856){f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}function Ct(){var b=0,d=0,e=0,f=0,g=0;b=c[276726]|0;d=c[276704]|0;e=(d&65535)+(c[b>>2]&65535)+(c[276731]<<16>>16)|0;c[276731]=(e|0)>65535;c[276732]=(d^32768^c[b>>2])&32768&(e^d);c[276729]=e;c[276730]=e;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)!=1106856){f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}function Cu(){var b=0,d=0,e=0,f=0,g=0;b=c[276726]|0;d=c[276705]|0;e=(d&65535)+(c[b>>2]&65535)+(c[276731]<<16>>16)|0;c[276731]=(e|0)>65535;c[276732]=(d^32768^c[b>>2])&32768&(e^d);c[276729]=e;c[276730]=e;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)!=1106856){f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}function Cv(){var b=0,d=0,e=0,f=0,g=0;b=c[276726]|0;d=c[276706]|0;e=(d&65535)+(c[b>>2]&65535)+(c[276731]<<16>>16)|0;c[276731]=(e|0)>65535;c[276732]=(d^32768^c[b>>2])&32768&(e^d);c[276729]=e;c[276730]=e;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)!=1106856){f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}function Cw(){var b=0,d=0,e=0,f=0,g=0;b=c[276726]|0;d=c[276707]|0;e=(d&65535)+(c[b>>2]&65535)+(c[276731]<<16>>16)|0;c[276731]=(e|0)>65535;c[276732]=(d^32768^c[b>>2])&32768&(e^d);c[276729]=e;c[276730]=e;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)!=1106856){f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}function Cx(){var b=0,d=0,e=0,f=0,g=0;b=c[276726]|0;d=c[276708]|0;e=(d&65535)+(c[b>>2]&65535)+(c[276731]<<16>>16)|0;c[276731]=(e|0)>65535;c[276732]=(d^32768^c[b>>2])&32768&(e^d);c[276729]=e;c[276730]=e;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)!=1106856){f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}function Cy(){var b=0,d=0,e=0,f=0,g=0;b=c[276726]|0;d=c[276709]|0;e=(d&65535)+(c[b>>2]&65535)+(c[276731]<<16>>16)|0;c[276731]=(e|0)>65535;c[276732]=(d^32768^c[b>>2])&32768&(e^d);c[276729]=e;c[276730]=e;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)!=1106856){f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}function Cz(){var b=0,d=0,e=0,f=0,g=0;b=c[276726]|0;d=c[276710]|0;e=(d&65535)+(c[b>>2]&65535)+(c[276731]<<16>>16)|0;c[276731]=(e|0)>65535;c[276732]=(d^32768^c[b>>2])&32768&(e^d);c[276729]=e;c[276730]=e;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)!=1106856){f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}function CA(){var b=0,d=0,e=0,f=0,g=0;b=c[276726]|0;d=c[276711]|0;e=(d&65535)+(c[b>>2]&65535)+(c[276731]<<16>>16)|0;c[276731]=(e|0)>65535;c[276732]=(d^32768^c[b>>2])&32768&(e^d);c[276729]=e;c[276730]=e;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)!=1106856){f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}function CB(){var b=0,d=0,e=0,f=0,g=0;b=c[276726]|0;d=c[276712]|0;e=(d&65535)+(c[b>>2]&65535)+(c[276731]<<16>>16)|0;c[276731]=(e|0)>65535;c[276732]=(d^32768^c[b>>2])&32768&(e^d);c[276729]=e;c[276730]=e;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)!=1106856){f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}function CC(){var b=0,d=0,e=0,f=0,g=0;b=c[276726]|0;d=c[276713]|0;e=(d&65535)+(c[b>>2]&65535)+(c[276731]<<16>>16)|0;c[276731]=(e|0)>65535;c[276732]=(d^32768^c[b>>2])&32768&(e^d);c[276729]=e;c[276730]=e;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)!=1106856){f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}function CD(){var b=0,d=0,e=0,f=0,g=0;b=c[276726]|0;d=c[276714]|0;e=(d&65535)+(c[b>>2]&65535)+(c[276731]<<16>>16)|0;c[276731]=(e|0)>65535;c[276732]=(d^32768^c[b>>2])&32768&(e^d);c[276729]=e;c[276730]=e;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)!=1106856){f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}function CE(){var b=0,d=0,e=0,f=0,g=0;b=c[276726]|0;d=c[276715]|0;e=(d&65535)+(c[b>>2]&65535)+(c[276731]<<16>>16)|0;c[276731]=(e|0)>65535;c[276732]=(d^32768^c[b>>2])&32768&(e^d);c[276729]=e;c[276730]=e;c[276715]=d+1;c[c[276725]>>2]=e;if((c[276725]|0)!=1106856){f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}function CF(){var b=0,d=0,e=0,f=0,g=0,h=0;b=c[276726]|0;d=c[276700]|0;e=(c[b>>2]&65535)-(d&65535)-(c[276731]&65535^1)|0;c[276731]=e>>>31^1;f=c[b>>2]|0;c[276732]=(f^d)&32768&(e^f);c[276729]=e;c[276730]=e;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)!=1106856){g=c[276718]|0;h=g&-4865;c[276718]=h;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;g=c[276718]|0;h=g&-4865;c[276718]=h;c[276726]=1106800;c[276725]=1106800;return}function CG(){var b=0,d=0,e=0,f=0,g=0,h=0;b=c[276726]|0;d=c[276701]|0;e=(c[b>>2]&65535)-(d&65535)-(c[276731]&65535^1)|0;c[276731]=e>>>31^1;f=c[b>>2]|0;c[276732]=(f^d)&32768&(e^f);c[276729]=e;c[276730]=e;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)!=1106856){g=c[276718]|0;h=g&-4865;c[276718]=h;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;g=c[276718]|0;h=g&-4865;c[276718]=h;c[276726]=1106800;c[276725]=1106800;return}function CH(){var b=0,d=0,e=0,f=0,g=0,h=0;b=c[276726]|0;d=c[276702]|0;e=(c[b>>2]&65535)-(d&65535)-(c[276731]&65535^1)|0;c[276731]=e>>>31^1;f=c[b>>2]|0;c[276732]=(f^d)&32768&(e^f);c[276729]=e;c[276730]=e;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)!=1106856){g=c[276718]|0;h=g&-4865;c[276718]=h;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;g=c[276718]|0;h=g&-4865;c[276718]=h;c[276726]=1106800;c[276725]=1106800;return}function CI(){var b=0,d=0,e=0,f=0,g=0,h=0;b=c[276726]|0;d=c[276703]|0;e=(c[b>>2]&65535)-(d&65535)-(c[276731]&65535^1)|0;c[276731]=e>>>31^1;f=c[b>>2]|0;c[276732]=(f^d)&32768&(e^f);c[276729]=e;c[276730]=e;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)!=1106856){g=c[276718]|0;h=g&-4865;c[276718]=h;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;g=c[276718]|0;h=g&-4865;c[276718]=h;c[276726]=1106800;c[276725]=1106800;return}function CJ(){var b=0,d=0,e=0,f=0,g=0,h=0;b=c[276726]|0;d=c[276704]|0;e=(c[b>>2]&65535)-(d&65535)-(c[276731]&65535^1)|0;c[276731]=e>>>31^1;f=c[b>>2]|0;c[276732]=(f^d)&32768&(e^f);c[276729]=e;c[276730]=e;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)!=1106856){g=c[276718]|0;h=g&-4865;c[276718]=h;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;g=c[276718]|0;h=g&-4865;c[276718]=h;c[276726]=1106800;c[276725]=1106800;return}function CK(){var b=0,d=0,e=0,f=0,g=0,h=0;b=c[276726]|0;d=c[276705]|0;e=(c[b>>2]&65535)-(d&65535)-(c[276731]&65535^1)|0;c[276731]=e>>>31^1;f=c[b>>2]|0;c[276732]=(f^d)&32768&(e^f);c[276729]=e;c[276730]=e;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)!=1106856){g=c[276718]|0;h=g&-4865;c[276718]=h;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;g=c[276718]|0;h=g&-4865;c[276718]=h;c[276726]=1106800;c[276725]=1106800;return}function CL(){var b=0,d=0,e=0,f=0,g=0,h=0;b=c[276726]|0;d=c[276706]|0;e=(c[b>>2]&65535)-(d&65535)-(c[276731]&65535^1)|0;c[276731]=e>>>31^1;f=c[b>>2]|0;c[276732]=(f^d)&32768&(e^f);c[276729]=e;c[276730]=e;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)!=1106856){g=c[276718]|0;h=g&-4865;c[276718]=h;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;g=c[276718]|0;h=g&-4865;c[276718]=h;c[276726]=1106800;c[276725]=1106800;return}function CM(){var b=0,d=0,e=0,f=0,g=0,h=0;b=c[276726]|0;d=c[276707]|0;e=(c[b>>2]&65535)-(d&65535)-(c[276731]&65535^1)|0;c[276731]=e>>>31^1;f=c[b>>2]|0;c[276732]=(f^d)&32768&(e^f);c[276729]=e;c[276730]=e;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)!=1106856){g=c[276718]|0;h=g&-4865;c[276718]=h;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;g=c[276718]|0;h=g&-4865;c[276718]=h;c[276726]=1106800;c[276725]=1106800;return}function CN(){var b=0,d=0,e=0,f=0,g=0,h=0;b=c[276726]|0;d=c[276708]|0;e=(c[b>>2]&65535)-(d&65535)-(c[276731]&65535^1)|0;c[276731]=e>>>31^1;f=c[b>>2]|0;c[276732]=(f^d)&32768&(e^f);c[276729]=e;c[276730]=e;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)!=1106856){g=c[276718]|0;h=g&-4865;c[276718]=h;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;g=c[276718]|0;h=g&-4865;c[276718]=h;c[276726]=1106800;c[276725]=1106800;return}function CO(){var b=0,d=0,e=0,f=0,g=0,h=0;b=c[276726]|0;d=c[276709]|0;e=(c[b>>2]&65535)-(d&65535)-(c[276731]&65535^1)|0;c[276731]=e>>>31^1;f=c[b>>2]|0;c[276732]=(f^d)&32768&(e^f);c[276729]=e;c[276730]=e;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)!=1106856){g=c[276718]|0;h=g&-4865;c[276718]=h;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;g=c[276718]|0;h=g&-4865;c[276718]=h;c[276726]=1106800;c[276725]=1106800;return}function CP(){var b=0,d=0,e=0,f=0,g=0,h=0;b=c[276726]|0;d=c[276710]|0;e=(c[b>>2]&65535)-(d&65535)-(c[276731]&65535^1)|0;c[276731]=e>>>31^1;f=c[b>>2]|0;c[276732]=(f^d)&32768&(e^f);c[276729]=e;c[276730]=e;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)!=1106856){g=c[276718]|0;h=g&-4865;c[276718]=h;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;g=c[276718]|0;h=g&-4865;c[276718]=h;c[276726]=1106800;c[276725]=1106800;return}function CQ(){var b=0,d=0,e=0,f=0,g=0,h=0;b=c[276726]|0;d=c[276711]|0;e=(c[b>>2]&65535)-(d&65535)-(c[276731]&65535^1)|0;c[276731]=e>>>31^1;f=c[b>>2]|0;c[276732]=(f^d)&32768&(e^f);c[276729]=e;c[276730]=e;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)!=1106856){g=c[276718]|0;h=g&-4865;c[276718]=h;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;g=c[276718]|0;h=g&-4865;c[276718]=h;c[276726]=1106800;c[276725]=1106800;return}function CR(){var b=0,d=0,e=0,f=0,g=0,h=0;b=c[276726]|0;d=c[276712]|0;e=(c[b>>2]&65535)-(d&65535)-(c[276731]&65535^1)|0;c[276731]=e>>>31^1;f=c[b>>2]|0;c[276732]=(f^d)&32768&(e^f);c[276729]=e;c[276730]=e;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)!=1106856){g=c[276718]|0;h=g&-4865;c[276718]=h;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;g=c[276718]|0;h=g&-4865;c[276718]=h;c[276726]=1106800;c[276725]=1106800;return}function CS(){var b=0,d=0,e=0,f=0,g=0,h=0;b=c[276726]|0;d=c[276713]|0;e=(c[b>>2]&65535)-(d&65535)-(c[276731]&65535^1)|0;c[276731]=e>>>31^1;f=c[b>>2]|0;c[276732]=(f^d)&32768&(e^f);c[276729]=e;c[276730]=e;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)!=1106856){g=c[276718]|0;h=g&-4865;c[276718]=h;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;g=c[276718]|0;h=g&-4865;c[276718]=h;c[276726]=1106800;c[276725]=1106800;return}function CT(){var b=0,d=0,e=0,f=0,g=0,h=0;b=c[276726]|0;d=c[276714]|0;e=(c[b>>2]&65535)-(d&65535)-(c[276731]&65535^1)|0;c[276731]=e>>>31^1;f=c[b>>2]|0;c[276732]=(f^d)&32768&(e^f);c[276729]=e;c[276730]=e;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)!=1106856){g=c[276718]|0;h=g&-4865;c[276718]=h;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;g=c[276718]|0;h=g&-4865;c[276718]=h;c[276726]=1106800;c[276725]=1106800;return}function CU(){var b=0,d=0,e=0,f=0,g=0,h=0;b=c[276726]|0;d=c[276715]|0;e=(c[b>>2]&65535)-(d&65535)-(c[276731]&65535^1)|0;c[276731]=e>>>31^1;f=c[b>>2]|0;c[276732]=(f^d)&32768&(e^f);c[276729]=e;c[276730]=e;c[276715]=d+1;c[c[276725]>>2]=e;if((c[276725]|0)!=1106856){g=c[276718]|0;h=g&-4865;c[276718]=h;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;g=c[276718]|0;h=g&-4865;c[276718]=h;c[276726]=1106800;c[276725]=1106800;return}function CV(){var b=0;b=c[c[276726]>>2]&~c[276701];c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function CW(){var b=0;b=c[c[276726]>>2]&~c[276702];c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function CX(){var b=0;b=c[c[276726]>>2]&~c[276703];c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function CY(){var b=0;b=c[c[276726]>>2]&~c[276704];c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function CZ(){var b=0;b=c[c[276726]>>2]&~c[276705];c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function C_(){var b=0;b=c[c[276726]>>2]&~c[276706];c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function C$(){var b=0;b=c[c[276726]>>2]&~c[276707];c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function C0(){var b=0;b=c[c[276726]>>2]&~c[276708];c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function C1(){var b=0;b=c[c[276726]>>2]&~c[276709];c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function C2(){var b=0;b=c[c[276726]>>2]&~c[276710];c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function C3(){var b=0;b=c[c[276726]>>2]&~c[276711];c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function C4(){var b=0;b=c[c[276726]>>2]&~c[276712];c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function C5(){var b=0;b=c[c[276726]>>2]&~c[276713];c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function C6(){var b=0;b=c[c[276726]>>2]&~c[276714];c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function C7(){var b=0,d=0;b=c[276715]|0;d=c[c[276726]>>2]&~b;c[276715]=b+1;c[c[276725]>>2]=d;c[276729]=d;c[276730]=d;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function C8(){var b=0;b=ab(c[276700]&255,c[c[276726]>>2]&255)|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function C9(){var b=0;b=ab(c[276701]&255,c[c[276726]>>2]&255)|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Da(){var b=0;b=ab(c[276702]&255,c[c[276726]>>2]&255)|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Db(){var b=0;b=ab(c[276703]&255,c[c[276726]>>2]&255)|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Dc(){var b=0;b=ab(c[276704]&255,c[c[276726]>>2]&255)|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Dd(){var b=0;b=ab(c[276705]&255,c[c[276726]>>2]&255)|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function De(){var b=0;b=ab(c[276706]&255,c[c[276726]>>2]&255)|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Df(){var b=0;b=ab(c[276707]&255,c[c[276726]>>2]&255)|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Dg(){var b=0;b=ab(c[276708]&255,c[c[276726]>>2]&255)|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Dh(){var b=0;b=ab(c[276709]&255,c[c[276726]>>2]&255)|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Di(){var b=0;b=ab(c[276710]&255,c[c[276726]>>2]&255)|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Dj(){var b=0;b=ab(c[276711]&255,c[c[276726]>>2]&255)|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Dk(){var b=0;b=ab(c[276712]&255,c[c[276726]>>2]&255)|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Dl(){var b=0;b=ab(c[276713]&255,c[c[276726]>>2]&255)|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Dm(){var b=0;b=ab(c[276714]&255,c[c[276726]>>2]&255)|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Dn(){var b=0,d=0;b=c[276715]|0;d=ab(b&255,c[c[276726]>>2]&255)|0;c[276715]=b+1;c[c[276725]>>2]=d;c[276729]=d;c[276730]=d;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Do(){var b=0,d=0,e=0;b=c[c[276726]>>2]<<16;d=b>>16;c[276731]=d&1;e=(d|0)==-1?0:b>>17;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;c[276729]=e;c[276730]=e;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Dp(){var b=0;b=c[276708]&127;c[276719]=b;c[276816]=c[1107284+(b<<2)>>2];b=c[c[276726]>>2]|0;c[276723]=0;c[276722]=b&65520;a[1108308]=1;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=b;return}function Dq(){var b=0;b=c[276709]&127;c[276719]=b;c[276816]=c[1107284+(b<<2)>>2];b=c[c[276726]>>2]|0;c[276723]=0;c[276722]=b&65520;a[1108308]=1;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=b;return}function Dr(){var b=0;b=c[276710]&127;c[276719]=b;c[276816]=c[1107284+(b<<2)>>2];b=c[c[276726]>>2]|0;c[276723]=0;c[276722]=b&65520;a[1108308]=1;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=b;return}function Ds(){var b=0;b=c[276711]&127;c[276719]=b;c[276816]=c[1107284+(b<<2)>>2];b=c[c[276726]>>2]|0;c[276723]=0;c[276722]=b&65520;a[1108308]=1;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=b;return}function Dt(){var b=0;b=c[276712]&127;c[276719]=b;c[276816]=c[1107284+(b<<2)>>2];b=c[c[276726]>>2]|0;c[276723]=0;c[276722]=b&65520;a[1108308]=1;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=b;return}function Du(){var b=0;b=c[276713]&127;c[276719]=b;c[276816]=c[1107284+(b<<2)>>2];b=c[c[276726]>>2]|0;c[276723]=0;c[276722]=b&65520;a[1108308]=1;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=b;return}function Dv(){var b=0,d=0,e=0,f=0;b=ab(c[276706]<<16>>16,c[c[276726]>>2]<<16>>16)|0;c[276704]=b;d=b>>>16;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=d;c[276729]=d;c[276730]=d;c[276731]=(c[276704]|0)>>>15&1;if((c[276725]|0)!=1106856){e=c[276718]|0;f=e&-4865;c[276718]=f;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;e=c[276718]|0;f=e&-4865;c[276718]=f;c[276726]=1106800;c[276725]=1106800;return}function Dw(){var b=0,e=0,f=0;b=(d[1106909]|0)<<1;c[276724]=b;e=c[276715]|0;f=e+1|0;c[276715]=f;a[1106909]=a[(c[276816]|0)+(f&65535)|0]|0;c[276715]=e+2;e=c[276814]|0;f=d[e+b|0]|0;c[276700]=f;c[276700]=(d[e+(b|1)|0]|0)<<8|f;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Dx(){var b=0,e=0,f=0;b=(d[1106909]|0)<<1;c[276724]=b;e=c[276715]|0;f=e+1|0;c[276715]=f;a[1106909]=a[(c[276816]|0)+(f&65535)|0]|0;c[276715]=e+2;e=c[276814]|0;f=d[e+b|0]|0;c[276701]=f;c[276701]=(d[e+(b|1)|0]|0)<<8|f;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Dy(){var b=0,e=0,f=0;b=(d[1106909]|0)<<1;c[276724]=b;e=c[276715]|0;f=e+1|0;c[276715]=f;a[1106909]=a[(c[276816]|0)+(f&65535)|0]|0;c[276715]=e+2;e=c[276814]|0;f=d[e+b|0]|0;c[276702]=f;c[276702]=(d[e+(b|1)|0]|0)<<8|f;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Dz(){var b=0,e=0,f=0;b=(d[1106909]|0)<<1;c[276724]=b;e=c[276715]|0;f=e+1|0;c[276715]=f;a[1106909]=a[(c[276816]|0)+(f&65535)|0]|0;c[276715]=e+2;e=c[276814]|0;f=d[e+b|0]|0;c[276703]=f;c[276703]=(d[e+(b|1)|0]|0)<<8|f;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function DA(){var b=0,e=0,f=0;b=(d[1106909]|0)<<1;c[276724]=b;e=c[276715]|0;f=e+1|0;c[276715]=f;a[1106909]=a[(c[276816]|0)+(f&65535)|0]|0;c[276715]=e+2;e=c[276814]|0;f=d[e+b|0]|0;c[276704]=f;c[276704]=(d[e+(b|1)|0]|0)<<8|f;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function DB(){var b=0,e=0,f=0;b=(d[1106909]|0)<<1;c[276724]=b;e=c[276715]|0;f=e+1|0;c[276715]=f;a[1106909]=a[(c[276816]|0)+(f&65535)|0]|0;c[276715]=e+2;e=c[276814]|0;f=d[e+b|0]|0;c[276705]=f;c[276705]=(d[e+(b|1)|0]|0)<<8|f;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function DC(){var b=0,e=0,f=0;b=(d[1106909]|0)<<1;c[276724]=b;e=c[276715]|0;f=e+1|0;c[276715]=f;a[1106909]=a[(c[276816]|0)+(f&65535)|0]|0;c[276715]=e+2;e=c[276814]|0;f=d[e+b|0]|0;c[276706]=f;c[276706]=(d[e+(b|1)|0]|0)<<8|f;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function DD(){var b=0,e=0,f=0;b=(d[1106909]|0)<<1;c[276724]=b;e=c[276715]|0;f=e+1|0;c[276715]=f;a[1106909]=a[(c[276816]|0)+(f&65535)|0]|0;c[276715]=e+2;e=c[276814]|0;f=d[e+b|0]|0;c[276707]=f;c[276707]=(d[e+(b|1)|0]|0)<<8|f;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function DE(){var b=0,e=0,f=0;b=(d[1106909]|0)<<1;c[276724]=b;e=c[276715]|0;f=e+1|0;c[276715]=f;a[1106909]=a[(c[276816]|0)+(f&65535)|0]|0;c[276715]=e+2;e=c[276814]|0;f=d[e+b|0]|0;c[276708]=f;c[276708]=(d[e+(b|1)|0]|0)<<8|f;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function DF(){var b=0,e=0,f=0;b=(d[1106909]|0)<<1;c[276724]=b;e=c[276715]|0;f=e+1|0;c[276715]=f;a[1106909]=a[(c[276816]|0)+(f&65535)|0]|0;c[276715]=e+2;e=c[276814]|0;f=d[e+b|0]|0;c[276709]=f;c[276709]=(d[e+(b|1)|0]|0)<<8|f;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function DG(){var b=0,e=0,f=0;b=(d[1106909]|0)<<1;c[276724]=b;e=c[276715]|0;f=e+1|0;c[276715]=f;a[1106909]=a[(c[276816]|0)+(f&65535)|0]|0;c[276715]=e+2;e=c[276814]|0;f=d[e+b|0]|0;c[276710]=f;c[276710]=(d[e+(b|1)|0]|0)<<8|f;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function DH(){var b=0,e=0,f=0;b=(d[1106909]|0)<<1;c[276724]=b;e=c[276715]|0;f=e+1|0;c[276715]=f;a[1106909]=a[(c[276816]|0)+(f&65535)|0]|0;c[276715]=e+2;e=c[276814]|0;f=d[e+b|0]|0;c[276711]=f;c[276711]=(d[e+(b|1)|0]|0)<<8|f;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function DI(){var b=0,e=0,f=0;b=(d[1106909]|0)<<1;c[276724]=b;e=c[276715]|0;f=e+1|0;c[276715]=f;a[1106909]=a[(c[276816]|0)+(f&65535)|0]|0;c[276715]=e+2;e=c[276814]|0;f=d[e+b|0]|0;c[276712]=f;c[276712]=(d[e+(b|1)|0]|0)<<8|f;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function DJ(){var b=0,e=0,f=0;b=(d[1106909]|0)<<1;c[276724]=b;e=c[276715]|0;f=e+1|0;c[276715]=f;a[1106909]=a[(c[276816]|0)+(f&65535)|0]|0;c[276715]=e+2;e=c[276814]|0;f=d[e+b|0]|0;c[276713]=f;c[276713]=(d[e+(b|1)|0]|0)<<8|f;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function DK(){var b=0,e=0,f=0,g=0;b=(d[1106909]|0)<<1;c[276724]=b;e=c[276715]|0;f=e+1|0;c[276715]=f;a[1106909]=a[(c[276816]|0)+(f&65535)|0]|0;c[276715]=e+2;e=c[276814]|0;f=d[e+b|0]|0;c[276714]=f;g=(d[e+(b|1)|0]|0)<<8|f;c[276714]=g;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;a[1106908]=a[(c[276815]|0)+g|0]|0;return}function DL(){var b=0,e=0,f=0;b=(d[1106909]|0)<<1;c[276724]=b;e=c[276715]|0;f=e+1|0;c[276715]=f;a[1106909]=a[(c[276816]|0)+(f&65535)|0]|0;c[276715]=e+2;e=c[276814]|0;f=d[e+b|0]|0;c[276715]=f;c[276715]=(d[e+(b|1)|0]|0)<<8|f;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function DM(){var b=0;b=c[276701]^c[c[276726]>>2];c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function DN(){var b=0;b=c[276702]^c[c[276726]>>2];c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function DO(){var b=0;b=c[276703]^c[c[276726]>>2];c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function DP(){var b=0;b=c[276704]^c[c[276726]>>2];c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function DQ(){var b=0;b=c[276705]^c[c[276726]>>2];c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function DR(){var b=0;b=c[276706]^c[c[276726]>>2];c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function DS(){var b=0;b=c[276707]^c[c[276726]>>2];c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function DT(){var b=0;b=c[276708]^c[c[276726]>>2];c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function DU(){var b=0;b=c[276709]^c[c[276726]>>2];c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function DV(){var b=0;b=c[276710]^c[c[276726]>>2];c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function DW(){var b=0;b=c[276711]^c[c[276726]>>2];c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function DX(){var b=0;b=c[276712]^c[c[276726]>>2];c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function DY(){var b=0;b=c[276713]^c[c[276726]>>2];c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function DZ(){var b=0;b=c[276714]^c[c[276726]>>2];c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function D_(){var b=0,d=0;b=c[276715]|0;d=b^c[c[276726]>>2];c[276715]=b+1;c[c[276725]>>2]=d;c[276729]=d;c[276730]=d;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function D$(){var b=0;b=c[c[276726]>>2]&255|(d[1106908]|0)<<8;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function D0(){var b=0,e=0,f=0,g=0,h=0,i=0;b=d[1106909]|0;c[276724]=b;e=c[276715]|0;f=e+1|0;c[276715]=f;g=c[276816]|0;h=a[g+(f&65535)|0]|0;a[1106909]=h;f=e+2|0;c[276715]=f;i=(h&255)<<8|b;c[276724]=i;a[1106909]=a[g+(f&65535)|0]|0;c[276715]=e+3;e=c[276814]|0;f=d[e+i|0]|0;c[276700]=f;c[276700]=(d[e+(i^1)|0]|0)<<8|f;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function D1(){var b=0,e=0,f=0,g=0,h=0,i=0;b=d[1106909]|0;c[276724]=b;e=c[276715]|0;f=e+1|0;c[276715]=f;g=c[276816]|0;h=a[g+(f&65535)|0]|0;a[1106909]=h;f=e+2|0;c[276715]=f;i=(h&255)<<8|b;c[276724]=i;a[1106909]=a[g+(f&65535)|0]|0;c[276715]=e+3;e=c[276814]|0;f=d[e+i|0]|0;c[276701]=f;c[276701]=(d[e+(i^1)|0]|0)<<8|f;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function D2(){var b=0,e=0,f=0,g=0,h=0,i=0;b=d[1106909]|0;c[276724]=b;e=c[276715]|0;f=e+1|0;c[276715]=f;g=c[276816]|0;h=a[g+(f&65535)|0]|0;a[1106909]=h;f=e+2|0;c[276715]=f;i=(h&255)<<8|b;c[276724]=i;a[1106909]=a[g+(f&65535)|0]|0;c[276715]=e+3;e=c[276814]|0;f=d[e+i|0]|0;c[276702]=f;c[276702]=(d[e+(i^1)|0]|0)<<8|f;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function D3(){var b=0,e=0,f=0,g=0,h=0,i=0;b=d[1106909]|0;c[276724]=b;e=c[276715]|0;f=e+1|0;c[276715]=f;g=c[276816]|0;h=a[g+(f&65535)|0]|0;a[1106909]=h;f=e+2|0;c[276715]=f;i=(h&255)<<8|b;c[276724]=i;a[1106909]=a[g+(f&65535)|0]|0;c[276715]=e+3;e=c[276814]|0;f=d[e+i|0]|0;c[276703]=f;c[276703]=(d[e+(i^1)|0]|0)<<8|f;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function D4(){var b=0,e=0,f=0,g=0,h=0,i=0;b=d[1106909]|0;c[276724]=b;e=c[276715]|0;f=e+1|0;c[276715]=f;g=c[276816]|0;h=a[g+(f&65535)|0]|0;a[1106909]=h;f=e+2|0;c[276715]=f;i=(h&255)<<8|b;c[276724]=i;a[1106909]=a[g+(f&65535)|0]|0;c[276715]=e+3;e=c[276814]|0;f=d[e+i|0]|0;c[276704]=f;c[276704]=(d[e+(i^1)|0]|0)<<8|f;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function D5(){var b=0,e=0,f=0,g=0,h=0,i=0;b=d[1106909]|0;c[276724]=b;e=c[276715]|0;f=e+1|0;c[276715]=f;g=c[276816]|0;h=a[g+(f&65535)|0]|0;a[1106909]=h;f=e+2|0;c[276715]=f;i=(h&255)<<8|b;c[276724]=i;a[1106909]=a[g+(f&65535)|0]|0;c[276715]=e+3;e=c[276814]|0;f=d[e+i|0]|0;c[276705]=f;c[276705]=(d[e+(i^1)|0]|0)<<8|f;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function D6(){var b=0,e=0,f=0,g=0,h=0,i=0;b=d[1106909]|0;c[276724]=b;e=c[276715]|0;f=e+1|0;c[276715]=f;g=c[276816]|0;h=a[g+(f&65535)|0]|0;a[1106909]=h;f=e+2|0;c[276715]=f;i=(h&255)<<8|b;c[276724]=i;a[1106909]=a[g+(f&65535)|0]|0;c[276715]=e+3;e=c[276814]|0;f=d[e+i|0]|0;c[276706]=f;c[276706]=(d[e+(i^1)|0]|0)<<8|f;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function D7(){var b=0,e=0,f=0,g=0,h=0,i=0;b=d[1106909]|0;c[276724]=b;e=c[276715]|0;f=e+1|0;c[276715]=f;g=c[276816]|0;h=a[g+(f&65535)|0]|0;a[1106909]=h;f=e+2|0;c[276715]=f;i=(h&255)<<8|b;c[276724]=i;a[1106909]=a[g+(f&65535)|0]|0;c[276715]=e+3;e=c[276814]|0;f=d[e+i|0]|0;c[276707]=f;c[276707]=(d[e+(i^1)|0]|0)<<8|f;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function D8(){var b=0,e=0,f=0,g=0,h=0,i=0;b=d[1106909]|0;c[276724]=b;e=c[276715]|0;f=e+1|0;c[276715]=f;g=c[276816]|0;h=a[g+(f&65535)|0]|0;a[1106909]=h;f=e+2|0;c[276715]=f;i=(h&255)<<8|b;c[276724]=i;a[1106909]=a[g+(f&65535)|0]|0;c[276715]=e+3;e=c[276814]|0;f=d[e+i|0]|0;c[276708]=f;c[276708]=(d[e+(i^1)|0]|0)<<8|f;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function D9(){var b=0,e=0,f=0,g=0,h=0,i=0;b=d[1106909]|0;c[276724]=b;e=c[276715]|0;f=e+1|0;c[276715]=f;g=c[276816]|0;h=a[g+(f&65535)|0]|0;a[1106909]=h;f=e+2|0;c[276715]=f;i=(h&255)<<8|b;c[276724]=i;a[1106909]=a[g+(f&65535)|0]|0;c[276715]=e+3;e=c[276814]|0;f=d[e+i|0]|0;c[276709]=f;c[276709]=(d[e+(i^1)|0]|0)<<8|f;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Ea(){var b=0,e=0,f=0,g=0,h=0,i=0;b=d[1106909]|0;c[276724]=b;e=c[276715]|0;f=e+1|0;c[276715]=f;g=c[276816]|0;h=a[g+(f&65535)|0]|0;a[1106909]=h;f=e+2|0;c[276715]=f;i=(h&255)<<8|b;c[276724]=i;a[1106909]=a[g+(f&65535)|0]|0;c[276715]=e+3;e=c[276814]|0;f=d[e+i|0]|0;c[276710]=f;c[276710]=(d[e+(i^1)|0]|0)<<8|f;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Eb(){var b=0,e=0,f=0,g=0,h=0,i=0;b=d[1106909]|0;c[276724]=b;e=c[276715]|0;f=e+1|0;c[276715]=f;g=c[276816]|0;h=a[g+(f&65535)|0]|0;a[1106909]=h;f=e+2|0;c[276715]=f;i=(h&255)<<8|b;c[276724]=i;a[1106909]=a[g+(f&65535)|0]|0;c[276715]=e+3;e=c[276814]|0;f=d[e+i|0]|0;c[276711]=f;c[276711]=(d[e+(i^1)|0]|0)<<8|f;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Ec(){var b=0,e=0,f=0,g=0,h=0,i=0;b=d[1106909]|0;c[276724]=b;e=c[276715]|0;f=e+1|0;c[276715]=f;g=c[276816]|0;h=a[g+(f&65535)|0]|0;a[1106909]=h;f=e+2|0;c[276715]=f;i=(h&255)<<8|b;c[276724]=i;a[1106909]=a[g+(f&65535)|0]|0;c[276715]=e+3;e=c[276814]|0;f=d[e+i|0]|0;c[276712]=f;c[276712]=(d[e+(i^1)|0]|0)<<8|f;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Ed(){var b=0,e=0,f=0,g=0,h=0,i=0;b=d[1106909]|0;c[276724]=b;e=c[276715]|0;f=e+1|0;c[276715]=f;g=c[276816]|0;h=a[g+(f&65535)|0]|0;a[1106909]=h;f=e+2|0;c[276715]=f;i=(h&255)<<8|b;c[276724]=i;a[1106909]=a[g+(f&65535)|0]|0;c[276715]=e+3;e=c[276814]|0;f=d[e+i|0]|0;c[276713]=f;c[276713]=(d[e+(i^1)|0]|0)<<8|f;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Ee(){var b=0,e=0,f=0,g=0,h=0,i=0;b=d[1106909]|0;c[276724]=b;e=c[276715]|0;f=e+1|0;c[276715]=f;g=c[276816]|0;h=a[g+(f&65535)|0]|0;a[1106909]=h;f=e+2|0;c[276715]=f;i=(h&255)<<8|b;c[276724]=i;a[1106909]=a[g+(f&65535)|0]|0;c[276715]=e+3;e=c[276814]|0;f=d[e+i|0]|0;c[276714]=f;g=(d[e+(i^1)|0]|0)<<8|f;c[276714]=g;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;a[1106908]=a[(c[276815]|0)+g|0]|0;return}function Ef(){var b=0,e=0,f=0,g=0,h=0,i=0;b=d[1106909]|0;c[276724]=b;e=c[276715]|0;f=e+1|0;c[276715]=f;g=c[276816]|0;h=a[g+(f&65535)|0]|0;a[1106909]=h;f=e+2|0;c[276715]=f;i=(h&255)<<8|b;c[276724]=i;a[1106909]=a[g+(f&65535)|0]|0;c[276715]=e+3;e=c[276814]|0;f=d[e+i|0]|0;c[276715]=f;c[276715]=(d[e+(i^1)|0]|0)<<8|f;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Eg(){var b=0,d=0,e=0;b=c[276726]|0;d=c[b>>2]|0;e=d&65535;c[276731]=0;c[276732]=d&32768&(c[b>>2]^32768);c[276729]=e;c[276730]=e;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Eh(){var b=0,d=0,e=0,f=0;b=c[276726]|0;d=(c[b>>2]&65535)+1|0;c[276731]=d>>>0>65535;c[276732]=d&32768&(c[b>>2]^32768);c[276729]=d;c[276730]=d;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=d;if((c[276725]|0)!=1106856){e=c[276718]|0;f=e&-4865;c[276718]=f;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;e=c[276718]|0;f=e&-4865;c[276718]=f;c[276726]=1106800;c[276725]=1106800;return}function Ei(){var b=0,d=0,e=0,f=0;b=c[276726]|0;d=(c[b>>2]&65535)+2|0;c[276731]=d>>>0>65535;c[276732]=d&32768&(c[b>>2]^32768);c[276729]=d;c[276730]=d;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=d;if((c[276725]|0)!=1106856){e=c[276718]|0;f=e&-4865;c[276718]=f;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;e=c[276718]|0;f=e&-4865;c[276718]=f;c[276726]=1106800;c[276725]=1106800;return}function Ej(){var b=0,d=0,e=0,f=0;b=c[276726]|0;d=(c[b>>2]&65535)+3|0;c[276731]=d>>>0>65535;c[276732]=d&32768&(c[b>>2]^32768);c[276729]=d;c[276730]=d;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=d;if((c[276725]|0)!=1106856){e=c[276718]|0;f=e&-4865;c[276718]=f;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;e=c[276718]|0;f=e&-4865;c[276718]=f;c[276726]=1106800;c[276725]=1106800;return}function Ek(){var b=0,d=0,e=0,f=0;b=c[276726]|0;d=(c[b>>2]&65535)+4|0;c[276731]=d>>>0>65535;c[276732]=d&32768&(c[b>>2]^32768);c[276729]=d;c[276730]=d;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=d;if((c[276725]|0)!=1106856){e=c[276718]|0;f=e&-4865;c[276718]=f;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;e=c[276718]|0;f=e&-4865;c[276718]=f;c[276726]=1106800;c[276725]=1106800;return}function El(){var b=0,d=0,e=0,f=0;b=c[276726]|0;d=(c[b>>2]&65535)+5|0;c[276731]=d>>>0>65535;c[276732]=d&32768&(c[b>>2]^32768);c[276729]=d;c[276730]=d;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=d;if((c[276725]|0)!=1106856){e=c[276718]|0;f=e&-4865;c[276718]=f;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;e=c[276718]|0;f=e&-4865;c[276718]=f;c[276726]=1106800;c[276725]=1106800;return}function Em(){var b=0,d=0,e=0,f=0;b=c[276726]|0;d=(c[b>>2]&65535)+6|0;c[276731]=d>>>0>65535;c[276732]=d&32768&(c[b>>2]^32768);c[276729]=d;c[276730]=d;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=d;if((c[276725]|0)!=1106856){e=c[276718]|0;f=e&-4865;c[276718]=f;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;e=c[276718]|0;f=e&-4865;c[276718]=f;c[276726]=1106800;c[276725]=1106800;return}function En(){var b=0,d=0,e=0,f=0;b=c[276726]|0;d=(c[b>>2]&65535)+7|0;c[276731]=d>>>0>65535;c[276732]=d&32768&(c[b>>2]^32768);c[276729]=d;c[276730]=d;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=d;if((c[276725]|0)!=1106856){e=c[276718]|0;f=e&-4865;c[276718]=f;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;e=c[276718]|0;f=e&-4865;c[276718]=f;c[276726]=1106800;c[276725]=1106800;return}function Eo(){var b=0,d=0,e=0,f=0;b=c[276726]|0;d=(c[b>>2]&65535)+8|0;c[276731]=d>>>0>65535;c[276732]=d&32768&(c[b>>2]^32768);c[276729]=d;c[276730]=d;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=d;if((c[276725]|0)!=1106856){e=c[276718]|0;f=e&-4865;c[276718]=f;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;e=c[276718]|0;f=e&-4865;c[276718]=f;c[276726]=1106800;c[276725]=1106800;return}function Ep(){var b=0,d=0,e=0,f=0;b=c[276726]|0;d=(c[b>>2]&65535)+9|0;c[276731]=d>>>0>65535;c[276732]=d&32768&(c[b>>2]^32768);c[276729]=d;c[276730]=d;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=d;if((c[276725]|0)!=1106856){e=c[276718]|0;f=e&-4865;c[276718]=f;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;e=c[276718]|0;f=e&-4865;c[276718]=f;c[276726]=1106800;c[276725]=1106800;return}function Eq(){var b=0,d=0,e=0,f=0;b=c[276726]|0;d=(c[b>>2]&65535)+10|0;c[276731]=d>>>0>65535;c[276732]=d&32768&(c[b>>2]^32768);c[276729]=d;c[276730]=d;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=d;if((c[276725]|0)!=1106856){e=c[276718]|0;f=e&-4865;c[276718]=f;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;e=c[276718]|0;f=e&-4865;c[276718]=f;c[276726]=1106800;c[276725]=1106800;return}function Er(){var b=0,d=0,e=0,f=0;b=c[276726]|0;d=(c[b>>2]&65535)+11|0;c[276731]=d>>>0>65535;c[276732]=d&32768&(c[b>>2]^32768);c[276729]=d;c[276730]=d;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=d;if((c[276725]|0)!=1106856){e=c[276718]|0;f=e&-4865;c[276718]=f;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;e=c[276718]|0;f=e&-4865;c[276718]=f;c[276726]=1106800;c[276725]=1106800;return}function Es(){var b=0,d=0,e=0,f=0;b=c[276726]|0;d=(c[b>>2]&65535)+12|0;c[276731]=d>>>0>65535;c[276732]=d&32768&(c[b>>2]^32768);c[276729]=d;c[276730]=d;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=d;if((c[276725]|0)!=1106856){e=c[276718]|0;f=e&-4865;c[276718]=f;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;e=c[276718]|0;f=e&-4865;c[276718]=f;c[276726]=1106800;c[276725]=1106800;return}function Et(){var b=0,d=0,e=0,f=0;b=c[276726]|0;d=(c[b>>2]&65535)+13|0;c[276731]=d>>>0>65535;c[276732]=d&32768&(c[b>>2]^32768);c[276729]=d;c[276730]=d;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=d;if((c[276725]|0)!=1106856){e=c[276718]|0;f=e&-4865;c[276718]=f;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;e=c[276718]|0;f=e&-4865;c[276718]=f;c[276726]=1106800;c[276725]=1106800;return}function Eu(){var b=0,d=0,e=0,f=0;b=c[276726]|0;d=(c[b>>2]&65535)+14|0;c[276731]=d>>>0>65535;c[276732]=d&32768&(c[b>>2]^32768);c[276729]=d;c[276730]=d;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=d;if((c[276725]|0)!=1106856){e=c[276718]|0;f=e&-4865;c[276718]=f;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;e=c[276718]|0;f=e&-4865;c[276718]=f;c[276726]=1106800;c[276725]=1106800;return}function Ev(){var b=0,d=0,e=0,f=0;b=c[276726]|0;d=(c[b>>2]&65535)+15|0;c[276731]=d>>>0>65535;c[276732]=d&32768&(c[b>>2]^32768);c[276729]=d;c[276730]=d;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=d;if((c[276725]|0)!=1106856){e=c[276718]|0;f=e&-4865;c[276718]=f;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;e=c[276718]|0;f=e&-4865;c[276718]=f;c[276726]=1106800;c[276725]=1106800;return}function Ew(){var b=0,d=0,e=0;b=c[276726]|0;d=c[b>>2]|0;e=d&65535;c[276731]=1;c[276732]=(d&32768^32768)&c[b>>2];c[276729]=e;c[276730]=e;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Ex(){var b=0,d=0,e=0,f=0;b=c[276726]|0;d=c[b>>2]|0;e=d&65535;f=e-1|0;c[276731]=(e|0)!=0;c[276732]=-d&32768&c[b>>2];c[276729]=f;c[276730]=f;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=f;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Ey(){var b=0,d=0,e=0,f=0,g=0;b=c[276726]|0;d=c[b>>2]|0;e=(d&65535)-2|0;c[276731]=e>>>31^1;c[276732]=1-d&32768&c[b>>2];c[276729]=e;c[276730]=e;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)!=1106856){f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}function Ez(){var b=0,d=0,e=0,f=0,g=0;b=c[276726]|0;d=c[b>>2]|0;e=(d&65535)-3|0;c[276731]=e>>>31^1;c[276732]=2-d&32768&c[b>>2];c[276729]=e;c[276730]=e;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)!=1106856){f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}function EA(){var b=0,d=0,e=0,f=0,g=0;b=c[276726]|0;d=c[b>>2]|0;e=(d&65535)-4|0;c[276731]=e>>>31^1;c[276732]=3-d&32768&c[b>>2];c[276729]=e;c[276730]=e;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)!=1106856){f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}function EB(){var b=0,d=0,e=0,f=0,g=0;b=c[276726]|0;d=c[b>>2]|0;e=(d&65535)-5|0;c[276731]=e>>>31^1;c[276732]=4-d&32768&c[b>>2];c[276729]=e;c[276730]=e;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)!=1106856){f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}function EC(){var b=0,d=0,e=0,f=0,g=0;b=c[276726]|0;d=c[b>>2]|0;e=(d&65535)-6|0;c[276731]=e>>>31^1;c[276732]=5-d&32768&c[b>>2];c[276729]=e;c[276730]=e;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)!=1106856){f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}function ED(){var b=0,d=0,e=0,f=0,g=0;b=c[276726]|0;d=c[b>>2]|0;e=(d&65535)-7|0;c[276731]=e>>>31^1;c[276732]=6-d&32768&c[b>>2];c[276729]=e;c[276730]=e;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)!=1106856){f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}function EE(){var b=0,d=0,e=0,f=0,g=0;b=c[276726]|0;d=c[b>>2]|0;e=(d&65535)-8|0;c[276731]=e>>>31^1;c[276732]=7-d&32768&c[b>>2];c[276729]=e;c[276730]=e;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)!=1106856){f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}function EF(){var b=0,d=0,e=0,f=0,g=0;b=c[276726]|0;d=c[b>>2]|0;e=(d&65535)-9|0;c[276731]=e>>>31^1;c[276732]=8-d&32768&c[b>>2];c[276729]=e;c[276730]=e;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)!=1106856){f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}function EG(){var b=0,d=0,e=0,f=0,g=0;b=c[276726]|0;d=c[b>>2]|0;e=(d&65535)-10|0;c[276731]=e>>>31^1;c[276732]=9-d&32768&c[b>>2];c[276729]=e;c[276730]=e;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)!=1106856){f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}function EH(){var b=0,d=0,e=0,f=0,g=0;b=c[276726]|0;d=c[b>>2]|0;e=(d&65535)-11|0;c[276731]=e>>>31^1;c[276732]=10-d&32768&c[b>>2];c[276729]=e;c[276730]=e;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)!=1106856){f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}function EI(){var b=0,d=0,e=0,f=0,g=0;b=c[276726]|0;d=c[b>>2]|0;e=(d&65535)-12|0;c[276731]=e>>>31^1;c[276732]=11-d&32768&c[b>>2];c[276729]=e;c[276730]=e;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)!=1106856){f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}function EJ(){var b=0,d=0,e=0,f=0,g=0;b=c[276726]|0;d=c[b>>2]|0;e=(d&65535)-13|0;c[276731]=e>>>31^1;c[276732]=12-d&32768&c[b>>2];c[276729]=e;c[276730]=e;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)!=1106856){f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}function EK(){var b=0,d=0,e=0,f=0,g=0;b=c[276726]|0;d=c[b>>2]|0;e=(d&65535)-14|0;c[276731]=e>>>31^1;c[276732]=13-d&32768&c[b>>2];c[276729]=e;c[276730]=e;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)!=1106856){f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}function EL(){var b=0,d=0,e=0,f=0,g=0;b=c[276726]|0;d=c[b>>2]|0;e=(d&65535)-15|0;c[276731]=e>>>31^1;c[276732]=14-d&32768&c[b>>2];c[276729]=e;c[276730]=e;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=e;if((c[276725]|0)!=1106856){f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;f=c[276718]|0;g=f&-4865;c[276718]=g;c[276726]=1106800;c[276725]=1106800;return}function EM(){var b=0;b=c[c[276726]>>2]&1;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function EN(){var b=0;b=c[c[276726]>>2]&2;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function EO(){var b=0;b=c[c[276726]>>2]&3;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function EP(){var b=0;b=c[c[276726]>>2]&4;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function EQ(){var b=0;b=c[c[276726]>>2]&5;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function ER(){var b=0;b=c[c[276726]>>2]&6;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function ES(){var b=0;b=c[c[276726]>>2]&7;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function ET(){var b=0;b=c[c[276726]>>2]&8;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function EU(){var b=0;b=c[c[276726]>>2]&9;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function EV(){var b=0;b=c[c[276726]>>2]&10;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function EW(){var b=0;b=c[c[276726]>>2]&11;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function EX(){var b=0;b=c[c[276726]>>2]&12;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function EY(){var b=0;b=c[c[276726]>>2]&13;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function EZ(){var b=0;b=c[c[276726]>>2]&14;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function E_(){var b=0;b=c[c[276726]>>2]&15;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function E$(){c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=0;c[276729]=0;c[276730]=0;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function E0(){var b=0;b=c[c[276726]>>2]<<24>>24;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function E1(){var b=0;b=c[c[276726]>>2]<<24>>23;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function E2(){var b=0;b=(c[c[276726]>>2]<<24>>24)*3|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function E3(){var b=0;b=c[c[276726]>>2]<<24>>22;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function E4(){var b=0;b=(c[c[276726]>>2]<<24>>24)*5|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function E5(){var b=0;b=(c[c[276726]>>2]<<24>>24)*6|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function E6(){var b=0;b=(c[c[276726]>>2]<<24>>24)*7|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function E7(){var b=0;b=c[c[276726]>>2]<<24>>21;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function E8(){var b=0;b=(c[c[276726]>>2]<<24>>24)*9|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function E9(){var b=0;b=(c[c[276726]>>2]<<24>>24)*10|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Fa(){var b=0;b=(c[c[276726]>>2]<<24>>24)*11|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Fb(){var b=0;b=(c[c[276726]>>2]<<24>>24)*12|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Fc(){var b=0;b=(c[c[276726]>>2]<<24>>24)*13|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Fd(){var b=0;b=(c[c[276726]>>2]<<24>>24)*14|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Fe(){var b=0;b=(c[c[276726]>>2]<<24>>24)*15|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Ff(){var b=0,e=0,f=0;b=c[276700]|0;e=(d[1106909]|0)<<1;c[276724]=e;f=(c[276715]|0)+1|0;c[276715]=f;a[1106909]=a[(c[276816]|0)+(f&65535)|0]|0;a[(c[276814]|0)+e|0]=b&255;a[(c[276814]|0)+((c[276724]|0)+1&65535)|0]=b>>>8&255;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function Fg(){var b=0,e=0,f=0;b=c[276701]|0;e=(d[1106909]|0)<<1;c[276724]=e;f=(c[276715]|0)+1|0;c[276715]=f;a[1106909]=a[(c[276816]|0)+(f&65535)|0]|0;a[(c[276814]|0)+e|0]=b&255;a[(c[276814]|0)+((c[276724]|0)+1&65535)|0]=b>>>8&255;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function Fh(){var b=0,e=0,f=0;b=c[276702]|0;e=(d[1106909]|0)<<1;c[276724]=e;f=(c[276715]|0)+1|0;c[276715]=f;a[1106909]=a[(c[276816]|0)+(f&65535)|0]|0;a[(c[276814]|0)+e|0]=b&255;a[(c[276814]|0)+((c[276724]|0)+1&65535)|0]=b>>>8&255;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function Fi(){var b=0,e=0,f=0;b=c[276703]|0;e=(d[1106909]|0)<<1;c[276724]=e;f=(c[276715]|0)+1|0;c[276715]=f;a[1106909]=a[(c[276816]|0)+(f&65535)|0]|0;a[(c[276814]|0)+e|0]=b&255;a[(c[276814]|0)+((c[276724]|0)+1&65535)|0]=b>>>8&255;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function Fj(){var b=0,e=0,f=0;b=c[276704]|0;e=(d[1106909]|0)<<1;c[276724]=e;f=(c[276715]|0)+1|0;c[276715]=f;a[1106909]=a[(c[276816]|0)+(f&65535)|0]|0;a[(c[276814]|0)+e|0]=b&255;a[(c[276814]|0)+((c[276724]|0)+1&65535)|0]=b>>>8&255;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function Fk(){var b=0,e=0,f=0;b=c[276705]|0;e=(d[1106909]|0)<<1;c[276724]=e;f=(c[276715]|0)+1|0;c[276715]=f;a[1106909]=a[(c[276816]|0)+(f&65535)|0]|0;a[(c[276814]|0)+e|0]=b&255;a[(c[276814]|0)+((c[276724]|0)+1&65535)|0]=b>>>8&255;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function Fl(){var b=0,e=0,f=0;b=c[276706]|0;e=(d[1106909]|0)<<1;c[276724]=e;f=(c[276715]|0)+1|0;c[276715]=f;a[1106909]=a[(c[276816]|0)+(f&65535)|0]|0;a[(c[276814]|0)+e|0]=b&255;a[(c[276814]|0)+((c[276724]|0)+1&65535)|0]=b>>>8&255;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function Fm(){var b=0,e=0,f=0;b=c[276707]|0;e=(d[1106909]|0)<<1;c[276724]=e;f=(c[276715]|0)+1|0;c[276715]=f;a[1106909]=a[(c[276816]|0)+(f&65535)|0]|0;a[(c[276814]|0)+e|0]=b&255;a[(c[276814]|0)+((c[276724]|0)+1&65535)|0]=b>>>8&255;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function Fn(){var b=0,e=0,f=0;b=c[276708]|0;e=(d[1106909]|0)<<1;c[276724]=e;f=(c[276715]|0)+1|0;c[276715]=f;a[1106909]=a[(c[276816]|0)+(f&65535)|0]|0;a[(c[276814]|0)+e|0]=b&255;a[(c[276814]|0)+((c[276724]|0)+1&65535)|0]=b>>>8&255;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function Fo(){var b=0,e=0,f=0;b=c[276709]|0;e=(d[1106909]|0)<<1;c[276724]=e;f=(c[276715]|0)+1|0;c[276715]=f;a[1106909]=a[(c[276816]|0)+(f&65535)|0]|0;a[(c[276814]|0)+e|0]=b&255;a[(c[276814]|0)+((c[276724]|0)+1&65535)|0]=b>>>8&255;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function Fp(){var b=0,e=0,f=0;b=c[276710]|0;e=(d[1106909]|0)<<1;c[276724]=e;f=(c[276715]|0)+1|0;c[276715]=f;a[1106909]=a[(c[276816]|0)+(f&65535)|0]|0;a[(c[276814]|0)+e|0]=b&255;a[(c[276814]|0)+((c[276724]|0)+1&65535)|0]=b>>>8&255;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function Fq(){var b=0,e=0,f=0;b=c[276711]|0;e=(d[1106909]|0)<<1;c[276724]=e;f=(c[276715]|0)+1|0;c[276715]=f;a[1106909]=a[(c[276816]|0)+(f&65535)|0]|0;a[(c[276814]|0)+e|0]=b&255;a[(c[276814]|0)+((c[276724]|0)+1&65535)|0]=b>>>8&255;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function Fr(){var b=0,e=0,f=0;b=c[276712]|0;e=(d[1106909]|0)<<1;c[276724]=e;f=(c[276715]|0)+1|0;c[276715]=f;a[1106909]=a[(c[276816]|0)+(f&65535)|0]|0;a[(c[276814]|0)+e|0]=b&255;a[(c[276814]|0)+((c[276724]|0)+1&65535)|0]=b>>>8&255;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function Fs(){var b=0,e=0,f=0;b=c[276713]|0;e=(d[1106909]|0)<<1;c[276724]=e;f=(c[276715]|0)+1|0;c[276715]=f;a[1106909]=a[(c[276816]|0)+(f&65535)|0]|0;a[(c[276814]|0)+e|0]=b&255;a[(c[276814]|0)+((c[276724]|0)+1&65535)|0]=b>>>8&255;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function Ft(){var b=0,e=0,f=0;b=c[276714]|0;e=(d[1106909]|0)<<1;c[276724]=e;f=(c[276715]|0)+1|0;c[276715]=f;a[1106909]=a[(c[276816]|0)+(f&65535)|0]|0;a[(c[276814]|0)+e|0]=b&255;a[(c[276814]|0)+((c[276724]|0)+1&65535)|0]=b>>>8&255;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function Fu(){var b=0,e=0,f=0;b=c[276715]|0;e=(d[1106909]|0)<<1;c[276724]=e;f=b+1|0;c[276715]=f;a[1106909]=a[(c[276816]|0)+(f&65535)|0]|0;a[(c[276814]|0)+e|0]=b&255;a[(c[276814]|0)+((c[276724]|0)+1&65535)|0]=b>>>8&255;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function Fv(){var b=0;b=c[c[276726]>>2]|1;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Fw(){var b=0;b=c[c[276726]>>2]|2;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Fx(){var b=0;b=c[c[276726]>>2]|3;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Fy(){var b=0;b=c[c[276726]>>2]|4;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Fz(){var b=0;b=c[c[276726]>>2]|5;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function FA(){var b=0;b=c[c[276726]>>2]|6;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function FB(){var b=0;b=c[c[276726]>>2]|7;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function FC(){var b=0;b=c[c[276726]>>2]|8;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function FD(){var b=0;b=c[c[276726]>>2]|9;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function FE(){var b=0;b=c[c[276726]>>2]|10;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function FF(){var b=0;b=c[c[276726]>>2]|11;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function FG(){var b=0;b=c[c[276726]>>2]|12;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function FH(){var b=0;b=c[c[276726]>>2]|13;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function FI(){var b=0;b=c[c[276726]>>2]|14;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function FJ(){var b=0;b=c[c[276726]>>2]|15;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function FK(){var a=0;a=c[c[276726]>>2]&3;c[276721]=a;c[276814]=c[1107268+(a<<2)>>2];c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function FL(){var b=0;b=c[c[276726]>>2]&65280|(d[1106908]|0);c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function FM(){var b=0,e=0,f=0,g=0,h=0,i=0;b=c[276700]|0;e=d[1106909]|0;c[276724]=e;f=c[276715]|0;g=f+1|0;c[276715]=g;h=c[276816]|0;i=a[h+(g&65535)|0]|0;a[1106909]=i;g=f+2|0;c[276715]=g;f=(i&255)<<8|e;c[276724]=f;a[1106909]=a[h+(g&65535)|0]|0;a[(c[276814]|0)+f|0]=b&255;a[(c[276814]|0)+(c[276724]&65535^1)|0]=b>>>8&255;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function FN(){var b=0,e=0,f=0,g=0,h=0,i=0;b=c[276701]|0;e=d[1106909]|0;c[276724]=e;f=c[276715]|0;g=f+1|0;c[276715]=g;h=c[276816]|0;i=a[h+(g&65535)|0]|0;a[1106909]=i;g=f+2|0;c[276715]=g;f=(i&255)<<8|e;c[276724]=f;a[1106909]=a[h+(g&65535)|0]|0;a[(c[276814]|0)+f|0]=b&255;a[(c[276814]|0)+(c[276724]&65535^1)|0]=b>>>8&255;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function FO(){var b=0,e=0,f=0,g=0,h=0,i=0;b=c[276702]|0;e=d[1106909]|0;c[276724]=e;f=c[276715]|0;g=f+1|0;c[276715]=g;h=c[276816]|0;i=a[h+(g&65535)|0]|0;a[1106909]=i;g=f+2|0;c[276715]=g;f=(i&255)<<8|e;c[276724]=f;a[1106909]=a[h+(g&65535)|0]|0;a[(c[276814]|0)+f|0]=b&255;a[(c[276814]|0)+(c[276724]&65535^1)|0]=b>>>8&255;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function FP(){var b=0,e=0,f=0,g=0,h=0,i=0;b=c[276703]|0;e=d[1106909]|0;c[276724]=e;f=c[276715]|0;g=f+1|0;c[276715]=g;h=c[276816]|0;i=a[h+(g&65535)|0]|0;a[1106909]=i;g=f+2|0;c[276715]=g;f=(i&255)<<8|e;c[276724]=f;a[1106909]=a[h+(g&65535)|0]|0;a[(c[276814]|0)+f|0]=b&255;a[(c[276814]|0)+(c[276724]&65535^1)|0]=b>>>8&255;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function FQ(){var b=0,e=0,f=0,g=0,h=0,i=0;b=c[276704]|0;e=d[1106909]|0;c[276724]=e;f=c[276715]|0;g=f+1|0;c[276715]=g;h=c[276816]|0;i=a[h+(g&65535)|0]|0;a[1106909]=i;g=f+2|0;c[276715]=g;f=(i&255)<<8|e;c[276724]=f;a[1106909]=a[h+(g&65535)|0]|0;a[(c[276814]|0)+f|0]=b&255;a[(c[276814]|0)+(c[276724]&65535^1)|0]=b>>>8&255;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function FR(){var b=0,e=0,f=0,g=0,h=0,i=0;b=c[276705]|0;e=d[1106909]|0;c[276724]=e;f=c[276715]|0;g=f+1|0;c[276715]=g;h=c[276816]|0;i=a[h+(g&65535)|0]|0;a[1106909]=i;g=f+2|0;c[276715]=g;f=(i&255)<<8|e;c[276724]=f;a[1106909]=a[h+(g&65535)|0]|0;a[(c[276814]|0)+f|0]=b&255;a[(c[276814]|0)+(c[276724]&65535^1)|0]=b>>>8&255;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function FS(){var b=0,e=0,f=0,g=0,h=0,i=0;b=c[276706]|0;e=d[1106909]|0;c[276724]=e;f=c[276715]|0;g=f+1|0;c[276715]=g;h=c[276816]|0;i=a[h+(g&65535)|0]|0;a[1106909]=i;g=f+2|0;c[276715]=g;f=(i&255)<<8|e;c[276724]=f;a[1106909]=a[h+(g&65535)|0]|0;a[(c[276814]|0)+f|0]=b&255;a[(c[276814]|0)+(c[276724]&65535^1)|0]=b>>>8&255;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function FT(){var b=0,e=0,f=0,g=0,h=0,i=0;b=c[276707]|0;e=d[1106909]|0;c[276724]=e;f=c[276715]|0;g=f+1|0;c[276715]=g;h=c[276816]|0;i=a[h+(g&65535)|0]|0;a[1106909]=i;g=f+2|0;c[276715]=g;f=(i&255)<<8|e;c[276724]=f;a[1106909]=a[h+(g&65535)|0]|0;a[(c[276814]|0)+f|0]=b&255;a[(c[276814]|0)+(c[276724]&65535^1)|0]=b>>>8&255;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function FU(){var b=0,e=0,f=0,g=0,h=0,i=0;b=c[276708]|0;e=d[1106909]|0;c[276724]=e;f=c[276715]|0;g=f+1|0;c[276715]=g;h=c[276816]|0;i=a[h+(g&65535)|0]|0;a[1106909]=i;g=f+2|0;c[276715]=g;f=(i&255)<<8|e;c[276724]=f;a[1106909]=a[h+(g&65535)|0]|0;a[(c[276814]|0)+f|0]=b&255;a[(c[276814]|0)+(c[276724]&65535^1)|0]=b>>>8&255;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function FV(){var b=0,e=0,f=0,g=0,h=0,i=0;b=c[276709]|0;e=d[1106909]|0;c[276724]=e;f=c[276715]|0;g=f+1|0;c[276715]=g;h=c[276816]|0;i=a[h+(g&65535)|0]|0;a[1106909]=i;g=f+2|0;c[276715]=g;f=(i&255)<<8|e;c[276724]=f;a[1106909]=a[h+(g&65535)|0]|0;a[(c[276814]|0)+f|0]=b&255;a[(c[276814]|0)+(c[276724]&65535^1)|0]=b>>>8&255;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function FW(){var b=0,e=0,f=0,g=0,h=0,i=0;b=c[276710]|0;e=d[1106909]|0;c[276724]=e;f=c[276715]|0;g=f+1|0;c[276715]=g;h=c[276816]|0;i=a[h+(g&65535)|0]|0;a[1106909]=i;g=f+2|0;c[276715]=g;f=(i&255)<<8|e;c[276724]=f;a[1106909]=a[h+(g&65535)|0]|0;a[(c[276814]|0)+f|0]=b&255;a[(c[276814]|0)+(c[276724]&65535^1)|0]=b>>>8&255;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function FX(){var b=0,e=0,f=0,g=0,h=0,i=0;b=c[276711]|0;e=d[1106909]|0;c[276724]=e;f=c[276715]|0;g=f+1|0;c[276715]=g;h=c[276816]|0;i=a[h+(g&65535)|0]|0;a[1106909]=i;g=f+2|0;c[276715]=g;f=(i&255)<<8|e;c[276724]=f;a[1106909]=a[h+(g&65535)|0]|0;a[(c[276814]|0)+f|0]=b&255;a[(c[276814]|0)+(c[276724]&65535^1)|0]=b>>>8&255;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function FY(){var b=0,e=0,f=0,g=0,h=0,i=0;b=c[276712]|0;e=d[1106909]|0;c[276724]=e;f=c[276715]|0;g=f+1|0;c[276715]=g;h=c[276816]|0;i=a[h+(g&65535)|0]|0;a[1106909]=i;g=f+2|0;c[276715]=g;f=(i&255)<<8|e;c[276724]=f;a[1106909]=a[h+(g&65535)|0]|0;a[(c[276814]|0)+f|0]=b&255;a[(c[276814]|0)+(c[276724]&65535^1)|0]=b>>>8&255;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function FZ(){var b=0,e=0,f=0,g=0,h=0,i=0;b=c[276713]|0;e=d[1106909]|0;c[276724]=e;f=c[276715]|0;g=f+1|0;c[276715]=g;h=c[276816]|0;i=a[h+(g&65535)|0]|0;a[1106909]=i;g=f+2|0;c[276715]=g;f=(i&255)<<8|e;c[276724]=f;a[1106909]=a[h+(g&65535)|0]|0;a[(c[276814]|0)+f|0]=b&255;a[(c[276814]|0)+(c[276724]&65535^1)|0]=b>>>8&255;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function F_(){var b=0,e=0,f=0,g=0,h=0,i=0;b=c[276714]|0;e=d[1106909]|0;c[276724]=e;f=c[276715]|0;g=f+1|0;c[276715]=g;h=c[276816]|0;i=a[h+(g&65535)|0]|0;a[1106909]=i;g=f+2|0;c[276715]=g;f=(i&255)<<8|e;c[276724]=f;a[1106909]=a[h+(g&65535)|0]|0;a[(c[276814]|0)+f|0]=b&255;a[(c[276814]|0)+(c[276724]&65535^1)|0]=b>>>8&255;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function F$(){var b=0,e=0,f=0,g=0,h=0,i=0;b=c[276715]|0;e=d[1106909]|0;c[276724]=e;f=b+1|0;c[276715]=f;g=c[276816]|0;h=a[g+(f&65535)|0]|0;a[1106909]=h;f=b+2|0;c[276715]=f;i=(h&255)<<8|e;c[276724]=i;a[1106909]=a[g+(f&65535)|0]|0;a[(c[276814]|0)+i|0]=b&255;a[(c[276814]|0)+(c[276724]&65535^1)|0]=b>>>8&255;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function F0(){var b=0,d=0,e=0,f=0;b=c[276726]|0;d=(c[276731]&65535)+(c[b>>2]&65535)|0;c[276731]=(d|0)>65535;c[276732]=d&32768&(c[b>>2]^32768);c[276729]=d;c[276730]=d;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=d;if((c[276725]|0)!=1106856){e=c[276718]|0;f=e&-4865;c[276718]=f;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;e=c[276718]|0;f=e&-4865;c[276718]=f;c[276726]=1106800;c[276725]=1106800;return}function F1(){var b=0,d=0,e=0,f=0;b=c[276726]|0;d=(c[b>>2]&65535)+1+(c[276731]&65535)|0;c[276731]=(d|0)>65535;c[276732]=d&32768&(c[b>>2]^32768);c[276729]=d;c[276730]=d;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=d;if((c[276725]|0)!=1106856){e=c[276718]|0;f=e&-4865;c[276718]=f;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;e=c[276718]|0;f=e&-4865;c[276718]=f;c[276726]=1106800;c[276725]=1106800;return}function F2(){var b=0,d=0,e=0,f=0;b=c[276726]|0;d=(c[b>>2]&65535)+2+(c[276731]&65535)|0;c[276731]=(d|0)>65535;c[276732]=d&32768&(c[b>>2]^32768);c[276729]=d;c[276730]=d;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=d;if((c[276725]|0)!=1106856){e=c[276718]|0;f=e&-4865;c[276718]=f;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;e=c[276718]|0;f=e&-4865;c[276718]=f;c[276726]=1106800;c[276725]=1106800;return}function F3(){var a=0,b=0,d=0,e=0;a=c[276726]|0;b=c[276700]|0;d=(c[a>>2]&65535)-(b&65535)|0;c[276731]=d>>>31^1;e=c[a>>2]|0;c[276732]=(e^b)&32768&(d^e);c[276729]=d;c[276730]=d;c[276715]=(c[276715]|0)+1;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function F4(){var a=0,b=0,d=0,e=0;a=c[276726]|0;b=c[276701]|0;d=(c[a>>2]&65535)-(b&65535)|0;c[276731]=d>>>31^1;e=c[a>>2]|0;c[276732]=(e^b)&32768&(d^e);c[276729]=d;c[276730]=d;c[276715]=(c[276715]|0)+1;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function F5(){var a=0,b=0,d=0,e=0;a=c[276726]|0;b=c[276702]|0;d=(c[a>>2]&65535)-(b&65535)|0;c[276731]=d>>>31^1;e=c[a>>2]|0;c[276732]=(e^b)&32768&(d^e);c[276729]=d;c[276730]=d;c[276715]=(c[276715]|0)+1;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function F6(){var a=0,b=0,d=0,e=0;a=c[276726]|0;b=c[276703]|0;d=(c[a>>2]&65535)-(b&65535)|0;c[276731]=d>>>31^1;e=c[a>>2]|0;c[276732]=(e^b)&32768&(d^e);c[276729]=d;c[276730]=d;c[276715]=(c[276715]|0)+1;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function F7(){var a=0,b=0,d=0,e=0;a=c[276726]|0;b=c[276704]|0;d=(c[a>>2]&65535)-(b&65535)|0;c[276731]=d>>>31^1;e=c[a>>2]|0;c[276732]=(e^b)&32768&(d^e);c[276729]=d;c[276730]=d;c[276715]=(c[276715]|0)+1;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function F8(){var a=0,b=0,d=0,e=0;a=c[276726]|0;b=c[276705]|0;d=(c[a>>2]&65535)-(b&65535)|0;c[276731]=d>>>31^1;e=c[a>>2]|0;c[276732]=(e^b)&32768&(d^e);c[276729]=d;c[276730]=d;c[276715]=(c[276715]|0)+1;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function F9(){var a=0,b=0,d=0,e=0;a=c[276726]|0;b=c[276706]|0;d=(c[a>>2]&65535)-(b&65535)|0;c[276731]=d>>>31^1;e=c[a>>2]|0;c[276732]=(e^b)&32768&(d^e);c[276729]=d;c[276730]=d;c[276715]=(c[276715]|0)+1;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Ga(){var a=0,b=0,d=0,e=0;a=c[276726]|0;b=c[276707]|0;d=(c[a>>2]&65535)-(b&65535)|0;c[276731]=d>>>31^1;e=c[a>>2]|0;c[276732]=(e^b)&32768&(d^e);c[276729]=d;c[276730]=d;c[276715]=(c[276715]|0)+1;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Gb(){var a=0,b=0,d=0,e=0;a=c[276726]|0;b=c[276708]|0;d=(c[a>>2]&65535)-(b&65535)|0;c[276731]=d>>>31^1;e=c[a>>2]|0;c[276732]=(e^b)&32768&(d^e);c[276729]=d;c[276730]=d;c[276715]=(c[276715]|0)+1;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Gc(){var a=0,b=0,d=0,e=0;a=c[276726]|0;b=c[276709]|0;d=(c[a>>2]&65535)-(b&65535)|0;c[276731]=d>>>31^1;e=c[a>>2]|0;c[276732]=(e^b)&32768&(d^e);c[276729]=d;c[276730]=d;c[276715]=(c[276715]|0)+1;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Gd(){var a=0,b=0,d=0,e=0;a=c[276726]|0;b=c[276710]|0;d=(c[a>>2]&65535)-(b&65535)|0;c[276731]=d>>>31^1;e=c[a>>2]|0;c[276732]=(e^b)&32768&(d^e);c[276729]=d;c[276730]=d;c[276715]=(c[276715]|0)+1;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Ge(){var a=0,b=0,d=0,e=0;a=c[276726]|0;b=c[276711]|0;d=(c[a>>2]&65535)-(b&65535)|0;c[276731]=d>>>31^1;e=c[a>>2]|0;c[276732]=(e^b)&32768&(d^e);c[276729]=d;c[276730]=d;c[276715]=(c[276715]|0)+1;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Gf(){var a=0,b=0,d=0,e=0;a=c[276726]|0;b=c[276712]|0;d=(c[a>>2]&65535)-(b&65535)|0;c[276731]=d>>>31^1;e=c[a>>2]|0;c[276732]=(e^b)&32768&(d^e);c[276729]=d;c[276730]=d;c[276715]=(c[276715]|0)+1;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Gg(){var a=0,b=0,d=0,e=0;a=c[276726]|0;b=c[276713]|0;d=(c[a>>2]&65535)-(b&65535)|0;c[276731]=d>>>31^1;e=c[a>>2]|0;c[276732]=(e^b)&32768&(d^e);c[276729]=d;c[276730]=d;c[276715]=(c[276715]|0)+1;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Gh(){var a=0,b=0,d=0,e=0;a=c[276726]|0;b=c[276714]|0;d=(c[a>>2]&65535)-(b&65535)|0;c[276731]=d>>>31^1;e=c[a>>2]|0;c[276732]=(e^b)&32768&(d^e);c[276729]=d;c[276730]=d;c[276715]=(c[276715]|0)+1;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Gi(){var b=0,d=0,e=0,f=0;b=c[276726]|0;d=(c[b>>2]&65535)+3+(c[276731]&65535)|0;c[276731]=(d|0)>65535;c[276732]=d&32768&(c[b>>2]^32768);c[276729]=d;c[276730]=d;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=d;if((c[276725]|0)!=1106856){e=c[276718]|0;f=e&-4865;c[276718]=f;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;e=c[276718]|0;f=e&-4865;c[276718]=f;c[276726]=1106800;c[276725]=1106800;return}function Gj(){var b=0,d=0,e=0,f=0;b=c[276726]|0;d=(c[b>>2]&65535)+4+(c[276731]&65535)|0;c[276731]=(d|0)>65535;c[276732]=d&32768&(c[b>>2]^32768);c[276729]=d;c[276730]=d;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=d;if((c[276725]|0)!=1106856){e=c[276718]|0;f=e&-4865;c[276718]=f;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;e=c[276718]|0;f=e&-4865;c[276718]=f;c[276726]=1106800;c[276725]=1106800;return}function Gk(){var b=0,d=0,e=0,f=0;b=c[276726]|0;d=(c[b>>2]&65535)+5+(c[276731]&65535)|0;c[276731]=(d|0)>65535;c[276732]=d&32768&(c[b>>2]^32768);c[276729]=d;c[276730]=d;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=d;if((c[276725]|0)!=1106856){e=c[276718]|0;f=e&-4865;c[276718]=f;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;e=c[276718]|0;f=e&-4865;c[276718]=f;c[276726]=1106800;c[276725]=1106800;return}function Gl(){var b=0,d=0,e=0,f=0;b=c[276726]|0;d=(c[b>>2]&65535)+6+(c[276731]&65535)|0;c[276731]=(d|0)>65535;c[276732]=d&32768&(c[b>>2]^32768);c[276729]=d;c[276730]=d;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=d;if((c[276725]|0)!=1106856){e=c[276718]|0;f=e&-4865;c[276718]=f;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;e=c[276718]|0;f=e&-4865;c[276718]=f;c[276726]=1106800;c[276725]=1106800;return}function Gm(){var b=0,d=0,e=0,f=0;b=c[276726]|0;d=(c[b>>2]&65535)+7+(c[276731]&65535)|0;c[276731]=(d|0)>65535;c[276732]=d&32768&(c[b>>2]^32768);c[276729]=d;c[276730]=d;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=d;if((c[276725]|0)!=1106856){e=c[276718]|0;f=e&-4865;c[276718]=f;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;e=c[276718]|0;f=e&-4865;c[276718]=f;c[276726]=1106800;c[276725]=1106800;return}function Gn(){var b=0,d=0,e=0,f=0;b=c[276726]|0;d=(c[b>>2]&65535)+8+(c[276731]&65535)|0;c[276731]=(d|0)>65535;c[276732]=d&32768&(c[b>>2]^32768);c[276729]=d;c[276730]=d;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=d;if((c[276725]|0)!=1106856){e=c[276718]|0;f=e&-4865;c[276718]=f;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;e=c[276718]|0;f=e&-4865;c[276718]=f;c[276726]=1106800;c[276725]=1106800;return}function Go(){var b=0,d=0,e=0,f=0;b=c[276726]|0;d=(c[b>>2]&65535)+9+(c[276731]&65535)|0;c[276731]=(d|0)>65535;c[276732]=d&32768&(c[b>>2]^32768);c[276729]=d;c[276730]=d;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=d;if((c[276725]|0)!=1106856){e=c[276718]|0;f=e&-4865;c[276718]=f;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;e=c[276718]|0;f=e&-4865;c[276718]=f;c[276726]=1106800;c[276725]=1106800;return}function Gp(){var b=0,d=0,e=0,f=0;b=c[276726]|0;d=(c[b>>2]&65535)+10+(c[276731]&65535)|0;c[276731]=(d|0)>65535;c[276732]=d&32768&(c[b>>2]^32768);c[276729]=d;c[276730]=d;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=d;if((c[276725]|0)!=1106856){e=c[276718]|0;f=e&-4865;c[276718]=f;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;e=c[276718]|0;f=e&-4865;c[276718]=f;c[276726]=1106800;c[276725]=1106800;return}function Gq(){var b=0,d=0,e=0,f=0;b=c[276726]|0;d=(c[b>>2]&65535)+11+(c[276731]&65535)|0;c[276731]=(d|0)>65535;c[276732]=d&32768&(c[b>>2]^32768);c[276729]=d;c[276730]=d;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=d;if((c[276725]|0)!=1106856){e=c[276718]|0;f=e&-4865;c[276718]=f;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;e=c[276718]|0;f=e&-4865;c[276718]=f;c[276726]=1106800;c[276725]=1106800;return}function Gr(){var b=0,d=0,e=0,f=0;b=c[276726]|0;d=(c[b>>2]&65535)+12+(c[276731]&65535)|0;c[276731]=(d|0)>65535;c[276732]=d&32768&(c[b>>2]^32768);c[276729]=d;c[276730]=d;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=d;if((c[276725]|0)!=1106856){e=c[276718]|0;f=e&-4865;c[276718]=f;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;e=c[276718]|0;f=e&-4865;c[276718]=f;c[276726]=1106800;c[276725]=1106800;return}function Gs(){var b=0,d=0,e=0,f=0;b=c[276726]|0;d=(c[b>>2]&65535)+13+(c[276731]&65535)|0;c[276731]=(d|0)>65535;c[276732]=d&32768&(c[b>>2]^32768);c[276729]=d;c[276730]=d;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=d;if((c[276725]|0)!=1106856){e=c[276718]|0;f=e&-4865;c[276718]=f;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;e=c[276718]|0;f=e&-4865;c[276718]=f;c[276726]=1106800;c[276725]=1106800;return}function Gt(){var b=0,d=0,e=0,f=0;b=c[276726]|0;d=(c[b>>2]&65535)+14+(c[276731]&65535)|0;c[276731]=(d|0)>65535;c[276732]=d&32768&(c[b>>2]^32768);c[276729]=d;c[276730]=d;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=d;if((c[276725]|0)!=1106856){e=c[276718]|0;f=e&-4865;c[276718]=f;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;e=c[276718]|0;f=e&-4865;c[276718]=f;c[276726]=1106800;c[276725]=1106800;return}function Gu(){var b=0,d=0,e=0,f=0;b=c[276726]|0;d=(c[b>>2]&65535)+15+(c[276731]&65535)|0;c[276731]=(d|0)>65535;c[276732]=d&32768&(c[b>>2]^32768);c[276729]=d;c[276730]=d;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=d;if((c[276725]|0)!=1106856){e=c[276718]|0;f=e&-4865;c[276718]=f;c[276726]=1106800;c[276725]=1106800;return}a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0;e=c[276718]|0;f=e&-4865;c[276718]=f;c[276726]=1106800;c[276725]=1106800;return}function Gv(){var a=0,b=0,d=0,e=0;a=c[276726]|0;b=c[276715]|0;d=(c[a>>2]&65535)-(b&65535)|0;c[276731]=d>>>31^1;e=c[a>>2]|0;c[276732]=(e^b)&32768&(d^e);c[276729]=d;c[276730]=d;c[276715]=b+1;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Gw(){var b=0;b=c[c[276726]>>2]&-2;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Gx(){var b=0;b=c[c[276726]>>2]&-3;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Gy(){var b=0;b=c[c[276726]>>2]&-4;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Gz(){var b=0;b=c[c[276726]>>2]&-5;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function GA(){var b=0;b=c[c[276726]>>2]&-6;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function GB(){var b=0;b=c[c[276726]>>2]&-7;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function GC(){var b=0;b=c[c[276726]>>2]&-8;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function GD(){var b=0;b=c[c[276726]>>2]&-9;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function GE(){var b=0;b=c[c[276726]>>2]&-10;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function GF(){var b=0;b=c[c[276726]>>2]&-11;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function GG(){var b=0;b=c[c[276726]>>2]&-12;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function GH(){var b=0;b=c[c[276726]>>2]&-13;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function GI(){var b=0;b=c[c[276726]>>2]&-14;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function GJ(){var b=0;b=c[c[276726]>>2]&-15;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function GK(){var b=0;b=c[c[276726]>>2]&-16;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function GL(){c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=0;c[276729]=0;c[276730]=0;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function GM(){var b=0;b=c[c[276726]>>2]&255;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function GN(){var b=0;b=c[c[276726]>>2]<<1&510;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function GO(){var b=0;b=(c[c[276726]>>2]&255)*3|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function GP(){var b=0;b=c[c[276726]>>2]<<2&1020;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function GQ(){var b=0;b=(c[c[276726]>>2]&255)*5|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function GR(){var b=0;b=(c[c[276726]>>2]&255)*6|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function GS(){var b=0;b=(c[c[276726]>>2]&255)*7|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function GT(){var b=0;b=c[c[276726]>>2]<<3&2040;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function GU(){var b=0;b=(c[c[276726]>>2]&255)*9|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function GV(){var b=0;b=(c[c[276726]>>2]&255)*10|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function GW(){var b=0;b=(c[c[276726]>>2]&255)*11|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function GX(){var b=0;b=(c[c[276726]>>2]&255)*12|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function GY(){var b=0;b=(c[c[276726]>>2]&255)*13|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function GZ(){var b=0;b=(c[c[276726]>>2]&255)*14|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function G_(){var b=0;b=(c[c[276726]>>2]&255)*15|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function G$(){var b=0;b=c[c[276726]>>2]^1;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function G0(){var b=0;b=c[c[276726]>>2]^2;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function G1(){var b=0;b=c[c[276726]>>2]^3;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function G2(){var b=0;b=c[c[276726]>>2]^4;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function G3(){var b=0;b=c[c[276726]>>2]^5;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function G4(){var b=0;b=c[c[276726]>>2]^6;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function G5(){var b=0;b=c[c[276726]>>2]^7;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function G6(){var b=0;b=c[c[276726]>>2]^8;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function G7(){var b=0;b=c[c[276726]>>2]^9;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function G8(){var b=0;b=c[c[276726]>>2]^10;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function G9(){var b=0;b=c[c[276726]>>2]^11;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Ha(){var b=0;b=c[c[276726]>>2]^12;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Hb(){var b=0;b=c[c[276726]>>2]^13;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Hc(){var b=0;b=c[c[276726]>>2]^14;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Hd(){var b=0;b=c[c[276726]>>2]^15;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;c[276729]=b;c[276730]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function He(){var a=0;a=c[c[276726]>>2]&127;c[276720]=a;c[276815]=c[1107284+(a<<2)>>2];c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276715]=(c[276715]|0)+1;return}function Hf(){var b=0;b=a[1106908]|0;c[276715]=(c[276715]|0)+1;c[c[276725]>>2]=b;if((c[276725]|0)==1106856){a[1106908]=a[(c[276815]|0)+(c[276714]&65535)|0]|0}c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;return}function Hg(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;c[277209]=0;a=c[276745]|0;b=c[276743]|0;d=(b-2|2-b)>>31;e=c[276810]|0;f=(d&3^3|d&b)+1|0;if((e|0)==256){b=f<<13;d=f<<12;g=0;h=0;i=0;while(1){j=ab(h,f)|0;k=g+16|0;c[1106984+(g<<2)>>2]=a+j;l=ab(i,f)|0;c[1107112+(g<<2)>>2]=l;c[1106984+(k<<2)>>2]=a+(j+b);c[1107112+(k<<2)>>2]=l+d;l=g+1|0;if((l|0)<16){g=l;h=h+256|0;i=i+16|0}else{break}}m=c[276743]|0;c[276744]=m;n=c[276810]|0;c[276812]=n;return}else{i=ab(e<<1,f)|0;e=0;h=0;while(1){c[1107112+(e<<2)>>2]=ab(i,e)|0;c[1106984+(e<<2)>>2]=a+(ab(h,f)|0);g=e+1|0;if((g|0)<32){e=g;h=h+16|0}else{break}}m=c[276743]|0;c[276744]=m;n=c[276810]|0;c[276812]=n;return}}function Hh(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[276701]|0;e=c[276702]|0;c[276715]=(c[276715]|0)+1;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276701]=b+1;f=c[276717]|0;if((f&2|0)==0){g=c[276716]|0}else{h=c[276716]|0;g=((e^b)&1|0)!=0?h>>>4:h}h=g&255;do{if((f&1|0)==0){if((h&15)!=0){break}return}}while(0);f=c[1106984+((e>>>3&31)<<2)>>2]|0;g=(c[1107112+((b>>>3&31)<<2)>>2]|0)+(e<<1&14)|0;e=f+g|0;i=128>>>((b&7)>>>0);b=h&255;if((b&1|0)==0){j=(d[e]|0)&(i^255)}else{j=d[e]|0|i}a[e]=j&255;if((b&2|0)==0){j=f+(g+1)|0;a[j]=(d[j]|0)&(i^255)&255}else{j=f+(g+1)|0;a[j]=(d[j]|0|i)&255}if((b&4|0)==0){j=f+(g+16)|0;a[j]=(d[j]|0)&(i^255)&255}else{j=f+(g+16)|0;a[j]=(d[j]|0|i)&255}if((b&8|0)==0){b=f+(g+17)|0;a[b]=(d[b]|0)&(i^255)&255;return}else{b=f+(g+17)|0;a[b]=(d[b]|0|i)&255;return}}function Hi(){return}function Hj(){return}function Hk(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0;b=c[276701]|0;e=c[276702]|0;c[276715]=(c[276715]|0)+1;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;c[276701]=b+1;f=c[276716]|0;g=c[276717]|0;h=(g&1|0)!=0;do{if((g&16|0)==0){if(h){break}if((f&15|0)!=0){break}return}else{if(!((f&255)<<24>>24==0&(h^1))){break}return}}while(0);h=c[1106984+((e>>>3&31)<<2)>>2]|0;g=(c[1107112+((b>>>3&31)<<2)>>2]|0)+(e<<1&14)|0;e=h+g|0;i=128>>>((b&7)>>>0);if((f&1|0)==0){j=(d[e]|0)&(i^255)}else{j=d[e]|0|i}a[e]=j&255;if((f&2|0)==0){j=h+(g+1)|0;a[j]=(d[j]|0)&(i^255)&255}else{j=h+(g+1)|0;a[j]=(d[j]|0|i)&255}if((f&4|0)==0){j=h+(g+16)|0;a[j]=(d[j]|0)&(i^255)&255}else{j=h+(g+16)|0;a[j]=(d[j]|0|i)&255}if((f&8|0)==0){j=h+(g+17)|0;a[j]=(d[j]|0)&(i^255)&255}else{j=h+(g+17)|0;a[j]=(d[j]|0|i)&255}if((f&16|0)==0){j=h+(g+32)|0;a[j]=(d[j]|0)&(i^255)&255}else{j=h+(g+32)|0;a[j]=(d[j]|0|i)&255}if((f&32|0)==0){j=h+(g+33)|0;a[j]=(d[j]|0)&(i^255)&255}else{j=h+(g+33)|0;a[j]=(d[j]|0|i)&255}if((f&64|0)==0){j=h+(g+48)|0;a[j]=(d[j]|0)&(i^255)&255}else{j=h+(g+48)|0;a[j]=(d[j]|0|i)&255}if((f&128|0)==0){f=h+(g+49)|0;a[f]=(d[f]|0)&(i^255)&255;return}else{f=h+(g+49)|0;a[f]=(d[f]|0|i)&255;return}}function Hl(){var a=0,b=0,e=0,f=0,g=0;a=c[276701]|0;b=c[276702]|0;c[276715]=(c[276715]|0)+1;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;e=c[1106984+((b>>>3&31)<<2)>>2]|0;f=(c[1107112+((a>>>3&31)<<2)>>2]|0)+(b<<1&14)|0;c[276700]=0;b=128>>>((a&7)>>>0)&255;a=((d[e+f|0]|0)&b|0)!=0|0;c[276700]=a;g=(((d[e+(f+1)|0]|0)&b|0)!=0)<<1|a;c[276700]=g;a=(((d[e+(f+16)|0]|0)&b|0)!=0)<<2|g;c[276700]=a;c[276700]=(((d[e+(f+17)|0]|0)&b|0)!=0)<<3|a;return}function Hm(){var a=0,b=0,e=0,f=0,g=0;a=c[276701]|0;b=c[276702]|0;c[276715]=(c[276715]|0)+1;c[276718]=c[276718]&-4865;c[276726]=1106800;c[276725]=1106800;e=c[1106984+((b>>>3&31)<<2)>>2]|0;f=(c[1107112+((a>>>3&31)<<2)>>2]|0)+(b<<1&14)|0;c[276700]=0;b=128>>>((a&7)>>>0)&255;a=((d[e+f|0]|0)&b|0)!=0|0;c[276700]=a;g=(((d[e+(f+1)|0]|0)&b|0)!=0)<<1|a;c[276700]=g;a=(((d[e+(f+16)|0]|0)&b|0)!=0)<<2|g;c[276700]=a;g=(((d[e+(f+17)|0]|0)&b|0)!=0)<<3|a;c[276700]=g;a=(((d[e+(f+32)|0]|0)&b|0)!=0)<<4|g;c[276700]=a;g=(((d[e+(f+33)|0]|0)&b|0)!=0)<<5|a;c[276700]=g;a=(((d[e+(f+48)|0]|0)&b|0)!=0)<<6|g;c[276700]=a;g=(((d[e+(f+49)|0]|0)&b|0)!=0)<<7|a;c[276700]=g;c[276730]=g;return}function Hn(){var b=0,d=0;b=c[263191]|0;if((b|0)!=0){XZ(b);c[263191]=0}b=c[263193]|0;if((b|0)!=0){XZ(b);c[263193]=0}b=c[263194]|0;if((b|0)!=0){XZ(b);c[263194]=0}b=c[263192]|0;if((b|0)!=0){d=b-32768|0;c[263192]=d;XZ(d);c[263192]=0}do{if((a[799127]|a[799126])<<24>>24!=0){d=c[199386]|0;if((d|0)==0){break}XZ(d)}}while(0);d=c[276523]|0;if((d|0)!=0){XZ(d);c[276523]=0}d=c[276530]|0;if((d|0)!=0){XZ(d);c[276530]=0}d=c[276524]|0;if((d|0)!=0){XZ(d);c[276524]=0}d=c[276531]|0;if((d|0)!=0){XZ(d);c[276531]=0}d=c[276525]|0;if((d|0)!=0){XZ(d);c[276525]=0}d=c[276532]|0;if((d|0)!=0){XZ(d);c[276532]=0}d=c[276526]|0;if((d|0)!=0){XZ(d);c[276526]=0}d=c[276533]|0;if((d|0)!=0){XZ(d);c[276533]=0}d=c[276527]|0;if((d|0)!=0){XZ(d);c[276527]=0}d=c[276534]|0;if((d|0)!=0){XZ(d);c[276534]=0}d=c[276528]|0;if((d|0)!=0){XZ(d);c[276528]=0}d=c[276535]|0;if((d|0)!=0){XZ(d);c[276535]=0}d=c[276529]|0;if((d|0)!=0){XZ(d);c[276529]=0}d=c[276536]|0;if((d|0)!=0){XZ(d);c[276536]=0}d=c[201856]|0;if((d|0)!=0){XZ(d);c[201856]=0}d=c[201860]|0;if((d|0)==0){return}XZ(d);c[201860]=0;return}function Ho(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;d=i;i=i+16416|0;e=d|0;f=d+8208|0;g=d+12312|0;h=g|0;c[263190]=0;j=d+4104|0;k=f|0;a[j]=0;a[k]=0;a[h]=0;l=e|0;a[l]=0;Yd(l|0,k|0)|0;m=c[198888]|0;n=c[133748]|0;if(!((m|0)!=0&(n|0)!=0)){o=0;i=d;return o|0}q=XY(12)|0;r=(q|0)==0;do{if(!r){if((c[q-4>>2]&3|0)==0){break}X2(q|0,0,12)}}while(0);s=q;c[s>>2]=m;m=q+4|0;c[m>>2]=n;n=q+8|0;c[n>>2]=0;c[198888]=0;c[133748]=0;if(r){o=0;i=d;return o|0}Yb(1093765,l|0)|0;r=f+2|0;t=f+3|0;u=f+4|0;v=f+5|0;w=b;y=w+8389120|0;z=g+1|0;g=q;q=b;b=0;A=c[m>>2]|0;m=c[n>>2]|0;n=c[s>>2]|0;L12015:while(1){s=y-q|0;B=g+8|0;C=A-m|0;D=C>>>0<s>>>0?C:s;s=n+m|0;X5(q|0,s|0,D)|0;s=(c[B>>2]|0)+D|0;c[B>>2]=s;c[125856]=s;XZ(g);s=D&-8192;if((D-s|0)==512){X9(q|0,q+512|0,s|0);E=D-512|0}else{E=D}F=E+b|0;D=q+E|0;if((D-w|0)>=8389120){break}s=a[h]|0;do{if(((s<<24>>24)-48|0)>>>0<10){if(!((a[z]|0)==0&s<<24>>24<57)){G=8939;break}B=s+1&255;a[h]=B;if((a[j]|0)==0){a[l]=0}else{Yb(l|0,j|0)|0;C=e+(X1(l|0)|0)|0;x=47;a[C]=x&255;x=x>>8;a[C+1|0]=x&255}Yd(l|0,k|0)|0;if(B<<24>>24==0){break}B=e+(X1(l|0)|0)|0;x=46;a[B]=x&255;x=x>>8;a[B+1|0]=x&255;Yd(l|0,h|0)|0}else{G=8939}}while(0);do{if((G|0)==8939){G=0;B=X1(k|0)|0;if((B-7|0)>>>0>=2){break L12015}if((X7(k|0,44184,2)|0)!=0){break L12015}if(((a[r]|0)-48|0)>>>0>=10){break L12015}if(((a[t]|0)-48|0)>>>0>=10){break L12015}if(((a[u]|0)-48|0)>>>0>=10){break L12015}if(((a[v]|0)-48|0)>>>0>=10){break L12015}C=f+(B-1)|0;B=a[C]|0;if((dk(B<<24>>24|0)|0)==0){break L12015}a[C]=B+1&255;if((a[j]|0)==0){a[l]=0}else{Yb(l|0,j|0)|0;B=e+(X1(l|0)|0)|0;x=47;a[B]=x&255;x=x>>8;a[B+1|0]=x&255}Yd(l|0,k|0)|0;if(s<<24>>24==0){break}B=e+(X1(l|0)|0)|0;x=46;a[B]=x&255;x=x>>8;a[B+1|0]=x&255;Yd(l|0,h|0)|0}}while(0);H=c[198888]|0;I=c[133748]|0;if(!((H|0)!=0&(I|0)!=0)){break}J=XY(12)|0;s=(J|0)==0;if(s){G=8956;break}if((c[J-4>>2]&3|0)!=0){X2(J|0,0,12)}c[J>>2]=H;c[J+4>>2]=I;c[J+8>>2]=0;c[198888]=0;c[133748]=0;if(s){break}else{g=J;q=D;b=F;A=I;m=0;n=H}}if((G|0)==8956){c[J>>2]=H;c[J+4>>2]=I;c[J+8>>2]=0;c[198888]=0;c[133748]=0}J=c[263190]|0;if((J|0)==1){I=c[p>>2]|0;ec(I|0,65208,(K=i,i=i+8|0,c[K>>2]=44024,K)|0)|0;i=K;o=F;i=d;return o|0}else if((J|0)==0){ec(c[p>>2]|0,65208,(K=i,i=i+8|0,c[K>>2]=44072,K)|0)|0;i=K;o=F;i=d;return o|0}else{ec(c[p>>2]|0,65208,(K=i,i=i+8|0,c[K>>2]=43576,K)|0)|0;i=K;o=F;i=d;return o|0}return 0}function Hp(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=f+65280+(e<<24>>24!=0?512:0)|0;e=a[c+(g+213)|0]|0;f=(e&1)==0?0:2;h=e<<24>>24==35?f-2|0:f;f=(a[c+(g+212)|0]|0)==32?h+2|0:h;h=d[c+(g+223)|0]<<8|d[c+(g+222)|0];if((h+(d[c+(g+221)|0]<<8|d[c+(g+220)|0])|0)==65535){i=((h|0)==0?2:3)+f|0}else{i=f}f=(a[c+(g+218)|0]|0)==51?i+2|0:i;i=(e&12)>>>0<4?f+2|0:f;f=a[c+(g+253)|0]|0;e=f<<24>>24<0?i:i-6|0;i=(d[c+(g+252)|0]|(f&255)<<8)>>>0>65456?e-2|0:e;e=(b>>>0>3145728?i+4|0:i)+(((1<<(d[c+(g+215)|0]|0)-7|0)>48)<<31>>31)|0;i=g+176|0;b=0;while(1){if((b|0)>=6){j=0;break}if(((a[c+(i+b)|0]|0)-32&255)>94){j=-1;break}else{b=b+1|0}}b=e+j|0;j=g+192|0;g=0;while(1){if((g|0)>=22){k=0;l=8976;break}if(((a[c+(j+g)|0]|0)-32&255)>94){k=-1;l=8977;break}else{g=g+1|0}}if((l|0)==8977){m=b+k|0;return m|0}else if((l|0)==8976){m=b+k|0;return m|0}return 0}function Hq(b,c,e,f){b=b|0;c=c|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0;g=f+32512+(e<<24>>24!=0?512:0)|0;e=a[c+(g+213)|0]|0;f=(e&1)==0?3:0;h=e<<24>>24==35?f+2|0:f;f=d[c+(g+223)|0]<<8|d[c+(g+222)|0];if((f+(d[c+(g+221)|0]<<8|d[c+(g+220)|0])|0)==65535){i=((f|0)==0?2:3)+h|0}else{i=h}h=(a[c+(g+218)|0]|0)==51?i+2|0:i;i=(e&12)>>>0<4?h+2|0:h;h=a[c+(g+253)|0]|0;e=h<<24>>24<0?i:i-6|0;i=(d[c+(g+252)|0]|(h&255)<<8)>>>0>65456?e-2|0:e;e=(b>>>0<16777217?i+2|0:i)+(((1<<(d[c+(g+215)|0]|0)-7|0)>48)<<31>>31)|0;i=g+176|0;b=0;while(1){if((b|0)>=6){j=0;break}if(((a[c+(i+b)|0]|0)-32&255)>94){j=-1;break}else{b=b+1|0}}b=e+j|0;j=g+192|0;g=0;while(1){if((g|0)>=22){k=0;l=8987;break}if(((a[c+(j+g)|0]|0)-32&255)>94){k=-1;l=8988;break}else{g=g+1|0}}if((l|0)==8988){m=b+k|0;return m|0}else if((l|0)==8987){m=b+k|0;return m|0}return 0}function Hr(b,c){b=b|0;c=c|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;d=i;i=i+256|0;e=d|0;f=b>>16;if((f|0)>0){b=0;do{g=b<<1;a[e+g|0]=b+f&255;a[e+(g|1)|0]=b&255;b=b+1|0;}while((b|0)<(f|0))}b=XY(32768)|0;if((b|0)==0){i=d;return}g=f<<1;if((g|0)>0){f=0;do{h=f;while(1){if((h|0)>=(g|0)){break}j=e+h|0;k=a[j]|0;if((k&255|0)==(f|0)){l=8996;break}else{h=h+1|0}}if((l|0)==8996){l=0;h=c+(f<<15)|0;X5(b|0,h|0,32768)|0;m=e+f|0;n=a[m]|0;o=c+((n&255)<<15)|0;X9(h|0,o|0,32768);X5(o|0,b|0,32768)|0;a[j]=n;a[m]=k}f=f+1|0;}while((f|0)<(g|0))}XZ(b);i=d;return}function Hs(){var b=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,be=0,bf=0,bg=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bK=0,bL=0,bM=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,cf=0,cg=0,ch=0,ci=0,cj=0,ck=0,cl=0,cm=0,cn=0,co=0,cp=0,cq=0,cr=0,cs=0,ct=0,cu=0,cv=0,cw=0,cx=0,cy=0,cz=0,cA=0,cB=0,cC=0,cD=0,cE=0,cF=0,cG=0,cH=0,cI=0,cJ=0,cK=0,cM=0,cN=0,cO=0,cP=0,cQ=0,cR=0,cS=0,cT=0,cU=0,cV=0,cW=0,cX=0,cY=0,cZ=0,c_=0,c$=0,c0=0,c3=0,c4=0,c6=0,c7=0,c8=0,c9=0,da=0,db=0,dc=0,de=0,df=0,dg=0,dh=0,di=0,dj=0,dk=0,dl=0,dm=0,dn=0,dp=0,dq=0,dr=0,ds=0,dt=0,du=0,dv=0,dw=0,dx=0,dy=0,dz=0,dA=0,dB=0,dC=0,dD=0,dE=0,dF=0,dG=0,dH=0,dI=0,dJ=0,dK=0,dL=0,dM=0,dN=0,dO=0,dP=0,dQ=0,dR=0,dS=0,dT=0,dU=0,dV=0,dW=0;b=i;i=i+8840|0;e=b|0;f=b+56|0;g=b+4160|0;h=b+8264|0;j=b+8272|0;k=b+8288|0;l=b+8312|0;m=b+8832|0;X2(799121,0,10);c[199762]=(c[274486]|0)>>>15;a[807393]=1;c[274479]=-1;X2(1097908,0,5);n=c[263192]|0;o=(a[1093764]|0)==2?n+4226992|0:n+32688|0;q=(a[1097936]|0)==0?o:o+32768|0;a[799131]=0;o=n+32704|0;do{if((Ya(o|0,65464,21)|0)==0){a[799131]=1;a[799132]=1;a[1097937]=1;a[1097936]=0;X9(c[263200]|0,n|0,1048576);a[1125512]=0;c[281374]=2097152;a[1394258]=1;r=9029}else{a[799132]=0;s=a[n+32730|0]|0;do{if((s<<24>>24|0)==51|(s<<24>>24|0)==(-1|0)){t=a[n+32725|0]|0;if(!(t<<24>>24==0|(t&-125)<<24>>24==-128)){r=9013;break}t=a[n+32728|0]|0;if(!((t<<24>>24|0)==32|(t<<24>>24|0)==33|(t<<24>>24|0)==48|(t<<24>>24|0)==49)){r=9013;break}t=a[n+32726|0]|0;if(t<<24>>24==0){u=(a[n+32727|0]|0)!=0;break}v=t&255;if(t<<24>>24==-1){if((a[n+32727|0]|0)==-1){u=1;break}}if((v&15|0)!=0){r=9013;break}if(((v>>>4)-1|0)<12){u=1}else{r=9013}}else{r=9013}}while(0);if((r|0)==9013){u=0}s=u&1;v=a[n+65498|0]|0;do{if((v<<24>>24|0)==51|(v<<24>>24|0)==(-1|0)){t=a[n+65493|0]|0;if(!(t<<24>>24==0|(t&-125)<<24>>24==-128)){r=9023;break}t=a[n+65496|0]|0;if(!((t<<24>>24|0)==32|(t<<24>>24|0)==33|(t<<24>>24|0)==48|(t<<24>>24|0)==49)){r=9023;break}t=a[n+65494|0]|0;if(t<<24>>24==0){w=(a[n+65495|0]|0)!=0|0;break}y=t&255;if(t<<24>>24==-1){if((a[n+65495|0]|0)==-1){w=1;break}}if((y&15|0)!=0){r=9023;break}if(((y>>>4)-1|0)<12){w=1}else{r=9023}}else{r=9023}}while(0);if((r|0)==9023){w=0}v=w|s;a[799131]=v;if(v<<24>>24==0){z=0;break}a[1097937]=s;a[1097936]=w;v=u?o:n+65472|0;a[1125512]=(a[v+24|0]&-17)<<24>>24!=32|0;c[281374]=(a[v+25|0]&32)!=0?524288:2097152;a[1394258]=a[799133]|0;v=f|0;y=g|0;Yb(v|0,0)|0;t=f+(X1(v|0)|0)|0;x=47;a[t]=x&255;x=x>>8;a[t+1|0]=x&255;Yb(y|0,v|0)|0;t=g+(X1(y|0)|0)|0;X5(t|0,63288,9)|0;t=c5(y|0,23072)|0;if((t|0)==0){Yb(y|0,v|0)|0;v=g+(X1(y|0)|0)|0;X5(v|0,46040,10)|0;v=c5(y|0,23072)|0;if((v|0)!=0){A=v;r=9027}}else{A=t;r=9027}if((r|0)==9027){t=d6(c[263200]|0,1,1048576,A|0)|0;aQ(A|0)|0;if((t|0)==1048576){r=9029;break}}a[1394258]=0;X2(c[263200]|0,0,1048576);r=9029}}while(0);do{if((r|0)==9029){if((a[799131]|0)==0){z=0;break}c[274488]=0;c[281376]=c[263192];eG(h|0)|0;A=bd(h|0)|0;c[348556]=0;X5(1394373,9528,32)|0;g=c[A>>2]|0;c[348558]=g;a[1394383]=g&255;g=c[A+4>>2]|0;c[348560]=g;a[1394384]=g&255;g=c[A+8>>2]|0;c[348562]=g;a[1394385]=g&255;a[808072]=0;z=a[799131]|0}}while(0);h=(a[799132]|0)==0&z;Yc(1097862,q+16|0,22)|0;if(h<<24>>24==0){a[1097923]=a[q+39|0]|0;a[1097938]=a[q+40|0]|0;a[1097921]=a[q+37|0]|0;a[1097922]=a[q+38|0]|0;B=a[q+41|0]|0}else{X2(1097878,32,6);h=a[q+41|0]&32;z=c[274486]|0;do{if((h|0)!=0&z>>>0<1048576){C=z}else{if((h|0)==0&(z|0)==1048576){C=1048576;break}dd(1616)|0;C=c[274486]|0}}while(0);z=0;while(1){if((1<<z|0)<(C|0)){z=z+1|0}else{break}}a[1097923]=z+246&255;a[1097938]=5;a[1097921]=a[q+40|0]|0;a[1097922]=-27;B=0}a[1097920]=B;c[274481]=d[q+47|0]<<8|d[q+46|0];c[274482]=d[q+45|0]<<8|d[q+44|0];B=q+2|0;c[274477]=d[B]|d[B+1|0]<<8|d[B+2|0]<<16|d[B+3|0]<<24;B=q+42|0;z=a[B]|0;C=z&255;do{if(z<<24>>24==51){if((bh(d[q]|0)|0)==0){break}h=q+1|0;if((bh(d[h]|0)|0)==0){break}g=c1(d[q]|0)|0;A=c1(d[h]|0)|0;c[274479]=((A|0)>57?-55:-48)+A+((((g|0)>57?-55:-48)+g|0)*36|0)}else{c[274479]=((C>>>4)*36|0)+(C&15)}}while(0);C=a[1097922]|0;L12165:do{if((C<<24>>24|0)==3){if((a[1097921]|0)==48){a[799122]=4;r=9062;break}else{a[799122]=1;r=9054;break}}else if((C<<24>>24|0)==5){q=a[1097921]|0;if((q<<24>>24|0)==32){a[799122]=2;r=9060;break}else if((q<<24>>24|0)==48){r=9050}do{if((r|0)==9050){if((a[B]|0)!=-78){break}a[799122]=3;r=9061;break L12165}}while(0);a[799122]=1;r=9054}else{s=d[799122]|0;if((s|0)==4){r=9062;break}else if((s|0)==1){r=9054;break}else if((s|0)==2){r=9060;break}else if((s|0)==3){r=9061;break}c[201852]=0;c[276698]=0}}while(0);if((r|0)==9062){c[295940]=49152;c[295942]=5;c[201852]=10;c[276698]=86}else if((r|0)==9054){do{if((a[1097936]|0)==0){if((c[274486]|0)>>>0>1048576){c[295940]=16384;c[295942]=1;break}else{c[295940]=49152;c[295942]=0;break}}else{c[295940]=28672;c[295942]=2}}while(0);c[201852]=8;c[276698]=54}else if((r|0)==9060){c[295940]=65536;c[295942]=3;c[201852]=86;c[276698]=44}else if((r|0)==9061){c[295940]=49152;c[295942]=4;c[201852]=14;c[276698]=70}B=d[1097921]|(C&255)<<8;do{if((B|0)==62240){a[799124]=1;D=0}else if((B|0)==63802){a[799127]=1;r=9067}else if((B|0)==62768){a[799129]=3;c[36646]=0;c[40480]=0;a[1097938]=2;a[808072]=0;D=0}else if((B|0)==63024){C=(a[(c[263192]|0)+32727|0]|0)==9;a[799129]=C?2:1;c[36646]=C?4:6;c[40480]=C?18:64;a[1097938]=2;a[808072]=0;D=0}else if((B|0)==21813){a[799130]=1;T6();c[58916]=2;c[58918]=-1;eG(0)|0;X2(1041680,0,20);D=0}else if((B|0)==62778){r=9067}else if((B|0)==9520){a[799128]=1;D=0}else if((B|0)==13347|(B|0)==13603){a[799123]=1;D=0}else if((B|0)==17202|(B|0)==17714){a[799125]=1;D=0}else if((B|0)==4896|(B|0)==5152|(B|0)==5408|(B|0)==6688){a[799121]=1;X2(1106800,0,2044);C=c[263192]|0;if((a[C+32730|0]|0)==51){a[1097938]=a[C+32701|0]|0;D=0;break}else{a[1097938]=5;D=0;break}}else{D=0}}while(0);if((r|0)==9067){a[799126]=1;T6();T4();X2(1041680,0,20);D=0}do{c[1052804+(D<<2)>>2]=18;c[1069188+(D<<2)>>2]=18;a[1089668+D|0]=0;a[1085572+D|0]=0;D=D+1|0;}while((D|0)<4096);c[274487]=0;D=(a[799131]|0)!=0;L12210:do{if((a[1097936]|0)==0){if(D){break}B=a[799129]|0;if(!((B<<24>>24|0)==0|(B<<24>>24|0)==3)){dd(1432)|0;B=c[263191]|0;C=0;while(1){s=C<<4;c[1052804+(s<<2)>>2]=B;a[1089668+s|0]=0;a[1085572+s|0]=1;q=s|1;c[1052804+(q<<2)>>2]=B;a[1089668+q|0]=0;a[1085572+q|0]=1;q=C+1|0;if(q>>>0<64){C=q}else{E=0;break}}while(1){C=E<<4;q=C|2;c[1052804+(q<<2)>>2]=1;a[1089668+q|0]=0;a[1085572+q|0]=0;q=C|3;c[1052804+(q<<2)>>2]=1;a[1089668+q|0]=0;a[1085572+q|0]=0;q=E+1|0;if(q>>>0<64){E=q}else{F=0;break}}while(1){q=F<<4;C=q|4;c[1052804+(C<<2)>>2]=0;a[1089668+C|0]=0;a[1085572+C|0]=0;C=q|5;c[1052804+(C<<2)>>2]=0;a[1089668+C|0]=0;a[1085572+C|0]=0;C=F+1|0;if(C>>>0<64){F=C}else{G=128;break}}while(1){C=G<<4;c[1052804+(C<<2)>>2]=B;a[1089668+C|0]=0;a[1085572+C|0]=1;q=C|1;c[1052804+(q<<2)>>2]=B;a[1089668+q|0]=0;a[1085572+q|0]=1;q=G+1|0;if(q>>>0<192){G=q}else{H=128;break}}while(1){B=H<<4;q=B|2;c[1052804+(q<<2)>>2]=1;a[1089668+q|0]=0;a[1085572+q|0]=0;q=B|3;c[1052804+(q<<2)>>2]=1;a[1089668+q|0]=0;a[1085572+q|0]=0;q=H+1|0;if(q>>>0<192){H=q}else{I=128;break}}while(1){q=I<<4;B=q|4;c[1052804+(B<<2)>>2]=0;a[1089668+B|0]=0;a[1085572+B|0]=0;B=q|5;c[1052804+(B<<2)>>2]=0;a[1089668+B|0]=0;a[1085572+B|0]=0;B=I+1|0;if(B>>>0<192){I=B}else{J=0;break}}while(1){B=J<<4;q=J<<15;C=32768;do{s=C>>>12|B;z=c[263192]|0;c[1052804+(s<<2)>>2]=z+((Hv(c[274486]|0,q)|0)-(C&32768));a[1089668+s|0]=1;a[1085572+s|0]=0;C=C+4096|0;}while(C>>>0<65536);C=J+1|0;if(C>>>0<64){J=C}else{K=64;break}}while(1){C=K<<4;q=K<<15;B=32768;do{s=B>>>12|C;z=c[263192]|0;c[1052804+(s<<2)>>2]=z+((Hv(c[274486]|0,q)|0)-(B&32768));a[1089668+s|0]=1;a[1085572+s|0]=0;B=B+4096|0;}while(B>>>0<65536);B=K+1|0;if(B>>>0<128){K=B}else{L=128;break}}while(1){B=L<<4;q=L<<15&4161536;C=32768;do{s=C>>>12|B;z=c[263192]|0;c[1052804+(s<<2)>>2]=z+((Hv(c[274486]|0,q)|0)-(C&32768));a[1089668+s|0]=1;a[1085572+s|0]=0;C=C+4096|0;}while(C>>>0<65536);C=L+1|0;if(C>>>0<192){L=C}else{M=192;break}}while(1){C=M<<4;q=M<<15&4161536;B=32768;do{s=B>>>12|C;z=c[263192]|0;c[1052804+(s<<2)>>2]=z+((Hv(c[274486]|0,q)|0)-(B&32768));a[1089668+s|0]=1;a[1085572+s|0]=0;B=B+4096|0;}while(B>>>0<65536);B=M+1|0;if(B>>>0<256){M=B}else{N=104;break}}while(1){B=N<<4;c[1052804+(B<<2)>>2]=15;a[1089668+B|0]=0;a[1085572+B|0]=1;q=B|1;c[1052804+(q<<2)>>2]=15;a[1089668+q|0]=0;a[1085572+q|0]=1;q=B|2;c[1052804+(q<<2)>>2]=15;a[1089668+q|0]=0;a[1085572+q|0]=1;q=B|3;c[1052804+(q<<2)>>2]=15;a[1089668+q|0]=0;a[1085572+q|0]=1;q=B|4;c[1052804+(q<<2)>>2]=15;a[1089668+q|0]=0;a[1085572+q|0]=1;q=B|5;c[1052804+(q<<2)>>2]=15;a[1089668+q|0]=0;a[1085572+q|0]=1;q=B|6;c[1052804+(q<<2)>>2]=15;a[1089668+q|0]=0;a[1085572+q|0]=1;q=B|7;c[1052804+(q<<2)>>2]=15;a[1089668+q|0]=0;a[1085572+q|0]=1;q=N+1|0;if(q>>>0<112){N=q}else{O=96;break}}while(1){q=O<<4;c[1052804+(q<<2)>>2]=15;a[1089668+q|0]=0;a[1085572+q|0]=0;B=q|1;c[1052804+(B<<2)>>2]=15;a[1089668+B|0]=0;a[1085572+B|0]=0;B=q|2;c[1052804+(B<<2)>>2]=15;a[1089668+B|0]=0;a[1085572+B|0]=0;B=q|3;c[1052804+(B<<2)>>2]=15;a[1089668+B|0]=0;a[1085572+B|0]=0;B=O+1|0;if(B>>>0<104){O=B}else{P=112;break}}while(1){B=P<<4;c[1052804+(B<<2)>>2]=2;a[1089668+B|0]=0;a[1085572+B|0]=1;q=B|1;c[1052804+(q<<2)>>2]=2;a[1089668+q|0]=0;a[1085572+q|0]=1;q=B|2;c[1052804+(q<<2)>>2]=2;a[1089668+q|0]=0;a[1085572+q|0]=1;q=B|3;c[1052804+(q<<2)>>2]=2;a[1089668+q|0]=0;a[1085572+q|0]=1;q=B|4;c[1052804+(q<<2)>>2]=2;a[1089668+q|0]=0;a[1085572+q|0]=1;q=B|5;c[1052804+(q<<2)>>2]=2;a[1089668+q|0]=0;a[1085572+q|0]=1;q=B|6;c[1052804+(q<<2)>>2]=2;a[1089668+q|0]=0;a[1085572+q|0]=1;q=B|7;c[1052804+(q<<2)>>2]=2;a[1089668+q|0]=0;a[1085572+q|0]=1;q=P+1|0;if(q>>>0<128){P=q}else{Q=240;break}}while(1){q=Q<<4;c[1052804+(q<<2)>>2]=2;a[1089668+q|0]=0;a[1085572+q|0]=1;B=q|1;c[1052804+(B<<2)>>2]=2;a[1089668+B|0]=0;a[1085572+B|0]=1;B=q|2;c[1052804+(B<<2)>>2]=2;a[1089668+B|0]=0;a[1085572+B|0]=1;B=q|3;c[1052804+(B<<2)>>2]=2;a[1089668+B|0]=0;a[1085572+B|0]=1;B=q|4;c[1052804+(B<<2)>>2]=2;a[1089668+B|0]=0;a[1085572+B|0]=1;B=q|5;c[1052804+(B<<2)>>2]=2;a[1089668+B|0]=0;a[1085572+B|0]=1;B=q|6;c[1052804+(B<<2)>>2]=2;a[1089668+B|0]=0;a[1085572+B|0]=1;B=q|7;c[1052804+(B<<2)>>2]=2;a[1089668+B|0]=0;a[1085572+B|0]=1;B=Q+1|0;if(B>>>0<256){Q=B}else{R=0;break}}while(1){B=R>>>12|2016;c[1052804+(B<<2)>>2]=c[263191];a[1089668+B|0]=0;a[1085572+B|0]=1;B=R+4096|0;if(B>>>0<65536){R=B}else{S=0;break}}do{B=S>>>12|2032;c[1052804+(B<<2)>>2]=(c[263191]|0)+65536;a[1089668+B|0]=0;a[1085572+B|0]=1;S=S+4096|0;}while(S>>>0<65536);X5(1069188,1052804,16384)|0;B=0;while(1){if((a[1089668+B|0]|0)!=0){c[1069188+(B<<2)>>2]=18}B=B+1|0;if((B|0)>=4096){break L12210}}}if((a[799121]|0)!=0){dd(1408)|0;B=c[263191]|0;q=0;while(1){C=q<<4;c[1052804+(C<<2)>>2]=B;a[1089668+C|0]=0;a[1085572+C|0]=1;s=C|1;c[1052804+(s<<2)>>2]=B;a[1089668+s|0]=0;a[1085572+s|0]=1;s=q+1|0;if(s>>>0<64){q=s}else{T=0;break}}while(1){q=T<<4;s=q|2;c[1052804+(s<<2)>>2]=1;a[1089668+s|0]=0;a[1085572+s|0]=0;s=q|3;c[1052804+(s<<2)>>2]=1;a[1089668+s|0]=0;a[1085572+s|0]=0;s=T+1|0;if(s>>>0<64){T=s}else{U=0;break}}while(1){s=U<<4;q=s|4;c[1052804+(q<<2)>>2]=0;a[1089668+q|0]=0;a[1085572+q|0]=0;q=s|5;c[1052804+(q<<2)>>2]=0;a[1089668+q|0]=0;a[1085572+q|0]=0;q=U+1|0;if(q>>>0<64){U=q}else{V=128;break}}while(1){q=V<<4;c[1052804+(q<<2)>>2]=B;a[1089668+q|0]=0;a[1085572+q|0]=1;s=q|1;c[1052804+(s<<2)>>2]=B;a[1089668+s|0]=0;a[1085572+s|0]=1;s=V+1|0;if(s>>>0<192){V=s}else{W=128;break}}while(1){B=W<<4;s=B|2;c[1052804+(s<<2)>>2]=1;a[1089668+s|0]=0;a[1085572+s|0]=0;s=B|3;c[1052804+(s<<2)>>2]=1;a[1089668+s|0]=0;a[1085572+s|0]=0;s=W+1|0;if(s>>>0<192){W=s}else{X=128;break}}while(1){s=X<<4;B=s|4;c[1052804+(B<<2)>>2]=0;a[1089668+B|0]=0;a[1085572+B|0]=0;B=s|5;c[1052804+(B<<2)>>2]=0;a[1089668+B|0]=0;a[1085572+B|0]=0;B=X+1|0;if(B>>>0<192){X=B}else{Y=0;break}}while(1){B=Y<<16;s=c[263192]|0;q=Y<<15;X9(s+(B+2097152)|0,s+q|0,32768);s=c[263192]|0;X9(s+(B+2129920)|0,s+q|0,32768);q=Y+1|0;if((q|0)<64){Y=q}else{Z=0;break}}while(1){q=Z<<4;s=Z<<15;B=32768;do{C=B>>>12|q;z=c[263192]|0;c[1052804+(C<<2)>>2]=z+((Hv(c[274486]|0,s)|0)-(B&32768));a[1089668+C|0]=1;a[1085572+C|0]=0;B=B+4096|0;}while(B>>>0<65536);B=Z+1|0;if(B>>>0<64){Z=B}else{_=128;break}}while(1){B=_<<4;s=_<<15&4161536;q=32768;do{C=q>>>12|B;z=c[263192]|0;c[1052804+(C<<2)>>2]=z+((Hv(c[274486]|0,s)|0)-(q&32768));a[1089668+C|0]=1;a[1085572+C|0]=0;q=q+4096|0;}while(q>>>0<65536);q=_+1|0;if(q>>>0<192){_=q}else{$=64;break}}while(1){q=$<<4;s=($<<16)-4194304|0;B=0;do{C=B>>>12|q;z=c[263192]|0;c[1052804+(C<<2)>>2]=z+(Hv(c[274486]|0,s)|0);a[1089668+C|0]=1;a[1085572+C|0]=0;B=B+4096|0;}while(B>>>0<65536);B=$+1|0;if(B>>>0<128){$=B}else{aa=192;break}}do{B=aa<<4;s=(aa<<16)-12582912|0;q=0;do{C=q>>>12|B;z=c[263192]|0;c[1052804+(C<<2)>>2]=z+(Hv(c[274486]|0,s)|0);a[1089668+C|0]=1;a[1085572+C|0]=0;q=q+4096|0;}while(q>>>0<65536);aa=aa+1|0;}while(aa>>>0<256);q=c[263193]|0;s=q-24576|0;B=0;while(1){C=B<<4;z=C|6;c[1052804+(z<<2)>>2]=s;a[1089668+z|0]=0;a[1085572+z|0]=1;z=C|7;c[1052804+(z<<2)>>2]=s;a[1089668+z|0]=0;a[1085572+z|0]=1;z=B+1|0;if(z>>>0<64){B=z}else{ac=128;break}}do{B=ac<<4;z=B|6;c[1052804+(z<<2)>>2]=s;a[1089668+z|0]=0;a[1085572+z|0]=1;z=B|7;c[1052804+(z<<2)>>2]=s;a[1089668+z|0]=0;a[1085572+z|0]=1;ac=ac+1|0;}while(ac>>>0<192);c[264993]=q;a[1091460]=0;a[1087364]=1;s=4096;z=q;while(1){B=s>>>12|1792;c[1052804+(B<<2)>>2]=z;a[1089668+B|0]=0;a[1085572+B|0]=1;B=s+4096|0;if(B>>>0>=65536){ad=0;break}s=B;z=c[263193]|0}while(1){z=ad>>>12|1808;c[1052804+(z<<2)>>2]=(c[263193]|0)+65536;a[1089668+z|0]=0;a[1085572+z|0]=1;z=ad+4096|0;if(z>>>0<65536){ad=z}else{ae=0;break}}while(1){z=ae>>>12|2016;c[1052804+(z<<2)>>2]=c[263191];a[1089668+z|0]=0;a[1085572+z|0]=1;z=ae+4096|0;if(z>>>0<65536){ae=z}else{af=0;break}}do{z=af>>>12|2032;c[1052804+(z<<2)>>2]=(c[263191]|0)+65536;a[1089668+z|0]=0;a[1085572+z|0]=1;af=af+4096|0;}while(af>>>0<65536);X5(1069188,1052804,16384)|0;z=0;while(1){if((a[1089668+z|0]|0)!=0){c[1069188+(z<<2)>>2]=18}z=z+1|0;if((z|0)>=4096){break L12210}}}if((a[799123]|0)!=0){dd(1392)|0;z=c[263191]|0;s=0;while(1){q=s<<4;c[1052804+(q<<2)>>2]=z;a[1089668+q|0]=0;a[1085572+q|0]=1;B=q|1;c[1052804+(B<<2)>>2]=z;a[1089668+B|0]=0;a[1085572+B|0]=1;B=s+1|0;if(B>>>0<64){s=B}else{ag=0;break}}while(1){s=ag<<4;B=s|2;c[1052804+(B<<2)>>2]=1;a[1089668+B|0]=0;a[1085572+B|0]=0;B=s|3;c[1052804+(B<<2)>>2]=1;a[1089668+B|0]=0;a[1085572+B|0]=0;B=ag+1|0;if(B>>>0<64){ag=B}else{ah=0;break}}while(1){B=ah<<4;s=B|4;c[1052804+(s<<2)>>2]=0;a[1089668+s|0]=0;a[1085572+s|0]=0;s=B|5;c[1052804+(s<<2)>>2]=0;a[1089668+s|0]=0;a[1085572+s|0]=0;s=ah+1|0;if(s>>>0<64){ah=s}else{ai=128;break}}while(1){s=ai<<4;c[1052804+(s<<2)>>2]=z;a[1089668+s|0]=0;a[1085572+s|0]=1;B=s|1;c[1052804+(B<<2)>>2]=z;a[1089668+B|0]=0;a[1085572+B|0]=1;B=ai+1|0;if(B>>>0<192){ai=B}else{aj=128;break}}while(1){z=aj<<4;B=z|2;c[1052804+(B<<2)>>2]=1;a[1089668+B|0]=0;a[1085572+B|0]=0;B=z|3;c[1052804+(B<<2)>>2]=1;a[1089668+B|0]=0;a[1085572+B|0]=0;B=aj+1|0;if(B>>>0<192){aj=B}else{ak=128;break}}while(1){B=ak<<4;z=B|4;c[1052804+(z<<2)>>2]=0;a[1089668+z|0]=0;a[1085572+z|0]=0;z=B|5;c[1052804+(z<<2)>>2]=0;a[1089668+z|0]=0;a[1085572+z|0]=0;z=ak+1|0;if(z>>>0<192){ak=z}else{al=0;break}}while(1){z=al<<4;B=al<<15;s=32768;do{q=s>>>12|z;C=c[263192]|0;c[1052804+(q<<2)>>2]=C+((Hv(c[274486]|0,B)|0)-(s&32768));a[1089668+q|0]=1;a[1085572+q|0]=0;s=s+4096|0;}while(s>>>0<65536);s=al+1|0;if(s>>>0<64){al=s}else{am=128;break}}while(1){s=am<<4;B=am<<15&4161536;z=32768;do{q=z>>>12|s;C=c[263192]|0;c[1052804+(q<<2)>>2]=C+((Hv(c[274486]|0,B)|0)-(z&32768));a[1089668+q|0]=1;a[1085572+q|0]=0;z=z+4096|0;}while(z>>>0<65536);z=am+1|0;if(z>>>0<192){am=z}else{an=192;break}}do{z=an<<4;B=(an<<16)-12582912|0;s=0;do{q=s>>>12|z;C=c[263192]|0;c[1052804+(q<<2)>>2]=C+(Hv(c[274486]|0,B)|0);a[1089668+q|0]=1;a[1085572+q|0]=0;s=s+4096|0;}while(s>>>0<65536);an=an+1|0;}while(an>>>0<256);s=c[263195]|0;B=0;while(1){z=B<<4|3;c[1052804+(z<<2)>>2]=s;a[1089668+z|0]=0;a[1085572+z|0]=1;z=B+1|0;if(z>>>0<64){B=z}else{ao=128;break}}while(1){B=ao<<4|3;c[1052804+(B<<2)>>2]=s;a[1089668+B|0]=0;a[1085572+B|0]=1;B=ao+1|0;if(B>>>0<192){ao=B}else{ap=0;break}}while(1){s=ap<<4;B=s|6;c[1052804+(B<<2)>>2]=7;a[1089668+B|0]=0;a[1085572+B|0]=0;B=s|7;c[1052804+(B<<2)>>2]=7;a[1089668+B|0]=0;a[1085572+B|0]=0;B=ap+1|0;if(B>>>0<64){ap=B}else{aq=128;break}}while(1){B=aq<<4;s=B|6;c[1052804+(s<<2)>>2]=7;a[1089668+s|0]=0;a[1085572+s|0]=0;s=B|7;c[1052804+(s<<2)>>2]=7;a[1089668+s|0]=0;a[1085572+s|0]=0;s=aq+1|0;if(s>>>0<192){aq=s}else{ar=64;break}}while(1){s=ar<<16&65536;B=ar<<4;z=0;do{q=z>>>12|B;c[1052804+(q<<2)>>2]=(c[263193]|0)+s;a[1089668+q|0]=0;a[1085572+q|0]=1;z=z+4096|0;}while(z>>>0<65536);z=ar+1|0;if((z|0)<128){ar=z}else{as=0;break}}while(1){z=as>>>12|2016;c[1052804+(z<<2)>>2]=c[263191];a[1089668+z|0]=0;a[1085572+z|0]=1;z=as+4096|0;if(z>>>0<65536){as=z}else{at=0;break}}do{z=at>>>12|2032;c[1052804+(z<<2)>>2]=(c[263191]|0)+65536;a[1089668+z|0]=0;a[1085572+z|0]=1;at=at+4096|0;}while(at>>>0<65536);X5(1069188,1052804,16384)|0;z=0;do{if((a[1089668+z|0]|0)!=0){c[1069188+(z<<2)>>2]=18}z=z+1|0;}while((z|0)<4096);X5(808144,1052804,16384)|0;X5(824528,1069188,16384)|0;z=(c[263195]|0)+12288|0;s=0;while(1){B=s+2048|0;c[808144+(B<<2)>>2]=z;c[808144+(s<<2)>>2]=z;q=s+2049|0;c[808144+(q<<2)>>2]=18;C=s|1;c[808144+(C<<2)>>2]=18;c[824528+(B<<2)>>2]=z;c[824528+(s<<2)>>2]=z;c[824528+(q<<2)>>2]=18;c[824528+(C<<2)>>2]=18;C=s+16|0;if((C|0)<1024){s=C}else{au=1536;break}}do{c[824528+(au<<2)>>2]=8;c[808144+(au<<2)>>2]=8;au=au+1|0;}while((au|0)<1792);c[263196]=c[263193];break}if((a[799125]|0)!=0){dd(1368)|0;s=c[263191]|0;z=0;while(1){C=z<<4;c[1052804+(C<<2)>>2]=s;a[1089668+C|0]=0;a[1085572+C|0]=1;q=C|1;c[1052804+(q<<2)>>2]=s;a[1089668+q|0]=0;a[1085572+q|0]=1;q=z+1|0;if(q>>>0<64){z=q}else{av=0;break}}while(1){z=av<<4;q=z|2;c[1052804+(q<<2)>>2]=1;a[1089668+q|0]=0;a[1085572+q|0]=0;q=z|3;c[1052804+(q<<2)>>2]=1;a[1089668+q|0]=0;a[1085572+q|0]=0;q=av+1|0;if(q>>>0<64){av=q}else{aw=0;break}}while(1){q=aw<<4;z=q|4;c[1052804+(z<<2)>>2]=0;a[1089668+z|0]=0;a[1085572+z|0]=0;z=q|5;c[1052804+(z<<2)>>2]=0;a[1089668+z|0]=0;a[1085572+z|0]=0;z=aw+1|0;if(z>>>0<64){aw=z}else{ax=128;break}}while(1){z=ax<<4;c[1052804+(z<<2)>>2]=s;a[1089668+z|0]=0;a[1085572+z|0]=1;q=z|1;c[1052804+(q<<2)>>2]=s;a[1089668+q|0]=0;a[1085572+q|0]=1;q=ax+1|0;if(q>>>0<192){ax=q}else{ay=128;break}}while(1){s=ay<<4;q=s|2;c[1052804+(q<<2)>>2]=1;a[1089668+q|0]=0;a[1085572+q|0]=0;q=s|3;c[1052804+(q<<2)>>2]=1;a[1089668+q|0]=0;a[1085572+q|0]=0;q=ay+1|0;if(q>>>0<192){ay=q}else{az=128;break}}while(1){q=az<<4;s=q|4;c[1052804+(s<<2)>>2]=0;a[1089668+s|0]=0;a[1085572+s|0]=0;s=q|5;c[1052804+(s<<2)>>2]=0;a[1089668+s|0]=0;a[1085572+s|0]=0;s=az+1|0;if(s>>>0<192){az=s}else{aA=0;break}}while(1){s=aA<<4;q=aA<<15;z=32768;do{C=z>>>12|s;B=c[263192]|0;c[1052804+(C<<2)>>2]=B+((Hv(c[274486]|0,q)|0)-(z&32768));a[1089668+C|0]=1;a[1085572+C|0]=0;z=z+4096|0;}while(z>>>0<65536);z=aA+1|0;if(z>>>0<64){aA=z}else{aB=128;break}}while(1){z=aB<<4;q=aB<<15&4161536;s=32768;do{C=s>>>12|z;B=c[263192]|0;c[1052804+(C<<2)>>2]=B+((Hv(c[274486]|0,q)|0)-(s&32768));a[1089668+C|0]=1;a[1085572+C|0]=0;s=s+4096|0;}while(s>>>0<65536);s=aB+1|0;if(s>>>0<192){aB=s}else{aC=64;break}}while(1){s=aC<<4;q=(aC<<16)-4194304|0;z=0;do{C=z>>>12|s;B=c[263192]|0;c[1052804+(C<<2)>>2]=B+(Hv(c[274486]|0,q)|0);a[1089668+C|0]=1;a[1085572+C|0]=0;z=z+4096|0;}while(z>>>0<65536);z=aC+1|0;if(z>>>0<128){aC=z}else{aD=192;break}}while(1){z=aD<<4;q=(aD<<16)-12582912|0;s=0;do{C=s>>>12|z;B=c[263192]|0;c[1052804+(C<<2)>>2]=B+(Hv(c[274486]|0,q)|0);a[1089668+C|0]=1;a[1085572+C|0]=0;s=s+4096|0;}while(s>>>0<65536);s=aD+1|0;if(s>>>0<256){aD=s}else{aE=112;break}}while(1){s=aE<<4;c[1052804+(s<<2)>>2]=2;a[1089668+s|0]=0;a[1085572+s|0]=1;q=s|1;c[1052804+(q<<2)>>2]=2;a[1089668+q|0]=0;a[1085572+q|0]=1;q=s|2;c[1052804+(q<<2)>>2]=2;a[1089668+q|0]=0;a[1085572+q|0]=1;q=s|3;c[1052804+(q<<2)>>2]=2;a[1089668+q|0]=0;a[1085572+q|0]=1;q=s|4;c[1052804+(q<<2)>>2]=2;a[1089668+q|0]=0;a[1085572+q|0]=1;q=s|5;c[1052804+(q<<2)>>2]=2;a[1089668+q|0]=0;a[1085572+q|0]=1;q=s|6;c[1052804+(q<<2)>>2]=2;a[1089668+q|0]=0;a[1085572+q|0]=1;q=s|7;c[1052804+(q<<2)>>2]=2;a[1089668+q|0]=0;a[1085572+q|0]=1;q=aE+1|0;if(q>>>0<128){aE=q}else{aF=0;break}}while(1){q=aF>>>12|2016;c[1052804+(q<<2)>>2]=c[263191];a[1089668+q|0]=0;a[1085572+q|0]=1;q=aF+4096|0;if(q>>>0<65536){aF=q}else{aG=0;break}}do{q=aG>>>12|2032;c[1052804+(q<<2)>>2]=(c[263191]|0)+65536;a[1089668+q|0]=0;a[1085572+q|0]=1;aG=aG+4096|0;}while(aG>>>0<65536);X5(1069188,1052804,16384)|0;q=0;while(1){if((a[1089668+q|0]|0)!=0){c[1069188+(q<<2)>>2]=18}q=q+1|0;if((q|0)>=4096){break L12210}}}if((a[1093764]|0)!=0){dd(1576)|0;q=c[263191]|0;s=0;while(1){z=s<<4;c[1052804+(z<<2)>>2]=q;a[1089668+z|0]=0;a[1085572+z|0]=1;C=z|1;c[1052804+(C<<2)>>2]=q;a[1089668+C|0]=0;a[1085572+C|0]=1;C=s+1|0;if(C>>>0<64){s=C}else{aH=0;break}}while(1){s=aH<<4;C=s|2;c[1052804+(C<<2)>>2]=1;a[1089668+C|0]=0;a[1085572+C|0]=0;C=s|3;c[1052804+(C<<2)>>2]=1;a[1089668+C|0]=0;a[1085572+C|0]=0;C=aH+1|0;if(C>>>0<64){aH=C}else{aI=0;break}}while(1){C=aI<<4;s=C|4;c[1052804+(s<<2)>>2]=0;a[1089668+s|0]=0;a[1085572+s|0]=0;s=C|5;c[1052804+(s<<2)>>2]=0;a[1089668+s|0]=0;a[1085572+s|0]=0;s=aI+1|0;if(s>>>0<64){aI=s}else{aJ=128;break}}while(1){s=aJ<<4;c[1052804+(s<<2)>>2]=q;a[1089668+s|0]=0;a[1085572+s|0]=1;C=s|1;c[1052804+(C<<2)>>2]=q;a[1089668+C|0]=0;a[1085572+C|0]=1;C=aJ+1|0;if(C>>>0<192){aJ=C}else{aK=128;break}}while(1){q=aK<<4;C=q|2;c[1052804+(C<<2)>>2]=1;a[1089668+C|0]=0;a[1085572+C|0]=0;C=q|3;c[1052804+(C<<2)>>2]=1;a[1089668+C|0]=0;a[1085572+C|0]=0;C=aK+1|0;if(C>>>0<192){aK=C}else{aL=128;break}}while(1){C=aL<<4;q=C|4;c[1052804+(q<<2)>>2]=0;a[1089668+q|0]=0;a[1085572+q|0]=0;q=C|5;c[1052804+(q<<2)>>2]=0;a[1089668+q|0]=0;a[1085572+q|0]=0;q=aL+1|0;if(q>>>0<192){aL=q}else{aM=0;break}}while(1){q=aM<<4;C=aM<<15;s=32768;do{z=s>>>12|q;B=c[263192]|0;c[1052804+(z<<2)>>2]=B+(4194304-(s&32768)+(Hv((c[274486]|0)-4194304|0,C)|0));a[1089668+z|0]=1;a[1085572+z|0]=0;s=s+4096|0;}while(s>>>0<65536);s=aM+1|0;if(s>>>0<64){aM=s}else{aN=64;break}}while(1){s=aN<<4;C=(aN<<15)+2097152&4161536;q=0;do{z=q>>>12|s;B=c[263192]|0;c[1052804+(z<<2)>>2]=B+(4194304-(q&32768)+(Hv((c[274486]|0)-4194304|0,C)|0));a[1089668+z|0]=1;a[1085572+z|0]=0;q=q+4096|0;}while(q>>>0<65536);q=aN+1|0;if(q>>>0<128){aN=q}else{aO=128;break}}while(1){q=aO<<4;C=Hv(4194304,aO<<15&4161536)|0;s=q|8;z=C-32768|0;C=(c[263192]|0)+z|0;c[1052804+(s<<2)>>2]=C;a[1089668+s|0]=1;a[1085572+s|0]=0;s=q|9;c[1052804+(s<<2)>>2]=C;a[1089668+s|0]=1;a[1085572+s|0]=0;s=q|10;c[1052804+(s<<2)>>2]=C;a[1089668+s|0]=1;a[1085572+s|0]=0;s=q|11;c[1052804+(s<<2)>>2]=C;a[1089668+s|0]=1;a[1085572+s|0]=0;s=q|12;c[1052804+(s<<2)>>2]=C;a[1089668+s|0]=1;a[1085572+s|0]=0;s=q|13;c[1052804+(s<<2)>>2]=(c[263192]|0)+z;a[1089668+s|0]=1;a[1085572+s|0]=0;s=q|14;c[1052804+(s<<2)>>2]=(c[263192]|0)+z;a[1089668+s|0]=1;a[1085572+s|0]=0;s=q|15;c[1052804+(s<<2)>>2]=(c[263192]|0)+z;a[1089668+s|0]=1;a[1085572+s|0]=0;s=aO+1|0;if(s>>>0<192){aO=s}else{aP=192;break}}while(1){s=aP<<4;z=(Hv(4194304,(aP<<15)+2097152&4161536)|0)+2097152|0;q=0;do{C=q>>>12|s;c[1052804+(C<<2)>>2]=(c[263192]|0)+(z-(q&32768));a[1089668+C|0]=1;a[1085572+C|0]=0;q=q+4096|0;}while(q>>>0<65536);q=aP+1|0;if(q>>>0<256){aP=q}else{aR=112;break}}while(1){q=aR<<4;c[1052804+(q<<2)>>2]=2;a[1089668+q|0]=0;a[1085572+q|0]=1;z=q|1;c[1052804+(z<<2)>>2]=2;a[1089668+z|0]=0;a[1085572+z|0]=1;z=q|2;c[1052804+(z<<2)>>2]=2;a[1089668+z|0]=0;a[1085572+z|0]=1;z=q|3;c[1052804+(z<<2)>>2]=2;a[1089668+z|0]=0;a[1085572+z|0]=1;z=q|4;c[1052804+(z<<2)>>2]=2;a[1089668+z|0]=0;a[1085572+z|0]=1;z=q|5;c[1052804+(z<<2)>>2]=2;a[1089668+z|0]=0;a[1085572+z|0]=1;z=q|6;c[1052804+(z<<2)>>2]=2;a[1089668+z|0]=0;a[1085572+z|0]=1;z=q|7;c[1052804+(z<<2)>>2]=2;a[1089668+z|0]=0;a[1085572+z|0]=1;z=aR+1|0;if(z>>>0<128){aR=z}else{aS=240;break}}while(1){z=aS<<4;c[1052804+(z<<2)>>2]=2;a[1089668+z|0]=0;a[1085572+z|0]=1;q=z|1;c[1052804+(q<<2)>>2]=2;a[1089668+q|0]=0;a[1085572+q|0]=1;q=z|2;c[1052804+(q<<2)>>2]=2;a[1089668+q|0]=0;a[1085572+q|0]=1;q=z|3;c[1052804+(q<<2)>>2]=2;a[1089668+q|0]=0;a[1085572+q|0]=1;q=z|4;c[1052804+(q<<2)>>2]=2;a[1089668+q|0]=0;a[1085572+q|0]=1;q=z|5;c[1052804+(q<<2)>>2]=2;a[1089668+q|0]=0;a[1085572+q|0]=1;q=z|6;c[1052804+(q<<2)>>2]=2;a[1089668+q|0]=0;a[1085572+q|0]=1;q=z|7;c[1052804+(q<<2)>>2]=2;a[1089668+q|0]=0;a[1085572+q|0]=1;q=aS+1|0;if(q>>>0<256){aS=q}else{aT=0;break}}while(1){q=aT>>>12|2016;c[1052804+(q<<2)>>2]=c[263191];a[1089668+q|0]=0;a[1085572+q|0]=1;q=aT+4096|0;if(q>>>0<65536){aT=q}else{aU=0;break}}do{q=aU>>>12|2032;c[1052804+(q<<2)>>2]=(c[263191]|0)+65536;a[1089668+q|0]=0;a[1085572+q|0]=1;aU=aU+4096|0;}while(aU>>>0<65536);X5(1069188,1052804,16384)|0;q=0;while(1){if((a[1089668+q|0]|0)!=0){c[1069188+(q<<2)>>2]=18}q=q+1|0;if((q|0)>=4096){break L12210}}}if((bJ(1097862,72448,17)|0)==0){dd(1344)|0;q=c[263191]|0;z=0;while(1){s=z<<4;c[1052804+(s<<2)>>2]=q;a[1089668+s|0]=0;a[1085572+s|0]=1;C=s|1;c[1052804+(C<<2)>>2]=q;a[1089668+C|0]=0;a[1085572+C|0]=1;C=z+1|0;if(C>>>0<64){z=C}else{aV=0;break}}while(1){z=aV<<4;C=z|2;c[1052804+(C<<2)>>2]=1;a[1089668+C|0]=0;a[1085572+C|0]=0;C=z|3;c[1052804+(C<<2)>>2]=1;a[1089668+C|0]=0;a[1085572+C|0]=0;C=aV+1|0;if(C>>>0<64){aV=C}else{aW=0;break}}while(1){C=aW<<4;z=C|4;c[1052804+(z<<2)>>2]=0;a[1089668+z|0]=0;a[1085572+z|0]=0;z=C|5;c[1052804+(z<<2)>>2]=0;a[1089668+z|0]=0;a[1085572+z|0]=0;z=aW+1|0;if(z>>>0<64){aW=z}else{aX=128;break}}while(1){z=aX<<4;c[1052804+(z<<2)>>2]=q;a[1089668+z|0]=0;a[1085572+z|0]=1;C=z|1;c[1052804+(C<<2)>>2]=q;a[1089668+C|0]=0;a[1085572+C|0]=1;C=aX+1|0;if(C>>>0<192){aX=C}else{aY=128;break}}while(1){q=aY<<4;C=q|2;c[1052804+(C<<2)>>2]=1;a[1089668+C|0]=0;a[1085572+C|0]=0;C=q|3;c[1052804+(C<<2)>>2]=1;a[1089668+C|0]=0;a[1085572+C|0]=0;C=aY+1|0;if(C>>>0<192){aY=C}else{aZ=128;break}}while(1){C=aZ<<4;q=C|4;c[1052804+(q<<2)>>2]=0;a[1089668+q|0]=0;a[1085572+q|0]=0;q=C|5;c[1052804+(q<<2)>>2]=0;a[1089668+q|0]=0;a[1085572+q|0]=0;q=aZ+1|0;if(q>>>0<192){aZ=q}else{a_=0;break}}while(1){q=a_<<4;C=a_<<15;z=32768;do{s=z>>>12|q;B=c[263192]|0;c[1052804+(s<<2)>>2]=B+((Hv(c[274486]|0,C)|0)-(z&32768));a[1089668+s|0]=1;a[1085572+s|0]=0;z=z+4096|0;}while(z>>>0<65536);z=a_+1|0;if(z>>>0<64){a_=z}else{a$=64;break}}while(1){z=a$<<4;C=a$<<15;q=0;do{s=q>>>12|z;B=c[263192]|0;c[1052804+(s<<2)>>2]=B+((Hv(c[274486]|0,C)|0)-(q&32768));a[1089668+s|0]=1;a[1085572+s|0]=0;q=q+4096|0;}while(q>>>0<65536);q=a$+1|0;if(q>>>0<128){a$=q}else{a0=128;break}}while(1){q=a0<<4;C=a0<<15&4161536;z=32768;do{s=z>>>12|q;B=c[263192]|0;c[1052804+(s<<2)>>2]=B+((Hv(c[274486]|0,C)|0)-(z&32768));a[1089668+s|0]=1;a[1085572+s|0]=0;z=z+4096|0;}while(z>>>0<65536);z=a0+1|0;if(z>>>0<192){a0=z}else{a1=192;break}}while(1){z=a1<<4;C=a1<<15&4161536;q=0;do{s=q>>>12|z;B=c[263192]|0;c[1052804+(s<<2)>>2]=B+((Hv(c[274486]|0,C)|0)-(q&32768));a[1089668+s|0]=1;a[1085572+s|0]=0;q=q+4096|0;}while(q>>>0<65536);q=a1+1|0;if(q>>>0<256){a1=q}else{a2=112;break}}while(1){q=a2<<4;C=0;do{z=C>>>12|q;c[1052804+(z<<2)>>2]=2;a[1089668+z|0]=0;a[1085572+z|0]=1;C=C+4096|0;}while(C>>>0<65536);C=a2+1|0;if(C>>>0<128){a2=C}else{a3=240;break}}while(1){C=a3<<4;q=0;do{z=q>>>12|C;c[1052804+(z<<2)>>2]=2;a[1089668+z|0]=0;a[1085572+z|0]=1;q=q+4096|0;}while(q>>>0<65536);q=a3+1|0;if(q>>>0<256){a3=q}else{a4=0;break}}while(1){q=a4>>>12|2016;c[1052804+(q<<2)>>2]=c[263191];a[1089668+q|0]=0;a[1085572+q|0]=1;q=a4+4096|0;if(q>>>0<65536){a4=q}else{a5=0;break}}do{q=a5>>>12|2032;c[1052804+(q<<2)>>2]=(c[263191]|0)+65536;a[1089668+q|0]=0;a[1085572+q|0]=1;a5=a5+4096|0;}while(a5>>>0<65536);X5(1069188,1052804,16384)|0;q=0;while(1){if((a[1089668+q|0]|0)!=0){c[1069188+(q<<2)>>2]=18}q=q+1|0;if((q|0)>=4096){break L12210}}}do{if((bJ(1097862,69992,17)|0)!=0){if((bJ(1097862,68856,17)|0)==0){break}do{if((bJ(1097862,67152,21)|0)!=0){if((bJ(1097862,65e3,11)|0)==0){break}if((bJ(1097862,62088,19)|0)==0){if((c[261130]|0)!=4){a[1097938]=5;dd(1640)|0;q=c[263191]|0;C=0;while(1){z=C<<4;c[1052804+(z<<2)>>2]=q;a[1089668+z|0]=0;a[1085572+z|0]=1;s=z|1;c[1052804+(s<<2)>>2]=q;a[1089668+s|0]=0;a[1085572+s|0]=1;s=C+1|0;if(s>>>0<64){C=s}else{a6=0;break}}while(1){C=a6<<4;s=C|2;c[1052804+(s<<2)>>2]=1;a[1089668+s|0]=0;a[1085572+s|0]=0;s=C|3;c[1052804+(s<<2)>>2]=1;a[1089668+s|0]=0;a[1085572+s|0]=0;s=a6+1|0;if(s>>>0<64){a6=s}else{a7=0;break}}while(1){s=a7<<4;C=s|4;c[1052804+(C<<2)>>2]=0;a[1089668+C|0]=0;a[1085572+C|0]=0;C=s|5;c[1052804+(C<<2)>>2]=0;a[1089668+C|0]=0;a[1085572+C|0]=0;C=a7+1|0;if(C>>>0<64){a7=C}else{a8=128;break}}while(1){C=a8<<4;c[1052804+(C<<2)>>2]=q;a[1089668+C|0]=0;a[1085572+C|0]=1;s=C|1;c[1052804+(s<<2)>>2]=q;a[1089668+s|0]=0;a[1085572+s|0]=1;s=a8+1|0;if(s>>>0<192){a8=s}else{a9=128;break}}while(1){q=a9<<4;s=q|2;c[1052804+(s<<2)>>2]=1;a[1089668+s|0]=0;a[1085572+s|0]=0;s=q|3;c[1052804+(s<<2)>>2]=1;a[1089668+s|0]=0;a[1085572+s|0]=0;s=a9+1|0;if(s>>>0<192){a9=s}else{ba=128;break}}while(1){s=ba<<4;q=s|4;c[1052804+(q<<2)>>2]=0;a[1089668+q|0]=0;a[1085572+q|0]=0;q=s|5;c[1052804+(q<<2)>>2]=0;a[1089668+q|0]=0;a[1085572+q|0]=0;q=ba+1|0;if(q>>>0<192){ba=q}else{bb=0;break}}while(1){q=bb<<4;s=Hv(262144,bb<<15)|0;C=q|8;z=s-32768|0;s=(c[263192]|0)+z|0;c[1052804+(C<<2)>>2]=s;a[1089668+C|0]=1;a[1085572+C|0]=0;C=q|9;c[1052804+(C<<2)>>2]=s;a[1089668+C|0]=1;a[1085572+C|0]=0;C=q|10;c[1052804+(C<<2)>>2]=s;a[1089668+C|0]=1;a[1085572+C|0]=0;C=q|11;c[1052804+(C<<2)>>2]=s;a[1089668+C|0]=1;a[1085572+C|0]=0;C=q|12;c[1052804+(C<<2)>>2]=s;a[1089668+C|0]=1;a[1085572+C|0]=0;C=q|13;c[1052804+(C<<2)>>2]=(c[263192]|0)+z;a[1089668+C|0]=1;a[1085572+C|0]=0;C=q|14;c[1052804+(C<<2)>>2]=(c[263192]|0)+z;a[1089668+C|0]=1;a[1085572+C|0]=0;C=q|15;c[1052804+(C<<2)>>2]=(c[263192]|0)+z;a[1089668+C|0]=1;a[1085572+C|0]=0;C=bb+1|0;if(C>>>0<32){bb=C}else{bc=32;break}}while(1){C=bc<<4;z=Hv(1048576,(bc<<15)+3145728&4161536)|0;q=C|8;s=z+1015808|0;z=(c[263192]|0)+s|0;c[1052804+(q<<2)>>2]=z;a[1089668+q|0]=1;a[1085572+q|0]=0;q=C|9;c[1052804+(q<<2)>>2]=z;a[1089668+q|0]=1;a[1085572+q|0]=0;q=C|10;c[1052804+(q<<2)>>2]=z;a[1089668+q|0]=1;a[1085572+q|0]=0;q=C|11;c[1052804+(q<<2)>>2]=z;a[1089668+q|0]=1;a[1085572+q|0]=0;q=C|12;c[1052804+(q<<2)>>2]=z;a[1089668+q|0]=1;a[1085572+q|0]=0;q=C|13;c[1052804+(q<<2)>>2]=(c[263192]|0)+s;a[1089668+q|0]=1;a[1085572+q|0]=0;q=C|14;c[1052804+(q<<2)>>2]=(c[263192]|0)+s;a[1089668+q|0]=1;a[1085572+q|0]=0;q=C|15;c[1052804+(q<<2)>>2]=(c[263192]|0)+s;a[1089668+q|0]=1;a[1085572+q|0]=0;q=bc+1|0;if(q>>>0<64){bc=q}else{be=64;break}}while(1){q=be<<4;s=Hv(1048576,(be<<15)+2097152&4161536)|0;C=q|8;z=s+2064384|0;s=(c[263192]|0)+z|0;c[1052804+(C<<2)>>2]=s;a[1089668+C|0]=1;a[1085572+C|0]=0;C=q|9;c[1052804+(C<<2)>>2]=s;a[1089668+C|0]=1;a[1085572+C|0]=0;C=q|10;c[1052804+(C<<2)>>2]=s;a[1089668+C|0]=1;a[1085572+C|0]=0;C=q|11;c[1052804+(C<<2)>>2]=s;a[1089668+C|0]=1;a[1085572+C|0]=0;C=q|12;c[1052804+(C<<2)>>2]=s;a[1089668+C|0]=1;a[1085572+C|0]=0;C=q|13;c[1052804+(C<<2)>>2]=(c[263192]|0)+z;a[1089668+C|0]=1;a[1085572+C|0]=0;C=q|14;c[1052804+(C<<2)>>2]=(c[263192]|0)+z;a[1089668+C|0]=1;a[1085572+C|0]=0;C=q|15;c[1052804+(C<<2)>>2]=(c[263192]|0)+z;a[1089668+C|0]=1;a[1085572+C|0]=0;C=be+1|0;if(C>>>0<96){be=C}else{bf=128;break}}while(1){C=bf<<4;z=Hv(262144,bf<<15&4161536)|0;q=C|8;s=z-32768|0;z=(c[263192]|0)+s|0;c[1052804+(q<<2)>>2]=z;a[1089668+q|0]=1;a[1085572+q|0]=0;q=C|9;c[1052804+(q<<2)>>2]=z;a[1089668+q|0]=1;a[1085572+q|0]=0;q=C|10;c[1052804+(q<<2)>>2]=z;a[1089668+q|0]=1;a[1085572+q|0]=0;q=C|11;c[1052804+(q<<2)>>2]=z;a[1089668+q|0]=1;a[1085572+q|0]=0;q=C|12;c[1052804+(q<<2)>>2]=z;a[1089668+q|0]=1;a[1085572+q|0]=0;q=C|13;c[1052804+(q<<2)>>2]=(c[263192]|0)+s;a[1089668+q|0]=1;a[1085572+q|0]=0;q=C|14;c[1052804+(q<<2)>>2]=(c[263192]|0)+s;a[1089668+q|0]=1;a[1085572+q|0]=0;q=C|15;c[1052804+(q<<2)>>2]=(c[263192]|0)+s;a[1089668+q|0]=1;a[1085572+q|0]=0;q=bf+1|0;if(q>>>0<160){bf=q}else{bg=160;break}}while(1){q=bg<<4;s=Hv(1048576,(bg<<15)+3145728&4161536)|0;C=q|8;z=s+1015808|0;s=(c[263192]|0)+z|0;c[1052804+(C<<2)>>2]=s;a[1089668+C|0]=1;a[1085572+C|0]=0;C=q|9;c[1052804+(C<<2)>>2]=s;a[1089668+C|0]=1;a[1085572+C|0]=0;C=q|10;c[1052804+(C<<2)>>2]=s;a[1089668+C|0]=1;a[1085572+C|0]=0;C=q|11;c[1052804+(C<<2)>>2]=s;a[1089668+C|0]=1;a[1085572+C|0]=0;C=q|12;c[1052804+(C<<2)>>2]=s;a[1089668+C|0]=1;a[1085572+C|0]=0;C=q|13;c[1052804+(C<<2)>>2]=(c[263192]|0)+z;a[1089668+C|0]=1;a[1085572+C|0]=0;C=q|14;c[1052804+(C<<2)>>2]=(c[263192]|0)+z;a[1089668+C|0]=1;a[1085572+C|0]=0;C=q|15;c[1052804+(C<<2)>>2]=(c[263192]|0)+z;a[1089668+C|0]=1;a[1085572+C|0]=0;C=bg+1|0;if(C>>>0<192){bg=C}else{bi=192;break}}do{C=bi<<4;z=Hv(1048576,(bi<<15)+2097152&4161536)|0;q=C|8;s=z+2064384|0;z=(c[263192]|0)+s|0;c[1052804+(q<<2)>>2]=z;a[1089668+q|0]=1;a[1085572+q|0]=0;q=C|9;c[1052804+(q<<2)>>2]=z;a[1089668+q|0]=1;a[1085572+q|0]=0;q=C|10;c[1052804+(q<<2)>>2]=z;a[1089668+q|0]=1;a[1085572+q|0]=0;q=C|11;c[1052804+(q<<2)>>2]=z;a[1089668+q|0]=1;a[1085572+q|0]=0;q=C|12;c[1052804+(q<<2)>>2]=z;a[1089668+q|0]=1;a[1085572+q|0]=0;q=C|13;c[1052804+(q<<2)>>2]=(c[263192]|0)+s;a[1089668+q|0]=1;a[1085572+q|0]=0;q=C|14;c[1052804+(q<<2)>>2]=(c[263192]|0)+s;a[1089668+q|0]=1;a[1085572+q|0]=0;q=C|15;c[1052804+(q<<2)>>2]=(c[263192]|0)+s;a[1089668+q|0]=1;a[1085572+q|0]=0;bi=bi+1|0;}while(bi>>>0<224);q=96;s=c[263193]|0;while(1){C=q<<4;z=C|8;c[1052804+(z<<2)>>2]=s-32768;a[1089668+z|0]=0;a[1085572+z|0]=1;z=C|9;B=c[263193]|0;g=B-32768|0;c[1052804+(z<<2)>>2]=g;a[1089668+z|0]=0;a[1085572+z|0]=1;z=C|10;c[1052804+(z<<2)>>2]=g;a[1089668+z|0]=0;a[1085572+z|0]=1;z=C|11;c[1052804+(z<<2)>>2]=g;a[1089668+z|0]=0;a[1085572+z|0]=1;z=C|12;c[1052804+(z<<2)>>2]=g;a[1089668+z|0]=0;a[1085572+z|0]=1;z=C|13;c[1052804+(z<<2)>>2]=g;a[1089668+z|0]=0;a[1085572+z|0]=1;z=C|14;c[1052804+(z<<2)>>2]=g;a[1089668+z|0]=0;a[1085572+z|0]=1;z=C|15;c[1052804+(z<<2)>>2]=g;a[1089668+z|0]=0;a[1085572+z|0]=1;z=q+1|0;if(z>>>0<100){q=z;s=B}else{bj=224;bk=B;break}}while(1){s=bj<<4;q=s|8;c[1052804+(q<<2)>>2]=bk-32768;a[1089668+q|0]=0;a[1085572+q|0]=1;q=s|9;B=c[263193]|0;z=B-32768|0;c[1052804+(q<<2)>>2]=z;a[1089668+q|0]=0;a[1085572+q|0]=1;q=s|10;c[1052804+(q<<2)>>2]=z;a[1089668+q|0]=0;a[1085572+q|0]=1;q=s|11;c[1052804+(q<<2)>>2]=z;a[1089668+q|0]=0;a[1085572+q|0]=1;q=s|12;c[1052804+(q<<2)>>2]=z;a[1089668+q|0]=0;a[1085572+q|0]=1;q=s|13;c[1052804+(q<<2)>>2]=z;a[1089668+q|0]=0;a[1085572+q|0]=1;q=s|14;c[1052804+(q<<2)>>2]=z;a[1089668+q|0]=0;a[1085572+q|0]=1;q=s|15;c[1052804+(q<<2)>>2]=z;a[1089668+q|0]=0;a[1085572+q|0]=1;q=bj+1|0;if(q>>>0<228){bj=q;bk=B}else{bl=112;bm=B;break}}while(1){B=bl<<4;q=B|8;c[1052804+(q<<2)>>2]=bm-16384;a[1089668+q|0]=0;a[1085572+q|0]=1;q=B|9;z=c[263193]|0;s=z-16384|0;c[1052804+(q<<2)>>2]=s;a[1089668+q|0]=0;a[1085572+q|0]=1;q=B|10;c[1052804+(q<<2)>>2]=s;a[1089668+q|0]=0;a[1085572+q|0]=1;q=B|11;c[1052804+(q<<2)>>2]=s;a[1089668+q|0]=0;a[1085572+q|0]=1;q=B|12;c[1052804+(q<<2)>>2]=s;a[1089668+q|0]=0;a[1085572+q|0]=1;q=B|13;c[1052804+(q<<2)>>2]=s;a[1089668+q|0]=0;a[1085572+q|0]=1;q=B|14;c[1052804+(q<<2)>>2]=s;a[1089668+q|0]=0;a[1085572+q|0]=1;q=B|15;c[1052804+(q<<2)>>2]=s;a[1089668+q|0]=0;a[1085572+q|0]=1;q=bl+1|0;if(q>>>0<116){bl=q;bm=z}else{bn=240;bo=z;break}}while(1){z=bn<<4;q=z|8;c[1052804+(q<<2)>>2]=bo-16384;a[1089668+q|0]=0;a[1085572+q|0]=1;q=z|9;s=c[263193]|0;B=s-16384|0;c[1052804+(q<<2)>>2]=B;a[1089668+q|0]=0;a[1085572+q|0]=1;q=z|10;c[1052804+(q<<2)>>2]=B;a[1089668+q|0]=0;a[1085572+q|0]=1;q=z|11;c[1052804+(q<<2)>>2]=B;a[1089668+q|0]=0;a[1085572+q|0]=1;q=z|12;c[1052804+(q<<2)>>2]=B;a[1089668+q|0]=0;a[1085572+q|0]=1;q=z|13;c[1052804+(q<<2)>>2]=B;a[1089668+q|0]=0;a[1085572+q|0]=1;q=z|14;c[1052804+(q<<2)>>2]=B;a[1089668+q|0]=0;a[1085572+q|0]=1;q=z|15;c[1052804+(q<<2)>>2]=B;a[1089668+q|0]=0;a[1085572+q|0]=1;q=bn+1|0;if(q>>>0<244){bn=q;bo=s}else{bp=0;break}}while(1){s=bp>>>12|2016;c[1052804+(s<<2)>>2]=c[263191];a[1089668+s|0]=0;a[1085572+s|0]=1;s=bp+4096|0;if(s>>>0<65536){bp=s}else{bq=0;break}}do{s=bq>>>12|2032;c[1052804+(s<<2)>>2]=(c[263191]|0)+65536;a[1089668+s|0]=0;a[1085572+s|0]=1;bq=bq+4096|0;}while(bq>>>0<65536);X5(1069188,1052804,16384)|0;s=0;while(1){if((a[1089668+s|0]|0)!=0){c[1069188+(s<<2)>>2]=18}s=s+1|0;if((s|0)>=4096){break L12210}}}a[1097938]=c[261133]&255;dd(1296)|0;s=c[263191]|0;q=0;while(1){B=q<<4;c[1052804+(B<<2)>>2]=s;a[1089668+B|0]=0;a[1085572+B|0]=1;z=B|1;c[1052804+(z<<2)>>2]=s;a[1089668+z|0]=0;a[1085572+z|0]=1;z=q+1|0;if(z>>>0<64){q=z}else{br=0;break}}while(1){q=br<<4;z=q|2;c[1052804+(z<<2)>>2]=1;a[1089668+z|0]=0;a[1085572+z|0]=0;z=q|3;c[1052804+(z<<2)>>2]=1;a[1089668+z|0]=0;a[1085572+z|0]=0;z=br+1|0;if(z>>>0<64){br=z}else{bs=0;break}}while(1){z=bs<<4;q=z|4;c[1052804+(q<<2)>>2]=0;a[1089668+q|0]=0;a[1085572+q|0]=0;q=z|5;c[1052804+(q<<2)>>2]=0;a[1089668+q|0]=0;a[1085572+q|0]=0;q=bs+1|0;if(q>>>0<64){bs=q}else{bt=128;break}}while(1){q=bt<<4;c[1052804+(q<<2)>>2]=s;a[1089668+q|0]=0;a[1085572+q|0]=1;z=q|1;c[1052804+(z<<2)>>2]=s;a[1089668+z|0]=0;a[1085572+z|0]=1;z=bt+1|0;if(z>>>0<192){bt=z}else{bu=128;break}}while(1){s=bu<<4;z=s|2;c[1052804+(z<<2)>>2]=1;a[1089668+z|0]=0;a[1085572+z|0]=0;z=s|3;c[1052804+(z<<2)>>2]=1;a[1089668+z|0]=0;a[1085572+z|0]=0;z=bu+1|0;if(z>>>0<192){bu=z}else{bv=128;break}}while(1){z=bv<<4;s=z|4;c[1052804+(s<<2)>>2]=0;a[1089668+s|0]=0;a[1085572+s|0]=0;s=z|5;c[1052804+(s<<2)>>2]=0;a[1089668+s|0]=0;a[1085572+s|0]=0;s=bv+1|0;if(s>>>0<192){bv=s}else{bw=0;break}}do{s=bw<<4;z=Hv(262144,bw<<15)|0;q=s|8;B=z-32768|0;z=(c[263192]|0)+B|0;c[1052804+(q<<2)>>2]=z;a[1089668+q|0]=1;a[1085572+q|0]=0;q=s|9;c[1052804+(q<<2)>>2]=z;a[1089668+q|0]=1;a[1085572+q|0]=0;q=s|10;c[1052804+(q<<2)>>2]=z;a[1089668+q|0]=1;a[1085572+q|0]=0;q=s|11;c[1052804+(q<<2)>>2]=z;a[1089668+q|0]=1;a[1085572+q|0]=0;q=s|12;c[1052804+(q<<2)>>2]=z;a[1089668+q|0]=1;a[1085572+q|0]=0;q=s|13;c[1052804+(q<<2)>>2]=(c[263192]|0)+B;a[1089668+q|0]=1;a[1085572+q|0]=0;q=s|14;c[1052804+(q<<2)>>2]=(c[263192]|0)+B;a[1089668+q|0]=1;a[1085572+q|0]=0;q=s|15;c[1052804+(q<<2)>>2]=(c[263192]|0)+B;a[1089668+q|0]=1;a[1085572+q|0]=0;bw=bw+1|0;}while(bw>>>0<32);q=c[261131]|0;B=(c[261137]|0)-32768|0;s=32;do{z=s<<4;g=Hv(q,(s<<15)+3145728&4161536)|0;C=z|8;A=g+B|0;g=(c[263192]|0)+A|0;c[1052804+(C<<2)>>2]=g;a[1089668+C|0]=1;a[1085572+C|0]=0;C=z|9;c[1052804+(C<<2)>>2]=g;a[1089668+C|0]=1;a[1085572+C|0]=0;C=z|10;c[1052804+(C<<2)>>2]=g;a[1089668+C|0]=1;a[1085572+C|0]=0;C=z|11;c[1052804+(C<<2)>>2]=g;a[1089668+C|0]=1;a[1085572+C|0]=0;C=z|12;c[1052804+(C<<2)>>2]=g;a[1089668+C|0]=1;a[1085572+C|0]=0;C=z|13;c[1052804+(C<<2)>>2]=(c[263192]|0)+A;a[1089668+C|0]=1;a[1085572+C|0]=0;C=z|14;c[1052804+(C<<2)>>2]=(c[263192]|0)+A;a[1089668+C|0]=1;a[1085572+C|0]=0;C=z|15;c[1052804+(C<<2)>>2]=(c[263192]|0)+A;a[1089668+C|0]=1;a[1085572+C|0]=0;s=s+1|0;}while(s>>>0<64);s=c[261132]|0;C=(c[261138]|0)-32768|0;A=64;while(1){z=A<<4;g=Hv(s,(A<<15)+2097152&4161536)|0;h=z|8;f=g+C|0;g=(c[263192]|0)+f|0;c[1052804+(h<<2)>>2]=g;a[1089668+h|0]=1;a[1085572+h|0]=0;h=z|9;c[1052804+(h<<2)>>2]=g;a[1089668+h|0]=1;a[1085572+h|0]=0;h=z|10;c[1052804+(h<<2)>>2]=g;a[1089668+h|0]=1;a[1085572+h|0]=0;h=z|11;c[1052804+(h<<2)>>2]=g;a[1089668+h|0]=1;a[1085572+h|0]=0;h=z|12;c[1052804+(h<<2)>>2]=g;a[1089668+h|0]=1;a[1085572+h|0]=0;h=z|13;c[1052804+(h<<2)>>2]=(c[263192]|0)+f;a[1089668+h|0]=1;a[1085572+h|0]=0;h=z|14;c[1052804+(h<<2)>>2]=(c[263192]|0)+f;a[1089668+h|0]=1;a[1085572+h|0]=0;h=z|15;c[1052804+(h<<2)>>2]=(c[263192]|0)+f;a[1089668+h|0]=1;a[1085572+h|0]=0;h=A+1|0;if(h>>>0<96){A=h}else{bx=128;break}}while(1){A=bx<<4;h=Hv(262144,bx<<15&4161536)|0;f=A|8;z=h-32768|0;h=(c[263192]|0)+z|0;c[1052804+(f<<2)>>2]=h;a[1089668+f|0]=1;a[1085572+f|0]=0;f=A|9;c[1052804+(f<<2)>>2]=h;a[1089668+f|0]=1;a[1085572+f|0]=0;f=A|10;c[1052804+(f<<2)>>2]=h;a[1089668+f|0]=1;a[1085572+f|0]=0;f=A|11;c[1052804+(f<<2)>>2]=h;a[1089668+f|0]=1;a[1085572+f|0]=0;f=A|12;c[1052804+(f<<2)>>2]=h;a[1089668+f|0]=1;a[1085572+f|0]=0;f=A|13;c[1052804+(f<<2)>>2]=(c[263192]|0)+z;a[1089668+f|0]=1;a[1085572+f|0]=0;f=A|14;c[1052804+(f<<2)>>2]=(c[263192]|0)+z;a[1089668+f|0]=1;a[1085572+f|0]=0;f=A|15;c[1052804+(f<<2)>>2]=(c[263192]|0)+z;a[1089668+f|0]=1;a[1085572+f|0]=0;f=bx+1|0;if(f>>>0<160){bx=f}else{by=160;break}}while(1){f=by<<4;z=Hv(q,(by<<15)+3145728&4161536)|0;A=f|8;h=z+B|0;z=(c[263192]|0)+h|0;c[1052804+(A<<2)>>2]=z;a[1089668+A|0]=1;a[1085572+A|0]=0;A=f|9;c[1052804+(A<<2)>>2]=z;a[1089668+A|0]=1;a[1085572+A|0]=0;A=f|10;c[1052804+(A<<2)>>2]=z;a[1089668+A|0]=1;a[1085572+A|0]=0;A=f|11;c[1052804+(A<<2)>>2]=z;a[1089668+A|0]=1;a[1085572+A|0]=0;A=f|12;c[1052804+(A<<2)>>2]=z;a[1089668+A|0]=1;a[1085572+A|0]=0;A=f|13;c[1052804+(A<<2)>>2]=(c[263192]|0)+h;a[1089668+A|0]=1;a[1085572+A|0]=0;A=f|14;c[1052804+(A<<2)>>2]=(c[263192]|0)+h;a[1089668+A|0]=1;a[1085572+A|0]=0;A=f|15;c[1052804+(A<<2)>>2]=(c[263192]|0)+h;a[1089668+A|0]=1;a[1085572+A|0]=0;A=by+1|0;if(A>>>0<192){by=A}else{bz=192;break}}do{B=bz<<4;q=Hv(s,(bz<<15)+2097152&4161536)|0;A=B|8;h=q+C|0;q=(c[263192]|0)+h|0;c[1052804+(A<<2)>>2]=q;a[1089668+A|0]=1;a[1085572+A|0]=0;A=B|9;c[1052804+(A<<2)>>2]=q;a[1089668+A|0]=1;a[1085572+A|0]=0;A=B|10;c[1052804+(A<<2)>>2]=q;a[1089668+A|0]=1;a[1085572+A|0]=0;A=B|11;c[1052804+(A<<2)>>2]=q;a[1089668+A|0]=1;a[1085572+A|0]=0;A=B|12;c[1052804+(A<<2)>>2]=q;a[1089668+A|0]=1;a[1085572+A|0]=0;A=B|13;c[1052804+(A<<2)>>2]=(c[263192]|0)+h;a[1089668+A|0]=1;a[1085572+A|0]=0;A=B|14;c[1052804+(A<<2)>>2]=(c[263192]|0)+h;a[1089668+A|0]=1;a[1085572+A|0]=0;A=B|15;c[1052804+(A<<2)>>2]=(c[263192]|0)+h;a[1089668+A|0]=1;a[1085572+A|0]=0;bz=bz+1|0;}while(bz>>>0<224);if((c[261133]|0)!=0){C=96;while(1){s=C<<4;A=s|8;c[1052804+(A<<2)>>2]=2;a[1089668+A|0]=0;a[1085572+A|0]=1;A=s|9;c[1052804+(A<<2)>>2]=2;a[1089668+A|0]=0;a[1085572+A|0]=1;A=s|10;c[1052804+(A<<2)>>2]=2;a[1089668+A|0]=0;a[1085572+A|0]=1;A=s|11;c[1052804+(A<<2)>>2]=2;a[1089668+A|0]=0;a[1085572+A|0]=1;A=s|12;c[1052804+(A<<2)>>2]=2;a[1089668+A|0]=0;a[1085572+A|0]=1;A=s|13;c[1052804+(A<<2)>>2]=2;a[1089668+A|0]=0;a[1085572+A|0]=1;A=s|14;c[1052804+(A<<2)>>2]=2;a[1089668+A|0]=0;a[1085572+A|0]=1;A=s|15;c[1052804+(A<<2)>>2]=2;a[1089668+A|0]=0;a[1085572+A|0]=1;A=C+1|0;if(A>>>0<100){C=A}else{bA=224;break}}do{C=bA<<4;A=C|8;c[1052804+(A<<2)>>2]=2;a[1089668+A|0]=0;a[1085572+A|0]=1;A=C|9;c[1052804+(A<<2)>>2]=2;a[1089668+A|0]=0;a[1085572+A|0]=1;A=C|10;c[1052804+(A<<2)>>2]=2;a[1089668+A|0]=0;a[1085572+A|0]=1;A=C|11;c[1052804+(A<<2)>>2]=2;a[1089668+A|0]=0;a[1085572+A|0]=1;A=C|12;c[1052804+(A<<2)>>2]=2;a[1089668+A|0]=0;a[1085572+A|0]=1;A=C|13;c[1052804+(A<<2)>>2]=2;a[1089668+A|0]=0;a[1085572+A|0]=1;A=C|14;c[1052804+(A<<2)>>2]=2;a[1089668+A|0]=0;a[1085572+A|0]=1;A=C|15;c[1052804+(A<<2)>>2]=2;a[1089668+A|0]=0;a[1085572+A|0]=1;bA=bA+1|0;}while(bA>>>0<228)}if((c[261134]|0)==0){bB=0}else{A=112;while(1){C=A<<4;s=C|8;c[1052804+(s<<2)>>2]=3;a[1089668+s|0]=0;a[1085572+s|0]=1;s=C|9;c[1052804+(s<<2)>>2]=3;a[1089668+s|0]=0;a[1085572+s|0]=1;s=C|10;c[1052804+(s<<2)>>2]=3;a[1089668+s|0]=0;a[1085572+s|0]=1;s=C|11;c[1052804+(s<<2)>>2]=3;a[1089668+s|0]=0;a[1085572+s|0]=1;s=C|12;c[1052804+(s<<2)>>2]=3;a[1089668+s|0]=0;a[1085572+s|0]=1;s=C|13;c[1052804+(s<<2)>>2]=3;a[1089668+s|0]=0;a[1085572+s|0]=1;s=C|14;c[1052804+(s<<2)>>2]=3;a[1089668+s|0]=0;a[1085572+s|0]=1;s=C|15;c[1052804+(s<<2)>>2]=3;a[1089668+s|0]=0;a[1085572+s|0]=1;s=A+1|0;if(s>>>0<116){A=s}else{bC=240;break}}while(1){A=bC<<4;s=A|8;c[1052804+(s<<2)>>2]=3;a[1089668+s|0]=0;a[1085572+s|0]=1;s=A|9;c[1052804+(s<<2)>>2]=3;a[1089668+s|0]=0;a[1085572+s|0]=1;s=A|10;c[1052804+(s<<2)>>2]=3;a[1089668+s|0]=0;a[1085572+s|0]=1;s=A|11;c[1052804+(s<<2)>>2]=3;a[1089668+s|0]=0;a[1085572+s|0]=1;s=A|12;c[1052804+(s<<2)>>2]=3;a[1089668+s|0]=0;a[1085572+s|0]=1;s=A|13;c[1052804+(s<<2)>>2]=3;a[1089668+s|0]=0;a[1085572+s|0]=1;s=A|14;c[1052804+(s<<2)>>2]=3;a[1089668+s|0]=0;a[1085572+s|0]=1;s=A|15;c[1052804+(s<<2)>>2]=3;a[1089668+s|0]=0;a[1085572+s|0]=1;s=bC+1|0;if(s>>>0<244){bC=s}else{bB=0;break}}}while(1){s=bB>>>12|2016;c[1052804+(s<<2)>>2]=c[263191];a[1089668+s|0]=0;a[1085572+s|0]=1;s=bB+4096|0;if(s>>>0<65536){bB=s}else{bD=0;break}}do{s=bD>>>12|2032;c[1052804+(s<<2)>>2]=(c[263191]|0)+65536;a[1089668+s|0]=0;a[1085572+s|0]=1;bD=bD+4096|0;}while(bD>>>0<65536);X5(1069188,1052804,16384)|0;s=0;while(1){if((a[1089668+s|0]|0)!=0){c[1069188+(s<<2)>>2]=18}s=s+1|0;if((s|0)>=4096){break L12210}}}else{dd(1536)|0;s=c[263191]|0;A=0;while(1){C=A<<4;c[1052804+(C<<2)>>2]=s;a[1089668+C|0]=0;a[1085572+C|0]=1;h=C|1;c[1052804+(h<<2)>>2]=s;a[1089668+h|0]=0;a[1085572+h|0]=1;h=A+1|0;if(h>>>0<64){A=h}else{bE=0;break}}while(1){A=bE<<4;h=A|2;c[1052804+(h<<2)>>2]=1;a[1089668+h|0]=0;a[1085572+h|0]=0;h=A|3;c[1052804+(h<<2)>>2]=1;a[1089668+h|0]=0;a[1085572+h|0]=0;h=bE+1|0;if(h>>>0<64){bE=h}else{bF=0;break}}while(1){h=bF<<4;A=h|4;c[1052804+(A<<2)>>2]=0;a[1089668+A|0]=0;a[1085572+A|0]=0;A=h|5;c[1052804+(A<<2)>>2]=0;a[1089668+A|0]=0;a[1085572+A|0]=0;A=bF+1|0;if(A>>>0<64){bF=A}else{bG=128;break}}while(1){A=bG<<4;c[1052804+(A<<2)>>2]=s;a[1089668+A|0]=0;a[1085572+A|0]=1;h=A|1;c[1052804+(h<<2)>>2]=s;a[1089668+h|0]=0;a[1085572+h|0]=1;h=bG+1|0;if(h>>>0<192){bG=h}else{bH=128;break}}while(1){s=bH<<4;h=s|2;c[1052804+(h<<2)>>2]=1;a[1089668+h|0]=0;a[1085572+h|0]=0;h=s|3;c[1052804+(h<<2)>>2]=1;a[1089668+h|0]=0;a[1085572+h|0]=0;h=bH+1|0;if(h>>>0<192){bH=h}else{bI=128;break}}while(1){h=bI<<4;s=h|4;c[1052804+(s<<2)>>2]=0;a[1089668+s|0]=0;a[1085572+s|0]=0;s=h|5;c[1052804+(s<<2)>>2]=0;a[1089668+s|0]=0;a[1085572+s|0]=0;s=bI+1|0;if(s>>>0<192){bI=s}else{bK=0;break}}while(1){s=bK<<4;h=bK<<15;A=32768;do{C=A>>>12|s;B=c[263192]|0;c[1052804+(C<<2)>>2]=B+((Hv(c[274486]|0,h)|0)-(A&32768));a[1089668+C|0]=1;a[1085572+C|0]=0;A=A+4096|0;}while(A>>>0<65536);A=bK+1|0;if(A>>>0<64){bK=A}else{bL=64;break}}while(1){A=bL<<4;h=bL<<15;s=0;do{C=s>>>12|A;B=c[263192]|0;c[1052804+(C<<2)>>2]=B+((Hv(c[274486]|0,h)|0)-(s&32768));a[1089668+C|0]=1;a[1085572+C|0]=0;s=s+4096|0;}while(s>>>0<65536);s=bL+1|0;if(s>>>0<128){bL=s}else{bM=128;break}}while(1){s=bM<<4;h=bM<<15&4161536;A=32768;do{C=A>>>12|s;B=c[263192]|0;c[1052804+(C<<2)>>2]=B+((Hv(c[274486]|0,h)|0)-(A&32768));a[1089668+C|0]=1;a[1085572+C|0]=0;A=A+4096|0;}while(A>>>0<65536);A=bM+1|0;if(A>>>0<192){bM=A}else{bO=192;break}}do{A=bO<<4;h=bO<<15&4161536;s=0;do{C=s>>>12|A;B=c[263192]|0;c[1052804+(C<<2)>>2]=B+((Hv(c[274486]|0,h)|0)-(s&32768));a[1089668+C|0]=1;a[1085572+C|0]=0;s=s+4096|0;}while(s>>>0<65536);bO=bO+1|0;}while(bO>>>0<256);L12668:do{if((a[799122]|0)==0){if((a[799124]|0)!=0){s=0;while(1){h=s<<4;A=h|6;c[1052804+(A<<2)>>2]=13;a[1089668+A|0]=0;a[1085572+A|0]=0;A=h|7;c[1052804+(A<<2)>>2]=13;a[1089668+A|0]=0;a[1085572+A|0]=0;A=s+1|0;if(A>>>0<64){s=A}else{bP=128;break}}while(1){s=bP<<4;A=s|6;c[1052804+(A<<2)>>2]=13;a[1089668+A|0]=0;a[1085572+A|0]=0;A=s|7;c[1052804+(A<<2)>>2]=13;a[1089668+A|0]=0;a[1085572+A|0]=0;A=bP+1|0;if(A>>>0<192){bP=A}else{bQ=112;break L12668}}}if((a[799128]|0)!=0){A=0;while(1){s=A<<4;h=s|6;c[1052804+(h<<2)>>2]=14;a[1089668+h|0]=0;a[1085572+h|0]=0;h=s|7;c[1052804+(h<<2)>>2]=14;a[1089668+h|0]=0;a[1085572+h|0]=0;h=A+1|0;if(h>>>0<64){A=h}else{bR=128;break}}while(1){A=bR<<4;h=A|6;c[1052804+(h<<2)>>2]=14;a[1089668+h|0]=0;a[1085572+h|0]=0;h=A|7;c[1052804+(h<<2)>>2]=14;a[1089668+h|0]=0;a[1085572+h|0]=0;h=bR+1|0;if(h>>>0<192){bR=h}else{bQ=112;break L12668}}}if((a[799129]|0)==3){bS=0}else{bQ=112;break}while(1){h=bS<<4|3;c[1052804+(h<<2)>>2]=16;a[1089668+h|0]=0;a[1085572+h|0]=0;h=bS+1|0;if(h>>>0<64){bS=h}else{bT=128;break}}while(1){h=bT<<4|3;c[1052804+(h<<2)>>2]=16;a[1089668+h|0]=0;a[1085572+h|0]=0;h=bT+1|0;if(h>>>0<192){bT=h}else{bQ=112;break}}}else{switch(c[295942]|0){case 0:{h=32;while(1){A=h<<4;s=A|8;c[1052804+(s<<2)>>2]=5;a[1089668+s|0]=0;a[1085572+s|0]=0;s=A|9;c[1052804+(s<<2)>>2]=5;a[1089668+s|0]=0;a[1085572+s|0]=0;s=A|10;c[1052804+(s<<2)>>2]=5;a[1089668+s|0]=0;a[1085572+s|0]=0;s=A|11;c[1052804+(s<<2)>>2]=5;a[1089668+s|0]=0;a[1085572+s|0]=0;s=A|12;c[1052804+(s<<2)>>2]=5;a[1089668+s|0]=0;a[1085572+s|0]=0;s=A|13;c[1052804+(s<<2)>>2]=5;a[1089668+s|0]=0;a[1085572+s|0]=0;s=A|14;c[1052804+(s<<2)>>2]=5;a[1089668+s|0]=0;a[1085572+s|0]=0;s=A|15;c[1052804+(s<<2)>>2]=5;a[1089668+s|0]=0;a[1085572+s|0]=0;s=h+1|0;if(s>>>0<64){h=s}else{bU=160;break}}while(1){h=bU<<4;s=h|8;c[1052804+(s<<2)>>2]=5;a[1089668+s|0]=0;a[1085572+s|0]=0;s=h|9;c[1052804+(s<<2)>>2]=5;a[1089668+s|0]=0;a[1085572+s|0]=0;s=h|10;c[1052804+(s<<2)>>2]=5;a[1089668+s|0]=0;a[1085572+s|0]=0;s=h|11;c[1052804+(s<<2)>>2]=5;a[1089668+s|0]=0;a[1085572+s|0]=0;s=h|12;c[1052804+(s<<2)>>2]=5;a[1089668+s|0]=0;a[1085572+s|0]=0;s=h|13;c[1052804+(s<<2)>>2]=5;a[1089668+s|0]=0;a[1085572+s|0]=0;s=h|14;c[1052804+(s<<2)>>2]=5;a[1089668+s|0]=0;a[1085572+s|0]=0;s=h|15;c[1052804+(s<<2)>>2]=5;a[1089668+s|0]=0;a[1085572+s|0]=0;s=bU+1|0;if(s>>>0<192){bU=s}else{bQ=112;break}}break};case 1:{s=96;while(1){h=s<<4;c[1052804+(h<<2)>>2]=5;a[1089668+h|0]=0;a[1085572+h|0]=0;A=h|1;c[1052804+(A<<2)>>2]=5;a[1089668+A|0]=0;a[1085572+A|0]=0;A=h|2;c[1052804+(A<<2)>>2]=5;a[1089668+A|0]=0;a[1085572+A|0]=0;A=h|3;c[1052804+(A<<2)>>2]=5;a[1089668+A|0]=0;a[1085572+A|0]=0;A=h|4;c[1052804+(A<<2)>>2]=5;a[1089668+A|0]=0;a[1085572+A|0]=0;A=h|5;c[1052804+(A<<2)>>2]=5;a[1089668+A|0]=0;a[1085572+A|0]=0;A=h|6;c[1052804+(A<<2)>>2]=5;a[1089668+A|0]=0;a[1085572+A|0]=0;A=h|7;c[1052804+(A<<2)>>2]=5;a[1089668+A|0]=0;a[1085572+A|0]=0;A=s+1|0;if(A>>>0<112){s=A}else{bV=224;break}}while(1){s=bV<<4;c[1052804+(s<<2)>>2]=5;a[1089668+s|0]=0;a[1085572+s|0]=0;A=s|1;c[1052804+(A<<2)>>2]=5;a[1089668+A|0]=0;a[1085572+A|0]=0;A=s|2;c[1052804+(A<<2)>>2]=5;a[1089668+A|0]=0;a[1085572+A|0]=0;A=s|3;c[1052804+(A<<2)>>2]=5;a[1089668+A|0]=0;a[1085572+A|0]=0;A=s|4;c[1052804+(A<<2)>>2]=5;a[1089668+A|0]=0;a[1085572+A|0]=0;A=s|5;c[1052804+(A<<2)>>2]=5;a[1089668+A|0]=0;a[1085572+A|0]=0;A=s|6;c[1052804+(A<<2)>>2]=5;a[1089668+A|0]=0;a[1085572+A|0]=0;A=s|7;c[1052804+(A<<2)>>2]=5;a[1089668+A|0]=0;a[1085572+A|0]=0;A=bV+1|0;if(A>>>0<240){bV=A}else{bQ=112;break}}break};case 2:{A=0;while(1){s=A<<4;h=s|6;c[1052804+(h<<2)>>2]=5;a[1089668+h|0]=0;a[1085572+h|0]=0;h=s|7;c[1052804+(h<<2)>>2]=5;a[1089668+h|0]=0;a[1085572+h|0]=0;h=A+1|0;if(h>>>0<32){A=h}else{bW=128;break}}while(1){A=bW<<4;h=A|6;c[1052804+(h<<2)>>2]=5;a[1089668+h|0]=0;a[1085572+h|0]=0;h=A|7;c[1052804+(h<<2)>>2]=5;a[1089668+h|0]=0;a[1085572+h|0]=0;h=bW+1|0;if(h>>>0<160){bW=h}else{bQ=112;break}}break};case 3:{h=32;while(1){A=h<<4|6;c[1052804+(A<<2)>>2]=5;a[1089668+A|0]=0;a[1085572+A|0]=0;A=h+1|0;if(A>>>0<64){h=A}else{bX=32;break}}while(1){h=bX<<4;A=h|8;c[1052804+(A<<2)>>2]=5;a[1089668+A|0]=0;a[1085572+A|0]=0;A=h|9;c[1052804+(A<<2)>>2]=5;a[1089668+A|0]=0;a[1085572+A|0]=0;A=h|10;c[1052804+(A<<2)>>2]=5;a[1089668+A|0]=0;a[1085572+A|0]=0;A=h|11;c[1052804+(A<<2)>>2]=5;a[1089668+A|0]=0;a[1085572+A|0]=0;A=bX+1|0;if(A>>>0<64){bX=A}else{bY=160;break}}while(1){A=bY<<4|6;c[1052804+(A<<2)>>2]=5;a[1089668+A|0]=0;a[1085572+A|0]=0;A=bY+1|0;if(A>>>0<192){bY=A}else{bZ=160;break}}while(1){A=bZ<<4;h=A|8;c[1052804+(h<<2)>>2]=5;a[1089668+h|0]=0;a[1085572+h|0]=0;h=A|9;c[1052804+(h<<2)>>2]=5;a[1089668+h|0]=0;a[1085572+h|0]=0;h=A|10;c[1052804+(h<<2)>>2]=5;a[1089668+h|0]=0;a[1085572+h|0]=0;h=A|11;c[1052804+(h<<2)>>2]=5;a[1089668+h|0]=0;a[1085572+h|0]=0;h=bZ+1|0;if(h>>>0<192){bZ=h}else{bQ=112;break}}break};case 4:{h=32;while(1){A=h<<4;s=A|8;c[1052804+(s<<2)>>2]=5;a[1089668+s|0]=0;a[1085572+s|0]=0;s=A|9;c[1052804+(s<<2)>>2]=5;a[1089668+s|0]=0;a[1085572+s|0]=0;s=A|10;c[1052804+(s<<2)>>2]=5;a[1089668+s|0]=0;a[1085572+s|0]=0;s=A|11;c[1052804+(s<<2)>>2]=5;a[1089668+s|0]=0;a[1085572+s|0]=0;s=A|12;c[1052804+(s<<2)>>2]=5;a[1089668+s|0]=0;a[1085572+s|0]=0;s=A|13;c[1052804+(s<<2)>>2]=5;a[1089668+s|0]=0;a[1085572+s|0]=0;s=A|14;c[1052804+(s<<2)>>2]=5;a[1089668+s|0]=0;a[1085572+s|0]=0;s=A|15;c[1052804+(s<<2)>>2]=5;a[1089668+s|0]=0;a[1085572+s|0]=0;s=h+1|0;if(s>>>0<64){h=s}else{b_=160;break}}while(1){h=b_<<4;s=h|8;c[1052804+(s<<2)>>2]=5;a[1089668+s|0]=0;a[1085572+s|0]=0;s=h|9;c[1052804+(s<<2)>>2]=5;a[1089668+s|0]=0;a[1085572+s|0]=0;s=h|10;c[1052804+(s<<2)>>2]=5;a[1089668+s|0]=0;a[1085572+s|0]=0;s=h|11;c[1052804+(s<<2)>>2]=5;a[1089668+s|0]=0;a[1085572+s|0]=0;s=h|12;c[1052804+(s<<2)>>2]=5;a[1089668+s|0]=0;a[1085572+s|0]=0;s=h|13;c[1052804+(s<<2)>>2]=5;a[1089668+s|0]=0;a[1085572+s|0]=0;s=h|14;c[1052804+(s<<2)>>2]=5;a[1089668+s|0]=0;a[1085572+s|0]=0;s=h|15;c[1052804+(s<<2)>>2]=5;a[1089668+s|0]=0;a[1085572+s|0]=0;s=b_+1|0;if(s>>>0<192){b_=s}else{bQ=112;break}}break};case 5:{s=48;while(1){h=s<<4;A=h|8;c[1052804+(A<<2)>>2]=5;a[1089668+A|0]=0;a[1085572+A|0]=0;A=h|9;c[1052804+(A<<2)>>2]=5;a[1089668+A|0]=0;a[1085572+A|0]=0;A=h|10;c[1052804+(A<<2)>>2]=5;a[1089668+A|0]=0;a[1085572+A|0]=0;A=h|11;c[1052804+(A<<2)>>2]=5;a[1089668+A|0]=0;a[1085572+A|0]=0;A=h|12;c[1052804+(A<<2)>>2]=5;a[1089668+A|0]=0;a[1085572+A|0]=0;A=h|13;c[1052804+(A<<2)>>2]=5;a[1089668+A|0]=0;a[1085572+A|0]=0;A=h|14;c[1052804+(A<<2)>>2]=5;a[1089668+A|0]=0;a[1085572+A|0]=0;A=h|15;c[1052804+(A<<2)>>2]=5;a[1089668+A|0]=0;a[1085572+A|0]=0;A=s+1|0;if(A>>>0<64){s=A}else{b$=176;break}}while(1){s=b$<<4;A=s|8;c[1052804+(A<<2)>>2]=5;a[1089668+A|0]=0;a[1085572+A|0]=0;A=s|9;c[1052804+(A<<2)>>2]=5;a[1089668+A|0]=0;a[1085572+A|0]=0;A=s|10;c[1052804+(A<<2)>>2]=5;a[1089668+A|0]=0;a[1085572+A|0]=0;A=s|11;c[1052804+(A<<2)>>2]=5;a[1089668+A|0]=0;a[1085572+A|0]=0;A=s|12;c[1052804+(A<<2)>>2]=5;a[1089668+A|0]=0;a[1085572+A|0]=0;A=s|13;c[1052804+(A<<2)>>2]=5;a[1089668+A|0]=0;a[1085572+A|0]=0;A=s|14;c[1052804+(A<<2)>>2]=5;a[1089668+A|0]=0;a[1085572+A|0]=0;A=s|15;c[1052804+(A<<2)>>2]=5;a[1089668+A|0]=0;a[1085572+A|0]=0;A=b$+1|0;if(A>>>0<192){b$=A}else{bQ=112;break}}break};default:{bQ=112;break L12668}}}}while(0);while(1){A=bQ<<4;c[1052804+(A<<2)>>2]=2;a[1089668+A|0]=0;a[1085572+A|0]=1;s=A|1;c[1052804+(s<<2)>>2]=2;a[1089668+s|0]=0;a[1085572+s|0]=1;s=A|2;c[1052804+(s<<2)>>2]=2;a[1089668+s|0]=0;a[1085572+s|0]=1;s=A|3;c[1052804+(s<<2)>>2]=2;a[1089668+s|0]=0;a[1085572+s|0]=1;s=A|4;c[1052804+(s<<2)>>2]=2;a[1089668+s|0]=0;a[1085572+s|0]=1;s=A|5;c[1052804+(s<<2)>>2]=2;a[1089668+s|0]=0;a[1085572+s|0]=1;s=A|6;c[1052804+(s<<2)>>2]=2;a[1089668+s|0]=0;a[1085572+s|0]=1;s=A|7;c[1052804+(s<<2)>>2]=2;a[1089668+s|0]=0;a[1085572+s|0]=1;s=bQ+1|0;if(s>>>0<128){bQ=s}else{b0=240;break}}while(1){s=b0<<4;c[1052804+(s<<2)>>2]=2;a[1089668+s|0]=0;a[1085572+s|0]=1;A=s|1;c[1052804+(A<<2)>>2]=2;a[1089668+A|0]=0;a[1085572+A|0]=1;A=s|2;c[1052804+(A<<2)>>2]=2;a[1089668+A|0]=0;a[1085572+A|0]=1;A=s|3;c[1052804+(A<<2)>>2]=2;a[1089668+A|0]=0;a[1085572+A|0]=1;A=s|4;c[1052804+(A<<2)>>2]=2;a[1089668+A|0]=0;a[1085572+A|0]=1;A=s|5;c[1052804+(A<<2)>>2]=2;a[1089668+A|0]=0;a[1085572+A|0]=1;A=s|6;c[1052804+(A<<2)>>2]=2;a[1089668+A|0]=0;a[1085572+A|0]=1;A=s|7;c[1052804+(A<<2)>>2]=2;a[1089668+A|0]=0;a[1085572+A|0]=1;A=b0+1|0;if(A>>>0<256){b0=A}else{b1=0;break}}while(1){A=b1>>>12|2016;c[1052804+(A<<2)>>2]=c[263191];a[1089668+A|0]=0;a[1085572+A|0]=1;A=b1+4096|0;if(A>>>0<65536){b1=A}else{b2=0;break}}do{A=b2>>>12|2032;c[1052804+(A<<2)>>2]=(c[263191]|0)+65536;a[1089668+A|0]=0;a[1085572+A|0]=1;b2=b2+4096|0;}while(b2>>>0<65536);X5(1069188,1052804,16384)|0;A=0;while(1){if((a[1089668+A|0]|0)!=0){c[1069188+(A<<2)>>2]=18}A=A+1|0;if((A|0)>=4096){break L12210}}}}}while(0);dd(1552)|0;A=c[263191]|0;s=0;while(1){h=s<<4;c[1052804+(h<<2)>>2]=A;a[1089668+h|0]=0;a[1085572+h|0]=1;C=h|1;c[1052804+(C<<2)>>2]=A;a[1089668+C|0]=0;a[1085572+C|0]=1;C=s+1|0;if(C>>>0<64){s=C}else{b3=0;break}}while(1){s=b3<<4;C=s|2;c[1052804+(C<<2)>>2]=1;a[1089668+C|0]=0;a[1085572+C|0]=0;C=s|3;c[1052804+(C<<2)>>2]=1;a[1089668+C|0]=0;a[1085572+C|0]=0;C=b3+1|0;if(C>>>0<64){b3=C}else{b4=0;break}}while(1){C=b4<<4;s=C|4;c[1052804+(s<<2)>>2]=0;a[1089668+s|0]=0;a[1085572+s|0]=0;s=C|5;c[1052804+(s<<2)>>2]=0;a[1089668+s|0]=0;a[1085572+s|0]=0;s=b4+1|0;if(s>>>0<64){b4=s}else{b5=128;break}}while(1){s=b5<<4;c[1052804+(s<<2)>>2]=A;a[1089668+s|0]=0;a[1085572+s|0]=1;C=s|1;c[1052804+(C<<2)>>2]=A;a[1089668+C|0]=0;a[1085572+C|0]=1;C=b5+1|0;if(C>>>0<192){b5=C}else{b6=128;break}}while(1){A=b6<<4;C=A|2;c[1052804+(C<<2)>>2]=1;a[1089668+C|0]=0;a[1085572+C|0]=0;C=A|3;c[1052804+(C<<2)>>2]=1;a[1089668+C|0]=0;a[1085572+C|0]=0;C=b6+1|0;if(C>>>0<192){b6=C}else{b7=128;break}}while(1){C=b7<<4;A=C|4;c[1052804+(A<<2)>>2]=0;a[1089668+A|0]=0;a[1085572+A|0]=0;A=C|5;c[1052804+(A<<2)>>2]=0;a[1089668+A|0]=0;a[1085572+A|0]=0;A=b7+1|0;if(A>>>0<192){b7=A}else{b8=0;break}}while(1){A=b8<<4;C=b8<<15;s=32768;do{h=s>>>12|A;B=c[263192]|0;c[1052804+(h<<2)>>2]=B+((Hv(c[274486]|0,C)|0)-(s&32768));a[1089668+h|0]=1;a[1085572+h|0]=0;s=s+4096|0;}while(s>>>0<65536);s=b8+1|0;if(s>>>0<64){b8=s}else{b9=64;break}}while(1){s=b9<<4;C=b9<<15;A=0;do{h=A>>>12|s;B=c[263192]|0;c[1052804+(h<<2)>>2]=B+((Hv(c[274486]|0,C)|0)-(A&32768));a[1089668+h|0]=1;a[1085572+h|0]=0;A=A+4096|0;}while(A>>>0<65536);A=b9+1|0;if(A>>>0<128){b9=A}else{ca=128;break}}while(1){A=ca<<4;C=ca<<15&4161536;s=32768;do{h=s>>>12|A;B=c[263192]|0;c[1052804+(h<<2)>>2]=B+((Hv(c[274486]|0,C)|0)-(s&32768));a[1089668+h|0]=1;a[1085572+h|0]=0;s=s+4096|0;}while(s>>>0<65536);s=ca+1|0;if(s>>>0<192){ca=s}else{cb=192;break}}while(1){s=cb<<4;C=cb<<15&4161536;A=0;do{h=A>>>12|s;B=c[263192]|0;c[1052804+(h<<2)>>2]=B+((Hv(c[274486]|0,C)|0)-(A&32768));a[1089668+h|0]=1;a[1085572+h|0]=0;A=A+4096|0;}while(A>>>0<65536);A=cb+1|0;if(A>>>0<256){cb=A}else{cc=0;break}}while(1){A=cc>>>12|1792;c[1052804+(A<<2)>>2]=c[263193];a[1089668+A|0]=0;a[1085572+A|0]=1;A=cc+4096|0;if(A>>>0<65536){cc=A}else{cd=0;break}}while(1){A=cd>>>12|1808;c[1052804+(A<<2)>>2]=(c[263193]|0)+32768;a[1089668+A|0]=0;a[1085572+A|0]=1;A=cd+4096|0;if(A>>>0<65536){cd=A}else{cf=0;break}}while(1){A=cf>>>12|1824;c[1052804+(A<<2)>>2]=(c[263193]|0)+65536;a[1089668+A|0]=0;a[1085572+A|0]=1;A=cf+4096|0;if(A>>>0<65536){cf=A}else{cg=0;break}}while(1){A=cg>>>12|1840;c[1052804+(A<<2)>>2]=(c[263193]|0)+98304;a[1089668+A|0]=0;a[1085572+A|0]=1;A=cg+4096|0;if(A>>>0<65536){cg=A}else{ch=0;break}}while(1){A=ch>>>12|2016;c[1052804+(A<<2)>>2]=c[263191];a[1089668+A|0]=0;a[1085572+A|0]=1;A=ch+4096|0;if(A>>>0<65536){ch=A}else{ci=0;break}}do{A=ci>>>12|2032;c[1052804+(A<<2)>>2]=(c[263191]|0)+65536;a[1089668+A|0]=0;a[1085572+A|0]=1;ci=ci+4096|0;}while(ci>>>0<65536);X5(1069188,1052804,16384)|0;A=0;while(1){if((a[1089668+A|0]|0)!=0){c[1069188+(A<<2)>>2]=18}A=A+1|0;if((A|0)>=4096){break L12210}}}}while(0);dd(1320)|0;A=c[263191]|0;C=0;while(1){s=C<<4;c[1052804+(s<<2)>>2]=A;a[1089668+s|0]=0;a[1085572+s|0]=1;h=s|1;c[1052804+(h<<2)>>2]=A;a[1089668+h|0]=0;a[1085572+h|0]=1;h=C+1|0;if(h>>>0<64){C=h}else{cj=0;break}}while(1){C=cj<<4;h=C|2;c[1052804+(h<<2)>>2]=1;a[1089668+h|0]=0;a[1085572+h|0]=0;h=C|3;c[1052804+(h<<2)>>2]=1;a[1089668+h|0]=0;a[1085572+h|0]=0;h=cj+1|0;if(h>>>0<64){cj=h}else{ck=0;break}}while(1){h=ck<<4;C=h|4;c[1052804+(C<<2)>>2]=0;a[1089668+C|0]=0;a[1085572+C|0]=0;C=h|5;c[1052804+(C<<2)>>2]=0;a[1089668+C|0]=0;a[1085572+C|0]=0;C=ck+1|0;if(C>>>0<64){ck=C}else{cl=128;break}}while(1){C=cl<<4;c[1052804+(C<<2)>>2]=A;a[1089668+C|0]=0;a[1085572+C|0]=1;h=C|1;c[1052804+(h<<2)>>2]=A;a[1089668+h|0]=0;a[1085572+h|0]=1;h=cl+1|0;if(h>>>0<192){cl=h}else{cm=128;break}}while(1){A=cm<<4;h=A|2;c[1052804+(h<<2)>>2]=1;a[1089668+h|0]=0;a[1085572+h|0]=0;h=A|3;c[1052804+(h<<2)>>2]=1;a[1089668+h|0]=0;a[1085572+h|0]=0;h=cm+1|0;if(h>>>0<192){cm=h}else{cn=128;break}}while(1){h=cn<<4;A=h|4;c[1052804+(A<<2)>>2]=0;a[1089668+A|0]=0;a[1085572+A|0]=0;A=h|5;c[1052804+(A<<2)>>2]=0;a[1089668+A|0]=0;a[1085572+A|0]=0;A=cn+1|0;if(A>>>0<192){cn=A}else{co=0;break}}while(1){A=co<<4;h=Hv(1048576,co<<15)|0;C=A|8;s=h-32768|0;h=(c[263192]|0)+s|0;c[1052804+(C<<2)>>2]=h;a[1089668+C|0]=1;a[1085572+C|0]=0;C=A|9;c[1052804+(C<<2)>>2]=h;a[1089668+C|0]=1;a[1085572+C|0]=0;C=A|10;c[1052804+(C<<2)>>2]=h;a[1089668+C|0]=1;a[1085572+C|0]=0;C=A|11;c[1052804+(C<<2)>>2]=h;a[1089668+C|0]=1;a[1085572+C|0]=0;C=A|12;c[1052804+(C<<2)>>2]=h;a[1089668+C|0]=1;a[1085572+C|0]=0;C=A|13;c[1052804+(C<<2)>>2]=(c[263192]|0)+s;a[1089668+C|0]=1;a[1085572+C|0]=0;C=A|14;c[1052804+(C<<2)>>2]=(c[263192]|0)+s;a[1089668+C|0]=1;a[1085572+C|0]=0;C=A|15;c[1052804+(C<<2)>>2]=(c[263192]|0)+s;a[1089668+C|0]=1;a[1085572+C|0]=0;C=co+1|0;if(C>>>0<32){co=C}else{cp=32;break}}while(1){C=cp<<4;s=Hv(1048576,(cp<<15)+3145728&4161536)|0;A=C|8;h=s+1015808|0;s=(c[263192]|0)+h|0;c[1052804+(A<<2)>>2]=s;a[1089668+A|0]=1;a[1085572+A|0]=0;A=C|9;c[1052804+(A<<2)>>2]=s;a[1089668+A|0]=1;a[1085572+A|0]=0;A=C|10;c[1052804+(A<<2)>>2]=s;a[1089668+A|0]=1;a[1085572+A|0]=0;A=C|11;c[1052804+(A<<2)>>2]=s;a[1089668+A|0]=1;a[1085572+A|0]=0;A=C|12;c[1052804+(A<<2)>>2]=s;a[1089668+A|0]=1;a[1085572+A|0]=0;A=C|13;c[1052804+(A<<2)>>2]=(c[263192]|0)+h;a[1089668+A|0]=1;a[1085572+A|0]=0;A=C|14;c[1052804+(A<<2)>>2]=(c[263192]|0)+h;a[1089668+A|0]=1;a[1085572+A|0]=0;A=C|15;c[1052804+(A<<2)>>2]=(c[263192]|0)+h;a[1089668+A|0]=1;a[1085572+A|0]=0;A=cp+1|0;if(A>>>0<64){cp=A}else{cq=128;break}}while(1){A=cq<<4;h=Hv(1048576,cq<<15&4161536)|0;C=A|8;s=h+2064384|0;h=(c[263192]|0)+s|0;c[1052804+(C<<2)>>2]=h;a[1089668+C|0]=1;a[1085572+C|0]=0;C=A|9;c[1052804+(C<<2)>>2]=h;a[1089668+C|0]=1;a[1085572+C|0]=0;C=A|10;c[1052804+(C<<2)>>2]=h;a[1089668+C|0]=1;a[1085572+C|0]=0;C=A|11;c[1052804+(C<<2)>>2]=h;a[1089668+C|0]=1;a[1085572+C|0]=0;C=A|12;c[1052804+(C<<2)>>2]=h;a[1089668+C|0]=1;a[1085572+C|0]=0;C=A|13;c[1052804+(C<<2)>>2]=(c[263192]|0)+s;a[1089668+C|0]=1;a[1085572+C|0]=0;C=A|14;c[1052804+(C<<2)>>2]=(c[263192]|0)+s;a[1089668+C|0]=1;a[1085572+C|0]=0;C=A|15;c[1052804+(C<<2)>>2]=(c[263192]|0)+s;a[1089668+C|0]=1;a[1085572+C|0]=0;C=cq+1|0;if(C>>>0<160){cq=C}else{cr=160;break}}while(1){C=cr<<4;s=Hv(1048576,(cr<<15)+3145728&4161536)|0;A=C|8;h=s+1015808|0;s=(c[263192]|0)+h|0;c[1052804+(A<<2)>>2]=s;a[1089668+A|0]=1;a[1085572+A|0]=0;A=C|9;c[1052804+(A<<2)>>2]=s;a[1089668+A|0]=1;a[1085572+A|0]=0;A=C|10;c[1052804+(A<<2)>>2]=s;a[1089668+A|0]=1;a[1085572+A|0]=0;A=C|11;c[1052804+(A<<2)>>2]=s;a[1089668+A|0]=1;a[1085572+A|0]=0;A=C|12;c[1052804+(A<<2)>>2]=s;a[1089668+A|0]=1;a[1085572+A|0]=0;A=C|13;c[1052804+(A<<2)>>2]=(c[263192]|0)+h;a[1089668+A|0]=1;a[1085572+A|0]=0;A=C|14;c[1052804+(A<<2)>>2]=(c[263192]|0)+h;a[1089668+A|0]=1;a[1085572+A|0]=0;A=C|15;c[1052804+(A<<2)>>2]=(c[263192]|0)+h;a[1089668+A|0]=1;a[1085572+A|0]=0;A=cr+1|0;if(A>>>0<192){cr=A}else{cs=112;break}}while(1){A=cs<<4;c[1052804+(A<<2)>>2]=2;a[1089668+A|0]=0;a[1085572+A|0]=1;h=A|1;c[1052804+(h<<2)>>2]=2;a[1089668+h|0]=0;a[1085572+h|0]=1;h=A|2;c[1052804+(h<<2)>>2]=2;a[1089668+h|0]=0;a[1085572+h|0]=1;h=A|3;c[1052804+(h<<2)>>2]=2;a[1089668+h|0]=0;a[1085572+h|0]=1;h=A|4;c[1052804+(h<<2)>>2]=2;a[1089668+h|0]=0;a[1085572+h|0]=1;h=A|5;c[1052804+(h<<2)>>2]=2;a[1089668+h|0]=0;a[1085572+h|0]=1;h=A|6;c[1052804+(h<<2)>>2]=2;a[1089668+h|0]=0;a[1085572+h|0]=1;h=A|7;c[1052804+(h<<2)>>2]=2;a[1089668+h|0]=0;a[1085572+h|0]=1;h=cs+1|0;if(h>>>0<128){cs=h}else{ct=240;break}}while(1){h=ct<<4;c[1052804+(h<<2)>>2]=2;a[1089668+h|0]=0;a[1085572+h|0]=1;A=h|1;c[1052804+(A<<2)>>2]=2;a[1089668+A|0]=0;a[1085572+A|0]=1;A=h|2;c[1052804+(A<<2)>>2]=2;a[1089668+A|0]=0;a[1085572+A|0]=1;A=h|3;c[1052804+(A<<2)>>2]=2;a[1089668+A|0]=0;a[1085572+A|0]=1;A=h|4;c[1052804+(A<<2)>>2]=2;a[1089668+A|0]=0;a[1085572+A|0]=1;A=h|5;c[1052804+(A<<2)>>2]=2;a[1089668+A|0]=0;a[1085572+A|0]=1;A=h|6;c[1052804+(A<<2)>>2]=2;a[1089668+A|0]=0;a[1085572+A|0]=1;A=h|7;c[1052804+(A<<2)>>2]=2;a[1089668+A|0]=0;a[1085572+A|0]=1;A=ct+1|0;if(A>>>0<256){ct=A}else{cu=0;break}}while(1){A=cu>>>12|2016;c[1052804+(A<<2)>>2]=c[263191];a[1089668+A|0]=0;a[1085572+A|0]=1;A=cu+4096|0;if(A>>>0<65536){cu=A}else{cv=0;break}}do{A=cv>>>12|2032;c[1052804+(A<<2)>>2]=(c[263191]|0)+65536;a[1089668+A|0]=0;a[1085572+A|0]=1;cv=cv+4096|0;}while(cv>>>0<65536);X5(1069188,1052804,16384)|0;A=0;do{if((a[1089668+A|0]|0)!=0){c[1069188+(A<<2)>>2]=18}A=A+1|0;}while((A|0)<4096)}else{if(D){break}if((a[799126]|0)!=0){dd(1696)|0;A=c[263191]|0;h=0;while(1){C=h<<4;c[1052804+(C<<2)>>2]=A;a[1089668+C|0]=0;a[1085572+C|0]=1;s=C|1;c[1052804+(s<<2)>>2]=A;a[1089668+s|0]=0;a[1085572+s|0]=1;s=h+1|0;if(s>>>0<64){h=s}else{cw=0;break}}while(1){h=cw<<4;s=h|2;c[1052804+(s<<2)>>2]=1;a[1089668+s|0]=0;a[1085572+s|0]=0;s=h|3;c[1052804+(s<<2)>>2]=1;a[1089668+s|0]=0;a[1085572+s|0]=0;s=cw+1|0;if(s>>>0<64){cw=s}else{cx=0;break}}while(1){s=cx<<4;h=s|4;c[1052804+(h<<2)>>2]=0;a[1089668+h|0]=0;a[1085572+h|0]=0;h=s|5;c[1052804+(h<<2)>>2]=0;a[1089668+h|0]=0;a[1085572+h|0]=0;h=cx+1|0;if(h>>>0<64){cx=h}else{cy=128;break}}while(1){h=cy<<4;c[1052804+(h<<2)>>2]=A;a[1089668+h|0]=0;a[1085572+h|0]=1;s=h|1;c[1052804+(s<<2)>>2]=A;a[1089668+s|0]=0;a[1085572+s|0]=1;s=cy+1|0;if(s>>>0<192){cy=s}else{cz=128;break}}while(1){A=cz<<4;s=A|2;c[1052804+(s<<2)>>2]=1;a[1089668+s|0]=0;a[1085572+s|0]=0;s=A|3;c[1052804+(s<<2)>>2]=1;a[1089668+s|0]=0;a[1085572+s|0]=0;s=cz+1|0;if(s>>>0<192){cz=s}else{cA=128;break}}do{s=cA<<4;A=s|4;c[1052804+(A<<2)>>2]=0;a[1089668+A|0]=0;a[1085572+A|0]=0;A=s|5;c[1052804+(A<<2)>>2]=0;a[1089668+A|0]=0;a[1085572+A|0]=0;cA=cA+1|0;}while(cA>>>0<192);c[263207]=4;a[1089674]=0;a[1085578]=1;c[263208]=4;a[1089675]=0;a[1085579]=1;A=c[274486]|0;s=0;do{h=s<<4;C=h|8;B=c[263192]|0;q=Hv(A,s<<16)|0;f=B+q|0;c[1052804+(C<<2)>>2]=f;a[1089668+C|0]=1;a[1085572+C|0]=0;C=h|9;c[1052804+(C<<2)>>2]=f;a[1089668+C|0]=1;a[1085572+C|0]=0;C=h|10;c[1052804+(C<<2)>>2]=f;a[1089668+C|0]=1;a[1085572+C|0]=0;C=h|11;c[1052804+(C<<2)>>2]=f;a[1089668+C|0]=1;a[1085572+C|0]=0;C=h|12;c[1052804+(C<<2)>>2]=f;a[1089668+C|0]=1;a[1085572+C|0]=0;C=h|13;c[1052804+(C<<2)>>2]=(c[263192]|0)+q;a[1089668+C|0]=1;a[1085572+C|0]=0;C=h|14;c[1052804+(C<<2)>>2]=(c[263192]|0)+q;a[1089668+C|0]=1;a[1085572+C|0]=0;C=h|15;c[1052804+(C<<2)>>2]=(c[263192]|0)+q;a[1089668+C|0]=1;a[1085572+C|0]=0;s=s+1|0;}while(s>>>0<16);c[263975]=4;a[1090442]=0;a[1086346]=1;c[263976]=4;a[1090443]=0;a[1086347]=1;s=0;do{A=s>>>12|1280;c[1052804+(A<<2)>>2]=11;a[1089668+A|0]=1;a[1085572+A|0]=0;s=s+4096|0;}while(s>>>0<65536);s=c[274486]|0;A=128;while(1){C=A<<4;q=C|8;h=c[263192]|0;f=Hv(s,A<<16)|0;B=h+f|0;c[1052804+(q<<2)>>2]=B;a[1089668+q|0]=1;a[1085572+q|0]=0;q=C|9;c[1052804+(q<<2)>>2]=B;a[1089668+q|0]=1;a[1085572+q|0]=0;q=C|10;c[1052804+(q<<2)>>2]=B;a[1089668+q|0]=1;a[1085572+q|0]=0;q=C|11;c[1052804+(q<<2)>>2]=B;a[1089668+q|0]=1;a[1085572+q|0]=0;q=C|12;c[1052804+(q<<2)>>2]=B;a[1089668+q|0]=1;a[1085572+q|0]=0;q=C|13;c[1052804+(q<<2)>>2]=(c[263192]|0)+f;a[1089668+q|0]=1;a[1085572+q|0]=0;q=C|14;c[1052804+(q<<2)>>2]=(c[263192]|0)+f;a[1089668+q|0]=1;a[1085572+q|0]=0;q=C|15;c[1052804+(q<<2)>>2]=(c[263192]|0)+f;a[1089668+q|0]=1;a[1085572+q|0]=0;q=A+1|0;if(q>>>0<144){A=q}else{cB=192;break}}while(1){A=cB<<4;s=(cB<<16)-12582912|0;q=0;do{f=q>>>12|A;C=c[263192]|0;c[1052804+(f<<2)>>2]=C+(Hv(c[274486]|0,s)|0);a[1089668+f|0]=1;a[1085572+f|0]=0;q=q+4096|0;}while(q>>>0<65536);q=cB+1|0;if(q>>>0<208){cB=q}else{cC=208;break}}while(1){q=cC<<4;s=0;do{A=s>>>12|q;c[1052804+(A<<2)>>2]=10;a[1089668+A|0]=1;a[1085572+A|0]=0;s=s+4096|0;}while(s>>>0<65536);s=cC+1|0;if(s>>>0<256){cC=s}else{cD=0;break}}while(1){s=cD>>>12|2016;c[1052804+(s<<2)>>2]=c[263191];a[1089668+s|0]=0;a[1085572+s|0]=1;s=cD+4096|0;if(s>>>0<65536){cD=s}else{cE=0;break}}do{s=cE>>>12|2032;c[1052804+(s<<2)>>2]=(c[263191]|0)+65536;a[1089668+s|0]=0;a[1085572+s|0]=1;cE=cE+4096|0;}while(cE>>>0<65536);X5(1069188,1052804,16384)|0;s=0;while(1){if((a[1089668+s|0]|0)!=0){c[1069188+(s<<2)>>2]=18}s=s+1|0;if((s|0)>=4096){break L12210}}}if((a[1093764]|0)!=0){dd(1672)|0;s=c[263191]|0;q=0;while(1){A=q<<4;c[1052804+(A<<2)>>2]=s;a[1089668+A|0]=0;a[1085572+A|0]=1;f=A|1;c[1052804+(f<<2)>>2]=s;a[1089668+f|0]=0;a[1085572+f|0]=1;f=q+1|0;if(f>>>0<64){q=f}else{cF=0;break}}while(1){q=cF<<4;f=q|2;c[1052804+(f<<2)>>2]=1;a[1089668+f|0]=0;a[1085572+f|0]=0;f=q|3;c[1052804+(f<<2)>>2]=1;a[1089668+f|0]=0;a[1085572+f|0]=0;f=cF+1|0;if(f>>>0<64){cF=f}else{cG=0;break}}while(1){f=cG<<4;q=f|4;c[1052804+(q<<2)>>2]=0;a[1089668+q|0]=0;a[1085572+q|0]=0;q=f|5;c[1052804+(q<<2)>>2]=0;a[1089668+q|0]=0;a[1085572+q|0]=0;q=cG+1|0;if(q>>>0<64){cG=q}else{cH=128;break}}while(1){q=cH<<4;c[1052804+(q<<2)>>2]=s;a[1089668+q|0]=0;a[1085572+q|0]=1;f=q|1;c[1052804+(f<<2)>>2]=s;a[1089668+f|0]=0;a[1085572+f|0]=1;f=cH+1|0;if(f>>>0<192){cH=f}else{cI=128;break}}while(1){s=cI<<4;f=s|2;c[1052804+(f<<2)>>2]=1;a[1089668+f|0]=0;a[1085572+f|0]=0;f=s|3;c[1052804+(f<<2)>>2]=1;a[1089668+f|0]=0;a[1085572+f|0]=0;f=cI+1|0;if(f>>>0<192){cI=f}else{cJ=128;break}}while(1){f=cJ<<4;s=f|4;c[1052804+(s<<2)>>2]=0;a[1089668+s|0]=0;a[1085572+s|0]=0;s=f|5;c[1052804+(s<<2)>>2]=0;a[1089668+s|0]=0;a[1085572+s|0]=0;s=cJ+1|0;if(s>>>0<192){cJ=s}else{cK=0;break}}while(1){s=cK<<4;f=cK<<16;q=32768;do{A=q>>>12|s;C=c[263192]|0;c[1052804+(A<<2)>>2]=C+((Hv((c[274486]|0)-4194304|0,f)|0)+4194304);a[1089668+A|0]=1;a[1085572+A|0]=0;q=q+4096|0;}while(q>>>0<65536);q=cK+1|0;if(q>>>0<64){cK=q}else{cM=64;break}}while(1){q=cM<<4;f=(cM<<16)-4194304|0;s=0;do{A=s>>>12|q;C=c[263192]|0;c[1052804+(A<<2)>>2]=C+((Hv((c[274486]|0)-4194304|0,f)|0)+4194304);a[1089668+A|0]=1;a[1085572+A|0]=0;s=s+4096|0;}while(s>>>0<65536);s=cM+1|0;if(s>>>0<128){cM=s}else{cN=128;break}}while(1){s=cN<<4;f=Hv(4194304,(cN<<16)-8388608|0)|0;q=s|8;A=(c[263192]|0)+f|0;c[1052804+(q<<2)>>2]=A;a[1089668+q|0]=1;a[1085572+q|0]=0;q=s|9;c[1052804+(q<<2)>>2]=A;a[1089668+q|0]=1;a[1085572+q|0]=0;q=s|10;c[1052804+(q<<2)>>2]=A;a[1089668+q|0]=1;a[1085572+q|0]=0;q=s|11;c[1052804+(q<<2)>>2]=A;a[1089668+q|0]=1;a[1085572+q|0]=0;q=s|12;c[1052804+(q<<2)>>2]=A;a[1089668+q|0]=1;a[1085572+q|0]=0;q=s|13;c[1052804+(q<<2)>>2]=(c[263192]|0)+f;a[1089668+q|0]=1;a[1085572+q|0]=0;q=s|14;c[1052804+(q<<2)>>2]=(c[263192]|0)+f;a[1089668+q|0]=1;a[1085572+q|0]=0;q=s|15;c[1052804+(q<<2)>>2]=(c[263192]|0)+f;a[1089668+q|0]=1;a[1085572+q|0]=0;q=cN+1|0;if(q>>>0<192){cN=q}else{cO=192;break}}while(1){q=cO<<4;f=Hv(4194304,(cO<<16)-12582912|0)|0;s=0;do{A=s>>>12|q;c[1052804+(A<<2)>>2]=(c[263192]|0)+f;a[1089668+A|0]=1;a[1085572+A|0]=0;s=s+4096|0;}while(s>>>0<65536);s=cO+1|0;if(s>>>0<256){cO=s}else{cP=32;break}}while(1){s=cP<<4;f=s|6;c[1052804+(f<<2)>>2]=4;a[1089668+f|0]=0;a[1085572+f|0]=1;f=s|7;c[1052804+(f<<2)>>2]=4;a[1089668+f|0]=0;a[1085572+f|0]=1;f=cP+1|0;if(f>>>0<64){cP=f}else{cQ=160;break}}while(1){f=cQ<<4;s=f|6;c[1052804+(s<<2)>>2]=4;a[1089668+s|0]=0;a[1085572+s|0]=1;s=f|7;c[1052804+(s<<2)>>2]=4;a[1089668+s|0]=0;a[1085572+s|0]=1;s=cQ+1|0;if(s>>>0<192){cQ=s}else{cR=0;break}}while(1){s=cR>>>12|2016;c[1052804+(s<<2)>>2]=c[263191];a[1089668+s|0]=0;a[1085572+s|0]=1;s=cR+4096|0;if(s>>>0<65536){cR=s}else{cS=0;break}}do{s=cS>>>12|2032;c[1052804+(s<<2)>>2]=(c[263191]|0)+65536;a[1089668+s|0]=0;a[1085572+s|0]=1;cS=cS+4096|0;}while(cS>>>0<65536);X5(1069188,1052804,16384)|0;s=0;while(1){if((a[1089668+s|0]|0)!=0){c[1069188+(s<<2)>>2]=18}s=s+1|0;if((s|0)>=4096){break L12210}}}if((c[261130]|0)==3){dd(1456)|0;s=c[263191]|0;f=0;while(1){q=f<<4;c[1052804+(q<<2)>>2]=s;a[1089668+q|0]=0;a[1085572+q|0]=1;A=q|1;c[1052804+(A<<2)>>2]=s;a[1089668+A|0]=0;a[1085572+A|0]=1;A=f+1|0;if(A>>>0<64){f=A}else{cT=0;break}}while(1){f=cT<<4;A=f|2;c[1052804+(A<<2)>>2]=1;a[1089668+A|0]=0;a[1085572+A|0]=0;A=f|3;c[1052804+(A<<2)>>2]=1;a[1089668+A|0]=0;a[1085572+A|0]=0;A=cT+1|0;if(A>>>0<64){cT=A}else{cU=0;break}}while(1){A=cU<<4;f=A|4;c[1052804+(f<<2)>>2]=0;a[1089668+f|0]=0;a[1085572+f|0]=0;f=A|5;c[1052804+(f<<2)>>2]=0;a[1089668+f|0]=0;a[1085572+f|0]=0;f=cU+1|0;if(f>>>0<64){cU=f}else{cV=128;break}}while(1){f=cV<<4;c[1052804+(f<<2)>>2]=s;a[1089668+f|0]=0;a[1085572+f|0]=1;A=f|1;c[1052804+(A<<2)>>2]=s;a[1089668+A|0]=0;a[1085572+A|0]=1;A=cV+1|0;if(A>>>0<192){cV=A}else{cW=128;break}}while(1){s=cW<<4;A=s|2;c[1052804+(A<<2)>>2]=1;a[1089668+A|0]=0;a[1085572+A|0]=0;A=s|3;c[1052804+(A<<2)>>2]=1;a[1089668+A|0]=0;a[1085572+A|0]=0;A=cW+1|0;if(A>>>0<192){cW=A}else{cX=128;break}}do{A=cX<<4;s=A|4;c[1052804+(s<<2)>>2]=0;a[1089668+s|0]=0;a[1085572+s|0]=0;s=A|5;c[1052804+(s<<2)>>2]=0;a[1089668+s|0]=0;a[1085572+s|0]=0;cX=cX+1|0;}while(cX>>>0<192);s=c[261137]|0;A=c[261131]|0;f=0;do{q=f<<4;C=(Hv(A,f<<16)|0)+s|0;B=q|8;h=(c[263192]|0)+C|0;c[1052804+(B<<2)>>2]=h;a[1089668+B|0]=1;a[1085572+B|0]=0;B=q|9;c[1052804+(B<<2)>>2]=h;a[1089668+B|0]=1;a[1085572+B|0]=0;B=q|10;c[1052804+(B<<2)>>2]=h;a[1089668+B|0]=1;a[1085572+B|0]=0;B=q|11;c[1052804+(B<<2)>>2]=h;a[1089668+B|0]=1;a[1085572+B|0]=0;B=q|12;c[1052804+(B<<2)>>2]=h;a[1089668+B|0]=1;a[1085572+B|0]=0;B=q|13;c[1052804+(B<<2)>>2]=(c[263192]|0)+C;a[1089668+B|0]=1;a[1085572+B|0]=0;B=q|14;c[1052804+(B<<2)>>2]=(c[263192]|0)+C;a[1089668+B|0]=1;a[1085572+B|0]=0;B=q|15;c[1052804+(B<<2)>>2]=(c[263192]|0)+C;a[1089668+B|0]=1;a[1085572+B|0]=0;f=f+1|0;}while(f>>>0<32);f=c[261138]|0;B=c[261132]|0;C=32;while(1){q=C<<4;h=(Hv(B,(C<<16)-2097152|0)|0)+f|0;z=q|8;g=(c[263192]|0)+h|0;c[1052804+(z<<2)>>2]=g;a[1089668+z|0]=1;a[1085572+z|0]=0;z=q|9;c[1052804+(z<<2)>>2]=g;a[1089668+z|0]=1;a[1085572+z|0]=0;z=q|10;c[1052804+(z<<2)>>2]=g;a[1089668+z|0]=1;a[1085572+z|0]=0;z=q|11;c[1052804+(z<<2)>>2]=g;a[1089668+z|0]=1;a[1085572+z|0]=0;z=q|12;c[1052804+(z<<2)>>2]=g;a[1089668+z|0]=1;a[1085572+z|0]=0;z=q|13;c[1052804+(z<<2)>>2]=(c[263192]|0)+h;a[1089668+z|0]=1;a[1085572+z|0]=0;z=q|14;c[1052804+(z<<2)>>2]=(c[263192]|0)+h;a[1089668+z|0]=1;a[1085572+z|0]=0;z=q|15;c[1052804+(z<<2)>>2]=(c[263192]|0)+h;a[1089668+z|0]=1;a[1085572+z|0]=0;z=C+1|0;if(z>>>0<64){C=z}else{cY=64;break}}while(1){C=cY<<4;z=(Hv(A,(cY<<16)-4194304|0)|0)+s|0;h=0;do{q=h>>>12|C;c[1052804+(q<<2)>>2]=(c[263192]|0)+z;a[1089668+q|0]=1;a[1085572+q|0]=0;h=h+4096|0;}while(h>>>0<65536);h=cY+1|0;if(h>>>0<96){cY=h}else{cZ=96;break}}while(1){h=cZ<<4;z=(Hv(B,(cZ<<16)-6291456|0)|0)+f|0;C=0;do{q=C>>>12|h;c[1052804+(q<<2)>>2]=(c[263192]|0)+z;a[1089668+q|0]=1;a[1085572+q|0]=0;C=C+4096|0;}while(C>>>0<65536);C=cZ+1|0;if(C>>>0<128){cZ=C}else{c_=128;break}}while(1){C=c_<<4;z=(Hv(A,(c_<<16)-8388608|0)|0)+s|0;h=C|8;q=(c[263192]|0)+z|0;c[1052804+(h<<2)>>2]=q;a[1089668+h|0]=1;a[1085572+h|0]=0;h=C|9;c[1052804+(h<<2)>>2]=q;a[1089668+h|0]=1;a[1085572+h|0]=0;h=C|10;c[1052804+(h<<2)>>2]=q;a[1089668+h|0]=1;a[1085572+h|0]=0;h=C|11;c[1052804+(h<<2)>>2]=q;a[1089668+h|0]=1;a[1085572+h|0]=0;h=C|12;c[1052804+(h<<2)>>2]=q;a[1089668+h|0]=1;a[1085572+h|0]=0;h=C|13;c[1052804+(h<<2)>>2]=(c[263192]|0)+z;a[1089668+h|0]=1;a[1085572+h|0]=0;h=C|14;c[1052804+(h<<2)>>2]=(c[263192]|0)+z;a[1089668+h|0]=1;a[1085572+h|0]=0;h=C|15;c[1052804+(h<<2)>>2]=(c[263192]|0)+z;a[1089668+h|0]=1;a[1085572+h|0]=0;h=c_+1|0;if(h>>>0<160){c_=h}else{c$=160;break}}while(1){h=c$<<4;z=(Hv(B,(c$<<16)-10485760|0)|0)+f|0;C=h|8;q=(c[263192]|0)+z|0;c[1052804+(C<<2)>>2]=q;a[1089668+C|0]=1;a[1085572+C|0]=0;C=h|9;c[1052804+(C<<2)>>2]=q;a[1089668+C|0]=1;a[1085572+C|0]=0;C=h|10;c[1052804+(C<<2)>>2]=q;a[1089668+C|0]=1;a[1085572+C|0]=0;C=h|11;c[1052804+(C<<2)>>2]=q;a[1089668+C|0]=1;a[1085572+C|0]=0;C=h|12;c[1052804+(C<<2)>>2]=q;a[1089668+C|0]=1;a[1085572+C|0]=0;C=h|13;c[1052804+(C<<2)>>2]=(c[263192]|0)+z;a[1089668+C|0]=1;a[1085572+C|0]=0;C=h|14;c[1052804+(C<<2)>>2]=(c[263192]|0)+z;a[1089668+C|0]=1;a[1085572+C|0]=0;C=h|15;c[1052804+(C<<2)>>2]=(c[263192]|0)+z;a[1089668+C|0]=1;a[1085572+C|0]=0;C=c$+1|0;if(C>>>0<192){c$=C}else{c0=192;break}}while(1){C=c0<<4;z=(Hv(A,(c0<<16)-12582912|0)|0)+s|0;h=0;do{q=h>>>12|C;c[1052804+(q<<2)>>2]=(c[263192]|0)+z;a[1089668+q|0]=1;a[1085572+q|0]=0;h=h+4096|0;}while(h>>>0<65536);h=c0+1|0;if(h>>>0<224){c0=h}else{c3=224;break}}while(1){s=c3<<4;A=(Hv(B,(c3<<16)-14680064|0)|0)+f|0;h=0;do{z=h>>>12|s;c[1052804+(z<<2)>>2]=(c[263192]|0)+A;a[1089668+z|0]=1;a[1085572+z|0]=0;h=h+4096|0;}while(h>>>0<65536);h=c3+1|0;if(h>>>0<256){c3=h}else{c4=32;break}}while(1){f=c4<<4;B=f|6;c[1052804+(B<<2)>>2]=4;a[1089668+B|0]=0;a[1085572+B|0]=1;B=f|7;c[1052804+(B<<2)>>2]=4;a[1089668+B|0]=0;a[1085572+B|0]=1;B=c4+1|0;if(B>>>0<64){c4=B}else{c6=160;break}}while(1){B=c6<<4;f=B|6;c[1052804+(f<<2)>>2]=4;a[1089668+f|0]=0;a[1085572+f|0]=1;f=B|7;c[1052804+(f<<2)>>2]=4;a[1089668+f|0]=0;a[1085572+f|0]=1;f=c6+1|0;if(f>>>0<192){c6=f}else{c7=0;break}}while(1){f=c7>>>12|2016;c[1052804+(f<<2)>>2]=c[263191];a[1089668+f|0]=0;a[1085572+f|0]=1;f=c7+4096|0;if(f>>>0<65536){c7=f}else{c8=0;break}}do{f=c8>>>12|2032;c[1052804+(f<<2)>>2]=(c[263191]|0)+65536;a[1089668+f|0]=0;a[1085572+f|0]=1;c8=c8+4096|0;}while(c8>>>0<65536);X5(1069188,1052804,16384)|0;f=0;while(1){if((a[1089668+f|0]|0)!=0){c[1069188+(f<<2)>>2]=18}f=f+1|0;if((f|0)>=4096){break L12210}}}dd(1600)|0;f=c[263191]|0;B=0;while(1){h=B<<4;c[1052804+(h<<2)>>2]=f;a[1089668+h|0]=0;a[1085572+h|0]=1;A=h|1;c[1052804+(A<<2)>>2]=f;a[1089668+A|0]=0;a[1085572+A|0]=1;A=B+1|0;if(A>>>0<64){B=A}else{c9=0;break}}while(1){B=c9<<4;A=B|2;c[1052804+(A<<2)>>2]=1;a[1089668+A|0]=0;a[1085572+A|0]=0;A=B|3;c[1052804+(A<<2)>>2]=1;a[1089668+A|0]=0;a[1085572+A|0]=0;A=c9+1|0;if(A>>>0<64){c9=A}else{da=0;break}}while(1){A=da<<4;B=A|4;c[1052804+(B<<2)>>2]=0;a[1089668+B|0]=0;a[1085572+B|0]=0;B=A|5;c[1052804+(B<<2)>>2]=0;a[1089668+B|0]=0;a[1085572+B|0]=0;B=da+1|0;if(B>>>0<64){da=B}else{db=128;break}}while(1){B=db<<4;c[1052804+(B<<2)>>2]=f;a[1089668+B|0]=0;a[1085572+B|0]=1;A=B|1;c[1052804+(A<<2)>>2]=f;a[1089668+A|0]=0;a[1085572+A|0]=1;A=db+1|0;if(A>>>0<192){db=A}else{dc=128;break}}while(1){f=dc<<4;A=f|2;c[1052804+(A<<2)>>2]=1;a[1089668+A|0]=0;a[1085572+A|0]=0;A=f|3;c[1052804+(A<<2)>>2]=1;a[1089668+A|0]=0;a[1085572+A|0]=0;A=dc+1|0;if(A>>>0<192){dc=A}else{de=128;break}}do{A=de<<4;f=A|4;c[1052804+(f<<2)>>2]=0;a[1089668+f|0]=0;a[1085572+f|0]=0;f=A|5;c[1052804+(f<<2)>>2]=0;a[1089668+f|0]=0;a[1085572+f|0]=0;de=de+1|0;}while(de>>>0<192);f=c[274486]|0;A=0;while(1){B=A<<4;h=B|8;s=c[263192]|0;z=Hv(f,A<<16)|0;C=s+z|0;c[1052804+(h<<2)>>2]=C;a[1089668+h|0]=1;a[1085572+h|0]=0;h=B|9;c[1052804+(h<<2)>>2]=C;a[1089668+h|0]=1;a[1085572+h|0]=0;h=B|10;c[1052804+(h<<2)>>2]=C;a[1089668+h|0]=1;a[1085572+h|0]=0;h=B|11;c[1052804+(h<<2)>>2]=C;a[1089668+h|0]=1;a[1085572+h|0]=0;h=B|12;c[1052804+(h<<2)>>2]=C;a[1089668+h|0]=1;a[1085572+h|0]=0;h=B|13;c[1052804+(h<<2)>>2]=(c[263192]|0)+z;a[1089668+h|0]=1;a[1085572+h|0]=0;h=B|14;c[1052804+(h<<2)>>2]=(c[263192]|0)+z;a[1089668+h|0]=1;a[1085572+h|0]=0;h=B|15;c[1052804+(h<<2)>>2]=(c[263192]|0)+z;a[1089668+h|0]=1;a[1085572+h|0]=0;h=A+1|0;if(h>>>0<64){A=h}else{df=64;break}}do{A=df<<4;f=df<<16;h=0;do{z=h>>>12|A;B=c[263192]|0;c[1052804+(z<<2)>>2]=B+(Hv(c[274486]|0,f)|0);a[1089668+z|0]=1;a[1085572+z|0]=0;h=h+4096|0;}while(h>>>0<65536);df=df+1|0;}while(df>>>0<128);h=c[274486]|0;f=128;while(1){A=f<<4;z=A|8;B=c[263192]|0;C=Hv(h,f<<16)|0;s=B+C|0;c[1052804+(z<<2)>>2]=s;a[1089668+z|0]=1;a[1085572+z|0]=0;z=A|9;c[1052804+(z<<2)>>2]=s;a[1089668+z|0]=1;a[1085572+z|0]=0;z=A|10;c[1052804+(z<<2)>>2]=s;a[1089668+z|0]=1;a[1085572+z|0]=0;z=A|11;c[1052804+(z<<2)>>2]=s;a[1089668+z|0]=1;a[1085572+z|0]=0;z=A|12;c[1052804+(z<<2)>>2]=s;a[1089668+z|0]=1;a[1085572+z|0]=0;z=A|13;c[1052804+(z<<2)>>2]=(c[263192]|0)+C;a[1089668+z|0]=1;a[1085572+z|0]=0;z=A|14;c[1052804+(z<<2)>>2]=(c[263192]|0)+C;a[1089668+z|0]=1;a[1085572+z|0]=0;z=A|15;c[1052804+(z<<2)>>2]=(c[263192]|0)+C;a[1089668+z|0]=1;a[1085572+z|0]=0;z=f+1|0;if(z>>>0<192){f=z}else{dg=192;break}}do{f=dg<<4;h=dg<<16;z=0;do{C=z>>>12|f;A=c[263192]|0;c[1052804+(C<<2)>>2]=A+(Hv(c[274486]|0,h)|0);a[1089668+C|0]=1;a[1085572+C|0]=0;z=z+4096|0;}while(z>>>0<65536);dg=dg+1|0;}while(dg>>>0<256);L12996:do{if((a[799122]|0)==0){dh=32}else{switch(c[295942]|0){case 4:{z=32;while(1){h=z<<4;f=h|8;c[1052804+(f<<2)>>2]=5;a[1089668+f|0]=0;a[1085572+f|0]=0;f=h|9;c[1052804+(f<<2)>>2]=5;a[1089668+f|0]=0;a[1085572+f|0]=0;f=h|10;c[1052804+(f<<2)>>2]=5;a[1089668+f|0]=0;a[1085572+f|0]=0;f=h|11;c[1052804+(f<<2)>>2]=5;a[1089668+f|0]=0;a[1085572+f|0]=0;f=h|12;c[1052804+(f<<2)>>2]=5;a[1089668+f|0]=0;a[1085572+f|0]=0;f=h|13;c[1052804+(f<<2)>>2]=5;a[1089668+f|0]=0;a[1085572+f|0]=0;f=h|14;c[1052804+(f<<2)>>2]=5;a[1089668+f|0]=0;a[1085572+f|0]=0;f=h|15;c[1052804+(f<<2)>>2]=5;a[1089668+f|0]=0;a[1085572+f|0]=0;f=z+1|0;if(f>>>0<64){z=f}else{di=160;break}}while(1){z=di<<4;f=z|8;c[1052804+(f<<2)>>2]=5;a[1089668+f|0]=0;a[1085572+f|0]=0;f=z|9;c[1052804+(f<<2)>>2]=5;a[1089668+f|0]=0;a[1085572+f|0]=0;f=z|10;c[1052804+(f<<2)>>2]=5;a[1089668+f|0]=0;a[1085572+f|0]=0;f=z|11;c[1052804+(f<<2)>>2]=5;a[1089668+f|0]=0;a[1085572+f|0]=0;f=z|12;c[1052804+(f<<2)>>2]=5;a[1089668+f|0]=0;a[1085572+f|0]=0;f=z|13;c[1052804+(f<<2)>>2]=5;a[1089668+f|0]=0;a[1085572+f|0]=0;f=z|14;c[1052804+(f<<2)>>2]=5;a[1089668+f|0]=0;a[1085572+f|0]=0;f=z|15;c[1052804+(f<<2)>>2]=5;a[1089668+f|0]=0;a[1085572+f|0]=0;f=di+1|0;if(f>>>0<192){di=f}else{dh=32;break}}break};case 5:{f=48;while(1){z=f<<4;h=z|8;c[1052804+(h<<2)>>2]=5;a[1089668+h|0]=0;a[1085572+h|0]=0;h=z|9;c[1052804+(h<<2)>>2]=5;a[1089668+h|0]=0;a[1085572+h|0]=0;h=z|10;c[1052804+(h<<2)>>2]=5;a[1089668+h|0]=0;a[1085572+h|0]=0;h=z|11;c[1052804+(h<<2)>>2]=5;a[1089668+h|0]=0;a[1085572+h|0]=0;h=z|12;c[1052804+(h<<2)>>2]=5;a[1089668+h|0]=0;a[1085572+h|0]=0;h=z|13;c[1052804+(h<<2)>>2]=5;a[1089668+h|0]=0;a[1085572+h|0]=0;h=z|14;c[1052804+(h<<2)>>2]=5;a[1089668+h|0]=0;a[1085572+h|0]=0;h=z|15;c[1052804+(h<<2)>>2]=5;a[1089668+h|0]=0;a[1085572+h|0]=0;h=f+1|0;if(h>>>0<64){f=h}else{dj=176;break}}while(1){f=dj<<4;h=f|8;c[1052804+(h<<2)>>2]=5;a[1089668+h|0]=0;a[1085572+h|0]=0;h=f|9;c[1052804+(h<<2)>>2]=5;a[1089668+h|0]=0;a[1085572+h|0]=0;h=f|10;c[1052804+(h<<2)>>2]=5;a[1089668+h|0]=0;a[1085572+h|0]=0;h=f|11;c[1052804+(h<<2)>>2]=5;a[1089668+h|0]=0;a[1085572+h|0]=0;h=f|12;c[1052804+(h<<2)>>2]=5;a[1089668+h|0]=0;a[1085572+h|0]=0;h=f|13;c[1052804+(h<<2)>>2]=5;a[1089668+h|0]=0;a[1085572+h|0]=0;h=f|14;c[1052804+(h<<2)>>2]=5;a[1089668+h|0]=0;a[1085572+h|0]=0;h=f|15;c[1052804+(h<<2)>>2]=5;a[1089668+h|0]=0;a[1085572+h|0]=0;h=dj+1|0;if(h>>>0<192){dj=h}else{dh=32;break}}break};case 1:{h=96;while(1){f=h<<4;c[1052804+(f<<2)>>2]=5;a[1089668+f|0]=0;a[1085572+f|0]=0;z=f|1;c[1052804+(z<<2)>>2]=5;a[1089668+z|0]=0;a[1085572+z|0]=0;z=f|2;c[1052804+(z<<2)>>2]=5;a[1089668+z|0]=0;a[1085572+z|0]=0;z=f|3;c[1052804+(z<<2)>>2]=5;a[1089668+z|0]=0;a[1085572+z|0]=0;z=f|4;c[1052804+(z<<2)>>2]=5;a[1089668+z|0]=0;a[1085572+z|0]=0;z=f|5;c[1052804+(z<<2)>>2]=5;a[1089668+z|0]=0;a[1085572+z|0]=0;z=f|6;c[1052804+(z<<2)>>2]=5;a[1089668+z|0]=0;a[1085572+z|0]=0;z=f|7;c[1052804+(z<<2)>>2]=5;a[1089668+z|0]=0;a[1085572+z|0]=0;z=h+1|0;if(z>>>0<112){h=z}else{dk=224;break}}while(1){h=dk<<4;c[1052804+(h<<2)>>2]=5;a[1089668+h|0]=0;a[1085572+h|0]=0;z=h|1;c[1052804+(z<<2)>>2]=5;a[1089668+z|0]=0;a[1085572+z|0]=0;z=h|2;c[1052804+(z<<2)>>2]=5;a[1089668+z|0]=0;a[1085572+z|0]=0;z=h|3;c[1052804+(z<<2)>>2]=5;a[1089668+z|0]=0;a[1085572+z|0]=0;z=h|4;c[1052804+(z<<2)>>2]=5;a[1089668+z|0]=0;a[1085572+z|0]=0;z=h|5;c[1052804+(z<<2)>>2]=5;a[1089668+z|0]=0;a[1085572+z|0]=0;z=h|6;c[1052804+(z<<2)>>2]=5;a[1089668+z|0]=0;a[1085572+z|0]=0;z=h|7;c[1052804+(z<<2)>>2]=5;a[1089668+z|0]=0;a[1085572+z|0]=0;z=dk+1|0;if(z>>>0<240){dk=z}else{dh=32;break}}break};case 2:{z=0;while(1){h=z<<4;f=h|6;c[1052804+(f<<2)>>2]=5;a[1089668+f|0]=0;a[1085572+f|0]=0;f=h|7;c[1052804+(f<<2)>>2]=5;a[1089668+f|0]=0;a[1085572+f|0]=0;f=z+1|0;if(f>>>0<32){z=f}else{dl=128;break}}while(1){z=dl<<4;f=z|6;c[1052804+(f<<2)>>2]=5;a[1089668+f|0]=0;a[1085572+f|0]=0;f=z|7;c[1052804+(f<<2)>>2]=5;a[1089668+f|0]=0;a[1085572+f|0]=0;f=dl+1|0;if(f>>>0<160){dl=f}else{dh=32;break}}break};case 3:{f=32;while(1){z=f<<4|6;c[1052804+(z<<2)>>2]=5;a[1089668+z|0]=0;a[1085572+z|0]=0;z=f+1|0;if(z>>>0<64){f=z}else{dm=32;break}}while(1){f=dm<<4;z=f|8;c[1052804+(z<<2)>>2]=5;a[1089668+z|0]=0;a[1085572+z|0]=0;z=f|9;c[1052804+(z<<2)>>2]=5;a[1089668+z|0]=0;a[1085572+z|0]=0;z=f|10;c[1052804+(z<<2)>>2]=5;a[1089668+z|0]=0;a[1085572+z|0]=0;z=f|11;c[1052804+(z<<2)>>2]=5;a[1089668+z|0]=0;a[1085572+z|0]=0;z=dm+1|0;if(z>>>0<64){dm=z}else{dn=160;break}}while(1){z=dn<<4|6;c[1052804+(z<<2)>>2]=5;a[1089668+z|0]=0;a[1085572+z|0]=0;z=dn+1|0;if(z>>>0<192){dn=z}else{dp=160;break}}while(1){z=dp<<4;f=z|8;c[1052804+(f<<2)>>2]=5;a[1089668+f|0]=0;a[1085572+f|0]=0;f=z|9;c[1052804+(f<<2)>>2]=5;a[1089668+f|0]=0;a[1085572+f|0]=0;f=z|10;c[1052804+(f<<2)>>2]=5;a[1089668+f|0]=0;a[1085572+f|0]=0;f=z|11;c[1052804+(f<<2)>>2]=5;a[1089668+f|0]=0;a[1085572+f|0]=0;f=dp+1|0;if(f>>>0<192){dp=f}else{dh=32;break}}break};case 0:{f=32;while(1){z=f<<4;h=z|8;c[1052804+(h<<2)>>2]=5;a[1089668+h|0]=0;a[1085572+h|0]=0;h=z|9;c[1052804+(h<<2)>>2]=5;a[1089668+h|0]=0;a[1085572+h|0]=0;h=z|10;c[1052804+(h<<2)>>2]=5;a[1089668+h|0]=0;a[1085572+h|0]=0;h=z|11;c[1052804+(h<<2)>>2]=5;a[1089668+h|0]=0;a[1085572+h|0]=0;h=z|12;c[1052804+(h<<2)>>2]=5;a[1089668+h|0]=0;a[1085572+h|0]=0;h=z|13;c[1052804+(h<<2)>>2]=5;a[1089668+h|0]=0;a[1085572+h|0]=0;h=z|14;c[1052804+(h<<2)>>2]=5;a[1089668+h|0]=0;a[1085572+h|0]=0;h=z|15;c[1052804+(h<<2)>>2]=5;a[1089668+h|0]=0;a[1085572+h|0]=0;h=f+1|0;if(h>>>0<64){f=h}else{dq=160;break}}while(1){f=dq<<4;h=f|8;c[1052804+(h<<2)>>2]=5;a[1089668+h|0]=0;a[1085572+h|0]=0;h=f|9;c[1052804+(h<<2)>>2]=5;a[1089668+h|0]=0;a[1085572+h|0]=0;h=f|10;c[1052804+(h<<2)>>2]=5;a[1089668+h|0]=0;a[1085572+h|0]=0;h=f|11;c[1052804+(h<<2)>>2]=5;a[1089668+h|0]=0;a[1085572+h|0]=0;h=f|12;c[1052804+(h<<2)>>2]=5;a[1089668+h|0]=0;a[1085572+h|0]=0;h=f|13;c[1052804+(h<<2)>>2]=5;a[1089668+h|0]=0;a[1085572+h|0]=0;h=f|14;c[1052804+(h<<2)>>2]=5;a[1089668+h|0]=0;a[1085572+h|0]=0;h=f|15;c[1052804+(h<<2)>>2]=5;a[1089668+h|0]=0;a[1085572+h|0]=0;h=dq+1|0;if(h>>>0<192){dq=h}else{dh=32;break}}break};default:{dh=32;break L12996}}}}while(0);while(1){h=dh<<4;f=h|6;c[1052804+(f<<2)>>2]=4;a[1089668+f|0]=0;a[1085572+f|0]=1;f=h|7;c[1052804+(f<<2)>>2]=4;a[1089668+f|0]=0;a[1085572+f|0]=1;f=dh+1|0;if(f>>>0<64){dh=f}else{dr=160;break}}while(1){f=dr<<4;h=f|6;c[1052804+(h<<2)>>2]=4;a[1089668+h|0]=0;a[1085572+h|0]=1;h=f|7;c[1052804+(h<<2)>>2]=4;a[1089668+h|0]=0;a[1085572+h|0]=1;h=dr+1|0;if(h>>>0<192){dr=h}else{ds=0;break}}while(1){h=ds>>>12|2016;c[1052804+(h<<2)>>2]=c[263191];a[1089668+h|0]=0;a[1085572+h|0]=1;h=ds+4096|0;if(h>>>0<65536){ds=h}else{dt=0;break}}do{h=dt>>>12|2032;c[1052804+(h<<2)>>2]=(c[263191]|0)+65536;a[1089668+h|0]=0;a[1085572+h|0]=1;dt=dt+4096|0;}while(dt>>>0<65536);X5(1069188,1052804,16384)|0;h=0;do{if((a[1089668+h|0]|0)!=0){c[1069188+(h<<2)>>2]=18}h=h+1|0;}while((h|0)<4096)}}while(0);dt=a[799131]|0;ds=a[799132]|0;do{if(dt<<24>>24==0|ds<<24>>24!=0){if((a[799126]|0)!=0){dr=c[263192]|0;dh=c[274486]|0;if((dh|0)==0){du=0}else{dq=0;dp=0;while(1){dn=(d[dr+dq|0]|0)+dp&65535;dm=dq+1|0;if(dm>>>0<dh>>>0){dq=dm;dp=dn}else{du=dn;break}}}dv=du<<((dh|0)==3145728);dw=dt;dx=ds;break}dp=c[274486]|0;if((dp&32767|0)==0){c[m>>2]=dp;dq=Hw(c[263192]|0,m,8388608)|0;dv=dq;dw=a[799131]|0;dx=a[799132]|0;break}dq=c[263192]|0;if((dp|0)==0){dv=0;dw=dt;dx=ds;break}else{dy=0;dz=0}while(1){dr=(d[dq+dy|0]|0)+dz&65535;dn=dy+1|0;if(dn>>>0<dp>>>0){dy=dn;dz=dr}else{dv=dr;dw=dt;dx=ds;break}}}else{dp=c[263192]|0;dq=c[274486]|0;if((dq|0)==0){dA=0}else{dh=0;dr=0;while(1){dn=(d[dp+dh|0]|0)+dr&65535;dm=dh+1|0;if(dm>>>0<dq>>>0){dh=dm;dr=dn}else{dA=dn;break}}}dr=(a[1097936]|0)!=0?65456:32688;dh=0;dq=0;do{dq=(d[dp+(dh+dr)|0]|0)+dq&65535;dh=dh+1|0;}while(dh>>>0<48);dv=dA-dq&65535;dw=dt;dx=0}}while(0);dt=dv&65535;c[274487]=dt;dv=c[274481]|0;dA=((c[274482]|0)+dv|0)==65535&(dv|0)==(dt|0);if(dw<<24>>24!=0&dx<<24>>24==0){dx=(a[1097936]|0)!=0?65472:32704;dw=dx|22;dt=c[263192]|0;dv=dt+dw|0;ds=a[dv]|0;dz=dx|23;dx=a[dt+dz|0]|0;a[dv]=66;a[(c[263192]|0)+dz|0]=0;dv=c[263192]|0;dt=c[274486]|0;if((dt|0)==0){dB=0}else{dy=-1;m=0;do{dy=c[15944+((d[dv+m|0]^dy&255)<<2)>>2]^dy>>>8;m=m+1|0;}while(m>>>0<dt>>>0);dB=~dy}c[274483]=dB;a[dv+dw|0]=ds;a[(c[263192]|0)+dz|0]=dx}else{dx=c[263192]|0;dz=c[274486]|0;if((dz|0)==0){dC=0}else{ds=-1;dw=0;do{ds=c[15944+((d[dx+dw|0]^ds&255)<<2)>>2]^ds>>>8;dw=dw+1|0;}while(dw>>>0<dz>>>0);dC=~ds}c[274483]=dC}L13079:do{if((a[799143]|0)==0){if((a[799142]|0)!=0){a[799146]=1;break}do{if((a[799131]|0)==0){if(((a[1097920]|0)-2&255)>=11){break}a[799146]=1;break L13079}}while(0);a[799146]=0}else{a[799146]=0}}while(0);a[1097884]=0;if((a[1097862]|0)!=0){dq=X1(1097862)|0;dC=(dq|0)>21&(a[1097882]|0)==32?1097883:1097862+dq|0;while(1){if(dC>>>0<=1097862>>>0){break}dq=dC-1|0;if((a[dq]|0)==32){dC=dq}else{break}}a[dC]=0}dC=a[1097938]|0;if(dC<<24>>24==0){dD=0}else{dD=(128<<(dC&255)+3)-1|0}c[274485]=dD;c[199740]=1364;c[199741]=1364;c[199744]=1096;c[199745]=4;c[199746]=20;c[199747]=1106;c[199750]=192;dD=(a[799146]|0)!=0?312:262;c[199742]=dD;c[199743]=dD;c[199752]=18;c[199753]=24;c[199754]=0;a[807365]=a[807364]|0;c[199755]=0;a[799024]=0;do{if((a[807363]|0)==0){if((bJ(1097908,57808,4)|0)==0){c[199755]=4}do{if((cL(1097862,57152)|0)==0){r=9625}else{if((bJ(1097908,56384,4)|0)==0){r=9625;break}if((bJ(1097908,55240,4)|0)==0){r=9625;break}if((cL(1097862,54352)|0)==0){r=9625;break}if((cL(1097862,53456)|0)==0){r=9625;break}if((cL(1097862,52600)|0)==0){r=9625;break}if((bJ(1097908,51768,3)|0)==0){r=9625;break}if((bJ(1097862,50808,9)|0)==0){r=9625;break}if((bJ(1097862,50016,11)|0)==0){r=9625;break}if((bJ(1097908,49144,3)|0)==0){r=9625;break}if((bJ(1097908,48304,3)|0)==0){r=9625;break}if((bJ(1097908,47312,3)|0)==0){r=9625;break}if((bJ(1097908,45904,3)|0)==0){r=9625;break}if((bJ(1097908,45304,3)|0)==0){r=9625;break}if((bJ(1097908,44728,3)|0)==0){r=9625;break}if((bJ(1097908,43952,3)|0)==0){r=9625;break}if((bJ(1097908,43280,3)|0)==0){r=9625;break}if((cL(1097862,42568)|0)==0){r=9625;break}if((cL(1097862,41960)|0)==0){r=9625;break}if((cL(1097862,41344)|0)==0){r=9625;break}if((cL(1097862,40776)|0)==0){r=9625;break}if((cL(1097862,40128)|0)==0){r=9625;break}if((cL(1097862,39224)|0)==0){r=9625;break}if((cL(1097862,38648)|0)==0){r=9625;break}if((cL(1097862,38240)|0)==0){r=9625;break}if((cL(1097862,37936)|0)==0){r=9625;break}if((cL(1097862,37696)|0)==0){r=9625;break}if((bJ(1097862,37360,21)|0)==0){r=9625;break}if((bJ(1097862,36944,15)|0)==0){r=9625;break}if((bJ(1097862,36560,14)|0)==0){r=9625;break}if((bJ(1097862,36144,18)|0)==0){r=9625;break}if((bJ(1097862,35616,6)|0)==0){r=9625;break}if((cL(1097862,35e3)|0)==0){r=9625;break}if((bJ(1097862,34576,21)|0)==0){r=9625}}}while(0);if((r|0)==9625){c[199755]=1}do{if((cL(1097862,34120)|0)==0){r=9635}else{if((cL(1097862,33680)|0)==0){r=9635;break}if((cL(1097862,33320)|0)==0){r=9635;break}if((cL(1097862,32888)|0)==0){r=9635;break}if((cL(1097862,32280)|0)==0){r=9635;break}if((cL(1097862,31904)|0)==0){r=9635;break}if((cL(1097862,31456)|0)==0){r=9635;break}if((cL(1097862,31032)|0)==0){r=9635;break}if((cL(1097862,30408)|0)==0){r=9635}}}while(0);if((r|0)==9635){a[799024]=1}do{if((bJ(1097862,30016,15)|0)==0){dE=0}else{if((cL(1097862,29624)|0)==0){dE=0;break}dE=(cL(1097862,29264)|0)!=0|0}}while(0);a[1044438]=dE;do{if((cL(1097862,28952)|0)==0){dF=1}else{if((cL(1097862,28624)|0)==0){dF=1;break}if((cL(1097862,28288)|0)==0){dF=1;break}if((cL(1097862,27968)|0)==0){dF=1;break}dF=(cL(1097862,27568)|0)==0|0}}while(0);a[1044439]=dF;if((cL(1097862,27096)|0)==0){r=9646}else{if((bJ(1097908,26440,3)|0)==0){r=9646}}if((r|0)==9646){a[807393]=0}do{if((cL(1097862,26024)|0)==0){dG=0}else{if((cL(1097862,27096)|0)==0){dG=0;break}if((cL(1097862,25520)|0)==0){dG=0;break}if((cL(1097862,25152)|0)==0){dG=0;break}if((cL(1097862,24880)|0)==0){dG=0;break}if((bJ(1097908,24568,3)|0)==0){dG=0;break}if((cL(1097862,24120)|0)==0){dG=0;break}if((bJ(1097908,23744,3)|0)==0){dG=0;break}if((cL(1097862,23384)|0)==0){dG=0;break}if((cL(1097862,22968)|0)==0){dG=0;break}if((cL(1097862,28624)|0)==0){dG=0;break}if((bJ(1097908,22336,3)|0)==0){dG=0;break}if((bJ(1097908,21984,3)|0)==0){dG=0;break}if((cL(1097862,21624)|0)==0){dG=0;break}if((cL(1097862,21272)|0)==0){dG=0;break}if((bJ(1097908,21032,2)|0)==0){dG=0;break}if((cL(1097862,20696)|0)==0){dG=0;break}if((bJ(1097908,55240,4)|0)==0){dG=0;break}if((cL(1097862,20392)|0)==0){dG=0;break}if((cL(1097862,20088)|0)==0){dG=0;break}if((cL(1097862,101128)|0)==0){dG=0;break}if((cL(1097862,100680)|0)==0){dG=0;break}if((cL(1097862,1e5)|0)==0){dG=0;break}if((cL(1097862,99600)|0)==0){dG=0;break}if((cL(1097862,99232)|0)==0){dG=0;break}if((cL(1097862,98864)|0)==0){dG=0;break}if((cL(1097862,98488)|0)==0){dG=0;break}if((cL(1097862,98136)|0)==0){dG=0;break}if((bJ(1097908,97624,4)|0)==0){dG=0;break}if((cL(1097862,97168)|0)==0){dG=0;break}if((bJ(1097908,96792,3)|0)==0){dG=0;break}if((cL(1097862,96376)|0)==0){dG=0;break}if((cL(1097862,95696)|0)==0){dG=0;break}if((cL(1097862,95168)|0)==0){dG=0;break}if((bJ(1097908,94688,3)|0)==0){dG=0;break}if((cL(1097862,94328)|0)==0){dG=0;break}if((bJ(1097908,94048,3)|0)==0){dG=0;break}if((cL(1097862,93536)|0)==0){dG=0;break}if((cL(1097862,93152)|0)==0){dG=0;break}if((cL(1097862,92768)|0)==0){dG=0;break}if((cL(1097862,92464)|0)==0){dG=0;break}if((cL(1097862,92040)|0)==0){dG=0;break}if((cL(1097862,91552)|0)==0){dG=0;break}if((cL(1097862,57152)|0)==0){dG=0;break}if((bJ(1097908,91024,3)|0)==0){dG=0;break}if((bJ(1097908,90640,2)|0)==0){dG=0;break}if((bJ(1097908,90384,3)|0)==0){dG=0;break}if((cL(1097862,90120)|0)==0){dG=0;break}if((cL(1097862,89768)|0)==0){dG=0;break}if((cL(1097862,89464)|0)==0){dG=0;break}if((cL(1097862,89168)|0)==0){dG=0;break}if((cL(1097862,88896)|0)==0){dG=0;break}if((cL(1097862,88552)|0)==0){dG=0;break}if((cL(1097862,88096)|0)==0){dG=0;break}if((cL(1097862,87808)|0)==0){dG=0;break}if((cL(1097862,87536)|0)==0){dG=0;break}if((cL(1097862,87240)|0)==0){dG=0;break}if((cL(1097862,86984)|0)==0){dG=0;break}if((bJ(1097908,86656,2)|0)==0){dG=0;break}if((bJ(1097908,86384,3)|0)==0){dG=0;break}if((bJ(1097908,86104,3)|0)==0){dG=0;break}if((cL(1097862,85784)|0)==0){dG=0;break}if((bJ(1097908,85464,3)|0)==0){dG=0;break}if((cL(1097862,84960)|0)==0){dG=0;break}if((cL(1097862,84624)|0)==0){dG=0;break}if((bJ(1097908,84264,3)|0)==0){dG=0;break}if((cL(1097862,83896)|0)==0){dG=0;break}if((bJ(1097908,83536,4)|0)==0){dG=0;break}if((cL(1097862,83232)|0)==0){dG=0;break}if((cL(1097862,82936)|0)==0){dG=0;break}if((bJ(1097908,82616,3)|0)==0){dG=0;break}if((cL(1097862,82328)|0)==0){dG=0;break}if((cL(1097862,82e3)|0)==0){dG=0;break}if((cL(1097862,28288)|0)==0){dG=0;break}if((bJ(1097908,81512,3)|0)==0){dG=0;break}if((cL(1097862,27968)|0)==0){dG=0;break}if((cL(1097862,81208)|0)==0){dG=0;break}if((bJ(1097908,80720,2)|0)==0){dG=0;break}if((cL(1097862,80392)|0)==0){dG=0;break}if((cL(1097862,80064)|0)==0){dG=0;break}if((cL(1097862,79768)|0)==0){dG=0;break}if((cL(1097862,79504)|0)==0){dG=0;break}if((cL(1097862,79232)|0)==0){dG=0;break}if((cL(1097862,78936)|0)==0){dG=0;break}if((cL(1097862,78560)|0)==0){dG=0;break}if((cL(1097862,78080)|0)==0){dG=0;break}if((cL(1097862,77784)|0)==0){dG=0;break}if((cL(1097862,77400)|0)==0){dG=0;break}if((cL(1097862,53456)|0)==0){dG=0;break}if((cL(1097862,77072)|0)==0){dG=0;break}if((cL(1097862,54352)|0)==0){dG=0;break}if((cL(1097862,76816)|0)==0){dG=0;break}if((bJ(1097908,76536,3)|0)==0){dG=0;break}if((bJ(1097908,76296,2)|0)==0){dG=0;break}if((cL(1097862,75976)|0)==0){dG=0;break}if((cL(1097862,75672)|0)==0){dG=0;break}if((bJ(1097908,75304,2)|0)==0){dG=0;break}if((cL(1097862,74864)|0)==0){dG=0;break}if((bJ(1097908,74536,3)|0)==0){dG=0;break}if((bJ(1097908,74248,3)|0)==0){dG=0;break}if((bJ(1097908,73976,4)|0)==0){dG=0;break}if((cL(1097862,73744)|0)==0){dG=0;break}if((cL(1097862,73528)|0)==0){dG=0;break}if((bJ(1097908,73272,3)|0)==0){dG=0;break}if((cL(1097862,73056)|0)==0){dG=0;break}if((cL(1097862,72824)|0)==0){dG=0;break}if((cL(1097862,72328)|0)==0){dG=0;break}if((cL(1097862,71760)|0)==0){dG=0;break}if((cL(1097862,71416)|0)==0){dG=0;break}if((bJ(1097908,71056,3)|0)==0){dG=0;break}if((bJ(1097908,45304,3)|0)==0){dG=0;break}if((bJ(1097908,70744,3)|0)==0){dG=0;break}if((cL(1097862,70528)|0)==0){dG=0;break}if((cL(1097862,70368)|0)==0){dG=0;break}if((bJ(1097908,70304,3)|0)==0){dG=0;break}if((bJ(1097908,49144,3)|0)==0){dG=0;break}if((cL(1097862,70200)|0)==0){dG=0;break}if((bJ(1097908,70104,3)|0)==0){dG=0;break}if((cL(1097862,69952)|0)==0){dG=0;break}if((bJ(1097908,69736,3)|0)==0){dG=0;break}if((cL(1097862,69608)|0)==0){dG=0;break}if((bJ(1097908,69456,4)|0)==0){dG=0;break}if((cL(1097862,69320)|0)==0){dG=0;break}if((bJ(1097908,69272,3)|0)==0){dG=0;break}if((bJ(1097908,69192,4)|0)==0){dG=0;break}if((cL(1097862,69144)|0)==0){dG=0;break}if((cL(1097862,69040)|0)==0){dG=0;break}if((cL(1097862,68960)|0)==0){dG=0;break}if((cL(1097862,68784)|0)==0){dG=0;break}if((cL(1097862,68448)|0)==0){dG=0;break}if((cL(1097862,68344)|0)==0){dG=0;break}if((cL(1097862,68176)|0)==0){dG=0;break}if((cL(1097862,68032)|0)==0){dG=0;break}if((cL(1097862,67920)|0)==0){dG=0;break}if((cL(1097862,67824)|0)==0){dG=0;break}if((cL(1097862,67744)|0)==0){dG=0;break}if((bJ(1097908,67664,4)|0)==0){dG=0;break}if((bJ(1097908,67496,4)|0)==0){dG=0;break}if((bJ(1097908,67144,4)|0)==0){dG=0;break}if((cL(1097862,66776)|0)==0){dG=0;break}if((cL(1097862,66608)|0)==0){dG=0;break}if((cL(1097862,66392)|0)==0){dG=0;break}if((bJ(1097908,66144,3)|0)==0){dG=0;break}if((bJ(1097908,65936,4)|0)==0){dG=0;break}if((bJ(1097908,65648,4)|0)==0){dG=0;break}if((bJ(1097908,65488,3)|0)==0){dG=0;break}if((cL(1097862,65328)|0)==0){dG=0;break}if((cL(1097862,65216)|0)==0){dG=0;break}if((bJ(1097908,64992,4)|0)==0){dG=0;break}if((bJ(1097908,64776,3)|0)==0){dG=0;break}if((cL(1097862,64616)|0)==0){dG=0;break}if((cL(1097862,64376)|0)==0){dG=0;break}if((cL(1097862,64248)|0)==0){dG=0;break}if((cL(1097862,64136)|0)==0){dG=0;break}if((bJ(1097908,63976,3)|0)==0){dG=0;break}if((cL(1097862,63856)|0)==0){dG=0;break}if((bJ(1097908,63704,4)|0)==0){dG=0;break}if((bJ(1097908,63584,4)|0)==0){dG=0;break}if((bJ(1097908,63504,3)|0)==0){dG=0;break}if((bJ(1097908,63192,4)|0)==0){dG=0;break}if((bJ(1097908,63016,4)|0)==0){dG=0;break}if((cL(1097862,62864)|0)==0){dG=0;break}if((cL(1097862,62728)|0)==0){dG=0;break}if((cL(1097862,62656)|0)==0){dG=0;break}if((cL(1097862,34120)|0)==0){dG=0;break}if((cL(1097862,62536)|0)==0){dG=0;break}if((cL(1097862,62424)|0)==0){dG=0;break}if((cL(1097862,62320)|0)==0){dG=0;break}if((cL(1097862,62216)|0)==0){dG=0;break}if((cL(1097862,62072)|0)==0){dG=0;break}if((cL(1097862,61784)|0)==0){dG=0;break}if((cL(1097862,61704)|0)==0){dG=0;break}if((cL(1097862,31904)|0)==0){dG=0;break}if((cL(1097862,61648)|0)==0){dG=0;break}if((cL(1097862,61600)|0)==0){dG=0;break}dG=(cL(1097862,61464)|0)!=0|0}}while(0);a[1041770]=dG;do{if((cL(1097862,1e5)|0)==0){dH=0}else{if((cL(1097862,99600)|0)==0){dH=0;break}if((cL(1097862,99232)|0)==0){dH=0;break}if((cL(1097862,98864)|0)==0){dH=0;break}if((bJ(1097908,94048,3)|0)==0){dH=0;break}if((cL(1097862,90120)|0)==0){dH=0;break}dH=(bJ(1097908,83536,4)|0)!=0|0}}while(0);a[17264]=dH;c[199789]=0;if((cL(1097862,92464)|0)==0){dI=0}else{dI=(cL(1097862,92040)|0)!=0|0}a[1044495]=dI;if((cL(1097862,27096)|0)==0){c[199789]=2}if((cL(1097862,92464)|0)==0){r=9836}else{if((cL(1097862,92040)|0)==0){r=9836}}if((r|0)==9836){c[199789]=5}do{if((X7(1097862,78080,14)|0)==0){r=9840}else{if((bJ(1097908,61432,3)|0)==0){r=9840;break}if((bJ(1097908,61400,4)|0)==0){r=9840}}}while(0);if((r|0)==9840){c[199789]=1}if((cL(1097862,28288)|0)!=0){if((cL(1097862,27968)|0)!=0){dJ=dG;break}}c[199789]=6;dJ=dG}else{dJ=a[1041770]|0}}while(0);ec(c[p>>2]|0,61320,(dG=i,i=i+8|0,c[dG>>2]=dJ&255,dG)|0)|0;i=dG;ec(c[p>>2]|0,61264,(dG=i,i=i+8|0,c[dG>>2]=d[1044495]|0,dG)|0)|0;i=dG;ec(c[p>>2]|0,61192,(dG=i,i=i+8|0,c[dG>>2]=d[807394]|0,dG)|0)|0;i=dG;ec(c[p>>2]|0,60952,(dG=i,i=i+8|0,c[dG>>2]=c[199789],dG)|0)|0;i=dG;ec(c[p>>2]|0,60816,(dG=i,i=i+8|0,c[dG>>2]=d[1044439]|0,dG)|0)|0;i=dG;ec(c[p>>2]|0,60664,(dG=i,i=i+8|0,c[dG>>2]=d[17264]|0,dG)|0)|0;i=dG;L13376:do{if((c[201846]|0)==0){do{if((bJ(1097862,60576,7)|0)==0){dK=1}else{if((bJ(1097908,60496,4)|0)==0){dK=1;break}if((cL(1097862,60400)|0)==0){dK=1;break}if((bJ(1097908,60328,4)|0)==0){dK=1;break}if((bJ(1097908,60264,4)|0)==0){dK=1;break}if((X7(1097862,60184,9)|0)==0){dK=1;break}if((bJ(1097908,60104,3)|0)==0){dK=1;break}if((cL(1097862,59920)|0)==0){dK=1;break}if((cL(1097862,59760)|0)==0){dK=1;break}if((cL(1097862,59544)|0)==0){dK=1;break}if((bJ(1097908,24568,3)|0)==0){dK=1;break}if((cL(1097862,59480)|0)==0){dK=1;break}if((cL(1097862,59464)|0)==0){dK=1;break}if((cL(1097862,59424)|0)==0){dK=1;break}if((cL(1097862,59392)|0)==0){dK=1;break}if((bJ(1097908,59296,3)|0)==0){dK=1;break}if((bJ(1097908,59248,4)|0)==0){dK=1;break}if((bJ(1097908,59232,4)|0)==0){dK=1;break}if((cL(1097862,58984)|0)==0){dK=1;break}if((bJ(1097908,58888,15)|0)==0){dK=1;break}if((bJ(1097908,58776,3)|0)==0){dK=1;break}if((bJ(1097908,86104,3)|0)==0){dK=1;break}if((bJ(1097908,58736,3)|0)==0){dK=1;break}if((cL(1097862,93536)|0)==0){dK=1;break}if((bJ(1097908,58720,4)|0)==0){dK=1;break}if((bJ(1097908,58704,4)|0)==0){dK=1;break}if((bJ(1097908,58688,2)|0)==0){dK=1;break}if((bJ(1097908,58664,3)|0)==0){dK=1;break}if((cL(1097862,58632)|0)==0){dK=1;break}if((bJ(1097908,58552,2)|0)==0){dK=1;break}if((bJ(1097908,58304,4)|0)==0){dK=1;break}if((cL(1097862,58256)|0)==0){dK=1;break}if((cL(1097862,58120)|0)==0){dK=1;break}if((cL(1097862,23384)|0)==0){dK=1;break}if((cL(1097862,58056)|0)==0){dK=1;break}if((bJ(1097862,30016,15)|0)==0){dK=1;break}if((cL(1097862,58024)|0)==0){dK=1;break}if((bJ(1097908,64776,3)|0)==0){dK=1;break}if((cL(1097862,57992)|0)==0){dK=1;break}if((cL(1097862,57952)|0)==0){dK=1;break}if((bJ(1097908,57896,3)|0)==0){dK=1;break}if((bJ(1097908,71056,3)|0)==0){dK=1;break}if((bJ(1097908,57864,4)|0)==0){dK=1;break}if((bJ(1097908,57832,4)|0)==0){dK=1;break}if((bJ(1097908,57624,4)|0)==0){dK=1;break}if((bJ(1097908,57592,4)|0)==0){dK=1;break}if((bJ(1097908,57520,4)|0)==0){dK=1;break}if((bJ(1097908,57472,4)|0)==0){dK=1;break}if((bJ(1097908,57440,4)|0)==0){dK=1;break}if((bJ(1097908,57416,3)|0)==0){dK=1;break}if((cL(1097862,57376)|0)==0){dK=1;break}if((cL(1097862,57336)|0)==0){dK=1;break}if((bJ(1097908,82616,3)|0)==0){dK=1;break}if((cL(1097862,57224)|0)==0){dK=1;break}if((cL(1097862,57200)|0)==0){dK=1;break}if((bJ(1097908,56960,3)|0)==0){dK=1;break}if((X7(1097862,71760,15)|0)==0){dK=1;break}if((X7(1097862,56896,4)|0)==0){dK=1;break}if((bJ(1097862,56816,3)|0)==0){dK=1;break}if((X7(1097862,56776,6)|0)==0){dK=1;break}if((X7(1097862,56752,14)|0)==0){dK=1;break}dK=(bJ(1097908,56736,2)|0)==0|0}}while(0);a[807388]=dK;do{if((X7(1097862,56704,21)|0)==0){dL=1}else{if((bJ(1097908,56656,3)|0)==0){dL=1;break}if((X7(1097862,56600,11)|0)==0){dL=1;break}if((bJ(1097908,56424,4)|0)==0){dL=1;break}if((X7(1097862,56048,22)|0)==0){dL=1;break}if((bJ(1097908,55968,2)|0)==0){dL=1;break}if((cL(1097862,55784)|0)==0){dL=1;break}if((cL(1097862,55712)|0)==0){dL=1;break}if((bJ(1097908,55696,4)|0)==0){dL=1;break}if((cL(1097862,55600)|0)==0){dL=1;break}if((bJ(1097908,55424,4)|0)==0){dL=1;break}if((cL(1097862,55336)|0)==0){dL=1;break}if((bJ(1097908,55296,2)|0)==0){dL=1;break}if((cL(1097862,55272)|0)==0){dL=1;break}if((cL(1097862,54848)|0)==0){dL=1;break}if((bJ(1097908,54752,4)|0)==0){dL=1;break}if((bJ(1097908,54736,4)|0)==0){dL=1;break}if((bJ(1097908,54696,4)|0)==0){dL=1;break}if((cL(1097862,54664)|0)==0){dL=1;break}if((cL(1097862,61648)|0)==0){dL=1;break}if((bJ(1097908,26440,3)|0)==0){dL=1;break}if((bJ(1097908,54600,4)|0)==0){dL=1;break}if((cL(1097862,54528)|0)==0){dL=1;break}if((bJ(1097908,54480,4)|0)==0){dL=1;break}if((cL(1097862,54416)|0)==0){dL=1;break}if((cL(1097862,54392)|0)==0){dL=1;break}if((bJ(1097908,53968,4)|0)==0){dL=1;break}if((cL(1097862,53888)|0)==0){dL=1;break}if((cL(1097862,53840)|0)==0){dL=1;break}if((cL(1097862,41344)|0)==0){dL=1;break}if((cL(1097862,59464)|0)==0){dL=1;break}if((cL(1097862,53784)|0)==0){dL=1;break}if((cL(1097862,53752)|0)==0){dL=1;break}if((cL(1097862,53720)|0)==0){dL=1;break}if((cL(1097862,53632)|0)==0){dL=1;break}if((bJ(1097908,53616,4)|0)==0){dL=1;break}if((cL(1097862,53544)|0)==0){dL=1;break}if((cL(1097862,59392)|0)==0){dL=1;break}if((cL(1097862,53512)|0)==0){dL=1;break}if((bJ(1097908,53072,2)|0)==0){dL=1;break}if((cL(1097862,52992)|0)==0){dL=1;break}if((cL(1097862,52904)|0)==0){dL=1;break}if((cL(1097862,52864)|0)==0){dL=1;break}if((bJ(1097908,52848,4)|0)==0){dL=1;break}if((X7(1097862,52824,10)|0)==0){dL=1;break}if((cL(1097862,52744)|0)==0){dL=1;break}if((bJ(1097908,52712,4)|0)==0){dL=1;break}if((cL(1097862,52688)|0)==0){dL=1;break}if((cL(1097862,52656)|0)==0){dL=1;break}if((cL(1097862,52224)|0)==0){dL=1;break}if((cL(1097862,52192)|0)==0){dL=1;break}if((cL(1097862,52088)|0)==0){dL=1;break}if((cL(1097862,52040)|0)==0){dL=1;break}if((cL(1097862,58632)|0)==0){dL=1;break}if((bJ(1097908,58552,2)|0)==0){dL=1;break}if((X7(1097862,52016,11)|0)==0){dL=1;break}if((cL(1097862,51992)|0)==0){dL=1;break}if((cL(1097862,51920)|0)==0){dL=1;break}if((bJ(1097908,51904,3)|0)==0){dL=1;break}if((cL(1097862,51824)|0)==0){dL=1;break}if((cL(1097862,51808)|0)==0){dL=1;break}if((cL(1097862,51328)|0)==0){dL=1;break}if((cL(1097862,51304)|0)==0){dL=1;break}if((X7(1097862,51184,6)|0)==0){dL=1;break}if((cL(1097862,51136)|0)==0){dL=1;break}if((cL(1097862,51104)|0)==0){dL=1;break}if((cL(1097862,51080)|0)==0){dL=1;break}if((bJ(1097908,51024,4)|0)==0){dL=1;break}if((cL(1097862,50928)|0)==0){dL=1;break}if((cL(1097862,50880)|0)==0){dL=1;break}if((cL(1097862,50848)|0)==0){dL=1;break}if((cL(1097862,50456)|0)==0){dL=1;break}if((cL(1097862,50440)|0)==0){dL=1;break}if((bJ(1097908,50360,2)|0)==0){dL=1;break}if((cL(1097862,50304)|0)==0){dL=1;break}if((bJ(1097908,50288,4)|0)==0){dL=1;break}if((cL(1097862,50264)|0)==0){dL=1;break}if((cL(1097862,50208)|0)==0){dL=1;break}if((cL(1097862,57224)|0)==0){dL=1;break}if((X7(1097862,50184,14)|0)==0){dL=1;break}if((cL(1097862,50152)|0)==0){dL=1;break}if((bJ(1097908,67144,4)|0)==0){dL=1;break}if((cL(1097862,50128)|0)==0){dL=1;break}dL=(cL(1097862,41960)|0)==0|0}}while(0);a[807389]=dL;do{if((cL(1097862,49840)|0)!=0){if((cL(1097862,49584)|0)==0){break}if((cL(1097862,49536)|0)==0){break}if((cL(1097862,52040)|0)==0){break}if((cL(1097862,49456)|0)==0){break}if((cL(1097862,50440)|0)==0){break}if((bJ(1097908,50360,2)|0)==0){break}if((cL(1097862,49440)|0)==0){break}if((cL(1097862,49416)|0)==0){break}a[807390]=0;break L13376}}while(0);a[807390]=1}}while(0);dL=c[199755]|0;if((dL|0)!=0){c2(93080,(dG=i,i=i+8|0,c[dG>>2]=dL,dG)|0)|0;i=dG}dK=256-dL|0;c[202]=dK;c[109232]=dK;c[109211]=4;c[109205]=7;c[109199]=7;dL=(a[799146]|0)!=0;c[1502]=dL?34176:15664;c[1504]=(ab(dL?709379:328125,dK)|0)>>>8;dL=c[199791]|0;if((dL|0)==0){c[199791]=32e3;dM=32e3}else{dM=dL}c[59338]=~~(+(dM>>>0>>>0)*256.0/+((ab(c[199790]|0,dK)|0)>>>0>>>0)*65536.0);c[59004]=0;c[59006]=0;X2(c[59010]|0,0,c[59008]|0);c[59356]=65536;c[59348]=0;c[59350]=0;c[59352]=0;c[59354]=0;c[59340]=0;c[59342]=0;c[59344]=0;c[59346]=0;a[798240]=a[799024]|0;dK=c[201842]|0;c[199747]=dK+1006;c[199744]=dK+996;do{if((a[807363]|0)==0){if((cL(1097862,49336)|0)==0){c[199752]=20;c2(49288,(dG=i,i=i+8|0,c[dG>>2]=20,dG)|0)|0;i=dG;if((a[807363]|0)!=0){break}}if((cL(1097862,49208)|0)==0){c[199754]=1;c2(49176,(dG=i,i=i+8|0,c[dG>>2]=1,dG)|0)|0;i=dG}if((cL(1097862,48808)|0)==0){c[199754]=2;c2(49176,(dG=i,i=i+8|0,c[dG>>2]=2,dG)|0)|0;i=dG}if((cL(1097862,48784)|0)==0){c[199754]=1;c2(49176,(dG=i,i=i+8|0,c[dG>>2]=1,dG)|0)|0;i=dG}if((a[807363]|0)!=0){break}if((cL(1097862,48744)|0)==0){a[807365]=0;dd(1504)|0;if((a[807363]|0)!=0){break}}if((cL(1097862,48672)|0)==0){a[1097938]=1;c[274485]=2047}do{if((cL(1097862,48648)|0)==0){r=10023}else{if((cL(1097862,48496)|0)==0){r=10023;break}if((cL(1097862,48472)|0)==0){r=10023}}}while(0);if((r|0)==10023){a[808072]=0}if((cL(1097862,48352)|0)==0){a[808072]=107}if((bJ(1097862,78936,9)|0)!=0){break}a[808073]=1;dd(1480)|0}}while(0);Yb(1097885,1097862)|0;dK=k|0;k=a[1097920]|0;dM=X1(1097862)|0;dL=c[201860]|0;dJ=dM+1|0;do{if((dL|0)==0){r=10031}else{if((dJ|0)<=(c[201858]|0)){dN=dL;break}XZ(dL);r=10031}}while(0);if((r|0)==10031){c[201858]=dJ;dL=XY(dJ)|0;c[201860]=dL;dN=dL}L13582:do{if((dM|0)>0){if(k<<24>>24==0){dO=0}else{dL=a[1097862]|0;a[dN]=dL<<24>>24<32|dL<<24>>24==127?95:dL;if((dM|0)>1){dP=1}else{break}while(1){dL=a[1097862+dP|0]|0;a[dN+dP|0]=dL<<24>>24<32|dL<<24>>24==127?95:dL;dP=dP+1|0;if((dP|0)>=(dM|0)){break L13582}}}do{dL=a[1097862+dO|0]|0;do{if(dL<<24>>24<32|dL<<24>>24==127){dJ=dN+dO|0;if((dL+96&255)<64){a[dJ]=dL;break}else{a[dJ]=95;break}}else{a[dN+dO|0]=dL}}while(0);dO=dO+1|0;}while((dO|0)<(dM|0))}}while(0);a[dN+dM|0]=0;dM=(X1(dN|0)|0)+1|0;X5(dK|0,dN|0,dM)|0;dM=X1(1097862)|0;dN=c[201856]|0;dO=dM+1|0;do{if((dN|0)==0){r=10045}else{if((dO|0)<=(c[201854]|0)){dQ=dN;break}XZ(dN);r=10045}}while(0);if((r|0)==10045){c[201854]=dO;dN=XY(dO)|0;c[201856]=dN;dQ=dN}if((dM|0)>0){dN=0;do{dO=a[1097862+dN|0]|0;a[dQ+dN|0]=dO<<24>>24<32|dO<<24>>24==127?95:dO;dN=dN+1|0;}while((dN|0)<(dM|0))}a[dQ+dM|0]=0;dM=(X1(dQ|0)|0)+1|0;X5(1097862,dQ|0,dM)|0;dM=X1(1097908)|0;dN=dM+1|0;do{if((dQ|0)==0){r=10051}else{if((dN|0)<=(c[201854]|0)){dR=dQ;break}XZ(dQ);r=10051}}while(0);if((r|0)==10051){c[201854]=dN;dQ=XY(dN)|0;c[201856]=dQ;dR=dQ}if((dM|0)>0){dQ=0;do{dN=a[1097908+dQ|0]|0;a[dR+dQ|0]=dN<<24>>24<32|dN<<24>>24==127?95:dN;dQ=dQ+1|0;}while((dQ|0)<(dM|0))}a[dR+dM|0]=0;dM=(X1(dR|0)|0)+1|0;X5(1097908,dR|0,dM)|0;dM=l|0;if(dA){dS=47776}else{dS=(c[261130]|0)==4?47728:47704}if((a[1097936]|0)==0){dT=47592}else{dT=(a[1093764]|0)!=0?47688:47632}L13624:do{if((c[261130]|0)==4){c[199774]=4271950}else{dA=a[1097923]|0;do{if((dA&255)>=7){l=(dA&255)-7|0;if((l|0)>23){break}dR=1<<l;ce(799096,44928,(dG=i,i=i+8|0,c[dG>>2]=dR,dG)|0)|0;i=dG;break L13624}}while(0);dA=799096;c[dA>>2]=1920102211;c[dA+4>>2]=7630965}}while(0);dA=a[1097922]|0;dR=j;l=j|0;dQ=j;j=dA&255;dN=a[799131]|0;if((dN|dA)<<24>>24==0){dU=46704}else{do{if(dN<<24>>24==0){if((a[799121]|0)!=0){X5(dR|0,46176,10)|0;break}if((a[799125]|0)!=0){a[dR]=a[46016]|0;a[dR+1|0]=a[46017|0]|0;a[dR+2|0]=a[46018|0]|0;a[dR+3|0]=a[46019|0]|0;a[dR+4|0]=a[46020|0]|0;a[dR+5|0]=a[46021|0]|0;a[dR+6|0]=a[46022|0]|0;break}if((a[799128]|0)!=0){a[dR]=a[45968]|0;a[dR+1|0]=a[45969|0]|0;a[dR+2|0]=a[45970|0]|0;a[dR+3|0]=a[45971|0]|0;a[dR+4|0]=a[45972|0]|0;a[dR+5|0]=a[45973|0]|0;break}if((a[799123]|0)!=0){a[dR]=a[45944]|0;a[dR+1|0]=a[45945|0]|0;a[dR+2|0]=a[45946|0]|0;a[dR+3|0]=a[45947|0]|0;a[dR+4|0]=a[45948|0]|0;a[dR+5|0]=a[45949|0]|0;break}if((a[799127]|0)!=0){X5(dR|0,45560,13)|0;break}if((a[799126]|0)!=0){X5(dR|0,45528,9)|0;break}if((a[799130]|0)!=0){a[dR]=a[45504]|0;a[dR+1|0]=a[45505|0]|0;a[dR+2|0]=a[45506|0]|0;a[dR+3|0]=a[45507|0]|0;a[dR+4|0]=a[45508|0]|0;a[dR+5|0]=a[45509|0]|0;a[dR+6|0]=a[45510|0]|0;break}if((a[799124]|0)!=0){c[dQ>>2]=3425067;break}dA=a[799129]|0;if((dA<<24>>24|0)==1){c[l>>2]=760501035;c[l+4>>2]=3158320;break}else if((dA<<24>>24|0)==2){c[l>>2]=760501035;c[l+4>>2]=3223856;break}else if((dA<<24>>24|0)==3){c[l>>2]=760501035;c[l+4>>2]=3682608;break}else{dA=a[799122]|0;if(dA<<24>>24==0){a[dR]=0;break}else{dO=dA&255;ce(dR|0,45400,(dG=i,i=i+8|0,c[dG>>2]=dO,dG)|0)|0;i=dG;break}}}else{c[dQ>>2]=5456427}}while(0);dQ=c[161872+((((j&15)>>>0)%3|0)<<2)>>2]|0;ce(1105640,45336,(dG=i,i=i+16|0,c[dG>>2]=dQ,c[dG+8>>2]=l,dG)|0)|0;i=dG;dU=1105640}l=(a[799146]|0)!=0?47520:47320;if((d[1097938]|0)>16){dQ=799072;c[dQ>>2]=1920102211;c[dQ+4>>2]=7630965}else{dQ=((c[274485]<<3)+8|0)>>>10;ce(799072,46784,(dG=i,i=i+8|0,c[dG>>2]=dQ,dG)|0)|0;i=dG}dQ=c[274483]|0;ce(dM|0,47864,(dG=i,i=i+72|0,c[dG>>2]=dK,c[dG+8>>2]=dS,c[dG+16>>2]=dT,c[dG+24>>2]=799096,c[dG+32>>2]=dU,c[dG+40>>2]=l,c[dG+48>>2]=799072,c[dG+56>>2]=1097908,c[dG+64>>2]=dQ,dG)|0)|0;i=dG;ec(c[p>>2]|0,65208,(dG=i,i=i+8|0,c[dG>>2]=dM,dG)|0)|0;i=dG;X2(799134,0,10);X2(e|0,0,52);dM=e+44|0;dQ=e+40|0;l=0;do{dU=7072+(l<<2)|0;dT=c[dU>>2]|0;L13677:do{switch(dT|0){case-1:{dS=238600+(l<<2)|0;dK=a[dS]|0;if(dK<<24>>24==-2){r=10105}else{j=e+(dK<<24>>24<<2)|0;dR=c[j>>2]|0;c[j>>2]=dR+1;if((dR|0)>0){dV=dS;dW=dK}else{r=10105}}do{if((r|0)==10105){r=0;dK=238601+(l<<2)|0;dS=a[dK]|0;if(dS<<24>>24!=-2){dR=e+(dS<<24>>24<<2)|0;j=c[dR>>2]|0;c[dR>>2]=j+1;if((j|0)>0){dV=dK;dW=dS;break}}dS=238602+(l<<2)|0;dK=a[dS]|0;if(dK<<24>>24!=-2){j=e+(dK<<24>>24<<2)|0;dR=c[j>>2]|0;c[j>>2]=dR+1;if((dR|0)>0){dV=dS;dW=dK;break}}dK=238603+(l<<2)|0;dS=a[dK]|0;if(dS<<24>>24==-2){break L13677}dR=e+(dS<<24>>24<<2)|0;j=c[dR>>2]|0;c[dR>>2]=j+1;if((j|0)>0){dV=dK;dW=dS}else{break L13677}}}while(0);bN(797968,256,46536,(dG=i,i=i+8|0,c[dG>>2]=(dW<<24>>24)+1,dG)|0)|0;i=dG;ec(c[p>>2]|0,65208,(dG=i,i=i+8|0,c[dG>>2]=797968,dG)|0)|0;i=dG;a[dV]=-2;break};case 8:case 9:{dS=e+(dT<<2)|0;dK=c[dS>>2]|0;c[dS>>2]=dK+1;if((dK|0)<=0){break L13677}bN(797968,256,95624,(dG=i,i=i+8|0,c[dG>>2]=dT-7,dG)|0)|0;i=dG;ec(c[p>>2]|0,65208,(dG=i,i=i+8|0,c[dG>>2]=797968,dG)|0)|0;i=dG;c[dU>>2]=-2;break};case 10:{dK=c[dQ>>2]|0;c[dQ>>2]=dK+1;if((dK|0)<=0){break L13677}bN(797968,256,66544,(dG=i,i=i+1|0,i=i+7>>3<<3,c[dG>>2]=0,dG)|0)|0;i=dG;ec(c[p>>2]|0,65208,(dG=i,i=i+8|0,c[dG>>2]=797968,dG)|0)|0;i=dG;c[dU>>2]=-2;break};case 11:case 12:{dK=c[dM>>2]|0;c[dM>>2]=dK+1;if((dK|0)<=0){break L13677}bN(797968,256,55864,(dG=i,i=i+1|0,i=i+7>>3<<3,c[dG>>2]=0,dG)|0)|0;i=dG;ec(c[p>>2]|0,65208,(dG=i,i=i+8|0,c[dG>>2]=797968,dG)|0)|0;i=dG;c[dU>>2]=-2;break};case 0:case 1:case 2:case 3:case 4:case 5:case 6:case 7:{dK=e+(dT<<2)|0;dS=c[dK>>2]|0;c[dK>>2]=dS+1;if((dS|0)<=0){break L13677}bN(797968,256,46536,(dG=i,i=i+8|0,c[dG>>2]=dT+1,dG)|0)|0;i=dG;ec(c[p>>2]|0,65208,(dG=i,i=i+8|0,c[dG>>2]=797968,dG)|0)|0;i=dG;c[dU>>2]=-2;break};default:{}}}while(0);l=l+1|0;}while((l|0)<2);i=b;return}function Ht(b){b=b|0;var d=0,f=0,g=0;d=b&65535;switch(d|0){case 32756:{f=(c[263198]|0)+((e[522257]|0)+512+((e[522256]|0)>>>2))|0;g=a[f]|0;return g|0};case 32755:{f=(c[263198]|0)+((e[522257]|0)+3+((e[522256]|0)<<2))|0;g=a[f]|0;return g|0};case 32754:{f=(c[263198]|0)+((e[522257]|0)+2+((e[522256]|0)<<2))|0;g=a[f]|0;return g|0};case 32753:{f=(c[263198]|0)+((e[522257]|0)+1+((e[522256]|0)<<2))|0;g=a[f]|0;return g|0};case 32752:{f=(c[263198]|0)+(((e[522256]|0)<<2)+(e[522257]|0))|0;g=a[f]|0;return g|0};default:{f=(c[263198]|0)+(d-24576)|0;g=a[f]|0;return g|0}}return 0}function Hu(f,g){f=f|0;g=g|0;var h=0,i=0;h=g&65535;L13716:do{switch(h|0){case 32754:{a[(c[263198]|0)+((e[522257]|0)+2+((e[522256]|0)<<2))|0]=f;break};case 32758:{g=f&255;b[522256]=g&127;b[522258]=g<<1&6;break};case 32753:{a[(c[263198]|0)+((e[522257]|0)+1+((e[522256]|0)<<2))|0]=f;break};case 32757:{if((f&1)==0){b[522257]=7168;break L13716}else{b[522257]=6144;break L13716}break};case 32755:{a[(c[263198]|0)+((e[522257]|0)+3+((e[522256]|0)<<2))|0]=f;break};case 32756:{g=(c[263198]|0)+((e[522257]|0)+512+((e[522256]|0)>>>2))|0;i=e[522258]|0;a[g]=((3<<i^255)&(d[g]|0)|(f&3)<<i)&255;break};case 32752:{a[(c[263198]|0)+(((e[522256]|0)<<2)+(e[522257]|0))|0]=f;break};default:{}}}while(0);a[(c[263198]|0)+(h-24576)|0]=f;return}function Hv(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0,g=0,h=0;if((a|0)==0){c=0;return c|0}else{d=b}while(1){if(d>>>0<a>>>0){c=d;e=10146;break}else{f=-2147483648}while(1){g=f&d;if((g|0)==0){f=f>>>1}else{break}}h=d-f|0;if(g>>>0<a>>>0){e=10144;break}else{d=h}}if((e|0)==10146){return c|0}else if((e|0)==10144){return(Hv(a-f|0,h)|0)+f|0}return 0}function Hw(a,b,e){a=a|0;b=b|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;f=i;i=i+8|0;g=f|0;h=c[b>>2]|0;j=e;while(1){k=j>>>1;if((j&h|0)==0){j=k}else{break}}if((j|0)==0){l=0}else{e=0;m=0;while(1){n=(d[a+e|0]|0)+m&65535;o=e+1|0;if(o>>>0<j>>>0){e=o;m=n}else{l=n;break}}}c[g>>2]=h-j;if((h|0)==(j|0)){p=0;q=p+l&65535;i=f;return q|0}h=Hw(a+j|0,g,k)|0;k=c[g>>2]|0;if(k>>>0<j>>>0){a=h;m=k;do{m=m<<1;a=a<<1;}while(m>>>0<j>>>0);c[g>>2]=m;r=a}else{r=h}c[b>>2]=j<<1;p=r;q=p+l&65535;i=f;return q|0}function Hx(){var a=0;a=c[277220]|0;if((a|0)!=0){XZ(a);c[277220]=0}a=c[277221]|0;if((a|0)!=0){XZ(a);c[277221]=0}a=c[277213]|0;if((a|0)!=0){XZ(a);c[277213]=0}a=c[277214]|0;if((a|0)!=0){XZ(a);c[277214]=0}a=c[277215]|0;if((a|0)==0){return}XZ(a);c[277215]=0;return}function Hy(){var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0;f=i;i=i+31096|0;g=f|0;h=f+16|0;j=f+24|0;k=f+264|0;l=f+30856|0;m=a[1106150]|0;if((m|a[1106088])<<24>>24!=0){n=j|0;o=l|0;p=a[1043830]|0;if((p&255)<8){q=p&255;r=c[6944+(q<<4)>>2]&255;s=c[6948+(q<<4)>>2]|0;t=c[6956+(q<<4)>>2]|0;u=c[6952+(q<<4)>>2]&255}else{r=16;s=16;t=64;u=64}q=m<<24>>24!=0;m=q?2:1;if(q){v=(a[1108917]|0)!=0|0}else{v=0}do{if((a[1043836]|0)==0){w=10180}else{if((a[1043837]&1&e[521916]|0)==0){w=10180;break}X2(o|0,0,239);q=v&255;p=0;x=0;while(1){y=1108929+x|0;a[y]=r;if((a[1042296+(x*12|0)|0]|0)==0){z=s;A=r}else{a[y]=u;z=t;A=u}y=b[1042286+(x*12|0)>>1]|0;B=y<<16>>16==-256?256:y<<16>>16;y=A&255;do{if((B|0)>(-y|0)&(B|0)<257){do{if((B|0)<0){a[1109057+x|0]=(y+7+B|0)>>>3&255}else{if((B+y|0)>256){a[1109057+x|0]=(264-B|0)>>>3&255;break}else{a[1109057+x|0]=(A&255)>>>3;break}}}while(0);if((q|0)>=(z|0)){break}C=1042291+(x*12|0)|0;D=A-1&255;E=b[1042288+(x*12|0)>>1]&255;F=q;while(1){G=E&255;if((E&255)<=238){H=l+G|0;if((a[H]|0)==0){X2(k+(G<<7)|0,0,128);a[H]=1}H=k+(G<<7)+x|0;G=a[H]|0;if((a[C]|0)==0){I=G}else{J=G^D;a[H]=J;I=J}a[H]=I|-128}H=F+m&255;if((H|0)<(z|0)){E=E+1&255;F=H}else{break}}}}while(0);B=p+1&255;if(B<<24>>24>-1){p=B;x=B&255}else{break}}x=d[1044388]|0;p=0;do{if((p|0)==0){K=0}else{K=a[1109192+((p-1|0)*68|0)|0]|0}q=1109192+(p*68|0)|0;a[q]=K;B=1109194+(p*68|0)|0;b[B>>1]=34;y=p+x&127;do{if((a[l+p|0]|0)==0){L=0;w=10238}else{F=0;E=y;while(1){D=E&255;C=a[k+(p<<7)+D|0]|0;if(C<<24>>24==0){M=F}else{if((F|0)>31){w=10232;break}H=(b[B>>1]|0)-(d[1109057+D|0]|0)&65535;b[B>>1]=H;if(H<<16>>16<0){a[q]=a[q]|-128}a[1109196+(p*68|0)+(F<<1)|0]=E;a[1109196+(p*68|0)+(F<<1)+1|0]=C&127;M=F+1|0}C=E+1&127;if(C<<24>>24==y<<24>>24){w=10237;break}else{F=M;E=C}}if((w|0)==10232){w=0;a[q]=a[q]|64;break}else if((w|0)==10237){w=0;if((M|0)<32){L=M;w=10238;break}else{break}}}}while(0);if((w|0)==10238){w=0;a[1109196+(p*68|0)+(L<<1)|0]=-1}p=p+1|0;}while((p|0)<239)}}while(0);if((w|0)==10180){X2(n|0,0,239);n=0;do{a[1109192+(n*68|0)|0]=0;b[1109194+(n*68|0)>>1]=34;L=0;do{a[1109196+(n*68|0)+(L<<1)|0]=-1;L=L+1|0;}while((L|0)<32);n=n+1|0;}while((n|0)<239);n=a[1044388]|0;L=v&255;M=n;do{k=M&255;l=1108929+k|0;a[l]=r;if((a[1042296+(k*12|0)|0]|0)==0){N=s;O=r}else{a[l]=u;N=t;O=u}K=b[1042286+(k*12|0)>>1]|0;z=K<<16>>16==-256?0:K<<16>>16;K=O&255;do{if((z|0)>(-K|0)&(z|0)<257){do{if((z|0)<0){a[1109057+k|0]=(K+7+z|0)>>>3&255}else{if((z+K|0)>255){a[1109057+k|0]=(263-z|0)>>>3&255;break}else{a[1109057+k|0]=(O&255)>>>3;break}}}while(0);if((L|0)>=(N|0)){break}I=1109057+k|0;A=1042291+(k*12|0)|0;o=b[1042288+(k*12|0)>>1]&255;p=v;x=L;while(1){q=o&255;do{if((o&255)<=238){y=j+q|0;B=a[y]|0;if((B&255)>31){E=1109192+(q*68|0)|0;a[E]=a[E]|64;break}E=1109194+(q*68|0)|0;F=(b[E>>1]|0)-(d[I]|0)&65535;b[E>>1]=F;if(F<<16>>16<0){F=1109192+(q*68|0)|0;a[F]=a[F]|-128}F=B&255;a[1109196+(q*68|0)+(F<<1)|0]=M;E=1109196+(q*68|0)+(F<<1)+1|0;a[E]=p;if((a[A]|0)!=0){a[E]=(a[l]|0)-1&255^p}a[y]=B+1&255}}while(0);q=x+m|0;B=q&255;if((B|0)<(N|0)){o=o+1&255;p=q&255;x=B}else{break}}}}while(0);M=M+1&127;}while(M<<24>>24!=n<<24>>24);n=1;M=a[1109192]|0;do{N=1109192+(n*68|0)|0;M=a[N]|M;a[N]=M;n=n+1|0;}while((n|0)<239)}a[1106088]=0}a[1044390]=a[1044390]|a[1109192+((c[277231]|0)*68|0)|0];n=c[276540]|0;c[277230]=n;M=(c[276539]|0)-1|0;c[277231]=M;N=e[522243]|0;if(M>>>0<N>>>0){P=M}else{M=N-1|0;c[277231]=M;P=M}if((a[1044481]|0)!=0){M=c[277212]|0;N=ab(c[277223]|0,n)|0;m=M+(N<<1)|0;c[277218]=m;if((a[1108916]|0)==0|(a[1108917]|0)==0){Q=m}else{m=M+((c[277222]|0)+N<<1)|0;c[277218]=m;Q=m}if(n>>>0>P>>>0){R=c[276539]|0;c[276540]=R;i=f;return}else{S=n;T=Q}do{X2(T|0,0,c[276670]<<2|0);S=S+1|0;T=(c[277218]|0)+(c[277223]<<1)|0;c[277218]=T;}while(S>>>0<=(c[277231]|0)>>>0);R=c[276539]|0;c[276540]=R;i=f;return}if((a[1044444]|0)!=0){S=g;b[S>>1]=b[80444]|0;b[S+2>>1]=b[80445]|0;b[S+4>>1]=b[80446]|0;b[S+6>>1]=b[80447]|0;b[S+8>>1]=b[80448]|0;b[S+10>>1]=b[80449]|0;X2(h|0,0,5);S=a[1044440]|0;T=a[1044441]|0;do{if((S&255)>(T&255)){U=1;V=T}else{if(S<<24>>24==0){W=1}else{b[g+2>>1]=S&255;W=2}if(T<<24>>24==-1){U=W;V=-1;break}b[g+(W<<1)>>1]=(T&255)+1&65535;U=W+1|0;V=T}}while(0);T=a[1044442]|0;W=a[1044443]|0;Q=(T&255)>(W&255);L13900:do{if(Q){X=U}else{P=T&255;m=0;while(1){if((m|0)>(U|0)){Y=U;break}Z=g+(m<<1)|0;N=b[Z>>1]|0;if((P|0)==(N|0)){Y=U;break}if((P|0)<(N|0)){_=U;w=10256;break}else{m=m+1|0}}if((w|0)==10256){while(1){w=0;b[g+(_+1<<1)>>1]=b[g+(_<<1)>>1]|0;P=_-1|0;if((P|0)<(m|0)){break}else{_=P;w=10256}}b[Z>>1]=T&255;Y=U+1|0}P=(W&255)+1|0;N=m;while(1){if((N|0)>(Y|0)){X=Y;break L13900}$=g+(N<<1)|0;M=b[$>>1]|0;if((P|0)==(M|0)){X=Y;break L13900}if((P|0)<(M|0)){aa=Y;break}else{N=N+1|0}}do{b[g+(aa+1<<1)>>1]=b[g+(aa<<1)>>1]|0;aa=aa-1|0;}while((aa|0)>=(N|0));b[$>>1]=(W&255)+1&65535;X=Y+1|0}}while(0);if((S&255)>(V&255)){ac=0}else{Y=S&255;S=0;while(1){if((b[g+(S<<1)>>1]|0)==(Y|0)){break}else{S=S+1|0}}$=(V&255)+1|0;if((Y|0)==($|0)){ad=S}else{Y=S;while(1){V=Y+1|0;if((b[g+(V<<1)>>1]|0)==($|0)){ad=V;break}else{Y=V}}}ac=a[5712+(S*6|0)+ad|0]|0}if(Q){ae=0}else{Q=T&255;T=0;while(1){if((b[g+(T<<1)>>1]|0)==(Q|0)){break}else{T=T+1|0}}ad=(W&255)+1|0;if((Q|0)==(ad|0)){af=T}else{Q=T;while(1){W=Q+1|0;if((b[g+(W<<1)>>1]|0)==(ad|0)){af=W;break}else{Q=W}}}ae=a[5712+(T*6|0)+af|0]|0}af=(a[1044468]|0)!=0;do{if((a[1044462]|0)==0){if(!af){ag=0;break}ag=((a[1044480]|0)==0)<<31>>31^ae}else{T=((a[1044474]|0)==0)<<31>>31^ac;if(!af){ag=T;break}Q=((a[1044480]|0)==0)<<31>>31^ae;ad=d[1044456]|0;if((ad|0)==2){ag=Q^T;break}else if((ad|0)==3){ag=Q^~T;break}else if((ad|0)==0){ag=Q|T;break}else if((ad|0)==1){ag=Q&T;break}else{ag=0;break}}}while(0);af=c[263195]|0;T=d[af+8496|0]|0;Q=T&192;if((Q|0)==64){ah=~ag}else if((Q|0)==128){ah=ag}else if((Q|0)==192){ah=-1}else{ah=0}Q=T&48;if((Q|0)==16){ai=~ag}else if((Q|0)==32){ai=ag}else if((Q|0)==48){ai=-1}else{ai=0}if((X|0)>0){Q=ah&255;ah=ai&255;ai=0;do{ag=1<<ai;if((ag&Q|0)==0){T=h+ai|0;a[T]=a[T]|1}if((ag&ah|0)==0){ag=h+ai|0;a[ag]=a[ag]|2}ai=ai+1|0;}while((ai|0)<(X|0))}if((a[1044495]|0)!=0){ai=0;ah=0;Q=0;while(1){ag=a[h+ai|0]|0;T=ag|1;do{if((Q|0)>0){ad=Q-1|0;W=1105884+(ad<<1)|0;S=b[g+(ai<<1)>>1]|0;if((e[W>>1]|0)!=(S<<16>>16|0)){aj=S;w=10305;break}if((a[1105865+ad|0]|0)!=ag<<24>>24){aj=S;w=10305;break}ad=b[g+(ai+1<<1)>>1]|0;b[W>>1]=ad;ak=Q;al=S;am=ad}else{aj=b[g+(ai<<1)>>1]|0;w=10305}}while(0);if((w|0)==10305){w=0;b[1105872+(Q<<1)>>1]=aj;ad=b[g+(ai+1<<1)>>1]|0;b[1105884+(Q<<1)>>1]=ad;a[1105865+Q|0]=ag;ak=Q+1|0;al=aj;am=ad}do{if((ah|0)>0){ad=ah-1|0;S=1106076+(ad<<1)|0;if((e[S>>1]|0)!=(al<<16>>16|0)){w=10310;break}if((a[1106057+ad|0]|0)!=ag<<24>>24){w=10310;break}b[S>>1]=am;an=ah}else{w=10310}}while(0);if((w|0)==10310){w=0;b[1106064+(ah<<1)>>1]=al;b[1106076+(ah<<1)>>1]=am;a[1106057+ah|0]=T;an=ah+1|0}ag=ai+1|0;if((ag|0)<(X|0)){ai=ag;ah=an;Q=ak}else{break}}a[1105864]=ak&255;a[1106056]=an&255}an=af+8494|0;ak=af+8495|0;af=0;do{Q=(a[1044463+af|0]|0)!=0;do{if((a[1044457+af|0]|0)==0){if(!Q){ao=0;break}ao=((a[1044475+af|0]|0)==0)<<31>>31^ae}else{ah=((a[1044469+af|0]|0)==0)<<31>>31^ac;if(!Q){ao=ah;break}ai=((a[1044475+af|0]|0)==0)<<31>>31^ae;am=d[1044451+af|0]|0;if((am|0)==1){ao=ai&ah;break}else if((am|0)==2){ao=ai^ah;break}else if((am|0)==3){ao=ai^~ah;break}else if((am|0)==0){ao=ai|ah;break}else{ao=0;break}}}while(0);Q=1<<af;T=ao&255;ah=(d[an]&Q|0)==0?0:T;ai=d[ak]|0;am=0;al=0;while(1){aj=(1<<am&ah|0)==0?d[h+am|0]|0:0;L14006:do{if((aj|0)==0){ap=al;aq=am+1|0}else{do{if((al|0)>0){ag=al-1|0;S=1105724+(af<<5)+(ag<<1)|0;ad=b[g+(am<<1)>>1]|0;if((e[S>>1]|0)!=(ad<<16>>16|0)){ar=ad;break}if((d[1105705+(af<<5)+ag|0]|0)!=(aj|0)){ar=ad;break}ad=am+1|0;b[S>>1]=b[g+(ad<<1)>>1]|0;ap=al;aq=ad;break L14006}else{ar=b[g+(am<<1)>>1]|0}}while(0);b[1105712+(af<<5)+(al<<1)>>1]=ar;ad=am+1|0;b[1105724+(af<<5)+(al<<1)>>1]=b[g+(ad<<1)>>1]|0;a[1105705+(af<<5)+al|0]=aj&255;ap=al+1|0;aq=ad}}while(0);if((aq|0)<(X|0)){am=aq;al=ap}else{break}}al=(ai&Q|0)==0?0:T;a[1105704+(af<<5)|0]=ap&255;am=0;ah=0;while(1){aj=(1<<am&al|0)==0?d[h+am|0]|1:0;L14019:do{if((aj|0)==0){as=ah;at=am+1|0}else{do{if((ah|0)>0){ad=ah-1|0;S=1105916+(af<<5)+(ad<<1)|0;ag=b[g+(am<<1)>>1]|0;if((e[S>>1]|0)!=(ag<<16>>16|0)){au=ag;break}if((d[1105897+(af<<5)+ad|0]|0)!=(aj|0)){au=ag;break}ag=am+1|0;b[S>>1]=b[g+(ag<<1)>>1]|0;as=ah;at=ag;break L14019}else{au=b[g+(am<<1)>>1]|0}}while(0);b[1105904+(af<<5)+(ah<<1)>>1]=au;ag=am+1|0;b[1105916+(af<<5)+(ah<<1)>>1]=b[g+(ag<<1)>>1]|0;a[1105897+(af<<5)+ah|0]=aj&255;as=ah+1|0;at=ag}}while(0);if((at|0)<(X|0)){am=at;ah=as}else{break}}a[1105896+(af<<5)|0]=as&255;af=af+1|0;}while((af|0)<5);a[1044444]=0}do{if((a[807393]|0)!=0){do{if((a[1106152]|0)==0){if(((a[1041768]|0)-5&255)>1&(a[1106151]|0)==0){av=n;break}if((n|0)==0){aw=0}else{af=0;while(1){as=c[277212]|0;at=ab(c[277223]|0,af)|0;X=255;g=as+(at+255<<1)|0;au=as+(at+510<<1)|0;while(1){at=b[g>>1]|0;b[au+2>>1]=at;b[au>>1]=at;if((X|0)>0){X=X-1|0;g=g-2|0;au=au-4|0}else{break}}au=af+1|0;g=c[277230]|0;if(au>>>0<g>>>0){af=au}else{aw=g;break}}}a[1106152]=1;c[276670]=512;av=aw}else{av=n}}while(0);if((a[1106153]|0)!=0|(a[1106149]|0)==0){break}if(((a[1041768]|0)-5&255)>=2){break}a[1106153]=1;c[276671]=e[522243]<<1;af=c[277222]|0;g=af<<1;c[277223]=g;a[1108916]=2;if((av|0)<=0){break}au=av-1|0;X=c[277212]|0;at=X+((ab(au,g)|0)<<1)|0;g=X+((ab(au,af)|0)<<1)|0;X9(at|0,g|0,c[276670]<<1|0);if((au|0)>0){ax=au}else{break}do{au=c[277222]|0;ax=ax-1|0;g=c[277212]|0;at=g+((ab(ax,c[277223]|0)|0)<<1)|0;af=g+((ab(ax,au)|0)<<1)|0;X9(at|0,af|0,c[276670]<<1|0);}while((ax|0)>0)}}while(0);ax=c[263195]|0;av=ax+8496|0;do{if((a[av]&48)!=48){if((a[ax+8497|0]&63)==0){break}n=c[276541]|0;c[277228]=d[n+(d[1044483]|0)|0]<<6|d[n+(d[1044482]|0)|0]<<11|d[n+(d[1044484]|0)|0]}}while(0);if((a[1044439]|0)==0){do{if(((a[1041768]|0)-5&255)>1&(a[1106151]|0)==0){n=d[av]|0;if((n&48|0)==48|(n&2|0)==0){break}if((a[ax+8497|0]&63)==0){break}if((a[ax+8493|0]&31)!=0){w=10366}}else{w=10366}}while(0);do{if((w|0)==10366){Hz(1);if((a[1041770]|0)==0){break}n=ab(c[277223]|0,c[277230]|0)|0;aw=c[277297]|0;if((a[aw+160|0]|0)==0){break}else{ay=0;az=aw}do{a[1108928]=a[az+161+ay|0]&1^1;fy[c[281362]&511](n,e[az+168+(ay<<1)>>1]|0,e[az+180+(ay<<1)>>1]|0);ay=ay+1|0;az=c[277297]|0;}while((ay|0)<(d[az+160|0]|0))}}while(0);Hz(0)}else{c[277218]=c[277213];c[277219]=c[277215];c[277297]=1105896;az=d[av]<<4&32;ay=d[ax+8493|0]|0;if((ay&16|0)==0){aA=ax}else{c[348604]=e[521913]|0;c[348602]=e[521914]|0;a[1394512]=0;c[348634]=128;c[348636]=18;c[348638]=18;n=c[276524]|0;c[348622]=n;c[348624]=n;n=c[276531]|0;c[348618]=n;c[348620]=n;c[348606]=5;c[348632]=6;c[348630]=112;a[1394464]=0;c[277224]=8;c[281364]=54;c[281366]=128;c[281362]=176;n=d[ax+8497|0]|0;ax=(n&128|0)!=0?4:1;if((n&64|0)==0){aB=ax}else{aB=(a[av]&2)==0?ax+1|0:ax|2}c[281363]=c[160936+(aB<<2)>>2];c[281365]=c[161640+(aB<<2)>>2];c[281361]=c[161800+(aB<<2)>>2];HO(az|4);aA=c[263195]|0}c[348602]=0;c[277224]=8;c[281364]=54;c[281366]=128;c[281362]=176;aB=d[aA+8497|0]|0;ax=(aB&128|0)!=0?4:1;if((aB&64|0)==0){aC=ax}else{aC=(a[aA+8496|0]&2)==0?ax+1|0:ax|2}c[281363]=c[160936+(aC<<2)>>2];c[281365]=c[161640+(aC<<2)>>2];c[281361]=c[161800+(aC<<2)>>2];aC=d[1041768]|0;do{if((aC|0)==2){if((ay&1|0)!=0){c[348634]=0;a[1394512]=0;ax=(a[1041726]|0)!=0?16:8;c[348614]=ax;c[348612]=ax;c[348636]=18;c[348638]=18;ax=c[276524]|0;c[348622]=ax;c[348624]=ax;ax=c[276531]|0;c[348618]=ax;c[348620]=ax;c[348606]=5;c[348632]=6;c[348630]=112;a[1394464]=0;ax=(a[1041750]|0)!=0?16:8;c[348608]=ax;c[348610]=ax}if((ay&2|0)==0){break}c[348634]=0;a[1394512]=0;ax=(a[1041738]|0)!=0?16:8;c[348614]=ax;c[348612]=ax;c[348636]=18;c[348638]=18;ax=c[276524]|0;c[348622]=ax;c[348624]=ax;ax=c[276531]|0;c[348618]=ax;c[348620]=ax;c[348606]=5;c[348632]=6;c[348630]=112;a[1394464]=0;ax=(a[1041750]|0)!=0?16:8;c[348608]=ax;c[348610]=ax}else if((aC|0)==1){if((ay&1|0)!=0){c[348634]=0;a[1394512]=0;ax=(a[1041726]|0)!=0?16:8;c[348614]=ax;c[348612]=ax;c[348636]=18;c[348638]=18;ax=c[276524]|0;c[348622]=ax;c[348624]=ax;ax=c[276531]|0;c[348618]=ax;c[348620]=ax;c[348606]=5;c[348632]=6;c[348630]=112;a[1394464]=0;HP(0,(az|15)&255,(az|11)&255)}if((ay&2|0)!=0){c[348634]=0;a[1394512]=0;ax=(a[1041738]|0)!=0?16:8;c[348614]=ax;c[348612]=ax;c[348636]=18;c[348638]=18;ax=c[276524]|0;c[348622]=ax;c[348624]=ax;ax=c[276531]|0;c[348618]=ax;c[348620]=ax;c[348606]=5;c[348632]=6;c[348630]=112;a[1394464]=0;HP(1,(az|14)&255,(az|10)&255)}if((ay&4|0)==0){break}c[348634]=0;a[1394512]=0;ax=(a[1041750]|0)!=0?16:8;c[348614]=ax;c[348612]=ax;c[348636]=16;c[348638]=16;ax=c[276523]|0;c[348622]=ax;c[348624]=ax;ax=c[276530]|0;c[348618]=ax;c[348620]=ax;c[348606]=4;c[348632]=8;c[348630]=28;a[1394464]=0;HP(2,(((a[1041769]|0)!=0?17:7)|az)&255,(az|3)&255)}}while(0);a[1394512]=0;c[277218]=c[277212];c[277219]=c[277214];c[277297]=1105704;az=c[263195]|0;ay=d[az+8492|0]|0;if((ay&16|0)==0){aD=az}else{c[348604]=e[521913]|0;c[348602]=e[521914]|0;aC=az+8497|0;a[1394512]=a[aC]&16;c[348634]=128;c[348636]=18;c[348638]=18;ax=c[276524]|0;c[348622]=ax;c[348624]=ax;ax=c[276531]|0;c[348618]=ax;c[348620]=ax;c[348606]=5;c[348632]=6;c[348630]=112;a[1394464]=0;c[277224]=8;c[281364]=54;c[281366]=128;c[281362]=176;ax=d[aC]|0;aC=(ax&128|0)!=0?4:1;if((ax&64|0)==0){aE=aC}else{aE=(a[az+8496|0]&2)==0?aC+1|0:aC|2}c[281363]=c[160936+(aE<<2)>>2];c[281365]=c[161640+(aE<<2)>>2];c[281361]=c[161800+(aE<<2)>>2];HO(36);aD=c[263195]|0}c[348602]=0;c[277224]=8;c[281364]=54;c[281366]=128;c[281362]=176;aE=aD+8497|0;aC=d[aE]|0;az=(aC&128|0)!=0?4:1;if((aC&64|0)==0){aF=az}else{aF=(a[aD+8496|0]&2)==0?az+1|0:az|2}c[281363]=c[160936+(aF<<2)>>2];c[281365]=c[161640+(aF<<2)>>2];c[281361]=c[161800+(aF<<2)>>2];aF=d[1041768]|0;do{if((aF|0)==2){if((ay&1|0)!=0){c[348634]=0;a[1394512]=a[aE]&1;az=(a[1041726]|0)!=0?16:8;c[348612]=az;c[348614]=az;c[348636]=18;c[348638]=18;az=c[276524]|0;c[348622]=az;c[348624]=az;az=c[276531]|0;c[348618]=az;c[348620]=az;c[348606]=5;c[348632]=6;c[348630]=112;a[1394464]=0;az=(a[1041750]|0)!=0?16:8;c[348608]=az;c[348610]=az;HQ(0,47,39,8)}if((ay&2|0)==0){break}c[348634]=0;a[1394512]=a[(c[263195]|0)+8497|0]&2;az=(a[1041738]|0)!=0?16:8;c[348612]=az;c[348614]=az;c[348636]=18;c[348638]=18;az=c[276524]|0;c[348622]=az;c[348624]=az;az=c[276531]|0;c[348618]=az;c[348620]=az;c[348606]=5;c[348632]=6;c[348630]=112;a[1394464]=0;az=(a[1041750]|0)!=0?16:8;c[348608]=az;c[348610]=az;HQ(1,43,35,8)}else if((aF|0)==1){if((ay&1|0)!=0){c[348634]=0;a[1394512]=a[aE]&1;az=(a[1041726]|0)!=0?16:8;c[348612]=az;c[348614]=az;c[348636]=18;c[348638]=18;az=c[276524]|0;c[348622]=az;c[348624]=az;az=c[276531]|0;c[348618]=az;c[348620]=az;c[348606]=5;c[348632]=6;c[348630]=112;a[1394464]=0;HP(0,47,43)}if((ay&2|0)!=0){c[348634]=0;a[1394512]=a[(c[263195]|0)+8497|0]&2;az=(a[1041738]|0)!=0?16:8;c[348612]=az;c[348614]=az;c[348636]=18;c[348638]=18;az=c[276524]|0;c[348622]=az;c[348624]=az;az=c[276531]|0;c[348618]=az;c[348620]=az;c[348606]=5;c[348632]=6;c[348630]=112;a[1394464]=0;HP(1,46,42)}if((ay&4|0)==0){break}c[348634]=0;a[1394512]=a[(c[263195]|0)+8497|0]&4;az=(a[1041750]|0)!=0?16:8;c[348612]=az;c[348614]=az;c[348636]=16;c[348638]=16;az=c[276523]|0;c[348622]=az;c[348624]=az;az=c[276530]|0;c[348618]=az;c[348620]=az;c[348606]=4;c[348632]=8;c[348630]=28;a[1394464]=0;HP(2,(a[1041769]|0)!=0?49:39,35)}}while(0);a[1394512]=a[(c[263195]|0)+8497|0]&32}ay=ab(c[277223]|0,c[277230]|0)|0;aE=c[277297]|0;if((a[aE+160|0]|0)==0){R=c[276539]|0;c[276540]=R;i=f;return}else{aG=0;aH=aE}do{aE=aH+161+aG|0;a[1108928]=a[aE]&1^1;do{if((a[1394512]|0)==0){w=10409}else{if((a[aE]&2)==0){w=10409;break}fy[c[281361]&511](ay,e[aH+168+(aG<<1)>>1]|0,e[aH+180+(aG<<1)>>1]|0)}}while(0);if((w|0)==10409){w=0;fy[c[281362]&511](ay,e[aH+168+(aG<<1)>>1]|0,e[aH+180+(aG<<1)>>1]|0)}aG=aG+1|0;aH=c[277297]|0;}while((aG|0)<(d[aH+160|0]|0));R=c[276539]|0;c[276540]=R;i=f;return}function Hz(b){b=b|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;f=b&255;c[277297]=1105704+(f*192|0);g=c[263195]|0;h=a[g+(f+8492)|0]|0;f=b<<24>>24!=0;if(f){c[277218]=c[277213];c[277219]=c[277215];i=d[g+8496|0]<<4&32}else{j=c[277212]|0;c[277218]=j;if(!((a[1108916]|0)==0|(a[1108917]|0)==0)){c[277218]=j+(c[277222]<<1)}c[277219]=c[277214];i=32}j=h&255;if((j&16|0)!=0){c[348604]=e[521913]|0;c[348602]=e[521914]|0;if(f){k=0}else{k=(d[g+8497|0]|0)>>>4&1}a[1394512]=k;c[348634]=128;c[348636]=18;c[348638]=18;k=c[276524]|0;c[348622]=k;c[348624]=k;k=c[276531]|0;c[348618]=k;c[348620]=k;c[348606]=5;c[348632]=6;c[348630]=112;a[1394464]=0;T7(d[1041768]|0,b,1);HO(i|4)}c[348602]=0;T7(d[1041768]|0,b,0);L14142:do{switch(d[1041768]|0){case 0:{do{if((j&1|0)!=0){c[348634]=0;if(f){l=0}else{l=a[(c[263195]|0)+8497|0]&1}a[1394512]=l;k=(a[1041726]|0)!=0?16:8;c[348614]=k;c[348612]=k;c[348636]=16;c[348638]=16;k=c[276523]|0;c[348622]=k;c[348624]=k;k=c[276530]|0;c[348618]=k;c[348620]=k;c[348606]=4;c[348632]=8;c[348630]=28;a[1394464]=0;k=(i|15)&255;g=(i|11)&255;if((a[1044434]|0)!=0&(d[1044432]|0)>1){HS(0,k,g);break}else{HP(0,k,g);break}}}while(0);do{if((j&2|0)!=0){c[348634]=32;if(f){m=0}else{m=(d[(c[263195]|0)+8497|0]|0)>>>1&1}a[1394512]=m;g=(a[1041738]|0)!=0?16:8;c[348614]=g;c[348612]=g;c[348636]=16;c[348638]=16;g=c[276523]|0;c[348622]=g;c[348624]=g;g=c[276530]|0;c[348618]=g;c[348620]=g;c[348606]=4;c[348632]=8;c[348630]=28;a[1394464]=0;g=(i|14)&255;k=(i|10)&255;if((a[1044435]|0)!=0&(d[1044432]|0)>1){HS(1,g,k);break}else{HP(1,g,k);break}}}while(0);do{if((j&4|0)!=0){c[348634]=64;if(f){n=0}else{n=(d[(c[263195]|0)+8497|0]|0)>>>2&1}a[1394512]=n;k=(a[1041750]|0)!=0?16:8;c[348614]=k;c[348612]=k;c[348636]=16;c[348638]=16;k=c[276523]|0;c[348622]=k;c[348624]=k;k=c[276530]|0;c[348618]=k;c[348620]=k;c[348606]=4;c[348632]=8;c[348630]=28;a[1394464]=0;k=(i|7)&255;g=(i|3)&255;if((a[1044436]|0)!=0&(d[1044432]|0)>1){HS(2,k,g);break}else{HP(2,k,g);break}}}while(0);if((j&8|0)==0){break L14142}c[348634]=96;if(f){o=0}else{o=(d[(c[263195]|0)+8497|0]|0)>>>3&1}a[1394512]=o;g=(a[1041762]|0)!=0?16:8;c[348614]=g;c[348612]=g;c[348636]=16;c[348638]=16;g=c[276523]|0;c[348622]=g;c[348624]=g;g=c[276530]|0;c[348618]=g;c[348620]=g;c[348606]=4;c[348632]=8;c[348630]=28;a[1394464]=0;g=(i|6)&255;k=(i|2)&255;if((a[1044437]|0)!=0&(d[1044432]|0)>1){HS(3,g,k);break L14142}else{HP(3,g,k);break L14142}break};case 7:{L14179:do{if((j&1|0)!=0){if(f){p=0}else{p=a[(c[263195]|0)+8497|0]&1}a[1394512]=p;k=c[281369]|0;g=c[281370]|0;h=c[277297]|0;if((a[h|0]|0)==0){break}else{q=0;r=h;s=p}while(1){h=r+1+q|0;a[1108928]=a[h]&1^1;do{if(s<<24>>24==0){t=10533}else{if((a[h]&2)==0){t=10533;break}fy[k&511](e[r+8+(q<<1)>>1]|0,e[r+20+(q<<1)>>1]|0,i)}}while(0);if((t|0)==10533){t=0;fy[g&511](e[r+8+(q<<1)>>1]|0,e[r+20+(q<<1)>>1]|0,i)}h=q+1|0;u=c[277297]|0;if((h|0)>=(d[u|0]|0)){break L14179}q=h;r=u;s=a[1394512]|0}}}while(0);g=c[263195]|0;if((a[g+8499|0]&64)==0){break L14142}if((j&2|0)==0){break L14142}if(f){v=0}else{v=(d[g+8497|0]|0)>>>1&1}a[1394512]=v;g=c[281371]|0;k=c[281372]|0;u=c[277297]|0;if((a[u+32|0]|0)==0){break L14142}else{w=0;x=u;y=v}while(1){u=x+33+w|0;a[1108928]=a[u]&1^1;do{if(y<<24>>24==0){t=10544}else{if((a[u]&2)==0){t=10544;break}fy[g&511](e[x+40+(w<<1)>>1]|0,e[x+52+(w<<1)>>1]|0,i)}}while(0);if((t|0)==10544){t=0;fy[k&511](e[x+40+(w<<1)>>1]|0,e[x+52+(w<<1)>>1]|0,i)}u=w+1|0;h=c[277297]|0;if((u|0)>=(d[h+32|0]|0)){break L14142}w=u;x=h;y=a[1394512]|0}break};case 1:{do{if((j&1|0)!=0){c[348634]=0;if(f){z=0}else{z=a[(c[263195]|0)+8497|0]&1}a[1394512]=z;k=(a[1041726]|0)!=0?16:8;c[348614]=k;c[348612]=k;c[348636]=18;c[348638]=18;k=c[276524]|0;c[348622]=k;c[348624]=k;k=c[276531]|0;c[348618]=k;c[348620]=k;c[348606]=5;c[348632]=6;c[348630]=112;a[1394464]=0;k=(i|15)&255;g=(i|11)&255;if((a[1044434]|0)!=0&(d[1044432]|0)>1){HS(0,k,g);break}else{HP(0,k,g);break}}}while(0);do{if((j&2|0)!=0){c[348634]=0;if(f){A=0}else{A=(d[(c[263195]|0)+8497|0]|0)>>>1&1}a[1394512]=A;g=(a[1041738]|0)!=0?16:8;c[348614]=g;c[348612]=g;c[348636]=18;c[348638]=18;g=c[276524]|0;c[348622]=g;c[348624]=g;g=c[276531]|0;c[348618]=g;c[348620]=g;c[348606]=5;c[348632]=6;c[348630]=112;a[1394464]=0;g=(i|14)&255;k=(i|10)&255;if((a[1044435]|0)!=0&(d[1044432]|0)>1){HS(1,g,k);break}else{HP(1,g,k);break}}}while(0);if((j&4|0)==0){break L14142}c[348634]=0;if(f){B=0}else{B=(d[(c[263195]|0)+8497|0]|0)>>>2&1}a[1394512]=B;k=(a[1041750]|0)!=0?16:8;c[348614]=k;c[348612]=k;c[348636]=16;c[348638]=16;k=c[276523]|0;c[348622]=k;c[348624]=k;k=c[276530]|0;c[348618]=k;c[348620]=k;c[348606]=4;c[348632]=8;c[348630]=28;a[1394464]=0;k=(((a[1041769]|0)!=0?17:7)|i)&255;g=(i|3)&255;if((a[1044436]|0)!=0&(d[1044432]|0)>1){HS(2,k,g);break L14142}else{HP(2,k,g);break L14142}break};case 2:{do{if((j&1|0)!=0){c[348634]=0;if(f){C=0}else{C=a[(c[263195]|0)+8497|0]&1}a[1394512]=C;g=(a[1041726]|0)!=0?16:8;c[348614]=g;c[348612]=g;c[348636]=18;c[348638]=18;g=c[276524]|0;c[348622]=g;c[348624]=g;g=c[276531]|0;c[348618]=g;c[348620]=g;c[348606]=5;c[348632]=6;c[348630]=112;a[1394464]=0;g=(a[1041750]|0)!=0?16:8;c[348610]=g;c[348608]=g;g=(i|15)&255;k=(i|7)&255;if((a[1044434]|0)!=0&(d[1044432]|0)>1){HT(0,g,k,8);break}else{HQ(0,g,k,8);break}}}while(0);if((j&2|0)==0){break L14142}c[348634]=0;if(f){D=0}else{D=(d[(c[263195]|0)+8497|0]|0)>>>1&1}a[1394512]=D;k=(a[1041738]|0)!=0?16:8;c[348614]=k;c[348612]=k;c[348636]=18;c[348638]=18;k=c[276524]|0;c[348622]=k;c[348624]=k;k=c[276531]|0;c[348618]=k;c[348620]=k;c[348606]=5;c[348632]=6;c[348630]=112;a[1394464]=0;k=(a[1041750]|0)!=0?16:8;c[348610]=k;c[348608]=k;k=(i|11)&255;g=(i|3)&255;if((a[1044435]|0)!=0&(d[1044432]|0)>1){HT(1,k,g,8);break L14142}else{HQ(1,k,g,8);break L14142}break};case 3:{do{if((j&1|0)!=0){c[348634]=0;g=c[263195]|0;if(f){E=0}else{E=a[g+8497|0]&1}a[1394512]=E;k=(a[1041726]|0)!=0?16:8;c[348614]=k;c[348612]=k;c[348636]=28;c[348638]=28;k=c[276525]|0;c[348622]=k;c[348624]=k;k=c[276532]|0;c[348618]=k;c[348620]=k;c[348606]=6;c[348632]=0;c[348630]=0;a[1394464]=a[g+8496|0]&1;g=(i|15)&255;k=(i|7)&255;if((a[1044434]|0)!=0&(d[1044432]|0)>1){HS(0,g,k);break}else{HP(0,g,k);break}}}while(0);if((j&2|0)==0){break L14142}c[348634]=0;if(f){F=0}else{F=(d[(c[263195]|0)+8497|0]|0)>>>1&1}a[1394512]=F;k=(a[1041738]|0)!=0?16:8;c[348614]=k;c[348612]=k;c[348636]=18;c[348638]=18;k=c[276524]|0;c[348622]=k;c[348624]=k;k=c[276531]|0;c[348618]=k;c[348620]=k;c[348606]=5;c[348632]=6;c[348630]=112;a[1394464]=0;k=(i|11)&255;g=(i|3)&255;if((a[1044435]|0)!=0&(d[1044432]|0)>1){HS(1,k,g);break L14142}else{HP(1,k,g);break L14142}break};case 4:{do{if((j&1|0)!=0){c[348634]=0;g=c[263195]|0;if(f){G=0}else{G=a[g+8497|0]&1}a[1394512]=G;k=(a[1041726]|0)!=0?16:8;c[348614]=k;c[348612]=k;c[348636]=28;c[348638]=28;k=c[276525]|0;c[348622]=k;c[348624]=k;k=c[276532]|0;c[348618]=k;c[348620]=k;c[348606]=6;c[348632]=0;c[348630]=0;a[1394464]=a[g+8496|0]&1;g=(a[1041750]|0)!=0?16:8;c[348610]=g;c[348608]=g;g=(i|15)&255;k=(i|7)&255;if((a[1044434]|0)!=0&(d[1044432]|0)>1){HT(0,g,k,0);break}else{HQ(0,g,k,0);break}}}while(0);if((j&2|0)==0){break L14142}c[348634]=0;if(f){H=0}else{H=(d[(c[263195]|0)+8497|0]|0)>>>1&1}a[1394512]=H;k=(a[1041738]|0)!=0?16:8;c[348614]=k;c[348612]=k;c[348636]=16;c[348638]=16;k=c[276523]|0;c[348622]=k;c[348624]=k;k=c[276530]|0;c[348618]=k;c[348620]=k;c[348606]=4;c[348632]=8;c[348630]=28;a[1394464]=0;k=(a[1041750]|0)!=0?16:8;c[348610]=k;c[348608]=k;k=(i|11)&255;g=(i|3)&255;if((a[1044435]|0)!=0&(d[1044432]|0)>1){HT(1,k,g,0);break L14142}else{HQ(1,k,g,0);break L14142}break};case 5:{do{if((j&1|0)!=0){c[348634]=0;if(f){I=0}else{I=a[(c[263195]|0)+8497|0]&1}a[1394512]=I;c[348614]=8;c[348612]=(a[1041726]|0)!=0?16:8;g=a[1044434]|0;k=(g|b)<<24>>24==0;c[348638]=k?14:26;h=c[276529]|0;u=c[276528]|0;c[348624]=k?h:u;J=c[276536]|0;K=c[276535]|0;c[348620]=k?J:K;c[348636]=k?26:14;c[348622]=k?u:h;c[348618]=k?K:J;c[348606]=5;c[348632]=6;c[348630]=112;a[1394464]=0;J=(i|15)&255;K=(i|7)&255;if(g<<24>>24==0){HP(0,J,K);break}else{HS(0,J,K);break}}}while(0);if((j&2|0)==0){break L14142}c[348634]=0;if(f){L=0}else{L=(d[(c[263195]|0)+8497|0]|0)>>>1&1}a[1394512]=L;c[348614]=8;c[348612]=(a[1041738]|0)!=0?16:8;K=a[1044435]|0;J=(K|b)<<24>>24==0;c[348638]=J?48:36;g=c[276527]|0;k=c[276526]|0;c[348624]=J?g:k;h=c[276534]|0;u=c[276533]|0;c[348620]=J?h:u;c[348636]=J?36:48;c[348622]=J?k:g;c[348618]=J?u:h;c[348606]=4;c[348632]=8;c[348630]=28;a[1394464]=0;h=(i|11)&255;u=(i|3)&255;if(K<<24>>24==0){HP(1,h,u);break L14142}else{HS(1,h,u);break L14142}break};case 6:{if((j&1|0)==0){break L14142}c[348634]=0;if(f){M=0}else{M=a[(c[263195]|0)+8497|0]&1}a[1394512]=M;c[348614]=8;c[348612]=(a[1041726]|0)!=0?16:8;u=a[1044434]|0;h=(u|b)<<24>>24==0;c[348638]=h?14:26;K=c[276529]|0;J=c[276528]|0;c[348624]=h?K:J;g=c[276536]|0;k=c[276535]|0;c[348620]=h?g:k;c[348636]=h?26:14;c[348622]=h?J:K;c[348618]=h?k:g;c[348606]=5;c[348632]=6;c[348630]=112;a[1394464]=0;c[348610]=8;c[348608]=(a[1041750]|0)!=0?16:8;g=(i|15)&255;k=(i|7)&255;if(u<<24>>24==0){HQ(0,g,k,8);break L14142}else{HT(0,g,k,8);break L14142}break};default:{}}}while(0);if(f){N=0;a[1394512]=N;return}N=(d[(c[263195]|0)+8497|0]|0)>>>5&1;a[1394512]=N;return}function HA(d,e,f,g,h){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;if((d|0)==0){return}i=b[522243]|0;j=h-7&65535;h=(a[1106152]|0)==0;k=h?1:2;l=h?256:512;if((a[1106153]|0)==0){m=j;n=i;o=1}else{m=j<<1;n=i<<1;o=2}switch(e&15|0){case 8:{p=-64;break};case 3:{p=-31728;break};case 11:{p=1503;break};case 9:{p=1984;break};case 5:{p=-33;break};case 7:{p=-1024;break};case 4:{p=-16937;break};case 10:{p=2015;break};case 6:{p=-2048;break};case 12:{p=31;break};case 13:{p=-18401;break};case 14:{p=-2017;break};case 15:{p=-2032;break};case 2:{p=16904;break};default:{p=0}}switch(f&15|0){case 2:{q=16904;break};case 3:{q=-31728;break};case 4:{q=-16937;break};case 5:{q=-33;break};case 6:{q=-2048;break};case 7:{q=-1024;break};case 8:{q=-64;break};case 9:{q=1984;break};case 10:{q=2015;break};case 11:{q=1503;break};case 12:{q=31;break};case 13:{q=-18401;break};case 14:{q=-2017;break};case 15:{q=-2032;break};default:{q=0}}i=m<<16>>16;m=(g-7&65535)<<(h&1^1)<<16>>16;h=n<<16>>16;n=o*15|0;if((n|0)==0){return}g=(ab(c[277222]|0,i)|0)+m|0;j=k*15|0;r=k*-15|0;s=e<<24>>24==0;t=f<<24>>24==0;u=(f&16)==0;f=q&63454;v=(e&16)==0;e=p&63454;w=0;x=(c[277212]|0)+(g<<1)|0;g=0;L14357:while(1){y=g+i|0;L14359:do{if((y|0)<0){z=x+(j<<1)|0}else{if((y|0)>=(h|0)){A=10616;break L14357}L14362:do{if(s){B=1;C=x;D=0;while(1){E=D+m|0;do{if(!((E|0)<0|C>>>0<(c[277212]|0)>>>0)){if((E|0)>=(l|0)){F=C;G=D;break L14362}if((a[d+((((g|0)/(o|0)|0)*15|0)+((D|0)/(k|0)|0))|0]|0)!=46|t){break}if(u){H=q}else{I=b[C>>1]|0;H=(((I&63454)+f|0)>>>1)+(I&q&2049)&65535}b[C>>1]=H}}while(0);E=C+2|0;I=B<<16>>16;if((I|0)>=(j|0)){z=E;break L14359}B=B+1&65535;C=E;D=I}}else{D=1;C=x;B=0;while(1){I=B+m|0;do{if(!((I|0)<0|C>>>0<(c[277212]|0)>>>0)){if((I|0)>=(l|0)){F=C;G=B;break L14362}E=a[d+((((g|0)/(o|0)|0)*15|0)+((B|0)/(k|0)|0))|0]|0;if(E<<24>>24==35){if(v){J=p}else{K=b[C>>1]|0;J=(((K&63454)+e|0)>>>1)+(K&p&2049)&65535}b[C>>1]=J;break}if(E<<24>>24!=46|t){break}if(u){L=q}else{E=b[C>>1]|0;L=(((E&63454)+f|0)>>>1)+(E&q&2049)&65535}b[C>>1]=L}}while(0);I=C+2|0;E=D<<16>>16;if((E|0)>=(j|0)){z=I;break L14359}D=D+1&65535;C=I;B=E}}}while(0);z=F+(j-G<<1)|0}}while(0);y=w+1&65535;B=y<<16>>16;if((B|0)<(n|0)){w=y;x=z+((c[277222]|0)+r<<1)|0;g=B}else{A=10615;break}}if((A|0)==10615){return}else if((A|0)==10616){return}}
function ip(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;f=i;if((a[637400]&1)!=0){g=c[198610]|0;h=(g|0)!=0?g:c[p>>2]|0;g=(e|0)!=0?e:32904;ec(h|0,33336,(h=i,i=i+8|0,c[h>>2]=g,h)|0)|0;i=h;h=c[198610]|0;g=(h|0)!=0?h:c[p>>2]|0;aY(g|0)|0}if(!(fi[c[(c[199305]|0)+20>>2]&63](c[199308]|0,d,e)|0)){d=c[198610]|0;g=(d|0)!=0?d:c[p>>2]|0;a2(32296,46,1,g|0)|0;g=c[198610]|0;d=(g|0)!=0?g:c[p>>2]|0;aY(d|0)|0;a[539208]=0;i=f;return}d=(e|0)!=0;g=4096;h=535112;j=d?e:798256;while(1){k=g-1|0;if((k|0)==0){l=5809;break}m=a[j]|0;a[h]=m;if(m<<24>>24==0){break}else{g=k;h=h+1|0;j=j+1|0}}do{if((l|0)==5809){a[h]=0;if((a[j]|0)==0){break}else{n=j}do{n=n+1|0;}while((a[n]|0)!=0)}}while(0);a[539208]=1;if((b|0)==0|d^1){i=f;return}d=gH(e,0)|0;if((d|0)!=0){h_(d,b)|0;h2(b,e);gF(d)}a[(c[58922]|0)+52|0]=1;i=f;return}function iq(d){d=d|0;var e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0.0,bc=0.0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0;e=i;i=i+1480|0;f=e|0;j=e+256|0;k=e+512|0;l=e+576|0;m=e+832|0;n=e+1088|0;o=e+1160|0;p=e+1416|0;do{if((a[d+52|0]&1)!=0){q=794432;if((c[q>>2]&4|0)==0&(c[q+4>>2]&0|0)==0){break}if((a[d+53|0]&1)!=0){break}i=e;return}}while(0);q=d+48|0;r=c[q>>2]|0;s=r>>>0<8?0:r-8|0;t=r+17|0;r=d+44|0;u=c[(c[r>>2]|0)+8>>2]|0;v=t>>>0>u>>>0?u:t;t=(v-s|0)>>>0>17?s+17|0:v;v=d+28|0;u=c[v>>2]|0;w=d+32|0;x=(c[w>>2]|0)>>>1;y=0;do{z=ab(y,x)|0;A=y>>>1;B=0;do{C=((B>>>1)+A&1)+1|0;b[u+(B+z<<1)>>1]=(C<<9|C<<13|C<<5|12)&65535;B=B+1|0;}while(B>>>0<320);y=y+1|0;}while(y>>>0<240);y=c[v>>2]|0;u=(c[w>>2]|0)>>>1;x=u*5|0;B=5;do{z=(B>>>1&1)+1|0;b[y+(B+x<<1)>>1]=(z<<10|z<<13|z<<5|12)&65535;B=B+1|0;}while(B>>>0<315);B=u*6|0;x=5;do{z=2-(x>>>1&1)|0;b[y+(x+B<<1)>>1]=(z<<10|z<<13|z<<5|12)&65535;x=x+1|0;}while(x>>>0<315);x=u*7|0;B=5;do{z=2-(B>>>1&1)|0;b[y+(B+x<<1)>>1]=(z<<10|z<<13|z<<5|12)&65535;B=B+1|0;}while(B>>>0<315);B=u<<3;x=5;do{z=(x>>>1&1)+1|0;b[y+(x+B<<1)>>1]=(z<<10|z<<13|z<<5|12)&65535;x=x+1|0;}while(x>>>0<315);x=u*9|0;u=5;do{B=(u>>>1&1)+1|0;b[y+(u+x<<1)>>1]=(B<<10|B<<13|B<<5|12)&65535;u=u+1|0;}while(u>>>0<315);u=c[v>>2]|0;x=(c[w>>2]|0)>>>1;y=x*230|0;B=5;do{z=2-(B>>>1&1)|0;b[u+(B+y<<1)>>1]=(z<<10|z<<13|z<<5|12)&65535;B=B+1|0;}while(B>>>0<315);B=x*231|0;y=5;do{z=2-(y>>>1&1)|0;b[u+(y+B<<1)>>1]=(z<<10|z<<13|z<<5|12)&65535;y=y+1|0;}while(y>>>0<315);y=x*232|0;B=5;do{z=(B>>>1&1)+1|0;b[u+(B+y<<1)>>1]=(z<<10|z<<13|z<<5|12)&65535;B=B+1|0;}while(B>>>0<315);B=x*233|0;y=5;do{z=(y>>>1&1)+1|0;b[u+(y+B<<1)>>1]=(z<<10|z<<13|z<<5|12)&65535;y=y+1|0;}while(y>>>0<315);y=x*234|0;x=5;do{B=2-(x>>>1&1)|0;b[u+(x+y<<1)>>1]=(B<<10|B<<13|B<<5|12)&65535;x=x+1|0;}while(x>>>0<315);x=c[v>>2]|0;y=(c[w>>2]|0)>>>1;u=5;do{B=ab(u,y)|0;z=u>>>1&1;A=z+1|0;C=(A<<10|A<<13|A<<5|12)&65535;b[x+(B+5<<1)>>1]=C;A=2-z|0;z=(A<<10|A<<13|A<<5|12)&65535;b[x+(B+6<<1)>>1]=z;b[x+(B+7<<1)>>1]=z;b[x+(B+8<<1)>>1]=C;b[x+(B+9<<1)>>1]=C;u=u+1|0;}while(u>>>0<235);u=c[v>>2]|0;v=(c[w>>2]|0)>>>1;w=5;do{x=ab(w,v)|0;y=w>>>1&1;C=2-y|0;B=(C<<10|C<<13|C<<5|12)&65535;b[u+(x+310<<1)>>1]=B;b[u+(x+311<<1)>>1]=B;C=y+1|0;y=(C<<10|C<<13|C<<5|12)&65535;b[u+(x+312<<1)>>1]=y;b[u+(x+313<<1)>>1]=y;b[u+(x+314<<1)>>1]=B;w=w+1|0;}while(w>>>0<235);w=c[d+40>>2]|0;u=c[w+8>>2]|0;L8173:do{if((u|0)==0){D=0;E=0;G=5855}else{v=u-1|0;B=c[w>>2]|0;x=c[B+(v*12|0)>>2]|0;y=c[B+(v*12|0)+4>>2]|0;switch(y|0){case 66:{bN(f|0,256,46616,(H=i,i=i+8|0,c[H>>2]=x,H)|0)|0;i=H;I=66;break L8173;break};case 52:{bN(f|0,256,55736,(H=i,i=i+8|0,c[H>>2]=x,H)|0)|0;i=H;I=52;break L8173;break};case 5:{a[f|0]=86;a[f+1|0]=73;a[f+2|0]=68;a[f+3|0]=69;a[f+4|0]=79;a[f+5|0]=32;a[f+6|0]=79;a[f+7|0]=80;a[f+8|0]=84;a[f+9|0]=73;a[f+10|0]=79;a[f+11|0]=78;a[f+12|0]=83;a[f+13|0]=0;I=5;break L8173;break};case 21:{a[f|0]=83;a[f+1|0]=72;a[f+2|0]=65;a[f+3|0]=68;a[f+4|0]=69;a[f+5|0]=82;a[f+6|0]=32;a[f+7|0]=79;a[f+8|0]=80;a[f+9|0]=84;a[f+10|0]=73;a[f+11|0]=79;a[f+12|0]=78;a[f+13|0]=83;a[f+14|0]=0;I=21;break L8173;break};case 54:{a[f|0]=65;a[f+1|0]=85;a[f+2|0]=68;a[f+3|0]=73;a[f+4|0]=79;a[f+5|0]=32;a[f+6|0]=79;a[f+7|0]=80;a[f+8|0]=84;a[f+9|0]=73;a[f+10|0]=79;a[f+11|0]=78;a[f+12|0]=83;a[f+13|0]=0;I=54;break L8173;break};case 64:{a[f|0]=68;a[f+1|0]=73;a[f+2|0]=83;a[f+3|0]=75;a[f+4|0]=32;a[f+5|0]=79;a[f+6|0]=80;a[f+7|0]=84;a[f+8|0]=73;a[f+9|0]=79;a[f+10|0]=78;a[f+11|0]=83;a[f+12|0]=0;I=64;break L8173;break};case 53:{a[f|0]=67;a[f+1|0]=79;a[f+2|0]=82;a[f+3|0]=69;a[f+4|0]=32;a[f+5|0]=79;a[f+6|0]=80;a[f+7|0]=84;a[f+8|0]=73;a[f+9|0]=79;a[f+10|0]=78;a[f+11|0]=83;a[f+12|0]=0;I=53;break L8173;break};default:{D=x;E=y;G=5855;break L8173}}}}while(0);L8183:do{if((G|0)==5855){w=E-26|0;if(w>>>0<24&((w>>>0)%3|0|0)==0|(E|0)==23){w=f|0;bN(w|0,256,100608,(H=i,i=i+8|0,c[H>>2]=D,H)|0)|0;i=H;I=E;break}if((E-55|0)>>>0<3|(E|0)==12|(E|0)==13|(E|0)==4){w=f|0;bN(w|0,256,96240,(H=i,i=i+8|0,c[H>>2]=D,H)|0)|0;i=H;I=E;break}switch(E|0){case 72:{bN(f|0,256,72128,(H=i,i=i+8|0,c[H>>2]=D,H)|0)|0;i=H;I=72;break L8183;break};case 51:{a[f|0]=76;a[f+1|0]=79;a[f+2|0]=65;a[f+3|0]=68;a[f+4|0]=32;a[f+5|0]=72;a[f+6|0]=73;a[f+7|0]=83;a[f+8|0]=84;a[f+9|0]=79;a[f+10|0]=82;a[f+11|0]=89;a[f+12|0]=0;I=51;break L8183;break};case 68:{bN(f|0,256,85280,(H=i,i=i+8|0,c[H>>2]=D,H)|0)|0;i=H;I=68;break L8183;break};case 73:{bN(f|0,256,69920,(H=i,i=i+8|0,c[H>>2]=D,H)|0)|0;i=H;I=73;break L8183;break};case 69:{bN(f|0,256,81872,(H=i,i=i+8|0,c[H>>2]=D,H)|0)|0;i=H;I=69;break L8183;break};case 82:{bN(f|0,256,88400,(H=i,i=i+8|0,c[H>>2]=D,H)|0)|0;i=H;I=82;break L8183;break};case 70:{bN(f|0,256,78400,(H=i,i=i+8|0,c[H>>2]=D,H)|0)|0;i=H;I=70;break L8183;break};case 71:{bN(f|0,256,75184,(H=i,i=i+8|0,c[H>>2]=D,H)|0)|0;i=H;I=71;break L8183;break};default:{w=c[d+4160>>2]|0;u=(w|0)==0?c[182922]|0:w;bN(f|0,256,66984,(H=i,i=i+16|0,c[H>>2]=(u|0)==0?68640:u,c[H+8>>2]=D,H)|0)|0;i=H;I=E;break L8183}}}}while(0);E=j|0;ik(E,45,((c[198551]|0)>>>0)/15|0,f|0,1);ir(d,30,15,E,1);E=c[d+4160>>2]|0;f=(E|0)==0?c[182922]|0:E;E=c[d+4164>>2]|0;j=(E|0)==0?c[182923]|0:E;E=k|0;bN(E|0,64,64960,(H=i,i=i+24|0,c[H>>2]=63384,c[H+8>>2]=(f|0)==0?68640:f,c[H+16>>2]=(j|0)==0?798256:j,H)|0)|0;i=H;ir(d,30,216,E,1);if(s>>>0>=t>>>0){i=e;return}E=d+113708|0;j=m|0;f=o|0;o=p|0;p=l|0;l=n+8|0;k=n|0;D=n;u=(I|0)==55?24:(I|0)==56?24:19;w=I-26|0;y=w>>>0<24&((w>>>0)%3|0|0)==0|(I|0)==23;w=m+1|0;x=m+2|0;v=m+3|0;B=m+4|0;C=m+5|0;z=m+6|0;A=m+7|0;J=m+8|0;K=m+9|0;L=m+10|0;M=d+4252|0;N=(I-68|0)>>>0<6;O=(I|0)==51;P=m+11|0;Q=m+12|0;S=m+13|0;T=m+14|0;U=m+15|0;V=m+16|0;W=m+17|0;X=m+18|0;m=n+9|0;Y=n+10|0;Z=n+11|0;_=n+12|0;$=n+13|0;aa=n+14|0;ac=n+15|0;n=s;s=27;while(1){ad=c[c[r>>2]>>2]|0;ae=c[ad+(n*12|0)>>2]|0;af=c[ad+(n*12|0)+4>>2]|0;ad=c[E>>2]|0;L8207:do{if((af-22|0)>>>0<28){do{if(y){ag=af-26|0;if(!(ag>>>0<24&((ag>>>0)%3|0|0)==0|(af|0)==23)){break}a[j]=40;a[w]=68;a[x]=73;a[v]=82;a[B]=41;a[C]=0;ah=5;ai=1;break L8207}}while(0);if((af|0)==23){a[j]=46;a[w]=46;a[x]=46;a[v]=0;ah=u;ai=23;break}else if((af|0)==25){bN(j|0,256,52576,(H=i,i=i+8|0,c[H>>2]=c[M>>2],H)|0)|0;i=H;ah=u;ai=25;break}else if((af|0)==24){a[j]=0;ah=u;ai=24;break}else if((af|0)==22){bN(j|0,256,60088,(H=i,i=i+8|0,c[H>>2]=(a[535096]&1)!=0?59072:58432,H)|0)|0;i=H;ah=u;ai=22;break}else{ag=af-26|0;aj=(ag>>>0)/3|0;ak=(ag>>>0)%3|0;if((ak|0)==2){ag=~~+g[d+4256+(aj*4148|0)+4116>>2];if((ag|0)==0){a[j]=68;a[w]=111;a[x]=110;a[v]=39;a[B]=116;a[C]=32;a[z]=99;a[A]=97;a[J]=114;a[K]=101;a[L]=0;ah=u;ai=af;break}else{bN(j|0,256,96248,(H=i,i=i+8|0,c[H>>2]=ag,H)|0)|0;i=H;ah=u;ai=af;break}}else if((ak|0)==1){ag=c[d+4256+(aj*4148|0)+4136>>2]|0;if((ag|0)==1){a[j]=76;a[w]=105;a[x]=110;a[v]=101;a[B]=97;a[C]=114;a[z]=0;ah=u;ai=af;break}else if((ag|0)==2){a[j]=78;a[w]=101;a[x]=97;a[v]=114;a[B]=101;a[C]=115;a[z]=116;a[A]=0;ah=u;ai=af;break}else if((ag|0)==0){a[j]=68;a[w]=111;a[x]=110;a[v]=39;a[B]=116;a[C]=32;a[z]=99;a[A]=97;a[J]=114;a[K]=101;a[L]=0;ah=u;ai=af;break}else{ah=u;ai=af;break}}else if((ak|0)==0){ak=d+4256+(aj*4148|0)|0;if((a[ak]|0)==0){a[j]=78;a[w]=47;a[x]=65;a[v]=0;ah=u;ai=af;break}else{gz(j,ak,256);ah=u;ai=af;break}}else{ah=u;ai=af;break}}}else{do{if(!((I|0)==82|(I|0)==66|(I|0)==52)){if(N){break}if(O){a[j]=0;ah=0;ai=af;break L8207}if(af>>>0>65535){ak=af-65536|0;aj=c[(c[184120]|0)+4100>>2]|0;ag=256;al=j;am=c[(c[c[aj+(ak<<4)+8>>2]>>2]|0)+(c[aj+(ak<<4)+12>>2]<<3)>>2]|0;while(1){ak=ag-1|0;if((ak|0)==0){break}aj=a[am]|0;a[al]=aj;if(aj<<24>>24==0){ah=u;ai=af;break L8207}else{ag=ak;al=al+1|0;am=am+1|0}}a[al]=0;if((a[am]|0)==0){ah=u;ai=af;break L8207}else{an=am}while(1){ag=an+1|0;if((a[ag]|0)==0){ah=u;ai=af;break L8207}else{an=ag}}}switch(af|0){case 69:{if((a[543313]|0)==0){a[j]=60;a[w]=100;a[x]=101;a[v]=102;a[B]=97;a[C]=117;a[z]=108;a[A]=116;a[J]=62;a[K]=0;ah=u;ai=69;break L8207}else{ao=256;ap=j;aq=543313}while(1){am=ao-1|0;if((am|0)==0){break}al=a[aq]|0;a[ap]=al;if(al<<24>>24==0){ah=u;ai=69;break L8207}else{ao=am;ap=ap+1|0;aq=aq+1|0}}a[ap]=0;if((a[aq]|0)==0){ah=u;ai=69;break L8207}else{ar=aq}while(1){am=ar+1|0;if((a[am]|0)==0){ah=u;ai=69;break L8207}else{ar=am}}break};case 73:{if((a[629148]|0)==0){a[j]=60;a[w]=82;a[x]=79;a[v]=77;a[B]=32;a[C]=100;a[z]=105;a[A]=114;a[J]=62;a[K]=0;ah=u;ai=73;break L8207}else{as=256;at=j;au=629148}while(1){am=as-1|0;if((am|0)==0){break}al=a[au]|0;a[at]=al;if(al<<24>>24==0){ah=u;ai=73;break L8207}else{as=am;at=at+1|0;au=au+1|0}}a[at]=0;if((a[au]|0)==0){ah=u;ai=73;break L8207}else{av=au}while(1){am=av+1|0;if((a[am]|0)==0){ah=u;ai=73;break L8207}else{av=am}}break};case 83:{bN(j|0,256,45896,(H=i,i=i+8|0,h[H>>3]=+g[150116],H)|0)|0;i=H;ah=u;ai=83;break L8207;break};case 84:{bN(j|0,256,45896,(H=i,i=i+8|0,h[H>>3]=+g[150117],H)|0)|0;i=H;ah=u;ai=84;break L8207;break};case 85:{bN(j|0,256,45296,(H=i,i=i+8|0,c[H>>2]=ad+1,H)|0)|0;i=H;ah=u;ai=85;break L8207;break};case 50:case 51:case 53:case 12:case 14:case 5:case 54:case 64:case 21:case 23:case 52:case 66:case 55:case 56:case 57:{a[j]=46;a[w]=46;a[x]=46;a[v]=0;ah=u;ai=af;break L8207;break};case 62:case 63:{bN(j|0,256,53432,(H=i,i=i+8|0,c[H>>2]=c[182916],H)|0)|0;i=H;ah=u;ai=af;break L8207;break};case 75:{am=(a[736529]&1)==0;a[j]=79;if(am){a[w]=70;a[x]=70;a[v]=0;ah=u;ai=75;break L8207}else{a[w]=78;a[x]=0;ah=u;ai=75;break L8207}break};case 82:{am=cg(596368,47)|0;al=256;ag=j;ak=(am|0)==0?596368:am+1|0;while(1){am=al-1|0;if((am|0)==0){break}aj=a[ak]|0;a[ag]=aj;if(aj<<24>>24==0){ah=u;ai=82;break L8207}else{al=am;ag=ag+1|0;ak=ak+1|0}}a[ag]=0;if((a[ak]|0)==0){ah=u;ai=82;break L8207}else{aw=ak}while(1){al=aw+1|0;if((a[al]|0)==0){ah=u;ai=82;break L8207}else{aw=al}}break};case 71:{if((a[707082]|0)==0){a[j]=60;a[w]=82;a[x]=79;a[v]=77;a[B]=32;a[C]=100;a[z]=105;a[A]=114;a[J]=62;a[K]=0;ah=u;ai=71;break L8207}else{ax=256;ay=j;az=707082}while(1){ak=ax-1|0;if((ak|0)==0){break}ag=a[az]|0;a[ay]=ag;if(ag<<24>>24==0){ah=u;ai=71;break L8207}else{ax=ak;ay=ay+1|0;az=az+1|0}}a[ay]=0;if((a[az]|0)==0){ah=u;ai=71;break L8207}else{aA=az}while(1){ak=aA+1|0;if((a[ak]|0)==0){ah=u;ai=71;break L8207}else{aA=ak}}break};case 1:{a[j]=40;a[w]=68;a[x]=73;a[v]=82;a[B]=41;a[C]=0;ah=5;ai=1;break L8207;break};case 0:{a[j]=40;a[w]=70;a[x]=73;a[v]=76;a[B]=69;a[C]=41;a[z]=0;ah=6;ai=0;break L8207;break};case 9:{bN(j|0,256,53432,(H=i,i=i+8|0,c[H>>2]=c[198603],H)|0)|0;i=H;ah=u;ai=9;break L8207;break};case 16:{ak=256;ag=j;al=(a[535088]&1)!=0?57128:56296;while(1){am=ak-1|0;if((am|0)==0){break}aj=a[al]|0;a[ag]=aj;if(aj<<24>>24==0){ah=u;ai=16;break L8207}else{ak=am;ag=ag+1|0;al=al+1|0}}a[ag]=0;if((a[al]|0)==0){ah=u;ai=16;break L8207}else{aB=al}while(1){ak=aB+1|0;if((a[ak]|0)==0){ah=u;ai=16;break L8207}else{aB=ak}}break};case 10:{al=256;ag=j;ak=(a[535105]&1)!=0?57128:56296;while(1){am=al-1|0;if((am|0)==0){break}aj=a[ak]|0;a[ag]=aj;if(aj<<24>>24==0){ah=u;ai=10;break L8207}else{al=am;ag=ag+1|0;ak=ak+1|0}}a[ag]=0;if((a[ak]|0)==0){ah=u;ai=10;break L8207}else{aC=ak}while(1){al=aC+1|0;if((a[al]|0)==0){ah=u;ai=10;break L8207}else{aC=al}}break};case 65:{ak=fw[c[184100]&31]()|0;ag=fw[c[184098]&31]()|0;if(ag>>>0<ak>>>0){ak=ag+1|0;bN(j|0,256,52576,(H=i,i=i+8|0,c[H>>2]=ak,H)|0)|0;i=H;ah=u;ai=65;break L8207}else{a[j]=78;a[w]=111;a[x]=32;a[v]=68;a[B]=105;a[C]=115;a[z]=107;a[A]=0;ah=u;ai=65;break L8207}break};case 7:{if((a[535096]&1)==0){a[j]=80;a[w]=111;a[x]=105;a[v]=110;a[B]=116;a[C]=32;a[z]=102;a[A]=105;a[J]=108;a[K]=116;a[L]=101;a[P]=114;a[Q]=105;a[S]=110;a[T]=103;a[U]=0;ah=u;ai=7;break L8207}else{a[j]=66;a[w]=105;a[x]=108;a[v]=105;a[B]=110;a[C]=101;a[z]=97;a[A]=114;a[J]=32;a[K]=102;a[L]=105;a[P]=108;a[Q]=116;a[S]=101;a[T]=114;a[U]=105;a[V]=110;a[W]=103;a[X]=0;ah=u;ai=7;break L8207}break};case 72:{if((a[715274]|0)==0){a[j]=60;a[w]=100;a[x]=101;a[v]=102;a[B]=97;a[C]=117;a[z]=108;a[A]=116;a[J]=62;a[K]=0;ah=u;ai=72;break L8207}else{aD=256;aE=j;aF=715274}while(1){ak=aD-1|0;if((ak|0)==0){break}ag=a[aF]|0;a[aE]=ag;if(ag<<24>>24==0){ah=u;ai=72;break L8207}else{aD=ak;aE=aE+1|0;aF=aF+1|0}}a[aE]=0;if((a[aF]|0)==0){ah=u;ai=72;break L8207}else{aG=aF}while(1){ak=aG+1|0;if((a[ak]|0)==0){ah=u;ai=72;break L8207}else{aG=ak}}break};case 70:{if((a[711178]|0)==0){a[j]=60;a[w]=82;a[x]=79;a[v]=77;a[B]=32;a[C]=100;a[z]=105;a[A]=114;a[J]=62;a[K]=0;ah=u;ai=70;break L8207}else{aH=256;aI=j;aJ=711178}while(1){ak=aH-1|0;if((ak|0)==0){break}ag=a[aJ]|0;a[aI]=ag;if(ag<<24>>24==0){ah=u;ai=70;break L8207}else{aH=ak;aI=aI+1|0;aJ=aJ+1|0}}a[aI]=0;if((a[aJ]|0)==0){ah=u;ai=70;break L8207}else{aK=aJ}while(1){ak=aK+1|0;if((a[ak]|0)==0){ah=u;ai=70;break L8207}else{aK=ak}}break};case 60:{ak=256;ag=j;al=(a[794446]&1)!=0?57128:56296;while(1){am=ak-1|0;if((am|0)==0){break}aj=a[al]|0;a[ag]=aj;if(aj<<24>>24==0){ah=u;ai=60;break L8207}else{ak=am;ag=ag+1|0;al=al+1|0}}a[ag]=0;if((a[al]|0)==0){ah=u;ai=60;break L8207}else{aL=al}while(1){ak=aL+1|0;if((a[ak]|0)==0){ah=u;ai=60;break L8207}else{aL=ak}}break};case 61:{al=256;ag=j;ak=(c[158317]|0)!=0?57128:56296;while(1){am=al-1|0;if((am|0)==0){break}aj=a[ak]|0;a[ag]=aj;if(aj<<24>>24==0){ah=u;ai=61;break L8207}else{al=am;ag=ag+1|0;ak=ak+1|0}}a[ag]=0;if((a[ak]|0)==0){ah=u;ai=61;break L8207}else{aM=ak}while(1){al=aM+1|0;if((a[al]|0)==0){ah=u;ai=61;break L8207}else{aM=al}}break};case 8:{ak=794432;bN(j|0,256,((c[ak>>2]&65536|0)!=0|(c[ak+4>>2]&0|0)!=0?57128:56296)|0,(H=i,i=i+1|0,i=i+7>>3<<3,c[H>>2]=0,H)|0)|0;i=H;ah=u;ai=8;break L8207;break};case 87:{switch(c[637404+(ad<<2)>>2]|0){case 1:{aN=256;aO=j;aP=39904;break};case 5:{aN=256;aO=j;aP=41936;break};case 257:{aN=256;aO=j;aP=41328;break};case 2:{aN=256;aO=j;aP=91752;break};case 516:{aN=256;aO=j;aP=69792;break};case 772:{aN=256;aO=j;aP=39472;break};case 260:{aN=256;aO=j;aP=38872;break};case 0:{aN=256;aO=j;aP=43272;break};default:{aN=256;aO=j;aP=38256}}while(1){ak=aN-1|0;if((ak|0)==0){break}ag=a[aP]|0;a[aO]=ag;if(ag<<24>>24==0){ah=u;ai=87;break L8207}else{aN=ak;aO=aO+1|0;aP=aP+1|0}}a[aO]=0;if((a[aP]|0)==0){ah=u;ai=87;break L8207}else{aQ=aP}while(1){ak=aQ+1|0;if((a[ak]|0)==0){ah=u;ai=87;break L8207}else{aQ=ak}}break};case 15:{ak=256;ag=j;al=1920+(c[198602]<<5)|0;while(1){am=ak-1|0;if((am|0)==0){break}aj=a[al]|0;a[ag]=aj;if(aj<<24>>24==0){ah=u;ai=15;break L8207}else{ak=am;ag=ag+1|0;al=al+1|0}}a[ag]=0;if((a[al]|0)==0){ah=u;ai=15;break L8207}else{aR=al}while(1){ak=aR+1|0;if((a[ak]|0)==0){ah=u;ai=15;break L8207}else{aR=ak}}break};case 58:{al=(a[633244]&1)==0;a[j]=79;if(al){a[w]=70;a[x]=70;a[v]=0;ah=u;ai=58;break L8207}else{a[w]=78;a[x]=0;ah=u;ai=58;break L8207}break};case 59:{bN(j|0,256,52576,(H=i,i=i+8|0,c[H>>2]=c[158313],H)|0)|0;i=H;ah=u;ai=59;break L8207;break};case 76:{bN(j|0,256,49992,(H=i,i=i+8|0,h[H>>3]=+g[139947],H)|0)|0;i=H;ah=u;ai=76;break L8207;break};case 78:{al=794432;bN(j|0,256,((c[al>>2]&256|0)!=0|(c[al+4>>2]&0|0)!=0?57128:56296)|0,(H=i,i=i+1|0,i=i+7>>3<<3,c[H>>2]=0,H)|0)|0;i=H;ah=u;ai=78;break L8207;break};case 68:{if((a[633281]|0)==0){a[j]=60;a[w]=100;a[x]=101;a[v]=102;a[B]=97;a[C]=117;a[z]=108;a[A]=116;a[J]=62;a[K]=0;ah=u;ai=68;break L8207}else{aS=256;aT=j;aU=633281}while(1){al=aS-1|0;if((al|0)==0){break}ag=a[aU]|0;a[aT]=ag;if(ag<<24>>24==0){ah=u;ai=68;break L8207}else{aS=al;aT=aT+1|0;aU=aU+1|0}}a[aT]=0;if((a[aU]|0)==0){ah=u;ai=68;break L8207}else{aV=aU}while(1){al=aV+1|0;if((a[al]|0)==0){ah=u;ai=68;break L8207}else{aV=al}}break};case 17:{al=256;ag=j;ak=(a[535089]&1)!=0?57128:56296;while(1){am=al-1|0;if((am|0)==0){break}aj=a[ak]|0;a[ag]=aj;if(aj<<24>>24==0){ah=u;ai=17;break L8207}else{al=am;ag=ag+1|0;ak=ak+1|0}}a[ag]=0;if((a[ak]|0)==0){ah=u;ai=17;break L8207}else{aW=ak}while(1){al=aW+1|0;if((a[al]|0)==0){ah=u;ai=17;break L8207}else{aW=al}}break};case 88:{ak=c[596324+(ad<<2)>>2]|0;if((ak|0)==2){a[j]=82;a[w]=105;a[x]=103;a[v]=104;a[B]=116;a[C]=32;a[z]=83;a[A]=116;a[J]=105;a[K]=99;a[L]=107;a[P]=0;ah=u;ai=88;break L8207}else if((ak|0)==3){a[j]=68;a[w]=117;a[x]=97;a[v]=108;a[B]=32;a[C]=65;a[z]=110;a[A]=97;a[J]=108;a[K]=111;a[L]=103;a[P]=0;ah=u;ai=88;break L8207}else if((ak|0)==1){a[j]=76;a[w]=101;a[x]=102;a[v]=116;a[B]=32;a[C]=83;a[z]=116;a[A]=105;a[J]=99;a[K]=107;a[L]=0;ah=u;ai=88;break L8207}else if((ak|0)==0){a[j]=78;a[w]=111;a[x]=110;a[v]=101;a[B]=0;ah=u;ai=88;break L8207}else{ah=u;ai=88;break L8207}break};case 89:case 90:case 91:case 92:case 93:case 94:case 95:case 96:case 97:case 98:case 99:case 100:case 101:case 102:case 103:case 104:{ak=c[2152+(af-89<<2)>>2]|0;a[l]=85;a[m]=110;a[Y]=107;a[Z]=110;a[_]=111;a[$]=119;a[aa]=110;a[ac]=0;ag=559896+(ad*2240|0)+(ak*40|0)+16|0;ak=c[ag+4>>2]|0;c[k>>2]=c[ag>>2];c[k+4>>2]=ak;ak=c[(c[199306]|0)+20>>2]|0;if((ak|0)==0){aX=256;aY=j;aZ=l}else{fa[ak&15](D,0,0,0,256);aX=256;aY=j;aZ=l}while(1){ak=aX-1|0;if((ak|0)==0){break}ag=a[aZ]|0;a[aY]=ag;if(ag<<24>>24==0){ah=u;ai=af;break L8207}else{aX=ak;aY=aY+1|0;aZ=aZ+1|0}}a[aY]=0;if((a[aZ]|0)==0){ah=u;ai=af;break L8207}else{a_=aZ}while(1){ak=a_+1|0;if((a[ak]|0)==0){ah=u;ai=af;break L8207}else{a_=ak}}break};case 86:{ak=c[595748+(ad<<2)>>2]|0;if(ak>>>0>=8){a[j]=68;a[w]=105;a[x]=115;a[v]=97;a[B]=98;a[C]=108;a[z]=101;a[A]=100;a[J]=0;ah=u;ai=86;break L8207}ag=595812+(ak<<6)|0;if((a[ag]|0)==0){bN(j|0,256,44704,(H=i,i=i+8|0,c[H>>2]=ak,H)|0)|0;i=H;ah=u;ai=86;break L8207}else{a$=256;a0=j;a1=ag}while(1){ag=a$-1|0;if((ag|0)==0){break}ak=a[a1]|0;a[a0]=ak;if(ak<<24>>24==0){ah=u;ai=86;break L8207}else{a$=ag;a0=a0+1|0;a1=a1+1|0}}a[a0]=0;if((a[a1]|0)==0){ah=u;ai=86;break L8207}else{a2=a1}while(1){ag=a2+1|0;if((a[ag]|0)==0){ah=u;ai=86;break L8207}else{a2=ag}}break};case 11:{ag=256;ak=j;al=19304+((c[133777]|0)*68|0)|0;while(1){am=ag-1|0;if((am|0)==0){break}aj=a[al]|0;a[ak]=aj;if(aj<<24>>24==0){ah=u;ai=11;break L8207}else{ag=am;ak=ak+1|0;al=al+1|0}}a[ak]=0;if((a[al]|0)==0){ah=u;ai=11;break L8207}else{a3=al}while(1){ag=a3+1|0;if((a[ag]|0)==0){ah=u;ai=11;break L8207}else{a3=ag}}break};case 18:{bN(j|0,256,52576,(H=i,i=i+8|0,c[H>>2]=c[133773],H)|0)|0;i=H;ah=u;ai=18;break L8207;break};case 19:{do{if((a[543312]&1)==0){al=785752;ak=c[al>>2]|0;ag=c[al+4>>2]|0;al=0;am=ag>>>0>al>>>0|ag>>>0==al>>>0&ak>>>0>2048>>>0?2048:ak;if(am>>>0<2){break}else{a4=0;a5=0;a6=0}do{ak=769368+(a4<<3)|0;a6=Ye(c[ak>>2]|0,c[ak+4>>2]|0,a6,a5)|0;a5=F;a4=a4+1|0;}while(a4>>>0<am>>>0);ak=Ym(a6,a5,am,0)|0;al=F;ag=0;aj=0;a7=0;do{a8=769368+(a7<<3)|0;a9=Yf(c[a8>>2]|0,c[a8+4>>2]|0,ak,al)|0;a8=F;ba=Yo(a9,a8,a9,a8)|0;aj=Ye(ba,F,aj,ag)|0;ag=F;a7=a7+1|0;}while(a7>>>0<am>>>0);bb=+(ak>>>0)+ +(al|0)*4294967296.0;bc=+R(+((+(aj>>>0)+ +(ag|0)*4294967296.0)/+((am-1|0)>>>0>>>0)))/bb*100.0;bN(j|0,256,51712,(H=i,i=i+24|0,h[H>>3]=1.0e6/bb,h[H+8>>3]=bc,c[H+16>>2]=am,H)|0)|0;i=H;ah=u;ai=19;break L8207}}while(0);a[j]=78;a[w]=47;a[x]=65;a[v]=0;ah=u;ai=19;break L8207;break};default:{a[j]=0;ah=0;ai=af;break L8207}}}}while(0);if((af|0)==3){a[j]=0;ah=0;ai=3;break}else if((af|0)==0){a[j]=40;a[w]=70;a[x]=73;a[v]=76;a[B]=69;a[C]=41;a[z]=0;ah=6;ai=0;break}else{a[j]=40;a[w]=68;a[x]=73;a[v]=82;a[B]=41;a[C]=0;ah=5;ai=1;break}}}while(0);af=(n|0)==(c[q>>2]|0);ad=256;a7=f;ba=ae;while(1){a8=ad-1|0;if((a8|0)==0){G=6023;break}a9=a[ba]|0;a[a7]=a9;if(a9<<24>>24==0){bd=64;be=o;bf=j;break}else{ad=a8;a7=a7+1|0;ba=ba+1|0}}do{if((G|0)==6023){G=0;a[a7]=0;if((a[ba]|0)==0){bd=64;be=o;bf=j;break}else{bg=ba}while(1){ad=bg+1|0;if((a[ad]|0)==0){bd=64;be=o;bf=j;break}else{bg=ad}}}}while(0);while(1){ba=bd-1|0;if((ba|0)==0){G=6027;break}a7=a[bf]|0;a[be]=a7;if(a7<<24>>24==0){break}else{bd=ba;be=be+1|0;bf=bf+1|0}}do{if((G|0)==6027){G=0;a[be]=0;if((a[bf]|0)==0){break}else{bh=bf}do{bh=bh+1|0;}while((a[bh]|0)!=0)}}while(0);if(ai>>>0<2){ba=-3-ah|0;ik(f,ba+48|0,((c[198551]|0)>>>0)/15|0,ae,af);bi=ba}else{ik(o,ah,((c[198551]|0)>>>0)/15|0,j,af);bi=-3-ah|0}ba=bi+48|0;bN(p|0,256,36960,(H=i,i=i+48|0,c[H>>2]=af?62:32,c[H+8>>2]=ba,c[H+16>>2]=ba,c[H+24>>2]=f,c[H+32>>2]=ah,c[H+40>>2]=o,H)|0)|0;i=H;ir(d,15,s,p,af);ba=n+1|0;if(ba>>>0<t>>>0){n=ba;s=s+11|0}else{break}}i=e;return}function ir(e,f,g,h,i){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;j=a[h]|0;if(j<<24>>24==0){return}k=e+4152|0;l=i?32639:-1;i=e+32|0;m=e+28|0;e=h;h=f;f=j;while(1){j=h+4|0;n=h+3|0;o=h+2|0;p=h+1|0;q=0;r=f;while(1){s=q*5|0;t=q+g|0;u=c[k>>2]|0;if((1<<(s&7)&(d[u+((s>>3)+((r&255)*7|0))|0]|0)|0)==0){v=r;w=u}else{u=(ab((c[i>>2]|0)>>>1,t)|0)+h|0;b[(c[m>>2]|0)+(u<<1)>>1]=l;v=a[e]|0;w=c[k>>2]|0}u=s+1|0;if(((d[w+(((v&255)*7|0)+(u>>3))|0]|0)&1<<(u&7)|0)==0){x=v;y=w}else{u=p+(ab((c[i>>2]|0)>>>1,t)|0)|0;b[(c[m>>2]|0)+(u<<1)>>1]=l;x=a[e]|0;y=c[k>>2]|0}u=s+2|0;if(((d[y+(((x&255)*7|0)+(u>>3))|0]|0)&1<<(u&7)|0)==0){z=x;A=y}else{u=o+(ab((c[i>>2]|0)>>>1,t)|0)|0;b[(c[m>>2]|0)+(u<<1)>>1]=l;z=a[e]|0;A=c[k>>2]|0}u=s+3|0;if(((d[A+(((z&255)*7|0)+(u>>3))|0]|0)&1<<(u&7)|0)==0){B=z;C=A}else{u=n+(ab((c[i>>2]|0)>>>1,t)|0)|0;b[(c[m>>2]|0)+(u<<1)>>1]=l;B=a[e]|0;C=c[k>>2]|0}u=s+4|0;if(((d[C+(((B&255)*7|0)+(u>>3))|0]|0)&1<<(u&7)|0)!=0){u=j+(ab((c[i>>2]|0)>>>1,t)|0)|0;b[(c[m>>2]|0)+(u<<1)>>1]=l}u=q+1|0;if((u|0)>=10){break}q=u;r=a[e]|0}r=e+1|0;q=a[r]|0;if(q<<24>>24==0){break}else{e=r;h=h+6|0;f=q}}return}function is(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=i;i=i+16|0;f=e|0;g=a+4|0;h=c[g>>2]|0;L8496:do{if((h|0)==0){j=0}else{k=a|0;l=c[k>>2]|0;L8498:do{if((b|0)==0){m=0;while(1){do{if((c[l+(m*12|0)>>2]|0)==0){if((cL(c[l+(m*12|0)+4>>2]|0,612764)|0)!=0){break}if((cL(c[l+(m*12|0)+8>>2]|0,d|0)|0)==0){n=m;break L8498}}}while(0);o=m+1|0;if(o>>>0<h>>>0){m=o}else{j=h;break L8496}}}else{m=0;while(1){o=c[l+(m*12|0)>>2]|0;do{if((o|0)!=0){if((cL(b|0,o|0)|0)!=0){break}if((cL(c[l+(m*12|0)+4>>2]|0,612764)|0)!=0){break}if((cL(c[l+(m*12|0)+8>>2]|0,d|0)|0)==0){n=m;break L8498}}}while(0);o=m+1|0;if(o>>>0<h>>>0){m=o}else{j=h;break L8496}}}}while(0);if((n|0)==0){i=e;return}m=f;o=l+(n*12|0)|0;c[m>>2]=c[o>>2];c[m+4>>2]=c[o+4>>2];c[m+8>>2]=c[o+8>>2];X9(l+12|0,l|0,n*12|0|0);o=c[k>>2]|0;c[o>>2]=c[m>>2];c[o+4>>2]=c[m+4>>2];c[o+8>>2]=c[m+8>>2];i=e;return}}while(0);n=a+8|0;f=c[n>>2]|0;if((j|0)==(f|0)){h=j-1|0;j=a|0;m=c[j>>2]|0;o=m+(h*12|0)|0;XZ(c[o>>2]|0);XZ(c[m+(h*12|0)+4>>2]|0);XZ(c[m+(h*12|0)+8>>2]|0);X2(o|0,0,12);c[g>>2]=(c[g>>2]|0)-1;p=c[n>>2]|0;q=j}else{p=f;q=a|0}a=c[q>>2]|0;X9(a+12|0,a|0,(p*12|0)-12|0);if((b|0)==0){r=0}else{r=dq(b|0)|0}c[c[q>>2]>>2]=r;r=dq(612764)|0;c[(c[q>>2]|0)+4>>2]=r;r=dq(d|0)|0;c[(c[q>>2]|0)+8>>2]=r;c[g>>2]=(c[g>>2]|0)+1;i=e;return}function it(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0;b=i;if((a|0)==0){i=b;return}d=a+12|0;e=c[d>>2]|0;do{if((e|0)!=0){f=c5(e|0,94016)|0;if((f|0)==0){break}g=a+4|0;if((c[g>>2]|0)!=0){h=a|0;j=0;do{k=c[h>>2]|0;l=c[k+(j*12|0)>>2]|0;m=c[k+(j*12|0)+4>>2]|0;n=c[k+(j*12|0)+8>>2]|0;ec(f|0,65920,(k=i,i=i+24|0,c[k>>2]=(l|0)==0?798256:l,c[k+8>>2]=m,c[k+16>>2]=n,k)|0)|0;i=k;j=j+1|0;}while(j>>>0<(c[g>>2]|0)>>>0)}aQ(f|0)|0}}while(0);XZ(c[d>>2]|0);d=a+8|0;e=a|0;g=c[e>>2]|0;if((c[d>>2]|0)==0){o=g}else{j=0;h=g;while(1){g=h+(j*12|0)|0;XZ(c[g>>2]|0);XZ(c[h+(j*12|0)+4>>2]|0);XZ(c[h+(j*12|0)+8>>2]|0);X2(g|0,0,12);g=j+1|0;k=c[e>>2]|0;if(g>>>0<(c[d>>2]|0)>>>0){j=g;h=k}else{o=k;break}}}XZ(o);XZ(a);i=b;return}function iu(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;f=i;i=i+72|0;h=f|0;j=f+8|0;k=f+40|0;l=b+4|0;m=c[l>>2]|0;if((m|0)==0){i=f;return}if((fw[c[m+16>>2]&31]()|0)==0){i=f;return}m=j|0;a[m]=0;n=c[l>>2]|0;do{if((n|0)==0){o=6128}else{fc[c[n+28>>2]&127](1,j);q=c[l>>2]|0;if((q|0)==0){o=6128;break}r=fw[c[q+16>>2]&31]()|0;q=c[l>>2]|0;s=k|0;a[s]=0;if((q|0)==0){t=0;u=s;break}fc[c[q+28>>2]&127](r,k);r=c[l>>2]|0;if((r|0)==0){t=0;u=s;break}do{if((fw[c[r+16>>2]&31]()|0)==1){if((a[m]&1)!=0){break}i=f;return}}while(0);r=c[l>>2]|0;if((r|0)==0){t=0;u=s;break}t=fw[c[r+16>>2]&31]()|0;u=s}}while(0);if((o|0)==6128){n=k|0;a[n]=0;t=0;u=n}n=t-1|0;k=b+1636|0;c[k>>2]=n;if((a[u]&1)==0){v=n}else{c[k>>2]=t;v=t}if((a[m]&1)==0){g[j+12>>2]=1.0;g[j+16>>2]=1.0;c[j+8>>2]=0;c[j+4>>2]=0;a[m]=1}j=b+1124|0;t=j;X5(j|0,m|0,32)|0;if((v|0)>1){v=1;while(1){m=v+1|0;j=t+(v<<5)|0;n=j|0;a[n]=0;u=c[l>>2]|0;if((u|0)==0){o=6143}else{fc[c[u+28>>2]&127](m,j);if((a[n]&1)==0){o=6143}}if((o|0)==6143){o=0;g[t+(v<<5)+16>>2]=1.0;g[t+(v<<5)+12>>2]=1.0;c[t+(v<<5)+8>>2]=0;c[t+(v<<5)+4>>2]=0;a[n]=1}if((m|0)<(c[k>>2]|0)){v=m}else{break}}}iv(b,d,e,c[b+1728>>2]|0,c[b+1732>>2]|0);e=c[k>>2]|0;if((e|0)>0){d=b+740|0;v=0;while(1){m=(c[d+(v*24|0)>>2]|0)-1|0;n=m>>>1|m;m=n>>>2|n;n=m>>>4|m;m=n>>>8|n;n=(m>>>16|m)+1|0;c[d+(v*24|0)+16>>2]=n;m=(c[d+(v*24|0)+4>>2]|0)-1|0;j=m>>>1|m;m=j>>>2|j;j=m>>>4|m;m=j>>>8|j;j=(m>>>16|m)+1|0;c[d+(v*24|0)+20>>2]=j;if((a[637400]&1)!=0){m=c[198610]|0;u=(m|0)!=0?m:c[p>>2]|0;ec(u|0,77560,(w=i,i=i+24|0,c[w>>2]=v,c[w+8>>2]=n,c[w+16>>2]=j,w)|0)|0;i=w;j=c[198610]|0;n=(j|0)!=0?j:c[p>>2]|0;aY(n|0)|0}n=v+1|0;j=c[k>>2]|0;if((n|0)<(j|0)){v=n}else{x=j;break}}}else{x=e}e=b+676|0;v=e;d=e;bx(x|0,d|0);x=(a[535096]&1)!=0?9729:9728;if((c[k>>2]|0)>0){e=b+740|0;j=b+2584|0;n=0;do{aX(3553,c[v+(n<<2)>>2]|0);a[h]=0;u=c[l>>2]|0;do{if((u|0)==0){y=33071;z=x}else{m=n+2|0;if(ft[c[u+20>>2]&63](m,h)|0){A=(a[h]&1)!=0?9729:9728}else{A=x}r=c[l>>2]|0;if((r|0)==0){y=33071;z=A;break}q=fe[c[r+24>>2]&127](m)|0;if((q|0)==2){y=10497;z=A;break}else if((q|0)==3){y=33648;z=A;break}else if((q|0)==0|(q|0)==1){y=33071;z=A;break}else{y=0;z=A;break}}}while(0);eW(3553,10240,z|0);eW(3553,10241,z|0);eW(3553,10242,y|0);eW(3553,10243,y|0);do{if((a[t+(n<<5)|0]&1)==0){o=6171}else{if((a[t+(n<<5)+28|0]&1)==0){o=6171;break}do{if((a[j]&1)==0){u=a1(7939)|0;if((u|0)==0){B=0;break}B=(bu(u|0,42536)|0)!=0}else{B=0}}while(0);if((a[637400]&1)!=0){u=c[198610]|0;s=(u|0)!=0?u:c[p>>2]|0;u=B?96184:91856;ec(s|0,100528,(w=i,i=i+16|0,c[w>>2]=42536,c[w+8>>2]=u,w)|0)|0;i=w;u=c[198610]|0;s=(u|0)!=0?u:c[p>>2]|0;aY(s|0)|0}if(!B){s=c[198610]|0;u=(s|0)!=0?s:c[p>>2]|0;a2(41864,67,1,u|0)|0;u=c[198610]|0;s=(u|0)!=0?u:c[p>>2]|0;aY(s|0)|0}if((a[637400]&1)!=0){s=c[198610]|0;u=(s|0)!=0?s:c[p>>2]|0;ec(u|0,41280,(w=i,i=i+8|0,c[w>>2]=n,w)|0)|0;i=w;u=c[198610]|0;s=(u|0)!=0?u:c[p>>2]|0;aY(s|0)|0}d2(3553,0,6408,c[e+(n*24|0)+16>>2]|0,c[e+(n*24|0)+20>>2]|0,0,6408,5126,0)}}while(0);if((o|0)==6171){o=0;d2(3553,0,6408,c[e+(n*24|0)+16>>2]|0,c[e+(n*24|0)+20>>2]|0,0,6408,5121,0)}n=n+1|0;}while((n|0)<(c[k>>2]|0))}aX(3553,0);aX(3553,0);n=b+612|0;e=n;w=n;dO(c[k>>2]|0,w|0);n=0;while(1){if((n|0)>=(c[k>>2]|0)){o=6177;break}b$(36160,c[e+(n<<2)>>2]|0);dt(36160,36064,3553,c[v+(n<<2)>>2]|0,0);if((cl(36160)|0)==36053){n=n+1|0}else{o=6176;break}}if((o|0)==6176){b5(c[k>>2]|0,w|0);w=c[198610]|0;n=(w|0)!=0?w:c[p>>2]|0;a2(43176,94,1,n|0)|0;n=c[198610]|0;w=(n|0)!=0?n:c[p>>2]|0;aY(w|0)|0;be(c[k>>2]|0,d|0);d=c[198610]|0;k=(d|0)!=0?d:c[p>>2]|0;a2(93920,78,1,k|0)|0;k=c[198610]|0;d=(k|0)!=0?k:c[p>>2]|0;aY(d|0)|0;i=f;return}else if((o|0)==6177){a[b+1640|0]=1;i=f;return}}function iv(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0.0,r=0.0,s=0,t=0.0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;h=i;i=i+8|0;j=h|0;k=c[a+1832>>2]|0;l=c[a+1836>>2]|0;c[j>>2]=0;dT(3379,j|0);m=a+1636|0;if((c[m>>2]|0)<=0){i=h;return}n=a+1124|0;o=a+740|0;q=+(f>>>0>>>0);r=+(e>>>0>>>0);e=b;b=d;d=k;k=l;l=0;f=0;while(1){a=c[n+(f<<5)+4>>2]|0;if((a|0)==1){s=c[n+(f<<5)+20>>2]|0;c[o+(f*24|0)+8>>2]=s;c[o+(f*24|0)>>2]=s}else if((a|0)==0){t=+g[n+(f<<5)+12>>2];c[o+(f*24|0)>>2]=~~(+(e>>>0>>>0)*t);c[o+(f*24|0)+8>>2]=~~(+(d>>>0>>>0)*t)}else if((a|0)==2){a=~~(r*+g[n+(f<<5)+12>>2]);c[o+(f*24|0)+8>>2]=a;c[o+(f*24|0)>>2]=a}a=c[n+(f<<5)+8>>2]|0;if((a|0)==0){t=+g[n+(f<<5)+16>>2];c[o+(f*24|0)+4>>2]=~~(+(b>>>0>>>0)*t);c[o+(f*24|0)+12>>2]=~~(+(k>>>0>>>0)*t)}else if((a|0)==2){s=~~(q*+g[n+(f<<5)+16>>2]);c[o+(f*24|0)+12>>2]=s;c[o+(f*24|0)+4>>2]=s}else if((a|0)==1){a=c[n+(f<<5)+24>>2]|0;c[o+(f*24|0)+12>>2]=a;c[o+(f*24|0)+4>>2]=a}a=o+(f*24|0)|0;s=c[a>>2]|0;u=c[j>>2]|0;if(s>>>0>u>>>0){c[a>>2]=u;v=1;w=u}else{v=l;w=s}s=o+(f*24|0)+4|0;x=c[s>>2]|0;if(x>>>0>u>>>0){c[s>>2]=u;y=1;z=u}else{y=v;z=x}x=o+(f*24|0)+8|0;A=c[x>>2]|0;if(A>>>0>u>>>0){c[x>>2]=u;B=1;C=u}else{B=y;C=A}A=o+(f*24|0)+12|0;D=c[A>>2]|0;if(D>>>0>u>>>0){c[A>>2]=u;E=6203}else{if(B){E=6203}else{F=0;G=w;H=z;I=C;J=D}}if((E|0)==6203){E=0;D=c[198610]|0;K=(D|0)!=0?D:c[p>>2]|0;ec(K|0,40960,(K=i,i=i+16|0,c[K>>2]=u,c[K+8>>2]=u,K)|0)|0;i=K;K=c[198610]|0;u=(K|0)!=0?K:c[p>>2]|0;aY(u|0)|0;F=1;G=c[a>>2]|0;H=c[s>>2]|0;I=c[x>>2]|0;J=c[A>>2]|0}A=f+1|0;if((A|0)<(c[m>>2]|0)){e=G;b=H;d=I;k=J;l=F;f=A}else{break}}i=h;return}function iw(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var h=0,j=0,k=0,l=0.0,m=0,n=0,o=0,p=0,q=0.0,r=0,s=0,t=0,u=0,v=0.0,w=0.0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;h=i;i=i+64|0;j=h|0;k=c[(c[b>>2]|0)+24>>2]|0;if((k|0)==0){l=+(d>>>0>>>0)/+(e>>>0>>>0)}else{l=+fm[k&3](d,e)}do{if((a[535105]&1)==0){if((a[b+1714|0]&1)==0){c[b+1740>>2]=0;c[b+1736>>2]=0;c[b+1744>>2]=d;c[b+1748>>2]=e;m=d;n=e;o=0;p=0;break}q=+g[182936];do{if((c[133777]|0)==7){k=c[198599]|0;r=c[198598]|0;s=k;t=(c[b+1732>>2]|0)-(c[198597]|0)-k|0;u=c[198596]|0}else{if(+Q(+(l-q))<1.0e-4){r=d;s=e;t=0;u=0;break}if(l>q){v=+(d>>>0>>>0);w=(q/l+-1.0)*.5+.5;r=~~(v*2.0*w);s=e;t=0;u=~~(v*(.5-w));break}else{w=+(e>>>0>>>0);v=(l/q+-1.0)*.5+.5;r=d;s=~~(w*2.0*v);t=~~(w*(.5-v));u=0;break}}}while(0);c[b+1736>>2]=u;c[b+1740>>2]=t;c[b+1744>>2]=r;c[b+1748>>2]=s;m=r;n=s;o=u;p=t}else{k=b+1736|0;x=(a[b+1714|0]&1)==0;if((c[133777]|0)==7){y=c[198598]|0;z=c[198599]|0;A=y;B=z;C=d-y|0;D=e-z|0}else{z=c[182927]|0;y=~~+bH(+(+g[182936]*+(z>>>0>>>0)));do{if(y>>>0>d>>>0|z>>>0>e>>>0){E=0;F=0}else{if(x){E=(d>>>0)%(y>>>0)|0;F=(e>>>0)%(z>>>0)|0;break}else{G=(d>>>0)/(y>>>0)|0;H=(e>>>0)/(z>>>0)|0;I=G>>>0<H>>>0?G:H;H=d-(ab(I,y)|0)|0;E=H;F=e-(ab(I,z)|0)|0;break}}}while(0);A=d-E|0;B=e-F|0;C=E;D=F}c[b+1744>>2]=A;c[b+1748>>2]=B;z=(C|0)/2|0;c[k>>2]=z;y=(D|0)/2|0;c[b+1740>>2]=y;m=A;n=B;o=z;p=y}}while(0);eE(o|0,p|0,m|0,n|0);p=b+1936|0;X2(p|0,0,48);g[b+1996>>2]=1.0;g[p>>2]=2.0;g[b+1956>>2]=2.0;g[b+1976>>2]=-1.0;g[b+1984>>2]=-1.0;g[b+1988>>2]=-1.0;g[b+1992>>2]=-0.0;if(f){l=+((c[b+1716>>2]|0)>>>0>>>0)*3.141592653589793/180.0;q=+T(+l);v=+U(+l);X2(j|0,0,60);g[j+40>>2]=1.0;g[j+60>>2]=1.0;g[j>>2]=q;g[j+20>>2]=q;g[j+16>>2]=-0.0-v;g[j+4>>2]=v;i$(b+1872|0,j,p);J=b+1760|0;K=J;c[K>>2]=m;L=b+1764|0;M=L;c[M>>2]=n;i=h;return}else{j=b+1872|0;X5(j|0,p|0,64)|0;J=b+1760|0;K=J;c[K>>2]=m;L=b+1764|0;M=L;c[M>>2]=n;i=h;return}}function ix(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;f=i;i=i+8|0;h=f|0;j=XY(2592)|0;if((j|0)==0){k=0;i=f;return k|0}if((c[j-4>>2]&3|0)!=0){X2(j|0,0,2592)}l=j;m=c[184108]|0;n=c[184109]|0;L8704:do{if((a[535032]|0)==0){do{if((bf(12448)|0)!=0){if(!(jc()|0)){break}o=j;c[o>>2]=9792;q=9792;r=o;break L8704}}while(0);c[j>>2]=0;s=6250}else{o=(cL(75608,535032)|0)==0;t=o?9792:0;if(!o){o=c[198610]|0;u=(o|0)!=0?o:c[p>>2]|0;ec(u|0,43896,(v=i,i=i+8|0,c[v>>2]=535032,v)|0)|0;i=v;u=c[198610]|0;o=(u|0)!=0?u:c[p>>2]|0;aY(o|0)|0;s=6250;break}if(!(fi[c[t+8>>2]&63](1,m,n)|0)){o=c[198610]|0;u=(o|0)!=0?o:c[p>>2]|0;ec(u|0,45232,(v=i,i=i+16|0,c[v>>2]=45880,c[v+8>>2]=535032,v)|0)|0;i=v;u=c[198610]|0;o=(u|0)!=0?u:c[p>>2]|0;aY(o|0)|0;s=6250;break}if(fw[c[t>>2]&31]()|0){o=j;c[o>>2]=t;q=t;r=o;break}else{o=c[198610]|0;u=(o|0)!=0?o:c[p>>2]|0;o=c[t+68>>2]|0;ec(u|0,44648,(v=i,i=i+8|0,c[v>>2]=o,v)|0)|0;i=v;o=c[198610]|0;u=(o|0)!=0?o:c[p>>2]|0;aY(u|0)|0;s=6250;break}}}while(0);if((s|0)==6250){XZ(j);k=0;i=f;return k|0}n=j+2476|0;m=b;c[n>>2]=c[m>>2];c[n+4>>2]=c[m+4>>2];c[n+8>>2]=c[m+8>>2];c[n+12>>2]=c[m+12>>2];c[n+16>>2]=c[m+16>>2];if((a[637400]&1)==0){w=q}else{m=c[198610]|0;n=(m|0)!=0?m:c[p>>2]|0;m=c[q+68>>2]|0;ec(n|0,64920,(v=i,i=i+8|0,c[v>>2]=m,v)|0)|0;i=v;m=c[198610]|0;n=(m|0)!=0?m:c[p>>2]|0;aY(n|0)|0;w=c[r>>2]|0}n=j+1720|0;m=j+1724|0;fc[c[w+20>>2]&127](n,m);if((a[637400]&1)!=0){w=c[198610]|0;q=(w|0)!=0?w:c[p>>2]|0;w=c[n>>2]|0;u=c[m>>2]|0;ec(q|0,63336,(v=i,i=i+16|0,c[v>>2]=w,c[v+8>>2]=u,v)|0)|0;i=v;u=c[198610]|0;w=(u|0)!=0?u:c[p>>2]|0;aY(w|0)|0}w=b+9|0;fb[c[(c[r>>2]|0)+12>>2]&127](a[w]&1);u=c[b>>2]|0;q=c[b+4>>2]|0;o=b+8|0;t=(a[o]&1)!=0;if(t&(u|0)==0&(q|0)==0){y=c[n>>2]|0;z=c[m>>2]|0}else{y=u;z=q}if(!(fi[c[(c[r>>2]|0)+16>>2]&63](y,z,t)|0)){XZ(j);k=0;i=f;return k|0}dF()|0;t=a1(7936)|0;z=a1(7937)|0;if((a[637400]&1)!=0){y=c[198610]|0;q=(y|0)!=0?y:c[p>>2]|0;ec(q|0,61976,(v=i,i=i+16|0,c[v>>2]=t,c[v+8>>2]=z,v)|0)|0;i=v;z=c[198610]|0;t=(z|0)!=0?z:c[p>>2]|0;aY(t|0)|0}t=a1(7938)|0;if((a[637400]&1)!=0){z=c[198610]|0;q=(z|0)!=0?z:c[p>>2]|0;ec(q|0,61112,(v=i,i=i+8|0,c[v>>2]=t,v)|0)|0;i=v;t=c[198610]|0;q=(t|0)!=0?t:c[p>>2]|0;aY(q|0)|0}q=c[(c[r>>2]|0)+52>>2]|0;t=2216;z=73496;do{y=fe[q&127](z)|0;u=c[t+4>>2]|0;x=y;a[u]=x&255;x=x>>8;a[u+1|0]=x&255;x=x>>8;a[u+2|0]=x&255;x=x>>8;a[u+3|0]=x&255;t=t+8|0;z=c[t>>2]|0;}while((z|0)!=0);ey(770,771);a[797396]=0;z=j+2584|0;do{if((a[z]&1)==0){t=a1(7939)|0;if((t|0)==0){A=0;break}A=(bu(t|0,49104)|0)!=0}else{A=0}}while(0);if((a[637400]&1)!=0){t=c[198610]|0;q=(t|0)!=0?t:c[p>>2]|0;t=A?96184:91856;ec(q|0,100528,(v=i,i=i+16|0,c[v>>2]=49104,c[v+8>>2]=t,v)|0)|0;i=v;t=c[198610]|0;q=(t|0)!=0?t:c[p>>2]|0;aY(q|0)|0}do{if(A){if((a[637400]&1)==0){break}q=c[198610]|0;t=(q|0)!=0?q:c[p>>2]|0;a2(48240,52,1,t|0)|0;t=c[198610]|0;q=(t|0)!=0?t:c[p>>2]|0;aY(q|0)|0}else{a[797396]=1;q=c[198610]|0;t=(q|0)!=0?q:c[p>>2]|0;a2(47128,117,1,t|0)|0;t=c[198610]|0;q=(t|0)!=0?t:c[p>>2]|0;aY(q|0)|0}}while(0);a[j+8|0]=a[w]&1;a[j+1713|0]=a[o]&1;o=j+1728|0;w=j+1732|0;fc[c[(c[r>>2]|0)+20>>2]&127](o,w);if((a[637400]&1)!=0){A=c[198610]|0;q=(A|0)!=0?A:c[p>>2]|0;A=c[o>>2]|0;t=c[w>>2]|0;ec(q|0,60048,(v=i,i=i+16|0,c[v>>2]=A,c[v+8>>2]=t,v)|0)|0;i=v;t=c[198610]|0;A=(t|0)!=0?t:c[p>>2]|0;aY(A|0)|0}if((c[n>>2]|0)==0){if((c[m>>2]|0)!=0){s=6278}}else{s=6278}if((s|0)==6278){c[n>>2]=c[o>>2];c[m>>2]=c[w>>2]}m=j+2016|0;c[m>>2]=(a[736430]&1)!=0?168:136;n=j+48|0;c[n>>2]=4;A=(c[184103]|0)==2;t=j+1710|0;a[t]=A&1;if(A){c[n>>2]=1}A=j+2020|0;c[A>>2]=8;c[131714]=c[(c[r>>2]|0)+52>>2];q=c[184108]|0;u=c[184109]|0;a[526864]=a[z]&1;c[131712]=q;c[131710]=u;if((a[539208]&1)==0){B=0}else{B=(a[535112]|0)!=0?535112:0}u=h1(B,2)|0;do{if((u|0)==2){if((a[637400]&1)!=0){q=c[198610]|0;z=(q|0)!=0?q:c[p>>2]|0;a2(52528,44,1,z|0)|0;z=c[198610]|0;q=(z|0)!=0?z:c[p>>2]|0;aY(q|0)|0}q=j+4|0;c[q>>2]=9680;if(jj(B)|0){break}z=c[198610]|0;y=(z|0)!=0?z:c[p>>2]|0;a2(49912,73,1,y|0)|0;y=c[198610]|0;z=(y|0)!=0?y:c[p>>2]|0;aY(z|0)|0;if(fe[c[c[q>>2]>>2]&127](0)|0){break}q=c[198610]|0;z=(q|0)!=0?q:c[p>>2]|0;a2(59024,47,1,z|0)|0;z=c[198610]|0;q=(z|0)!=0?z:c[p>>2]|0;aY(q|0)|0;fz[c[(c[r>>2]|0)+4>>2]&8191]();XZ(j);k=0;i=f;return k|0}else if((u|0)==3){if((a[637400]&1)==0){break}q=c[198610]|0;a2(53384,41,1,((q|0)!=0?q:c[p>>2]|0)|0)|0;q=c[198610]|0;aY(((q|0)!=0?q:c[p>>2]|0)|0)|0}else{q=c[198610]|0;a2(51616,89,1,((q|0)!=0?q:c[p>>2]|0)|0)|0;q=c[198610]|0;aY(((q|0)!=0?q:c[p>>2]|0)|0)|0}}while(0);u=j+4|0;B=c[u>>2]|0;if((B|0)!=0){q=(fw[c[B+40>>2]&31]()|0)+1|0;B=c[n>>2]|0;c[n>>2]=q>>>0>B>>>0?q:B}B=a[637400]|0;if((B&1)==0){C=B}else{B=c[198610]|0;q=(B|0)!=0?B:c[p>>2]|0;B=c[n>>2]|0;ec(q|0,39848,(v=i,i=i+8|0,c[v>>2]=B,v)|0)|0;i=v;B=c[198610]|0;q=(B|0)!=0?B:c[p>>2]|0;aY(q|0)|0;C=a[637400]|0}if((C&1)!=0){C=c[198610]|0;q=(C|0)!=0?C:c[p>>2]|0;C=c[u>>2]|0;if((C|0)==0){D=0}else{D=fw[c[C+16>>2]&31]()|0}ec(q|0,58392,(v=i,i=i+8|0,c[v>>2]=D,v)|0)|0;i=v;v=c[198610]|0;D=(v|0)!=0?v:c[p>>2]|0;aY(D|0)|0}D=c[b+12>>2]<<8;v=j+1832|0;c[v>>2]=D;q=j+1836|0;c[q>>2]=D;a[j+1714|0]=a[b+10|0]&1;D=c[u>>2]|0;if((D|0)!=0){fb[c[D+12>>2]&127](0)}iw(j,c[o>>2]|0,c[w>>2]|0,1);D=c[u>>2]|0;if((D|0)!=0){fb[c[D+12>>2]&127](1)}iw(j,c[o>>2]|0,c[w>>2]|0,1);a[h]=0;w=c[u>>2]|0;do{if((w|0)==0){s=6307}else{if(!(ft[c[w+20>>2]&63](1,h)|0)){s=6307;break}c[j+468>>2]=(a[h]&1)!=0?9729:9728}}while(0);if((s|0)==6307){c[j+468>>2]=(a[b+11|0]&1)!=0?9729:9728}s=c[u>>2]|0;do{if((s|0)==0){E=33071}else{u=fe[c[s+24>>2]&127](1)|0;if((u|0)==3){E=33648;break}else if((u|0)==2){E=10497;break}else if((u|0)==0|(u|0)==1){E=33071;break}else{E=0;break}}}while(0);c[j+2040>>2]=E;E=(a[b+16|0]&1)!=0;s=E?32993:6407;u=j+2028|0;c[u>>2]=s;h=j+2032|0;c[h>>2]=s;c[j+2036>>2]=E?5121:33635;c[j+2044>>2]=E?4:2;if(!((a[797396]&1)==0|E^1)){c[u>>2]=6408;c[h>>2]=6408}dc(2929);dc(2884);dc(3024);h=j+1840|0;X5(h|0,816,32)|0;c[j+2e3>>2]=c[m>>2];c[j+2008>>2]=h;c[j+2004>>2]=c[A>>2];c[j+2012>>2]=816;A=ab(c[q>>2]|0,c[v>>2]|0)|0;h=A<<2;m=A>>>0>65535;if(m){F=(A&1073741823|0)==(A|0)?h:-1}else{F=h}u=XY(F)|0;do{if((u|0)!=0){if((c[u-4>>2]&3|0)==0){break}X2(u|0,0,F|0)}}while(0);c[j+472>>2]=u;if(m){G=(A&1073741823|0)==(A|0)?h:-1}else{G=h}h=XY(G)|0;if((h|0)==0){c[j+476>>2]=0;fz[c[(c[r>>2]|0)+4>>2]&8191]();XZ(j);k=0;i=f;return k|0}if((c[h-4>>2]&3|0)!=0){X2(h|0,0,G|0)}c[j+476>>2]=h;iZ(j,b);do{if((c[n>>2]|0)!=0){b=j+1768|0;h=j+1800|0;G=0;do{c[b+(G<<2)>>2]=c[v>>2];c[h+(G<<2)>>2]=c[q>>2];G=G+1|0;H=c[n>>2]|0;}while(G>>>0<H>>>0);if((H|0)==0){break}G=j+12|0;h=j+52|0;b=0;do{c[h+(b*52|0)>>2]=c[G>>2];g[h+(b*52|0)+4>>2]=+((c[v>>2]|0)>>>0>>>0);g[h+(b*52|0)+12>>2]=+((c[v>>2]|0)>>>0>>>0);g[h+(b*52|0)+8>>2]=+((c[q>>2]|0)>>>0>>>0);g[h+(b*52|0)+16>>2]=+((c[q>>2]|0)>>>0>>>0);A=h+(b*52|0)+20|0;X5(A|0,816,32)|0;b=b+1|0;}while(b>>>0<(c[n>>2]|0)>>>0)}}while(0);iu(j,c[v>>2]|0,c[q>>2]|0);do{if((a[t]&1)!=0){if(i_(l,c[v>>2]|0,c[q>>2]|0)|0){break}fz[c[(c[r>>2]|0)+4>>2]&8191]();XZ(j);k=0;i=f;return k|0}}while(0);if(!((d|0)==0|(e|0)==0)){fc[c[(c[r>>2]|0)+48>>2]&127](d,e)}if((a[551512]&1)!=0){c[j+2052>>2]=i1(j,547409,+g[137877])|0?9600:0}switch(dF()|0){case 1280:{e=c[198610]|0;a2(57712,39,1,((e|0)!=0?e:c[p>>2]|0)|0)|0;e=c[198610]|0;aY(((e|0)!=0?e:c[p>>2]|0)|0)|0;break};case 1281:{e=c[198610]|0;a2(57080,40,1,((e|0)!=0?e:c[p>>2]|0)|0)|0;e=c[198610]|0;aY(((e|0)!=0?e:c[p>>2]|0)|0)|0;break};case 1282:{e=c[198610]|0;a2(56248,44,1,((e|0)!=0?e:c[p>>2]|0)|0)|0;e=c[198610]|0;aY(((e|0)!=0?e:c[p>>2]|0)|0)|0;break};case 0:{k=j;i=f;return k|0};case 1285:{e=c[198610]|0;a2(55176,40,1,((e|0)!=0?e:c[p>>2]|0)|0)|0;e=c[198610]|0;aY(((e|0)!=0?e:c[p>>2]|0)|0)|0;break};default:{e=c[198610]|0;a2(54280,45,1,((e|0)!=0?e:c[p>>2]|0)|0)|0;e=c[198610]|0;aY(((e|0)!=0?e:c[p>>2]|0)|0)|0}}fz[c[(c[r>>2]|0)+4>>2]&8191]();XZ(j);k=0;i=f;return k|0}function iy(b,d,e,f,h,j){b=b|0;d=d|0;e=e|0;f=f|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0.0,O=0.0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0.0,ac=0,ad=0.0,ae=0,af=0.0,ag=0.0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0;k=i;i=i+992|0;l=k|0;m=k+64|0;n=k+96|0;o=k+928|0;q=k+936|0;r=b+4|0;s=c[r>>2]|0;if((s|0)!=0){fb[c[s+12>>2]&127](1)}s=b+1640|0;if((a[s]&1)!=0){iv(b,e,f,c[b+1760>>2]|0,c[b+1764>>2]|0);aX(3553,c[b+12+(c[b+44>>2]<<2)>>2]|0);b$(36160,c[b+612>>2]|0);t=c[b+740>>2]|0;u=c[b+744>>2]|0;v=c[(c[b>>2]|0)+24>>2]|0;if((v|0)!=0){+fm[v&3](t,u)}c[b+1740>>2]=0;c[b+1736>>2]=0;c[b+1744>>2]=t;c[b+1748>>2]=u;eE(0,0,t|0,u|0);u=b+1936|0;X2(u|0,0,48);g[b+1996>>2]=1.0;g[u>>2]=2.0;g[b+1956>>2]=2.0;g[b+1976>>2]=-1.0;g[b+1984>>2]=-1.0;g[b+1988>>2]=-1.0;g[b+1992>>2]=-0.0;t=b+1872|0;X5(t|0,u|0,64)|0;c[b+2e3>>2]=168}u=b+1711|0;do{if((a[u]&1)!=0){a[u]=0;t=b;v=b+1728|0;w=b+1732|0;fc[c[(c[t>>2]|0)+36>>2]&127](c[v>>2]|0,c[w>>2]|0);if((a[s]&1)==0){iw(b,c[v>>2]|0,c[w>>2]|0,1);break}w=b+1636|0;if((c[w>>2]|0)>0){v=b+740|0;x=v;y=b+612|0;z=y;A=b+676|0;B=0;while(1){C=c[x+(B*24|0)+8>>2]|0;D=x+(B*24|0)+16|0;E=c[x+(B*24|0)+12>>2]|0;F=x+(B*24|0)+20|0;if(C>>>0>(c[D>>2]|0)>>>0){G=6369}else{if(E>>>0>(c[F>>2]|0)>>>0){G=6369}}do{if((G|0)==6369){G=0;H=(C>>>0>E>>>0?C:E)-1|0;I=H>>>1|H;H=I>>>2|I;I=H>>>4|H;H=I>>>8|I;I=(H>>>16|H)+1|0;c[F>>2]=I;c[D>>2]=I;b$(36160,c[z+(B<<2)>>2]|0);I=A+(B<<2)|0;aX(3553,c[I>>2]|0);d2(3553,0,32993,c[D>>2]|0,c[F>>2]|0,0,32993,5121,0);dt(36160,36064,3553,c[I>>2]|0,0);if((cl(36160)|0)!=36053){I=c[198610]|0;H=(I|0)!=0?I:c[p>>2]|0;a2(68568,50,1,H|0)|0;H=c[198610]|0;I=(H|0)!=0?H:c[p>>2]|0;aY(I|0)|0}if((a[637400]&1)==0){break}I=c[198610]|0;H=(I|0)!=0?I:c[p>>2]|0;I=c[D>>2]|0;J=c[F>>2]|0;ec(H|0,66936,(H=i,i=i+24|0,c[H>>2]=B,c[H+8>>2]=I,c[H+16>>2]=J,H)|0)|0;i=H;H=c[198610]|0;J=(H|0)!=0?H:c[p>>2]|0;aY(J|0)|0}}while(0);F=B+1|0;if((F|0)<(c[w>>2]|0)){B=F}else{K=y;L=v;break}}}else{K=b+612|0;L=b+740|0}aX(3553,c[b+12+(c[b+44>>2]<<2)>>2]|0);b$(36160,c[K>>2]|0);v=c[L>>2]|0;y=c[b+744>>2]|0;B=c[(c[t>>2]|0)+24>>2]|0;if((B|0)!=0){+fm[B&3](v,y)}c[b+1740>>2]=0;c[b+1736>>2]=0;c[b+1744>>2]=v;c[b+1748>>2]=y;eE(0,0,v|0,y|0);y=b+1936|0;X2(y|0,0,48);g[b+1996>>2]=1.0;g[y>>2]=2.0;g[b+1956>>2]=2.0;g[b+1976>>2]=-1.0;g[b+1984>>2]=-1.0;g[b+1988>>2]=-1.0;g[b+1992>>2]=-0.0;v=b+1872|0;X5(v|0,y|0,64)|0;c[b+2e3>>2]=168}}while(0);L=b+44|0;K=c[L>>2]|0;L8898:do{if((d|0)==0){aX(3553,c[b+12+(K<<2)>>2]|0);M=b+1708|0}else{u=b+48|0;y=((K+1|0)>>>0)%((c[u>>2]|0)>>>0)|0;c[L>>2]=y;aX(3553,c[b+12+(y<<2)>>2]|0);y=b+1708|0;v=c[L>>2]|0;B=b+1768|0;w=B+(v<<2)|0;A=(c[w>>2]|0)==(e|0);if((a[y]&1)!=0){if(A){if((c[b+1800+(v<<2)>>2]|0)==(f|0)){G=6383}else{G=6381}}else{G=6381}do{if((G|0)==6381){if((c[b+472>>2]|0)==0){G=6383;break}c[w>>2]=e;c[b+1800+(c[L>>2]<<2)>>2]=f;N=+(e>>>0>>>0)/+((c[b+1832>>2]|0)>>>0>>>0);O=+(f>>>0>>>0)/+((c[b+1836>>2]|0)>>>0>>>0);g[b+1848>>2]=N;g[b+1864>>2]=N;g[b+1860>>2]=O;g[b+1868>>2]=O}}while(0);do{if((G|0)==6383){t=c[u>>2]|0;z=((v-1+t|0)>>>0)%(t>>>0)|0;if((c[B+(z<<2)>>2]|0)==(e|0)){if((c[b+1800+(z<<2)>>2]|0)==(f|0)){break}}O=+(e>>>0>>>0)/+((c[b+1832>>2]|0)>>>0>>>0);N=+(f>>>0>>>0)/+((c[b+1836>>2]|0)>>>0>>>0);g[b+1848>>2]=O;g[b+1864>>2]=O;g[b+1860>>2]=N;g[b+1868>>2]=N}}while(0);if((a[s]&1)!=0){M=y;break}b$(36160,0);iw(b,c[b+1728>>2]|0,c[b+1732>>2]|0,1);M=y;break}if(A){if((c[b+1800+(v<<2)>>2]|0)==(f|0)){G=6392}else{G=6390}}else{G=6390}do{if((G|0)==6390){z=b+472|0;if((c[z>>2]|0)==0){G=6392;break}c[w>>2]=e;c[b+1800+(c[L>>2]<<2)>>2]=f;e4(3317,(e<<2&4^4)+4|0);t=b+1832|0;x=b+1836|0;d4(3553,0,0,0,c[t>>2]|0,c[x>>2]|0,c[b+2032>>2]|0,c[b+2036>>2]|0,c[z>>2]|0);N=+(e>>>0>>>0)/+((c[t>>2]|0)>>>0>>>0);O=+(f>>>0>>>0)/+((c[x>>2]|0)>>>0>>>0);g[b+1848>>2]=N;g[b+1864>>2]=N;g[b+1860>>2]=O;g[b+1868>>2]=O}}while(0);do{if((G|0)==6392){w=c[u>>2]|0;A=((v-1+w|0)>>>0)%(w>>>0)|0;if((c[B+(A<<2)>>2]|0)==(e|0)){if((c[b+1800+(A<<2)>>2]|0)==(f|0)){break}}O=+(e>>>0>>>0)/+((c[b+1832>>2]|0)>>>0>>>0);N=+(f>>>0>>>0)/+((c[b+1836>>2]|0)>>>0>>>0);g[b+1848>>2]=O;g[b+1864>>2]=O;g[b+1860>>2]=N;g[b+1868>>2]=N}}while(0);if((a[b+2472|0]&1)!=0){c[o>>2]=0;B=e8[c[(c[b>>2]|0)+60>>2]&3](d,e,f,h,(c[b+2044>>2]|0)==4,c[L>>2]|0,o)|0;v=c[o>>2]|0;if((v|0)==0){u=c[198610]|0;A=(u|0)!=0?u:c[p>>2]|0;a2(69848,55,1,A|0)|0;A=c[198610]|0;u=(A|0)!=0?A:c[p>>2]|0;aY(u|0)|0;M=y;break}if(!B){M=y;break}fc[c[199720]&127](3553,v);M=y;break}v=b+2044|0;B=ab(c[v>>2]|0,e)|0;do{if((B&1|0)==0){if((B&2|0)!=0){P=2;break}P=(B&4^4)+4|0}else{P=1}}while(0);e4(3317,P|0);B=c[v>>2]|0;do{if((B|0)==4){if((a[797396]&1)==0){break}u=b+476|0;A=c[u>>2]|0;w=b+480|0;x=w;t=w;w=b+484|0;if((c[t>>2]|0)==(e|0)){if((c[w>>2]|0)!=(f|0)){G=6407}}else{G=6407}if((G|0)==6407){c[t>>2]=e;c[w>>2]=f;c[b+492>>2]=e;c[b+496>>2]=f;c[b+504>>2]=0;c[b+508>>2]=1;c[b+512>>2]=1;hJ(x)|0}c[b+488>>2]=h;c[b+500>>2]=e<<2;hV(x,A,d);d4(3553,0,0,0,e|0,f|0,c[b+2032>>2]|0,c[b+2036>>2]|0,c[u>>2]|0);M=y;break L8898}}while(0);if(((h>>>0)/(B>>>0)|0|0)==(e|0)){d4(3553,0,0,0,e|0,f|0,c[b+2032>>2]|0,c[b+2036>>2]|0,d|0);M=y;break}v=ab(B,e)|0;u=b+476|0;if((f|0)!=0){A=c[u>>2]|0;x=d;w=0;while(1){X5(A|0,x|0,v)|0;t=w+1|0;if(t>>>0<f>>>0){A=A+v|0;x=x+h|0;w=t}else{break}}}d4(3553,0,0,0,e|0,f|0,c[b+2032>>2]|0,c[b+2036>>2]|0,c[u>>2]|0);M=y}}while(0);if((a[M]&1)!=0){dc(2929);dc(2960);dc(2884);dc(3024);dc(3042);ey(770,771);aO(0.0,0.0,0.0,1.0)}h=q;X2(h|0,0,52);c[q>>2]=c[b+12+(c[L>>2]<<2)>>2];g[q+4>>2]=+(e>>>0>>>0);g[q+8>>2]=+(f>>>0>>>0);L=b+1832|0;g[q+12>>2]=+((c[L>>2]|0)>>>0>>>0);d=b+1836|0;g[q+16>>2]=+((c[d>>2]|0)>>>0>>>0);G=q+20|0;P=b+1840|0;X5(G|0,P|0,32)|0;dg(16384);G=c[r>>2]|0;do{if((G|0)==0){o=b+2e3|0;K=b+1872|0;Q=o;R=o;S=K;T=K}else{ff[c[G+8>>2]&3](e,f,c[L>>2]|0,c[d>>2]|0,c[b+1744>>2]|0,c[b+1748>>2]|0,c[198551]|0,q,b+52|0,0,0);K=c[r>>2]|0;o=b+2e3|0;w=o;x=b+1872|0;v=x;if((K|0)==0){Q=o;R=w;S=x;T=v;break}A=c[K+32>>2]|0;fe[A&127](w)|0;A=c[r>>2]|0;if((A|0)==0){Q=o;R=w;S=x;T=v;break}K=c[A+36>>2]|0;fe[K&127](v)|0;Q=o;R=w;S=x;T=v}}while(0);c7(5,0,4);if((a[s]&1)!=0){s=m;X2(s|0,0,32);d=b+2008|0;c[d>>2]=m;L=b+1636|0;f=c[L>>2]|0;e=b+740|0;G=m+8|0;v=m+24|0;x=m+20|0;w=m+28|0;if((f|0)>1){m=b+676|0;o=b+612|0;K=b;A=b+1740|0;B=b+1736|0;t=b+1744|0;z=b+1748|0;F=b+1936|0;D=b+52|0;E=n|0;C=F;J=b+1956|0;H=b+1976|0;I=b+1996|0;U=b+1984|0;V=b+1988|0;W=b+1992|0;X=1;Y=0;while(1){Z=X-1|0;_=e+(Z*24|0)|0;N=+((c[_>>2]|0)>>>0>>>0);$=e+(Z*24|0)+16|0;O=+((c[$>>2]|0)>>>0>>>0);aa=N/O;ac=e+(Z*24|0)+4|0;ad=+((c[ac>>2]|0)>>>0>>>0);ae=e+(Z*24|0)+20|0;af=+((c[ae>>2]|0)>>>0>>>0);ag=ad/af;g[G>>2]=aa;g[v>>2]=aa;g[x>>2]=ag;g[w>>2]=ag;ah=m+(Z<<2)|0;c[n+(Z*52|0)>>2]=c[ah>>2];g[n+(Z*52|0)+4>>2]=N;g[n+(Z*52|0)+8>>2]=ad;g[n+(Z*52|0)+12>>2]=O;g[n+(Z*52|0)+16>>2]=af;ai=n+(Z*52|0)+20|0;X5(ai|0,s|0,32)|0;b$(36160,c[o+(X<<2)>>2]|0);ai=c[r>>2]|0;if((ai|0)!=0){fb[c[ai+12>>2]&127](X+1|0)}aX(3553,c[ah>>2]|0);dg(16384);ah=c[e+(X*24|0)>>2]|0;ai=c[e+(X*24|0)+4>>2]|0;Z=c[(c[K>>2]|0)+24>>2]|0;if((Z|0)!=0){+fm[Z&3](ah,ai)}c[A>>2]=0;c[B>>2]=0;c[t>>2]=ah;c[z>>2]=ai;eE(0,0,ah|0,ai|0);X2(F|0,0,48);g[I>>2]=1.0;g[C>>2]=2.0;g[J>>2]=2.0;g[H>>2]=-1.0;g[U>>2]=-1.0;g[V>>2]=-1.0;g[W>>2]=-0.0;X5(S|0,F|0,64)|0;ai=c[r>>2]|0;do{if((ai|0)!=0){ff[c[ai+8>>2]&3](c[_>>2]|0,c[ac>>2]|0,c[$>>2]|0,c[ae>>2]|0,c[t>>2]|0,c[z>>2]|0,c[198551]|0,q,D,E,Y);ah=c[r>>2]|0;if((ah|0)==0){break}Z=c[ah+32>>2]|0;fe[Z&127](R)|0;Z=c[r>>2]|0;if((Z|0)==0){break}ah=c[Z+36>>2]|0;fe[ah&127](T)|0}}while(0);c7(5,0,4);ae=Y+1|0;$=X+1|0;ac=c[L>>2]|0;if(($|0)<(ac|0)){X=$;Y=ae}else{aj=ae;ak=ac;break}}}else{aj=0;ak=f}f=ak-1|0;ak=e+(f*24|0)|0;Y=e+(f*24|0)+16|0;af=+((c[ak>>2]|0)>>>0>>>0)/+((c[Y>>2]|0)>>>0>>>0);X=e+(f*24|0)+4|0;E=e+(f*24|0)+20|0;O=+((c[X>>2]|0)>>>0>>>0)/+((c[E>>2]|0)>>>0>>>0);g[G>>2]=af;g[v>>2]=af;g[x>>2]=O;g[w>>2]=O;b$(36160,0);w=c[r>>2]|0;if((w|0)!=0){fb[c[w+12>>2]&127]((c[L>>2]|0)+1|0)}aX(3553,c[b+676+((c[L>>2]|0)-1<<2)>>2]|0);dg(16384);iw(b,c[b+1728>>2]|0,c[b+1732>>2]|0,1);L=c[r>>2]|0;do{if((L|0)==0){c[Q>>2]=c[b+2016>>2]}else{ff[c[L+8>>2]&3](c[ak>>2]|0,c[X>>2]|0,c[Y>>2]|0,c[E>>2]|0,c[b+1744>>2]|0,c[b+1748>>2]|0,c[198551]|0,q,b+52|0,n|0,aj);w=c[r>>2]|0;c[Q>>2]=c[b+2016>>2];if((w|0)==0){break}x=c[w+32>>2]|0;fe[x&127](R)|0;x=c[r>>2]|0;if((x|0)==0){break}w=c[x+36>>2]|0;fe[w&127](T)|0}}while(0);c7(5,0,4);c[d>>2]=P}d=b+52|0;X9(b+104|0,d|0,((c[b+48>>2]|0)*52|0)-52|0);X5(d|0,h|0,52)|0;do{if((a[b+2576|0]&1)!=0){h=c[b+2572>>2]|0;if((h|0)==0){break}d=l|0;g[d>>2]=1.0;g[l+4>>2]=1.0;g[l+8>>2]=1.0;O=+g[b+2580>>2];g[l+12>>2]=O;g[l+16>>2]=1.0;g[l+20>>2]=1.0;g[l+24>>2]=1.0;g[l+28>>2]=O;g[l+32>>2]=1.0;g[l+36>>2]=1.0;g[l+40>>2]=1.0;g[l+44>>2]=O;g[l+48>>2]=1.0;g[l+52>>2]=1.0;g[l+56>>2]=1.0;g[l+60>>2]=O;T=Q;c[T>>2]=136;aj=b+2008|0;c[aj>>2]=816;n=b+2004|0;c[n>>2]=d;aX(3553,h|0);h=c[r>>2]|0;do{if((h|0)!=0){fb[c[h+12>>2]&127](15);d=c[r>>2]|0;q=b+1936|0;if((d|0)==0){break}E=c[d+32>>2]|0;fe[E&127](R)|0;E=c[r>>2]|0;if((E|0)==0){break}d=c[E+36>>2]|0;fe[d&127](q)|0}}while(0);ek(3042);if((a[b+2577|0]&1)==0){c7(5,0,4)}else{eE(0,0,c[b+1728>>2]|0,c[b+1732>>2]|0);c7(5,0,4);eE(c[b+1736>>2]|0,c[b+1740>>2]|0,c[b+1744>>2]|0,c[b+1748>>2]|0)}dc(3042);c[T>>2]=c[b+2016>>2];c[aj>>2]=P;c[n>>2]=c[b+2020>>2]}}while(0);do{if((j|0)!=0){h=c[b+2052>>2]|0;if((h|0)==0){break}fy[c[h+8>>2]&511](b,j,0)}}while(0);if((a[b+2496|0]&1)!=0){aX(3553,c[b+2500>>2]|0);j=l|0;g[j>>2]=1.0;g[l+4>>2]=1.0;g[l+8>>2]=1.0;O=+g[b+2568>>2];g[l+12>>2]=O;g[l+16>>2]=1.0;g[l+20>>2]=1.0;g[l+24>>2]=1.0;g[l+28>>2]=O;g[l+32>>2]=1.0;g[l+36>>2]=1.0;g[l+40>>2]=1.0;g[l+44>>2]=O;g[l+48>>2]=1.0;g[l+52>>2]=1.0;g[l+56>>2]=1.0;g[l+60>>2]=O;l=c[r>>2]|0;if((l|0)!=0){fb[c[l+12>>2]&127](15)}ek(3042);l=Q;c[l>>2]=b+2536;Q=b+2008|0;c[Q>>2]=b+2504;h=b+2004|0;c[h>>2]=j;j=b+1936|0;q=c[r>>2]|0;do{if((q|0)!=0){d=c[q+32>>2]|0;fe[d&127](R)|0;d=c[r>>2]|0;if((d|0)==0){break}E=c[d+36>>2]|0;fe[E&127](j)|0}}while(0);if((a[b+2497|0]&1)==0){c7(5,0,4)}else{eE(0,0,c[b+1728>>2]|0,c[b+1732>>2]|0);c7(5,0,4);eE(c[b+1736>>2]|0,c[b+1740>>2]|0,c[b+1744>>2]|0,c[b+1748>>2]|0)}dc(3042);c[l>>2]=c[b+2016>>2];c[Q>>2]=P;c[h>>2]=c[b+2020>>2]}h=b;fz[c[(c[h>>2]|0)+28>>2]&8191]();if((a[M]&1)==0){al=c[h>>2]|0;am=al+44|0;an=c[am>>2]|0;fz[an&8191]();ao=c[198551]|0;ap=ao+1|0;c[198551]=ap;i=k;return 1}M=c[r>>2]|0;if((M|0)!=0){fb[c[M+12>>2]&127](0)}aX(3553,0);al=c[h>>2]|0;am=al+44|0;an=c[am>>2]|0;fz[an&8191]();ao=c[198551]|0;ap=ao+1|0;c[198551]=ap;i=k;return 1}function iz(a,b){a=a|0;b=b|0;c[b>>2]=9656;return}function iA(a,b){a=a|0;b=b|0;c[b>>2]=9616;return}function iB(a){a=a|0;return c[a+1644+(((((c[a+44>>2]|0)+1|0)>>>0)%((c[a+48>>2]|0)>>>0)|0)<<2)>>2]|0}function iC(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;e=i;if((a[637400]&1)!=0){f=c[198610]|0;g=(f|0)!=0?f:c[p>>2]|0;f=d?75104:72072;ec(g|0,78312,(g=i,i=i+8|0,c[g>>2]=f,g)|0)|0;i=g;g=c[198610]|0;f=(g|0)!=0?g:c[p>>2]|0;aY(f|0)|0}fb[c[(c[b>>2]|0)+12>>2]&127](d&1^1);i=e;return}function iD(b){b=b|0;var d=0,e=0,f=0;d=i;i=i+16|0;e=d|0;f=d+8|0;fa[c[(c[b>>2]|0)+32>>2]&15](e,f,b+1728|0,b+1732|0,c[198551]|0);do{if((a[e]&1)==0){if((a[f]&1)==0){break}a[b+1711|0]=1}else{a[b+1712|0]=1}}while(0);i=d;return(a[b+1712|0]&1)==0|0}function iE(a){a=a|0;return fw[c[(c[a>>2]|0)+40>>2]&31]()|0}function iF(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0;f=i;i=i+8|0;h=f|0;j=b;if((d|0)==3){k=0;i=f;return k|0}l=b+4|0;m=c[l>>2]|0;if((m|0)!=0){fz[c[m+4>>2]&8191]()}m=(d|0)==2;c[l>>2]=m?9680:0;if(!m){m=c[198610]|0;d=(m|0)!=0?m:c[p>>2]|0;ec(d|0,55616,(n=i,i=i+8|0,c[n>>2]=e,n)|0)|0;i=n;d=c[198610]|0;m=(d|0)!=0?d:c[p>>2]|0;aY(m|0)|0;k=0;i=f;return k|0}m=b+1640|0;if((a[m]&1)!=0){d=b+1636|0;be(c[d>>2]|0,b+676|0);o=b+612|0;b5(c[d>>2]|0,o|0);a[m]=0;c[d>>2]=0;X2(o|0,0,128)}o=b+44|0;d=b+12|0;aX(3553,c[d+(c[o>>2]<<2)>>2]|0);if(!(fe[c[c[l>>2]>>2]&127](e)|0)){e=c[198610]|0;m=(e|0)!=0?e:c[p>>2]|0;a2(46408,81,1,m|0)|0;m=c[198610]|0;e=(m|0)!=0?m:c[p>>2]|0;aY(e|0)|0;if(fe[c[c[l>>2]>>2]&127](0)|0){k=0;i=f;return k|0}c[l>>2]=0;k=0;i=f;return k|0}a[h]=0;e=c[l>>2]|0;if((e|0)==0){q=6497}else{if(!(ft[c[e+20>>2]&63](1,h)|0)){q=6497}}if((q|0)==6497){a[h]=a[535096]&1}e=c[l>>2]|0;do{if((e|0)==0){r=33071}else{m=fe[c[e+24>>2]&127](1)|0;if((m|0)==0|(m|0)==1){r=33071;break}else if((m|0)==2){r=10497;break}else if((m|0)==3){r=33648;break}else{r=0;break}}}while(0);e=a[h]&1;a[b+2487|0]=e;h=e<<24>>24!=0?9729:9728;e=b+468|0;m=b+2040|0;if((h|0)==(c[e>>2]|0)){if((r|0)!=(c[m>>2]|0)){q=6505}}else{q=6505}if((q|0)==6505){c[e>>2]=h;c[m>>2]=r;r=b+48|0;h=c[r>>2]|0;if((h|0)!=0){q=0;s=h;while(1){h=c[j+12+(q<<2)>>2]|0;if((h|0)==0){t=s}else{aX(3553,h|0);eW(3553,10242,c[m>>2]|0);eW(3553,10243,c[m>>2]|0);eW(3553,10240,c[e>>2]|0);eW(3553,10241,c[e>>2]|0);t=c[r>>2]|0}h=q+1|0;if(h>>>0<t>>>0){q=h;s=t}else{break}}}aX(3553,c[j+12+(c[o>>2]<<2)>>2]|0)}t=c[l>>2]|0;do{if((t|0)!=0){s=(fw[c[t+40>>2]&31]()|0)+1|0;q=b+48|0;r=c[q>>2]|0;if(s>>>0<=r>>>0){break}e=b+1708|0;if((a[e]&1)!=0){b5(r|0,b+1644|0)}if((a[b+1709|0]&1)!=0){bL(c[q>>2]|0,b+1676|0)}a[e]=0;e=d;be(c[q>>2]|0,e|0);c[q>>2]=s;if((a[637400]&1)!=0){r=c[198610]|0;m=(r|0)!=0?r:c[p>>2]|0;ec(m|0,39848,(n=i,i=i+8|0,c[n>>2]=s,n)|0)|0;i=n;s=c[198610]|0;m=(s|0)!=0?s:c[p>>2]|0;aY(m|0)|0}c[o>>2]=0;iZ(b,b+2476|0);do{if((c[q>>2]|0)!=0){m=b+1832|0;s=b+1768|0;r=b+1836|0;h=b+1800|0;u=0;do{c[s+(u<<2)>>2]=c[m>>2];c[h+(u<<2)>>2]=c[r>>2];u=u+1|0;v=c[q>>2]|0;}while(u>>>0<v>>>0);if((v|0)==0){break}u=b+52|0;h=0;do{c[u+(h*52|0)>>2]=c[e>>2];g[u+(h*52|0)+4>>2]=+((c[m>>2]|0)>>>0>>>0);g[u+(h*52|0)+12>>2]=+((c[m>>2]|0)>>>0>>>0);g[u+(h*52|0)+8>>2]=+((c[r>>2]|0)>>>0>>>0);g[u+(h*52|0)+16>>2]=+((c[r>>2]|0)>>>0>>>0);s=u+(h*52|0)+20|0;X5(s|0,816,32)|0;h=h+1|0;}while(h>>>0<(c[q>>2]|0)>>>0)}}while(0);if((a[b+1710|0]&1)==0){break}q=c[b+1832>>2]|0;e=c[b+1836>>2]|0;i_(j,q,e)|0}}while(0);iu(b,c[b+1832>>2]|0,c[b+1836>>2]|0);j=c[l>>2]|0;if((j|0)!=0){fb[c[j+12>>2]&127](0)}j=b+1728|0;v=b+1732|0;iw(b,c[j>>2]|0,c[v>>2]|0,1);o=c[l>>2]|0;if((o|0)!=0){fb[c[o+12>>2]&127](1)}iw(b,c[j>>2]|0,c[v>>2]|0,1);k=1;i=f;return k|0}function iG(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=c[b+2052>>2]|0;if((d|0)!=0){fb[c[d+4>>2]&127](b)}d=b+4|0;e=c[d>>2]|0;if((e|0)!=0){fz[c[e+4>>2]&8191]()}c[d>>2]=0;d=b+48|0;be(c[d>>2]|0,b+12|0);e=b+2572|0;if((c[e>>2]|0)!=0){be(1,e|0)}e=b+2500|0;if((c[e>>2]|0)!=0){be(1,e|0)}e=b+544|0;XZ(c[e>>2]|0);XZ(c[b+556>>2]|0);XZ(c[b+560>>2]|0);XZ(c[b+572>>2]|0);XZ(c[b+584>>2]|0);XZ(c[b+576>>2]|0);XZ(c[b+600>>2]|0);X2(e|0,0,64);e=b+1640|0;if((a[e]&1)!=0){f=b+1636|0;be(c[f>>2]|0,b+676|0);g=b+612|0;b5(c[f>>2]|0,g|0);a[e]=0;c[f>>2]=0;X2(g|0,0,128)}g=b+1708|0;if((a[g]&1)!=0){b5(c[d>>2]|0,b+1644|0)}if((a[b+1709|0]&1)==0){a[g]=0;h=b;i=c[h>>2]|0;j=i+4|0;k=c[j>>2]|0;fz[k&8191]();l=b+472|0;m=l;n=c[m>>2]|0;XZ(n);o=b+476|0;p=o;q=c[p>>2]|0;XZ(q);XZ(b);return}bL(c[d>>2]|0,b+1676|0);a[g]=0;h=b;i=c[h>>2]|0;j=i+4|0;k=c[j>>2]|0;fz[k&8191]();l=b+472|0;m=l;n=c[m>>2]|0;XZ(n);o=b+476|0;p=o;q=c[p>>2]|0;XZ(q);XZ(b);return}function iH(){var b=0,d=0,e=0;b=i;i=i+24|0;d=b|0;e=d;c[e>>2]=c[2394];c[e+4>>2]=c[2395];c[e+8>>2]=c[2396];c[e+12>>2]=c[2397];c[e+16>>2]=c[2398];a[d+9|0]=a[535088]&1;a[d+10|0]=0;a[d+11|0]=a[535096]&1;c[d+12>>2]=2;a[d+8|0]=1;if((c[133777]|0)==7){c[d>>2]=c[198598];c[d+4>>2]=c[198599]}e=ix(d,0,0)|0;c[199308]=e;c[199354]=9616;c[e+2052>>2]=i1(e,547409,+g[137877])|0?9600:0;i=b;return}function iI(){var b=0,d=0,e=0;b=i;i=i+24|0;d=b|0;e=c[199308]|0;if((e|0)==0){i=b;return}c[199308]=0;iG(e);e=d;c[e>>2]=c[2394];c[e+4>>2]=c[2395];c[e+8>>2]=c[2396];c[e+12>>2]=c[2397];c[e+16>>2]=c[2398];a[d+9|0]=a[535088]&1;a[d+10|0]=0;a[d+11|0]=a[535096]&1;c[d+12>>2]=2;a[d+8|0]=1;if((c[133777]|0)==7){c[d>>2]=c[198598];c[d+4>>2]=c[198599]}e=ix(d,0,0)|0;c[199308]=e;c[199354]=9616;c[e+2052>>2]=i1(e,547409,+g[137877])|0?9600:0;i=b;return}function iJ(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,h=0.0,j=0.0,k=0.0;d=i;i=i+64|0;e=d|0;f=b*90|0;c[a+1716>>2]=f;b=a+1936|0;X2(b|0,0,48);g[a+1996>>2]=1.0;g[b>>2]=2.0;g[a+1956>>2]=2.0;g[a+1976>>2]=-1.0;g[a+1984>>2]=-1.0;g[a+1988>>2]=-1.0;g[a+1992>>2]=-0.0;h=+(f>>>0>>>0)*3.141592653589793/180.0;j=+T(+h);k=+U(+h);X2(e|0,0,60);g[e+40>>2]=1.0;g[e+60>>2]=1.0;g[e>>2]=j;g[e+20>>2]=j;g[e+16>>2]=-0.0-k;g[e+4>>2]=k;i$(a+1872|0,e,b);i=d;return}function iK(a,b){a=a|0;b=b|0;var d=0,e=0;d=a+1736|0;e=b;c[e>>2]=c[d>>2];c[e+4>>2]=c[d+4>>2];c[e+8>>2]=c[d+8>>2];c[e+12>>2]=c[d+12>>2];c[e+16>>2]=c[d+16>>2];c[e+20>>2]=c[d+20>>2];c[b+16>>2]=c[a+1728>>2];d=a+1732|0;c[b+20>>2]=c[d>>2];a=b+4|0;c[a>>2]=(c[d>>2]|0)-((c[b+12>>2]|0)+(c[a>>2]|0));return}function iL(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=b+1736|0;f=b+1744|0;g=(c[f>>2]|0)*3|0;do{if((g&1|0)==0){if((g&2|0)!=0){h=2;break}h=(g&4^4)+4|0}else{h=1}}while(0);e4(3333,h|0);h=b+1748|0;dN(c[e>>2]|0,c[b+1740>>2]|0,c[f>>2]|0,c[h>>2]|0,6407,5121,d|0);b=ab(c[h>>2]|0,c[f>>2]|0)|0;f=0;h=d;while(1){d=h+2|0;e=a[d]|0;a[d]=a[h]|0;a[h]=e;e=f+1|0;if(e>>>0>b>>>0){break}else{f=e;h=h+3|0}}return 1}function iM(a,b){a=a|0;b=b|0;return fe[c[(c[a>>2]|0)+52>>2]&127](b)|0}function iN(b){b=b|0;a[b+1711|0]=1;return}function iO(b,c,d){b=b|0;c=c|0;d=d|0;a[b+2576|0]=c&1;a[b+2577|0]=d&1;return}function iP(a,b,c,d,e){a=a|0;b=+b;c=+c;d=+d;e=+e;var f=0.0;g[a+2504>>2]=b;g[a+2508>>2]=c;f=b+d;g[a+2512>>2]=f;g[a+2516>>2]=c;g[a+2520>>2]=b;b=c+e;g[a+2524>>2]=b;g[a+2528>>2]=f;g[a+2532>>2]=b;return}function iQ(a,b,c,d,e){a=a|0;b=+b;c=+c;d=+d;e=+e;var f=0.0;f=1.0-c;g[a+2536>>2]=b;g[a+2540>>2]=f;c=b+d;g[a+2544>>2]=c;g[a+2548>>2]=f;g[a+2552>>2]=b;b=f-e;g[a+2556>>2]=b;g[a+2560>>2]=c;g[a+2564>>2]=b;return}function iR(b,c){b=b|0;c=c|0;a[b+2497|0]=c&1;return}function iS(a,b){a=a|0;b=+b;g[a+2568>>2]=b;return}function iT(b,d){b=b|0;d=d|0;var e=0,f=0.0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=i;L9173:do{if((d|0)==4){f=+g[133775];if(f>=0.0){g[4910]=f;break}f=+g[182930];do{if(f>0.0){if((a[535104]&1)==0){break}g[4910]=f;break L9173}}while(0);g[4910]=+((c[182926]|0)>>>0>>>0)/+((c[182927]|0)>>>0>>>0)}else if((d|0)==6){if((a[794444]&1)==0){break}f=+g[182930];if(f>0.0){g[4944]=f;break}else{g[4944]=+((c[182926]|0)>>>0>>>0)/+((c[182927]|0)>>>0>>>0);break}}else if((d|0)==5){h=c[182926]|0;j=c[182927]|0;if((h|0)==0|(j|0)==0){break}k=h>>>0<j>>>0?h:j;if(k>>>0>1){l=1;m=1;while(1){if(((h>>>0)%(l>>>0)|0|0)==0){n=((j>>>0)%(l>>>0)|0|0)==0?l:m}else{n=m}o=l+1|0;if(o>>>0<k>>>0){l=o;m=n}else{p=n;break}}}else{p=1}m=(h>>>0)/(p>>>0)|0;l=(j>>>0)/(p>>>0)|0;bN(19644,64,58224,(k=i,i=i+16|0,c[k>>2]=m,c[k+8>>2]=l,k)|0)|0;i=k;g[4927]=+(m>>>0>>>0)/+(l>>>0>>>0)}}while(0);g[182936]=+g[19368+(d*68|0)>>2];a[b+1714|0]=1;a[b+1711|0]=1;i=e;return}function iU(b,d,e,f,h,i){b=b|0;d=d|0;e=e|0;f=f|0;h=h|0;i=+i;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;j=b+2572|0;k=c[j>>2]|0;if((k|0)==0){bx(1,j|0);aX(3553,c[j>>2]|0);eW(3553,10242,33071);eW(3553,10243,33071);eW(3553,10240,9729);eW(3553,10241,9729)}else{aX(3553,k|0)}g[b+2580>>2]=i;k=ab(e?4:2,f)|0;if((k&2|0)==0){l=(k&4^4)+4|0}else{l=2}e4(3317,l|0);if(e){e=(a[797396]&1)!=0?6408:32993;d2(3553,0,e|0,f|0,h|0,0,e|0,5121,d|0);m=b+44|0;n=m;o=c[n>>2]|0;p=b+12|0;q=p;r=q+(o<<2)|0;s=c[r>>2]|0;aX(3553,s|0);return}else{d2(3553,0,6408,f|0,h|0,0,6408,32819,d|0);m=b+44|0;n=m;o=c[n>>2]|0;p=b+12|0;q=p;r=q+(o<<2)|0;s=c[r>>2]|0;aX(3553,s|0);return}}function iV(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;e=c[a+2052>>2]|0;if((e|0)==0){return}fy[c[e+8>>2]&511](a,b,d);return}function iW(a,b){a=a|0;b=b|0;var d=0;d=c[(c[a>>2]|0)+64>>2]|0;if((d|0)==0){return}fb[d&127](b);return}function iX(b,d){b=b|0;d=d|0;var e=0;a[b+2496|0]=d&1;e=c[(c[b>>2]|0)+64>>2]|0;if((e|0)==0){return}if((a[b+1713|0]&1)==0){return}fb[e&127](d);return}function iY(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var h=0,i=0,j=0;h=b+2500|0;i=c[h>>2]|0;if((i|0)==0){bx(1,h|0);j=c[h>>2]|0}else{j=i}aX(3553,j|0);eW(3553,10242,33071);eW(3553,10243,33071);eW(3553,10240,9729);eW(3553,10241,9729);e4(3317,(e<<2&4^4)+4|0);j=(a[797396]&1)!=0?6408:32993;d2(3553,0,j|0,e|0,f|0,0,j|0,5121,d|0);g[b+2504>>2]=0.0;g[b+2508>>2]=0.0;g[b+2512>>2]=1.0;g[b+2516>>2]=0.0;g[b+2520>>2]=0.0;g[b+2524>>2]=1.0;g[b+2528>>2]=1.0;g[b+2532>>2]=1.0;g[b+2536>>2]=0.0;g[b+2540>>2]=1.0;g[b+2544>>2]=1.0;g[b+2548>>2]=1.0;g[b+2552>>2]=0.0;g[b+2556>>2]=0.0;g[b+2560>>2]=1.0;g[b+2564>>2]=0.0;return 1}function iZ(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;e=i;f=b+1710|0;g=a[f]|0;if((g&1)==0&(c[199720]|0)!=0){h=(fe[c[(c[b>>2]|0)+56>>2]&127](d)|0)&1;j=h;k=a[f]|0}else{j=0;k=g}g=b+2472|0;a[g]=j;j=c[b+2028>>2]|0;f=c[b+2032>>2]|0;h=c[b+2036>>2]|0;do{if((k&1)==0){l=j;m=h;n=f}else{if((c[b+2044>>2]|0)!=4){l=j;m=h;n=f;break}d=b+2584|0;do{if((a[d]&1)==0){o=a1(7939)|0;if((o|0)==0){q=0;break}q=(bu(o|0,88352)|0)!=0}else{q=0}}while(0);if((a[637400]&1)!=0){o=c[198610]|0;r=(o|0)!=0?o:c[p>>2]|0;o=q?96184:91856;ec(r|0,100528,(s=i,i=i+16|0,c[s>>2]=88352,c[s+8>>2]=o,s)|0)|0;i=s;o=c[198610]|0;r=(o|0)!=0?o:c[p>>2]|0;aY(r|0)|0}if(q){l=6408;m=5121;n=6408;break}do{if((a[d]&1)==0){r=a1(7939)|0;if((r|0)==0){t=0;break}t=(bu(r|0,85216)|0)!=0}else{t=0}}while(0);if((a[637400]&1)!=0){d=c[198610]|0;r=(d|0)!=0?d:c[p>>2]|0;d=t?96184:91856;ec(r|0,100528,(s=i,i=i+16|0,c[s>>2]=85216,c[s+8>>2]=d,s)|0)|0;i=s;d=c[198610]|0;r=(d|0)!=0?d:c[p>>2]|0;aY(r|0)|0}if(t){l=6408;m=5121;n=6408;break}r=c[198610]|0;d=(r|0)!=0?r:c[p>>2]|0;a2(81736,76,1,d|0)|0;d=c[198610]|0;r=(d|0)!=0?d:c[p>>2]|0;aY(r|0)|0;l=6407;m=33635;n=6407}}while(0);t=b+48|0;s=b+12|0;q=s;bx(c[t>>2]|0,s|0);if((c[t>>2]|0)==0){u=b+44|0;v=u;w=c[v>>2]|0;x=q+(w<<2)|0;y=c[x>>2]|0;aX(3553,y|0);i=e;return}s=b+2040|0;f=b+468|0;h=b+1832|0;j=b+1836|0;k=b+472|0;r=0;do{aX(3553,c[q+(r<<2)>>2]|0);eW(3553,10242,c[s>>2]|0);eW(3553,10243,c[s>>2]|0);eW(3553,10240,c[f>>2]|0);eW(3553,10241,c[f>>2]|0);if((a[g]&1)==0){d2(3553,0,l|0,c[h>>2]|0,c[j>>2]|0,0,n|0,m|0,c[k>>2]|0)}r=r+1|0;}while(r>>>0<(c[t>>2]|0)>>>0);u=b+44|0;v=u;w=c[v>>2]|0;x=q+(w<<2)|0;y=c[x>>2]|0;aX(3553,y|0);i=e;return}function i_(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0;f=i;i=i+16|0;g=f|0;h=f+8|0;if((a[637400]&1)!=0){j=c[198610]|0;k=(j|0)!=0?j:c[p>>2]|0;ec(k|0,35352,(l=i,i=i+16|0,c[l>>2]=d,c[l+8>>2]=e,l)|0)|0;i=l;k=c[198610]|0;j=(k|0)!=0?k:c[p>>2]|0;aY(j|0)|0}c[g>>2]=0;c[h>>2]=0;dT(3379,g|0);dT(34024,h|0);if((a[637400]&1)!=0){j=c[198610]|0;k=(j|0)!=0?j:c[p>>2]|0;j=c[g>>2]|0;g=c[h>>2]|0;ec(k|0,30720,(l=i,i=i+16|0,c[l>>2]=j,c[l+8>>2]=g,l)|0)|0;i=l;g=c[198610]|0;j=(g|0)!=0?g:c[p>>2]|0;aY(j|0)|0}aX(3553,0);j=b+48|0;dO(c[j>>2]|0,b+1644|0);g=(a[736428]&1)==0;k=(a[736429]&1)!=0;do{if(k){do{if((a[b+2584|0]&1)==0){h=a1(7939)|0;if((h|0)==0){m=0;break}m=(bu(h|0,26944)|0)!=0}else{m=0}}while(0);if((a[637400]&1)!=0){h=c[198610]|0;n=(h|0)!=0?h:c[p>>2]|0;h=m?96184:91856;ec(n|0,100528,(l=i,i=i+16|0,c[l>>2]=26944,c[l+8>>2]=h,l)|0)|0;i=l;h=c[198610]|0;n=(h|0)!=0?h:c[p>>2]|0;aY(n|0)|0}if(m){break}else{o=0}i=f;return o|0}}while(0);L9283:do{if(g){if(k){m=0;while(1){if(m>>>0>=(c[j>>2]|0)>>>0){q=6676;break L9283}b$(36160,c[b+1644+(m<<2)>>2]|0);dt(36160,36064,3553,c[b+12+(m<<2)>>2]|0,0);n=cl(36160)|0;if((n|0)==36053){m=m+1|0}else{r=m;s=n;q=6675;break}}}else{m=0;while(1){if(m>>>0>=(c[j>>2]|0)>>>0){q=6676;break L9283}b$(36160,c[b+1644+(m<<2)>>2]|0);dt(36160,36064,3553,c[b+12+(m<<2)>>2]|0,0);n=cl(36160)|0;if((n|0)==36053){m=m+1|0}else{r=m;s=n;q=6675;break}}}}else{cV(c[j>>2]|0,b+1676|0);a[b+1709|0]=1;if(k){m=0;while(1){if(m>>>0>=(c[j>>2]|0)>>>0){q=6676;break L9283}b$(36160,c[b+1644+(m<<2)>>2]|0);dt(36160,36064,3553,c[b+12+(m<<2)>>2]|0,0);n=b+1676+(m<<2)|0;c3(36161,c[n>>2]|0);cf(36161,35056,d|0,e|0);c3(36161,0);dP(36160,36096,36161,c[n>>2]|0);dP(36160,36128,36161,c[n>>2]|0);n=cl(36160)|0;if((n|0)==36053){m=m+1|0}else{r=m;s=n;q=6675;break}}}else{m=0;while(1){if(m>>>0>=(c[j>>2]|0)>>>0){q=6676;break L9283}b$(36160,c[b+1644+(m<<2)>>2]|0);dt(36160,36064,3553,c[b+12+(m<<2)>>2]|0,0);n=b+1676+(m<<2)|0;c3(36161,c[n>>2]|0);cf(36161,33189,d|0,e|0);c3(36161,0);dP(36160,36096,36161,c[n>>2]|0);n=cl(36160)|0;if((n|0)==36053){m=m+1|0}else{r=m;s=n;q=6675;break}}}}}while(0);if((q|0)==6676){b$(36160,0);a[b+1708|0]=1;o=1;i=f;return o|0}else if((q|0)==6675){q=c[198610]|0;ec(((q|0)!=0?q:c[p>>2]|0)|0,22752,(l=i,i=i+16|0,c[l>>2]=r,c[l+8>>2]=s,l)|0)|0;i=l;l=c[198610]|0;aY(((l|0)!=0?l:c[p>>2]|0)|0)|0;o=0;i=f;return o|0}return 0}function i$(a,b,c){a=a|0;b=b|0;c=c|0;var d=0,e=0,f=0.0,h=0.0,j=0.0,k=0.0,l=0.0,m=0.0,n=0.0,o=0.0,p=0.0,q=0.0,r=0.0,s=0.0,t=0.0,u=0.0,v=0.0,w=0.0,x=0.0,y=0,z=0.0,A=0,B=0.0,C=0,D=0.0;d=i;i=i+64|0;e=d|0;f=+g[c>>2];h=+g[c+4>>2];j=+g[c+8>>2];k=+g[c+12>>2];l=+g[c+16>>2];m=+g[c+20>>2];n=+g[c+24>>2];o=+g[c+28>>2];p=+g[c+32>>2];q=+g[c+36>>2];r=+g[c+40>>2];s=+g[c+44>>2];t=+g[c+48>>2];u=+g[c+52>>2];v=+g[c+56>>2];w=+g[c+60>>2];c=0;do{x=+g[b+(c<<2)>>2];y=c+4|0;z=+g[b+(y<<2)>>2];A=c+8|0;B=+g[b+(A<<2)>>2];C=c+12|0;D=+g[b+(C<<2)>>2];g[e+(c<<2)>>2]=x*f+0.0+z*h+B*j+D*k;g[e+(y<<2)>>2]=x*l+0.0+z*m+B*n+D*o;g[e+(A<<2)>>2]=x*p+0.0+z*q+B*r+D*s;g[e+(C<<2)>>2]=x*t+0.0+z*u+B*v+D*w;c=c+1|0;}while(c>>>0<4);c=a;a=e;X5(c|0,a|0,64)|0;i=d;return}function i0(a){a=a|0;var b=0;b=c[a+2048>>2]|0;if((b|0)==0){return}fb[c[(c[a+2056>>2]|0)+12>>2]&127](b);be(1,a+2060|0);b=c[a+2076>>2]|0;if((b|0)==0){return}XZ(b);return}function i1(b,d,e){b=b|0;d=d|0;e=+e;var f=0,h=0,j=0,k=0,l=0,m=0,n=0.0,o=0.0,q=0.0,r=0.0,s=0.0,t=0.0,u=0.0,v=0.0,w=0.0,x=0.0,y=0.0;d=i;if((a[551512]&1)==0){f=0;i=d;return f|0}h=b+2056|0;j=b+2048|0;k=h4((a[547409]|0)!=0?547409:798256,+g[137877])|0;c[j>>2]=k;if((k|0)==0){k=c[198610]|0;l=(k|0)!=0?k:c[p>>2]|0;ec(l|0,94776,(m=i,i=i+8|0,c[m>>2]=85776,m)|0)|0;i=m;l=c[198610]|0;k=(l|0)!=0?l:c[p>>2]|0;aY(k|0)|0;c[h>>2]=0;c[j>>2]=0;j=c[198610]|0;k=(j|0)!=0?j:c[p>>2]|0;a2(93656,49,1,k|0)|0;k=c[198610]|0;j=(k|0)!=0?k:c[p>>2]|0;aY(j|0)|0;f=0;i=d;return f|0}if((a[637400]&1)!=0){j=c[198610]|0;k=(j|0)!=0?j:c[p>>2]|0;ec(k|0,85880,(m=i,i=i+8|0,c[m>>2]=85776,m)|0)|0;i=m;m=c[198610]|0;k=(m|0)!=0?m:c[p>>2]|0;aY(k|0)|0}c[h>>2]=17368;h=b+2060|0;bx(1,h|0);aX(3553,c[h>>2]|0);eW(3553,10242,33071);eW(3553,10243,33071);eW(3553,10240,9729);eW(3553,10241,9729);aX(3553,c[b+12+(c[b+44>>2]<<2)>>2]|0);dT(3379,b+2064|0);e=+g[137881];g[b+2344>>2]=e;n=+g[137882];g[b+2348>>2]=n;o=+g[137883];g[b+2352>>2]=o;g[b+2356>>2]=1.0;q=+g[137881];g[b+2360>>2]=q;r=+g[137882];g[b+2364>>2]=r;s=+g[137883];g[b+2368>>2]=s;g[b+2372>>2]=1.0;t=+g[137881];g[b+2376>>2]=t;u=+g[137882];g[b+2380>>2]=u;v=+g[137883];g[b+2384>>2]=v;g[b+2388>>2]=1.0;w=+g[137881];g[b+2392>>2]=w;x=+g[137882];g[b+2396>>2]=x;y=+g[137883];g[b+2400>>2]=y;g[b+2404>>2]=1.0;g[b+2408>>2]=e*.3;g[b+2412>>2]=n*.3;g[b+2416>>2]=o*.3;g[b+2420>>2]=1.0;g[b+2424>>2]=q*.3;g[b+2428>>2]=r*.3;g[b+2432>>2]=s*.3;g[b+2436>>2]=1.0;g[b+2440>>2]=t*.3;g[b+2444>>2]=u*.3;g[b+2448>>2]=v*.3;g[b+2452>>2]=1.0;g[b+2456>>2]=w*.3;g[b+2460>>2]=x*.3;g[b+2464>>2]=y*.3;g[b+2468>>2]=1.0;f=1;i=d;return f|0}function i2(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,h=0,j=0,k=0,l=0,m=0,n=0.0,o=0.0,p=0.0,q=0.0,r=0.0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ac=0,ad=0,ae=0.0,af=0.0,ag=0.0,ah=0.0;f=i;i=i+168|0;h=f|0;j=f+64|0;k=f+96|0;l=f+128|0;m=f+160|0;do{if((e|0)==0){n=+g[137879];o=+g[137880];if((a[551513]&1)==0){p=n;q=o;r=1.0;break}p=n;q=o;r=+((c[b+1744>>2]|0)>>>0>>>0)/+((c[b+1720>>2]|0)>>>0>>>0)}else{p=+g[e>>2];q=+g[e+4>>2];r=+g[e+8>>2]}}while(0);e=b+2048|0;if((c[e>>2]|0)==0){i=f;return}s=b+4|0;t=c[s>>2]|0;if((t|0)!=0){fb[c[t+12>>2]&127](15)}iw(b,c[b+1728>>2]|0,c[b+1732>>2]|0,0);ek(3042);aX(3553,c[b+2060>>2]|0);t=l|0;u=b+2e3|0;v=u;w=b+2008|0;c[w>>2]=t;x=b+2080|0;if((cL(x|0,d|0)|0)==0){y=c[b+2336>>2]|0;z=c[b+2340>>2]|0;A=b+2068|0;B=b+2072|0}else{C=b+2056|0;fy[c[(c[C>>2]|0)+4>>2]&511](c[e>>2]|0,d,m);D=c[m>>2]|0;E=c[D+24>>2]|0;F=(c[D+4>>2]|0)+E|0;G=c[D+28>>2]|0;H=(c[D+8>>2]|0)+G|0;I=c[D+48>>2]|0;if((I|0)==0){J=H;K=G;L=F;M=E}else{N=H;H=G;G=F;F=E;E=I;while(1){I=c[E+24>>2]|0;O=(c[E+4>>2]|0)+I|0;P=c[E+28>>2]|0;Q=(c[E+8>>2]|0)+P|0;R=(I|0)<(F|0)?I:F;I=(O|0)>(G|0)?O:G;O=(P|0)<(H|0)?P:H;P=(Q|0)>(N|0)?Q:N;Q=c[E+48>>2]|0;if((Q|0)==0){J=P;K=O;L=I;M=R;break}else{N=P;H=O;G=I;F=R;E=Q}}}E=L-M|0;L=J-K|0;J=E-1|0;F=J>>>1|J;J=F>>>2|F;F=J>>>4|J;J=F>>>8|F;F=(J>>>16|J)+1|0;J=L-1|0;G=J>>>1|J;J=G>>>2|G;G=J>>>4|J;J=G>>>8|G;G=(J>>>16|J)+1|0;J=c[b+2064>>2]|0;H=(F|0)>(J|0)?J:F;F=(G|0)>(J|0)?J:G;G=b+2068|0;J=c[G>>2]|0;N=b+2072|0;do{if((H|0)>(J|0)){S=6715}else{Q=c[N>>2]|0;if((F|0)>(Q|0)){S=6715;break}V=J;W=Q;X=b+2076|0}}while(0);if((S|0)==6715){J=b+2076|0;Q=c[J>>2]|0;c[J>>2]=X_(Q,ab(H<<2,F)|0)|0;d2(3553,0,6408,H|0,F|0,0,6408,5121,0);c[G>>2]=H;c[N>>2]=F;V=H;W=F;X=J}J=c[X>>2]|0;X2(J|0,0,ab(W<<2,V)|0);if((D|0)!=0){V=D;do{D=c[X>>2]|0;W=c[G>>2]|0;J=c[N>>2]|0;F=(c[V+24>>2]|0)-M|0;H=c[V+8>>2]|0;Q=J-H+(K-(c[V+28>>2]|0))|0;R=Q-1|0;I=c[V>>2]|0;O=(F|0)<0;P=(c[V+4>>2]|0)+(O?F:0)|0;Y=(R|0)<0;Z=(Y?R:0)+H|0;if(O){_=I+(-F|0)|0;$=0}else{_=I;$=F}if(Y){aa=_+(ab(c[V+12>>2]|0,1-Q|0)|0)|0;ac=0}else{aa=_;ac=R}R=($+P|0)>(W|0)?W-$|0:P;P=(ac+Z|0)>(J|0)?J-ac|0:Z;do{if((P|0)>0){Z=V+12|0;if((R|0)<=0){break}J=aa;Q=D+((ab(ac,W)|0)+$<<2)|0;Y=0;while(1){F=Q;I=0;while(1){a[F]=-1;a[F+1|0]=-1;a[F+2|0]=-1;a[F+3|0]=a[J+I|0]|0;O=I+1|0;if((O|0)<(R|0)){F=F+4|0;I=O}else{break}}I=Y+1|0;if((I|0)<(P|0)){J=J+(c[Z>>2]|0)|0;Q=Q+(W<<2)|0;Y=I}else{break}}}}while(0);V=c[V+48>>2]|0;}while((V|0)!=0)}e4(3317,8);d4(3553,0,0,0,c[G>>2]|0,c[N>>2]|0,6408,5121,c[X>>2]|0);fc[c[(c[C>>2]|0)+8>>2]&127](c[e>>2]|0,m);m=256;e=x;x=d;while(1){d=m-1|0;if((d|0)==0){S=6731;break}C=a[x]|0;a[e]=C;if(C<<24>>24==0){break}else{m=d;e=e+1|0;x=x+1|0}}do{if((S|0)==6731){a[e]=0;if((a[x]|0)==0){break}else{ad=x}do{ad=ad+1|0;}while((a[ad]|0)!=0)}}while(0);c[b+2336>>2]=E;c[b+2340>>2]=L;y=E;z=L;A=G;B=N}N=j|0;G=k|0;o=+(y|0);n=+((c[b+1744>>2]|0)>>>0>>>0);ae=p+r*o/n;af=+(z|0);ag=+((c[b+1748>>2]|0)>>>0>>>0);ah=q+r*af/ag;g[N>>2]=p;g[j+8>>2]=ae;g[j+16>>2]=p;g[j+24>>2]=ae;g[j+4>>2]=ah;g[j+12>>2]=ah;g[j+20>>2]=q;g[j+28>>2]=q;r=2.0/n;n=2.0/ag;ag=p-r;g[G>>2]=ag;p=ah-n;g[k+4>>2]=p;ah=ae-r;g[k+8>>2]=ah;g[k+12>>2]=p;g[k+16>>2]=ag;ag=q-n;g[k+20>>2]=ag;g[k+24>>2]=ah;g[k+28>>2]=ag;ag=o/+(c[A>>2]|0);o=1.0-af/+(c[B>>2]|0);g[t>>2]=0.0;g[l+8>>2]=ag;g[l+16>>2]=0.0;g[l+24>>2]=ag;g[l+4>>2]=o;g[l+12>>2]=o;g[l+20>>2]=1.0;g[l+28>>2]=1.0;l=u;c[l>>2]=G;G=b+2004|0;c[G>>2]=b+2408;u=b+1872|0;t=c[s>>2]|0;do{if((t|0)!=0){B=c[t+32>>2]|0;fe[B&127](v)|0;B=c[s>>2]|0;if((B|0)==0){break}A=c[B+36>>2]|0;fe[A&127](u)|0}}while(0);c7(5,0,4);c[l>>2]=N;c[G>>2]=b+2344;N=c[s>>2]|0;do{if((N|0)!=0){t=c[N+32>>2]|0;fe[t&127](v)|0;t=c[s>>2]|0;if((t|0)==0){break}A=c[t+36>>2]|0;fe[A&127](u)|0}}while(0);c7(5,0,4);c[l>>2]=c[b+2016>>2];c[w>>2]=b+1840;c[G>>2]=c[b+2020>>2];aX(3553,c[b+12+(c[b+44>>2]<<2)>>2]|0);dc(3042);G=b+1936|0;X2(G|0,0,48);g[b+1996>>2]=1.0;g[G>>2]=2.0;g[b+1956>>2]=2.0;g[b+1976>>2]=-1.0;g[b+1984>>2]=-1.0;g[b+1988>>2]=-1.0;g[b+1992>>2]=-0.0;o=+((c[b+1716>>2]|0)>>>0>>>0)*3.141592653589793/180.0;ag=+T(+o);af=+U(+o);X2(h|0,0,60);g[h+40>>2]=1.0;g[h+60>>2]=1.0;g[h>>2]=ag;g[h+20>>2]=ag;g[h+16>>2]=-0.0-af;g[h+4>>2]=af;i$(u,h,G);i=f;return}function i3(a){a=a|0;return}function i4(a,b){a=a|0;b=b|0;return}function i5(){return}function i6(a){a=a|0;return 0}function i7(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;return 0}function i8(b,c,d){b=b|0;c=c|0;d=d|0;var e=0;if(a[10888]|0){e=0}else{a[10888]=1;e=1}return e|0}function i9(a,b){a=a|0;b=b|0;c[a>>2]=c[159346];c[b>>2]=c[159348];return}function ja(){return a[10888]|0}function jb(a,b){a=a|0;b=b|0;return+(+(a>>>0>>>0)/+(b>>>0>>>0))}function jc(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;b=i;i=i+24|0;d=b|0;e=b+8|0;f=b+16|0;if((a[637400]&1)!=0){g=c[198610]|0;h=(g|0)!=0?g:c[p>>2]|0;a2(65736,45,1,h|0)|0;h=c[198610]|0;g=(h|0)!=0?h:c[p>>2]|0;aY(g|0)|0}if(a[10888]|0){if((a[637400]&1)==0){j=1;i=b;return j|0}g=c[198610]|0;h=(g|0)!=0?g:c[p>>2]|0;a2(55528,64,1,h|0)|0;h=c[198610]|0;g=(h|0)!=0?h:c[p>>2]|0;aY(g|0)|0;j=1;i=b;return j|0}g=e$(0)|0;c[198882]=g;do{if((g|0)!=0){do{if((cA(g|0,0,0)|0)!=0){if((ef(c[198882]|0,9744,795544,1,f|0)|0)==0){break}h=a9(c[198882]|0,c[198886]|0,0,9728)|0;c[198884]=h;if((h|0)==0){break}h=eb(c[198882]|0,c[198886]|0,0,0)|0;c[198880]=h;if((h|0)==0){break}if((dw(c[198882]|0,h|0,h|0,c[198884]|0)|0)==0){break}h=c[198882]|0;k=c[198880]|0;e3(h|0,k|0,12375,d|0)|0;k=c[198882]|0;h=c[198880]|0;e3(k|0,h|0,12374,e|0)|0;h=c[d>>2]|0;c[159346]=h;k=c[e>>2]|0;c[159348]=k;if((a[637400]&1)==0){j=1;i=b;return j|0}l=c[198610]|0;m=(l|0)!=0?l:c[p>>2]|0;ec(m|0,46352,(m=i,i=i+16|0,c[m>>2]=h,c[m+8>>2]=k,m)|0)|0;i=m;m=c[198610]|0;k=(m|0)!=0?m:c[p>>2]|0;aY(k|0)|0;j=1;i=b;return j|0}}while(0);k=c[198882]|0;if((k|0)==0){break}dw(k|0,0,0,0)|0;k=c[198884]|0;if((k|0)!=0){m=c[198882]|0;dj(m|0,k|0)|0}k=c[198880]|0;if((k|0)!=0){m=c[198882]|0;aU(m|0,k|0)|0}k=c[198882]|0;b6(k|0)|0}}while(0);c[198884]=0;c[198880]=0;c[198882]=0;c[198886]=0;a[10888]=0;j=0;i=b;return j|0}function jd(){var b=0,d=0;b=c[198882]|0;if((b|0)!=0){dw(b|0,0,0,0)|0;b=c[198884]|0;if((b|0)!=0){d=c[198882]|0;dj(d|0,b|0)|0}b=c[198880]|0;if((b|0)!=0){d=c[198882]|0;aU(d|0,b|0)|0}b=c[198882]|0;b6(b|0)|0}c[198884]=0;c[198880]=0;c[198882]=0;c[198886]=0;a[10888]=0;return}function je(a,b,c){a=a|0;b=b|0;c=c|0;var d=0;if((a|0)==1){d=(bf(12448)|0)!=0}else{d=0}return d|0}function jf(){var b=0,d=0,e=0.0,f=0,g=0,j=0,k=0,l=0,m=0;b=i;i=i+128|0;d=b|0;a[d]=0;e=+a8()*1.0e3;f=~~e>>>0;g=+Q(e)>=1.0?e>0.0?(ag(+P(e/4294967296.0),4294967295.0)|0)>>>0:~~+aa((e- +(~~e>>>0))/4294967296.0)>>>0:0;do{if((c[198551]|0)==0){c[133746]=f;c[133747]=g;c[133744]=f;c[133745]=g;bN(d|0,128,60088,(j=i,i=i+8|0,c[j>>2]=794208,j)|0)|0;i=j}else{k=785752;l=c[k>>2]|0;m=Ye(l,c[k+4>>2]|0,1,0)|0;k=785752;c[k>>2]=m;c[k+4>>2]=F;k=Yf(f,g,c[133746]|0,c[133747]|0)|0;m=769368+((l&2047)<<3)|0;c[m>>2]=k;c[m+4>>2]=F;c[133746]=f;c[133747]=g;m=c[198551]|0;if((m&255|0)==0){k=Yf(f,g,c[133744]|0,c[133745]|0)|0;c[133744]=f;c[133745]=g;e=256.0e6/(+(k>>>0)+ +(F|0)*4294967296.0);bN(d|0,128,25976,(j=i,i=i+24|0,c[j>>2]=794208,h[j+8>>3]=e,c[j+16>>2]=m,j)|0)|0;i=j;break}else{i=b;return}}}while(0);if((a[637400]&1)==0){i=b;return}g=c[198610]|0;ec(((g|0)!=0?g:c[p>>2]|0)|0,93640,(j=i,i=i+8|0,c[j>>2]=d,j)|0)|0;i=j;j=c[198610]|0;aY(((j|0)!=0?j:c[p>>2]|0)|0)|0;i=b;return}function jg(b,d,e,f,g){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0;g=i;i=i+24|0;h=g|0;j=g+8|0;cu(h|0,j|0,g+16|0);k=c[h>>2]|0;c[e>>2]=k;h=c[j>>2]|0;c[f>>2]=h;a[d]=(c[e>>2]|0)==(c[159346]|0)&(h|0)==(c[159348]|0)&1^1;c[159346]=k;c[159348]=h;a[b]=0;i=g;return}function jh(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0;c[a>>2]=0;d=XY(48)|0;if((d|0)==0){return}if((c[d-4>>2]&3|0)!=0){X2(d|0,0,48)}e=bm()|0;c[d+44>>2]=e;if((e|0)==0){XZ(d);return}X2(236048,0,1292);e=6024;f=276;while(1){c[236048+(f<<2)>>2]=c[e>>2];g=c[e+12>>2]|0;if((g|0)==0){break}else{e=e+8|0;f=g}}c[a>>2]=7808;c[b>>2]=d;return}function ji(a){a=a|0;return ca(a|0)|0}function jj(d){d=d|0;var e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aW=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0,cf=0,ch=0,ci=0,cj=0,ck=0,cl=0,cm=0,cn=0,co=0,cp=0,cq=0,cr=0,cs=0,ct=0,cu=0,cv=0,cw=0,cx=0,cy=0,cz=0,cA=0,cB=0,cC=0,cD=0,cE=0,cF=0,cG=0,cH=0,cI=0,cJ=0,cK=0,cM=0,cN=0,cO=0,cP=0,cQ=0,cR=0,cS=0,cT=0,cU=0,cV=0,cW=0,cX=0.0,cY=0.0,cZ=0,c_=0,c0=0,c1=0,c2=0,c3=0,c4=0,c5=0,c6=0,c7=0,c8=0,c9=0,da=0,db=0,dc=0,dd=0,de=0,df=0,dg=0,dh=0;e=i;i=i+848|0;f=e|0;j=e+64|0;k=e+128|0;l=e+192|0;m=e+256|0;n=e+320|0;o=e+384|0;q=e+448|0;r=e+512|0;s=e+576|0;t=e+640|0;u=e+704|0;v=e+768|0;w=e+832|0;x=XY(109528)|0;if((x|0)==0){c[131708]=0;y=0;i=e;return y|0}if((c[x-4>>2]&3|0)!=0){X2(x|0,0,109528)}z=x;c[131708]=z;L9487:do{if((d|0)==0){A=c[198610]|0;B=(A|0)!=0?A:c[p>>2]|0;a2(55456,59,1,B|0)|0;B=c[198610]|0;A=(B|0)!=0?B:c[p>>2]|0;aY(A|0)|0;c[(c[131708]|0)+72>>2]=1;A=dq(((a[526864]&1)!=0?38672:39248)|0)|0;c[(c[131708]|0)+4172>>2]=A;A=dq(((a[526864]&1)!=0?40144:40784)|0)|0;B=c[131708]|0;c[B+4176>>2]=A;a[B+4|0]=1}else{B=cg(d|0,46)|0;A=(B|0)==0?798256:B+1|0;if((cL(A|0,75176)|0)==0){B=4096;C=x+76|0;D=d;while(1){E=B-1|0;if((E|0)==0){F=6824;break}G=a[D]|0;a[C]=G;if(G<<24>>24==0){break}else{B=E;C=C+1|0;D=D+1|0}}do{if((F|0)==6824){a[C]=0;if((a[D]|0)==0){break}else{H=D}do{H=H+1|0;}while((a[H]|0)!=0)}}while(0);c[x+72>>2]=1;a[x+4|0]=1;break}do{if((cL(A|0,93544)|0)==0){D=gH(d,0)|0;if((D|0)==0){break}C=h_(D,c[131708]|0)|0;a[(c[131708]|0)+4|0]=1;gF(D);if(C){break L9487}}else{C=v|0;if((a[637400]&1)!=0){D=c[198610]|0;B=(D|0)!=0?D:c[p>>2]|0;ec(B|0,46792,(I=i,i=i+8|0,c[I>>2]=d,I)|0)|0;i=I;B=c[198610]|0;D=(B|0)!=0?B:c[p>>2]|0;aY(D|0)|0}D=hr(d)|0;B=(D|0)!=0;L9508:do{if(B){E=D|0;G=c[E>>2]|0;if((G|0)==0){break}else{J=G}L9510:while(1){do{if((c[J+20>>2]|0)==0){if((cL(c[J>>2]|0,35576)|0)!=0){break}K=J+8|0;G=K;while(1){L=c[G>>2]|0;if((L|0)==0){F=6845;break}if((cL(30984,c[L>>2]|0)|0)==0){F=6840;break}else{G=L+8|0}}L9518:do{if((F|0)==6840){F=0;G=c[L+4>>2]|0;if((G|0)==0){F=6845;break}else{M=64;N=C;O=G}while(1){G=M-1|0;if((G|0)==0){break}P=a[O]|0;a[N]=P;if(P<<24>>24==0){break L9518}else{M=G;N=N+1|0;O=O+1|0}}a[N]=0;if((a[O]|0)==0){break}else{Q=O}do{Q=Q+1|0;}while((a[Q]|0)!=0)}}while(0);if((F|0)==6845){F=0;a[C]=0}if((cL(C|0,27056)|0)==0){break L9510}}}while(0);G=c[J+16>>2]|0;if((G|0)==0){break L9508}else{J=G}}c[x>>2]=2;G=K;while(1){R=c[G>>2]|0;if((R|0)==0){F=6855;break}if((cL(22928,c[R>>2]|0)|0)==0){F=6850;break}else{G=R+8|0}}L9534:do{if((F|0)==6850){G=c[R+4>>2]|0;if((G|0)==0){F=6855;break}else{S=64;T=C;U=G}while(1){G=S-1|0;if((G|0)==0){break}P=a[U]|0;a[T]=P;if(P<<24>>24==0){break L9534}else{S=G;T=T+1|0;U=U+1|0}}a[T]=0;if((a[U]|0)==0){break}else{V=U}do{V=V+1|0;}while((a[V]|0)!=0)}}while(0);if((F|0)==6855){a[C]=0}G=x+4|0;a[G]=(cL(C|0,100656)|0)==0|0;P=x+5|0;W=K;while(1){X=c[W>>2]|0;if((X|0)==0){F=6860;break}if((cL(96352,c[X>>2]|0)|0)==0){F=6859;break}else{W=X+8|0}}do{if((F|0)==6859){W=c[X+4>>2]|0;if((W|0)==0){F=6860;break}else{Y=64;Z=0;_=P;$=W}while(1){W=Y-1|0;if((W|0)==0){F=6863;break}aa=a[$]|0;a[_]=aa;if(aa<<24>>24==0){ab=Z;break}else{Y=W;Z=Z+1|0;_=_+1|0;$=$+1|0}}do{if((F|0)==6863){a[_]=0;if((a[$]|0)==0){ab=Z;break}else{ac=$;ad=Z}while(1){W=ac+1|0;aa=ad+1|0;if((a[W]|0)==0){ab=aa;break}else{ac=W;ad=aa}}}}while(0);if(ab>>>0>=64){break}if((a[637400]&1)==0){break}aa=c[198610]|0;ec(((aa|0)!=0?aa:c[p>>2]|0)|0,91968,(I=i,i=i+8|0,c[I>>2]=P,I)|0)|0;i=I;aa=c[198610]|0;aY(((aa|0)!=0?aa:c[p>>2]|0)|0)|0}}while(0);if((F|0)==6860){a[P]=0}do{if((a[G]&1)==0){aa=c[198610]|0;W=(aa|0)!=0?aa:c[p>>2]|0;a2(85328,57,1,W|0)|0;W=c[198610]|0;aa=(W|0)!=0?W:c[p>>2]|0;aY(aa|0)|0}else{if((a[637400]&1)==0){break}aa=c[198610]|0;W=(aa|0)!=0?aa:c[p>>2]|0;a2(88480,54,1,W|0)|0;W=c[198610]|0;aa=(W|0)!=0?W:c[p>>2]|0;aY(aa|0)|0}}while(0);P=c[J+12>>2]|0;aa=x+72|0;L9568:do{if((P|0)==0){F=7193}else{W=f|0;ae=j|0;af=k|0;ag=l|0;ah=m|0;ai=n|0;aj=o|0;ak=q|0;al=r|0;am=s|0;an=t|0;ao=u|0;ap=x+66444|0;aq=x+99792|0;ar=x+109012|0;as=x+109016|0;at=P;L9570:while(1){if((c[aa>>2]|0)>>>0>=16){break L9568}do{if((c[at+20>>2]|0)==0){au=at+4|0;av=c[au>>2]|0;if((av|0)==0){break}aw=dq(av|0)|0;if((aw|0)==0){break}av=c[aa>>2]|0;ax=c[at>>2]|0;if((cL(ax|0,81976)|0)==0){ay=z+76+(av*4148|0)+4096|0;if((c[ay>>2]|0)!=0){F=6881;break L9570}az=h0(aw,d,at)|0;if((az|0)==0){F=6883;break L9570}c[ay>>2]=az;break}if((cL(ax|0,69936)|0)!=0){if((cL(ax|0,64984)|0)==0){XZ(aw);az=c[ap>>2]|0;if(az>>>0>7){ay=c[198610]|0;aA=(ay|0)!=0?ay:c[p>>2]|0;a2(25192,58,1,aA|0)|0;aA=c[198610]|0;ay=(aA|0)!=0?aA:c[p>>2]|0;aY(ay|0)|0;break}ay=z+66448+(az*4168|0)|0;aA=at+8|0;aB=aA;while(1){aC=c[aB>>2]|0;if((aC|0)==0){F=7050;break}if((cL(29296,c[aC>>2]|0)|0)==0){F=7045;break}else{aB=aC+8|0}}L9592:do{if((F|0)==7045){F=0;aB=c[aC+4>>2]|0;if((aB|0)==0){F=7050;break}else{aD=64;aE=ay;aF=aB}while(1){aB=aD-1|0;if((aB|0)==0){break}aG=a[aF]|0;a[aE]=aG;if(aG<<24>>24==0){break L9592}else{aD=aB;aE=aE+1|0;aF=aF+1|0}}a[aE]=0;if((a[aF]|0)==0){break}else{aH=aF}do{aH=aH+1|0;}while((a[aH]|0)!=0)}}while(0);if((F|0)==7050){F=0;a[ay]=0}aB=z+66448+(az*4168|0)+64|0;aG=aA;while(1){aI=c[aG>>2]|0;if((aI|0)==0){F=7059;break}if((cL(24912,c[aI>>2]|0)|0)==0){F=7054;break}else{aG=aI+8|0}}L9606:do{if((F|0)==7054){F=0;aG=c[aI+4>>2]|0;if((aG|0)==0){F=7059;break}else{aJ=4096;aK=aB;aL=aG}while(1){aG=aJ-1|0;if((aG|0)==0){break}aM=a[aL]|0;a[aK]=aM;if(aM<<24>>24==0){break L9606}else{aJ=aG;aK=aK+1|0;aL=aL+1|0}}a[aK]=0;if((a[aL]|0)==0){break}else{aN=aL}do{aN=aN+1|0;}while((a[aN]|0)!=0)}}while(0);if((F|0)==7059){F=0;a[aB]=0}X2(W|0,0,64);aG=aA;while(1){aO=c[aG>>2]|0;if((aO|0)==0){F=7068;break}if((cL(24584,c[aO>>2]|0)|0)==0){F=7063;break}else{aG=aO+8|0}}L9620:do{if((F|0)==7063){F=0;aG=c[aO+4>>2]|0;if((aG|0)==0){F=7068;break}else{aP=64;aQ=W;aR=aG}while(1){aG=aP-1|0;if((aG|0)==0){break}aA=a[aR]|0;a[aQ]=aA;if(aA<<24>>24==0){break L9620}else{aP=aG;aQ=aQ+1|0;aR=aR+1|0}}a[aQ]=0;if((a[aR]|0)==0){break}else{aS=aR}do{aS=aS+1|0;}while((a[aS]|0)!=0)}}while(0);if((F|0)==7068){F=0;a[W]=0}if((a[ay]|0)==0){F=7070;break L9570}if((a[aB]|0)==0){F=7072;break L9570}do{if((cL(W|0,23424)|0)==0){c[z+66448+(az*4168|0)+4160>>2]=1}else{if((cL(W|0,23024)|0)==0){c[z+66448+(az*4168|0)+4160>>2]=2;break}if((a[W]|0)!=0){F=7079;break L9570}c[z+66448+(az*4168|0)+4160>>2]=0}}while(0);c[ap>>2]=(c[ap>>2]|0)+1;break}if((cL(ax|0,62064)|0)!=0){if((cL(ax|0,60096)|0)!=0){break}XZ(aw);if((c[ar>>2]|0)!=0){F=7166;break L9570}az=at+8|0;aB=az;while(1){aT=c[aB>>2]|0;if((aT|0)==0){F=7175;break}if((cL(31096,c[aT>>2]|0)|0)==0){F=7170;break}else{aB=aT+8|0}}L9649:do{if((F|0)==7170){F=0;aB=c[aT+4>>2]|0;if((aB|0)==0){F=7175;break}else{aU=512;aW=as;aZ=aB}while(1){aB=aU-1|0;if((aB|0)==0){break}ax=a[aZ]|0;a[aW]=ax;if(ax<<24>>24==0){a_=az;break L9649}else{aU=aB;aW=aW+1|0;aZ=aZ+1|0}}a[aW]=0;if((a[aZ]|0)==0){a_=az;break}else{a$=aZ}while(1){aB=a$+1|0;if((a[aB]|0)==0){a_=az;break}else{a$=aB}}}}while(0);if((F|0)==7175){F=0;a[as]=0;a_=az}while(1){a0=c[a_>>2]|0;if((a0|0)==0){F=7183;break}if((cL(30984,c[a0>>2]|0)|0)==0){F=7178;break}else{a_=a0+8|0}}L9662:do{if((F|0)==7178){F=0;az=c[a0+4>>2]|0;if((az|0)==0){F=7183;break}else{a1=64;a3=W;a4=az}while(1){az=a1-1|0;if((az|0)==0){break}aB=a[a4]|0;a[a3]=aB;if(aB<<24>>24==0){break L9662}else{a1=az;a3=a3+1|0;a4=a4+1|0}}a[a3]=0;if((a[a4]|0)==0){break}else{a5=a4}do{a5=a5+1|0;}while((a[a5]|0)!=0)}}while(0);if((F|0)==7183){F=0;a[W]=0}if((cL(W|0,37952)|0)!=0){F=7185;break L9570}az=c[au>>2]|0;if((az|0)==0){F=7187;break L9570}aB=dq(az|0)|0;c[ar>>2]=aB;if((aB|0)==0){F=7191;break L9570}az=h0(aB,d,at)|0;c[ar>>2]=az;if((az|0)==0){F=7190;break L9570}else{break}}XZ(aw);az=c[aq>>2]|0;if(az>>>0>63){F=7084;break L9570}aB=z+99796+(az*80|0)|0;ax=at+8|0;ay=ax;while(1){a6=c[ay>>2]|0;if((a6|0)==0){F=7093;break}if((cL(29296,c[a6>>2]|0)|0)==0){F=7088;break}else{ay=a6+8|0}}L9681:do{if((F|0)==7088){F=0;ay=c[a6+4>>2]|0;if((ay|0)==0){F=7093;break}else{a7=64;a8=aB;a9=ay}while(1){ay=a7-1|0;if((ay|0)==0){break}au=a[a9]|0;a[a8]=au;if(au<<24>>24==0){ba=ax;break L9681}else{a7=ay;a8=a8+1|0;a9=a9+1|0}}a[a8]=0;if((a[a9]|0)==0){ba=ax;break}else{bb=a9}while(1){ay=bb+1|0;if((a[ay]|0)==0){ba=ax;break}else{bb=ay}}}}while(0);if((F|0)==7093){F=0;a[aB]=0;ba=ax}while(1){bc=c[ba>>2]|0;if((bc|0)==0){F=7101;break}if((cL(28984,c[bc>>2]|0)|0)==0){F=7096;break}else{ba=bc+8|0}}L9694:do{if((F|0)==7096){F=0;ay=c[bc+4>>2]|0;if((ay|0)==0){F=7101;break}else{bd=64;be=W;bf=ay}while(1){ay=bd-1|0;if((ay|0)==0){break}au=a[bf]|0;a[be]=au;if(au<<24>>24==0){bg=ax;break L9694}else{bd=ay;be=be+1|0;bf=bf+1|0}}a[be]=0;if((a[bf]|0)==0){bg=ax;break}else{bh=bf}while(1){ay=bh+1|0;if((a[ay]|0)==0){bg=ax;break}else{bh=ay}}}}while(0);if((F|0)==7101){F=0;a[W]=0;bg=ax}while(1){bi=c[bg>>2]|0;if((bi|0)==0){F=7109;break}if((cL(28664,c[bi>>2]|0)|0)==0){F=7104;break}else{bg=bi+8|0}}L9707:do{if((F|0)==7104){F=0;ay=c[bi+4>>2]|0;if((ay|0)==0){F=7109;break}else{bj=64;bk=ae;bl=ay}while(1){ay=bj-1|0;if((ay|0)==0){break}au=a[bl]|0;a[bk]=au;if(au<<24>>24==0){bm=ax;break L9707}else{bj=ay;bk=bk+1|0;bl=bl+1|0}}a[bk]=0;if((a[bl]|0)==0){bm=ax;break}else{bn=bl}while(1){ay=bn+1|0;if((a[ay]|0)==0){bm=ax;break}else{bn=ay}}}}while(0);if((F|0)==7109){F=0;a[ae]=0;bm=ax}while(1){bo=c[bm>>2]|0;if((bo|0)==0){F=7117;break}if((cL(28376,c[bo>>2]|0)|0)==0){F=7112;break}else{bm=bo+8|0}}L9720:do{if((F|0)==7112){F=0;ay=c[bo+4>>2]|0;if((ay|0)==0){F=7117;break}else{bp=64;bq=af;br=ay}while(1){ay=bp-1|0;if((ay|0)==0){break}au=a[br]|0;a[bq]=au;if(au<<24>>24==0){bs=ax;break L9720}else{bp=ay;bq=bq+1|0;br=br+1|0}}a[bq]=0;if((a[br]|0)==0){bs=ax;break}else{bt=br}while(1){ay=bt+1|0;if((a[ay]|0)==0){bs=ax;break}else{bt=ay}}}}while(0);if((F|0)==7117){F=0;a[af]=0;bs=ax}while(1){bu=c[bs>>2]|0;if((bu|0)==0){F=7125;break}if((cL(28008,c[bu>>2]|0)|0)==0){F=7120;break}else{bs=bu+8|0}}L9733:do{if((F|0)==7120){F=0;ay=c[bu+4>>2]|0;if((ay|0)==0){F=7125;break}else{bv=64;bw=ag;by=ay}while(1){ay=bv-1|0;if((ay|0)==0){break}au=a[by]|0;a[bw]=au;if(au<<24>>24==0){bz=ax;break L9733}else{bv=ay;bw=bw+1|0;by=by+1|0}}a[bw]=0;if((a[by]|0)==0){bz=ax;break}else{bA=by}while(1){ay=bA+1|0;if((a[ay]|0)==0){bz=ax;break}else{bA=ay}}}}while(0);if((F|0)==7125){F=0;a[ag]=0;bz=ax}while(1){bB=c[bz>>2]|0;if((bB|0)==0){F=7133;break}if((cL(27608,c[bB>>2]|0)|0)==0){F=7128;break}else{bz=bB+8|0}}L9746:do{if((F|0)==7128){F=0;ax=c[bB+4>>2]|0;if((ax|0)==0){F=7133;break}else{bC=64;bD=ah;bE=ax}while(1){ax=bC-1|0;if((ax|0)==0){break}ay=a[bE]|0;a[bD]=ay;if(ay<<24>>24==0){break L9746}else{bC=ax;bD=bD+1|0;bE=bE+1|0}}a[bD]=0;if((a[bE]|0)==0){break}else{bF=bE}do{bF=bF+1|0;}while((a[bF]|0)!=0)}}while(0);if((F|0)==7133){F=0;a[ah]=0}if((a[W]|0)==0){F=7136;break L9570}if((a[aB]|0)==0){F=7136;break L9570}do{if((cL(W|0,41056)|0)==0){c[z+99796+(az*80|0)+68>>2]=0;F=7150}else{if((cL(W|0,38888)|0)==0){c[z+99796+(az*80|0)+68>>2]=1;F=7150;break}if((cL(W|0,40360)|0)==0){c[z+99796+(az*80|0)+68>>2]=2;F=7150;break}if((cL(W|0,39488)|0)==0){c[z+99796+(az*80|0)+68>>2]=3;F=7150;break}if((cL(W|0,38264)|0)==0){c[z+99796+(az*80|0)+68>>2]=4;F=7150;break}if((cL(W|0,37952)|0)!=0){F=7148;break L9570}c[z+99796+(az*80|0)+68>>2]=5}}while(0);do{if((F|0)==7150){F=0;if((a[af]|0)==0){if((a[ae]|0)==0){F=7157;break L9570}c[z+99796+(az*80|0)+64>>2]=aV(ae|0,0,16)|0;c[z+99796+(az*80|0)+72>>2]=1;break}aB=aV(af|0,0,0)|0;if((aB|0)==1){c[z+99796+(az*80|0)+72>>2]=2;break}else if((aB|0)==2){c[z+99796+(az*80|0)+72>>2]=3;break}else{F=7154;break L9570}}}while(0);if((a[ag]|0)!=0){b[z+99796+(az*80|0)+76>>1]=(aV(ag|0,0,16)|0)&65535}if((a[ah]|0)!=0){b[z+99796+(az*80|0)+78>>1]=(aV(ah|0,0,16)|0)&65535}c[aq>>2]=(c[aq>>2]|0)+1;break}if((a[G]&1)!=0){if((c[z+76+(av*4148|0)+4096>>2]|0)==0){F=6888;break L9570}}aB=h0(aw,d,at)|0;if((aB|0)==0){F=6890;break L9570}c[z+76+(av*4148|0)+4100>>2]=aB;aB=z+76+(av*4148|0)+4144|0;c[aB>>2]=0;ax=z+76+(av*4148|0)+4136|0;c[ax>>2]=0;ay=z+76+(av*4148|0)+4132|0;a[ay]=0;au=z+76+(av*4148|0)+4116|0;g[au>>2]=1.0;aG=z+76+(av*4148|0)+4120|0;g[aG>>2]=1.0;aA=z+76+(av*4148|0)+4112|0;c[aA>>2]=0;aM=z+76+(av*4148|0)+4108|0;c[aM>>2]=0;bG=z+76+(av*4148|0)+4104|0;a[bG]=0;bH=at+8|0;bI=bH;while(1){bJ=c[bI>>2]|0;if((bJ|0)==0){F=6895;break}if((cL(24584,c[bJ>>2]|0)|0)==0){F=6894;break}else{bI=bJ+8|0}}do{if((F|0)==6894){F=0;bI=c[bJ+4>>2]|0;if((bI|0)==0){F=6895;break}else{bK=64;bL=0;bM=W;bN=bI}while(1){bI=bK-1|0;if((bI|0)==0){F=6898;break}az=a[bN]|0;a[bM]=az;if(az<<24>>24==0){bO=bL;break}else{bK=bI;bL=bL+1|0;bM=bM+1|0;bN=bN+1|0}}do{if((F|0)==6898){F=0;a[bM]=0;if((a[bN]|0)==0){bO=bL;break}else{bP=bN;bQ=bL}while(1){bI=bP+1|0;az=bQ+1|0;if((a[bI]|0)==0){bO=az;break}else{bP=bI;bQ=az}}}}while(0);if(bO>>>0>=64){bR=bH;F=6908;break}if((cL(W|0,23024)|0)==0){c[ax>>2]=2;if((a[637400]&1)==0){bR=bH;F=6908;break}az=c[198610]|0;bI=(az|0)!=0?az:c[p>>2]|0;a2(22008,42,1,bI|0)|0;bI=c[198610]|0;az=(bI|0)!=0?bI:c[p>>2]|0;aY(az|0)|0;bR=bH;F=6908;break}if((cL(W|0,23424)|0)!=0){az=c[198610]|0;bI=(az|0)!=0?az:c[p>>2]|0;a2(21312,54,1,bI|0)|0;bI=c[198610]|0;az=(bI|0)!=0?bI:c[p>>2]|0;aY(az|0)|0;bS=0;break}c[ax>>2]=1;if((a[637400]&1)==0){bR=bH;F=6908;break}az=c[198610]|0;a2(21664,41,1,((az|0)!=0?az:c[p>>2]|0)|0)|0;az=c[198610]|0;aY(((az|0)!=0?az:c[p>>2]|0)|0)|0;bR=bH;F=6908}}while(0);if((F|0)==6895){F=0;a[W]=0;bR=bH;F=6908}do{if((F|0)==6908){while(1){F=0;bT=c[bR>>2]|0;if((bT|0)==0){F=6915;break}if((cL(21048,c[bT>>2]|0)|0)==0){F=6910;break}else{bR=bT+8|0;F=6908}}L9824:do{if((F|0)==6910){F=0;ax=c[bT+4>>2]|0;if((ax|0)==0){F=6915;break}else{bU=64;bV=ae;bW=ax}while(1){ax=bU-1|0;if((ax|0)==0){break}az=a[bW]|0;a[bV]=az;if(az<<24>>24==0){bX=bH;break L9824}else{bU=ax;bV=bV+1|0;bW=bW+1|0}}a[bV]=0;if((a[bW]|0)==0){bX=bH;break}else{bY=bW}while(1){ax=bY+1|0;if((a[ax]|0)==0){bX=bH;break}else{bY=ax}}}}while(0);if((F|0)==6915){F=0;a[ae]=0;bX=bH}while(1){bZ=c[bX>>2]|0;if((bZ|0)==0){F=6923;break}if((cL(20736,c[bZ>>2]|0)|0)==0){F=6918;break}else{bX=bZ+8|0}}L9837:do{if((F|0)==6918){F=0;ax=c[bZ+4>>2]|0;if((ax|0)==0){F=6923;break}else{b_=64;b$=af;b0=ax}while(1){ax=b_-1|0;if((ax|0)==0){break}az=a[b0]|0;a[b$]=az;if(az<<24>>24==0){b1=bH;break L9837}else{b_=ax;b$=b$+1|0;b0=b0+1|0}}a[b$]=0;if((a[b0]|0)==0){b1=bH;break}else{b2=b0}while(1){ax=b2+1|0;if((a[ax]|0)==0){b1=bH;break}else{b2=ax}}}}while(0);if((F|0)==6923){F=0;a[af]=0;b1=bH}while(1){b3=c[b1>>2]|0;if((b3|0)==0){F=6931;break}if((cL(20432,c[b3>>2]|0)|0)==0){F=6926;break}else{b1=b3+8|0}}L9850:do{if((F|0)==6926){F=0;ax=c[b3+4>>2]|0;if((ax|0)==0){F=6931;break}else{b4=64;b5=ag;b6=ax}while(1){ax=b4-1|0;if((ax|0)==0){break}az=a[b6]|0;a[b5]=az;if(az<<24>>24==0){b7=bH;break L9850}else{b4=ax;b5=b5+1|0;b6=b6+1|0}}a[b5]=0;if((a[b6]|0)==0){b7=bH;break}else{b8=b6}while(1){ax=b8+1|0;if((a[ax]|0)==0){b7=bH;break}else{b8=ax}}}}while(0);if((F|0)==6931){F=0;a[ag]=0;b7=bH}while(1){b9=c[b7>>2]|0;if((b9|0)==0){F=6939;break}if((cL(20104,c[b9>>2]|0)|0)==0){F=6934;break}else{b7=b9+8|0}}L9863:do{if((F|0)==6934){F=0;ax=c[b9+4>>2]|0;if((ax|0)==0){F=6939;break}else{ca=64;cb=ah;cc=ax}while(1){ax=ca-1|0;if((ax|0)==0){break}az=a[cc]|0;a[cb]=az;if(az<<24>>24==0){cd=bH;break L9863}else{ca=ax;cb=cb+1|0;cc=cc+1|0}}a[cb]=0;if((a[cc]|0)==0){cd=bH;break}else{ce=cc}while(1){ax=ce+1|0;if((a[ax]|0)==0){cd=bH;break}else{ce=ax}}}}while(0);if((F|0)==6939){F=0;a[ah]=0;cd=bH}while(1){cf=c[cd>>2]|0;if((cf|0)==0){F=6947;break}if((cL(101168,c[cf>>2]|0)|0)==0){F=6942;break}else{cd=cf+8|0}}L9876:do{if((F|0)==6942){F=0;ax=c[cf+4>>2]|0;if((ax|0)==0){F=6947;break}else{ch=64;ci=ai;cj=ax}while(1){ax=ch-1|0;if((ax|0)==0){break}az=a[cj]|0;a[ci]=az;if(az<<24>>24==0){ck=bH;break L9876}else{ch=ax;ci=ci+1|0;cj=cj+1|0}}a[ci]=0;if((a[cj]|0)==0){ck=bH;break}else{cl=cj}while(1){ax=cl+1|0;if((a[ax]|0)==0){ck=bH;break}else{cl=ax}}}}while(0);if((F|0)==6947){F=0;a[ai]=0;ck=bH}while(1){cm=c[ck>>2]|0;if((cm|0)==0){F=6955;break}if((cL(100768,c[cm>>2]|0)|0)==0){F=6950;break}else{ck=cm+8|0}}L9889:do{if((F|0)==6950){F=0;ax=c[cm+4>>2]|0;if((ax|0)==0){F=6955;break}else{cn=64;co=aj;cp=ax}while(1){ax=cn-1|0;if((ax|0)==0){break}az=a[cp]|0;a[co]=az;if(az<<24>>24==0){cq=bH;break L9889}else{cn=ax;co=co+1|0;cp=cp+1|0}}a[co]=0;if((a[cp]|0)==0){cq=bH;break}else{cr=cp}while(1){ax=cr+1|0;if((a[ax]|0)==0){cq=bH;break}else{cr=ax}}}}while(0);if((F|0)==6955){F=0;a[aj]=0;cq=bH}while(1){cs=c[cq>>2]|0;if((cs|0)==0){F=6963;break}if((cL(100040,c[cs>>2]|0)|0)==0){F=6958;break}else{cq=cs+8|0}}L9902:do{if((F|0)==6958){F=0;ax=c[cs+4>>2]|0;if((ax|0)==0){F=6963;break}else{ct=64;cu=ak;cv=ax}while(1){ax=ct-1|0;if((ax|0)==0){break}az=a[cv]|0;a[cu]=az;if(az<<24>>24==0){cw=bH;break L9902}else{ct=ax;cu=cu+1|0;cv=cv+1|0}}a[cu]=0;if((a[cv]|0)==0){cw=bH;break}else{cx=cv}while(1){ax=cx+1|0;if((a[ax]|0)==0){cw=bH;break}else{cx=ax}}}}while(0);if((F|0)==6963){F=0;a[ak]=0;cw=bH}while(1){cy=c[cw>>2]|0;if((cy|0)==0){F=6971;break}if((cL(99640,c[cy>>2]|0)|0)==0){F=6966;break}else{cw=cy+8|0}}L9915:do{if((F|0)==6966){F=0;ax=c[cy+4>>2]|0;if((ax|0)==0){F=6971;break}else{cz=64;cA=al;cB=ax}while(1){ax=cz-1|0;if((ax|0)==0){break}az=a[cB]|0;a[cA]=az;if(az<<24>>24==0){cC=bH;break L9915}else{cz=ax;cA=cA+1|0;cB=cB+1|0}}a[cA]=0;if((a[cB]|0)==0){cC=bH;break}else{cD=cB}while(1){ax=cD+1|0;if((a[ax]|0)==0){cC=bH;break}else{cD=ax}}}}while(0);if((F|0)==6971){F=0;a[al]=0;cC=bH}while(1){cE=c[cC>>2]|0;if((cE|0)==0){F=6979;break}if((cL(99272,c[cE>>2]|0)|0)==0){F=6974;break}else{cC=cE+8|0}}L9928:do{if((F|0)==6974){F=0;ax=c[cE+4>>2]|0;if((ax|0)==0){F=6979;break}else{cF=64;cG=am;cH=ax}while(1){ax=cF-1|0;if((ax|0)==0){break}az=a[cH]|0;a[cG]=az;if(az<<24>>24==0){cI=bH;break L9928}else{cF=ax;cG=cG+1|0;cH=cH+1|0}}a[cG]=0;if((a[cH]|0)==0){cI=bH;break}else{cJ=cH}while(1){ax=cJ+1|0;if((a[ax]|0)==0){cI=bH;break}else{cJ=ax}}}}while(0);if((F|0)==6979){F=0;a[am]=0;cI=bH}while(1){cK=c[cI>>2]|0;if((cK|0)==0){F=6987;break}if((cL(98904,c[cK>>2]|0)|0)==0){F=6982;break}else{cI=cK+8|0}}L9941:do{if((F|0)==6982){F=0;ax=c[cK+4>>2]|0;if((ax|0)==0){F=6987;break}else{cM=64;cN=an;cO=ax}while(1){ax=cM-1|0;if((ax|0)==0){break}az=a[cO]|0;a[cN]=az;if(az<<24>>24==0){cP=bH;break L9941}else{cM=ax;cN=cN+1|0;cO=cO+1|0}}a[cN]=0;if((a[cO]|0)==0){cP=bH;break}else{cQ=cO}while(1){ax=cQ+1|0;if((a[ax]|0)==0){cP=bH;break}else{cQ=ax}}}}while(0);if((F|0)==6987){F=0;a[an]=0;cP=bH}while(1){cR=c[cP>>2]|0;if((cR|0)==0){F=6995;break}if((cL(98528,c[cR>>2]|0)|0)==0){F=6990;break}else{cP=cR+8|0}}L9954:do{if((F|0)==6990){F=0;ax=c[cR+4>>2]|0;if((ax|0)==0){F=6995;break}else{cS=64;cT=ao;cU=ax}while(1){ax=cS-1|0;if((ax|0)==0){break}az=a[cU]|0;a[cT]=az;if(az<<24>>24==0){break L9954}else{cS=ax;cT=cT+1|0;cU=cU+1|0}}a[cT]=0;if((a[cU]|0)==0){break}else{cV=cU}do{cV=cV+1|0;}while((a[cV]|0)!=0)}}while(0);if((F|0)==6995){F=0;a[ao]=0}a[ay]=(cL(ao|0,98168)|0)==0|0;do{if((a[an]|0)!=0){ax=aV(an|0,0,0)|0;c[aB>>2]=ax;if((a[637400]&1)==0){break}az=c[198610]|0;bI=(az|0)!=0?az:c[p>>2]|0;ec(bI|0,97648,(I=i,i=i+8|0,c[I>>2]=ax,I)|0)|0;i=I;ax=c[198610]|0;bI=(ax|0)!=0?ax:c[p>>2]|0;aY(bI|0)|0}}while(0);do{if((a[ae]|0)==0){cW=0}else{cX=+X0(ae);g[au>>2]=cX;g[aG>>2]=cX;a[bG]=1;if((a[637400]&1)==0){cW=1;break}bI=c[198610]|0;ax=(bI|0)!=0?bI:c[p>>2]|0;cY=cX;ec(ax|0,97192,(I=i,i=i+8|0,h[I>>3]=cY,I)|0)|0;i=I;ax=c[198610]|0;bI=(ax|0)!=0?ax:c[p>>2]|0;aY(bI|0)|0;cW=1}}while(0);if((a[af]|0)==0){cZ=cW}else{cY=+X0(af);g[au>>2]=cY;a[bG]=1;if((a[637400]&1)!=0){bI=c[198610]|0;ax=(bI|0)!=0?bI:c[p>>2]|0;cX=cY;ec(ax|0,96808,(I=i,i=i+8|0,h[I>>3]=cX,I)|0)|0;i=I;ax=c[198610]|0;bI=(ax|0)!=0?ax:c[p>>2]|0;aY(bI|0)|0}cZ=cW+1|0}if((a[ag]|0)==0){c_=cW}else{cX=+X0(ag);g[aG>>2]=cX;a[bG]=1;if((a[637400]&1)!=0){bI=c[198610]|0;ax=(bI|0)!=0?bI:c[p>>2]|0;cY=cX;ec(ax|0,96416,(I=i,i=i+8|0,h[I>>3]=cY,I)|0)|0;i=I;ax=c[198610]|0;bI=(ax|0)!=0?ax:c[p>>2]|0;aY(bI|0)|0}c_=cW+1|0}if((a[ah]|0)==0){c0=cZ;c1=c_}else{bI=aV(ah|0,0,0)|0;c[z+76+(av*4148|0)+4128>>2]=bI;c[z+76+(av*4148|0)+4124>>2]=bI;a[bG]=1;c[aA>>2]=1;c[aM>>2]=1;if((a[637400]&1)!=0){ax=c[198610]|0;az=(ax|0)!=0?ax:c[p>>2]|0;ec(az|0,95704,(I=i,i=i+8|0,c[I>>2]=bI,I)|0)|0;i=I;bI=c[198610]|0;az=(bI|0)!=0?bI:c[p>>2]|0;aY(az|0)|0}c0=cZ+1|0;c1=c_+1|0}if((a[ai]|0)==0){c2=c0}else{az=aV(ai|0,0,0)|0;c[z+76+(av*4148|0)+4124>>2]=az;a[bG]=1;c[aM>>2]=1;if((a[637400]&1)!=0){bI=c[198610]|0;ax=(bI|0)!=0?bI:c[p>>2]|0;ec(ax|0,95192,(I=i,i=i+8|0,c[I>>2]=az,I)|0)|0;i=I;az=c[198610]|0;ax=(az|0)!=0?az:c[p>>2]|0;aY(ax|0)|0}c2=c0+1|0}if((a[aj]|0)==0){c3=c1}else{ax=aV(aj|0,0,0)|0;c[z+76+(av*4148|0)+4128>>2]=ax;a[bG]=1;c[aA>>2]=1;if((a[637400]&1)!=0){az=c[198610]|0;bI=(az|0)!=0?az:c[p>>2]|0;ec(bI|0,94696,(I=i,i=i+8|0,c[I>>2]=ax,I)|0)|0;i=I;ax=c[198610]|0;bI=(ax|0)!=0?ax:c[p>>2]|0;aY(bI|0)|0}c3=c1+1|0}if((a[ak]|0)==0){c4=c2;c5=c3}else{cY=+X0(ak);g[aG>>2]=cY;g[au>>2]=cY;a[bG]=1;c[aA>>2]=2;c[aM>>2]=2;if((a[637400]&1)!=0){bI=c[198610]|0;ax=(bI|0)!=0?bI:c[p>>2]|0;cX=cY;ec(ax|0,94352,(I=i,i=i+8|0,h[I>>3]=cX,I)|0)|0;i=I;ax=c[198610]|0;bI=(ax|0)!=0?ax:c[p>>2]|0;aY(bI|0)|0}c4=c2+1|0;c5=c3+1|0}if((a[al]|0)==0){c6=c4}else{cX=+X0(al);g[au>>2]=cX;a[bG]=1;c[aM>>2]=2;if((a[637400]&1)!=0){bI=c[198610]|0;ax=(bI|0)!=0?bI:c[p>>2]|0;cY=cX;ec(ax|0,94056,(I=i,i=i+8|0,h[I>>3]=cY,I)|0)|0;i=I;ax=c[198610]|0;bI=(ax|0)!=0?ax:c[p>>2]|0;aY(bI|0)|0}c6=c4+1|0}if((a[am]|0)==0){c7=c5}else{cY=+X0(am);g[aG>>2]=cY;a[bG]=1;c[aA>>2]=2;if((a[637400]&1)!=0){bI=c[198610]|0;ax=(bI|0)!=0?bI:c[p>>2]|0;cX=cY;ec(ax|0,93560,(I=i,i=i+8|0,h[I>>3]=cX,I)|0)|0;i=I;ax=c[198610]|0;bI=(ax|0)!=0?ax:c[p>>2]|0;aY(bI|0)|0}c7=c5+1|0}if(c6>>>0>1){bS=0;break}bS=c7>>>0<2}}while(0);if(!bS){F=7037;break L9570}c[aa>>2]=(c[aa>>2]|0)+1}}while(0);aA=c[at+16>>2]|0;if((aA|0)==0){F=7193;break L9568}else{at=aA}}if((F|0)==7185){at=c[198610]|0;am=(at|0)!=0?at:c[p>>2]|0;a2(30440,52,1,am|0)|0;am=c[198610]|0;at=(am|0)!=0?am:c[p>>2]|0;aY(at|0)|0;F=7191}else if((F|0)==7136){at=c[198610]|0;a2(27200,57,1,((at|0)!=0?at:c[p>>2]|0)|0)|0;at=c[198610]|0;aY(((at|0)!=0?at:c[p>>2]|0)|0)|0;F=7163}else if((F|0)==6883){at=c[198610]|0;a2(72248,74,1,((at|0)!=0?at:c[p>>2]|0)|0)|0;at=c[198610]|0;aY(((at|0)!=0?at:c[p>>2]|0)|0)|0;break L9508}else if((F|0)==7166){at=c[198610]|0;a2(31512,46,1,((at|0)!=0?at:c[p>>2]|0)|0)|0;at=c[198610]|0;aY(((at|0)!=0?at:c[p>>2]|0)|0)|0;F=7191}else if((F|0)==7187){c[ar>>2]=0;F=7191}else if((F|0)==7190){at=c[198610]|0;a2(30056,48,1,((at|0)!=0?at:c[p>>2]|0)|0)|0;at=c[198610]|0;aY(((at|0)!=0?at:c[p>>2]|0)|0)|0;F=7191}else if((F|0)==6881){at=c[198610]|0;a2(78480,75,1,((at|0)!=0?at:c[p>>2]|0)|0)|0;at=c[198610]|0;aY(((at|0)!=0?at:c[p>>2]|0)|0)|0;XZ(aw);break L9508}else if((F|0)==7148){at=c[198610]|0;a2(26464,56,1,((at|0)!=0?at:c[p>>2]|0)|0)|0;at=c[198610]|0;aY(((at|0)!=0?at:c[p>>2]|0)|0)|0;F=7163}else if((F|0)==7154){at=c[198610]|0;a2(26056,52,1,((at|0)!=0?at:c[p>>2]|0)|0)|0;at=c[198610]|0;aY(((at|0)!=0?at:c[p>>2]|0)|0)|0;F=7163}else if((F|0)==6888){at=c[198610]|0;a2(68680,98,1,((at|0)!=0?at:c[p>>2]|0)|0)|0;at=c[198610]|0;aY(((at|0)!=0?at:c[p>>2]|0)|0)|0;XZ(aw);break L9508}else if((F|0)==7157){at=c[198610]|0;a2(25544,65,1,((at|0)!=0?at:c[p>>2]|0)|0)|0;at=c[198610]|0;aY(((at|0)!=0?at:c[p>>2]|0)|0)|0;F=7163}else if((F|0)==7070){at=c[198610]|0;a2(24264,51,1,((at|0)!=0?at:c[p>>2]|0)|0)|0;at=c[198610]|0;aY(((at|0)!=0?at:c[p>>2]|0)|0)|0;F=7081}else if((F|0)==7072){at=c[198610]|0;a2(23776,57,1,((at|0)!=0?at:c[p>>2]|0)|0)|0;at=c[198610]|0;aY(((at|0)!=0?at:c[p>>2]|0)|0)|0;F=7081}else if((F|0)==6890){at=c[198610]|0;a2(72248,74,1,((at|0)!=0?at:c[p>>2]|0)|0)|0;at=c[198610]|0;aY(((at|0)!=0?at:c[p>>2]|0)|0)|0;break L9508}else if((F|0)==7037){at=c[198610]|0;a2(67064,78,1,((at|0)!=0?at:c[p>>2]|0)|0)|0;at=c[198610]|0;aY(((at|0)!=0?at:c[p>>2]|0)|0)|0;break L9508}else if((F|0)==7079){at=c[198610]|0;a2(22368,46,1,((at|0)!=0?at:c[p>>2]|0)|0)|0;at=c[198610]|0;aY(((at|0)!=0?at:c[p>>2]|0)|0)|0;F=7081}else if((F|0)==7084){at=c[198610]|0;a2(29680,51,1,((at|0)!=0?at:c[p>>2]|0)|0)|0;at=c[198610]|0;aY(((at|0)!=0?at:c[p>>2]|0)|0)|0;F=7163}if((F|0)==7163){at=c[198610]|0;am=(at|0)!=0?at:c[p>>2]|0;a2(61144,46,1,am|0)|0;am=c[198610]|0;at=(am|0)!=0?am:c[p>>2]|0;aY(at|0)|0;break L9508}else if((F|0)==7191){at=c[198610]|0;a2(59080,40,1,((at|0)!=0?at:c[p>>2]|0)|0)|0;at=c[198610]|0;aY(((at|0)!=0?at:c[p>>2]|0)|0)|0;break L9508}else if((F|0)==7081){at=c[198610]|0;a2(63448,51,1,((at|0)!=0?at:c[p>>2]|0)|0)|0;at=c[198610]|0;aY(((at|0)!=0?at:c[p>>2]|0)|0)|0;break L9508}}}while(0);do{if((F|0)==7193){if((c[aa>>2]|0)!=0){break}G=c[198610]|0;P=(G|0)!=0?G:c[p>>2]|0;a2(58440,82,1,P|0)|0;P=c[198610]|0;G=(P|0)!=0?P:c[p>>2]|0;aY(G|0)|0;break L9508}}while(0);aa=c[E>>2]|0;if((aa|0)!=0){ht(aa)}XZ(D);break L9487}else{aa=c[198610]|0;ec(((aa|0)!=0?aa:c[p>>2]|0)|0,40040,(I=i,i=i+8|0,c[I>>2]=d,I)|0)|0;i=I;aa=c[198610]|0;aY(((aa|0)!=0?aa:c[p>>2]|0)|0)|0}}while(0);C=c[198610]|0;aa=(C|0)!=0?C:c[p>>2]|0;a2(57752,51,1,aa|0)|0;aa=c[198610]|0;C=(aa|0)!=0?aa:c[p>>2]|0;aY(C|0)|0;if(!B){break}C=c[D>>2]|0;if((C|0)!=0){ht(C)}XZ(D)}}while(0);A=c[198610]|0;C=(A|0)!=0?A:c[p>>2]|0;a2(65656,56,1,C|0)|0;C=c[198610]|0;A=(C|0)!=0?C:c[p>>2]|0;aY(A|0)|0;y=0;i=e;return y|0}}while(0);h2(c[131708]|0,d);d=(a[526864]&1)==0;L10063:do{if((a[(c[131708]|0)+4|0]&1)==0){aw=c[198610]|0;bS=(aw|0)!=0?aw:c[p>>2]|0;a2(46256,90,1,bS|0)|0;bS=c[198610]|0;aw=(bS|0)!=0?bS:c[p>>2]|0;aY(aw|0)|0}else{aw=jv(d?39248:38672,d?40784:40144,0)|0;c[133568]=aw;if((aw|0)==0){aw=c[198610]|0;bS=(aw|0)!=0?aw:c[p>>2]|0;a2(39768,60,1,bS|0)|0;bS=c[198610]|0;aw=(bS|0)!=0?bS:c[p>>2]|0;aY(aw|0)|0;break}else{c8=0}while(1){c9=c[131708]|0;if(c8>>>0>=(c[c9+72>>2]|0)>>>0){F=7217;break}da=c9+76+(c8*4148|0)|0;aw=c9+76+(c8*4148|0)+4096|0;if((a[da]|0)==0){db=c[aw>>2]|0;dc=c[c9+76+(c8*4148|0)+4100>>2]|0}else{if((gg(da,aw)|0)<1){F=7214;break}bS=dq(c[aw>>2]|0)|0;c[c9+76+(c8*4148|0)+4100>>2]=bS;if((bS|0)==0){F=7214;break}c7=c[aw>>2]|0;if((c7|0)==0){F=7214;break}else{db=c7;dc=bS}}a[da]=0;bS=jv(db,dc,c8)|0;c7=c8+1|0;c[534272+(c7<<2)>>2]=bS;if((bS|0)==0){F=7216;break}else{c8=c7}}if((F|0)==7214){c7=c[198610]|0;bS=(c7|0)!=0?c7:c[p>>2]|0;ec(bS|0,54224,(I=i,i=i+8|0,c[I>>2]=da,I)|0)|0;i=I;bS=c[198610]|0;c7=(bS|0)!=0?bS:c[p>>2]|0;aY(c7|0)|0;break}else if((F|0)==7216){c7=c[198610]|0;ec(((c7|0)!=0?c7:c[p>>2]|0)|0,53328,(I=i,i=i+8|0,c[I>>2]=c8,I)|0)|0;i=I;c7=c[198610]|0;aY(((c7|0)!=0?c7:c[p>>2]|0)|0)|0;break}else if((F|0)==7217){c7=w;L10081:do{if((c[c9+66444>>2]|0)==0){dd=0}else{bx(1,534232);bS=c[131708]|0;if((c[bS+66444>>2]|0)==0){dd=0;break}aw=w|0;c6=w+4|0;c5=w+8|0;c4=0;c3=bS;while(1){if((a[637400]&1)==0){de=c3}else{bS=c[198610]|0;c2=(bS|0)!=0?bS:c[p>>2]|0;bS=c3+66448+(c4*4168|0)+64|0;ec(c2|0,56192,(I=i,i=i+8|0,c[I>>2]=bS,I)|0)|0;i=I;bS=c[198610]|0;c2=(bS|0)!=0?bS:c[p>>2]|0;aY(c2|0)|0;de=c[131708]|0}X2(c7|0,0,12);c2=de+66448+(c4*4168|0)+64|0;if((a[797396]&1)==0){if(!(h8(c2,w,16,0)|0)){break}}else{if(!(h8(c2,w,0,16)|0)){break}}aX(3553,c[534232+(c4<<2)>>2]|0);eW(3553,10242,33071);eW(3553,10243,33071);c2=(c[(c[131708]|0)+66448+(c4*4168|0)+4160>>2]|0)==2?9728:9729;eW(3553,10240,c2|0);eW(3553,10241,c2|0);e4(3317,4);c2=(a[797396]&1)!=0?6408:32993;bS=c[c5>>2]|0;d2(3553,0,c2|0,c[aw>>2]|0,c[c6>>2]|0,0,c2|0,5121,bS|0);aX(3553,0);XZ(bS);bS=c4+1|0;c2=c[131708]|0;if(bS>>>0<(c[c2+66444>>2]|0)>>>0){c4=bS;c3=c2}else{dd=0;break L10081}}c3=c[198610]|0;ec(((c3|0)!=0?c3:c[p>>2]|0)|0,55112,(I=i,i=i+8|0,c[I>>2]=(c[131708]|0)+66448+(c4*4168|0)+64,I)|0)|0;i=I;c3=c[198610]|0;aY(((c3|0)!=0?c3:c[p>>2]|0)|0)|0;c3=c[198610]|0;a2(35256,48,1,((c3|0)!=0?c3:c[p>>2]|0)|0)|0;c3=c[198610]|0;aY(((c3|0)!=0?c3:c[p>>2]|0)|0)|0;break L10063}}while(0);do{jw(dd,c[534272+(dd<<2)>>2]|0,526872+(dd*460|0)|0);dd=dd+1|0;df=c[131708]|0;}while(dd>>>0<=(c[df+72>>2]|0)>>>0);do{if((c[df+99792>>2]|0)!=0){c7=fe[c[59500]&127](2)|0;c3=c[131708]|0;c6=c[c3+99792>>2]|0;aw=XY(12)|0;if((aw|0)==0){c[133566]=0}else{if((c[aw-4>>2]&3|0)!=0){X2(aw|0,0,12)}c5=aw;D=(c6|0)==0;do{if(D){dg=0}else{B=c6*112|0;if(c6>>>0<=65535){dg=B;break}dg=((B>>>0)/(c6>>>0)|0|0)==112?B:-1}}while(0);c4=XY(dg)|0;do{if((c4|0)!=0){if((c[c4-4>>2]&3|0)==0){break}X2(c4|0,0,dg|0)}}while(0);B=c4;c2=aw;c[c2>>2]=B;c[aw+4>>2]=c6;L10113:do{if(!D){bS=aw+8|0;c1=aw+10|0;z=(c7|0)==0?169504:c7;c0=0;c_=B;while(1){cZ=64;cW=c_+(c0*112|0)|0;cV=c3+99796+(c0*80|0)|0;while(1){cU=cZ-1|0;if((cU|0)==0){F=7244;break}cT=a[cV]|0;a[cW]=cT;if(cT<<24>>24==0){break}else{cZ=cU;cW=cW+1|0;cV=cV+1|0}}do{if((F|0)==7244){F=0;a[cW]=0;if((a[cV]|0)==0){break}else{dh=cV}do{dh=dh+1|0;}while((a[dh]|0)!=0)}}while(0);c[(c[c2>>2]|0)+(c0*112|0)+76>>2]=c[c3+99796+(c0*80|0)+64>>2];c[(c[c2>>2]|0)+(c0*112|0)+84>>2]=c[c3+99796+(c0*80|0)+68>>2];cV=b[c3+99796+(c0*80|0)+76>>1]|0;b[(c[c2>>2]|0)+(c0*112|0)+80>>1]=cV<<16>>16==0?-1:cV;b[(c[c2>>2]|0)+(c0*112|0)+82>>1]=b[c3+99796+(c0*80|0)+78>>1]|0;cV=c[c3+99796+(c0*80|0)+72>>2]|0;if((cV|0)==1){c[(c[c2>>2]|0)+(c0*112|0)+72>>2]=z}else if((cV|0)==2){c[(c[c2>>2]|0)+(c0*112|0)+68>>2]=bS;a[(c[c2>>2]|0)+(c0*112|0)+64|0]=1}else if((cV|0)==3){c[(c[c2>>2]|0)+(c0*112|0)+68>>2]=c1;a[(c[c2>>2]|0)+(c0*112|0)+64|0]=1}else{c[(c[c2>>2]|0)+(c0*112|0)+72>>2]=169504}cV=c0+1|0;if(cV>>>0>=c6>>>0){break L10113}c0=cV;c_=c[c2>>2]|0}}}while(0);c[133566]=c5;if((aw|0)!=0){break}}c2=c[198610]|0;c6=(c2|0)!=0?c2:c[p>>2]|0;a2(30648,50,1,c6|0)|0;c6=c[198610]|0;c2=(c6|0)!=0?c6:c[p>>2]|0;aY(c2|0)|0}}while(0);a[9568]=1;c2=c[131708]|0;c6=c2+72|0;c[534272+((c[c6>>2]|0)+1<<2)>>2]=c[133568];c3=526872+(((c[c6>>2]|0)+1|0)*460|0)|0;X5(c3|0,526872,460)|0;if((a[c2+4|0]&1)==0){c[133583]=c[133568];X5(533772,526872,460)|0}else{c2=(a[526864]&1)!=0;c3=jv(c2?95936:100248,c2?22584:26736,15)|0;c[133583]=c3;jw(0,c3,533772)}if((c[133742]|0)!=0){c3=0;do{c$(c[534856+(c3<<2)>>2]|0);c3=c3+1|0;}while(c3>>>0<(c[133742]|0)>>>0)}c[133742]=0;c3=0;while(1){es(1,510192+(c3*1040|0)|0);es(1,510712+(c3*1040|0)|0);c2=c3+1|0;if(c2>>>0<16){c3=c2}else{y=1;break}}i=e;return y|0}}}while(0);jk();y=0;i=e;return y|0}function jk(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;i=i+16|0;d=b|0;e=b+8|0;d1(0);f=e;g=e;h=0;do{j=c[534272+(h<<2)>>2]|0;do{if((j|0)!=0){if((h|0)!=0&(j|0)==(c[133568]|0)){break}c[e>>2]=0;c[e+4>>2]=0;b_(j|0,2,d|0,g|0);if((c[d>>2]|0)>0){k=0;do{l=f+(k<<2)|0;cQ(j|0,c[l>>2]|0);bl(c[l>>2]|0);k=k+1|0;}while((k|0)<(c[d>>2]|0))}cc(j|0)}}while(0);h=h+1|0;}while(h>>>0<16);h=c[131708]|0;do{if((h|0)==0){m=0}else{d=c[h+66444>>2]|0;if((d|0)==0){m=h;break}be(d|0,534232);m=c[131708]|0}}while(0);X2(534272,0,64);X2(526872,0,7360);a[9568]=0;c[199562]=0;if((m|0)!=0){if((c[m+72>>2]|0)==0){n=m}else{h=0;d=m;while(1){XZ(c[d+76+(h*4148|0)+4096>>2]|0);XZ(c[(c[131708]|0)+76+(h*4148|0)+4100>>2]|0);m=h+1|0;f=c[131708]|0;if(m>>>0<(c[f+72>>2]|0)>>>0){h=m;d=f}else{n=f;break}}}XZ(c[n+109012>>2]|0);XZ(c[131708]|0);c[131708]=0}n=c[133566]|0;if((n|0)!=0){XZ(c[n>>2]|0);XZ(n)}c[133566]=0;if((c[133742]|0)!=0){n=0;do{c$(c[534856+(n<<2)>>2]|0);n=n+1|0;}while(n>>>0<(c[133742]|0)>>>0)}c[133742]=0;n=0;do{d=510192+(n*1040|0)|0;if((c[d>>2]|0)!=0){e_(1,d|0)}d=510712+(n*1040|0)|0;if((c[d>>2]|0)!=0){e_(1,d|0)}n=n+1|0;}while(n>>>0<16);X2(510192,0,16640);i=b;return}function jl(){return c[(c[131708]|0)+72>>2]|0}function jm(b,d){b=b|0;d=d|0;var e=0,f=0;if((b|0)==0|a[9568]^1){e=0;return e|0}f=c[(c[131708]|0)+76+((b-1|0)*4148|0)+4136>>2]|0;if((f|0)==0){e=0;return e|0}a[d]=(f|0)==1|0;e=1;return e|0}function jn(b){b=b|0;var d=0;if((b|0)==0|a[9568]^1){d=0;return d|0}d=c[(c[131708]|0)+76+((b-1|0)*4148|0)+4140>>2]|0;return d|0}function jo(e,f,h,j,k,l,m,n,o,p,q){e=e|0;f=f|0;h=h|0;j=j|0;k=k|0;l=l|0;m=m|0;n=n|0;o=o|0;p=p|0;q=q|0;var r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0;r=i;i=i+920|0;s=r|0;t=r+512|0;u=r+896|0;v=r+904|0;w=r+912|0;if(!(a[9568]|0)){i=r;return}y=c[199562]|0;if((c[534272+(y<<2)>>2]|0)==0){i=r;return}z=t|0;A=u|0;g[A>>2]=+(e>>>0>>>0);g[u+4>>2]=+(f>>>0>>>0);f=v|0;g[f>>2]=+(k>>>0>>>0);g[v+4>>2]=+(l>>>0>>>0);l=w|0;g[l>>2]=+(h>>>0>>>0);g[w+4>>2]=+(j>>>0>>>0);j=c[526892+(y*460|0)>>2]|0;if((j|0)>-1){a7(j|0,1,A|0)}A=c[526896+(y*460|0)>>2]|0;if((A|0)>-1){a7(A|0,1,f|0)}f=c[526900+(y*460|0)>>2]|0;if((f|0)>-1){a7(f|0,1,l|0)}l=c[526904+(y*460|0)>>2]|0;f=c[199562]|0;if((l|0)>-1&(f|0)!=0){A=c[(c[131708]|0)+76+((f-1|0)*4148|0)+4144>>2]|0;if((A|0)==0){B=m}else{B=(m>>>0)%(A>>>0)|0}bI(l|0,B|0);C=B}else{C=m}m=c[526912+(y*460|0)>>2]|0;if((m|0)>-1){bI(m|0,((a[785940]&1)!=0?-1:1)|0)}m=c[131708]|0;if((c[m+66444>>2]|0)==0){D=0}else{B=0;l=m;while(1){m=526916+(y*460|0)+(B<<2)|0;if((c[m>>2]|0)>-1){cI(B+33985|0);aX(3553,c[534232+(B<<2)>>2]|0);A=B+1|0;bI(c[m>>2]|0,A|0);E=c[131708]|0;F=A}else{E=l;F=B+1|0}A=c[E+66444>>2]|0;if(F>>>0<A>>>0){B=F;l=E}else{D=A;break}}}E=D+1|0;do{if((c[199562]|0)>>>0>1){l=526948+(y*460|0)|0;if((c[l>>2]|0)>-1){cI(D+33985|0);bI(c[l>>2]|0,E|0);aX(3553,c[n>>2]|0)}l=D+2|0;F=c[526956+(y*460|0)>>2]|0;if((F|0)>-1){a7(F|0,1,n+12|0)}F=c[526952+(y*460|0)>>2]|0;if((F|0)>-1){a7(F|0,1,n+4|0)}F=c[526960+(y*460|0)>>2]|0;if((F|0)>-1){c[t>>2]=F;c[t+4>>2]=2;c[t+8>>2]=0;F=t+12|0;B=s;A=n+20|0;X5(B|0,A|0,32)|0;G=8;H=1;I=F}else{G=0;H=0;I=z}if((q|0)==0){J=I;K=H;L=l;M=G;N=0;break}cI(q+33985+D|0);aX(3553,c[p+((q-1|0)*52|0)>>2]|0);F=I;A=H;B=l;l=0;m=G;while(1){f=c[526964+(y*460|0)+(l<<4)>>2]|0;if((f|0)!=0){bI(f|0,B|0)}f=c[526964+(y*460|0)+(l<<4)+8>>2]|0;if((f|0)>-1){a7(f|0,1,p+(l*52|0)+12|0)}f=c[526964+(y*460|0)+(l<<4)+4>>2]|0;if((f|0)>-1){a7(f|0,1,p+(l*52|0)+4|0)}f=c[526964+(y*460|0)+(l<<4)+12>>2]|0;if((f|0)>-1){c[F>>2]=f;c[F+4>>2]=2;c[F+8>>2]=m<<2;f=A+1|0;j=F+12|0;w=s+(m<<2)|0;h=p+(l*52|0)+20|0;X5(w|0,h|0,32)|0;O=m+8|0;P=f;Q=j}else{O=m;P=A;Q=F}j=l+1|0;if(j>>>0<q>>>0){F=Q;A=P;B=B+1|0;l=j;m=O}else{break}}J=Q;K=P;L=q+2+D|0;M=O;N=0}else{cI(D+33985|0);aX(3553,0);if((c[(c[131708]|0)+72>>2]|0)==0){J=z;K=0;L=E;M=0;N=0;break}m=D+33986|0;l=0;while(1){cI(m+l|0);aX(3553,0);B=l+1|0;if(B>>>0<(c[(c[131708]|0)+72>>2]|0)>>>0){l=B}else{J=z;K=0;L=E;M=0;N=0;break}}}}while(0);while(1){E=527220+(y*460|0)+(N<<4)|0;if((c[E>>2]|0)>-1){cI(L+33984|0);aX(3553,c[o+(N*52|0)>>2]|0);bI(c[E>>2]|0,L|0);R=L+1|0}else{R=L}E=c[527220+(y*460|0)+(N<<4)+8>>2]|0;if((E|0)>-1){a7(E|0,1,o+(N*52|0)+12|0)}E=c[527220+(y*460|0)+(N<<4)+4>>2]|0;if((E|0)>-1){a7(E|0,1,o+(N*52|0)+4|0)}E=c[527220+(y*460|0)+(N<<4)+12>>2]|0;if((E|0)>-1){c[J>>2]=E;c[J+4>>2]=2;c[J+8>>2]=M<<2;E=K+1|0;D=J+12|0;O=s+(M<<2)|0;q=o+(N*52|0)+20|0;X5(O|0,q|0,32)|0;S=M+8|0;T=E;U=D}else{S=M;T=K;U=J}D=N+1|0;if(D>>>0<7){J=U;K=T;L=R+1|0;M=S;N=D}else{break}}if((S|0)!=0){N=c[199562]|0;ju(c[510712+(N*1040|0)>>2]|0,510716+(N*1040|0)|0,511228+(N*1040|0)|0,s|0,S,z,T)}cI(33984);T=c[133566]|0;if((T|0)==0){i=r;return}if((c[199562]|0)==1){z=c[T+4>>2]|0;S=z>>>0<64?z:64;z=c[199306]|0;if((z|0)!=0){s=4;N=0;M=0;R=z;while(1){z=c[200+(s-4<<2)>>2]|0;V=((fd[c[R+8>>2]&15](c[199309]|0,248,0,1,0,z)|0)<<16>>16!=0)<<s|N;W=((fd[c[(c[199306]|0)+8>>2]&15](c[199309]|0,248,1,1,0,z)|0)<<16>>16!=0)<<s|M;z=s+1|0;if(z>>>0>=16){break}s=z;N=V&65535;M=W&65535;R=c[199306]|0}R=T+8|0;x=W<<16|V&65535;b[R>>1]=x&65535;b[R+2>>1]=x>>16}L10298:do{if((S|0)!=0){R=T|0;V=0;while(1){W=c[R>>2]|0;c[534336+(V<<3)>>2]=W+(V*112|0);switch(c[W+(V*112|0)+84>>2]|0){case 0:{if((a[W+(V*112|0)+64|0]&1)==0){X=d[(c[W+(V*112|0)+72>>2]|0)+(c[W+(V*112|0)+76>>2]|0)|0]|0}else{X=b[c[W+(V*112|0)+68>>2]>>1]|0}M=b[W+(V*112|0)+80>>1]&X;N=b[W+(V*112|0)+82>>1]|0;g[534340+(V<<3)>>2]=N<<16>>16==0|M<<16>>16==N<<16>>16?+((M&65535)>>>0):0.0;break};case 1:{M=W+(V*112|0)+88|0;N=c[M>>2]|0;s=(a[W+(V*112|0)+64|0]&1)==0;if(s){Y=d[(c[W+(V*112|0)+72>>2]|0)+(c[W+(V*112|0)+76>>2]|0)|0]|0}else{Y=b[c[W+(V*112|0)+68>>2]>>1]|0}z=b[W+(V*112|0)+80>>1]|0;L=z&Y;K=b[W+(V*112|0)+82>>1]|0;U=K<<16>>16==0;J=W+(V*112|0)+92|0;if((N|0)==((U|L<<16>>16==K<<16>>16?L&65535:0)|0)){Z=c[J>>2]|0}else{c[J>>2]=N;if(s){_=d[(c[W+(V*112|0)+72>>2]|0)+(c[W+(V*112|0)+76>>2]|0)|0]|0}else{_=b[c[W+(V*112|0)+68>>2]>>1]|0}s=_&z;c[M>>2]=U|s<<16>>16==K<<16>>16?s&65535:0;Z=N}g[534340+(V<<3)>>2]=+(Z>>>0>>>0);break};case 2:{N=W+(V*112|0)+104|0;s=(a[W+(V*112|0)+64|0]&1)==0;if(s){$=d[(c[W+(V*112|0)+72>>2]|0)+(c[W+(V*112|0)+76>>2]|0)|0]|0}else{$=b[c[W+(V*112|0)+68>>2]>>1]|0}K=b[W+(V*112|0)+80>>1]|0;U=K&$;M=b[W+(V*112|0)+82>>1]|0;z=M<<16>>16==0;if((c[N>>2]|0)==((z|U<<16>>16==M<<16>>16?U&65535:0)|0)){aa=c[W+(V*112|0)+96>>2]|0}else{if(s){ab=d[(c[W+(V*112|0)+72>>2]|0)+(c[W+(V*112|0)+76>>2]|0)|0]|0}else{ab=b[c[W+(V*112|0)+68>>2]>>1]|0}s=ab&K;c[N>>2]=z|s<<16>>16==M<<16>>16?s&65535:0;c[W+(V*112|0)+96>>2]=C;aa=C}g[534340+(V<<3)>>2]=+(aa|0);break};case 3:{s=W+(V*112|0)+104|0;M=(a[W+(V*112|0)+64|0]&1)==0;if(M){ac=d[(c[W+(V*112|0)+72>>2]|0)+(c[W+(V*112|0)+76>>2]|0)|0]|0}else{ac=b[c[W+(V*112|0)+68>>2]>>1]|0}z=b[W+(V*112|0)+80>>1]|0;N=z&ac;K=b[W+(V*112|0)+82>>1]|0;U=K<<16>>16==0;if((c[s>>2]|0)==((U|N<<16>>16==K<<16>>16?N&65535:0)|0)){ad=c[W+(V*112|0)+108>>2]|0}else{if(M){ae=d[(c[W+(V*112|0)+72>>2]|0)+(c[W+(V*112|0)+76>>2]|0)|0]|0}else{ae=b[c[W+(V*112|0)+68>>2]>>1]|0}M=ae&z;c[s>>2]=U|M<<16>>16==K<<16>>16?M&65535:0;M=W+(V*112|0)+108|0;K=(c[M>>2]|0)+1|0;c[M>>2]=K;ad=K}g[534340+(V<<3)>>2]=+(ad|0);break};case 4:{K=W+(V*112|0)+104|0;M=(a[W+(V*112|0)+64|0]&1)==0;if(M){af=d[(c[W+(V*112|0)+72>>2]|0)+(c[W+(V*112|0)+76>>2]|0)|0]|0}else{af=b[c[W+(V*112|0)+68>>2]>>1]|0}U=b[W+(V*112|0)+80>>1]|0;s=U&af;z=b[W+(V*112|0)+82>>1]|0;N=z<<16>>16==0;if((c[K>>2]|0)==((N|s<<16>>16==z<<16>>16?s&65535:0)|0)){ag=c[W+(V*112|0)+100>>2]|0}else{if(M){ah=d[(c[W+(V*112|0)+72>>2]|0)+(c[W+(V*112|0)+76>>2]|0)|0]|0}else{ah=b[c[W+(V*112|0)+68>>2]>>1]|0}M=ah&U;c[K>>2]=N|M<<16>>16==z<<16>>16?M&65535:0;M=W+(V*112|0)+96|0;z=c[M>>2]|0;c[W+(V*112|0)+100>>2]=z;c[M>>2]=C;ag=z}g[534340+(V<<3)>>2]=+(ag|0);break};default:{}}V=V+1|0;if(V>>>0>=S>>>0){break L10298}}}}while(0);c[133712]=S;ai=S}else{ai=c[133712]|0}if((ai|0)==0){i=r;return}else{aj=0}do{ai=dB(c[534272+(c[199562]<<2)>>2]|0,c[534336+(aj<<3)>>2]|0)|0;bB(ai|0,+(+g[534340+(aj<<3)>>2]));aj=aj+1|0;}while(aj>>>0<(c[133712]|0)>>>0);i=r;return}function jp(b){b=b|0;var d=0;if(!(a[9568]|0)){return}if((c[133742]|0)!=0){d=0;do{c$(c[534856+(d<<2)>>2]|0);d=d+1|0;}while(d>>>0<(c[133742]|0)>>>0)}c[133742]=0;c[199562]=b;d1(c[534272+(b<<2)>>2]|0);return}function jq(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;if(!(a[9568]|0)){b=0;return b|0}d=c[(c[131708]|0)+72>>2]|0;if((d|0)==0){b=0;return b|0}else{e=0;f=1}while(1){if((c[527220+(f*460|0)>>2]|0)>-1){g=(e|0)==0?1:e}else{g=e}if((c[527236+(f*460|0)>>2]|0)>-1){h=g>>>0<2?2:g}else{h=g}if((c[527252+(f*460|0)>>2]|0)>-1){i=h>>>0<3?3:h}else{i=h}if((c[527268+(f*460|0)>>2]|0)>-1){j=i>>>0<4?4:i}else{j=i}if((c[527284+(f*460|0)>>2]|0)>-1){k=j>>>0<5?5:j}else{k=j}if((c[527300+(f*460|0)>>2]|0)>-1){l=k>>>0<6?6:k}else{l=k}if((c[527316+(f*460|0)>>2]|0)>-1){m=l>>>0<7?7:l}else{m=l}n=f+1|0;if(n>>>0>d>>>0){b=m;break}else{e=m;f=n}}return b|0}function jr(b,d){b=b|0;d=d|0;var e=0;if((b|0)==0|a[9568]^1){a[d|0]=0;return}else{e=d|0;d=(c[131708]|0)+76+((b-1|0)*4148|0)+4104|0;X5(e|0,d|0,32)|0;return}}function js(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;d=i;i=i+560|0;e=d|0;f=d+512|0;if(!(a[9568]|0)){g=0;i=d;return g|0}if((a[(c[131708]|0)+4|0]&1)==0){g=0;i=d;return g|0}h=f|0;j=c[199562]|0;k=c[526876+(j*460|0)>>2]|0;if((k|0)>-1){c[f>>2]=k;c[f+4>>2]=2;c[f+8>>2]=0;k=f+12|0;f=e;l=c[b+8>>2]|0;X5(f|0,l|0,32)|0;m=k;n=1;o=8}else{m=h;n=0;o=0}k=c[526880+(j*460|0)>>2]|0;if((k|0)>-1){c[m>>2]=k;c[m+4>>2]=2;c[m+8>>2]=o<<2;k=n+1|0;l=m+12|0;f=e+(o<<2)|0;p=c[b>>2]|0;X5(f|0,p|0,32)|0;q=l;r=k;s=o+8|0}else{q=m;r=n;s=o}o=c[526884+(j*460|0)>>2]|0;if((o|0)>-1){c[q>>2]=o;c[q+4>>2]=4;c[q+8>>2]=s<<2;o=r+1|0;n=q+12|0;m=e+(s<<2)|0;k=c[b+4>>2]|0;X5(m|0,k|0,64)|0;t=n;u=o;v=s+16|0}else{t=q;u=r;v=s}s=c[526888+(j*460|0)>>2]|0;if((s|0)>-1){c[t>>2]=s;c[t+4>>2]=2;c[t+8>>2]=v<<2;t=u+1|0;s=e+(v<<2)|0;r=c[b+12>>2]|0;X5(s|0,r|0,32)|0;w=t;x=v+8|0}else{w=u;x=v}if((x|0)==0){g=1;i=d;return g|0}ju(c[510192+(j*1040|0)>>2]|0,510196+(j*1040|0)|0,510708+(j*1040|0)|0,e|0,x,h,w);g=1;i=d;return g|0}function jt(b){b=b|0;var d=0,e=0;if(!(a[9568]|0)){d=0;return d|0}if((a[(c[131708]|0)+4|0]&1)==0){d=0;return d|0}e=c[526872+((c[199562]|0)*460|0)>>2]|0;if((e|0)<=-1){d=1;return d|0}eO(e|0,1,0,b|0);d=1;return d|0}function ju(a,b,d,e,f,g,h){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0;bV(34962,a|0);if((c[d>>2]|0)==(f|0)){a=e;i=b;j=f<<2;if((Ya(a|0,i|0,j|0)|0)!=0){k=i;l=a;m=j;n=7487}}else{k=b;l=e;m=f<<2;n=7487}if((n|0)==7487){X5(k|0,l|0,m)|0;dz(34962,m|0,l|0,35044);c[d>>2]=f}if((h|0)==0){bV(34962,0);return}else{o=0}do{f=c[g+(o*12|0)>>2]|0;dl(f|0);d=c[133742]|0;c[133742]=d+1;c[534856+(d<<2)>>2]=f;bT(f|0,c[g+(o*12|0)+4>>2]|0,5126,0,0,c[g+(o*12|0)+8>>2]|0);o=o+1|0;}while(o>>>0<h>>>0);bV(34962,0);return}function jv(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0;f=i;i=i+88|0;g=f|0;h=f+64|0;j=f+72|0;k=f+80|0;l=ez()|0;if((l|0)==0){m=0;i=f;return m|0}n=(b|0)!=0;do{if(n){if((a[637400]&1)!=0){o=c[198610]|0;q=(o|0)!=0?o:c[p>>2]|0;a2(52488,37,1,q|0)|0;q=c[198610]|0;o=(q|0)!=0?q:c[p>>2]|0;aY(o|0)|0}o=bG(35633)|0;if(jy(o,51600,b)|0){ch(l|0,o|0);break}o=c[198610]|0;q=(o|0)!=0?o:c[p>>2]|0;ec(q|0,50728,(r=i,i=i+8|0,c[r>>2]=e,r)|0)|0;i=r;q=c[198610]|0;o=(q|0)!=0?q:c[p>>2]|0;aY(o|0)|0;m=0;i=f;return m|0}}while(0);b=(d|0)!=0;do{if(b){if((a[637400]&1)!=0){o=c[198610]|0;q=(o|0)!=0?o:c[p>>2]|0;a2(49872,39,1,q|0)|0;q=c[198610]|0;o=(q|0)!=0?q:c[p>>2]|0;aY(o|0)|0}o=bG(35632)|0;if(jy(o,49080,d)|0){ch(l|0,o|0);break}o=c[198610]|0;q=(o|0)!=0?o:c[p>>2]|0;ec(q|0,48176,(r=i,i=i+8|0,c[r>>2]=e,r)|0)|0;i=r;q=c[198610]|0;o=(q|0)!=0?q:c[p>>2]|0;aY(o|0)|0;m=0;i=f;return m|0}}while(0);if(!(n|b)){m=l;i=f;return m|0}if((a[637400]&1)!=0){b=c[198610]|0;n=(b|0)!=0?b:c[p>>2]|0;a2(47088,33,1,n|0)|0;n=c[198610]|0;b=(n|0)!=0?n:c[p>>2]|0;aY(b|0)|0}bM(l|0);dI(l|0,35714,k|0);c[h>>2]=0;dI(l|0,35716,j|0);b=c[j>>2]|0;do{if((b|0)!=0){j=XY(b)|0;if((j|0)==0){break}d3(l|0,b|0,h|0,j|0);do{if((c[h>>2]|0)>0){if((a[637400]&1)==0){break}n=c[198610]|0;d=(n|0)!=0?n:c[p>>2]|0;ec(d|0,45200,(r=i,i=i+8|0,c[r>>2]=j,r)|0)|0;i=r;d=c[198610]|0;n=(d|0)!=0?d:c[p>>2]|0;aY(n|0)|0}}while(0);XZ(j)}}while(0);if((c[k>>2]|0)!=1){k=c[198610]|0;h=(k|0)!=0?k:c[p>>2]|0;ec(h|0,45824,(r=i,i=i+8|0,c[r>>2]=e,r)|0)|0;i=r;e=c[198610]|0;h=(e|0)!=0?e:c[p>>2]|0;aY(h|0)|0;m=0;i=f;return m|0}d1(l|0);d1(l|0);h=g|0;bN(h|0,64,45336,(r=i,i=i+16|0,c[r>>2]=(c[131708]|0)+5,c[r+8>>2]=58384,r)|0)|0;i=r;g=dB(l|0,h|0)|0;L10501:do{if((g|0)>-1){s=g}else{e=0;while(1){if(e>>>0>=2){s=-1;break L10501}bN(h|0,64,45336,(r=i,i=i+16|0,c[r>>2]=c[9560+(e<<2)>>2],c[r+8>>2]=58384,r)|0)|0;i=r;k=dB(l|0,h|0)|0;if((k|0)>-1){s=k;break}else{e=e+1|0}}}}while(0);bI(s|0,0);d1(0);m=l;i=f;return m|0}function jw(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;e=i;i=i+128|0;f=e+64|0;d1(b|0);g=e|0;bN(g|0,64,45336,(h=i,i=i+16|0,c[h>>2]=(c[131708]|0)+5,c[h+8>>2]=91824,h)|0)|0;i=h;j=dB(b|0,g|0)|0;L10508:do{if((j|0)>-1){k=j}else{l=0;while(1){if(l>>>0>=2){k=-1;break L10508}bN(g|0,64,45336,(h=i,i=i+16|0,c[h>>2]=c[9560+(l<<2)>>2],c[h+8>>2]=91824,h)|0)|0;i=h;m=dB(b|0,g|0)|0;if((m|0)>-1){k=m;break}else{l=l+1|0}}}}while(0);c[d>>2]=k;bN(g|0,64,45336,(h=i,i=i+16|0,c[h>>2]=(c[131708]|0)+5,c[h+8>>2]=88320,h)|0)|0;i=h;k=dB(b|0,g|0)|0;L10513:do{if((k|0)>-1){n=k}else{j=0;while(1){if(j>>>0>=2){n=-1;break L10513}bN(g|0,64,45336,(h=i,i=i+16|0,c[h>>2]=c[9560+(j<<2)>>2],c[h+8>>2]=88320,h)|0)|0;i=h;l=eu(b|0,g|0)|0;if((l|0)>-1){n=l;break}else{j=j+1|0}}}}while(0);c[d+4>>2]=n;bN(g|0,64,45336,(h=i,i=i+16|0,c[h>>2]=(c[131708]|0)+5,c[h+8>>2]=85184,h)|0)|0;i=h;n=dB(b|0,g|0)|0;L10518:do{if((n|0)>-1){o=n}else{k=0;while(1){if(k>>>0>=2){o=-1;break L10518}bN(g|0,64,45336,(h=i,i=i+16|0,c[h>>2]=c[9560+(k<<2)>>2],c[h+8>>2]=85184,h)|0)|0;i=h;j=eu(b|0,g|0)|0;if((j|0)>-1){o=j;break}else{k=k+1|0}}}}while(0);c[d+8>>2]=o;bN(g|0,64,45336,(h=i,i=i+16|0,c[h>>2]=(c[131708]|0)+5,c[h+8>>2]=81712,h)|0)|0;i=h;o=dB(b|0,g|0)|0;L10523:do{if((o|0)>-1){p=o}else{n=0;while(1){if(n>>>0>=2){p=-1;break L10523}bN(g|0,64,45336,(h=i,i=i+16|0,c[h>>2]=c[9560+(n<<2)>>2],c[h+8>>2]=81712,h)|0)|0;i=h;k=eu(b|0,g|0)|0;if((k|0)>-1){p=k;break}else{n=n+1|0}}}}while(0);c[d+12>>2]=p;bN(g|0,64,45336,(h=i,i=i+16|0,c[h>>2]=(c[131708]|0)+5,c[h+8>>2]=78280,h)|0)|0;i=h;p=dB(b|0,g|0)|0;L10528:do{if((p|0)>-1){q=p}else{o=0;while(1){if(o>>>0>=2){q=-1;break L10528}bN(g|0,64,45336,(h=i,i=i+16|0,c[h>>2]=c[9560+(o<<2)>>2],c[h+8>>2]=78280,h)|0)|0;i=h;n=eu(b|0,g|0)|0;if((n|0)>-1){q=n;break}else{o=o+1|0}}}}while(0);c[d+16>>2]=q;bN(g|0,64,45336,(h=i,i=i+16|0,c[h>>2]=(c[131708]|0)+5,c[h+8>>2]=75072,h)|0)|0;i=h;q=dB(b|0,g|0)|0;L10533:do{if((q|0)>-1){r=q}else{p=0;while(1){if(p>>>0>=2){r=-1;break L10533}bN(g|0,64,45336,(h=i,i=i+16|0,c[h>>2]=c[9560+(p<<2)>>2],c[h+8>>2]=75072,h)|0)|0;i=h;o=dB(b|0,g|0)|0;if((o|0)>-1){r=o;break}else{p=p+1|0}}}}while(0);c[d+20>>2]=r;bN(g|0,64,45336,(h=i,i=i+16|0,c[h>>2]=(c[131708]|0)+5,c[h+8>>2]=72032,h)|0)|0;i=h;r=dB(b|0,g|0)|0;L10538:do{if((r|0)>-1){s=r}else{q=0;while(1){if(q>>>0>=2){s=-1;break L10538}bN(g|0,64,45336,(h=i,i=i+16|0,c[h>>2]=c[9560+(q<<2)>>2],c[h+8>>2]=72032,h)|0)|0;i=h;p=dB(b|0,g|0)|0;if((p|0)>-1){s=p;break}else{q=q+1|0}}}}while(0);c[d+24>>2]=s;bN(g|0,64,45336,(h=i,i=i+16|0,c[h>>2]=(c[131708]|0)+5,c[h+8>>2]=69832,h)|0)|0;i=h;s=dB(b|0,g|0)|0;L10543:do{if((s|0)>-1){t=s}else{r=0;while(1){if(r>>>0>=2){t=-1;break L10543}bN(g|0,64,45336,(h=i,i=i+16|0,c[h>>2]=c[9560+(r<<2)>>2],c[h+8>>2]=69832,h)|0)|0;i=h;q=dB(b|0,g|0)|0;if((q|0)>-1){t=q;break}else{r=r+1|0}}}}while(0);c[d+28>>2]=t;bN(g|0,64,45336,(h=i,i=i+16|0,c[h>>2]=(c[131708]|0)+5,c[h+8>>2]=68552,h)|0)|0;i=h;t=dB(b|0,g|0)|0;L10548:do{if((t|0)>-1){u=t}else{s=0;while(1){if(s>>>0>=2){u=-1;break L10548}bN(g|0,64,45336,(h=i,i=i+16|0,c[h>>2]=c[9560+(s<<2)>>2],c[h+8>>2]=68552,h)|0)|0;i=h;r=dB(b|0,g|0)|0;if((r|0)>-1){u=r;break}else{s=s+1|0}}}}while(0);c[d+32>>2]=u;bN(g|0,64,45336,(h=i,i=i+16|0,c[h>>2]=(c[131708]|0)+5,c[h+8>>2]=66920,h)|0)|0;i=h;u=dB(b|0,g|0)|0;L10553:do{if((u|0)>-1){v=u}else{t=0;while(1){if(t>>>0>=2){v=-1;break L10553}bN(g|0,64,45336,(h=i,i=i+16|0,c[h>>2]=c[9560+(t<<2)>>2],c[h+8>>2]=66920,h)|0)|0;i=h;s=dB(b|0,g|0)|0;if((s|0)>-1){v=s;break}else{t=t+1|0}}}}while(0);c[d+40>>2]=v;v=c[131708]|0;if((c[v+66444>>2]|0)!=0){g=0;u=v;do{c[d+44+(g<<2)>>2]=dB(b|0,u+66448+(g*4168|0)|0)|0;g=g+1|0;u=c[131708]|0;}while(g>>>0<(c[u+66444>>2]|0)>>>0)}u=d+76|0;X2(u|0,-1|0,16);jx(b,u,64912);g=f|0;if(a>>>0>1){bN(g|0,64,63320,(h=i,i=i+8|0,c[h>>2]=a,h)|0)|0;i=h;jx(b,u,g);w=0}else{w=0}while(1){u=w+1|0;bN(g|0,64,61968,(h=i,i=i+8|0,c[h>>2]=u,h)|0)|0;i=h;f=d+92+(w<<4)|0;X2(f|0,-1|0,16);jx(b,f,g);if((w|0)!=0&u>>>0<a>>>0){v=a-w|0;bN(g|0,64,63320,(h=i,i=i+8|0,c[h>>2]=v,h)|0)|0;i=h;jx(b,f,g)}if(u>>>0<16){w=u}else{break}}w=d+348|0;X2(w|0,-1|0,16);jx(b,w,61104);bN(g|0,64,60040,(h=i,i=i+8|0,c[h>>2]=1,h)|0)|0;i=h;w=d+364|0;X2(w|0,-1|0,16);jx(b,w,g);bN(g|0,64,60040,(h=i,i=i+8|0,c[h>>2]=2,h)|0)|0;i=h;w=d+380|0;X2(w|0,-1|0,16);jx(b,w,g);bN(g|0,64,60040,(h=i,i=i+8|0,c[h>>2]=3,h)|0)|0;i=h;w=d+396|0;X2(w|0,-1|0,16);jx(b,w,g);bN(g|0,64,60040,(h=i,i=i+8|0,c[h>>2]=4,h)|0)|0;i=h;w=d+412|0;X2(w|0,-1|0,16);jx(b,w,g);bN(g|0,64,60040,(h=i,i=i+8|0,c[h>>2]=5,h)|0)|0;i=h;w=d+428|0;X2(w|0,-1|0,16);jx(b,w,g);bN(g|0,64,60040,(h=i,i=i+8|0,c[h>>2]=6,h)|0)|0;i=h;h=d+444|0;X2(h|0,-1|0,16);jx(b,h,g);d1(0);i=e;return}function jx(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=i;i=i+320|0;f=e|0;g=e+64|0;bN(g|0,64,45336,(h=i,i=i+16|0,c[h>>2]=d,c[h+8>>2]=58384,h)|0)|0;i=h;j=e+128|0;bN(j|0,64,45336,(h=i,i=i+16|0,c[h>>2]=d,c[h+8>>2]=69832,h)|0)|0;i=h;k=e+192|0;bN(k|0,64,45336,(h=i,i=i+16|0,c[h>>2]=d,c[h+8>>2]=75072,h)|0)|0;i=h;l=e+256|0;bN(l|0,64,45336,(h=i,i=i+16|0,c[h>>2]=d,c[h+8>>2]=88320,h)|0)|0;i=h;d=b|0;if((c[d>>2]|0)<0){m=f|0;n=(c[131708]|0)+5|0;bN(m|0,64,45336,(h=i,i=i+16|0,c[h>>2]=n,c[h+8>>2]=g,h)|0)|0;i=h;n=dB(a|0,m|0)|0;L10573:do{if((n|0)>-1){o=n}else{p=0;while(1){if(p>>>0>=2){o=-1;break L10573}bN(m|0,64,45336,(h=i,i=i+16|0,c[h>>2]=c[9560+(p<<2)>>2],c[h+8>>2]=g,h)|0)|0;i=h;q=dB(a|0,m|0)|0;if((q|0)>-1){o=q;break}else{p=p+1|0}}}}while(0);c[d>>2]=o}o=b+8|0;if((c[o>>2]|0)<0){d=f|0;m=(c[131708]|0)+5|0;bN(d|0,64,45336,(h=i,i=i+16|0,c[h>>2]=m,c[h+8>>2]=j,h)|0)|0;i=h;m=dB(a|0,d|0)|0;L10581:do{if((m|0)>-1){r=m}else{g=0;while(1){if(g>>>0>=2){r=-1;break L10581}bN(d|0,64,45336,(h=i,i=i+16|0,c[h>>2]=c[9560+(g<<2)>>2],c[h+8>>2]=j,h)|0)|0;i=h;n=dB(a|0,d|0)|0;if((n|0)>-1){r=n;break}else{g=g+1|0}}}}while(0);c[o>>2]=r}r=b+4|0;if((c[r>>2]|0)<0){o=f|0;d=(c[131708]|0)+5|0;bN(o|0,64,45336,(h=i,i=i+16|0,c[h>>2]=d,c[h+8>>2]=k,h)|0)|0;i=h;d=dB(a|0,o|0)|0;L10589:do{if((d|0)>-1){s=d}else{j=0;while(1){if(j>>>0>=2){s=-1;break L10589}bN(o|0,64,45336,(h=i,i=i+16|0,c[h>>2]=c[9560+(j<<2)>>2],c[h+8>>2]=k,h)|0)|0;i=h;m=dB(a|0,o|0)|0;if((m|0)>-1){s=m;break}else{j=j+1|0}}}}while(0);c[r>>2]=s}s=b+12|0;if((c[s>>2]|0)>=0){i=e;return}b=f|0;bN(b|0,64,45336,(h=i,i=i+16|0,c[h>>2]=(c[131708]|0)+5,c[h+8>>2]=l,h)|0)|0;i=h;f=dB(a|0,b|0)|0;L10598:do{if((f|0)>-1){t=f}else{r=0;while(1){if(r>>>0>=2){t=-1;break L10598}bN(b|0,64,45336,(h=i,i=i+16|0,c[h>>2]=c[9560+(r<<2)>>2],c[h+8>>2]=l,h)|0)|0;i=h;o=eu(a|0,b|0)|0;if((o|0)>-1){t=o;break}else{r=r+1|0}}}}while(0);c[s>>2]=t;i=e;return}function jy(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0;f=i;i=i+72|0;g=f|0;h=f+8|0;j=f+48|0;k=f+64|0;l=f+16|0;X2(l|0,0,32);do{if((a[526864]&1)!=0){if((bu(e|0,44632)|0)!=0){break}m=((c[131710]|0)*10|0)+((c[131712]|0)*100|0)|0;if((m|0)==320){n=150}else if((m|0)==300){n=130}else if((m|0)==310){n=140}else{n=m}bN(l|0,32,43880,(o=i,i=i+8|0,c[o>>2]=n,o)|0)|0;i=o;if((a[637400]&1)==0){break}m=c[198610]|0;q=(m|0)!=0?m:c[p>>2]|0;ec(q|0,43128,(o=i,i=i+8|0,c[o>>2]=n,o)|0)|0;i=o;q=c[198610]|0;m=(q|0)!=0?q:c[p>>2]|0;aY(m|0)|0}}while(0);n=j|0;c[n>>2]=l;c[j+4>>2]=d;c[j+8>>2]=e;bR(b|0,3,n|0,0);bb(b|0);cR(b|0,35713,k|0);c[g>>2]=0;cR(b|0,35716,h|0);n=c[h>>2]|0;if((n|0)==0){r=c[k>>2]|0;s=(r|0)==1;i=f;return s|0}h=XY(n)|0;if((h|0)==0){r=c[k>>2]|0;s=(r|0)==1;i=f;return s|0}d9(b|0,n|0,g|0,h|0);do{if((c[g>>2]|0)>0){if((a[637400]&1)==0){break}n=c[198610]|0;b=(n|0)!=0?n:c[p>>2]|0;ec(b|0,42504,(o=i,i=i+8|0,c[o>>2]=h,o)|0)|0;i=o;b=c[198610]|0;n=(b|0)!=0?b:c[p>>2]|0;aY(n|0)|0}}while(0);XZ(h);r=c[k>>2]|0;s=(r|0)==1;i=f;return s|0}function jz(b,e,f,g,h){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;j=i;k=e|0;l=e+4|0;m=e+9|0;switch(d[m]|0){case 2:{n=(d[e+8|0]|0)*3|0;o=((ab(n,c[k>>2]|0)|0)+7|0)>>>3;q=(n+7|0)>>>3;break};case 3:{n=d[e+8|0]|0;o=((ab(c[k>>2]|0,n)|0)+7|0)>>>3;q=(n+7|0)>>>3;break};case 0:{n=d[e+8|0]|0;o=((ab(c[k>>2]|0,n)|0)+7|0)>>>3;q=(n+7|0)>>>3;break};case 4:{n=d[e+8|0]<<1;o=((ab(n,c[k>>2]|0)|0)+7|0)>>>3;q=(n+7|0)>>>3;break};case 6:{n=d[e+8|0]<<2;o=((ab(n,c[k>>2]|0)|0)+7|0)>>>3;q=(n+7|0)>>>3;break};default:{o=0;q=0}}n=o+1|0;if((ab(c[l>>2]|0,n)|0)>>>0>g>>>0){r=0;i=j;return r|0}g=XY(o)|0;do{if((g|0)!=0){if((c[g-4>>2]&3|0)==0){break}X2(g|0,0,o|0)}}while(0);s=XY(o)|0;L10641:do{if((s|0)==0){t=c[p>>2]|0;ec(t|0,93272,(u=i,i=i+8|0,c[u>>2]=394,u)|0)|0;i=u;v=0}else{if((c[s-4>>2]&3|0)!=0){X2(s|0,0,o|0)}if((c[l>>2]|0)==0){v=1;break}t=e+8|0;w=(q|0)==0;x=(o|0)==0;y=0;z=f;A=b;L10647:while(1){L10649:do{switch(d[z]|0){case 4:{if(w){B=0}else{C=0;while(1){D=C+1|0;a[s+C|0]=(a[z+D|0]|0)+(a[g+C|0]|0)&255;if(D>>>0<q>>>0){C=D}else{B=q;break}}}if(B>>>0<o>>>0){E=B}else{break L10649}while(1){C=E-B|0;D=a[s+C|0]|0;F=D&255;G=a[g+E|0]|0;H=G&255;I=a[g+C|0]|0;C=I&255;J=H+F-C|0;K=J-F|0;F=(K|0)>-1?K:-K|0;K=J-H|0;H=(K|0)>-1?K:-K|0;K=J-C|0;C=(K|0)>-1?K:-K|0;if((F|0)>(H|0)|(F|0)>(C|0)){L=(H|0)>(C|0)?I:G}else{L=D}D=E+1|0;a[s+E|0]=(a[z+D|0]|0)+L&255;if(D>>>0<o>>>0){E=D}else{break}}break};case 3:{if(w){M=0}else{D=0;while(1){G=D+1|0;a[s+D|0]=((d[g+D|0]|0)>>>1)+(a[z+G|0]|0)&255;if(G>>>0<q>>>0){D=G}else{M=q;break}}}if(M>>>0<o>>>0){N=M}else{break L10649}while(1){D=N+1|0;a[s+N|0]=(((d[g+N|0]|0)+(d[s+(N-M)|0]|0)|0)>>>1)+(d[z+D|0]|0)&255;if(D>>>0<o>>>0){N=D}else{break}}break};case 0:{D=z+1|0;X5(s|0,D|0,o)|0;break};case 1:{if(w){O=0}else{D=0;while(1){G=D+1|0;a[s+D|0]=a[z+G|0]|0;if(G>>>0<q>>>0){D=G}else{O=q;break}}}if(O>>>0<o>>>0){P=O}else{break L10649}while(1){D=P+1|0;a[s+P|0]=(a[z+D|0]|0)+(a[s+(P-O)|0]|0)&255;if(D>>>0<o>>>0){P=D}else{break}}break};case 2:{if(x){break L10649}else{Q=0}while(1){D=Q+1|0;a[s+Q|0]=(a[z+D|0]|0)+(a[g+Q|0]|0)&255;if(D>>>0<o>>>0){Q=D}else{break}}break};default:{break L10647}}}while(0);L10679:do{switch(a[m]|0){case 0:{D=c[k>>2]|0;G=a[t]|0;I=G&255;if(G<<24>>24==16){if((D|0)==0){break L10679}else{R=0}while(1){c[A+(R<<2)>>2]=(d[s+(R<<1)|0]|0)*65793|0|-16777216;R=R+1|0;if(R>>>0>=D>>>0){break L10679}}}G=(1<<I)-1|0;if((D|0)==0){break L10679}C=8-I|0;H=(c[17224+(I<<2)>>2]|0)*65793|0;F=0;K=0;while(1){c[A+(K<<2)>>2]=ab(H,(d[s+(F>>>3)|0]|0)>>>((C-(F&7)|0)>>>0)&G)|0|-16777216;J=K+1|0;if(J>>>0<D>>>0){F=F+I|0;K=J}else{break}}break};case 2:{K=c[k>>2]|0;I=(d[t]|0)>>>3;if((K|0)==0){break L10679}F=I<<1;D=F+I|0;G=0;C=s;while(1){c[A+(G<<2)>>2]=d[C]<<16|d[C+I|0]<<8|d[C+F|0]|-16777216;H=G+1|0;if(H>>>0<K>>>0){G=H;C=C+D|0}else{break}}break};case 3:{D=c[k>>2]|0;C=d[t]|0;G=(1<<C)-1|0;if((D|0)==0){break L10679}K=8-C|0;F=0;I=0;while(1){c[A+(I<<2)>>2]=c[h+(((d[s+(F>>>3)|0]|0)>>>((K-(F&7)|0)>>>0)&G)<<2)>>2];H=I+1|0;if(H>>>0<D>>>0){F=F+C|0;I=H}else{break}}break};case 4:{I=c[k>>2]|0;C=(d[t]|0)>>>3;if((I|0)==0){break L10679}F=C<<1;D=0;G=s;while(1){c[A+(D<<2)>>2]=d[G+C|0]<<24|((d[G]|0)*65793|0);K=D+1|0;if(K>>>0<I>>>0){D=K;G=G+F|0}else{break}}break};case 6:{F=c[k>>2]|0;G=(d[t]|0)>>>3;if((F|0)==0){break L10679}D=G<<1;I=D+G|0;C=I+G|0;K=0;H=s;while(1){c[A+(K<<2)>>2]=d[H+G|0]<<8|d[H]<<16|d[H+D|0]|d[H+I|0]<<24;J=K+1|0;if(J>>>0<F>>>0){K=J;H=H+C|0}else{break}}break};default:{}}}while(0);X5(g|0,s|0,o)|0;C=y+1|0;if(C>>>0<(c[l>>2]|0)>>>0){y=C;z=z+n|0;A=A+(c[k>>2]<<2)|0}else{v=1;break L10641}}ec(c[p>>2]|0,93272,(u=i,i=i+8|0,c[u>>2]=439,u)|0)|0;i=u;v=0}}while(0);XZ(s);XZ(g);r=v;i=j;return r|0}function jA(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;b=i;i=i+16|0;d=b|0;e=b+8|0;if((a|0)==0){f=-2;i=b;return f|0}g=c[a+28>>2]|0;if((g|0)==0){f=-2;i=b;return f|0}h=g;j=(c[h+11008>>2]|0)>0?9:8;k=a+4|0;l=c[k>>2]|0;m=h+11e3|0;n=c[m>>2]|0;c[m>>2]=0;m=h+43780|0;if((c[m>>2]|0)<0){f=-3;i=b;return f|0}o=h+11004|0;c[o>>2]=c[o>>2]|1;if((n|0)!=0){c[d>>2]=c[k>>2];n=a+16|0;c[e>>2]=c[n>>2];o=g;p=a|0;q=a+12|0;r=c[q>>2]|0;s=jB(o,c[p>>2]|0,d,r,r,e,j|4)|0;c[m>>2]=s;r=c[d>>2]|0;c[p>>2]=(c[p>>2]|0)+r;c[k>>2]=(c[k>>2]|0)-r;p=a+8|0;c[p>>2]=(c[p>>2]|0)+r;c[a+40>>2]=c[o+28>>2];o=c[e>>2]|0;c[q>>2]=(c[q>>2]|0)+o;c[n>>2]=(c[n>>2]|0)-o;n=a+20|0;c[n>>2]=(c[n>>2]|0)+o;if((s|0)<0){f=-3;i=b;return f|0}if((s|0)==0){f=1;i=b;return f|0}c[m>>2]=-1;f=-5;i=b;return f|0}s=h+10996|0;o=c[s>>2]|0;if((o|0)!=0){n=a+16|0;q=c[n>>2]|0;r=o>>>0<q>>>0?o:q;q=a+12|0;o=c[q>>2]|0;p=h+10992|0;t=(c[p>>2]|0)+(h+11012)|0;X5(o|0,t|0,r)|0;c[q>>2]=(c[q>>2]|0)+r;c[n>>2]=(c[n>>2]|0)-r;n=a+20|0;c[n>>2]=(c[n>>2]|0)+r;n=c[s>>2]|0;c[s>>2]=n-r;c[p>>2]=(c[p>>2]|0)+r&32767;if((c[m>>2]|0)!=0){f=0;i=b;return f|0}f=(n|0)==(r|0)|0;i=b;return f|0}r=h+10992|0;n=g;g=a|0;p=h+11012|0;q=a+8|0;t=n+28|0;o=a+40|0;u=a+16|0;v=a+12|0;w=a+20|0;a=c[r>>2]|0;L10737:do{if((l|0)==0){x=a;while(1){c[d>>2]=c[k>>2];c[e>>2]=32768-x;y=jB(n,c[g>>2]|0,d,p,h+11012+x|0,e,j)|0;c[m>>2]=y;z=c[d>>2]|0;c[g>>2]=(c[g>>2]|0)+z;c[k>>2]=(c[k>>2]|0)-z;c[q>>2]=(c[q>>2]|0)+z;c[o>>2]=c[t>>2];z=c[e>>2]|0;c[s>>2]=z;A=c[u>>2]|0;B=z>>>0<A>>>0?z:A;A=c[v>>2]|0;z=(c[r>>2]|0)+(h+11012)|0;X5(A|0,z|0,B)|0;c[v>>2]=(c[v>>2]|0)+B;c[u>>2]=(c[u>>2]|0)-B;c[w>>2]=(c[w>>2]|0)+B;z=(c[s>>2]|0)-B|0;c[s>>2]=z;A=(c[r>>2]|0)+B&32767;c[r>>2]=A;if((y|0)<0){f=-3;C=7687;break}if((y|0)==0){D=z;break L10737}else if((y|0)==1){f=-5;C=7698;break}if((c[u>>2]|0)==0){f=-5;C=7686;break}else{x=A}}if((C|0)==7687){i=b;return f|0}else if((C|0)==7686){i=b;return f|0}else if((C|0)==7698){i=b;return f|0}}else{x=a;while(1){c[d>>2]=c[k>>2];c[e>>2]=32768-x;A=jB(n,c[g>>2]|0,d,p,h+11012+x|0,e,j)|0;c[m>>2]=A;y=c[d>>2]|0;c[g>>2]=(c[g>>2]|0)+y;c[k>>2]=(c[k>>2]|0)-y;c[q>>2]=(c[q>>2]|0)+y;c[o>>2]=c[t>>2];y=c[e>>2]|0;c[s>>2]=y;z=c[u>>2]|0;B=y>>>0<z>>>0?y:z;z=c[v>>2]|0;y=(c[r>>2]|0)+(h+11012)|0;X5(z|0,y|0,B)|0;c[v>>2]=(c[v>>2]|0)+B;c[u>>2]=(c[u>>2]|0)-B;c[w>>2]=(c[w>>2]|0)+B;y=(c[s>>2]|0)-B|0;c[s>>2]=y;z=(c[r>>2]|0)+B&32767;c[r>>2]=z;if((A|0)<0){f=-3;C=7689;break}if((A|0)==0){D=y;break L10737}if((c[u>>2]|0)==0){f=-5;C=7692;break}else{x=z}}if((C|0)==7689){i=b;return f|0}else if((C|0)==7692){i=b;return f|0}}}while(0);f=(D|0)!=0?-5:1;i=b;return f|0}function jB(e,f,g,h,j,k,l){e=e|0;f=f|0;g=g|0;h=h|0;j=j|0;k=k|0;l=l|0;var m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0,cf=0,cg=0,ch=0,ci=0,cj=0,ck=0,cl=0,cm=0,cn=0,co=0,cp=0,cq=0,cr=0,cs=0,ct=0,cu=0,cv=0,cw=0,cx=0,cy=0,cz=0,cA=0,cB=0,cC=0,cD=0,cE=0,cF=0,cG=0,cH=0,cI=0,cJ=0,cK=0,cL=0,cM=0,cN=0,cO=0,cP=0,cQ=0,cR=0,cS=0,cT=0,cU=0,cV=0,cW=0,cX=0,cY=0,cZ=0,c_=0,c$=0,c0=0,c1=0,c2=0,c3=0,c4=0,c5=0,c6=0,c7=0,c8=0,c9=0,da=0,db=0,dc=0,dd=0,de=0,df=0,dg=0,dh=0,di=0,dj=0,dk=0,dl=0,dm=0,dn=0,dp=0,dq=0,dr=0,ds=0,dt=0,du=0,dv=0,dw=0,dx=0,dy=0,dz=0,dA=0,dB=0,dC=0,dD=0,dE=0,dF=0,dG=0,dH=0,dI=0,dJ=0,dK=0,dL=0,dM=0,dN=0,dO=0,dP=0,dQ=0,dR=0,dS=0,dT=0,dU=0,dV=0,dW=0,dX=0,dY=0,dZ=0,d_=0,d$=0,d0=0,d1=0,d2=0,d3=0,d4=0,d5=0,d6=0,d7=0,d8=0,d9=0,ea=0,eb=0,ec=0,ed=0,ee=0,ef=0,eg=0,eh=0,ei=0,ej=0,ek=0,el=0,em=0,en=0,eo=0,ep=0,eq=0,er=0,es=0,et=0,eu=0,ev=0,ew=0,ex=0,ey=0,ez=0,eA=0,eB=0,eC=0,eD=0,eE=0,eF=0,eG=0,eH=0,eI=0,eJ=0,eK=0,eL=0,eM=0,eN=0,eO=0,eP=0,eQ=0,eR=0,eS=0,eT=0,eU=0,eV=0,eW=0,eX=0,eY=0,eZ=0,e_=0,e$=0,e0=0,e1=0,e2=0,e3=0,e4=0,e5=0,e6=0,e7=0,e8=0,e9=0,fa=0,fb=0,fc=0,fd=0,fe=0,ff=0,fg=0,fh=0,fi=0,fj=0,fk=0,fl=0,fm=0,fn=0,fo=0,fp=0,fq=0,fr=0,fs=0,ft=0,fu=0,fv=0,fw=0,fx=0,fy=0,fz=0,fA=0,fB=0,fC=0,fD=0,fE=0,fF=0,fG=0,fH=0,fI=0,fJ=0,fK=0,fL=0,fM=0,fN=0,fO=0,fP=0,fQ=0,fR=0,fS=0,fT=0,fU=0,fV=0,fW=0,fX=0,fY=0,fZ=0,f_=0,f$=0,f0=0,f1=0,f2=0,f3=0,f4=0,f5=0,f6=0,f7=0,f8=0,f9=0,ga=0,gb=0,gc=0,gd=0,ge=0,gf=0,gg=0,gh=0,gi=0,gj=0,gk=0,gl=0,gm=0,gn=0,go=0,gp=0,gq=0,gr=0,gs=0,gt=0,gu=0,gv=0,gw=0,gx=0,gy=0,gz=0,gA=0,gB=0,gC=0,gD=0,gE=0,gF=0,gG=0,gH=0,gI=0,gJ=0,gK=0,gL=0,gM=0,gN=0,gO=0,gP=0,gQ=0,gR=0,gS=0,gT=0,gU=0,gV=0,gW=0,gX=0,gY=0,gZ=0,g_=0,g$=0,g0=0,g1=0,g2=0,g3=0,g4=0,g5=0,g6=0,g7=0,g8=0,g9=0,ha=0,hb=0,hc=0,hd=0,he=0,hf=0,hg=0,hh=0,hi=0,hj=0,hk=0,hl=0,hm=0,hn=0,ho=0,hp=0,hq=0,hr=0,hs=0,ht=0,hu=0,hv=0,hw=0,hx=0,hy=0,hz=0,hA=0,hB=0,hC=0,hD=0,hE=0,hF=0,hG=0,hH=0,hI=0,hJ=0,hK=0,hL=0,hM=0,hN=0,hO=0,hP=0,hQ=0,hR=0,hS=0,hT=0,hU=0,hV=0,hW=0,hX=0,hY=0,hZ=0,h_=0,h$=0,h0=0,h1=0,h2=0,h3=0,h4=0,h5=0,h6=0,h7=0,h8=0,h9=0,ia=0,ib=0,ic=0,id=0,ie=0,ig=0,ih=0,ii=0,ij=0,ik=0,il=0,im=0,io=0,ip=0,iq=0,ir=0,is=0,it=0,iu=0,iv=0,iw=0,ix=0,iy=0,iz=0,iA=0,iB=0,iC=0,iD=0,iE=0,iF=0,iG=0,iH=0,iI=0,iJ=0,iK=0,iL=0,iM=0,iN=0,iO=0,iP=0,iQ=0,iR=0,iS=0,iT=0,iU=0,iV=0,iW=0,iX=0,iY=0,iZ=0,i_=0,i$=0,i0=0,i1=0,i2=0,i3=0,i4=0,i5=0,i6=0,i7=0,i8=0,i9=0,ja=0,jb=0,jc=0,jd=0,je=0,jf=0,jg=0,jh=0,ji=0,jj=0,jk=0,jl=0,jm=0,jn=0,jo=0,jp=0,jq=0,jr=0,js=0,jt=0,ju=0,jv=0,jw=0,jx=0,jy=0,jz=0,jA=0,jB=0,jC=0,jD=0,jE=0,jF=0,jG=0,jH=0,jI=0,jJ=0,jK=0,jL=0,jM=0,jN=0,jO=0,jP=0,jQ=0,jR=0,jS=0,jT=0,jU=0,jV=0,jW=0,jX=0,jY=0,jZ=0,j_=0,j$=0,j0=0,j1=0,j2=0,j3=0,j4=0,j5=0,j6=0,j7=0,j8=0,j9=0,ka=0,kb=0,kc=0,kd=0,ke=0,kf=0,kg=0,kh=0,ki=0,kj=0,kk=0,kl=0,km=0,kn=0,ko=0,kp=0,kq=0,kr=0,ks=0,kt=0,ku=0,kv=0,kw=0,kx=0,ky=0,kz=0,kA=0,kB=0,kC=0,kD=0,kE=0,kF=0,kG=0,kH=0,kI=0,kJ=0,kK=0,kL=0,kM=0,kN=0,kO=0,kP=0,kQ=0,kR=0,kS=0,kT=0,kU=0,kV=0,kW=0,kX=0,kY=0,kZ=0,k_=0,k$=0,k0=0,k1=0,k2=0,k3=0,k4=0,k5=0,k6=0,k7=0,k8=0,k9=0,la=0,lb=0,lc=0,ld=0,le=0,lf=0,lg=0,lh=0,li=0,lj=0,lk=0,ll=0,lm=0,ln=0,lo=0,lp=0,lq=0,lr=0,ls=0,lt=0,lu=0,lv=0,lw=0,lx=0,ly=0,lz=0,lA=0,lB=0,lC=0,lD=0,lE=0,lF=0,lG=0,lH=0,lI=0,lJ=0,lK=0,lL=0,lM=0,lN=0,lO=0,lP=0,lQ=0,lR=0,lS=0,lT=0,lU=0,lV=0,lW=0,lX=0,lY=0,lZ=0,l_=0,l$=0,l0=0,l1=0,l2=0,l3=0,l4=0,l5=0,l6=0,l7=0,l8=0,l9=0,ma=0,mb=0,mc=0,md=0,me=0,mf=0,mg=0,mh=0,mi=0,mj=0,mk=0,ml=0,mm=0,mn=0,mo=0,mp=0,mq=0,mr=0,ms=0,mt=0,mu=0,mv=0,mw=0,mx=0,my=0,mz=0,mA=0,mB=0,mC=0,mD=0,mE=0,mF=0,mG=0,mH=0,mI=0,mJ=0,mK=0,mL=0,mM=0,mN=0,mO=0,mP=0,mQ=0,mR=0,mS=0,mT=0,mU=0,mV=0,mW=0,mX=0,mY=0,mZ=0,m_=0,m$=0,m0=0,m1=0,m2=0,m3=0,m4=0,m5=0;m=i;i=i+136|0;n=m|0;o=m+72|0;p=c[g>>2]|0;q=f+p|0;r=c[k>>2]|0;s=j+r|0;t=(l&4|0)!=0;if(t){u=-1}else{u=j+~h+r|0}r=u+1|0;if((r&u|0)!=0|j>>>0<h>>>0){c[k>>2]=0;c[g>>2]=0;v=-3;i=m;return v|0}w=e+4|0;y=c[w>>2]|0;z=e+56|0;A=c[z>>2]|0;B=e+32|0;C=c[B>>2]|0;D=e+36|0;E=c[D>>2]|0;F=e+40|0;G=c[F>>2]|0;H=e+60|0;I=c[H>>2]|0;J=e|0;L10763:do{switch(c[J>>2]|0){case 27:{if((p|0)<=0){K=y;L=C;M=E;N=G;O=A;P=I;Q=f;R=j;S=7949;break L10763}T=d[f]|0;U=y;V=C;W=E;X=G;Y=A;Z=I;_=f+1|0;$=j;S=7954;break};case 9:{aa=y;ab=C;ac=E;ad=G;ae=A;af=I;ag=f;ah=j;S=7780;break};case 40:{ai=y;aj=C;ak=E;al=G;am=A;an=I;ao=f;ap=j;S=7785;break};case 10:{aq=y;ar=C;as=E;at=G;au=A;av=I;aw=f;ax=j;S=7787;break};case 52:{ay=y;az=C;aA=E;aB=G;aC=A;aD=I;aE=f;aF=j;S=7776;break};case 34:{aG=y;aH=C;aI=E;aJ=G;aK=A;aL=I;aM=f;aN=j;S=7997;break};case 35:{aO=y;aP=C;aQ=E;aR=G;aS=A;aT=I;aU=f;aV=j;S=7817;break};case 37:{aW=y;aX=C;aY=E;aZ=G;a_=A;a$=I;a0=f;a1=j;S=7957;break};case 6:{if((p|0)<=0){a2=y;a3=C;a4=E;a5=G;a6=A;a7=I;a8=f;a9=j;S=7749;break L10763}ba=y;bb=C;bc=E;bd=G;be=A;bf=d[f]|0;bg=I;bh=f+1|0;bi=j;S=7754;break};case 1:{if((p|0)<=0){bj=y;bk=C;bl=E;bm=G;bn=A;S=7706;break L10763}c[e+8>>2]=d[f]|0;bo=y;bp=C;bq=E;br=G;bs=A;bt=f+1|0;S=7712;break};case 16:{if((p|0)<=0){bu=y;bv=C;bw=E;bx=G;by=A;bz=I;bA=f;bB=j;S=7847;break L10763}bC=d[f]|0;bD=y;bE=C;bF=E;bG=G;bH=A;bI=I;bJ=f+1|0;bK=j;S=7852;break};case 51:{if((p|0)<=0){bL=y;bM=C;bN=E;bO=G;bP=A;bQ=I;bR=f;bS=j;S=7769;break L10763}bT=y;bU=C;bV=E;bW=G;bX=A;bY=d[f]|0;bZ=I;b_=f+1|0;b$=j;S=7774;break};case 39:{b0=y;b1=C;b2=E;b3=G;b4=A;b5=I;b6=f;b7=j;S=7765;break};case 36:{b8=y;b9=C;ca=E;cb=G;cc=A;cd=f;S=7726;break};case 24:{ce=y;cf=C;cg=E;ch=G;ci=A;cj=I;ck=f;cl=j;S=7897;break};case 18:{if((p|0)<=0){cm=y;cn=C;co=E;cp=G;cq=A;cr=I;cs=f;ct=j;S=7863;break L10763}cu=d[f]|0;cv=y;cw=C;cx=E;cy=G;cz=A;cA=I;cB=f+1|0;cC=j;S=7868;break};case 25:{if((p|0)<=0){cD=y;cE=C;cF=E;cG=G;cH=A;cI=I;cJ=f;cK=j;S=7920;break L10763}cL=d[f]|0;cM=y;cN=C;cO=E;cP=G;cQ=A;cR=I;cS=f+1|0;cT=j;S=7925;break};case 5:{if((p|0)<=0){cU=y;cV=C;cW=E;cX=G;cY=A;cZ=I;c_=f;c$=j;S=7738;break L10763}c0=y;c1=C;c2=E;c3=G;c4=A;c5=d[f]|0;c6=I;c7=f+1|0;c8=j;S=7743;break};case 2:{if((p|0)<=0){c9=y;da=C;db=E;dc=G;dd=A;de=f;S=7713;break L10763}df=d[f]|0;c[e+12>>2]=df;dg=y;dh=C;di=G;dj=A;dk=f+1|0;dl=df;S=7719;break};case 32:{if((p|0)<=0){dm=y;dn=C;dp=E;dq=G;dr=A;ds=I;dt=f;du=j;S=7972;break L10763}dv=d[f]|0;dw=y;dx=C;dy=E;dz=G;dA=A;dB=I;dC=f+1|0;dD=j;S=7977;break};case 14:{if((p|0)<=0){dE=y;dF=C;dG=E;dH=G;dI=A;dJ=I;dK=f;dL=j;S=7802;break L10763}dM=y;dN=C;dO=E;dP=d[f]|0;dQ=G;dR=A;dS=I;dT=f+1|0;dU=j;S=7807;break};case 11:{if((p|0)<=0){dV=y;dW=C;dX=E;dY=G;dZ=A;d_=I;d$=f;d0=j;S=7791;break L10763}d1=y;d2=C;d3=E;d4=G;d5=d[f]|0;d6=A;d7=I;d8=f+1|0;d9=j;S=7796;break};case 21:{ea=y;eb=C;ec=E;ed=G;ee=A;ef=I;eg=f;eh=j;S=7873;break};case 3:{if((p|0)<=0){ei=y;ej=C;ek=E;el=G;em=A;en=I;eo=f;ep=j;S=7729;break L10763}eq=y;er=C;es=E;et=G;eu=A;ev=d[f]|0;ew=I;ex=f+1|0;ey=j;S=7734;break};case 0:{c[e+12>>2]=0;df=e+8|0;c[df>>2]=0;c[e+28>>2]=1;c[e+16>>2]=1;if((l&1|0)==0){ez=0;eA=0;eB=0;eC=0;eD=0;eE=I;eF=f;eG=j;S=7727;break L10763}if((p|0)<1){bj=0;bk=0;bl=0;bm=0;bn=0;S=7706;break L10763}c[df>>2]=d[f]|0;bo=0;bp=0;bq=0;br=0;bs=0;bt=f+1|0;S=7712;break};case 26:{if((p|0)<=0){eH=y;eI=C;eJ=E;eK=G;eL=A;eM=I;eN=f;eO=j;S=7936;break L10763}eP=d[f]|0;eQ=y;eR=C;eS=E;eT=G;eU=A;eV=I;eW=f+1|0;eX=j;S=7941;break};case 41:{if((p|0)<=0){eY=y;eZ=C;e_=E;e$=G;e0=A;e1=I;e2=f;e3=j;S=7983;break L10763}e4=d[f]|0;e5=y;e6=C;e7=E;e8=G;e9=A;fa=I;fb=f+1|0;fc=j;S=7988;break};case 53:{fd=y;fe=C;ff=E;fg=G;fh=A;fi=I;fj=f;fk=j;S=7960;break};case 17:{fl=y;fm=C;fn=E;fo=G;fp=A;fq=I;fr=f;fs=j;S=7860;break};case 42:{if((p|0)<=0){ft=y;fu=C;fv=E;fw=G;fx=A;fy=I;fz=f;fA=j;S=7991;break L10763}fB=d[f]|0;fC=y;fD=C;fE=E;fF=G;fG=A;fH=I;fI=f+1|0;fJ=j;S=7996;break};case 23:{if((p|0)<=0){fK=y;fL=C;fM=E;fN=G;fO=A;fP=I;fQ=f;fR=j;S=7886;break L10763}fS=d[f]|0;fT=y;fU=C;fV=E;fW=G;fX=A;fY=I;fZ=f+1|0;f_=j;S=7891;break};case 38:{f$=y;f0=C;f1=E;f2=G;f3=A;f4=I;f5=f;f6=j;S=7782;break};case 7:{if((p|0)<=0){f7=y;f8=C;f9=E;ga=G;gb=A;gc=I;gd=f;ge=j;S=7757;break L10763}a[e+10528+E|0]=a[f]|0;gf=y;gg=C;gh=E;gi=G;gj=A;gk=I;gl=f+1|0;gm=j;S=7763;break};default:{gn=-1;go=y;gp=C;gq=E;gr=G;gs=A;gt=I;gu=f;gv=j;S=7998}}}while(0);do{if((S|0)==7706){if((l&2|0)==0){c[e+8>>2]=0;bo=bj;bp=bk;bq=bl;br=bm;bs=bn;bt=f;S=7712;break}else{c[J>>2]=1;gn=1;go=bj;gp=bk;gq=bl;gr=bm;gs=bn;gt=I;gu=f;gv=j;S=7998;break}}}while(0);do{if((S|0)==7712){if(bt>>>0>=q>>>0){c9=bo;da=bp;db=bq;dc=br;dd=bs;de=bt;S=7713;break}bn=d[bt]|0;c[e+12>>2]=bn;dg=bo;dh=bp;di=br;dj=bs;dk=bt+1|0;dl=bn;S=7719}}while(0);do{if((S|0)==7713){if((l&2|0)==0){c[e+12>>2]=0;dg=c9;dh=da;di=dc;dj=dd;dk=de;dl=0;S=7719;break}else{c[J>>2]=2;gn=1;go=c9;gp=da;gq=db;gr=dc;gs=dd;gt=I;gu=de;gv=j;S=7998;break}}}while(0);if((S|0)==7719){de=c[e+8>>2]|0;if((((de<<8|dl)>>>0)%31|0|dl&32|0)==0){gw=(de&15|0)!=8|0}else{gw=1}if(t){gx=gw}else{dl=1<<(de>>>4)+8;if(dl>>>0>32768){gy=1}else{gy=r>>>0<dl>>>0|0}gx=gy|gw}if((gx|0)==0){ez=dg;eA=dh;eB=0;eC=di;eD=dj;eE=I;eF=dk;eG=j;S=7727}else{b8=dg;b9=dh;ca=gx;cb=di;cc=dj;cd=dk;S=7726}}if((S|0)==7726){c[J>>2]=36;gn=-1;go=b8;gp=b9;gq=ca;gr=cb;gs=cc;gt=I;gu=cd;gv=j;S=7998}L10829:while(1){do{if((S|0)==7949){S=0;if((l&2|0)==0){T=0;U=K;V=L;W=M;X=N;Y=O;Z=P;_=Q;$=R;S=7954;continue L10829}c[J>>2]=27;gn=1;go=K;gp=L;gq=M;gr=N;gs=O;gt=P;gu=Q;gv=R;S=7998;continue L10829}else if((S|0)==7852){S=0;cd=bC<<bD|bH;I=bD+8|0;if(I>>>0<15){gz=I;gA=bE;gB=bF;gC=bG;gD=cd;gE=bI;gF=bJ;gG=bK;S=7840}else{gH=I;gI=bF;gJ=bG;gK=cd;gL=bI;gM=bJ;gN=bK;S=7854}}else if((S|0)==7780){S=0;if(ah>>>0<s>>>0){f$=aa;f0=ab;f1=ac;f2=ad;f3=ae;f4=af;f5=ag;f6=ah;S=7782;continue L10829}c[J>>2]=9;gn=2;go=aa;gp=ab;gq=ac;gr=ad;gs=ae;gt=af;gu=ag;gv=ah;S=7998;continue L10829}else if((S|0)==7785){S=0;c[J>>2]=40;gn=-1;go=ai;gp=aj;gq=ak;gr=al;gs=am;gt=an;gu=ao;gv=ap;S=7998;continue L10829}else if((S|0)==7787){S=0;c[J>>2]=10;gn=-1;go=aq;gp=ar;gq=as;gr=at;gs=au;gt=av;gu=aw;gv=ax;S=7998;continue L10829}else if((S|0)==7754){S=0;cd=bf<<ba|be;I=ba+8|0;if(ba>>>0>4294967287){gO=I;gP=bb;gQ=bc;gR=bd;gS=cd;gT=bg;gU=bh;gV=bi;S=7748}else{gW=I;gX=bb;gY=bc;gZ=bd;g_=cd;g$=bg;g0=bh;g1=bi;S=7755}}else if((S|0)==7776){S=0;if(aF>>>0<s>>>0){a[aF]=az&255;g2=ay;g3=az;g4=aA-1|0;g5=aB;g6=aC;g7=aD;g8=aE;g9=aF+1|0;S=7766;break}else{c[J>>2]=52;gn=2;go=ay;gp=az;gq=aA;gr=aB;gs=aC;gt=aD;gu=aE;gv=aF;S=7998;continue L10829}}else if((S|0)==7941){S=0;cd=eP<<eQ|eU;I=eQ+8|0;if(I>>>0<15){ha=I;hb=eR;hc=eS;hd=eT;he=cd;hf=eV;hg=eW;hh=eX;S=7929}else{hi=I;hj=eS;hk=cd;hl=eV;hm=eW;hn=eX;S=7943}}else if((S|0)==7997){S=0;c[J>>2]=34;gn=0;go=aG;gp=aH;gq=aI;gr=aJ;gs=aK;gt=aL;gu=aM;gv=aN;S=7998;continue L10829}else if((S|0)==7998){S=0;c[w>>2]=go;c[z>>2]=gs;c[B>>2]=gp;c[D>>2]=gq;c[F>>2]=gr;c[H>>2]=gt;c[g>>2]=gu-f;ho=gv-j|0;c[k>>2]=ho;if((l&9|0)!=0&(gn|0)>-1){break L10829}else{v=gn;S=8011;break L10829}}else if((S|0)==7817){S=0;c[J>>2]=35;gn=-1;go=aO;gp=aP;gq=aQ;gr=aR;gs=aS;gt=aT;gu=aU;gv=aV;S=7998;continue L10829}else if((S|0)==7796){S=0;cd=d5<<d1|d6;I=d1+8|0;cc=a[95880+d3|0]|0;if(I>>>0<cc<<24>>24>>>0){hp=I;hq=d2;hr=d3;hs=d4;ht=cd;hu=d7;hv=d8;hw=d9;S=7790}else{hx=I;hy=d2;hz=d3;hA=d4;hB=cd;hC=d7;hD=d8;hE=d9;hF=cc;S=7797}}else if((S|0)==7957){S=0;c[J>>2]=37;gn=-1;go=aW;gp=aX;gq=aY;gr=aZ;gs=a_;gt=a$;gu=a0;gv=a1;S=7998;continue L10829}else if((S|0)==7847){S=0;if((l&2|0)==0){bC=0;bD=bu;bE=bv;bF=bw;bG=bx;bH=by;bI=bz;bJ=bA;bK=bB;S=7852;continue L10829}c[J>>2]=16;gn=1;go=bu;gp=bv;gq=bw;gr=bx;gs=by;gt=bz;gu=bA;gv=bB;S=7998;continue L10829}else if((S|0)==7749){S=0;if((l&2|0)==0){ba=a2;bb=a3;bc=a4;bd=a5;be=a6;bf=0;bg=a7;bh=a8;bi=a9;S=7754;continue L10829}c[J>>2]=6;gn=1;go=a2;gp=a3;gq=a4;gr=a5;gs=a6;gt=a7;gu=a8;gv=a9;S=7998;continue L10829}else if((S|0)==7954){S=0;cc=T<<U|Y;cd=U+8|0;if(cd>>>0<X>>>0){hG=cd;hH=V;hI=W;hJ=X;hK=cc;hL=Z;hM=_;hN=$;S=7948}else{hO=cd;hP=V;hQ=W;hR=X;hS=cc;hT=_;hU=$;S=7955}}else if((S|0)==7807){S=0;cc=dP<<dM|dR;cd=dM+8|0;if(cd>>>0<3){hV=cd;hW=dN;hX=dO;hY=dQ;hZ=cc;h_=dS;h$=dT;h0=dU;S=7801}else{h1=cd;h2=dN;h3=dO;h4=dQ;h5=cc;h6=dS;h7=dT;h8=dU;S=7808}}else if((S|0)==7757){S=0;if((l&2|0)==0){a[e+10528+f9|0]=0;gf=f7;gg=f8;gh=f9;gi=ga;gj=gb;gk=gc;gl=gd;gm=ge;S=7763;continue L10829}else{c[J>>2]=7;gn=1;go=f7;gp=f8;gq=f9;gr=ga;gs=gb;gt=gc;gu=gd;gv=ge;S=7998;continue L10829}}else if((S|0)==7765){S=0;c[J>>2]=39;gn=-1;go=b0;gp=b1;gq=b2;gr=b3;gs=b4;gt=b5;gu=b6;gv=b7;S=7998;continue L10829}else if((S|0)==7743){S=0;cc=c5<<c0|c4;cd=c0+8|0;if(cd>>>0<(cd&7)>>>0){h9=cd;ia=c1;ib=c2;ic=c3;id=cc;ie=c6;ig=c7;ih=c8;S=7737}else{ii=cd;ij=c1;ik=c3;il=cc;im=c6;io=c7;ip=c8;S=7744}}else if((S|0)==7763){S=0;iq=gf;ir=gg;is=gh+1|0;it=gi;iu=gj;iv=gk;iw=gl;ix=gm;S=7745}else if((S|0)==7897){S=0;if(cl>>>0<s>>>0){a[cl]=cg&255;iy=ce;iz=cf;iA=cg;iB=ch;iC=ci;iD=cj;iE=ck;iF=cl+1|0;S=7900;break}else{c[J>>2]=24;gn=2;go=ce;gp=cf;gq=cg;gr=ch;gs=ci;gt=cj;gu=ck;gv=cl;S=7998;continue L10829}}else if((S|0)==7925){S=0;cc=cL<<cM|cQ;cd=cM+8|0;if(cd>>>0<cP>>>0){iG=cd;iH=cN;iI=cO;iJ=cP;iK=cc;iL=cR;iM=cS;iN=cT;S=7919}else{iO=cd;iP=cN;iQ=cO;iR=cP;iS=cc;iT=cR;iU=cS;iV=cT;S=7926}}else if((S|0)==7791){S=0;if((l&2|0)==0){d1=dV;d2=dW;d3=dX;d4=dY;d5=0;d6=dZ;d7=d_;d8=d$;d9=d0;S=7796;continue L10829}c[J>>2]=11;gn=1;go=dV;gp=dW;gq=dX;gr=dY;gs=dZ;gt=d_;gu=d$;gv=d0;S=7998;continue L10829}else if((S|0)==7738){S=0;if((l&2|0)==0){c0=cU;c1=cV;c2=cW;c3=cX;c4=cY;c5=0;c6=cZ;c7=c_;c8=c$;S=7743;continue L10829}c[J>>2]=5;gn=1;go=cU;gp=cV;gq=cW;gr=cX;gs=cY;gt=cZ;gu=c_;gv=c$;S=7998;continue L10829}else if((S|0)==7988){S=0;cc=e4<<e5|e9;cd=e5+8|0;if(e5>>>0>4294967287){iW=cd;iX=e6;iY=e7;iZ=e8;i_=cc;i$=fa;i0=fb;i1=fc;S=7982}else{i2=cd;i3=e6;i4=e7;i5=e8;i6=cc;i7=fa;i8=fb;i9=fc;S=7989}}else if((S|0)==7991){S=0;if((l&2|0)==0){fB=0;fC=ft;fD=fu;fE=fv;fF=fw;fG=fx;fH=fy;fI=fz;fJ=fA;S=7996;continue L10829}c[J>>2]=42;gn=1;go=ft;gp=fu;gq=fv;gr=fw;gs=fx;gt=fy;gu=fz;gv=fA;S=7998;continue L10829}else if((S|0)==7920){S=0;if((l&2|0)==0){cL=0;cM=cD;cN=cE;cO=cF;cP=cG;cQ=cH;cR=cI;cS=cJ;cT=cK;S=7925;continue L10829}c[J>>2]=25;gn=1;go=cD;gp=cE;gq=cF;gr=cG;gs=cH;gt=cI;gu=cJ;gv=cK;S=7998;continue L10829}else if((S|0)==7886){S=0;if((l&2|0)==0){fS=0;fT=fK;fU=fL;fV=fM;fW=fN;fX=fO;fY=fP;fZ=fQ;f_=fR;S=7891;continue L10829}c[J>>2]=23;gn=1;go=fK;gp=fL;gq=fM;gr=fN;gs=fO;gt=fP;gu=fQ;gv=fR;S=7998;continue L10829}else if((S|0)==7972){S=0;if((l&2|0)==0){dv=0;dw=dm;dx=dn;dy=dp;dz=dq;dA=dr;dB=ds;dC=dt;dD=du;S=7977;continue L10829}c[J>>2]=32;gn=1;go=dm;gp=dn;gq=dp;gr=dq;gs=dr;gt=ds;gu=dt;gv=du;S=7998;continue L10829}else if((S|0)==7734){S=0;cc=ev<<eq|eu;cd=eq+8|0;if(cd>>>0<3){ja=cd;jb=er;jc=es;jd=et;je=cc;jf=ew;jg=ex;jh=ey;S=7728}else{ji=cd;jj=er;jk=es;jl=et;jm=cc;jn=ew;jo=ex;jp=ey;S=7735}}else if((S|0)==7774){S=0;cc=bY<<bT|bX;cd=bT+8|0;if(bT>>>0>4294967287){jq=cd;jr=bU;js=bV;jt=bW;ju=cc;jv=bZ;jw=b_;jx=b$;S=7768}else{jy=cd;jz=bV;jA=bW;jB=cc;jC=bZ;jD=b_;jE=b$;S=7775}}else if((S|0)==7977){S=0;cc=dv<<dw|dA;cd=dw+8|0;if(cd>>>0<(cd&7)>>>0){jF=cd;jG=dx;jH=dy;jI=dz;jJ=cc;jK=dB;jL=dC;jM=dD;S=7971}else{jN=cd;jO=dx;jP=dz;jQ=cc;jR=dB;jS=dC;jT=dD;S=7978}}else if((S|0)==7873){S=0;c[J>>2]=21;gn=-1;go=ea;gp=eb;gq=ec;gr=ed;gs=ee;gt=ef;gu=eg;gv=eh;S=7998;continue L10829}else if((S|0)==7802){S=0;if((l&2|0)==0){dM=dE;dN=dF;dO=dG;dP=0;dQ=dH;dR=dI;dS=dJ;dT=dK;dU=dL;S=7807;continue L10829}c[J>>2]=14;gn=1;go=dE;gp=dF;gq=dG;gr=dH;gs=dI;gt=dJ;gu=dK;gv=dL;S=7998;continue L10829}else if((S|0)==7727){S=0;if(ez>>>0<3){ja=ez;jb=eA;jc=eB;jd=eC;je=eD;jf=eE;jg=eF;jh=eG;S=7728}else{ji=ez;jj=eA;jk=eB;jl=eC;jm=eD;jn=eE;jo=eF;jp=eG;S=7735}}else if((S|0)==7769){S=0;if((l&2|0)==0){bT=bL;bU=bM;bV=bN;bW=bO;bX=bP;bY=0;bZ=bQ;b_=bR;b$=bS;S=7774;continue L10829}c[J>>2]=51;gn=1;go=bL;gp=bM;gq=bN;gr=bO;gs=bP;gt=bQ;gu=bR;gv=bS;S=7998;continue L10829}else if((S|0)==7863){S=0;if((l&2|0)==0){cu=0;cv=cm;cw=cn;cx=co;cy=cp;cz=cq;cA=cr;cB=cs;cC=ct;S=7868;continue L10829}c[J>>2]=18;gn=1;go=cm;gp=cn;gq=co;gr=cp;gs=cq;gt=cr;gu=cs;gv=ct;S=7998;continue L10829}else if((S|0)==7936){S=0;if((l&2|0)==0){eP=0;eQ=eH;eR=eI;eS=eJ;eT=eK;eU=eL;eV=eM;eW=eN;eX=eO;S=7941;continue L10829}c[J>>2]=26;gn=1;go=eH;gp=eI;gq=eJ;gr=eK;gs=eL;gt=eM;gu=eN;gv=eO;S=7998;continue L10829}else if((S|0)==7983){S=0;if((l&2|0)==0){e4=0;e5=eY;e6=eZ;e7=e_;e8=e$;e9=e0;fa=e1;fb=e2;fc=e3;S=7988;continue L10829}c[J>>2]=41;gn=1;go=eY;gp=eZ;gq=e_;gr=e$;gs=e0;gt=e1;gu=e2;gv=e3;S=7998;continue L10829}else if((S|0)==7960){S=0;if(fk>>>0<s>>>0){a[fk]=a[h+(fi-fe&u)|0]|0;jU=fd;jV=fe;jW=ff;jX=fg;jY=fh;jZ=fi+1|0;j_=fj;j$=fk+1|0;S=7959;break}else{c[J>>2]=53;gn=2;go=fd;gp=fe;gq=ff;gr=fg;gs=fh;gt=fi;gu=fj;gv=fk;S=7998;continue L10829}}else if((S|0)==7868){S=0;cc=cu<<cv|cz;cd=cv+8|0;if(cd>>>0<cy>>>0){j0=cd;j1=cw;j2=cx;j3=cy;j4=cc;j5=cA;j6=cB;j7=cC;S=7862}else{j8=cd;j9=cw;ka=cx;kb=cy;kc=cc;kd=cA;ke=cB;kf=cC;S=7869}}else if((S|0)==7860){S=0;c[J>>2]=17;gn=-1;go=fl;gp=fm;gq=fn;gr=fo;gs=fp;gt=fq;gu=fr;gv=fs;S=7998;continue L10829}else if((S|0)==7996){S=0;cc=e+16|0;c[cc>>2]=c[cc>>2]<<8|fB;kg=fC;kh=fD;ki=fE+1|0;kj=fF;kk=fG;kl=fH;km=fI;kn=fJ;S=7979}else if((S|0)==7891){S=0;cc=fS<<fT|fX;cd=fT+8|0;if(cd>>>0<15){ko=cd;kp=fU;kq=fV;kr=fW;ks=cc;kt=fY;ku=fZ;kv=f_;S=7879}else{kw=cd;kx=fU;ky=fW;kz=cc;kA=fY;kB=fZ;kC=f_;S=7893}}else if((S|0)==7782){S=0;if(f5>>>0<q>>>0){cc=s-f6|0;cd=q-f5|0;I=cc>>>0<cd>>>0?cc:cd;cd=I>>>0<f1>>>0?I:f1;X5(f6|0,f5|0,cd)|0;kD=f$;kE=f0;kF=f1-cd|0;kG=f2;kH=f3;kI=f4;kJ=f5+cd|0;kK=f6+cd|0;S=7779;break}if((l&2|0)==0){ai=f$;aj=f0;ak=f1;al=f2;am=f3;an=f4;ao=f5;ap=f6;S=7785;continue L10829}c[J>>2]=38;gn=1;go=f$;gp=f0;gq=f1;gr=f2;gs=f3;gt=f4;gu=f5;gv=f6;S=7998;continue L10829}else if((S|0)==7729){S=0;if((l&2|0)==0){eq=ei;er=ej;es=ek;et=el;eu=em;ev=0;ew=en;ex=eo;ey=ep;S=7734;continue L10829}c[J>>2]=3;gn=1;go=ei;gp=ej;gq=ek;gr=el;gs=em;gt=en;gu=eo;gv=ep;S=7998;continue L10829}}while(0);if((S|0)==7728){S=0;if(jg>>>0>=q>>>0){ei=ja;ej=jb;ek=jc;el=jd;em=je;en=jf;eo=jg;ep=jh;S=7729;continue}eq=ja;er=jb;es=jc;et=jd;eu=je;ev=d[jg]|0;ew=jf;ex=jg+1|0;ey=jh;S=7734;continue}do{if((S|0)==7735){S=0;cd=jm&7;c[e+20>>2]=cd;I=jm>>>3;cc=ji-3|0;cb=cd>>>1;cd=e+24|0;c[cd>>2]=cb;if((cb|0)==3){aq=cc;ar=jj;as=jk;at=jl;au=I;av=jn;aw=jo;ax=jp;S=7787;continue L10829}else if((cb|0)==1){c[e+44>>2]=288;c[e+48>>2]=32;X2(e+3552|0,5,32);X2(e+64|0,8,144);X2(e+208|0,9,112);X2(e+320|0,7,24);ca=e+344|0;b9=ca|0;x=134744072;a[b9]=x&255;x=x>>8;a[b9+1|0]=x&255;x=x>>8;a[b9+2|0]=x&255;x=x>>8;a[b9+3|0]=x&255;b9=ca+4|0;x=134744072;a[b9]=x&255;x=x>>8;a[b9+1|0]=x&255;x=x>>8;a[b9+2|0]=x&255;x=x>>8;a[b9+3|0]=x&255;kL=cc;kM=jj;kN=jk;kO=jl;kP=I;kQ=jn;kR=jo;kS=jp;kT=cd;kU=1;S=7811;break}else if((cb|0)==0){if(cc>>>0<(cc&7)>>>0){h9=cc;ia=jj;ib=jk;ic=jl;id=I;ie=jn;ig=jo;ih=jp;S=7737;break}else{ii=cc;ij=jj;ik=jl;il=I;im=jn;io=jo;ip=jp;S=7744;break}}else{kV=cc;kW=jj;kX=0;kY=jl;kZ=I;k_=jn;k$=jo;k0=jp;S=7788;break}}}while(0);if((S|0)==7744){S=0;I=ii&7;iq=ii-I|0;ir=ij;is=0;it=ik;iu=il>>>(I>>>0);iv=im;iw=io;ix=ip;S=7745}else if((S|0)==7737){S=0;if(ig>>>0>=q>>>0){cU=h9;cV=ia;cW=ib;cX=ic;cY=id;cZ=ie;c_=ig;c$=ih;S=7738;continue}c0=h9;c1=ia;c2=ib;c3=ic;c4=id;c5=d[ig]|0;c6=ie;c7=ig+1|0;c8=ih;S=7743;continue}do{if((S|0)==7745){S=0;if(is>>>0>=4){I=d[e+10529|0]<<8|d[e+10528|0];if((I|0)==((d[e+10531|0]<<8|d[e+10530|0])^65535|0)){g2=iq;g3=ir;g4=I;g5=it;g6=iu;g7=iv;g8=iw;g9=ix;S=7766;break}else{b0=iq;b1=ir;b2=I;b3=it;b4=iu;b5=iv;b6=iw;b7=ix;S=7765;continue L10829}}if((iq|0)!=0){if(iq>>>0<8){gO=iq;gP=ir;gQ=is;gR=it;gS=iu;gT=iv;gU=iw;gV=ix;S=7748;break}else{gW=iq;gX=ir;gY=is;gZ=it;g_=iu;g$=iv;g0=iw;g1=ix;S=7755;break}}if(iw>>>0>=q>>>0){f7=0;f8=ir;f9=is;ga=it;gb=iu;gc=iv;gd=iw;ge=ix;S=7757;continue L10829}a[e+10528+is|0]=a[iw]|0;gf=0;gg=ir;gh=is;gi=it;gj=iu;gk=iv;gl=iw+1|0;gm=ix;S=7763;continue L10829}}while(0);do{if((S|0)==7755){S=0;a[e+10528+gY|0]=g_&255;gf=gW-8|0;gg=gX;gh=gY;gi=gZ;gj=g_>>>8;gk=g$;gl=g0;gm=g1;S=7763;continue L10829}else if((S|0)==7748){S=0;if(gU>>>0>=q>>>0){a2=gO;a3=gP;a4=gQ;a5=gR;a6=gS;a7=gT;a8=gU;a9=gV;S=7749;continue L10829}ba=gO;bb=gP;bc=gQ;bd=gR;be=gS;bf=d[gU]|0;bg=gT;bh=gU+1|0;bi=gV;S=7754;continue L10829}else if((S|0)==7766){S=0;if((g4|0)==0|(g2|0)==0){kD=g2;kE=g3;kF=g4;kG=g5;kH=g6;kI=g7;kJ=g8;kK=g9;S=7779;break}if(g2>>>0<8){jq=g2;jr=g3;js=g4;jt=g5;ju=g6;jv=g7;jw=g8;jx=g9;S=7768}else{jy=g2;jz=g4;jA=g5;jB=g6;jC=g7;jD=g8;jE=g9;S=7775}}}while(0);if((S|0)==7775){S=0;ay=jy-8|0;az=jB&255;aA=jz;aB=jA;aC=jB>>>8;aD=jC;aE=jD;aF=jE;S=7776;continue}else if((S|0)==7768){S=0;if(jw>>>0>=q>>>0){bL=jq;bM=jr;bN=js;bO=jt;bP=ju;bQ=jv;bR=jw;bS=jx;S=7769;continue}bT=jq;bU=jr;bV=js;bW=jt;bX=ju;bY=d[jw]|0;bZ=jv;b_=jw+1|0;b$=jx;S=7774;continue}else if((S|0)==7779){S=0;if((kF|0)==0){k1=kD;k2=kE;k3=0;k4=kG;k5=kH;k6=kI;k7=kJ;k8=kK;S=7968}else{aa=kD;ab=kE;ac=kF;ad=kG;ae=kH;af=kI;ag=kJ;ah=kK;S=7780;continue}}L10942:while(1){L10943:do{if((S|0)==7788){S=0;if(kX>>>0<3){I=a[95880+kX|0]|0;if(kV>>>0<I<<24>>24>>>0){hp=kV;hq=kW;hr=kX;hs=kY;ht=kZ;hu=k_;hv=k$;hw=k0;S=7790;continue L10942}else{hx=kV;hy=kW;hz=kX;hA=kY;hB=kZ;hC=k_;hD=k$;hE=k0;hF=I;S=7797;continue L10942}}else{X2(e+7040|0,0,288);k9=kV;la=kW;lb=0;lc=kY;ld=kZ;le=k_;lf=k$;lg=k0;S=7799;break}}else if((S|0)==7790){S=0;if(hv>>>0<q>>>0){S=7795;break L10942}else{dV=hp;dW=hq;dX=hr;dY=hs;dZ=ht;d_=hu;d$=hv;d0=hw;S=7791;continue L10829}}else if((S|0)==7811){S=0;if((kU|0)<=-1){iy=kL;iz=kM;iA=kN;iB=kO;iC=kP;iD=kQ;iE=kR;iF=kS;S=7900;continue L10942}X2(o|0,0,64);X2(e+64+(kU*3488|0)+288|0,0,3200);I=c[kT>>2]|0;cc=c[e+44+(I<<2)>>2]|0;if((cc|0)==0){lh=0;li=0;lj=0;lk=0;ll=0;lm=0;ln=0;lo=0;lp=0;lq=0;lr=0;ls=0;lt=0;lu=0;lv=0;lw=0}else{cb=0;do{cd=o+(d[e+64+(kU*3488|0)+cb|0]<<2)|0;c[cd>>2]=(c[cd>>2]|0)+1;cb=cb+1|0;}while(cb>>>0<cc>>>0);lh=c[o+4>>2]|0;li=c[o+8>>2]|0;lj=c[o+12>>2]|0;lk=c[o+16>>2]|0;ll=c[o+20>>2]|0;lm=c[o+24>>2]|0;ln=c[o+28>>2]|0;lo=c[o+32>>2]|0;lp=c[o+36>>2]|0;lq=c[o+40>>2]|0;lr=c[o+44>>2]|0;ls=c[o+48>>2]|0;lt=c[o+52>>2]|0;lu=c[o+56>>2]|0;lv=c[o+60>>2]|0;lw=cc}c[n+4>>2]=0;c[n>>2]=0;cb=lh<<1;c[n+8>>2]=cb;cd=cb+li<<1;c[n+12>>2]=cd;cb=cd+lj<<1;c[n+16>>2]=cb;cd=cb+lk<<1;c[n+20>>2]=cd;cb=cd+ll<<1;c[n+24>>2]=cb;cd=cb+lm<<1;c[n+28>>2]=cd;cb=cd+ln<<1;c[n+32>>2]=cb;cd=cb+lo<<1;c[n+36>>2]=cd;cb=cd+lp<<1;c[n+40>>2]=cb;cd=cb+lq<<1;c[n+44>>2]=cd;cb=cd+lr<<1;c[n+48>>2]=cb;cd=cb+ls<<1;c[n+52>>2]=cd;cb=cd+lt<<1;c[n+56>>2]=cb;cd=cb+lu<<1;c[n+60>>2]=cd;cb=cd+lv<<1;c[n+64>>2]=cb;if((cb|0)!=65536&(lu+lv+lt+ls+lr+lq+lp+lo+ln+lm+ll+lk+lj+li+lh|0)>>>0>1){aO=kL;aP=kM;aQ=kN;aR=kO;aS=kP;aT=kQ;aU=kR;aV=kS;S=7817;continue L10829}if((lw|0)==0){lx=I}else{cb=-1;cd=0;while(1){b9=a[e+64+(kU*3488|0)+cd|0]|0;ca=b9&255;L10960:do{if(b9<<24>>24==0){ly=cb}else{b8=n+(ca<<2)|0;dk=c[b8>>2]|0;c[b8>>2]=dk+1;b8=0;dj=ca;di=dk;while(1){lz=b8<<1|di&1;dk=dj-1|0;if((dk|0)==0){break}else{b8=lz;dj=dk;di=di>>>1}}if((b9&255)<11){di=(ca<<9|cd)&65535;if(lz>>>0>=1024){ly=cb;break}dj=1<<ca;dk=lz;while(1){b[e+64+(kU*3488|0)+288+(dk<<1)>>1]=di;gx=dk+dj|0;if(gx>>>0<1024){dk=gx}else{ly=cb;break L10960}}}dk=e+64+(kU*3488|0)+288+((lz&1023)<<1)|0;dj=b[dk>>1]|0;if(dj<<16>>16==0){b[dk>>1]=cb&65535;lA=cb;lB=cb-2|0}else{lA=dj<<16>>16;lB=cb}dj=b8>>>9;dk=lA-(dj&1)|0;if((b9&255)>11){di=lB;gx=ca;dh=dj&4194303;dj=dk;while(1){dg=e+64+(kU*3488|0)+2336+(~dj<<1)|0;gw=b[dg>>1]|0;if(gw<<16>>16==0){b[dg>>1]=di&65535;lC=di;lD=di-2|0}else{lC=gw<<16>>16;lD=di}gw=gx-1|0;dg=dh>>>1;gy=lC-(dg&1)|0;if(gw>>>0>11){di=lD;gx=gw;dh=dg;dj=gy}else{lE=lD;lF=gy;break}}}else{lE=lB;lF=dk}b[e+64+(kU*3488|0)+2336+(~lF<<1)>>1]=cd&65535;ly=lE}}while(0);ca=cd+1|0;b9=c[kT>>2]|0;if(ca>>>0<(c[e+44+(b9<<2)>>2]|0)>>>0){cb=ly;cd=ca}else{lx=b9;break}}}if((lx|0)==2){lG=kL;lH=kM;lI=0;lJ=kO;lK=kP;lL=kQ;lM=kR;lN=kS;S=7837;break}lO=kL;lP=kM;lQ=kN;lR=kO;lS=kP;lT=kQ;lU=kR;lV=kS;lW=lx;lX=e+24|0;S=7875}else if((S|0)==7797){S=0;cd=hF<<24>>24;c[e+44+(hz<<2)>>2]=(c[256+(hz<<2)>>2]|0)+(hB&(1<<cd)-1);kV=hx-cd|0;kW=hy;kX=hz+1|0;kY=hA;kZ=hB>>>(cd>>>0);k_=hC;k$=hD;k0=hE;S=7788;continue L10942}else if((S|0)==7840){S=0;cd=b[e+7328+((gD&1023)<<1)>>1]|0;cb=cd<<16>>16;if(cd<<16>>16>-1){cd=cb>>9;if((cd|0)==0|gz>>>0<cd>>>0){S=7846;break L10942}else{gH=gz;gI=gB;gJ=gC;gK=gD;gL=gE;gM=gF;gN=gG;S=7854;continue L10942}}if(gz>>>0>10){lY=10;lZ=cb}else{S=7846;break L10942}while(1){l_=b[e+9376+((gD>>>(lY>>>0)&1)+~lZ<<1)>>1]|0;if(l_<<16>>16>=0){gH=gz;gI=gB;gJ=gC;gK=gD;gL=gE;gM=gF;gN=gG;S=7854;continue L10942}if(gz>>>0<(lY+2|0)>>>0){break}else{lY=lY+1|0;lZ=l_<<16>>16}}if(l_<<16>>16>-1){gH=gz;gI=gB;gJ=gC;gK=gD;gL=gE;gM=gF;gN=gG;S=7854;continue L10942}else{S=7846;break L10942}}else if((S|0)==7943){S=0;cb=b[e+3840+((hk&1023)<<1)>>1]|0;cd=cb<<16>>16;if(cb<<16>>16>-1){l$=cd>>9;l0=cd&511}else{cb=10;I=cd;while(1){cd=cb+1|0;cc=b[e+5888+((hk>>>(cb>>>0)&1)+~I<<1)>>1]|0;b9=cc<<16>>16;if(cc<<16>>16<0){cb=cd;I=b9}else{l$=cd;l0=b9;break}}}I=hk>>>(l$>>>0);cb=hi-l$|0;b9=c[552+(l0<<2)>>2]|0;cd=c[680+(l0<<2)>>2]|0;if((l0-4|0)>>>0>=26){l1=cb;l2=cd;l3=hj;l4=b9;l5=I;l6=hm;l7=hn;S=7956;break}if(cb>>>0<b9>>>0){hG=cb;hH=cd;hI=hj;hJ=b9;hK=I;hL=hl;hM=hm;hN=hn;S=7948;continue L10942}else{hO=cb;hP=cd;hQ=hj;hR=b9;hS=I;hT=hm;hU=hn;S=7955;continue L10942}}else if((S|0)==7801){S=0;if(h$>>>0<q>>>0){S=7806;break L10942}else{dE=hV;dF=hW;dG=hX;dH=hY;dI=hZ;dJ=h_;dK=h$;dL=h0;S=7802;continue L10829}}else if((S|0)==7955){S=0;l1=hO-hR|0;l2=((1<<hR)-1&hS)+hP|0;l3=hQ;l4=hR;l5=hS>>>(hR>>>0);l6=hT;l7=hU;S=7956}else if((S|0)==7929){S=0;I=b[e+3840+((he&1023)<<1)>>1]|0;b9=I<<16>>16;if(I<<16>>16>-1){I=b9>>9;if((I|0)==0|ha>>>0<I>>>0){S=7935;break L10942}else{hi=ha;hj=hc;hk=he;hl=hf;hm=hg;hn=hh;S=7943;continue L10942}}if(ha>>>0>10){l8=10;l9=b9}else{S=7935;break L10942}while(1){ma=b[e+5888+((he>>>(l8>>>0)&1)+~l9<<1)>>1]|0;if(ma<<16>>16>=0){hi=ha;hj=hc;hk=he;hl=hf;hm=hg;hn=hh;S=7943;continue L10942}if(ha>>>0<(l8+2|0)>>>0){break}else{l8=l8+1|0;l9=ma<<16>>16}}if(ma<<16>>16>-1){hi=ha;hj=hc;hk=he;hl=hf;hm=hg;hn=hh;S=7943;continue L10942}else{S=7935;break L10942}}else if((S|0)==7808){S=0;a[(d[400+h3|0]|0)+(e+7040)|0]=h5&7;k9=h1-3|0;la=h2;lb=h3+1|0;lc=h4;ld=h5>>>3;le=h6;lf=h7;lg=h8;S=7799}else if((S|0)==7948){S=0;if(hM>>>0<q>>>0){S=7953;break L10942}else{K=hG;L=hH;M=hI;N=hJ;O=hK;P=hL;Q=hM;R=hN;S=7949;continue L10829}}else if((S|0)==7968){S=0;if((c[e+20>>2]&1|0)==0){ez=k1;eA=k2;eB=k3;eC=k4;eD=k5;eE=k6;eF=k7;eG=k8;S=7727;continue L10829}if((l&1|0)==0){aG=k1;aH=k2;aI=k3;aJ=k4;aK=k5;aL=k6;aM=k7;aN=k8;S=7997;continue L10829}if(k1>>>0<(k1&7)>>>0){jF=k1;jG=k2;jH=k3;jI=k4;jJ=k5;jK=k6;jL=k7;jM=k8;S=7971;continue L10942}else{jN=k1;jO=k2;jP=k4;jQ=k5;jR=k6;jS=k7;jT=k8;S=7978;continue L10942}}else if((S|0)==7971){S=0;if(jL>>>0<q>>>0){S=7976;break L10942}else{dm=jF;dn=jG;dp=jH;dq=jI;dr=jJ;ds=jK;dt=jL;du=jM;S=7972;continue L10829}}else if((S|0)==7900){S=0;b9=q;I=b9-iE|0;L11019:do{if((I|0)<4){mb=iF;mc=iE;md=iC;me=iA;mf=iy;mg=I}else{cd=s;cb=iF;cc=iE;ca=iC;dj=iA;dh=iy;gx=I;while(1){if((cd-cb|0)<2){mb=cb;mc=cc;md=ca;me=dj;mf=dh;mg=gx;break L11019}if(dh>>>0<15){mh=dh+16|0;mi=(d[cc+1|0]<<8|d[cc])<<dh|ca;mj=cc+2|0}else{mh=dh;mi=ca;mj=cc}di=b[e+352+((mi&1023)<<1)>>1]|0;b8=di<<16>>16;if(di<<16>>16>-1){mk=b8>>9;ml=b8}else{di=10;gy=b8;while(1){b8=di+1|0;dg=b[e+2400+((mi>>>(di>>>0)&1)+~gy<<1)>>1]|0;gw=dg<<16>>16;if(dg<<16>>16<0){di=b8;gy=gw}else{mk=b8;ml=gw;break}}}gy=mi>>>(mk>>>0);di=mh-mk|0;if((ml&256|0)!=0){mm=di;mn=iz;mo=ml;mp=iB;mq=gy;mr=iD;ms=mj;mt=cb;S=7916;break L10943}if(di>>>0<15){mu=di+16|0;mv=(d[mj+1|0]<<8|d[mj])<<di|gy;mw=mj+2|0}else{mu=di;mv=gy;mw=mj}gy=b[e+352+((mv&1023)<<1)>>1]|0;di=gy<<16>>16;if(gy<<16>>16>-1){mx=di>>9;my=di}else{gy=10;dk=di;while(1){di=gy+1|0;gw=b[e+2400+((mv>>>(gy>>>0)&1)+~dk<<1)>>1]|0;b8=gw<<16>>16;if(gw<<16>>16<0){gy=di;dk=b8}else{mx=di;my=b8;break}}}mz=mv>>>(mx>>>0);mA=mu-mx|0;a[cb]=ml&255;if((my&256|0)!=0){break}a[cb+1|0]=my&255;dk=cb+2|0;gy=b9-mw|0;if((gy|0)<4){mb=dk;mc=mw;md=mz;me=ml;mf=mA;mg=gy;break L11019}else{cb=dk;cc=mw;ca=mz;dj=ml;dh=mA;gx=gy}}mm=mA;mn=iz;mo=my;mp=iB;mq=mz;mr=iD;ms=mw;mt=cb+1|0;S=7916;break L10943}}while(0);if(mf>>>0>=15){kw=mf;kx=iz;ky=iB;kz=md;kA=iD;kB=mc;kC=mb;S=7893;continue L10942}if((mg|0)<2){ko=mf;kp=iz;kq=me;kr=iB;ks=md;kt=iD;ku=mc;kv=mb;S=7879;continue L10942}kw=mf+16|0;kx=iz;ky=iB;kz=d[mc]<<mf|md|d[mc+1|0]<<mf+8;kA=iD;kB=mc+2|0;kC=mb;S=7893;continue L10942}else if((S|0)==7989){S=0;fB=i6&255;fC=i2-8|0;fD=i3;fE=i4;fF=i5;fG=i6>>>8;fH=i7;fI=i8;fJ=i9;S=7996;continue L10829}else if((S|0)==7879){S=0;b9=b[e+352+((ks&1023)<<1)>>1]|0;I=b9<<16>>16;if(b9<<16>>16>-1){b9=I>>9;if((b9|0)==0|ko>>>0<b9>>>0){S=7885;break L10942}else{kw=ko;kx=kp;ky=kr;kz=ks;kA=kt;kB=ku;kC=kv;S=7893;continue L10942}}if(ko>>>0>10){mB=10;mC=I}else{S=7885;break L10942}while(1){mD=b[e+2400+((ks>>>(mB>>>0)&1)+~mC<<1)>>1]|0;if(mD<<16>>16>=0){kw=ko;kx=kp;ky=kr;kz=ks;kA=kt;kB=ku;kC=kv;S=7893;continue L10942}if(ko>>>0<(mB+2|0)>>>0){break}else{mB=mB+1|0;mC=mD<<16>>16}}if(mD<<16>>16>-1){kw=ko;kx=kp;ky=kr;kz=ks;kA=kt;kB=ku;kC=kv;S=7893;continue L10942}else{S=7885;break L10942}}else if((S|0)==7919){S=0;if(iM>>>0<q>>>0){S=7924;break L10942}else{cD=iG;cE=iH;cF=iI;cG=iJ;cH=iK;cI=iL;cJ=iM;cK=iN;S=7920;continue L10829}}else if((S|0)==7978){S=0;I=jN&7;kg=jN-I|0;kh=jO;ki=0;kj=jP;kk=jQ>>>(I>>>0);kl=jR;km=jS;kn=jT;S=7979;continue L10942}else if((S|0)==7979){S=0;if(ki>>>0>=4){aG=kg;aH=kh;aI=ki;aJ=kj;aK=kk;aL=kl;aM=km;aN=kn;S=7997;continue L10829}if((kg|0)==0){S=7990;break L10942}if(kg>>>0<8){iW=kg;iX=kh;iY=ki;iZ=kj;i_=kk;i$=kl;i0=km;i1=kn;S=7982;continue L10942}else{i2=kg;i3=kh;i4=ki;i5=kj;i6=kk;i7=kl;i8=km;i9=kn;S=7989;continue L10942}}else if((S|0)==7926){S=0;mE=iO-iR|0;mF=iP;mG=((1<<iR)-1&iS)+iQ|0;mH=iR;mI=iS>>>(iR>>>0);mJ=iT;mK=iU;mL=iV}else if((S|0)==7854){S=0;I=b[e+7328+((gK&1023)<<1)>>1]|0;b9=I<<16>>16;if(I<<16>>16>-1){mM=b9>>9;mN=b9&511}else{I=10;gx=b9;while(1){b9=I+1|0;dh=b[e+9376+((gK>>>(I>>>0)&1)+~gx<<1)>>1]|0;dj=dh<<16>>16;if(dh<<16>>16<0){I=b9;gx=dj}else{mM=b9;mN=dj;break}}}gx=gK>>>(mM>>>0);I=gH-mM|0;if(mN>>>0<16){a[e+10532+gI|0]=mN&255;lG=I;lH=mN;lI=gI+1|0;lJ=gJ;lK=gx;lL=gL;lM=gM;lN=gN;S=7837;break}if((mN|0)==16&(gI|0)==0){fl=I;fm=16;fn=0;fo=gJ;fp=gx;fq=gL;fr=gM;fs=gN;S=7860;continue L10829}dj=a[91760+(mN-16)|0]|0;if(I>>>0<dj>>>0){j0=I;j1=mN;j2=gI;j3=dj;j4=gx;j5=gL;j6=gM;j7=gN;S=7862;continue L10942}else{j8=I;j9=mN;ka=gI;kb=dj;kc=gx;kd=gL;ke=gM;kf=gN;S=7869;continue L10942}}else if((S|0)==7862){S=0;if(j6>>>0<q>>>0){S=7867;break L10942}else{cm=j0;cn=j1;co=j2;cp=j3;cq=j4;cr=j5;cs=j6;ct=j7;S=7863;continue L10829}}else if((S|0)==7982){S=0;if(i0>>>0<q>>>0){S=7987;break L10942}else{eY=iW;eZ=iX;e_=iY;e$=iZ;e0=i_;e1=i$;e2=i0;e3=i1;S=7983;continue L10829}}else if((S|0)==7959){S=0;gx=jW-1|0;if((jW|0)==0){iy=jU;iz=jV;iA=gx;iB=jX;iC=jY;iD=jZ;iE=j_;iF=j$;S=7900;continue L10942}else{fd=jU;fe=jV;ff=gx;fg=jX;fh=jY;fi=jZ;fj=j_;fk=j$;S=7960;continue L10829}}else if((S|0)==7869){S=0;gx=(a[88272+(j9-16)|0]|0)+((1<<kb)-1&kc)|0;if((j9|0)==16){mO=a[ka-1+(e+10532)|0]|0}else{mO=0}X2(e+10532+ka|0,mO|0,gx|0);lG=j8-kb|0;lH=j9;lI=gx+ka|0;lJ=kb;lK=kc>>>(kb>>>0);lL=kd;lM=ke;lN=kf;S=7837}else if((S|0)==7893){S=0;gx=b[e+352+((kz&1023)<<1)>>1]|0;dj=gx<<16>>16;if(gx<<16>>16>-1){mP=dj>>9;mQ=dj&511}else{gx=10;I=dj;while(1){dj=gx+1|0;b9=b[e+2400+((kz>>>(gx>>>0)&1)+~I<<1)>>1]|0;dh=b9<<16>>16;if(b9<<16>>16<0){gx=dj;I=dh}else{mP=dj;mQ=dh;break}}}I=kz>>>(mP>>>0);gx=kw-mP|0;if(mQ>>>0>255){mm=gx;mn=kx;mo=mQ;mp=ky;mq=I;mr=kA;ms=kB;mt=kC;S=7916}else{ce=gx;cf=kx;cg=mQ;ch=ky;ci=I;cj=kA;ck=kB;cl=kC;S=7897;continue L10829}}}while(0);do{if((S|0)==7837){S=0;I=c[e+44>>2]|0;gx=c[e+48>>2]|0;dh=gx+I|0;if(lI>>>0>=dh>>>0){if((dh|0)!=(lI|0)){ea=lG;eb=lH;ec=lI;ed=lJ;ee=lK;ef=lL;eg=lM;eh=lN;S=7873;continue L10829}dh=e+64|0;dj=e+10532|0;X5(dh|0,dj|0,I)|0;dj=e+3552|0;dh=e+10532+I|0;X5(dj|0,dh|0,gx)|0;gx=e+24|0;lO=lG;lP=lH;lQ=lI;lR=lJ;lS=lK;lT=lL;lU=lM;lV=lN;lW=c[gx>>2]|0;lX=gx;S=7875;break}if(lG>>>0>=15){gH=lG;gI=lI;gJ=lJ;gK=lK;gL=lL;gM=lM;gN=lN;S=7854;continue L10942}if((q-lM|0)<2){gz=lG;gA=lH;gB=lI;gC=lJ;gD=lK;gE=lL;gF=lM;gG=lN;S=7840;continue L10942}gH=lG+16|0;gI=lI;gJ=lJ;gK=d[lM]<<lG|lK|d[lM+1|0]<<lG+8;gL=lL;gM=lM+2|0;gN=lN;S=7854;continue L10942}else if((S|0)==7799){S=0;gx=e+52|0;if(lb>>>0<(c[gx>>2]|0)>>>0){if(k9>>>0<3){hV=k9;hW=la;hX=lb;hY=lc;hZ=ld;h_=le;h$=lf;h0=lg;S=7801;continue L10942}else{h1=k9;h2=la;h3=lb;h4=lc;h5=ld;h6=le;h7=lf;h8=lg;S=7808;continue L10942}}else{c[gx>>2]=19;gx=e+24|0;kL=k9;kM=la;kN=lb;kO=lc;kP=ld;kQ=le;kR=lf;kS=lg;kT=gx;kU=c[gx>>2]|0;S=7811;continue L10942}}else if((S|0)==7956){S=0;gx=l7-h|0;if(!(l2>>>0<=gx>>>0|t^1)){aW=l1;aX=l2;aY=l3;aZ=l4;a_=l5;a$=gx;a0=l6;a1=l7;S=7957;continue L10829}dh=h+(gx-l2&u)|0;if(((l7>>>0>dh>>>0?l7:dh)+l3|0)>>>0>s>>>0){jU=l1;jV=l2;jW=l3;jX=l4;jY=l5;jZ=gx;j_=l6;j$=l7;S=7959;continue L10942}else{mR=dh;mS=l3;mT=l7}while(1){a[mT]=a[mR]|0;a[mT+1|0]=a[mR+1|0]|0;a[mT+2|0]=a[mR+2|0]|0;mU=mT+3|0;mV=mR+3|0;mW=mS-3|0;if((mW|0)>2){mR=mV;mS=mW;mT=mU}else{break}}if((mW|0)<=0){iy=l1;iz=l2;iA=mW;iB=l4;iC=l5;iD=gx;iE=l6;iF=mU;S=7900;continue L10942}a[mU]=a[mV]|0;if((mW|0)>1){a[mT+4|0]=a[mR+4|0]|0}iy=l1;iz=l2;iA=mW;iB=l4;iC=l5;iD=gx;iE=l6;iF=mT+mS|0;S=7900;continue L10942}else if((S|0)==7916){S=0;dh=mo&511;if((dh|0)==256){k1=mm;k2=mn;k3=256;k4=mp;k5=mq;k6=mr;k7=ms;k8=mt;S=7968;continue L10942}dj=dh-257|0;I=c[272+(dj<<2)>>2]|0;b9=c[424+(dj<<2)>>2]|0;if((dh-265|0)>>>0>=20){mE=mm;mF=mn;mG=b9;mH=I;mI=mq;mJ=mr;mK=ms;mL=mt;break}if(mm>>>0<I>>>0){iG=mm;iH=mn;iI=b9;iJ=I;iK=mq;iL=mr;iM=ms;iN=mt;S=7919;continue L10942}else{iO=mm;iP=mn;iQ=b9;iR=I;iS=mq;iT=mr;iU=ms;iV=mt;S=7926;continue L10942}}}while(0);if((S|0)==7875){S=0;I=lW-1|0;c[lX>>2]=I;kL=lO;kM=lP;kN=lQ;kO=lR;kP=lS;kQ=lT;kR=lU;kS=lV;kT=lX;kU=I;S=7811;continue}if(mE>>>0>=15){hi=mE;hj=mG;hk=mI;hl=mJ;hm=mK;hn=mL;S=7943;continue}if((q-mK|0)<2){ha=mE;hb=mF;hc=mG;hd=mH;he=mI;hf=mJ;hg=mK;hh=mL;S=7929;continue}hi=mE+16|0;hj=mG;hk=d[mK]<<mE|mI|d[mK+1|0]<<mE+8;hl=mJ;hm=mK+2|0;hn=mL;S=7943}if((S|0)==7953){S=0;T=d[hM]|0;U=hG;V=hH;W=hI;X=hJ;Y=hK;Z=hL;_=hM+1|0;$=hN;S=7954;continue}else if((S|0)==7846){S=0;if(gF>>>0>=q>>>0){bu=gz;bv=gA;bw=gB;bx=gC;by=gD;bz=gE;bA=gF;bB=gG;S=7847;continue}bC=d[gF]|0;bD=gz;bE=gA;bF=gB;bG=gC;bH=gD;bI=gE;bJ=gF+1|0;bK=gG;S=7852;continue}else if((S|0)==7867){S=0;cu=d[j6]|0;cv=j0;cw=j1;cx=j2;cy=j3;cz=j4;cA=j5;cB=j6+1|0;cC=j7;S=7868;continue}else if((S|0)==7924){S=0;cL=d[iM]|0;cM=iG;cN=iH;cO=iI;cP=iJ;cQ=iK;cR=iL;cS=iM+1|0;cT=iN;S=7925;continue}else if((S|0)==7990){S=0;if(km>>>0>=q>>>0){ft=0;fu=kh;fv=ki;fw=kj;fx=kk;fy=kl;fz=km;fA=kn;S=7991;continue}fB=d[km]|0;fC=0;fD=kh;fE=ki;fF=kj;fG=kk;fH=kl;fI=km+1|0;fJ=kn;S=7996;continue}else if((S|0)==7795){S=0;d1=hp;d2=hq;d3=hr;d4=hs;d5=d[hv]|0;d6=ht;d7=hu;d8=hv+1|0;d9=hw;S=7796;continue}else if((S|0)==7885){S=0;if(ku>>>0>=q>>>0){fK=ko;fL=kp;fM=kq;fN=kr;fO=ks;fP=kt;fQ=ku;fR=kv;S=7886;continue}fS=d[ku]|0;fT=ko;fU=kp;fV=kq;fW=kr;fX=ks;fY=kt;fZ=ku+1|0;f_=kv;S=7891;continue}else if((S|0)==7976){S=0;dv=d[jL]|0;dw=jF;dx=jG;dy=jH;dz=jI;dA=jJ;dB=jK;dC=jL+1|0;dD=jM;S=7977;continue}else if((S|0)==7806){S=0;dM=hV;dN=hW;dO=hX;dP=d[h$]|0;dQ=hY;dR=hZ;dS=h_;dT=h$+1|0;dU=h0;S=7807;continue}else if((S|0)==7935){S=0;if(hg>>>0>=q>>>0){eH=ha;eI=hb;eJ=hc;eK=hd;eL=he;eM=hf;eN=hg;eO=hh;S=7936;continue}eP=d[hg]|0;eQ=ha;eR=hb;eS=hc;eT=hd;eU=he;eV=hf;eW=hg+1|0;eX=hh;S=7941;continue}else if((S|0)==7987){S=0;e4=d[i0]|0;e5=iW;e6=iX;e7=iY;e8=iZ;e9=i_;fa=i$;fb=i0+1|0;fc=i1;S=7988;continue}}if((S|0)==8011){i=m;return v|0}S=e+28|0;i1=c[S>>2]|0;fc=i1&65535;i0=i1>>>16;if((gv|0)==(j|0)){mX=fc;mY=i0}else{gv=j;j=ho;i1=fc;fc=i0;i0=(ho>>>0)%5552|0;while(1){if(i0>>>0>7){ho=gv;fb=0;i$=i1;fa=fc;while(1){i_=(d[ho]|0)+i$|0;e9=i_+(d[ho+1|0]|0)|0;iZ=e9+(d[ho+2|0]|0)|0;e8=iZ+(d[ho+3|0]|0)|0;iY=e8+(d[ho+4|0]|0)|0;e7=iY+(d[ho+5|0]|0)|0;iX=e7+(d[ho+6|0]|0)|0;e6=iX+(d[ho+7|0]|0)|0;iW=i_+fa+e9+iZ+e8+iY+e7+iX+e6|0;iX=fb+8|0;e7=ho+8|0;if((iX|7)>>>0<i0>>>0){ho=e7;fb=iX;i$=e6;fa=iW}else{mZ=e7;m_=iX;m$=e6;m0=iW;break}}}else{mZ=gv;m_=0;m$=i1;m0=fc}if(m_>>>0<i0>>>0){fa=mZ;i$=m_;fb=m$;ho=m0;while(1){m1=(d[fa]|0)+fb|0;m2=m1+ho|0;iW=i$+1|0;if(iW>>>0<i0>>>0){fa=fa+1|0;i$=iW;fb=m1;ho=m2}else{break}}m3=mZ+(i0-m_)|0;m4=m1;m5=m2}else{m3=mZ;m4=m$;m5=m0}ho=(m4>>>0)%65521|0;fb=(m5>>>0)%65521|0;if((j|0)==(i0|0)){mX=ho;mY=fb;break}else{gv=m3;j=j-i0|0;i1=ho;fc=fb;i0=5552}}}i0=mY<<16|mX;c[S>>2]=i0;if((gn|0)!=0){v=gn;i=m;return v|0}if((l&1|0)==0){v=0;i=m;return v|0}else{i=m;return((i0|0)==(c[e+16>>2]|0)?0:-2)|0}return 0}function jC(){X2(437624,0,65536);c[109216]=c[109466];c[436868>>2]=c[437868>>2];c[436872>>2]=c[437872>>2];c[436876>>2]=c[437876>>2];c[109220]=c[109466];c[436884>>2]=c[437868>>2];c[436888>>2]=c[437872>>2];c[436892>>2]=c[437876>>2];a[436880]=0;a[436881]=0;a[436890]=0;a[436891]=0;a[436892]=0;X2(437368,-1|0,256);X2(503160,-1|0,256);X2(436893,15,3);X2(436896,0,24);c[109224]=65472;a[436864]=10;a[436865]=-80;c[109221]=0;c[109231]=0;c[109230]=33;c[109198]=1;c[109201]=0;c[109204]=1;c[109207]=0;c[109210]=1;c[109213]=0;c[199301]=128;c[109245]=128;X5(437048,503096,64)|0;X5(503096,436984,64)|0;c[109200]=((a[436874]|0)-1&255)+1;c[109202]=0;c[109203]=15;c[109206]=((a[436875]|0)-1&255)+1;c[109208]=0;c[109209]=15;c[109212]=((a[436876]|0)-1&255)+1;c[109214]=0;c[109215]=15;c[109211]=4;c[109205]=7;c[109199]=7;c[109233]=0;X2(436948,0,((436808+(-436793|0)|0)>>>1<<1)+2|0);c[109236]=((436808+(-436793|0)|0)>>>1<<1)+436950;c[109234]=0;c[199292]=797172;c[199290]=797172;c[199291]=797204;X5(795648,15488,128)|0;c[199281]=1;c[199283]=128;c[199282]=795760;c[199246]=1;c[199248]=64;c[199247]=795744;c[199211]=1;c[199213]=32;c[199212]=795728;c[199176]=1;c[199178]=16;c[199177]=795712;c[199141]=1;c[199143]=8;c[199142]=795696;c[199106]=1;c[199108]=4;c[199107]=795680;c[199071]=1;c[199073]=2;c[199072]=795664;c[199036]=1;c[199038]=1;c[199037]=795648;c[198984]=209;c[198989]=78;c[198996]=96;c[198979]=16384;c[198976]=795776;c[198977]=1;c[198981]=0;c[198983]=0;c[198980]=0;return}function jD(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0,cf=0,cg=0,ch=0,ci=0,cj=0,ck=0,cl=0,cm=0,cn=0,co=0,cp=0,cq=0,cr=0,cs=0,ct=0,cu=0,cv=0,cw=0,cx=0,cy=0,cz=0,cA=0,cB=0,cC=0,cD=0,cE=0,cF=0,cG=0,cH=0,cI=0,cJ=0,cK=0,cL=0,cM=0,cN=0,cO=0,cP=0,cQ=0,cR=0;e=(c[109231]|0)-b|0;c[109231]=b;c[109230]=(c[109230]|0)+e;c[109198]=(c[109198]|0)+e;c[109204]=(c[109204]|0)+e;c[109210]=(c[109210]|0)+e;b=c[109225]|0;f=c[109226]|0;g=c[109227]|0;h=437624+(c[109224]|0)|0;i=(c[109229]|0)+437881|0;j=c[109228]|0;k=j<<8;l=j<<3&256;m=(j<<4&2048|j&2)^2;n=(a[798240]|0)!=0;if(n&(e|0)>-1){o=h;p=e;q=i;r=g;s=f;t=b;u=j;v=k;w=m;x=l;y=o;z=y-437624|0;A=z&65535;c[109224]=A;B=q-257|0;C=B;D=C-437624|0;E=D&255;c[109229]=E;F=t&255;c[109225]=F;G=s&255;c[109226]=G;H=r&255;c[109227]=H;I=u&-164;J=v>>>8;K=J&1;L=x>>>3;M=w>>>4;N=M|w;O=N&128;P=I|L;Q=P|K;R=Q|O;S=w&255;T=S<<24>>24==0;U=R|2;V=T?U:R;W=V&255;c[109228]=W;X=c[109231]|0;Y=X+p|0;c[109231]=Y;Z=c[109230]|0;_=Z-p|0;c[109230]=_;$=c[109198]|0;aa=$-p|0;c[109198]=aa;ac=c[109204]|0;ad=ac-p|0;c[109204]=ad;ae=c[109210]|0;af=ae-p|0;c[109210]=af;return}else{ag=e;ah=i;ai=g;aj=f;ak=b;al=j;am=k;an=m;ao=l;ap=h}L11156:while(1){h=a[ap]|0;l=h&255;m=a[437112+l|0]|0;aq=(m&255)+ag|0;if(!((aq|0)<1|n)){ar=ap;as=m;break}at=ap+1|0;m=a[at]|0;au=m&255;L11159:do{switch(l|0){case 208:{if((an&255)<<24>>24==0){av=ao;aw=an;ax=am;ay=al;az=ak;aA=aj;aB=ai;aC=ap+2|0;aD=ah;aE=aq-2|0;break L11159}else{av=ao;aw=an;ax=am;ay=al;az=ak;aA=aj;aB=ai;aC=ap+((m<<24>>24)+2)|0;aD=ah;aE=aq;break L11159}break};case 240:{if((an&255)<<24>>24==0){av=ao;aw=an;ax=am;ay=al;az=ak;aA=aj;aB=ai;aC=ap+((m<<24>>24)+2)|0;aD=ah;aE=aq;break L11159}else{av=ao;aw=an;ax=am;ay=al;az=ak;aA=aj;aB=ai;aC=ap+2|0;aD=ah;aE=aq-2|0;break L11159}break};case 239:{o=ap;p=0;q=ah;r=ai;s=aj;t=ak;u=al;v=am;w=an;x=ao;aF=8378;break L11156;break};case 232:{aG=au;aH=am;aI=al;aJ=au;aK=aj;aL=ai;aM=at;aN=aq;aF=8018;break};case 111:{av=ao;aw=an;ax=am;ay=al;az=ak;aA=aj;aB=ai;aC=437624+(d[ah+1|0]<<8|d[ah])|0;aD=ah+2|0;aE=aq;break};case 63:{k=at-437624+2|0;j=437624+(d[ap+2|0]<<8|au)|0;b=ah-2|0;a[ah-1|0]=k>>>8&255;a[b]=k&255;av=ao;aw=an;ax=am;ay=al;az=ak;aA=aj;aB=ai;aC=j;aD=b;aE=aq;break};case 0:{av=ao;aw=an;ax=am;ay=al;az=ak;aA=aj;aB=ai;aC=at;aD=ah;aE=aq;break};case 228:{b=ap+2|0;j=au|ao;k=j-253|0;if(k>>>0<3){f=436792+(k*24|0)|0;g=c[f>>2]|0;do{if((aq|0)>=(g|0)){i=c[436796+(k*24|0)>>2]|0;e=aq-g>>i;aO=e+1|0;c[f>>2]=(aO<<i)+g;if((c[436808+(k*24|0)>>2]|0)==0){break}i=c[436800+(k*24|0)>>2]|0;aP=436804+(k*24|0)|0;aQ=c[aP>>2]|0;aR=e-(i+255-aQ&255)|0;if((aR|0)>-1){e=(aR|0)/(i|0)|0;aS=436812+(k*24|0)|0;c[aS>>2]=e+1+(c[aS>>2]|0)&15;aT=aR-(ab(e,i)|0)&255}else{aT=aQ+aO&255}c[aP>>2]=aT&255}}while(0);g=436812+(k*24|0)|0;f=c[g>>2]|0;c[g>>2]=0;av=ao;aw=f;ax=am;ay=al;az=f;aA=aj;aB=ai;aC=b;aD=ah;aE=aq;break L11159}else{f=d[437624+j|0]|0;g=j-240|0;if(g>>>0>=16){av=ao;aw=f;ax=am;ay=al;az=f;aA=aj;aB=ai;aC=b;aD=ah;aE=aq;break L11159}f=d[436880+g|0]|0;g=j-242|0;if(g>>>0>=2){av=ao;aw=f;ax=am;ay=al;az=f;aA=aj;aB=ai;aC=b;aD=ah;aE=aq;break L11159}f=a[436866]|0;aP=f&255;if((g|0)!=1){av=ao;aw=aP;ax=am;ay=al;az=aP;aA=aj;aB=ai;aC=b;aD=ah;aE=aq;break L11159}g=c[109230]|0;aO=aq-(a[235744+(aP&127)|0]|0)-g|0;if((aO|0)>-1){aP=aO+32&-32;c[109230]=aP+g;jF(aP);aU=a[436866]|0}else{aU=f}f=d[795648+(aU&127)|0]|0;av=ao;aw=f;ax=am;ay=al;az=f;aA=aj;aB=ai;aC=b;aD=ah;aE=aq;break L11159}break};case 90:{f=ak-(jK(au|ao,aq-1|0)|0)|0;aP=ai-(jK(m+1&255|ao,aq)|0)+(f>>8)|0;aG=(f>>>1|f)&127|aP&255;aH=~aP;aI=al;aJ=ak;aK=aj;aL=ai;aM=at;aN=aq;aF=8018;break};case 250:{aP=aq-2|0;f=au|ao;g=f-253|0;do{if(g>>>0<3){aO=436792+(g*24|0)|0;aQ=c[aO>>2]|0;do{if((aP|0)>=(aQ|0)){i=c[436796+(g*24|0)>>2]|0;e=aP-aQ>>i;aR=e+1|0;c[aO>>2]=(aR<<i)+aQ;if((c[436808+(g*24|0)>>2]|0)==0){break}i=c[436800+(g*24|0)>>2]|0;aS=436804+(g*24|0)|0;aV=c[aS>>2]|0;aW=e-(i+255-aV&255)|0;if((aW|0)>-1){e=(aW|0)/(i|0)|0;aX=436812+(g*24|0)|0;c[aX>>2]=e+1+(c[aX>>2]|0)&15;aY=aW-(ab(e,i)|0)&255}else{aY=aV+aR&255}c[aS>>2]=aY&255}}while(0);aQ=436812+(g*24|0)|0;aO=c[aQ>>2]|0;c[aQ>>2]=0;aZ=aO}else{aO=f-240|0;if(aO>>>0>=16){aZ=d[437624+f|0]|0;break}aQ=f-242|0;if(aQ>>>0>=2){aZ=d[436880+aO|0]|0;break}aO=a[436866]|0;aS=aO&255;if((aQ|0)!=1){aZ=aS;break}aQ=c[109230]|0;aR=aP-(a[235744+(aS&127)|0]|0)-aQ|0;if((aR|0)>-1){aS=aR+32&-32;c[109230]=aS+aQ;jF(aS);a_=a[436866]|0}else{a_=aO}aZ=d[795648+(a_&127)|0]|0}}while(0);a$=aZ+8192|0;aF=8058;break};case 143:{a$=au;aF=8058;break};case 196:{aP=ap+2|0;f=au|ao;g=ak&255;a[437624+f|0]=g;b=f-240|0;if(b>>>0>=16){av=ao;aw=an;ax=am;ay=al;az=ak;aA=aj;aB=ai;aC=aP;aD=ah;aE=aq;break L11159}j=f-242|0;a[436864+b|0]=g;if((j|0)!=1){if(j>>>0<=1){av=ao;aw=an;ax=am;ay=al;az=ak;aA=aj;aB=ai;aC=aP;aD=ah;aE=aq;break L11159}jJ(ak,aq,b);av=ao;aw=an;ax=am;ay=al;az=ak;aA=aj;aB=ai;aC=aP;aD=ah;aE=aq;break L11159}b=a[436866]|0;j=c[109230]|0;f=aq-(a[235744+(b&255)|0]|0)-j|0;if((f|0)>-1){k=f+32&-32;c[109230]=k+j;jF(k);a0=a[436866]|0}else{a0=b}if(a0<<24>>24<=-1){av=ao;aw=an;ax=am;ay=al;az=ak;aA=aj;aB=ai;aC=aP;aD=ah;aE=aq;break L11159}b=a0&255;a[795648+b|0]=g;k=b&15;if((k|0)==8){a[795941]=g;av=ao;aw=an;ax=am;ay=al;az=ak;aA=aj;aB=ai;aC=aP;aD=ah;aE=aq;break L11159}else if((k|0)==9){a[795942]=g;av=ao;aw=an;ax=am;ay=al;az=ak;aA=aj;aB=ai;aC=aP;aD=ah;aE=aq;break L11159}else if((k|0)==12){if((a0<<24>>24|0)==76){c[198984]=ak&255;av=ao;aw=an;ax=am;ay=al;az=ak;aA=aj;aB=ai;aC=aP;aD=ah;aE=aq;break L11159}else if((a0<<24>>24|0)==124){a[795940]=0;a[795772]=0;av=ao;aw=an;ax=am;ay=al;az=ak;aA=aj;aB=ai;aC=aP;aD=ah;aE=aq;break L11159}else{av=ao;aw=an;ax=am;ay=al;az=ak;aA=aj;aB=ai;aC=aP;aD=ah;aE=aq;break L11159}}else{av=ao;aw=an;ax=am;ay=al;az=ak;aA=aj;aB=ai;aC=aP;aD=ah;aE=aq;break L11159}break};case 230:{a1=ap;a2=aj+ao|0;aF=8091;break};case 247:{aP=au|ao;a1=at;a2=(d[aP+437625|0]<<8|d[437624+aP|0])+ai|0;aF=8091;break};case 231:{aP=au+aj&255|ao;a1=at;a2=d[aP+437625|0]<<8|d[437624+aP|0];aF=8091;break};case 246:{a3=au+ai|0;aF=8089;break};case 245:{a3=au+aj|0;aF=8089;break};case 229:{a3=au;aF=8089;break};case 244:{a1=at;a2=au+aj&255|ao;aF=8091;break};case 191:{aP=jK(aj+ao|0,aq-1|0)|0;av=ao;aw=aP;ax=am;ay=al;az=aP;aA=aj+1&255;aB=ai;aC=at;aD=ah;aE=aq;break};case 249:{a4=au+ai&255;aF=8094;break};case 248:{a4=au;aF=8094;break};case 233:{aP=ap+2|0;a5=aP;a6=jK(d[aP]<<8|au,aq)|0;aF=8108;break};case 205:{a5=at;a6=au;aF=8108;break};case 251:{a7=au+aj&255;aF=8110;break};case 235:{a7=au;aF=8110;break};case 236:{aP=d[ap+2|0]<<8|au;k=ap+3|0;g=aP-253|0;if(g>>>0<3){b=436792+(g*24|0)|0;j=c[b>>2]|0;do{if((aq|0)>=(j|0)){f=c[436796+(g*24|0)>>2]|0;aO=aq-j>>f;aS=aO+1|0;c[b>>2]=(aS<<f)+j;if((c[436808+(g*24|0)>>2]|0)==0){break}f=c[436800+(g*24|0)>>2]|0;aQ=436804+(g*24|0)|0;aR=c[aQ>>2]|0;aV=aO-(f+255-aR&255)|0;if((aV|0)>-1){aO=(aV|0)/(f|0)|0;i=436812+(g*24|0)|0;c[i>>2]=aO+1+(c[i>>2]|0)&15;a8=aV-(ab(aO,f)|0)&255}else{a8=aR+aS&255}c[aQ>>2]=a8&255}}while(0);j=436812+(g*24|0)|0;b=c[j>>2]|0;c[j>>2]=0;av=ao;aw=b;ax=am;ay=al;az=ak;aA=aj;aB=b;aC=k;aD=ah;aE=aq;break L11159}else{b=d[437624+aP|0]|0;j=aP-240|0;if(j>>>0>=16){av=ao;aw=b;ax=am;ay=al;az=ak;aA=aj;aB=b;aC=k;aD=ah;aE=aq;break L11159}b=d[436880+j|0]|0;j=aP-242|0;if(j>>>0>=2){av=ao;aw=b;ax=am;ay=al;az=ak;aA=aj;aB=b;aC=k;aD=ah;aE=aq;break L11159}b=a[436866]|0;aQ=b&255;if((j|0)!=1){av=ao;aw=aQ;ax=am;ay=al;az=ak;aA=aj;aB=aQ;aC=k;aD=ah;aE=aq;break L11159}j=c[109230]|0;aS=aq-(a[235744+(aQ&127)|0]|0)-j|0;if((aS|0)>-1){aQ=aS+32&-32;c[109230]=aQ+j;jF(aQ);a9=a[436866]|0}else{a9=b}b=d[795648+(a9&127)|0]|0;av=ao;aw=b;ax=am;ay=al;az=ak;aA=aj;aB=b;aC=k;aD=ah;aE=aq;break L11159}break};case 141:{aG=au;aH=am;aI=al;aJ=ak;aK=aj;aL=au;aM=at;aN=aq;aF=8018;break};case 198:{ba=ap;bb=aj+ao|0;aF=8144;break};case 215:{b=au|ao;ba=at;bb=(d[b+437625|0]<<8|d[437624+b|0])+ai|0;aF=8144;break};case 199:{b=au+aj&255|ao;ba=at;bb=d[b+437625|0]<<8|d[437624+b|0];aF=8144;break};case 214:{bc=au+ai|0;aF=8142;break};case 213:{bc=au+aj|0;aF=8142;break};case 197:{bc=au;aF=8142;break};case 212:{ba=at;bb=au+aj&255|ao;aF=8144;break};case 201:{bd=aj;aF=8146;break};case 204:{bd=ai;aF=8146;break};case 217:{be=au+ai&255;aF=8148;break};case 216:{be=au;aF=8148;break};case 219:{bf=au+aj&255;aF=8150;break};case 203:{bf=au;aF=8150;break};case 125:{av=ao;aw=aj;ax=am;ay=al;az=aj;aA=aj;aB=ai;aC=at;aD=ah;aE=aq;break};case 221:{av=ao;aw=ai;ax=am;ay=al;az=ai;aA=aj;aB=ai;aC=at;aD=ah;aE=aq;break};case 93:{av=ao;aw=ak;ax=am;ay=al;az=ak;aA=ak;aB=ai;aC=at;aD=ah;aE=aq;break};case 253:{av=ao;aw=ak;ax=am;ay=al;az=ak;aA=aj;aB=ak;aC=at;aD=ah;aE=aq;break};case 157:{b=ah-257-437624|0;av=ao;aw=b;ax=am;ay=al;az=ak;aA=b;aB=ai;aC=at;aD=ah;aE=aq;break};case 189:{av=ao;aw=an;ax=am;ay=al;az=ak;aA=aj;aB=ai;aC=at;aD=aj+437881|0;aE=aq;break};case 175:{jL(ak+8192|0,aj+ao|0,aq);av=ao;aw=an;ax=am;ay=al;az=ak;aA=aj+1|0;aB=ai;aC=at;aD=ah;aE=aq;break};case 38:{bg=ap;bh=aj+ao|0;aF=8166;break};case 55:{b=au|ao;bg=at;bh=(d[b+437625|0]<<8|d[437624+b|0])+ai|0;aF=8166;break};case 39:{b=au+aj&255|ao;bg=at;bh=d[b+437625|0]<<8|d[437624+b|0];aF=8166;break};case 54:{bi=au+ai|0;aF=8163;break};case 53:{bi=au+aj|0;aF=8163;break};case 37:{bi=au;aF=8163;break};case 52:{bj=au+aj&255;aF=8165;break};case 36:{bj=au;aF=8165;break};case 40:{bk=at;bl=au;aF=8167;break};case 57:{bm=at;bn=jK(ai+ao|0,aq-2|0)|0;bo=aj+ao|0;aF=8171;break};case 41:{bp=jK(au|ao,aq-3|0)|0;aF=8170;break};case 56:{bp=au;aF=8170;break};case 6:{bq=ap;br=aj+ao|0;aF=8180;break};case 23:{b=au|ao;bq=at;br=(d[b+437625|0]<<8|d[437624+b|0])+ai|0;aF=8180;break};case 7:{b=au+aj&255|ao;bq=at;br=d[b+437625|0]<<8|d[437624+b|0];aF=8180;break};case 22:{bs=au+ai|0;aF=8177;break};case 21:{bs=au+aj|0;aF=8177;break};case 5:{bs=au;aF=8177;break};case 20:{bt=au+aj&255;aF=8179;break};case 4:{bt=au;aF=8179;break};case 8:{bu=at;bv=au;aF=8181;break};case 25:{bw=at;bx=jK(ai+ao|0,aq-2|0)|0;by=aj+ao|0;aF=8185;break};case 9:{bz=jK(au|ao,aq-3|0)|0;aF=8184;break};case 24:{bz=au;aF=8184;break};case 70:{bA=ap;bB=aj+ao|0;aF=8194;break};case 87:{b=au|ao;bA=at;bB=(d[b+437625|0]<<8|d[437624+b|0])+ai|0;aF=8194;break};case 71:{b=au+aj&255|ao;bA=at;bB=d[b+437625|0]<<8|d[437624+b|0];aF=8194;break};case 86:{bC=au+ai|0;aF=8191;break};case 85:{bC=au+aj|0;aF=8191;break};case 69:{bC=au;aF=8191;break};case 84:{bD=au+aj&255;aF=8193;break};case 68:{bD=au;aF=8193;break};case 72:{bE=at;bF=au;aF=8195;break};case 89:{bG=at;bH=jK(ai+ao|0,aq-2|0)|0;bI=aj+ao|0;aF=8199;break};case 73:{bJ=jK(au|ao,aq-3|0)|0;aF=8198;break};case 88:{bJ=au;aF=8198;break};case 102:{bK=ap;bL=aj+ao|0;aF=8208;break};case 119:{b=au|ao;bK=at;bL=(d[b+437625|0]<<8|d[437624+b|0])+ai|0;aF=8208;break};case 103:{b=au+aj&255|ao;bK=at;bL=d[b+437625|0]<<8|d[437624+b|0];aF=8208;break};case 118:{bM=au+ai|0;aF=8205;break};case 117:{bM=au+aj|0;aF=8205;break};case 101:{bM=au;aF=8205;break};case 116:{bN=au+aj&255;aF=8207;break};case 100:{bN=au;aF=8207;break};case 104:{bO=at;bP=au;aF=8209;break};case 121:{b=jK(ai+ao|0,aq-2|0)|0;aQ=(jK(aj+ao|0,aq-1|0)|0)-b|0;av=ao;aw=aQ&255;ax=~aQ;ay=al;az=ak;aA=aj;aB=ai;aC=at;aD=ah;aE=aq;break};case 105:{bQ=jK(au|ao,aq-3|0)|0;aF=8212;break};case 120:{bQ=au;aF=8212;break};case 62:{bR=at;bS=au|ao;aF=8215;break};case 30:{aQ=ap+2|0;bR=aQ;bS=d[aQ]<<8|au;aF=8215;break};case 200:{bT=at;bU=au;aF=8216;break};case 126:{bV=at;bW=au|ao;aF=8219;break};case 94:{aQ=ap+2|0;bV=aQ;bW=d[aQ]<<8|au;aF=8219;break};case 173:{bX=at;bY=au;aF=8220;break};case 185:case 153:{bZ=ap;b_=jK(ai+ao|0,aq-2|0)|0;b$=aj+ao|0;aF=8224;break};case 169:case 137:{b0=jK(au|ao,aq-3|0)|0;aF=8223;break};case 184:case 152:{b0=au;aF=8223;break};case 134:case 166:{b1=ap;b2=aj+ao|0;aF=8233;break};case 151:case 183:{aQ=au|ao;b1=at;b2=(d[aQ+437625|0]<<8|d[437624+aQ|0])+ai|0;aF=8233;break};case 135:case 167:{aQ=au+aj&255|ao;b1=at;b2=d[aQ+437625|0]<<8|d[437624+aQ|0];aF=8233;break};case 150:case 182:{b3=au+ai|0;aF=8230;break};case 149:case 181:{b3=au+aj|0;aF=8230;break};case 133:case 165:{b3=au;aF=8230;break};case 148:case 180:{b4=au+aj&255;aF=8232;break};case 132:case 164:{b4=au;aF=8232;break};case 168:case 136:{b5=ak;b6=at;b7=au;b8=-1;aF=8234;break};case 188:{aQ=ak+1|0;av=ao;aw=aQ;ax=am;ay=al;az=aQ&255;aA=aj;aB=ai;aC=at;aD=ah;aE=aq;break};case 61:{aQ=aj+1|0;av=ao;aw=aQ;ax=am;ay=al;az=ak;aA=aQ&255;aB=ai;aC=at;aD=ah;aE=aq;break};case 252:{aQ=ai+1|0;av=ao;aw=aQ;ax=am;ay=al;az=ak;aA=aj;aB=aQ&255;aC=at;aD=ah;aE=aq;break};case 156:{aQ=ak-1|0;av=ao;aw=aQ;ax=am;ay=al;az=aQ&255;aA=aj;aB=ai;aC=at;aD=ah;aE=aq;break};case 29:{aQ=aj-1|0;av=ao;aw=aQ;ax=am;ay=al;az=ak;aA=aQ&255;aB=ai;aC=at;aD=ah;aE=aq;break};case 220:{aQ=ai-1|0;av=ao;aw=aQ;ax=am;ay=al;az=ak;aA=aj;aB=aQ&255;aC=at;aD=ah;aE=aq;break};case 155:case 187:{b9=au+aj&255;aF=8244;break};case 139:case 171:{b9=au;aF=8244;break};case 140:case 172:{aQ=ap+2|0;ca=aQ;cb=d[aQ]<<8|au;aF=8246;break};case 92:{cc=0;aF=8248;break};case 124:{cc=am;aF=8248;break};case 28:{cd=0;aF=8250;break};case 60:{cd=am;aF=8250;break};case 11:{ce=0;cf=at;cg=au|ao;aF=8257;break};case 27:{ch=0;aF=8253;break};case 59:{ch=am;aF=8253;break};case 43:{ci=am;cj=au;aF=8254;break};case 12:{ck=0;aF=8256;break};case 44:{ck=am;aF=8256;break};case 75:{cl=0;cm=at;cn=au|ao;aF=8264;break};case 91:{co=0;aF=8260;break};case 123:{co=am;aF=8260;break};case 107:{cp=am;cq=au;aF=8261;break};case 76:{cr=0;aF=8263;break};case 108:{cr=am;aF=8263;break};case 159:{aQ=ak<<4&240|ak>>4;av=ao;aw=aQ;ax=am;ay=al;az=aQ;aA=aj;aB=ai;aC=at;aD=ah;aE=aq;break};case 186:{aQ=jK(au|ao,aq-2|0)|0;b=jK(m+1&255|ao,aq)|0;aG=aQ&127|aQ>>1|b;aH=am;aI=al;aJ=aQ;aK=aj;aL=b;aM=at;aN=aq;aF=8018;break};case 218:{jL(ak,au|ao,aq-1|0);jL(ai+8192|0,m+1&255|ao,aq);aG=an;aH=am;aI=al;aJ=ak;aK=aj;aL=ai;aM=at;aN=aq;aF=8018;break};case 58:case 26:{b=au|ao;aQ=(l>>>4&2)-1+(jK(b,aq-3|0)|0)|0;jL(aQ,b,aq-2|0);b=m+1&255|ao;j=(aQ>>>8)+(jK(b,aq-1|0)|0)&255;jL(j,b,aq);aG=(aQ>>>1|aQ)&127|j;aH=am;aI=al;aJ=ak;aK=aj;aL=ai;aM=at;aN=aq;aF=8018;break};case 122:case 154:{j=jK(au|ao,aq-2|0)|0;aQ=jK(m+1&255|ao,aq)|0;if(h<<24>>24==-102){cs=aQ^255;ct=(j^255)+1|0}else{cs=aQ;ct=j}j=ct+ak|0;aQ=cs+ai+(j>>8)|0;b=cs^ai^aQ;aS=aQ&255;aG=(j>>>1|j)&127|aS;aH=aQ;aI=b>>>1&8|al&-73|(b+128|0)>>>2&64;aJ=j&255;aK=aj;aL=aS;aM=at;aN=aq;aF=8018;break};case 207:{aS=ab(ai,ak)|0;j=aS>>>8;av=ao;aw=(aS>>>1|aS)&127|j;ax=am;ay=al;az=aS&255;aA=aj;aB=j;aC=at;aD=ah;aE=aq;break};case 158:{j=(ai<<8)+ak|0;aS=al&-73;b=(ai|0)<(aj|0)?aS:aS|64;if((ai|0)<(aj<<1|0)){aS=(j>>>0)/(aj>>>0)|0;cu=j-(ab(aS,aj)|0)|0;cv=aS}else{aS=j-(aj<<9)|0;j=256-aj|0;cu=((aS>>>0)%(j>>>0)|0)+aj|0;cv=255-((aS>>>0)/(j>>>0)|0)|0}j=cv&255;av=ao;aw=j;ax=am;ay=(ai&15)>>>0<(aj&15)>>>0?b:b|8;az=j;aA=aj;aB=cu;aC=at;aD=ah;aE=aq;break};case 223:{if((ak|0)>153){aF=8280}else{if((am&256|0)==0){cw=am;cx=ak}else{aF=8280}}if((aF|0)==8280){aF=0;cw=256;cx=ak+96|0}if((cx&14)>>>0>9){aF=8283}else{if((al&8|0)==0){cy=cx}else{aF=8283}}if((aF|0)==8283){aF=0;cy=cx+6|0}av=ao;aw=cy;ax=cw;ay=al;az=cy&255;aA=aj;aB=ai;aC=at;aD=ah;aE=aq;break};case 190:{if((ak|0)>153){aF=8287}else{if((am&256|0)==0){aF=8287}else{cz=am;cA=ak}}if((aF|0)==8287){aF=0;cz=0;cA=ak-96|0}if((cA&14)>>>0>9){aF=8290}else{if((al&8|0)==0){aF=8290}else{cB=cA}}if((aF|0)==8290){aF=0;cB=cA-6|0}av=ao;aw=cB;ax=cz;ay=al;az=cB&255;aA=aj;aB=ai;aC=at;aD=ah;aE=aq;break};case 47:{aG=an;aH=am;aI=al;aJ=ak;aK=aj;aL=ai;aM=ap+((m<<24>>24)+1)|0;aN=aq;aF=8018;break};case 48:{if((an&2176|0)==0){av=ao;aw=an;ax=am;ay=al;az=ak;aA=aj;aB=ai;aC=ap+2|0;aD=ah;aE=aq-2|0;break L11159}else{av=ao;aw=an;ax=am;ay=al;az=ak;aA=aj;aB=ai;aC=ap+((m<<24>>24)+2)|0;aD=ah;aE=aq;break L11159}break};case 16:{if((an&2176|0)==0){av=ao;aw=an;ax=am;ay=al;az=ak;aA=aj;aB=ai;aC=ap+((m<<24>>24)+2)|0;aD=ah;aE=aq;break L11159}else{av=ao;aw=an;ax=am;ay=al;az=ak;aA=aj;aB=ai;aC=ap+2|0;aD=ah;aE=aq-2|0;break L11159}break};case 176:{if((am&256|0)==0){av=ao;aw=an;ax=am;ay=al;az=ak;aA=aj;aB=ai;aC=ap+2|0;aD=ah;aE=aq-2|0;break L11159}else{av=ao;aw=an;ax=am;ay=al;az=ak;aA=aj;aB=ai;aC=ap+((m<<24>>24)+2)|0;aD=ah;aE=aq;break L11159}break};case 144:{if((am&256|0)==0){av=ao;aw=an;ax=am;ay=al;az=ak;aA=aj;aB=ai;aC=ap+((m<<24>>24)+2)|0;aD=ah;aE=aq;break L11159}else{av=ao;aw=an;ax=am;ay=al;az=ak;aA=aj;aB=ai;aC=ap+2|0;aD=ah;aE=aq-2|0;break L11159}break};case 112:{if((al&64|0)==0){av=ao;aw=an;ax=am;ay=al;az=ak;aA=aj;aB=ai;aC=ap+2|0;aD=ah;aE=aq-2|0;break L11159}else{av=ao;aw=an;ax=am;ay=al;az=ak;aA=aj;aB=ai;aC=ap+((m<<24>>24)+2)|0;aD=ah;aE=aq;break L11159}break};case 80:{if((al&64|0)==0){av=ao;aw=an;ax=am;ay=al;az=ak;aA=aj;aB=ai;aC=ap+((m<<24>>24)+2)|0;aD=ah;aE=aq;break L11159}else{av=ao;aw=an;ax=am;ay=al;az=ak;aA=aj;aB=ai;aC=ap+2|0;aD=ah;aE=aq-2|0;break L11159}break};case 3:case 35:case 67:case 99:case 131:case 163:case 195:case 227:{j=ap+2|0;if(((jK(au|ao,aq-4|0)|0)&1<<(l>>>5)|0)!=0){cC=j;aF=8017;break L11159}aG=an;aH=am;aI=al;aJ=ak;aK=aj;aL=ai;aM=j;aN=aq-2|0;aF=8018;break};case 19:case 51:case 83:case 115:case 147:case 179:case 211:case 243:{j=ap+2|0;if(((jK(au|ao,aq-4|0)|0)&1<<(l>>>5)|0)==0){cC=j;aF=8017;break L11159}aG=an;aH=am;aI=al;aJ=ak;aK=aj;aL=ai;aM=j;aN=aq-2|0;aF=8018;break};case 222:{cD=au+aj&255;aF=8316;break};case 46:{cD=au;aF=8316;break};case 110:{j=au|ao;b=jK(j,aq-4|0)|0;jL(b+8191|0,j,aq-3|0);j=ap+2|0;if((b|0)!=1){cC=j;aF=8017;break L11159}aG=an;aH=am;aI=al;aJ=ak;aK=aj;aL=ai;aM=j;aN=aq-2|0;aF=8018;break};case 254:{j=ai+255&255;if((j|0)==0){av=ao;aw=an;ax=am;ay=al;az=ak;aA=aj;aB=0;aC=ap+2|0;aD=ah;aE=aq-2|0;break L11159}else{av=ao;aw=an;ax=am;ay=al;az=ak;aA=aj;aB=j;aC=ap+((m<<24>>24)+2)|0;aD=ah;aE=aq;break L11159}break};case 31:{j=437624+((d[ap+2|0]<<8|au)+aj)|0;cE=j;cF=a[j]|0;aF=8337;break};case 95:{cE=at;cF=m;aF=8337;break};case 15:{j=at-437624|0;b=437624+(d[503127]<<8|d[503126])|0;a[ah-1|0]=j>>>8&255;a[ah-2|0]=j&255;j=al&-164|ao>>>3|am>>>8&1|(an>>>4|an)&128;if((an&255)<<24>>24==0){cG=(j|2)&255}else{cG=j&255}j=ah-3|0;a[j]=cG;av=ao;aw=an;ax=am;ay=al&-21|16;az=ak;aA=aj;aB=ai;aC=b;aD=j;aE=aq;break};case 79:{j=at-437624+1|0;b=ah-2|0;a[ah-1|0]=j>>>8&255;a[b]=j&255;av=ao;aw=an;ax=am;ay=al;az=ak;aA=aj;aB=ai;aC=437624+(au|65280)|0;aD=b;aE=aq;break};case 1:case 17:case 33:case 49:case 65:case 81:case 97:case 113:case 129:case 145:case 161:case 177:case 193:case 209:case 225:case 241:{b=at-437624|0;j=65502-(l>>>3)|0;aS=437624+(d[j+437625|0]<<8|d[437624+j|0])|0;j=ah-2|0;a[ah-1|0]=b>>>8&255;a[j]=b&255;av=ao;aw=an;ax=am;ay=al;az=ak;aA=aj;aB=ai;aC=aS;aD=j;aE=aq;break};case 127:{cH=437624+(d[ah+2|0]<<8|d[ah+1|0])|0;cI=ah+3|0;aF=8345;break};case 142:{cH=at;cI=ah+1|0;aF=8345;break};case 13:{j=al&-164|ao>>>3|am>>>8&1|(an>>>4|an)&128;if((an&255)<<24>>24==0){cJ=(j|2)&255}else{cJ=j&255}j=ah-1|0;a[j]=cJ;av=ao;aw=an;ax=am;ay=al;az=ak;aA=aj;aB=ai;aC=at;aD=j;aE=aq;break};case 45:{j=ah-1|0;a[j]=ak&255;av=ao;aw=an;ax=am;ay=al;az=ak;aA=aj;aB=ai;aC=at;aD=j;aE=aq;break};case 77:{j=ah-1|0;a[j]=aj&255;av=ao;aw=an;ax=am;ay=al;az=ak;aA=aj;aB=ai;aC=at;aD=j;aE=aq;break};case 109:{j=ah-1|0;a[j]=ai&255;av=ao;aw=an;ax=am;ay=al;az=ak;aA=aj;aB=ai;aC=at;aD=j;aE=aq;break};case 174:{av=ao;aw=an;ax=am;ay=al;az=d[ah]|0;aA=aj;aB=ai;aC=at;aD=ah+1|0;aE=aq;break};case 206:{av=ao;aw=an;ax=am;ay=al;az=ak;aA=d[ah]|0;aB=ai;aC=at;aD=ah+1|0;aE=aq;break};case 238:{av=ao;aw=an;ax=am;ay=al;az=ak;aA=aj;aB=d[ah]|0;aC=at;aD=ah+1|0;aE=aq;break};case 2:case 34:case 66:case 98:case 130:case 162:case 194:case 226:case 18:case 50:case 82:case 114:case 146:case 178:case 210:case 242:{j=1<<(l>>>5);aS=au|ao;jL((jK(aS,aq-1|0)|0)&~j|((l&16|0)==0?j:0),aS,aq);aG=an;aH=am;aI=al;aJ=ak;aK=aj;aL=ai;aM=at;aN=aq;aF=8018;break};case 14:case 78:{aS=d[ap+2|0]<<8|au;j=jK(aS,aq-2|0)|0;jL(j&~ak|(h<<24>>24==14?ak:0),aS,aq);av=ao;aw=ak-j&255;ax=am;ay=al;az=ak;aA=aj;aB=ai;aC=ap+3|0;aD=ah;aE=aq;break};case 74:{j=d[ap+2|0]|0;av=ao;aw=an;ax=am&256&(jK(j<<8&7936|au,aq)|0)>>>(j>>>5>>>0)<<8;ay=al;az=ak;aA=aj;aB=ai;aC=ap+3|0;aD=ah;aE=aq;break};case 106:{j=d[ap+2|0]|0;av=ao;aw=an;ax=(((jK(j<<8&7936|au,aq)|0)>>>(j>>>5>>>0)<<8|-257)^256)&am;ay=al;az=ak;aA=aj;aB=ai;aC=ap+3|0;aD=ah;aE=aq;break};case 10:{j=d[ap+2|0]|0;av=ao;aw=an;ax=(jK(j<<8&7936|au,aq-1|0)|0)>>>(j>>>5>>>0)<<8&256|am;ay=al;az=ak;aA=aj;aB=ai;aC=ap+3|0;aD=ah;aE=aq;break};case 42:{j=d[ap+2|0]|0;av=ao;aw=an;ax=((jK(j<<8&7936|au,aq-1|0)|0)>>>(j>>>5>>>0)<<8|-257)^256|am;ay=al;az=ak;aA=aj;aB=ai;aC=ap+3|0;aD=ah;aE=aq;break};case 138:{j=d[ap+2|0]|0;av=ao;aw=an;ax=(jK(j<<8&7936|au,aq-1|0)|0)>>>(j>>>5>>>0)<<8&256^am;ay=al;az=ak;aA=aj;aB=ai;aC=ap+3|0;aD=ah;aE=aq;break};case 234:{j=d[ap+2|0]|0;aS=j<<8&7936|au;jL(1<<(j>>>5)^(jK(aS,aq-1|0)|0),aS,aq);av=ao;aw=an;ax=am;ay=al;az=ak;aA=aj;aB=ai;aC=ap+3|0;aD=ah;aE=aq;break};case 202:{aS=d[ap+2|0]|0;j=aS<<8&7936|au;b=aS>>>5;jL(((jK(j,aq-2|0)|0)&~(1<<b)|(am>>>8&1)<<b)+8192|0,j,aq);av=ao;aw=an;ax=am;ay=al;az=ak;aA=aj;aB=ai;aC=ap+3|0;aD=ah;aE=aq;break};case 170:{j=d[ap+2|0]|0;av=ao;aw=an;ax=(jK(j<<8&7936|au,aq)|0)>>>(j>>>5>>>0)<<8&256;ay=al;az=ak;aA=aj;aB=ai;aC=ap+3|0;aD=ah;aE=aq;break};case 96:{av=ao;aw=an;ax=0;ay=al;az=ak;aA=aj;aB=ai;aC=at;aD=ah;aE=aq;break};case 128:{av=ao;aw=an;ax=-1;ay=al;az=ak;aA=aj;aB=ai;aC=at;aD=ah;aE=aq;break};case 237:{av=ao;aw=an;ax=am^256;ay=al;az=ak;aA=aj;aB=ai;aC=at;aD=ah;aE=aq;break};case 224:{av=ao;aw=an;ax=am;ay=al&-73;az=ak;aA=aj;aB=ai;aC=at;aD=ah;aE=aq;break};case 32:{av=0;aw=an;ax=am;ay=al;az=ak;aA=aj;aB=ai;aC=at;aD=ah;aE=aq;break};case 64:{av=256;aw=an;ax=am;ay=al;az=ak;aA=aj;aB=ai;aC=at;aD=ah;aE=aq;break};case 160:{av=ao;aw=an;ax=am;ay=al|4;az=ak;aA=aj;aB=ai;aC=at;aD=ah;aE=aq;break};case 192:{av=ao;aw=an;ax=am;ay=al&-5;az=ak;aA=aj;aB=ai;aC=at;aD=ah;aE=aq;break};case 255:{j=at-437624-1|0;if(j>>>0<=65535){o=ap;p=0;q=ah;r=ai;s=aj;t=ak;u=al;v=am;w=an;x=ao;aF=8380;break L11156}av=ao;aw=an;ax=am;ay=al;az=ak;aA=aj;aB=ai;aC=437624+(j&65535)|0;aD=ah;aE=aq;break};default:{aF=8022;break L11156}}}while(0);do{if((aF|0)==8058){aF=0;m=ap+3|0;j=d[ap+2|0]|ao;b=a$&255;a[437624+j|0]=b;aS=j-240|0;if(aS>>>0>=16){av=ao;aw=an;ax=am;ay=al;az=ak;aA=aj;aB=ai;aC=m;aD=ah;aE=aq;break}a[436864+aS|0]=b;if((-788594688<<aS|0)>=0){av=ao;aw=an;ax=am;ay=al;az=ak;aA=aj;aB=ai;aC=m;aD=ah;aE=aq;break}if((aS|0)!=3){jJ(a$,aq,aS);av=ao;aw=an;ax=am;ay=al;az=ak;aA=aj;aB=ai;aC=m;aD=ah;aE=aq;break}aS=a[436866]|0;j=c[109230]|0;aQ=aq-(a[235744+(aS&255)|0]|0)-j|0;if((aQ|0)>-1){aR=aQ+32&-32;c[109230]=aR+j;jF(aR);cK=a[436866]|0}else{cK=aS}if(cK<<24>>24<=-1){av=ao;aw=an;ax=am;ay=al;az=ak;aA=aj;aB=ai;aC=m;aD=ah;aE=aq;break}aS=cK&255;a[795648+aS|0]=b;aR=aS&15;if((aR|0)==8){a[795941]=b;av=ao;aw=an;ax=am;ay=al;az=ak;aA=aj;aB=ai;aC=m;aD=ah;aE=aq;break}else if((aR|0)==9){a[795942]=b;av=ao;aw=an;ax=am;ay=al;az=ak;aA=aj;aB=ai;aC=m;aD=ah;aE=aq;break}else if((aR|0)==12){if((cK<<24>>24|0)==76){c[198984]=a$&255;av=ao;aw=an;ax=am;ay=al;az=ak;aA=aj;aB=ai;aC=m;aD=ah;aE=aq;break}else if((cK<<24>>24|0)==124){a[795940]=0;a[795772]=0;av=ao;aw=an;ax=am;ay=al;az=ak;aA=aj;aB=ai;aC=m;aD=ah;aE=aq;break}else{av=ao;aw=an;ax=am;ay=al;az=ak;aA=aj;aB=ai;aC=m;aD=ah;aE=aq;break}}else{av=ao;aw=an;ax=am;ay=al;az=ak;aA=aj;aB=ai;aC=m;aD=ah;aE=aq;break}}else if((aF|0)==8089){aF=0;m=ap+2|0;a1=m;a2=(d[m]<<8)+a3|0;aF=8091}else if((aF|0)==8094){aF=0;m=a4|ao;aR=m-253|0;if(aR>>>0<3){b=436792+(aR*24|0)|0;aS=c[b>>2]|0;do{if((aq|0)>=(aS|0)){j=c[436796+(aR*24|0)>>2]|0;aQ=aq-aS>>j;f=aQ+1|0;c[b>>2]=(f<<j)+aS;if((c[436808+(aR*24|0)>>2]|0)==0){break}j=c[436800+(aR*24|0)>>2]|0;aO=436804+(aR*24|0)|0;aV=c[aO>>2]|0;i=aQ-(j+255-aV&255)|0;if((i|0)>-1){aQ=(i|0)/(j|0)|0;e=436812+(aR*24|0)|0;c[e>>2]=aQ+1+(c[e>>2]|0)&15;cL=i-(ab(aQ,j)|0)&255}else{cL=aV+f&255}c[aO>>2]=cL&255}}while(0);aS=436812+(aR*24|0)|0;b=c[aS>>2]|0;c[aS>>2]=0;aG=b;aH=am;aI=al;aJ=ak;aK=b;aL=ai;aM=at;aN=aq;aF=8018;break}else{b=d[437624+m|0]|0;aS=m-240|0;if(aS>>>0>=16){aG=b;aH=am;aI=al;aJ=ak;aK=b;aL=ai;aM=at;aN=aq;aF=8018;break}b=d[436880+aS|0]|0;aS=m-242|0;if(aS>>>0>=2){aG=b;aH=am;aI=al;aJ=ak;aK=b;aL=ai;aM=at;aN=aq;aF=8018;break}b=a[436866]|0;k=b&255;if((aS|0)!=1){aG=k;aH=am;aI=al;aJ=ak;aK=k;aL=ai;aM=at;aN=aq;aF=8018;break}aS=c[109230]|0;aP=aq-(a[235744+(k&127)|0]|0)-aS|0;if((aP|0)>-1){k=aP+32&-32;c[109230]=k+aS;jF(k);cM=a[436866]|0}else{cM=b}b=d[795648+(cM&127)|0]|0;aG=b;aH=am;aI=al;aJ=ak;aK=b;aL=ai;aM=at;aN=aq;aF=8018;break}}else if((aF|0)==8108){aF=0;aG=a6;aH=am;aI=al;aJ=ak;aK=a6;aL=ai;aM=a5;aN=aq;aF=8018}else if((aF|0)==8110){aF=0;b=ap+2|0;k=a7|ao;aS=k-253|0;if(aS>>>0<3){aP=436792+(aS*24|0)|0;g=c[aP>>2]|0;do{if((aq|0)>=(g|0)){aO=c[436796+(aS*24|0)>>2]|0;f=aq-g>>aO;aV=f+1|0;c[aP>>2]=(aV<<aO)+g;if((c[436808+(aS*24|0)>>2]|0)==0){break}aO=c[436800+(aS*24|0)>>2]|0;j=436804+(aS*24|0)|0;aQ=c[j>>2]|0;i=f-(aO+255-aQ&255)|0;if((i|0)>-1){f=(i|0)/(aO|0)|0;e=436812+(aS*24|0)|0;c[e>>2]=f+1+(c[e>>2]|0)&15;cN=i-(ab(f,aO)|0)&255}else{cN=aQ+aV&255}c[j>>2]=cN&255}}while(0);g=436812+(aS*24|0)|0;aP=c[g>>2]|0;c[g>>2]=0;av=ao;aw=aP;ax=am;ay=al;az=ak;aA=aj;aB=aP;aC=b;aD=ah;aE=aq;break}else{aP=d[437624+k|0]|0;g=k-240|0;if(g>>>0>=16){av=ao;aw=aP;ax=am;ay=al;az=ak;aA=aj;aB=aP;aC=b;aD=ah;aE=aq;break}aP=d[436880+g|0]|0;g=k-242|0;if(g>>>0>=2){av=ao;aw=aP;ax=am;ay=al;az=ak;aA=aj;aB=aP;aC=b;aD=ah;aE=aq;break}aP=a[436866]|0;m=aP&255;if((g|0)!=1){av=ao;aw=m;ax=am;ay=al;az=ak;aA=aj;aB=m;aC=b;aD=ah;aE=aq;break}g=c[109230]|0;aR=aq-(a[235744+(m&127)|0]|0)-g|0;if((aR|0)>-1){m=aR+32&-32;c[109230]=m+g;jF(m);cO=a[436866]|0}else{cO=aP}aP=d[795648+(cO&127)|0]|0;av=ao;aw=aP;ax=am;ay=al;az=ak;aA=aj;aB=aP;aC=b;aD=ah;aE=aq;break}}else if((aF|0)==8142){aF=0;aP=ap+2|0;ba=aP;bb=(d[aP]<<8)+bc|0;aF=8144}else if((aF|0)==8146){aF=0;jL(bd,d[ap+2|0]<<8|au,aq);av=ao;aw=an;ax=am;ay=al;az=ak;aA=aj;aB=ai;aC=ap+3|0;aD=ah;aE=aq}else if((aF|0)==8148){aF=0;jL(aj,be|ao,aq);aG=an;aH=am;aI=al;aJ=ak;aK=aj;aL=ai;aM=at;aN=aq;aF=8018}else if((aF|0)==8150){aF=0;jL(ai,bf|ao,aq);aG=an;aH=am;aI=al;aJ=ak;aK=aj;aL=ai;aM=at;aN=aq;aF=8018}else if((aF|0)==8163){aF=0;aP=ap+2|0;bg=aP;bh=(d[aP]<<8)+bi|0;aF=8166}else if((aF|0)==8165){aF=0;bg=at;bh=bj|ao;aF=8166}else if((aF|0)==8170){aF=0;bm=ap+3|0;bn=bp;bo=d[ap+2|0]|ao;aF=8171}else if((aF|0)==8177){aF=0;aP=ap+2|0;bq=aP;br=(d[aP]<<8)+bs|0;aF=8180}else if((aF|0)==8179){aF=0;bq=at;br=bt|ao;aF=8180}else if((aF|0)==8184){aF=0;bw=ap+3|0;bx=bz;by=d[ap+2|0]|ao;aF=8185}else if((aF|0)==8191){aF=0;aP=ap+2|0;bA=aP;bB=(d[aP]<<8)+bC|0;aF=8194}else if((aF|0)==8193){aF=0;bA=at;bB=bD|ao;aF=8194}else if((aF|0)==8198){aF=0;bG=ap+3|0;bH=bJ;bI=d[ap+2|0]|ao;aF=8199}else if((aF|0)==8205){aF=0;aP=ap+2|0;bK=aP;bL=(d[aP]<<8)+bM|0;aF=8208}else if((aF|0)==8207){aF=0;bK=at;bL=bN|ao;aF=8208}else if((aF|0)==8212){aF=0;aP=ap+2|0;m=(jK(d[aP]|ao,aq-1|0)|0)-bQ|0;aG=m&255;aH=~m;aI=al;aJ=ak;aK=aj;aL=ai;aM=aP;aN=aq;aF=8018}else if((aF|0)==8215){aF=0;bT=bR;bU=jK(bS,aq)|0;aF=8216}else if((aF|0)==8219){aF=0;bX=bV;bY=jK(bW,aq)|0;aF=8220}else if((aF|0)==8223){aF=0;aP=ap+2|0;bZ=aP;b_=b0;b$=d[aP]|ao;aF=8224}else if((aF|0)==8230){aF=0;aP=ap+2|0;b1=aP;b2=(d[aP]<<8)+b3|0;aF=8233}else if((aF|0)==8232){aF=0;b1=at;b2=b4|ao;aF=8233}else if((aF|0)==8244){aF=0;ca=at;cb=b9|ao;aF=8246}else if((aF|0)==8248){aF=0;aP=cc>>>1&128|ak>>1;av=ao;aw=aP;ax=ak<<8;ay=al;az=aP;aA=aj;aB=ai;aC=at;aD=ah;aE=aq}else if((aF|0)==8250){aF=0;aP=ak<<1;m=cd>>>8&1|aP;av=ao;aw=m;ax=aP;ay=al;az=m&255;aA=aj;aB=ai;aC=at;aD=ah;aE=aq}else if((aF|0)==8253){aF=0;ci=ch;cj=au+aj&255;aF=8254}else if((aF|0)==8256){aF=0;m=ap+2|0;ce=ck;cf=m;cg=d[m]<<8|au;aF=8257}else if((aF|0)==8260){aF=0;cp=co;cq=au+aj&255;aF=8261}else if((aF|0)==8263){aF=0;m=ap+2|0;cl=cr;cm=m;cn=d[m]<<8|au;aF=8264}else if((aF|0)==8316){aF=0;m=aq-4|0;aP=cD|ao;g=aP-253|0;do{if(g>>>0<3){aR=436792+(g*24|0)|0;j=c[aR>>2]|0;do{if((m|0)>=(j|0)){aV=c[436796+(g*24|0)>>2]|0;aQ=m-j>>aV;aO=aQ+1|0;c[aR>>2]=(aO<<aV)+j;if((c[436808+(g*24|0)>>2]|0)==0){break}aV=c[436800+(g*24|0)>>2]|0;f=436804+(g*24|0)|0;i=c[f>>2]|0;e=aQ-(aV+255-i&255)|0;if((e|0)>-1){aQ=(e|0)/(aV|0)|0;aW=436812+(g*24|0)|0;c[aW>>2]=aQ+1+(c[aW>>2]|0)&15;cP=e-(ab(aQ,aV)|0)&255}else{cP=i+aO&255}c[f>>2]=cP&255}}while(0);j=436812+(g*24|0)|0;aR=c[j>>2]|0;c[j>>2]=0;cQ=aR}else{aR=aP-240|0;if(aR>>>0>=16){cQ=d[437624+aP|0]|0;break}j=aP-242|0;if(j>>>0>=2){cQ=d[436880+aR|0]|0;break}aR=a[436866]|0;f=aR&255;if((j|0)!=1){cQ=f;break}j=c[109230]|0;aO=m-(a[235744+(f&127)|0]|0)-j|0;if((aO|0)>-1){f=aO+32&-32;c[109230]=f+j;jF(f);cR=a[436866]|0}else{cR=aR}cQ=d[795648+(cR&127)|0]|0}}while(0);m=ap+2|0;if((cQ|0)!=(ak|0)){cC=m;aF=8017;break}aG=an;aH=am;aI=al;aJ=ak;aK=aj;aL=ai;aM=m;aN=aq-2|0;aF=8018}else if((aF|0)==8337){aF=0;av=ao;aw=an;ax=am;ay=al;az=ak;aA=aj;aB=ai;aC=437624+(d[cE+1|0]<<8|cF&255)|0;aD=ah;aE=aq}else if((aF|0)==8345){aF=0;m=d[ah]|0;av=m<<3&256;aw=(m<<4&2048|m&2)^2;ax=m<<8;ay=m;az=ak;aA=aj;aB=ai;aC=cH;aD=cI;aE=aq}}while(0);if((aF|0)==8017){aF=0;aG=an;aH=am;aI=al;aJ=ak;aK=aj;aL=ai;aM=cC+(a[cC]|0)|0;aN=aq;aF=8018}else if((aF|0)==8091){aF=0;m=jK(a2,aq)|0;aG=m;aH=am;aI=al;aJ=m;aK=aj;aL=ai;aM=a1;aN=aq;aF=8018}else if((aF|0)==8144){aF=0;jL(ak,bb,aq);aG=an;aH=am;aI=al;aJ=ak;aK=aj;aL=ai;aM=ba;aN=aq;aF=8018}else if((aF|0)==8166){aF=0;bk=bg;bl=jK(bh,aq)|0;aF=8167}else if((aF|0)==8171){aF=0;m=(jK(bo,aq-1|0)|0)&bn;jL(m,bo,aq);av=ao;aw=m;ax=am;ay=al;az=ak;aA=aj;aB=ai;aC=bm;aD=ah;aE=aq}else if((aF|0)==8180){aF=0;bu=bq;bv=jK(br,aq)|0;aF=8181}else if((aF|0)==8185){aF=0;m=jK(by,aq-1|0)|0|bx;jL(m,by,aq);av=ao;aw=m;ax=am;ay=al;az=ak;aA=aj;aB=ai;aC=bw;aD=ah;aE=aq}else if((aF|0)==8194){aF=0;bE=bA;bF=jK(bB,aq)|0;aF=8195}else if((aF|0)==8199){aF=0;m=(jK(bI,aq-1|0)|0)^bH;jL(m,bI,aq);av=ao;aw=m;ax=am;ay=al;az=ak;aA=aj;aB=ai;aC=bG;aD=ah;aE=aq}else if((aF|0)==8208){aF=0;bO=bK;bP=jK(bL,aq)|0;aF=8209}else if((aF|0)==8216){aF=0;m=aj-bU|0;aG=m&255;aH=~m;aI=al;aJ=ak;aK=aj;aL=ai;aM=bT;aN=aq;aF=8018}else if((aF|0)==8220){aF=0;m=ai-bY|0;aG=m&255;aH=~m;aI=al;aJ=ak;aK=aj;aL=ai;aM=bX;aN=aq;aF=8018}else if((aF|0)==8224){aF=0;b5=jK(b$,aq-1|0)|0;b6=bZ;b7=b_;b8=b$;aF=8234}else if((aF|0)==8233){aF=0;b5=ak;b6=b1;b7=jK(b2,aq)|0;b8=-1;aF=8234}else if((aF|0)==8246){aF=0;m=(l>>>4&2)-1+(jK(cb,aq-1|0)|0)|0;jL(m,cb,aq);aG=m;aH=am;aI=al;aJ=ak;aK=aj;aL=ai;aM=ca;aN=aq;aF=8018}else if((aF|0)==8254){aF=0;ce=ci;cf=at;cg=cj|ao;aF=8257}else if((aF|0)==8261){aF=0;cl=cp;cm=at;cn=cq|ao;aF=8264}do{if((aF|0)==8167){aF=0;m=bl&ak;aG=m;aH=am;aI=al;aJ=m;aK=aj;aL=ai;aM=bk;aN=aq;aF=8018}else if((aF|0)==8181){aF=0;m=bv|ak;aG=m;aH=am;aI=al;aJ=m;aK=aj;aL=ai;aM=bu;aN=aq;aF=8018}else if((aF|0)==8195){aF=0;m=bF^ak;aG=m;aH=am;aI=al;aJ=m;aK=aj;aL=ai;aM=bE;aN=aq;aF=8018}else if((aF|0)==8209){aF=0;m=ak-bP|0;aG=m&255;aH=~m;aI=al;aJ=ak;aK=aj;aL=ai;aM=bO;aN=aq;aF=8018}else if((aF|0)==8234){aF=0;m=(h&255)>159?b7^255:b7;aP=m+(am>>>8&1)+b5|0;g=m^b5^aP;m=g>>>1&8|al&-73|(g+128|0)>>>2&64;if((b8|0)<0){aG=aP;aH=aP;aI=m;aJ=aP&255;aK=aj;aL=ai;aM=b6;aN=aq;aF=8018;break}else{jL(aP,b8,aq);aG=aP;aH=aP;aI=m;aJ=ak;aK=aj;aL=ai;aM=b6;aN=aq;aF=8018;break}}else if((aF|0)==8257){aF=0;m=(jK(cg,aq-1|0)|0)<<1;aP=ce>>>8&1|m;jL(aP,cg,aq);aG=aP;aH=m;aI=al;aJ=ak;aK=aj;aL=ai;aM=cf;aN=aq;aF=8018}else if((aF|0)==8264){aF=0;m=jK(cn,aq-1|0)|0;aP=cl>>>1&128|m>>1;jL(aP,cn,aq);aG=aP;aH=m<<8;aI=al;aJ=ak;aK=aj;aL=ai;aM=cm;aN=aq;aF=8018}}while(0);if((aF|0)==8018){aF=0;av=ao;aw=aG;ax=aH;ay=aI;az=aJ;aA=aK;aB=aL;aC=aM+1|0;aD=ah;aE=aN}if(n&(aE|0)>-1){o=aC;p=aE;q=aD;r=aB;s=aA;t=az;u=ay;v=ax;w=aw;x=av;aF=8379;break}else{ag=aE;ah=aD;ai=aB;aj=aA;ak=az;al=ay;am=ax;an=aw;ao=av;ap=aC}}if((aF|0)==8380){y=o;z=y-437624|0;A=z&65535;c[109224]=A;B=q-257|0;C=B;D=C-437624|0;E=D&255;c[109229]=E;F=t&255;c[109225]=F;G=s&255;c[109226]=G;H=r&255;c[109227]=H;I=u&-164;J=v>>>8;K=J&1;L=x>>>3;M=w>>>4;N=M|w;O=N&128;P=I|L;Q=P|K;R=Q|O;S=w&255;T=S<<24>>24==0;U=R|2;V=T?U:R;W=V&255;c[109228]=W;X=c[109231]|0;Y=X+p|0;c[109231]=Y;Z=c[109230]|0;_=Z-p|0;c[109230]=_;$=c[109198]|0;aa=$-p|0;c[109198]=aa;ac=c[109204]|0;ad=ac-p|0;c[109204]=ad;ae=c[109210]|0;af=ae-p|0;c[109210]=af;return}else if((aF|0)==8022){ar=at;as=a[437112+au|0]|0}else if((aF|0)==8378){y=o;z=y-437624|0;A=z&65535;c[109224]=A;B=q-257|0;C=B;D=C-437624|0;E=D&255;c[109229]=E;F=t&255;c[109225]=F;G=s&255;c[109226]=G;H=r&255;c[109227]=H;I=u&-164;J=v>>>8;K=J&1;L=x>>>3;M=w>>>4;N=M|w;O=N&128;P=I|L;Q=P|K;R=Q|O;S=w&255;T=S<<24>>24==0;U=R|2;V=T?U:R;W=V&255;c[109228]=W;X=c[109231]|0;Y=X+p|0;c[109231]=Y;Z=c[109230]|0;_=Z-p|0;c[109230]=_;$=c[109198]|0;aa=$-p|0;c[109198]=aa;ac=c[109204]|0;ad=ac-p|0;c[109204]=ad;ae=c[109210]|0;af=ae-p|0;c[109210]=af;return}else if((aF|0)==8379){y=o;z=y-437624|0;A=z&65535;c[109224]=A;B=q-257|0;C=B;D=C-437624|0;E=D&255;c[109229]=E;F=t&255;c[109225]=F;G=s&255;c[109226]=G;H=r&255;c[109227]=H;I=u&-164;J=v>>>8;K=J&1;L=x>>>3;M=w>>>4;N=M|w;O=N&128;P=I|L;Q=P|K;R=Q|O;S=w&255;T=S<<24>>24==0;U=R|2;V=T?U:R;W=V&255;c[109228]=W;X=c[109231]|0;Y=X+p|0;c[109231]=Y;Z=c[109230]|0;_=Z-p|0;c[109230]=_;$=c[109198]|0;aa=$-p|0;c[109198]=aa;ac=c[109204]|0;ad=ac-p|0;c[109204]=ad;ae=c[109210]|0;af=ae-p|0;c[109210]=af;return}o=ar;p=aq-(as&255)|0;q=ah;r=ai;s=aj;t=ak;u=al;v=am;w=an;x=ao;y=o;z=y-437624|0;A=z&65535;c[109224]=A;B=q-257|0;C=B;D=C-437624|0;E=D&255;c[109229]=E;F=t&255;c[109225]=F;G=s&255;c[109226]=G;H=r&255;c[109227]=H;I=u&-164;J=v>>>8;K=J&1;L=x>>>3;M=w>>>4;N=M|w;O=N&128;P=I|L;Q=P|K;R=Q|O;S=w&255;T=S<<24>>24==0;U=R|2;V=T?U:R;W=V&255;c[109228]=W;X=c[109231]|0;Y=X+p|0;c[109231]=Y;Z=c[109230]|0;_=Z-p|0;c[109230]=_;$=c[109198]|0;aa=$-p|0;c[109198]=aa;ac=c[109204]|0;ad=ac-p|0;c[109204]=ad;ae=c[109210]|0;af=ae-p|0;c[109210]=af;return}function jE(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;c[59e3]=0;c[42380]=0;jC();c[109233]=c[109233]&31;d=c[125858]|0;e=a[17360]|0;f=d+((e?1024:0)<<1)|0;c[109234]=d;c[109235]=f;g=c[109236]|0;if(g>>>0>436948>>>0&e){h=d;i=436948;while(1){j=i+2|0;k=h+2|0;b[h>>1]=b[i>>1]|0;l=c[109236]|0;m=k>>>0<f>>>0;if(j>>>0<l>>>0&m){h=k;i=j}else{n=k;o=j;p=m;q=l;break}}}else{n=d;o=436948;p=e;q=g}do{if(p){r=f;s=n}else{if(o>>>0<q>>>0){t=797172;u=o}else{r=797204;s=797172;break}while(1){g=u+2|0;e=t+2|0;b[t>>1]=b[u>>1]|0;if(g>>>0<(c[109236]|0)>>>0){t=e;u=g}else{r=797204;s=e;break}}}}while(0);u=(s|0)==0;t=u?797172:s;c[199292]=t;c[199290]=t;c[199291]=t+((u?16:r-s>>1)<<1);c[59004]=0;c[59006]=0;X2(c[59010]|0,0,c[59008]|0);c[59356]=65536;c[59348]=0;c[59350]=0;c[59352]=0;c[59354]=0;c[59340]=0;c[59342]=0;c[59344]=0;c[59346]=0;return}function jF(e){e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0;f=c[198983]|0;c[198983]=f+e&31;switch(f|0){case 8:{g=e;h=8409;break};case 4:{i=e;h=8405;break};case 26:{j=e;k=c[199007]|0;h=8444;break};case 12:{l=e;h=8413;break};case 27:{m=e;n=c[199003]&65535;o=c[199008]|0;h=8451;break};case 2:{p=e;h=8403;break};case 10:{q=e;h=8411;break};case 1:{r=e;s=(c[199e3]|0)>>>8&255;t=c[199072]|0;u=c[198999]|0;v=c[199289]|0;h=8402;break};case 7:{w=e;h=8408;break};case 0:{x=e;h=8394;break};case 9:{y=e;h=8410;break};case 11:{z=e;h=8412;break};case 3:{A=e;h=8404;break};case 5:{B=e;h=8406;break};case 6:{C=e;h=8407;break};case 22:{D=e;E=c[199037]|0;F=c[198999]|0;h=8430;break};case 23:{G=e;H=c[198976]|0;I=c[199007]|0;J=c[199008]|0;h=8434;break};case 13:{K=e;h=8414;break};case 14:{L=e;h=8415;break};case 15:{M=e;h=8416;break};case 16:{N=e;h=8417;break};case 17:{O=e;h=8418;break};case 18:{P=e;h=8419;break};case 19:{Q=e;h=8420;break};case 20:{R=e;h=8421;break};case 21:{S=e;h=8422;break};case 24:{T=e;h=8438;break};case 25:{U=e;h=8439;break};case 28:{V=e;h=8456;break};case 29:{W=e;h=8457;break};case 30:{X=e;h=8467;break};case 31:{Y=e;h=8476;break};default:{return}}while(1){if((h|0)==8409){h=0;a[795772]=a[795940]|0;a[795941]=a[796452]|0;c[198998]=(c[198995]<<2)+(c[198989]<<8);c[198995]=d[(c[199212]|0)+4|0]|0;jH(796456);e=g-1|0;if((e|0)==0){h=8478;break}else{y=e;h=8410;continue}}else if((h|0)==8405){h=0;a[(c[199037]|0)+8|0]=a[795941]|0;a[795942]=(c[199e3]|0)>>>8&255;c[198999]=(d[(c[199107]|0)+3|0]<<8&16128)+(c[198999]|0);e=c[199105]|0;f=c[199289]|0;c[198994]=d[f+((c[199106]|0)+e&65535)|0]|0;c[198993]=d[f+e|0]|0;jI(796316);e=i-1|0;if((e|0)==0){h=8479;break}else{B=e;h=8406;continue}}else if((h|0)==8402){h=0;a[795942]=s;c[198999]=(d[t+3|0]<<8&16128)+u;e=c[199070]|0;c[198994]=d[v+((c[199071]|0)+e&65535)|0]|0;c[198993]=d[v+e|0]|0;jI(796176);e=r-1|0;if((e|0)==0){h=8480;break}else{p=e;h=8403;continue}}else if((h|0)==8413){h=0;jG(796456);e=l-1|0;if((e|0)==0){h=8481;break}else{K=e;h=8414;continue}}else if((h|0)==8403){h=0;a[795772]=a[795940]|0;a[795941]=a[796172]|0;c[198998]=(c[198995]<<2)+(c[198989]<<8);c[198995]=d[(c[199142]|0)+4|0]|0;jH(796176);e=p-1|0;if((e|0)==0){h=8482;break}else{A=e;h=8404;continue}}else if((h|0)==8411){h=0;a[(c[199107]|0)+8|0]=a[795941]|0;a[795942]=(c[199e3]|0)>>>8&255;c[198999]=(d[(c[199177]|0)+3|0]<<8&16128)+(c[198999]|0);e=c[199175]|0;f=c[199289]|0;c[198994]=d[f+((c[199176]|0)+e&65535)|0]|0;c[198993]=d[f+e|0]|0;jI(796596);e=q-1|0;if((e|0)==0){h=8483;break}else{z=e;h=8412;continue}}else if((h|0)==8408){h=0;a[(c[199072]|0)+8|0]=a[795941]|0;a[795942]=(c[199e3]|0)>>>8&255;c[198999]=(d[(c[199142]|0)+3|0]<<8&16128)+(c[198999]|0);e=c[199140]|0;f=c[199289]|0;c[198994]=d[f+((c[199141]|0)+e&65535)|0]|0;c[198993]=d[f+e|0]|0;jI(796456);e=w-1|0;if((e|0)==0){h=8484;break}else{g=e;h=8409;continue}}else if((h|0)==8394){h=0;e=c[199e3]|0;f=(ab(a[(c[199037]|0)+1|0]|0,e)|0)>>7;Z=f+(c[199004]|0)|0;if((Z<<16>>16|0)==(Z|0)){_=Z}else{_=Z>>31^32767}c[199004]=_;Z=c[199038]|0;do{if((Z&c[198988]|0)!=0){$=(c[199006]|0)+f|0;c[199006]=$;if(($<<16>>16|0)==($|0)){break}c[199006]=$>>31^32767}}while(0);f=d[795772]|c[199001];if((c[199039]|0)==5){aa=f&(Z^255)}else{aa=f}a[795940]=aa&255;f=c[198998]|0;$=c[199289]|0;ac=(c[199074]|0)==0?f+2|0:f;c[198991]=d[$+(ac+1)|0]<<8|d[$+ac|0];ac=c[199072]|0;c[198992]=d[ac+5|0]|0;f=d[ac+2|0]|0;c[198999]=f;ad=x-1|0;if((ad|0)==0){h=8485;break}else{r=ad;s=e>>>8&255;t=ac;u=f;v=$;h=8402;continue}}else if((h|0)==8410){h=0;jG(796316);$=y-1|0;if(($|0)==0){h=8486;break}else{q=$;h=8411;continue}}else if((h|0)==8412){h=0;a[795772]=a[795940]|0;a[795941]=a[796592]|0;c[198998]=(c[198995]<<2)+(c[198989]<<8);c[198995]=d[(c[199247]|0)+4|0]|0;jH(796596);$=z-1|0;if(($|0)==0){h=8487;break}else{l=$;h=8413;continue}}else if((h|0)==8404){h=0;jG(796036);$=A-1|0;if(($|0)==0){h=8488;break}else{i=$;h=8405;continue}}else if((h|0)==8406){h=0;a[795772]=a[795940]|0;a[795941]=a[796312]|0;c[198998]=(c[198995]<<2)+(c[198989]<<8);c[198995]=d[(c[199177]|0)+4|0]|0;jH(796316);$=B-1|0;if(($|0)==0){h=8489;break}else{C=$;h=8407;continue}}else if((h|0)==8407){h=0;jG(796176);$=C-1|0;if(($|0)==0){h=8491;break}else{w=$;h=8408;continue}}else if((h|0)==8414){h=0;a[(c[199142]|0)+8|0]=a[795941]|0;a[795942]=(c[199e3]|0)>>>8&255;c[198999]=(d[(c[199212]|0)+3|0]<<8&16128)+(c[198999]|0);$=c[199210]|0;f=c[199289]|0;c[198994]=d[f+((c[199211]|0)+$&65535)|0]|0;c[198993]=d[f+$|0]|0;jI(796736);$=K-1|0;if(($|0)==0){h=8492;break}else{L=$;h=8415;continue}}else if((h|0)==8415){h=0;a[795772]=a[795940]|0;a[795941]=a[796732]|0;c[198998]=(c[198995]<<2)+(c[198989]<<8);c[198995]=d[(c[199282]|0)+4|0]|0;jH(796736);$=L-1|0;if(($|0)==0){h=8493;break}else{M=$;h=8416;continue}}else if((h|0)==8416){h=0;jG(796596);$=M-1|0;if(($|0)==0){h=8494;break}else{N=$;h=8417;continue}}else if((h|0)==8417){h=0;a[(c[199177]|0)+8|0]=a[795941]|0;a[795942]=(c[199e3]|0)>>>8&255;c[198999]=(d[(c[199247]|0)+3|0]<<8&16128)+(c[198999]|0);$=c[199245]|0;f=c[199289]|0;c[198994]=d[f+((c[199246]|0)+$&65535)|0]|0;c[198993]=d[f+$|0]|0;jI(796876);$=N-1|0;if(($|0)==0){h=8495;break}else{O=$;h=8418;continue}}else if((h|0)==8418){h=0;c[198998]=(c[198995]<<2)+(c[198989]<<8);c[198995]=d[(c[199037]|0)+4|0]|0;a[795772]=a[795940]|0;a[795941]=a[796872]|0;jH(796876);$=O-1|0;if(($|0)==0){h=8496;break}else{P=$;h=8419;continue}}else if((h|0)==8419){h=0;jG(796736);$=P-1|0;if(($|0)==0){h=8497;break}else{Q=$;h=8420;continue}}else if((h|0)==8420){h=0;a[(c[199212]|0)+8|0]=a[795941]|0;a[795942]=(c[199e3]|0)>>>8&255;c[198999]=(d[(c[199282]|0)+3|0]<<8&16128)+(c[198999]|0);$=c[199280]|0;f=c[199289]|0;c[198994]=d[f+((c[199281]|0)+$&65535)|0]|0;c[198993]=d[f+$|0]|0;jI(797016);$=Q-1|0;if(($|0)==0){h=8498;break}else{R=$;h=8421;continue}}else if((h|0)==8421){h=0;c[198998]=(c[198995]<<2)+(c[198989]<<8);c[198995]=d[(c[199072]|0)+4|0]|0;a[795772]=a[795940]|0;a[795941]=a[797012]|0;jH(797016);$=R-1|0;if(($|0)==0){h=8499;break}else{S=$;h=8422;continue}}else if((h|0)==8422){h=0;a[(c[199247]|0)+9|0]=a[795942]|0;$=(ab(a[(c[199282]|0)+1|0]|0,c[199e3]|0)|0)>>7;f=$+(c[199004]|0)|0;if((f<<16>>16|0)==(f|0)){ae=f}else{ae=f>>31^32767}c[199004]=ae;f=c[199283]|0;do{if((f&c[198988]|0)!=0){ac=(c[199006]|0)+$|0;c[199006]=ac;if((ac<<16>>16|0)==(ac|0)){break}c[199006]=ac>>31^32767}}while(0);$=d[795772]|c[199001];if((c[199284]|0)==5){af=$&(f^255)&255}else{af=$&255}a[795940]=af;$=c[198998]|0;e=c[199289]|0;Z=(c[199039]|0)==0?$+2|0:$;c[198991]=d[e+(Z+1)|0]<<8|d[e+Z|0];Z=c[199037]|0;c[198992]=d[Z+5|0]|0;e=d[Z+2|0]|0;c[198999]=e;$=S-1|0;if(($|0)==0){h=8500;break}else{D=$;E=Z;F=e;h=8430;continue}}else if((h|0)==8430){h=0;c[198999]=(d[E+3|0]<<8&16128)+F;a[(c[199247]|0)+8|0]=a[795941]|0;a[795942]=(c[199e3]|0)>>>8&255;e=(c[198976]|0)+8|0;Z=e>>>0<795840>>>0?e:795776;c[198976]=Z;e=(c[198996]<<8)+(c[198981]|0)&65535;c[199002]=e;if(e>>>0>65471&(c[199301]|0)!=0){$=c[199303]|0;ag=d[$+(e-65471)|0]<<8|d[$+(e-65472)|0]}else{$=c[199289]|0;ag=d[$+(e+1)|0]<<8|d[$+e|0]}e=ag<<16>>17;c[Z+64>>2]=e;c[c[198976]>>2]=e;e=c[198976]|0;Z=a[795663]|0;$=(ab(Z,c[e+8>>2]|0)|0)>>6;ac=(ab(c[e+12>>2]|0,Z)|0)>>6;c[199007]=$;c[199008]=ac;Z=D-1|0;if((Z|0)==0){h=8501;break}else{G=Z;H=e;I=$;J=ac;h=8434;continue}}else if((h|0)==8434){h=0;a[795772]=a[795940]|0;a[795941]=a[797152]|0;ac=a[795679]|0;$=(ab(ac,c[H+16>>2]|0)|0)>>6;e=a[795695]|0;Z=(ab(e,c[H+24>>2]|0)|0)>>6;ad=(ab(c[H+20>>2]|0,ac)|0)>>6;ac=(ab(c[H+28>>2]|0,e)|0)>>6;c[199007]=$+I+Z;c[199008]=ad+J+ac;ac=c[199002]|0;if((ac|0)>65471&(c[199301]|0)!=0){ad=c[199303]|0;ah=d[ad+(ac-65469)|0]<<8|d[ad+(ac-65470)|0]}else{ad=c[199289]|0;ah=d[ad+(ac+3)|0]<<8|d[ad+(ac+2)|0]}ac=ah<<16>>17;c[H+68>>2]=ac;c[(c[198976]|0)+4>>2]=ac;ac=G-1|0;if((ac|0)==0){h=8502;break}else{T=ac;h=8438;continue}}else if((h|0)==8438){h=0;a[(c[199282]|0)+9|0]=a[795942]|0;ac=c[198976]|0;ad=a[795711]|0;Z=(ab(ad,c[ac+32>>2]|0)|0)>>6;$=a[795727]|0;e=((ab($,c[ac+40>>2]|0)|0)>>6)+Z|0;Z=a[795743]|0;ai=e+((ab(Z,c[ac+48>>2]|0)|0)>>6)|0;e=(ab(c[ac+36>>2]|0,ad)|0)>>6;ad=((ab(c[ac+44>>2]|0,$)|0)>>6)+e|0;e=ad+((ab(c[ac+52>>2]|0,Z)|0)>>6)|0;c[199007]=ai+(c[199007]|0);c[199008]=e+(c[199008]|0);e=T-1|0;if((e|0)==0){h=8503;break}else{U=e;h=8439;continue}}else if((h|0)==8439){h=0;e=c[199035]|0;ai=c[199289]|0;c[198994]=d[ai+((c[199036]|0)+e&65535)|0]|0;c[198993]=d[ai+e|0]|0;a[(c[199282]|0)+8|0]=a[795941]|0;e=c[199007]|0;ai=c[198976]|0;Z=a[795759]|0;ac=((ab(Z,c[ai+56>>2]|0)|0)>>>6)+e|0;e=c[199008]|0;ad=((ab(c[ai+60>>2]|0,Z)|0)>>>6)+e<<16>>16;e=a[795775]|0;Z=((ab(e,c[ai+64>>2]|0)|0)>>>6<<16>>16)+(ac<<16>>16)|0;ac=((ab(c[ai+68>>2]|0,e)|0)>>>6<<16>>16)+ad|0;if((Z<<16>>16|0)==(Z|0)){aj=Z}else{aj=Z>>31^32767}if((ac<<16>>16|0)==(ac|0)){ak=ac}else{ak=ac>>31^32767}ac=aj&-2;c[199007]=ac;c[199008]=ak&-2;Z=U-1|0;if((Z|0)==0){h=8504;break}else{j=Z;k=ac;h=8444;continue}}else if((h|0)==8444){h=0;ac=(ab(a[795660]|0,c[199003]|0)|0)>>>7<<16>>16;Z=((ab(a[795692]|0,k)|0)>>>7<<16>>16)+ac|0;if((Z<<16>>16|0)==(Z|0)){al=Z}else{al=Z>>31^32767}c[199003]=al;Z=c[199005]|0;ac=a[795661]|0;ad=((ab(ac,k)|0)>>>7<<16>>16)+Z|0;Z=c[199006]|0;e=c[199008]|0;ai=((ab(e,ac)|0)>>>7<<16>>16)+Z|0;if((ad<<16>>16|0)==(ad|0)){am=ad}else{am=ad>>31^32767}if((ai<<16>>16|0)==(ai|0)){an=ai}else{an=ai>>31^32767}c[199005]=am&-2;c[199006]=an&-2;ai=j-1|0;if((ai|0)==0){h=8505;break}else{m=ai;n=al&65535;o=e;h=8451;continue}}else if((h|0)==8451){h=0;c[198986]=a[795693]&254;e=(ab(a[795676]|0,c[199004]|0)|0)>>>7<<16>>16;ai=((ab(a[795708]|0,o)|0)>>>7<<16>>16)+e|0;if((ai<<16>>16|0)==(ai|0)){ao=ai&65535}else{ao=(ai>>31^32767)&65535}c[199003]=0;c[199004]=0;ai=(a[795756]&64)==0;e=c[199290]|0;b[e>>1]=ai?n:0;b[e+2>>1]=ai?ao:0;ai=e+4|0;if(ai>>>0<(c[199291]|0)>>>0){ap=ai}else{c[199291]=797204;ap=797172}c[199290]=ap;ai=m-1|0;if((ai|0)==0){h=8506;break}else{V=ai;h=8456;continue}}else if((h|0)==8456){h=0;c[198987]=d[795709]|0;c[198988]=d[795725]|0;c[198989]=d[795741]|0;c[198997]=d[795756]|0;ai=V-1|0;if((ai|0)==0){h=8507;break}else{W=ai;h=8457;continue}}else if((h|0)==8457){h=0;ai=c[198977]|0;c[198977]=ai^1;if((ai|0)!=1){c[198984]=c[198984]&~c[198978]}c[198996]=d[795757]|0;ai=c[198981]|0;if((ai|0)==0){e=d[795773]<<11&30720;c[198982]=e;aq=e}else{aq=c[198982]|0}e=ai+4|0;c[198981]=(e|0)<(aq|0)?e:0;do{if((c[198997]&32|0)==0){e=c[199002]|0;ai=c[199289]|0;ad=c[199005]|0;a[ai+(e+1)|0]=ad>>>8&255;a[ai+e|0]=ad&255;ad=c[199002]|0;if((ad|0)<=65471){break}e=c[199303]|0;ai=c[199005]|0;a[e+(ad-65471)|0]=ai>>>8&255;a[e+(ad-65472)|0]=ai&255;if((c[199301]|0)==0){break}ai=c[199002]|0;ad=c[199289]|0;e=c[199302]|0;Z=a[e+(ai-65472)|0]|0;a[ad+(ai+1)|0]=a[e+(ai-65471)|0]|0;a[ad+ai|0]=Z}}while(0);c[199005]=0;c[198997]=d[795756]|0;f=W-1|0;if((f|0)==0){h=8508;break}else{X=f;h=8467;continue}}else if((h|0)==8467){h=0;if((c[198977]|0)!=0){c[198978]=c[198984];c[198990]=d[795740]|0}f=(c[198980]|0)-1|0;Z=(f|0)<0?30719:f;c[198980]=Z;f=a[795756]&31;if((((Z+(c[17096+(f<<2)>>2]|0)|0)>>>0)%((c[16968+(f<<2)>>2]|0)>>>0)|0|0)==0){f=c[198979]|0;c[198979]=(f<<13^f<<14)&16384^f>>1}jI(796036);do{if((c[198997]&32|0)==0){f=c[199002]|0;Z=c[199289]|0;ai=c[199006]|0;a[Z+(f+3)|0]=ai>>>8&255;a[Z+(f+2)|0]=ai&255;ai=c[199002]|0;if((ai|0)<=65471){break}f=c[199303]|0;Z=c[199006]|0;a[f+(ai-65469)|0]=Z>>>8&255;a[f+(ai-65470)|0]=Z&255;if((c[199301]|0)==0){break}Z=c[199002]|0;ai=c[199289]|0;f=c[199302]|0;ad=a[f+(Z-65470)|0]|0;a[ai+(Z+3)|0]=a[f+(Z-65469)|0]|0;a[ai+(Z+2)|0]=ad}}while(0);c[199006]=0;ad=X-1|0;if((ad|0)==0){h=8509;break}else{Y=ad;h=8476;continue}}else if((h|0)==8476){h=0;jH(796036);c[198998]=(c[198995]<<2)+(c[198989]<<8);c[198995]=d[(c[199107]|0)+4|0]|0;ad=Y-1|0;if((ad|0)==0){h=8510;break}else{x=ad;h=8394;continue}}}if((h|0)==8505){return}else if((h|0)==8506){return}else if((h|0)==8507){return}else if((h|0)==8508){return}else if((h|0)==8495){return}else if((h|0)==8496){return}else if((h|0)==8497){return}else if((h|0)==8479){return}else if((h|0)==8480){return}else if((h|0)==8481){return}else if((h|0)==8486){return}else if((h|0)==8487){return}else if((h|0)==8488){return}else if((h|0)==8492){return}else if((h|0)==8493){return}else if((h|0)==8494){return}else if((h|0)==8501){return}else if((h|0)==8502){return}else if((h|0)==8503){return}else if((h|0)==8504){return}else if((h|0)==8498){return}else if((h|0)==8499){return}else if((h|0)==8500){return}else if((h|0)==8509){return}else if((h|0)==8510){return}else if((h|0)==8482){return}else if((h|0)==8483){return}else if((h|0)==8484){return}else if((h|0)==8485){return}else if((h|0)==8478){return}else if((h|0)==8489){return}else if((h|0)==8491){return}}function jG(b){b=b|0;var e=0,f=0,g=0,h=0;a[(c[b+112>>2]|0)+9|0]=a[795942]|0;e=(ab(a[(c[b+252>>2]|0)+1|0]|0,c[199e3]|0)|0)>>7;f=e+(c[199004]|0)|0;if((f<<16>>16|0)==(f|0)){g=f}else{g=f>>31^32767}c[199004]=g;g=b+256|0;do{if((c[g>>2]&c[198988]|0)!=0){f=(c[199006]|0)+e|0;c[199006]=f;if((f<<16>>16|0)==(f|0)){break}c[199006]=f>>31^32767}}while(0);e=d[795772]|c[199001];if((c[b+260>>2]|0)==5){h=(c[g>>2]^255)&e&255}else{h=e&255}a[795940]=h;h=c[198998]|0;e=c[199289]|0;g=(c[b+400>>2]|0)==0?h+2|0:h;c[198991]=d[e+(g+1)|0]<<8|d[e+g|0];g=b+392|0;c[198992]=d[(c[g>>2]|0)+5|0]|0;c[198999]=d[(c[g>>2]|0)+2|0]|0;return}function jH(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;c[199001]=0;e=b+100|0;do{if((c[e>>2]|0)>16383){f=b+104|0;g=b+108|0;h=d[(c[199289]|0)+((c[f>>2]|0)+1+(c[g>>2]|0)&65535)|0]|c[198994]<<8;i=c[198993]|0;j=b+96|0;k=c[j>>2]|0;l=b+(k<<2)|0;m=k+4|0;c[j>>2]=(m|0)>11?0:m;j=b+(m<<2)|0;L11751:do{if((k|0)<2147483644){m=i>>4;n=i&12;o=n>>>0>7;p=(n|0)==8;q=(n|0)==0;if((m|0)>12){n=l;r=h;while(1){s=r<<16>>28<<m>>26<<11;t=c[n+44>>2]|0;u=c[n+40>>2]|0;v=u>>1;do{if(o){w=t-v+s|0;if(p){x=((t*-3|0)>>6)+(u>>5)+w|0;break}else{x=w+((t*-13|0)>>7)+((v*3|0)>>4)|0;break}}else{if(q){x=s;break}x=(-t>>5)+(t>>1)+s|0}}while(0);if((x<<16>>16|0)==(x|0)){y=x}else{y=x>>31^32767}s=y<<17>>16;c[n>>2]=s;c[n+48>>2]=s;s=n+4|0;if(s>>>0<j>>>0){n=s;r=r<<4}else{break L11751}}}if(o){z=l;A=h}else{r=l;n=h;while(1){s=n<<16>>28<<m>>1;t=c[r+44>>2]|0;if(q){B=s}else{B=(-t>>5)+(t>>1)+s|0}if((B<<16>>16|0)==(B|0)){C=B}else{C=B>>31^32767}s=C<<17>>16;c[r>>2]=s;c[r+48>>2]=s;s=r+4|0;if(s>>>0<j>>>0){r=s;n=n<<4}else{break L11751}}}while(1){n=c[z+44>>2]|0;r=c[z+40>>2]|0;q=r>>1;o=(A<<16>>28<<m>>1)+n-q|0;if(p){D=((n*-3|0)>>6)+(r>>5)+o|0}else{D=o+((n*-13|0)>>7)+((q*3|0)>>4)|0}if((D<<16>>16|0)==(D|0)){E=D}else{E=D>>31^32767}q=E<<17>>16;c[z>>2]=q;c[z+48>>2]=q;q=z+4|0;if(q>>>0<j>>>0){z=q;A=A<<4}else{break}}}}while(0);j=(c[g>>2]|0)+2|0;c[g>>2]=j;if((j|0)<=8){break}c[f>>2]=(c[f>>2]|0)+9&65535;if((c[198993]&1|0)!=0){c[f>>2]=c[198991];c[199001]=c[b+116>>2]}c[g>>2]=1}}while(0);A=(c[e>>2]&16383)+(c[198999]|0)|0;c[e>>2]=(A|0)>32767?32767:A;A=(ab(a[c[b+112>>2]|0]|0,c[199e3]|0)|0)>>7;e=A+(c[199003]|0)|0;if((e<<16>>16|0)==(e|0)){F=e}else{F=e>>31^32767}c[199003]=F;if((c[b+116>>2]&c[198988]|0)==0){return}b=(c[199005]|0)+A|0;c[199005]=b;if((b<<16>>16|0)==(b|0)){return}c[199005]=b>>31^32767;return}function jI(e){e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;f=e+116|0;if((c[f>>2]&c[198986]|0)!=0){g=c[198999]|0;c[198999]=((ab(c[199e3]>>5,g)|0)>>10)+g}g=e+120|0;h=c[g>>2]|0;if((h|0)==0){i=e+100|0}else if((h|0)==5){c[e+104>>2]=c[198991];c[e+108>>2]=1;c[e+96>>2]=0;c[198993]=0;j=c[g>>2]|0;k=8561}else{j=h;k=8561}if((k|0)==8561){c[e+128>>2]=0;c[e+132>>2]=0;h=e+100|0;c[h>>2]=0;l=j-1|0;c[g>>2]=l;if((l&3|0)!=0){c[h>>2]=16384}c[198999]=0;i=h}h=c[i>>2]|0;i=h>>>4&255;l=i^255;j=(h>>12)+(c[e+96>>2]|0)|0;h=(ab(b[9864+(l<<1)>>1]|0,c[e+(j<<2)>>2]|0)|0)>>>11;m=((ab(b[9864+((l|256)<<1)>>1]|0,c[e+(j+1<<2)>>2]|0)|0)>>>11)+h|0;h=m+((ab(b[9864+((i|256)<<1)>>1]|0,c[e+(j+2<<2)>>2]|0)|0)>>>11)<<16>>16;m=h+((ab(b[9864+(i<<1)>>1]|0,c[e+(j+3<<2)>>2]|0)|0)>>11)|0;if((m<<16>>16|0)==(m|0)){n=m}else{n=m>>31^32767}if((c[f>>2]&c[198987]|0)==0){o=n&-2}else{o=c[198979]<<17>>16}n=e+128|0;c[199e3]=(ab(c[n>>2]|0,o)|0)>>11&-2;o=c[n>>2]|0;a[e+136|0]=o>>>4&255;if((a[795756]|0)<0){k=8570}else{if((c[198993]&3|0)==1){k=8570}else{p=o}}if((k|0)==8570){c[e+124>>2]=0;c[n>>2]=0;p=0}do{if((c[198977]|0)!=0){o=c[f>>2]|0;if((o&c[198990]|0)!=0){c[e+124>>2]=0}if((c[198978]&o|0)==0){break}c[g>>2]=5;c[e+124>>2]=1}}while(0);if((c[g>>2]|0)!=0){return}g=e+124|0;f=c[g>>2]|0;if((f|0)==0){o=p-8|0;c[n>>2]=(o|0)<0?0:o;return}o=c[e+112>>2]|0;m=d[o+6|0]|0;j=c[198992]|0;do{if((j&128|0)==0){i=a[o+7|0]|0;h=i&255;l=h>>>5;if(i<<24>>24>-1){q=h<<4;r=h;s=31;k=8592;break}t=h&31;if((l|0)==4){q=p-32|0;r=h;s=t;k=8592;break}if((i&255)<192){i=p-1|0;q=i-(i>>8)|0;r=h;s=t;k=8592;break}i=p+32|0;if((l|0)!=7){q=i;r=h;s=t;k=8592;break}q=(c[e+132>>2]|0)>>>0>1535?p+8|0:i;r=h;s=t;k=8592}else{if((f|0)<=1){t=j<<1&30|1;u=f;v=t;w=((t|0)!=31?32:1024)+p|0;break}t=p-1|0;h=t-(t>>8)|0;if((f|0)!=2){u=f;v=m&31;w=h;break}q=h;r=m;s=j>>>3&14|16;k=8592}}while(0);do{if((k|0)==8592){if(!((q>>8|0)==(r>>>5|0)&(f|0)==2)){u=f;v=s;w=q;break}c[g>>2]=3;u=3;v=s;w=q}}while(0);c[e+132>>2]=w;do{if(w>>>0>2047){e=(w>>31&-2047)+2047|0;if((u|0)!=1){x=e;break}c[g>>2]=2;x=e}else{x=w}}while(0);if(((((c[17096+(v<<2)>>2]|0)+(c[198980]|0)|0)>>>0)%((c[16968+(v<<2)>>2]|0)>>>0)|0|0)!=0){return}c[n>>2]=x;return}function jJ(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;switch(e|0){case 10:case 11:case 12:{f=e-10|0;g=(b+255&255)+1|0;h=436800+(f*24|0)|0;i=c[h>>2]|0;if((i|0)==(g|0)){return}j=436792+(f*24|0)|0;k=c[j>>2]|0;do{if((k|0)<=(d|0)){l=c[436796+(f*24|0)>>2]|0;m=d-k>>l;n=m+1|0;c[j>>2]=(n<<l)+k;if((c[436808+(f*24|0)>>2]|0)==0){break}l=436804+(f*24|0)|0;o=c[l>>2]|0;p=m-(i+255-o&255)|0;if((p|0)>-1){m=(p|0)/(i|0)|0;q=436812+(f*24|0)|0;c[q>>2]=m+1+(c[q>>2]|0)&15;r=p-(ab(m,i)|0)&255}else{r=o+n&255}c[l>>2]=r&255}}while(0);c[h>>2]=g;return};case 1:{if((b&16|0)!=0){a[436884]=0;a[436885]=0}if((b&32|0)==0){s=0}else{a[436886]=0;a[436887]=0;s=0}do{g=b>>>(s>>>0)&1;h=436808+(s*24|0)|0;r=c[h>>2]|0;do{if((r|0)!=(g|0)){i=436792+(s*24|0)|0;f=c[i>>2]|0;do{if((f|0)<=(d|0)){k=c[436796+(s*24|0)>>2]|0;j=d-f>>k;l=j+1|0;c[i>>2]=(l<<k)+f;if((r|0)==0){break}k=c[436800+(s*24|0)>>2]|0;n=436804+(s*24|0)|0;o=c[n>>2]|0;m=j-(k+255-o&255)|0;if((m|0)>-1){j=(m|0)/(k|0)|0;p=436812+(s*24|0)|0;c[p>>2]=j+1+(c[p>>2]|0)&15;t=m-(ab(j,k)|0)&255}else{t=o+l&255}c[n>>2]=t&255}}while(0);c[h>>2]=g;if((g|0)==0){break}c[436804+(s*24|0)>>2]=0;c[436812+(s*24|0)>>2]=0}}while(0);s=s+1|0;}while((s|0)<3);s=b&128;if((c[109245]|0)==(s|0)){return}c[199301]=s;c[109245]=s;t=(s|0)!=0;if(t){X5(437048,503096,64)|0}s=t?436984:437048;X5(503096,s|0,64)|0;return};case 8:case 9:{a[436880+e|0]=b&255;return};case 13:case 14:case 15:{if((b|0)>=4096){return}b=d-1|0;d=e-13|0;e=436792+(d*24|0)|0;s=c[e>>2]|0;if((b|0)<(s|0)){c[436812+(d*24|0)>>2]=0;return}t=c[436796+(d*24|0)>>2]|0;g=b-s>>t;b=g+1|0;c[e>>2]=(b<<t)+s;if((c[436808+(d*24|0)>>2]|0)!=0){s=c[436800+(d*24|0)>>2]|0;t=436804+(d*24|0)|0;e=c[t>>2]|0;h=g-(s+255-e&255)|0;if((h|0)>-1){g=(h|0)/(s|0)|0;r=436812+(d*24|0)|0;c[r>>2]=g+1+(c[r>>2]|0)&15;u=h-(ab(g,s)|0)&255}else{u=e+b&255}c[t>>2]=u&255}c[436812+(d*24|0)>>2]=0;return};default:{return}}}function jK(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=b;while(1){g=f-240|0;if(!((g|0)>-1&(f-256|0)>>>0>65279)){h=8663;break}i=f-253|0;if(i>>>0<3){h=8651;break}if((i|0)<0){h=8658;break}else{f=f-65536|0}}if((h|0)==8651){b=436792+(i*24|0)|0;j=c[b>>2]|0;do{if((j|0)<=(e|0)){k=c[436796+(i*24|0)>>2]|0;l=e-j>>k;m=l+1|0;c[b>>2]=(m<<k)+j;if((c[436808+(i*24|0)>>2]|0)==0){break}k=c[436800+(i*24|0)>>2]|0;n=436804+(i*24|0)|0;o=c[n>>2]|0;p=l-(k+255-o&255)|0;if((p|0)>-1){l=(p|0)/(k|0)|0;q=436812+(i*24|0)|0;c[q>>2]=l+1+(c[q>>2]|0)&15;r=p-(ab(l,k)|0)&255}else{r=o+m&255}c[n>>2]=r&255}}while(0);r=436812+(i*24|0)|0;i=c[r>>2]|0;c[r>>2]=0;s=i;return s|0}else if((h|0)==8658){i=f-242|0;if(i>>>0>=2){s=d[436880+g|0]|0;return s|0}g=a[436866]|0;r=g&255;if((i|0)!=1){s=r;return s|0}i=c[109230]|0;j=e-(a[235744+(r&127)|0]|0)-i|0;if((j|0)>-1){r=j+32&-32;c[109230]=r+i;jF(r);t=a[436866]|0}else{t=g}s=d[795648+(t&127)|0]|0;return s|0}else if((h|0)==8663){s=d[437624+f|0]|0;return s|0}return 0}function jL(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=b&255;g=437624+d|0;a[g]=f;h=d-240|0;if((h|0)>-1){i=d;j=g;k=h}else{return}while(1){if((k|0)<16){l=8672;break}m=i-65472|0;if((m|0)<=-1){l=8698;break}if((m|0)<64){l=8686;break}a[j]=-1;h=i-65536|0;g=437624+h|0;a[g]=f;d=i-65776|0;if((d|0)>-1){i=h;j=g;k=d}else{l=8700;break}}if((l|0)==8686){a[437048+m|0]=f;if((c[109245]|0)==0){return}a[j]=a[436984+m|0]|0;return}else if((l|0)==8698){return}else if((l|0)==8700){return}else if((l|0)==8672){a[436864+k|0]=f;if((-788594688<<k|0)>=0){return}if((k|0)!=3){jJ(b,e,k);return}k=a[436866]|0;l=c[109230]|0;m=e-(a[235744+(k&255)|0]|0)-l|0;if((m|0)>-1){e=m+32&-32;c[109230]=e+l;jF(e);n=a[436866]|0}else{n=k}if(n<<24>>24<=-1){return}k=n&255;a[795648+k|0]=f;e=k&15;if((e|0)==8){a[795941]=f;return}else if((e|0)==9){a[795942]=f;return}else if((e|0)==12){if((n<<24>>24|0)==124){a[795940]=0;a[795772]=0;return}else if((n<<24>>24|0)==76){c[198984]=b&255;return}else{return}}else{return}}}function jM(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=d&65535;f=d>>>16&255;L12000:do{if((f|0)!=0&f>>>0<15){if((d&65535|0)!=20480){g=8714;break}switch(f|0){case 192:{break L12000;break};case 14:{a[1394355]=b;if(b<<24>>24==0){return}if((a[1394257]|a[1394256])<<24>>24==0){g=8714;break L12000}jN();g=8714;break L12000;break};case 1:case 2:case 3:case 4:case 5:case 6:case 9:case 10:case 11:case 12:case 13:{h=1394341+f|0;if((a[h]|0)==b<<24>>24){g=8714;break L12000}a[h]=b;a[1394256]=1;g=8714;break L12000;break};case 7:case 8:{h=1394341+f|0;if((a[h]|0)==b<<24>>24){return}a[h]=b;a[1394257]=1;return};default:{return}}}else{g=8714}}while(0);do{if((g|0)==8714){if((f|0)==192){break}return}}while(0);f=c[348568]|0;c[348567]=f;c[348568]=d;if(!((f|0)!=(d|0)|(a[1394260]|0)==0)){f=d&65535;if((a[1394343]|0)!=0){a[(c[274488]|0)+f|0]=b;return}if(e<<16>>16>-1){a[(c[274488]|0)+f|0]=b;return}else{a[(c[274488]|0)+(f-32768)|0]=b;return}}f=d&65535;if((f|0)==21845){d=c[348566]<<8|b&255;c[348566]=d;e=d&16777215;if((e|0)==11163120){a[1394259]=0;a[1394260]=0;a[1394261]=0;return}else if((e|0)==11162992){a[1394260]=0;jN();return}else if((e|0)==11163040){c[348567]=0;c[348568]=0;a[1394259]=1;a[1394260]=1;jN();return}else{return}}else if((f|0)==0){e=c[348566]<<8|b&255;c[348566]=e;if((e&65535|0)!=14544){return}a[1394259]=1;a[1394261]=1;return}else if((f|0)==10922){c[348566]=c[348566]<<8|b&255;return}else{return}}function jN(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;X5(1394357,1394341,16)|0;if(!((a[1394257]|0)==0|(a[1394256]|0)!=0)){b=c[281374]|0;d=c[274488]|0;e=a[1394260]|0;f=e<<24>>24==0|0;if((a[1394343]|0)==0){g=0;while(1){h=g|8;i=g+16|0;if((h|0)<(i|0)){j=d+(((g<<11>>>0)%(b>>>0)|0)-32768)|0;k=h+2048|0;c[1052804+(k<<2)>>2]=j;c[1052804+(h<<2)>>2]=j;a[1085572+k|0]=e;a[1085572+h|0]=e;a[1089668+k|0]=f;a[1089668+h|0]=f;h=g|9;k=h+2048|0;c[1052804+(k<<2)>>2]=j;c[1052804+(h<<2)>>2]=j;a[1085572+k|0]=e;a[1085572+h|0]=e;a[1089668+k|0]=f;a[1089668+h|0]=f;k=h+1|0;l=h+2049|0;c[1052804+(l<<2)>>2]=j;c[1052804+(k<<2)>>2]=j;a[1085572+l|0]=e;a[1085572+k|0]=e;a[1089668+l|0]=f;a[1089668+k|0]=f;k=g|11;l=k+2048|0;c[1052804+(l<<2)>>2]=j;c[1052804+(k<<2)>>2]=j;a[1085572+l|0]=e;a[1085572+k|0]=e;a[1089668+l|0]=f;a[1089668+k|0]=f;l=k+1|0;h=k+2049|0;c[1052804+(h<<2)>>2]=j;c[1052804+(l<<2)>>2]=j;a[1085572+h|0]=e;a[1085572+l|0]=e;a[1089668+h|0]=f;a[1089668+l|0]=f;l=k+2|0;h=k+2050|0;c[1052804+(h<<2)>>2]=j;c[1052804+(l<<2)>>2]=j;a[1085572+h|0]=e;a[1085572+l|0]=e;a[1089668+h|0]=f;a[1089668+l|0]=f;l=k+3|0;h=k+2051|0;c[1052804+(h<<2)>>2]=j;c[1052804+(l<<2)>>2]=j;a[1085572+h|0]=e;a[1085572+l|0]=e;a[1089668+h|0]=f;a[1089668+l|0]=f;l=g|15;h=l+2048|0;c[1052804+(h<<2)>>2]=j;c[1052804+(l<<2)>>2]=j;a[1085572+h|0]=e;a[1085572+l|0]=e;a[1089668+h|0]=f;a[1089668+l|0]=f}if((i|0)<512){g=i}else{break}}}else{g=0;while(1){i=g|8;l=g+16|0;if((i|0)<(l|0)){h=d+((g<<12>>>0)%(b>>>0)|0)|0;j=i+2048|0;c[1052804+(j<<2)>>2]=h;c[1052804+(i<<2)>>2]=h;a[1085572+j|0]=e;a[1085572+i|0]=e;a[1089668+j|0]=f;a[1089668+i|0]=f;i=g|9;j=i+2048|0;c[1052804+(j<<2)>>2]=h;c[1052804+(i<<2)>>2]=h;a[1085572+j|0]=e;a[1085572+i|0]=e;a[1089668+j|0]=f;a[1089668+i|0]=f;j=i+1|0;k=i+2049|0;c[1052804+(k<<2)>>2]=h;c[1052804+(j<<2)>>2]=h;a[1085572+k|0]=e;a[1085572+j|0]=e;a[1089668+k|0]=f;a[1089668+j|0]=f;j=g|11;k=j+2048|0;c[1052804+(k<<2)>>2]=h;c[1052804+(j<<2)>>2]=h;a[1085572+k|0]=e;a[1085572+j|0]=e;a[1089668+k|0]=f;a[1089668+j|0]=f;k=j+1|0;i=j+2049|0;c[1052804+(i<<2)>>2]=h;c[1052804+(k<<2)>>2]=h;a[1085572+i|0]=e;a[1085572+k|0]=e;a[1089668+i|0]=f;a[1089668+k|0]=f;k=j+2|0;i=j+2050|0;c[1052804+(i<<2)>>2]=h;c[1052804+(k<<2)>>2]=h;a[1085572+i|0]=e;a[1085572+k|0]=e;a[1089668+i|0]=f;a[1089668+k|0]=f;k=j+3|0;i=j+2051|0;c[1052804+(i<<2)>>2]=h;c[1052804+(k<<2)>>2]=h;a[1085572+i|0]=e;a[1085572+k|0]=e;a[1089668+i|0]=f;a[1089668+k|0]=f;k=g|15;i=k+2048|0;c[1052804+(i<<2)>>2]=h;c[1052804+(k<<2)>>2]=h;a[1085572+i|0]=e;a[1085572+k|0]=e;a[1089668+i|0]=f;a[1089668+k|0]=f}if((l|0)<512){g=l}else{break}}}jO();a[1394257]=0;X5(1069188,1052804,16384)|0;g=0;do{if((a[1089668+g|0]|0)!=0){c[1069188+(g<<2)>>2]=18}g=g+1|0;}while((g|0)<4096);return}g=(a[1394342]|0)==0;f=g?c[281376]|0:c[263199]|0;c[274488]=f;c[281374]=g?2097152:524288;e=0;do{b=c[263191]|0;d=e+2048|0;c[1052804+(d<<2)>>2]=b;c[1052804+(e<<2)>>2]=b;b=c[263191]|0;l=e+2049|0;c[1052804+(l<<2)>>2]=b;k=e|1;c[1052804+(k<<2)>>2]=b;a[1085572+d|0]=1;a[1085572+e|0]=1;a[1085572+l|0]=1;a[1085572+k|0]=1;c[1052804+(e+2050<<2)>>2]=1;c[1052804+((e|2)<<2)>>2]=1;c[1052804+(e+2051<<2)>>2]=1;c[1052804+((e|3)<<2)>>2]=1;c[1052804+(e+2052<<2)>>2]=0;c[1052804+((e|4)<<2)>>2]=0;c[1052804+(e+2053<<2)>>2]=0;c[1052804+((e|5)<<2)>>2]=0;c[1052804+(e+2054<<2)>>2]=18;c[1052804+((e|6)<<2)>>2]=18;c[1052804+(e+2055<<2)>>2]=18;c[1052804+((e|7)<<2)>>2]=18;e=e+16|0;}while((e|0)<1024);e=a[1394260]|0;k=e<<24>>24==0|0;l=g?2097151:524287;if((a[1394343]|0)==0){g=0;while(1){d=g|8;b=g+16|0;if((d|0)<(b|0)){i=f+((g<<11&l)-32768)|0;h=d+2048|0;c[1052804+(h<<2)>>2]=i;c[1052804+(d<<2)>>2]=i;a[1085572+h|0]=e;a[1085572+d|0]=e;a[1089668+h|0]=k;a[1089668+d|0]=k;d=g|9;h=d+2048|0;c[1052804+(h<<2)>>2]=i;c[1052804+(d<<2)>>2]=i;a[1085572+h|0]=e;a[1085572+d|0]=e;a[1089668+h|0]=k;a[1089668+d|0]=k;h=d+1|0;j=d+2049|0;c[1052804+(j<<2)>>2]=i;c[1052804+(h<<2)>>2]=i;a[1085572+j|0]=e;a[1085572+h|0]=e;a[1089668+j|0]=k;a[1089668+h|0]=k;h=g|11;j=h+2048|0;c[1052804+(j<<2)>>2]=i;c[1052804+(h<<2)>>2]=i;a[1085572+j|0]=e;a[1085572+h|0]=e;a[1089668+j|0]=k;a[1089668+h|0]=k;j=h+1|0;d=h+2049|0;c[1052804+(d<<2)>>2]=i;c[1052804+(j<<2)>>2]=i;a[1085572+d|0]=e;a[1085572+j|0]=e;a[1089668+d|0]=k;a[1089668+j|0]=k;j=h+2|0;d=h+2050|0;c[1052804+(d<<2)>>2]=i;c[1052804+(j<<2)>>2]=i;a[1085572+d|0]=e;a[1085572+j|0]=e;a[1089668+d|0]=k;a[1089668+j|0]=k;j=h+3|0;d=h+2051|0;c[1052804+(d<<2)>>2]=i;c[1052804+(j<<2)>>2]=i;a[1085572+d|0]=e;a[1085572+j|0]=e;a[1089668+d|0]=k;a[1089668+j|0]=k;j=g|15;d=j+2048|0;c[1052804+(d<<2)>>2]=i;c[1052804+(j<<2)>>2]=i;a[1085572+d|0]=e;a[1085572+j|0]=e;a[1089668+d|0]=k;a[1089668+j|0]=k}if((b|0)<1024){g=b}else{m=0;break}}while(1){g=m|8;if((m|0)<(g|0)){b=f+(m<<11&l)|0;c[1052804+(m+3072<<2)>>2]=b;c[1052804+(m+1024<<2)>>2]=b;j=m|1;c[1052804+(j+3072<<2)>>2]=b;c[1052804+(j+1024<<2)>>2]=b;c[1052804+(j+3073<<2)>>2]=b;c[1052804+(j+1025<<2)>>2]=b;j=m|3;c[1052804+(j+3072<<2)>>2]=b;c[1052804+(j+1024<<2)>>2]=b;c[1052804+(j+3073<<2)>>2]=b;c[1052804+(j+1025<<2)>>2]=b;c[1052804+(j+3074<<2)>>2]=b;c[1052804+(j+1026<<2)>>2]=b;c[1052804+(j+3075<<2)>>2]=b;c[1052804+(j+1027<<2)>>2]=b;j=m|7;c[1052804+(j+3072<<2)>>2]=b;c[1052804+(j+1024<<2)>>2]=b}b=m+16|0;if((g|0)<(b|0)){j=f+((m<<11&l)-32768)|0;c[1052804+(g+3072<<2)>>2]=j;c[1052804+(g+1024<<2)>>2]=j;g=m|9;c[1052804+(g+3072<<2)>>2]=j;c[1052804+(g+1024<<2)>>2]=j;c[1052804+(g+3073<<2)>>2]=j;c[1052804+(g+1025<<2)>>2]=j;g=m|11;c[1052804+(g+3072<<2)>>2]=j;c[1052804+(g+1024<<2)>>2]=j;c[1052804+(g+3073<<2)>>2]=j;c[1052804+(g+1025<<2)>>2]=j;c[1052804+(g+3074<<2)>>2]=j;c[1052804+(g+1026<<2)>>2]=j;c[1052804+(g+3075<<2)>>2]=j;c[1052804+(g+1027<<2)>>2]=j;g=m|15;c[1052804+(g+3072<<2)>>2]=j;c[1052804+(g+1024<<2)>>2]=j;n=m}else{n=m}do{j=n+3072|0;a[1085572+j|0]=e;g=n+1024|0;a[1085572+g|0]=e;a[1089668+j|0]=k;a[1089668+g|0]=k;n=n+1|0;}while((n|0)<(b|0));if((b|0)<1024){m=b}else{o=0;break}}}else{m=0;while(1){n=m|8;g=m+16|0;if((n|0)<(g|0)){j=f+(m<<12&l)|0;d=n+2048|0;c[1052804+(d<<2)>>2]=j;c[1052804+(n<<2)>>2]=j;a[1085572+d|0]=e;a[1085572+n|0]=e;a[1089668+d|0]=k;a[1089668+n|0]=k;n=m|9;d=n+2048|0;c[1052804+(d<<2)>>2]=j;c[1052804+(n<<2)>>2]=j;a[1085572+d|0]=e;a[1085572+n|0]=e;a[1089668+d|0]=k;a[1089668+n|0]=k;d=n+1|0;i=n+2049|0;c[1052804+(i<<2)>>2]=j;c[1052804+(d<<2)>>2]=j;a[1085572+i|0]=e;a[1085572+d|0]=e;a[1089668+i|0]=k;a[1089668+d|0]=k;d=m|11;i=d+2048|0;c[1052804+(i<<2)>>2]=j;c[1052804+(d<<2)>>2]=j;a[1085572+i|0]=e;a[1085572+d|0]=e;a[1089668+i|0]=k;a[1089668+d|0]=k;i=d+1|0;n=d+2049|0;c[1052804+(n<<2)>>2]=j;c[1052804+(i<<2)>>2]=j;a[1085572+n|0]=e;a[1085572+i|0]=e;a[1089668+n|0]=k;a[1089668+i|0]=k;i=d+2|0;n=d+2050|0;c[1052804+(n<<2)>>2]=j;c[1052804+(i<<2)>>2]=j;a[1085572+n|0]=e;a[1085572+i|0]=e;a[1089668+n|0]=k;a[1089668+i|0]=k;i=d+3|0;n=d+2051|0;c[1052804+(n<<2)>>2]=j;c[1052804+(i<<2)>>2]=j;a[1085572+n|0]=e;a[1085572+i|0]=e;a[1089668+n|0]=k;a[1089668+i|0]=k;i=m|15;n=i+2048|0;c[1052804+(n<<2)>>2]=j;c[1052804+(i<<2)>>2]=j;a[1085572+n|0]=e;a[1085572+i|0]=e;a[1089668+n|0]=k;a[1089668+i|0]=k}if((g|0)<1024){m=g}else{p=0;break}}while(1){m=p+16|0;g=f+(p<<12&l)|0;i=p;do{n=i+3072|0;c[1052804+(n<<2)>>2]=g;j=i+1024|0;c[1052804+(j<<2)>>2]=g;a[1085572+n|0]=e;a[1085572+j|0]=e;a[1089668+n|0]=k;a[1089668+j|0]=k;i=i+1|0;}while((i|0)<(m|0));if((m|0)<1024){p=m}else{o=0;break}}}while(1){p=o+1792|0;c[1052804+(p<<2)>>2]=(c[263199]|0)+(o<<12&458752);a[1085572+p|0]=1;a[1089668+p|0]=0;p=o+1|0;if((p|0)<128){o=p}else{q=512;break}}do{o=q<<12&458752;p=q|6;c[1052804+(p<<2)>>2]=(c[263199]|0)+o;k=q|7;c[1052804+(k<<2)>>2]=(c[263199]|0)+o;a[1085572+p|0]=1;a[1085572+k|0]=1;a[1089668+p|0]=0;a[1089668+k|0]=0;q=q+16|0;}while((q|0)<1024);if((a[1394346]|0)==0){jP(64)}if((a[1394347]|0)==0){jP(80)}if((a[1394344]|0)==0){jP(96)}q=c[263193]|0;c[263462]=q-20480;a[1085833]=1;a[1089929]=0;c[263478]=q-16384;a[1085849]=1;a[1089945]=0;c[263494]=q-12288;a[1085865]=1;a[1089961]=0;c[263510]=q-8192;a[1085881]=1;a[1089977]=0;c[263526]=q-4096;a[1085897]=1;a[1089993]=0;c[263542]=q;a[1085913]=1;a[1090009]=0;c[263558]=q+4096;a[1085929]=1;a[1090025]=0;c[263574]=q+8192;a[1085945]=1;a[1090041]=0;q=0;do{k=q+2016|0;c[1052804+(k<<2)>>2]=c[263191];p=q+2032|0;c[1052804+(p<<2)>>2]=(c[263191]|0)+65536;a[1085572+k|0]=1;a[1085572+p|0]=1;a[1089668+k|0]=0;a[1089668+p|0]=0;q=q+1|0;}while((q|0)<16);jO();if((a[1394354]|a[1394353])<<24>>24!=0){q=0;do{p=q+3072|0;c[1052804+(p<<2)>>2]=17;a[1085572+p|0]=1;a[1089668+p|0]=0;q=q+1|0;}while((q|0)<16)}c[263222]=17;a[1089689]=0;a[1085593]=0;c[263238]=17;a[1089705]=0;a[1085609]=0;c[263254]=17;a[1089721]=0;a[1085625]=0;c[263270]=17;a[1089737]=0;a[1085641]=0;c[263286]=17;a[1089753]=0;a[1085657]=0;c[263302]=17;a[1089769]=0;a[1085673]=0;c[263318]=17;a[1089785]=0;a[1085689]=0;c[263334]=17;a[1089801]=0;a[1085705]=0;c[263350]=17;a[1089817]=0;a[1085721]=0;c[263366]=17;a[1089833]=0;a[1085737]=0;c[263382]=17;a[1089849]=0;a[1085753]=0;c[263398]=17;a[1089865]=0;a[1085769]=0;c[263414]=17;a[1089881]=0;a[1085785]=0;c[263430]=17;a[1089897]=0;a[1085801]=0;a[1394256]=0;a[1394257]=0;X5(1069188,1052804,16384)|0;q=0;do{if((a[1089668+q|0]|0)!=0){c[1069188+(q<<2)>>2]=18}q=q+1|0;}while((q|0)<4096);return}function jO(){var b=0,d=0,e=0,f=0,g=0,h=0;if((a[1394348]|0)!=0){b=0;while(1){d=b|8;e=b+16|0;if((d|0)<(e|0)){f=(b<<11)-32768|0;c[1052804+(d<<2)>>2]=(c[263200]|0)+f;a[1085572+d|0]=0;a[1089668+d|0]=1;d=b|9;c[1052804+(d<<2)>>2]=(c[263200]|0)+f;a[1085572+d|0]=0;a[1089668+d|0]=1;g=d+1|0;c[1052804+(g<<2)>>2]=(c[263200]|0)+f;a[1085572+g|0]=0;a[1089668+g|0]=1;g=b|11;c[1052804+(g<<2)>>2]=(c[263200]|0)+f;a[1085572+g|0]=0;a[1089668+g|0]=1;d=g+1|0;c[1052804+(d<<2)>>2]=(c[263200]|0)+f;a[1085572+d|0]=0;a[1089668+d|0]=1;d=g+2|0;c[1052804+(d<<2)>>2]=(c[263200]|0)+f;a[1085572+d|0]=0;a[1089668+d|0]=1;d=g+3|0;c[1052804+(d<<2)>>2]=(c[263200]|0)+f;a[1085572+d|0]=0;a[1089668+d|0]=1;d=b|15;c[1052804+(d<<2)>>2]=(c[263200]|0)+f;a[1085572+d|0]=0;a[1089668+d|0]=1}if((e|0)<512){b=e}else{break}}}if((a[1394349]|0)==0){return}else{h=0}while(1){b=h|8;e=h+16|0;if((b|0)<(e|0)){d=(h<<11)-32768|0;f=b+2048|0;c[1052804+(f<<2)>>2]=(c[263200]|0)+d;a[1085572+f|0]=0;a[1089668+f|0]=1;f=h|9;b=f+2048|0;c[1052804+(b<<2)>>2]=(c[263200]|0)+d;a[1085572+b|0]=0;a[1089668+b|0]=1;b=f+2049|0;c[1052804+(b<<2)>>2]=(c[263200]|0)+d;a[1085572+b|0]=0;a[1089668+b|0]=1;b=h|11;f=b+2048|0;c[1052804+(f<<2)>>2]=(c[263200]|0)+d;a[1085572+f|0]=0;a[1089668+f|0]=1;f=b+2049|0;c[1052804+(f<<2)>>2]=(c[263200]|0)+d;a[1085572+f|0]=0;a[1089668+f|0]=1;f=b+2050|0;c[1052804+(f<<2)>>2]=(c[263200]|0)+d;a[1085572+f|0]=0;a[1089668+f|0]=1;f=b+2051|0;c[1052804+(f<<2)>>2]=(c[263200]|0)+d;a[1085572+f|0]=0;a[1089668+f|0]=1;f=(h|15)+2048|0;c[1052804+(f<<2)>>2]=(c[263200]|0)+d;a[1085572+f|0]=0;a[1089668+f|0]=1}if((e|0)<512){h=e}else{break}}return}function jP(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b<<4;if((a[1394343]|0)!=0){b=0;while(1){e=b+16|0;f=(b<<12|0)%524288|0;g=b;do{h=g+d|0;c[1052804+(h<<2)>>2]=(c[263199]|0)+f;a[1085572+h|0]=1;a[1089668+h|0]=0;g=g+1|0;}while((g|0)<(e|0));if((e|0)<256){b=e}else{break}}return}b=d|1;g=d|2;f=d|3;h=0;while(1){i=h|8;if((h|0)<(i|0)){j=h<<11;c[1052804+(h+d<<2)>>2]=(c[263199]|0)+j;k=h|1;c[1052804+(k+d<<2)>>2]=(c[263199]|0)+j;c[1052804+(b+k<<2)>>2]=(c[263199]|0)+j;k=h|3;c[1052804+(k+d<<2)>>2]=(c[263199]|0)+j;c[1052804+(b+k<<2)>>2]=(c[263199]|0)+j;c[1052804+(g+k<<2)>>2]=(c[263199]|0)+j;c[1052804+(f+k<<2)>>2]=(c[263199]|0)+j;c[1052804+((h|7)+d<<2)>>2]=(c[263199]|0)+j}j=h+16|0;if((i|0)<(j|0)){k=(h<<11)-32768|0;c[1052804+(i+d<<2)>>2]=(c[263199]|0)+k;i=h|9;c[1052804+(i+d<<2)>>2]=(c[263199]|0)+k;c[1052804+(b+i<<2)>>2]=(c[263199]|0)+k;i=h|11;c[1052804+(i+d<<2)>>2]=(c[263199]|0)+k;c[1052804+(b+i<<2)>>2]=(c[263199]|0)+k;c[1052804+(g+i<<2)>>2]=(c[263199]|0)+k;c[1052804+(f+i<<2)>>2]=(c[263199]|0)+k;c[1052804+((h|15)+d<<2)>>2]=(c[263199]|0)+k;l=h}else{l=h}do{k=l+d|0;a[1085572+k|0]=1;a[1089668+k|0]=0;l=l+1|0;}while((l|0)<(j|0));if((j|0)<256){h=j}else{break}}return}function jQ(f,g){f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,S=0,V=0,W=0,X=0,Z=0,_=0,$=0,aa=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0.0,aq=0.0,ar=0.0,as=0.0,at=0.0,au=0.0,av=0.0,aw=0.0,ax=0.0,ay=0.0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0;a[(c[263197]|0)+((g&65535)-24576)|0]=f;if((g<<16>>16|0)==32583){h=c[263197]|0;X9(h+(d[h+8006|0]<<8&7936|d[h+8005|0])|0,(c[263192]|0)+(d[h+8001|0]<<8&32512|d[h+8e3|0]|d[h+8002|0]<<15)|0,d[h+8004|0]<<8|d[h+8003|0]|0);return}else if((g<<16>>16|0)==32591){g=c[263197]|0;h=a[g+8013|0]|0;if(h<<24>>24==14&(f&255)<64&(f&3)==0){a[g+8064|0]=(f&255)>>>2;return}switch(f&255|0){case 0:{switch(h&255|0){case 0:{h=a[g+1574|0]|0;f=(h&255)<<2;i=g+f|0;if(f>>>0<509){f=g+509|0;do{a[f]=-32;f=f-4|0;}while(f>>>0>i>>>0);f=c[263197]|0;j=f;k=a[f+1574|0]|0}else{j=g;k=h}h=d[j+1570|0]<<8|d[j+1569|0];f=d[j+1572|0]<<8|d[j+1571|0];l=a[j+1568|0]|0;if(l<<24>>24==0|k<<24>>24==-128){return}m=-128-k&255;n=k<<1&6;o=j+544|0;p=j+((k&255)>>>2|512)|0;k=i;i=l&255;L12187:while(1){l=(d[o+1|0]<<8|d[o])-h&65535;j=(d[o+3|0]<<8|d[o+2|0])-f&65535;q=a[o+5|0]|0;r=a[o+6|0]|a[o+4|0];s=c[263192]|0;t=d[o+8|0]<<8&32512|d[o+7|0]|d[o+9|0]<<15;u=a[s+t|0]|0;L12189:do{if(u<<24>>24==0){a[k]=l&255;a[k+1|0]=j&255;a[k+2|0]=q;a[k+3|0]=r;v=n&255;w=3<<v;a[p]=(d[p]&(w^255)|((l&256)==0?2<<v:w))&255;w=n+2&6;x=k+4|0;y=w<<24>>24==0?p+1|0:p;z=w;A=m-1&255}else{w=u&255;v=s+(t+1)|0;if(m<<24>>24==0){B=8945;break L12187}C=r&255;D=(C&128|0)==0;if((C&64|0)==0){E=v;G=m;H=n;I=p;J=k;K=w}else{C=v;v=m;L=n;M=p;N=k;O=w;while(1){w=(a[C]&32)!=0?-16:-8;P=(w-(a[C+1|0]|0)&65535)+l&65535;do{if((P+16&65535)<289){Q=a[C+2|0]|0;S=(D?Q:w-Q&65535)+j&65535;if((S+16&65535)>=241){V=N;W=M;X=L;Z=v;break}a[N]=P&255;a[N+1|0]=S&255;a[N+2|0]=(a[C+3|0]|0)+q&255;a[N+3|0]=a[C]&-64^r;S=L&255;Q=d[M]&(3<<S^255);if((P&256)==0){_=Q&255}else{_=(Q|1<<S)&255}a[M]=_;if((a[C]&32)!=0){a[M]=(_&255|2<<S)&255}S=L+2&6;V=N+4|0;W=S<<24>>24==0?M+1|0:M;X=S;Z=v-1&255}else{V=N;W=M;X=L;Z=v}}while(0);P=O-1|0;if((P|0)<1|Z<<24>>24==0){x=V;y=W;z=X;A=Z;break L12189}else{C=C+4|0;v=Z;L=X;M=W;N=V;O=P}}}while(1){O=(a[E+1|0]|0)+l&65535;do{if((O+16&65535)<289){N=a[E+2|0]|0;if(D){$=N}else{$=((a[E]&32)!=0?-16:-8)-N&65535}N=$+j&65535;if((N+16&65535)>=241){aa=J;ac=I;ad=H;ae=G;break}a[J]=O&255;a[J+1|0]=N&255;a[J+2|0]=(a[E+3|0]|0)+q&255;a[J+3|0]=a[E]&-64^r;N=H&255;M=d[I]&(3<<N^255);if((O&256)==0){af=M&255}else{af=(M|1<<N)&255}a[I]=af;if((a[E]&32)!=0){a[I]=(af&255|2<<N)&255}N=H+2&6;aa=J+4|0;ac=N<<24>>24==0?I+1|0:I;ad=N;ae=G-1&255}else{aa=J;ac=I;ad=H;ae=G}}while(0);O=K-1|0;if((O|0)<1|ae<<24>>24==0){x=aa;y=ac;z=ad;A=ae;break}else{E=E+4|0;G=ae;H=ad;I=ac;J=aa;K=O}}}}while(0);r=i-1|0;if(!((r|0)>0&A<<24>>24!=0)){B=8954;break}m=A;n=z;o=o+16|0;p=y;k=x;i=r}if((B|0)==8945){return}else if((B|0)==8954){return}break};case 12:{i=0;x=g;k=d[g+8067|0]|0;y=16191;while(1){p=y;o=-16192;z=k;while(1){n=o&65535;A=0;m=-16-(a[(c[263197]|0)+(z+2816)|0]|0)&65535;while(1){K=e[169384+(A<<1)>>1]|0;aa=x+K|0;J=x+(K+1)|0;K=(d[J]<<8|d[aa])&p;ac=m<<16>>16;I=K&255;ad=(K&65535)>>>8&255;do{if(m<<16>>16>-1){if(m<<16>>16<8){H=c[263197]|0;ae=ac<<1;G=(d[H+(ae+2561)|0]<<8|d[H+(ae+2560)|0])&n|K&65535;ag=(G&65535)>>>8&255;ah=G&255;break}else{ag=((K|o)&65535)>>>8&255;ah=I;break}}else{ag=ad;ah=I}}while(0);a[aa]=ah;a[J]=ag;I=A+1|0;if((I|0)<40){A=I;m=m+1&65535}else{break}}m=z+1&127;A=(o&65535)>>>2|o<<6;n=(p&65535)>>>2|p<<6;if(A<<16>>16==-16192){ai=n;aj=-16192;ak=m;break}else{p=n;o=A;z=m}}do{z=aj&65535;o=0;p=-16-(a[(c[263197]|0)+(ak|2816)|0]|0)&65535;while(1){m=e[169384+(o<<1)>>1]|0;A=x+(m+16)|0;n=x+(m+17)|0;m=(d[n]<<8|d[A])&ai;I=p<<16>>16;ad=m&255;K=(m&65535)>>>8&255;do{if(p<<16>>16>-1){if(p<<16>>16<8){ac=c[263197]|0;G=I<<1;ae=(d[ac+(G+2577)|0]<<8|d[ac+(G+2576)|0])&z|m&65535;al=(ae&65535)>>>8&255;am=ae&255;break}else{al=((m|aj)&65535)>>>8&255;am=ad;break}}else{al=K;am=ad}}while(0);a[A]=am;a[n]=al;ad=o+1|0;if((ad|0)<40){o=ad;p=p+1&65535}else{break}}ak=ak+1&127;aj=(aj&65535)>>>2|aj<<6;ai=(ai&65535)>>>2|ai<<6;}while(aj<<16>>16!=-16192);p=i+1|0;if((p|0)<16){i=p;x=x+32|0;k=ak;y=ai}else{break}}return};case 8:{jR();return};case 11:{ai=a[g+8073|0]|0;y=a[g+8076|0]|0;ak=a[g+8067|0]|0;k=a[g+8068|0]|0;x=(d[g+8071|0]<<8|d[g+8070|0])<<16>>16;i=(d[g+8080|0]<<8|d[g+8079|0])<<16>>16;aj=ab(256-x|0,(d[g+8065|0]<<8|d[g+8064|0])<<16>>16)|0;al=ai&255;am=y&255;X2(g|0,0,(ab(am,al)|0)>>>1|0);if(y<<24>>24==0){return}y=ai<<24>>24==0;ai=al<<2;ag=ab(256-i|0,((k&255)<<8|ak&255)<<16>>16)|0;ak=0;k=g+1536|0;while(1){if(y){an=k}else{ah=ag>>>8;p=ab(ah,al)|0;o=(ah<<1&14)+(ab(ai,ag>>>11)|0)|0;z=ah>>>0>=am>>>0;ah=aj;ad=0;K=k;while(1){m=ah>>>8;do{if(!(m>>>0>=al>>>0|z)){if((m+p|0)>>>0>=8192){break}I=a[K]|0;J=o+(ah>>>11<<5)|0;aa=128>>>((m&7)>>>0);ae=((ad&1|0)!=0?(I&255)>>>4:I)&255;if((ae&1|0)!=0){I=(c[263197]|0)+J|0;a[I]=(d[I]|aa)&255}if((ae&2|0)!=0){I=(c[263197]|0)+(J|1)|0;a[I]=(d[I]|aa)&255}if((ae&4|0)!=0){I=(c[263197]|0)+(J+16)|0;a[I]=(d[I]|aa)&255}if((ae&8|0)==0){break}ae=(c[263197]|0)+(J+17)|0;a[ae]=(d[ae]|aa)&255}}while(0);m=(ad&1|0)==0?K:K+1|0;aa=ad+1|0;if(aa>>>0<al>>>0){ah=ah+x|0;ad=aa;K=m}else{an=m;break}}}K=ak+1|0;if(K>>>0<am>>>0){ag=ag+i|0;ak=K;k=an}else{break}}return};case 3:{jS(0);return};case 5:{an=d[g+8067|0]|0;b[696828]=an;k=d[g+8070|0]|0;b[696820]=k;ak=d[g+8073|0]|0;b[696836]=ak;i=d[g+8076|0]|0;b[696832]=i;ag=d[g+8065|0]<<8|d[g+8064|0];if((ag|0)==0){ao=g}else{am=g;x=ag;while(1){ag=am+1|0;al=am+2|0;aj=am+5|0;ai=am+6|0;ap=+((d[al]<<8|d[ag])<<16>>16|0);aq=+((d[ai]<<8|d[aj])<<16>>16|0);ar=+((d[am+10|0]<<8|d[am+9|0])<<16>>16|0)+-149.0;as=+(an<<16>>16|0)*-3.14159265*2.0*.0078125;at=+T(+as);au=+U(+as);as=at*aq-au*ar;av=aq*au+at*ar;ar=+(k<<16>>16|0)*-3.14159265*2.0*.0078125;at=+T(+ar);au=+U(+ar);ar=ap*at+au*av;aq=+(ak<<16>>16|0)*-3.14159265*2.0*.0078125;aw=+T(+aq);ax=+U(+aq);aq=+(i<<16>>16|0);ay=(ap*(-0.0-au)+at*av+149.0)*144.0;az=~~(aq*(aw*ar-ax*as)/ay*149.0);aA=~~(aq*(aw*as+ax*ar)/ay*149.0);a[ag]=az&255^-128;a[al]=((az&65535)+128|0)>>>8&255;a[aj]=(aA&255)+80&255;a[ai]=((aA&65535)+80|0)>>>8&255;ai=x-1|0;if((ai|0)<=0){break}am=am+16|0;x=ai}b[696824]=az;b[696816]=aA;ao=c[263197]|0}a[ao+1536|0]=23;a[(c[263197]|0)+1537|0]=0;a[(c[263197]|0)+1538|0]=96;a[(c[263197]|0)+1539|0]=0;a[(c[263197]|0)+1541|0]=64;a[(c[263197]|0)+1542|0]=0;a[(c[263197]|0)+1544|0]=23;a[(c[263197]|0)+1545|0]=0;a[(c[263197]|0)+1546|0]=96;a[(c[263197]|0)+1547|0]=0;a[(c[263197]|0)+1549|0]=64;a[(c[263197]|0)+1550|0]=0;ao=c[263197]|0;aA=d[ao+2817|0]<<8|d[ao+2816|0];if((aA|0)==0){return}az=ao+2818|0;x=ao;am=aA;aA=ao;while(1){ao=d[az]<<4;i=ao|1;ak=ao|5;ao=d[aA+(ak+1)|0]<<8|d[aA+ak|0];ak=d[az+1|0]<<4;k=ak|1;aB=d[aA+(k+1)|0]<<8|d[aA+k|0];k=ak|5;aC=d[aA+(k+1)|0]<<8|d[aA+k|0];k=aB-(d[aA+(i+1)|0]<<8|d[aA+i|0])&65535;i=aC-ao&65535;ak=k<<16>>16;an=k<<16>>16>-1;ai=an?ak:-ak|0;ak=i<<16>>16;aj=i<<16>>16>-1;al=aj?ak:-ak|0;do{if((ai|0)>(al|0)){ak=(an?k:-k&65535)+1&65535;b[696836]=ak;aD=ak;aE=k<<16>>16<0?-256:256;aF=~~(+(i<<16>>16|0)*256.0/+(ai|0));B=8868}else{if(aC<<16>>16==ao<<16>>16){b[696836]=0;a[x+1536|0]=1;aG=0;aH=i;aI=k;break}else{ak=(aj?i:-i&65535)+1&65535;b[696836]=ak;aD=ak;aE=~~(+(k<<16>>16|0)*256.0/+(al|0));aF=i<<16>>16<0?-256:256;B=8868;break}}}while(0);do{if((B|0)==8868){B=0;i=aD<<16>>16==0;a[x+1536|0]=i?1:aD&255;if(i){aG=0;aH=aF;aI=aE;break}aG=(aD&65535)>>>8&255;aH=aF;aI=aE}}while(0);a[x+1537|0]=aG;a[x+1538|0]=aI&255;a[x+1539|0]=(aI&65535)>>>8&255;a[x+1541|0]=aH&255;a[x+1542|0]=(aH&65535)>>>8&255;i=am-1|0;if((i|0)<=0){break}az=az+2|0;x=x+8|0;am=i;aA=c[263197]|0}b[696824]=aI;b[696816]=aH;b[696828]=aB;b[696820]=aC;return};case 7:{jS(64);return};default:{return}}break};case 84:{aC=(d[g+8065|0]<<8|d[g+8064|0]|d[g+8066|0]<<16)<<8|0>>>24;aB=aC>>8|((aC|0)<0?-1:0)<<24;aH=((aC|0)<0?-1:0)>>8|((aC|0)<0?-1:0)<<24;aC=Yo(aB,aH,aB,aH)|0;aH=F;a[g+8067|0]=aC&255;a[(c[263197]|0)+8068|0]=(aC>>>8|aH<<24)&255;a[(c[263197]|0)+8069|0]=(aC>>>16|aH<<16)&255;a[(c[263197]|0)+8070|0]=(aC>>>24|aH<<8)&255;a[(c[263197]|0)+8071|0]=aH&255;a[(c[263197]|0)+8072|0]=(aH>>>8|0<<24)&255;return};case 137:{a[g+8064|0]=54;a[(c[263197]|0)+8065|0]=67;a[(c[263197]|0)+8066|0]=5;return};case 13:{aH=d[g+8071|0]<<8|d[g+8070|0];ay=+((d[g+8068|0]<<8|d[g+8067|0])<<16>>16|0);ar=+((d[g+8065|0]<<8|d[g+8064|0])<<16>>16|0);ax=+(aH<<16>>16|0)/+R(+(ar*ar+ay*ay));aH=~~(ay*ax*.99);b[696840]=aH;aC=~~(ar*ax*.98);b[696844]=aC;a[g+8073|0]=aC&255;a[(c[263197]|0)+8074|0]=(aC&65535)>>>8&255;a[(c[263197]|0)+8076|0]=aH&255;a[(c[263197]|0)+8077|0]=(aH&65535)>>>8&255;return};case 34:{aH=d[g+8077|0]<<8&256|d[g+8076|0];aC=d[g+8080|0]<<8&256|d[g+8079|0];aB=aH&65535;if((aH<<16>>16|0)==384|(aH<<16>>16|0)==128){aJ=-2147483648}else{aJ=(e[167336+(aB<<1)>>1]<<16|0)/(b[168360+(aB<<1)>>1]|0)|0}aB=aC&65535;if((aC<<16>>16|0)==384|(aC<<16>>16|0)==128){aK=-2147483648}else{aK=(e[167336+(aB<<1)>>1]<<16|0)/(b[168360+(aB<<1)>>1]|0)|0}aB=0;aC=(d[g+8068|0]<<8|d[g+8067|0])-(d[g+8074|0]<<8|d[g+8073|0])&65535;while(1){aH=aC<<16>>16;do{if(aC<<16>>16>-1){aI=(ab(aH,aJ)|0)>>>16;aA=c[263197]|0;am=d[aA+8065|0]<<8|d[aA+8064|0];x=d[aA+8071|0]<<8|d[aA+8070|0];az=x+(aI-am)|0;aI=az&65535;aG=((ab(aH,aK)|0)>>>16)-am+x|0;x=aG+(d[aA+8084|0]<<8|d[aA+8083|0])|0;aG=x&65535;am=x&az&65535;x=am<<16>>16<0?0:aG;if(aI<<16>>16<0){aL=x<<16>>16>255;aM=x&255;aN=(am&65535)>>>15&255}else{am=aG<<16>>16<0?0:aG;aG=aI<<16>>16>255;aI=am<<16>>16>255;if(aG&aI){aO=-2;aP=-1;aQ=aA;break}x=am&255;if(aG){aO=x;aP=-1;aQ=aA;break}else{aL=aI;aM=x;aN=az&255}}aO=aL?-1:aM;aP=aN;aQ=aA}else{aO=0;aP=1;aQ=c[263197]|0}}while(0);a[aQ+(aB+2048)|0]=aP;a[(c[263197]|0)+(aB+2304)|0]=aO;aH=aB+1|0;if((aH|0)<225){aB=aH;aC=aC+1&65535}else{break}}return};case 16:{aC=d[g+8068|0]<<8;aB=aC|d[g+8067|0];aO=(aC&32768|0)==0?aB&32767:aB|-32768;aB=ab(aO,b[168360+((d[g+8065|0]<<8&256|d[g+8064|0])<<1)>>1]|0)|0;a[g+8070|0]=aB>>>15&255;a[(c[263197]|0)+8071|0]=aB>>>23&255;a[(c[263197]|0)+8072|0]=aB>>31&255;aB=c[263197]|0;aC=ab(b[167336+((d[aB+8065|0]<<8&256|d[aB+8064|0])<<1)>>1]|0,aO)|0;aO=(aC>>15)-(aC>>21)|0;a[aB+8073|0]=aO&255;a[(c[263197]|0)+8074|0]=aO>>>8&255;a[(c[263197]|0)+8075|0]=aO>>>16&255;return};case 19:{aO=ab(b[168360+((d[g+8065|0]<<8&256|d[g+8064|0])<<1)>>1]|0,d[g+8068|0]<<8|d[g+8067|0])|0;a[g+8070|0]=aO>>>7&255;a[(c[263197]|0)+8071|0]=aO>>>15&255;a[(c[263197]|0)+8072|0]=aO>>>23&255;aO=c[263197]|0;aB=ab(b[167336+((d[aO+8065|0]<<8&256|d[aO+8064|0])<<1)>>1]|0,d[aO+8068|0]<<8|d[aO+8067|0])|0;a[aO+8073|0]=aB>>>7&255;a[(c[263197]|0)+8074|0]=aB>>>15&255;a[(c[263197]|0)+8075|0]=aB>>>23&255;return};case 21:{aB=g+8064|0;aO=d[g+8065|0]<<8|d[aB];b[696844]=aO;aC=d[g+8068|0]<<8|d[g+8067|0];b[696840]=aC;ax=+(aO<<16>>16|0);ar=+(aC<<16>>16|0);aC=~~+R(+(ax*ax+ar*ar));b[696848]=aC;a[aB]=aC&255;a[(c[263197]|0)+8065|0]=(aC&65535)>>>8&255;return};case 31:{aC=d[g+8065|0]<<8|d[g+8064|0];b[696844]=aC;aB=d[g+8068|0]<<8|d[g+8067|0];b[696840]=aB;do{if(aC<<16>>16==0){if(aB<<16>>16>0){b[696852]=128;aR=-128;aS=0;break}else{b[696852]=384;aR=-128;aS=1;break}}else{aO=~~(+Y(+(+(aB<<16>>16|0)/+(aC<<16>>16|0)))/6.2831853*512.0);aP=aC<<16>>16<0?aO+256&65535:aO;aO=aP&511;b[696852]=aO;aR=aP&255;aS=(aO&65535)>>>8&255}}while(0);a[g+8070|0]=aR;a[(c[263197]|0)+8071|0]=aS;return};case 92:{a[g]=0;aS=1;do{a[(c[263197]|0)+aS|0]=a[167288+aS|0]|0;aS=aS+1|0;}while((aS|0)<48);return};case 5:{aS=d[g+8068|0]<<8|d[g+8067|0];if((aS|0)==0){aT=0;aU=0}else{aR=ab(d[g+8066|0]<<8|d[g+8065|0],65536/(aS>>>0)|0)|0;aT=aR>>>16&255;aU=aR>>>8&255}a[g+8064|0]=aU;a[(c[263197]|0)+8065|0]=aT;return};case 1:{X2(g+768|0,0,2304);jR();return};case 37:{aT=g+8064|0;aU=ab(d[g+8068|0]<<8|d[g+8067|0]|d[g+8069|0]<<16,d[g+8065|0]<<8|d[aT]|d[g+8066|0]<<16)|0;a[aT]=aU&255;a[(c[263197]|0)+8065|0]=aU>>>8&255;a[(c[263197]|0)+8066|0]=aU>>>16&255;return};case 45:{aU=d[g+8066|0]<<8|d[g+8065|0];aT=d[g+8069|0]<<8|d[g+8068|0];aR=d[g+8072|0]<<8|d[g+8071|0];aS=d[g+8073|0]|0;b[696828]=aS;aC=d[g+8074|0]|0;b[696820]=aC;aB=d[g+8075|0]|0;b[696836]=aB;aO=d[g+8081|0]<<8|d[g+8080|0];b[696832]=aO;ar=+(aT<<16>>16|0);ax=+(aR<<16>>16|0);ay=+(aS<<16>>16|0)*-3.14159265*2.0*.0078125;as=+T(+ay);aw=+U(+ay);ay=ar*as-ax*aw;aq=+(aC<<16>>16|0)*-3.14159265*2.0*.0078125;av=+(aU<<16>>16|0)*+T(+aq);at=av+(ax*as+ar*aw)*+U(+aq);aq=+(aB<<16>>16|0)*-3.14159265*2.0*.0078125;aw=+T(+aq);ar=+U(+aq);aq=+(aO<<16>>16|0);aO=~~(aq*(aw*at-ay*ar)*.00390625);b[696824]=aO;aB=~~(aq*(ay*aw+at*ar)*.00390625);b[696816]=aB;a[g+8064|0]=aO&255;a[(c[263197]|0)+8065|0]=(aO&65535)>>>8&255;a[(c[263197]|0)+8067|0]=aB&255;a[(c[263197]|0)+8068|0]=(aB&65535)>>>8&255;return};case 64:{aB=0;aO=0;while(1){aU=aO+1|0;aV=(d[g+aO|0]|0)+aB&65535;if((aU|0)<2048){aB=aV;aO=aU}else{break}}a[g+8064|0]=aV&255;a[(c[263197]|0)+8065|0]=(aV&65535)>>>8&255;return};default:{return}}}else{return}}function jR(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0.0,z=0.0,A=0.0,B=0.0,C=0.0,D=0.0,E=0.0,F=0.0,G=0.0,H=0.0,I=0.0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0;e=c[263197]|0;f=a[e+661|0]|0;if(f<<24>>24==0){return}g=(c[263192]|0)+((d[e+8065|0]|0)<<8&32512|(d[e+8064|0]|0)|(d[e+8066|0]|0)<<15)|0;e=f&255;while(1){f=a[g]|0;h=a[g+1|0]|0;if(f<<24>>24==-1&h<<24>>24==-1){i=g;while(1){j=a[i-3|0]|0;if(j<<24>>24!=-1){k=8978;break}l=a[i-2|0]|0;if(l<<24>>24==-1){i=i-5|0}else{m=l;n=32512;break}}if((k|0)==8978){k=0;m=a[i-2|0]|0;n=(j&255)<<8&32512}l=c[263197]|0;o=a[l+8066|0]|0;p=c[263192]|0;q=p+(m&255|n|(o&255)<<15)|0;r=l;s=o;t=p}else{p=c[263197]|0;o=a[p+8066|0]|0;l=c[263192]|0;q=l+((f&255)<<8&32512|h&255|(o&255)<<15)|0;r=p;s=o;t=l}l=d[g+3|0]|0|(s&255)<<15|(d[g+2|0]|0)<<8&32512;o=(d[t+l|0]|0)<<8|(d[t+(l+1)|0]|0);p=(d[t+(l+2)|0]|0)<<8|(d[t+(l+3)|0]|0);u=(d[t+(l+4)|0]|0)<<8|(d[t+(l+5)|0]|0);l=a[g+4|0]|0;v=d[r+8080|0]|0;w=d[r+8071|0]|0;x=d[r+8072|0]|0;y=+(((d[q]|0)<<8|(d[q+1|0]|0))<<16>>16|0);z=+(((d[q+2|0]|0)<<8|(d[q+3|0]|0))<<16>>16|0);A=+(((d[q+4|0]|0)<<8|(d[q+5|0]|0))<<16>>16|0);B=+(d[r+8070|0]|0|0)*-3.14159265*2.0*.0078125;C=+T(+B);D=+U(+B);B=z*C-A*D;E=+(w<<16>>16|0)*-3.14159265*2.0*.0078125;F=+T(+E);G=+U(+E);E=y*F+(A*C+z*D)*G;z=+(x<<16>>16|0)*-3.14159265*2.0*.0078125;A=+T(+z);y=+U(+z);z=+(v<<16>>16|0);x=(~~(z*(A*E-B*y)*.00390625)<<16>>16<<8)+12288|0;w=(~~(z*(B*A+E*y)*.00390625)<<16>>16<<8)+12288|0;E=+(p<<16>>16|0);B=+(u<<16>>16|0);H=E*C-B*D;I=+(o<<16>>16|0)*F+(B*C+E*D)*G;o=w>>>8&65535;J=((~~(z*(A*I-H*y)*.00390625)<<16>>16<<8)+12288|0)>>>8&65535;K=((~~(z*(H*A+I*y)*.00390625)<<16>>16<<8)+12288|0)>>>8&65535;u=J-(x>>>8&65535)&65535;p=K-o&65535;L=u<<16>>16;M=u<<16>>16>-1;N=M?L:-L|0;L=p<<16>>16;O=p<<16>>16>-1;P=O?L:-L|0;do{if((N|0)>(P|0)){Q=u<<16>>16<0?-256:256;R=~~(+(p<<16>>16|0)*256.0/+(N|0));S=(M?u:-u&65535)+1&65535;k=8986}else{if(K<<16>>16==o<<16>>16){V=u;W=p;X=1;Y=0;k=8987;break}Q=~~(+(u<<16>>16|0)*256.0/+(P|0));R=p<<16>>16<0?-256:256;S=(O?p:-p&65535)+1&65535;k=8986}}while(0);if((k|0)==8986){k=0;p=S<<16>>16==0?1:S<<16>>16;if((p|0)>0){V=Q;W=R;X=p;Y=S;k=8987}else{Z=Q;_=R;$=S}}if((k|0)==8987){k=0;p=V<<16>>16;O=W<<16>>16;P=l&255;u=(P&2|0)==0;if((P&1|0)==0){P=X;o=w;M=x;while(1){do{if((M|0)>255&(o|0)>255&(M|0)<24576&(o|0)<24576){N=128>>>((M>>>8&7)>>>0);h=(N|-256)^255;f=((o>>11)*192|0)+(M>>11<<4)&65535|o>>>8<<1&14;i=(c[263197]|0)+(f+768)|0;a[i]=(d[i]|0)&h&255;i=f+769|0;f=(c[263197]|0)+i|0;a[f]=(d[f]|0)&h&255;if(u){break}h=(c[263197]|0)+i|0;a[h]=(d[h]|0|N)&255}}while(0);N=P-1|0;if((N|0)>0){P=N;o=o+O|0;M=M+p|0}else{Z=V;_=W;$=Y;break}}}else{M=X;o=w;P=x;while(1){do{if((P|0)>255&(o|0)>255&(P|0)<24576&(o|0)<24576){l=128>>>((P>>>8&7)>>>0);N=(l|-256)^255;h=((o>>11)*192|0)+(P>>11<<4)&65535|o>>>8<<1&14;i=h+768|0;f=(c[263197]|0)+i|0;a[f]=(d[f]|0)&N&255;f=h+769|0;h=(c[263197]|0)+f|0;a[h]=(d[h]|0)&N&255;N=(c[263197]|0)+i|0;a[N]=(d[N]|0|l)&255;if(u){break}N=(c[263197]|0)+f|0;a[N]=(d[N]|0|l)&255}}while(0);l=M-1|0;if((l|0)>0){M=l;o=o+O|0;P=P+p|0}else{Z=V;_=W;$=Y;break}}}}p=e-1|0;if((p|0)>0){g=g+5|0;e=p}else{break}}b[696824]=Z;b[696816]=_;b[696832]=v;b[696828]=J;b[696820]=K;b[696836]=$;return}function jS(e){e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;f=c[263197]|0;g=d[f+8080|0]<<8;h=(g&32768|0)==0?g|d[f+8079|0]:32767;g=d[f+8083|0]<<8;i=(g&32768|0)==0?g|d[f+8082|0]:32767;g=d[f+8065|0]<<8|d[f+8064|0];if((g|0)==384){j=0;k=0;l=-h&65535;m=i&65535}else if((g|0)==256){j=-h&65535;k=-i&65535;l=0;m=0}else if((g|0)==0){j=h&65535;k=i&65535;l=0;m=0}else if((g|0)==128){j=0;k=0;l=h&65535;m=-i&65535}else{n=g&511;g=b[168360+(n<<1)>>1]|0;o=(ab(g,h)|0)>>>15&65535;p=b[167336+(n<<1)>>1]|0;n=-((ab(p,i)|0)>>>15)&65535;q=(ab(p,h)|0)>>>15&65535;j=o;k=(ab(g,i)|0)>>>15&65535;l=q;m=n}n=a[f+8073|0]&-8;q=a[f+8076|0]&-8;i=n&255;g=q&255;X2(f|0,0,(ab(i+((e|0)/4|0)|0,g)|0)/2|0|0);f=c[263197]|0;o=(d[f+8068|0]<<8|d[f+8067|0])<<16>>16;h=(d[f+8071|0]<<8|d[f+8070|0])<<16>>16;f=j<<16>>16;j=m<<16>>16;m=l<<16>>16;l=k<<16>>16;if(q<<24>>24==0){return}q=ab(h,m)|0;k=ab(o,f)|0;p=(h<<12)-q-(ab(h,l)|0)|0;h=n<<24>>24==0;n=e+2|0;q=(i<<2)+e|0;e=-128;r=(o<<12)-k-(ab(o,j)|0)|0;o=p;p=0;k=0;while(1){if(h){s=e;t=k}else{u=e;v=r;w=o;x=0;y=k;while(1){z=v>>>12;do{if(z>>>0<i>>>0){A=w>>>12;if(A>>>0>=g>>>0){B=0;break}C=(ab(A,i)|0)+z|0;A=a[(c[263197]|0)+((C>>>1)+1536)|0]|0;if((C&1|0)==0){B=A;break}B=(A&255)>>>4}else{B=0}}while(0);z=B&255;if((z&1|0)!=0){A=(c[263197]|0)+y|0;a[A]=a[A]|u}if((z&2|0)!=0){A=(c[263197]|0)+(y+1)|0;a[A]=a[A]|u}if((z&4|0)!=0){A=(c[263197]|0)+(y+16)|0;a[A]=a[A]|u}if((z&8|0)!=0){z=(c[263197]|0)+(y+17)|0;a[z]=a[z]|u}z=(u&255)>>>1;A=z<<24>>24==0;C=A?-128:z;z=A?y+32|0:y;A=x+1|0;if((A|0)<(i|0)){u=C;v=v+f|0;w=w+m|0;x=A;y=z}else{s=C;t=z;break}}}y=n+t|0;x=p+1|0;if((x|0)<(g|0)){e=s;r=r+j|0;o=o+l|0;p=x;k=(y&16|0)==0?y-q|0:y&-17}else{break}}return}function jT(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=c[348392]|0;e=c[1052804+((b>>>12&4095)<<2)>>2]|0;do{if((b&4227072|0)==0){if((b+24576&16384|0)!=0){f=8;break}f=(b+16384&32256|0)==0?12:6}else{f=(b&8388608|0)==0?8:c[348401]|0}}while(0);L12452:do{if(e>>>0<19){switch(e|0){case 2:case 6:{g=a[(c[263193]|0)+(c[274485]&(b>>>1&8355840|b&32767))|0]|0;if((a[1393610]|0)!=0){h=g;break L12452}i=f+d|0;c[348392]=i;if((i|0)<(c[348406]|0)){h=g;break L12452}while(1){j1();if((c[348392]|0)<(c[348406]|0)){h=g;break}}break};case 4:case 12:{g=a[(c[263193]|0)+(c[274485]&(b&32767)-24576+(b>>>3&122880))|0]|0;if((a[1393610]|0)!=0){h=g;break L12452}i=f+d|0;c[348392]=i;if((i|0)<(c[348406]|0)){h=g;break L12452}while(1){j1();if((c[348392]|0)<(c[348406]|0)){h=g;break}}break};case 1:{do{if((a[1393610]|0)!=0){if((b&65280|0)!=8448){break}h=a[1044496]|0;break L12452}}while(0);g=HG(b&65535)|0;if((a[1393610]|0)!=0){h=g;break L12452}i=(c[348392]|0)+f|0;c[348392]=i;if((i|0)<(c[348406]|0)){h=g;break L12452}while(1){j1();if((c[348392]|0)<(c[348406]|0)){h=g;break}}break};case 13:{if((b&65535)<<16>>16==32606){j=0}else{j=a[(c[263197]|0)+((b&65535)-24576)|0]|0}if((a[1393610]|0)!=0){h=j;break L12452}g=d+f|0;c[348392]=g;if((g|0)<(c[348406]|0)){h=j;break L12452}while(1){j1();if((c[348392]|0)<(c[348406]|0)){h=j;break}}break};case 14:{g=Ht(b&65535)|0;if((a[1393610]|0)!=0){h=g;break L12452}i=d+f|0;c[348392]=i;if((i|0)<(c[348406]|0)){h=g;break L12452}while(1){j1();if((c[348392]|0)<(c[348406]|0)){h=g;break}}break};case 17:{g=b&65535;i=b>>>16&255;do{if((i|0)!=0&i>>>0<15){if((b&65535|0)!=20480){k=9091;break}l=a[1394341+i|0]|0}else{k=9091}}while(0);do{if((k|0)==9091){if((i|0)!=192){l=0;break}m=b&65535;do{if((a[1394343]|0)==0){if(g<<16>>16>-1){n=(c[274488]|0)+m|0;break}else{n=(c[274488]|0)+(m-32768)|0;break}}else{n=(c[274488]|0)+m|0}}while(0);o=a[n]|0;if((m|0)==2){l=(a[1394259]|0)==0?o:-128;break}else if((m|0)==21845){l=(a[1394259]|0)==0?o:-128;break}else if((m|0)==65280|(m|0)==65282|(m|0)==65284|(m|0)==65286|(m|0)==65288|(m|0)==65290|(m|0)==65292|(m|0)==65294|(m|0)==65296|(m|0)==65298){if((a[1394261]|0)==0){l=o;break}l=a[15064+(m-65280)|0]|0;break}else{l=o;break}}}while(0);if((a[1393610]|0)!=0){h=l;break L12452}g=d+f|0;c[348392]=g;if((g|0)<(c[348406]|0)){h=l;break L12452}while(1){j1();if((c[348392]|0)<(c[348406]|0)){h=l;break}}break};case 15:{g=fe[c[40480]&127](b)|0;if((a[1393610]|0)!=0){h=g;break L12452}i=(c[348392]|0)+f|0;c[348392]=i;if((i|0)<(c[348406]|0)){h=g;break L12452}while(1){j1();if((c[348392]|0)<(c[348406]|0)){h=g;break}}break};case 0:{g=HJ(b&65535)|0;if((a[1393610]|0)!=0){h=g;break L12452}i=(c[348392]|0)+f|0;c[348392]=i;if((i|0)<(c[348406]|0)){h=g;break L12452}while(1){j1();if((c[348392]|0)<(c[348406]|0)){h=g;break}}break};case 11:{g=Ua(18432)|0;if((a[1393610]|0)!=0){h=g;break L12452}i=(c[348392]|0)+f|0;c[348392]=i;if((i|0)<(c[348406]|0)){h=g;break L12452}while(1){j1();if((c[348392]|0)<(c[348406]|0)){h=g;break}}break};case 7:{g=a[(c[263196]|0)+((b&32767)-24576)|0]|0;if((a[1393610]|0)!=0){h=g;break L12452}i=f+d|0;c[348392]=i;if((i|0)<(c[348406]|0)){h=g;break L12452}while(1){j1();if((c[348392]|0)<(c[348406]|0)){h=g;break}}break};case 3:{g=a[(c[261140]|0)+(c[261136]&(b>>>1&8355840|b&32767))|0]|0;if((a[1393610]|0)!=0){h=g;break L12452}i=f+d|0;c[348392]=i;if((i|0)<(c[348406]|0)){h=g;break L12452}while(1){j1();if((c[348392]|0)<(c[348406]|0)){h=g;break}}break};case 10:{g=b&15728640;if((g|0)==15728640){p=c[198890]|0}else if((g|0)==14680064){p=c[198894]|0}else if((g|0)==13631488){p=c[198898]|0}else{p=0}g=a[(c[263192]|0)+(p+(b&1048575))|0]|0;if((a[1393610]|0)!=0){h=g;break L12452}i=d+f|0;c[348392]=i;if((i|0)<(c[348406]|0)){h=g;break L12452}while(1){j1();if((c[348392]|0)<(c[348406]|0)){h=g;break}}break};case 5:{g=fe[c[276698]&127](b&65535)|0;if((a[1393610]|0)!=0){h=g;break L12452}i=(c[348392]|0)+f|0;c[348392]=i;if((i|0)<(c[348406]|0)){h=g;break L12452}while(1){j1();if((c[348392]|0)<(c[348406]|0)){h=g;break}}break};case 16:{do{if((b&65535|0)==14340){g=c[201864]|0;if((g|0)==0){q=-127;break}i=c[201862]|0;o=a[807496+i|0]|0;r=i+1|0;c[201862]=r;if((g|0)!=(r|0)){q=o;break}c[201864]=0;q=o}else{q=0}}while(0);if((a[1393610]|0)!=0){h=q;break L12452}o=d+f|0;c[348392]=o;if((o|0)<(c[348406]|0)){h=q;break L12452}while(1){j1();if((c[348392]|0)<(c[348406]|0)){h=q;break}}break};default:{o=a[1044496]|0;if((a[1393610]|0)!=0){h=o;break L12452}r=f+d|0;c[348392]=r;if((r|0)<(c[348406]|0)){h=o;break L12452}while(1){j1();if((c[348392]|0)<(c[348406]|0)){h=o;break}}}}}else{o=a[e+(b&65535)|0]|0;if((a[1393610]|0)!=0){h=o;break}r=f+d|0;c[348392]=r;if((r|0)<(c[348406]|0)){h=o;break}while(1){j1();if((c[348392]|0)<(c[348406]|0)){h=o;break}}}}while(0);c[348392]=d;return h|0}function jU(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0;e=c[348392]|0;f=c[1069188+((d>>>12&4095)<<2)>>2]|0;do{if((d&4227072|0)==0){if((d+24576&16384|0)!=0){g=8;break}g=(d+16384&32256|0)==0?12:6}else{g=(d&8388608|0)==0?8:c[348401]|0}}while(0);L12562:do{if(f>>>0<19){switch(f|0){case 17:{jM(b,d);if((a[1393610]|0)!=0){break L12562}h=(c[348392]|0)+g|0;c[348392]=h;if((h|0)<(c[348406]|0)){break L12562}do{j1();}while((c[348392]|0)>=(c[348406]|0));break};case 0:{HH(b,d&65535);if((a[1393610]|0)!=0){break L12562}h=(c[348392]|0)+g|0;c[348392]=h;if((h|0)<(c[348406]|0)){break L12562}do{j1();}while((c[348392]|0)>=(c[348406]|0));break};case 16:{TZ(b,d);if((a[1393610]|0)!=0){break L12562}h=(c[348392]|0)+g|0;c[348392]=h;if((h|0)<(c[348406]|0)){break L12562}do{j1();}while((c[348392]|0)>=(c[348406]|0));break};case 15:{fc[c[36646]&127](d,b);if((a[1393610]|0)!=0){break L12562}h=(c[348392]|0)+g|0;c[348392]=h;if((h|0)<(c[348406]|0)){break L12562}do{j1();}while((c[348392]|0)>=(c[348406]|0));break};case 13:{jQ(b,d&65535);if((a[1393610]|0)!=0){break L12562}h=(c[348392]|0)+g|0;c[348392]=h;if((h|0)<(c[348406]|0)){break L12562}do{j1();}while((c[348392]|0)>=(c[348406]|0));break};case 1:{if((a[1393610]|0)!=0){if((d&65280|0)==8448){break L12562}}HB(b,d&65535);if((a[1393610]|0)!=0){break L12562}h=(c[348392]|0)+g|0;c[348392]=h;if((h|0)<(c[348406]|0)){break L12562}do{j1();}while((c[348392]|0)>=(c[348406]|0));break};case 4:{h=c[274485]|0;if((h|0)!=0){a[(c[263193]|0)+(h&(d&32767)-24576+(d>>>3&122880))|0]=b}if((a[1393610]|0)!=0){break L12562}h=(c[348392]|0)+g|0;c[348392]=h;if((h|0)<(c[348406]|0)){break L12562}do{j1();}while((c[348392]|0)>=(c[348406]|0));break};case 3:{h=c[261136]|0;if((h|0)!=0){a[(c[261140]|0)+(h&(d>>>1&8355840|d&32767))|0]=b}if((a[1393610]|0)!=0){break L12562}h=(c[348392]|0)+g|0;c[348392]=h;if((h|0)<(c[348406]|0)){break L12562}do{j1();}while((c[348392]|0)>=(c[348406]|0));break};case 14:{Hu(b,d&65535);if((a[1393610]|0)!=0){break L12562}h=(c[348392]|0)+g|0;c[348392]=h;if((h|0)<(c[348406]|0)){break L12562}do{j1();}while((c[348392]|0)>=(c[348406]|0));break};case 2:{h=c[274485]|0;if((h|0)!=0){a[(c[263193]|0)+(h&(d>>>1&8355840|d&32767))|0]=b}if((a[1393610]|0)!=0){break L12562}h=(c[348392]|0)+g|0;c[348392]=h;if((h|0)<(c[348406]|0)){break L12562}do{j1();}while((c[348392]|0)>=(c[348406]|0));break};case 5:{fc[c[201852]&127](b,d&65535);if((a[1393610]|0)!=0){break L12562}h=(c[348392]|0)+g|0;c[348392]=h;if((h|0)<(c[348406]|0)){break L12562}do{j1();}while((c[348392]|0)>=(c[348406]|0));break};case 6:{a[(c[263193]|0)+(d&65535)|0]=b;if((a[1393610]|0)!=0){break L12562}h=(c[348392]|0)+g|0;c[348392]=h;if((h|0)<(c[348406]|0)){break L12562}do{j1();}while((c[348392]|0)>=(c[348406]|0));break};case 7:{a[(c[263196]|0)+((d&32767)-24576)|0]=b;if((a[1393610]|0)!=0){break L12562}h=(c[348392]|0)+g|0;c[348392]=h;if((h|0)<(c[348406]|0)){break L12562}do{j1();}while((c[348392]|0)>=(c[348406]|0));break};default:{if((a[1393610]|0)!=0){break L12562}h=g+e|0;c[348392]=h;if((h|0)<(c[348406]|0)){break L12562}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}}else{a[f+(d&65535)|0]=b;if((a[1393610]|0)!=0){break}h=(c[348392]|0)+g|0;c[348392]=h;if((h|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);c[348392]=e;return}function jV(){var d=0,e=0;c[59002]=0;a[1125520]=0;a[238638]=a[238638]&-49;a[509608]=a[509608]&-9;d=238610;e=d|0;x=0;b[e>>1]=x&65535;b[e+2>>1]=x>>16;e=d+4|0;x=0;b[e>>1]=x&65535;b[e+2>>1]=x>>16;a[238618]=1;c[59655]=-1;e=a[238624]|0;if((e&1)==0){a[238625]=0}if((e&2)==0){a[238626]=5}if((e&4)==0){a[238627]=1}b[254808]=0;b[254812]=0;a[509600]=0;c[127398]=-1;a[7768]=1;a[7760]=1;a[7752]=1;e=238630;d=e|0;x=0;b[d>>1]=x&65535;b[d+2>>1]=x>>16;d=e+4|0;x=0;b[d>>1]=x&65535;b[d+2>>1]=x>>16;a[238638]=1;c[59660]=-1;d=a[238644]|0;if((d&1)==0){a[238645]=0}if((d&2)==0){a[238646]=5}if((d&4)==0){a[238647]=1}b[254809]=0;b[254813]=0;a[509601]=0;c[127396]=-1;a[7744]=1;a[7736]=1;a[7728]=1;a[509608]=0;X2(169488,0,7);c[42374]=-1;d=a[169500]|0;if((d&1)==0){a[169501]=2}if((d&2)==0){a[169502]=5}if((d&4)!=0){return}a[169503]=1;return}function jW(c,d){c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0;L12668:do{if((bJ(d|0,39904,6)|0)==0){do{if(((a[d+6|0]|0)-49&255)<=7){if((a[d+7|0]|0)!=32){break}e=d+8|0;if((bJ(e|0,35344,2)|0)==0){f=d+10|0;g=(a[f]|0)==43?d+11|0:f;h=2048}else{g=e;h=0}if((bJ(g|0,30624,4)|0)==0){e=g+4|0;i=(a[e]|0)==43?g+5|0:e;j=h|1024}else{i=g;j=h}if((bJ(i|0,26664,4)|0)==0){e=i+4|0;k=(a[e]|0)==43?i+5|0:e;l=j|512}else{k=i;l=j}if((bJ(k|0,22464,5)|0)==0){e=k+5|0;m=(a[e]|0)==43?k+6|0:e;n=l|256}else{m=k;n=l}e=a[m]|0;if(e<<24>>24==65){f=m+1|0;o=(a[f]|0)==43?m+2|0:f;p=o;q=n|128;r=a[o]|0}else{p=m;q=n;r=e}if(r<<24>>24==66){e=p+1|0;o=(a[e]|0)==43?p+2|0:e;s=o;t=q|32768;u=a[o]|0}else{s=p;t=q;u=r}if(u<<24>>24==88){o=s+1|0;e=(a[o]|0)==43?s+2|0:o;v=e;w=t|64;x=a[e]|0}else{v=s;w=t;x=u}if(x<<24>>24==89){e=v+1|0;o=(a[e]|0)==43?v+2|0:e;y=o;z=w|16384;A=a[o]|0}else{y=v;z=w;A=x}if(A<<24>>24==76){o=y+1|0;e=(a[o]|0)==43?y+2|0:o;B=e;C=z|32;D=a[e]|0}else{B=y;C=z;D=A}if(D<<24>>24==82){e=B+1|0;E=(a[e]|0)==43?B+2|0:e;F=C|16}else{E=B;F=C}if((bJ(E|0,100096,5)|0)==0){e=E+5|0;G=(a[e]|0)==43?E+6|0:e;H=F|4096}else{G=E;H=F}if((bJ(G|0,95616,6)|0)==0){I=G+6|0;J=H|8192;K=9219}else{if((H|0)!=0){I=G;J=H;K=9219}}do{if((K|0)==9219){if((a[I]|0)!=0){break}if((a[I-1|0]|0)!=43){L=1;M=J&65535;break L12668}}}while(0);e=c|0;a[e]=-1;a[e+1|0]=0;b[c+2>>1]=0;b[c+4>>1]=0;return}}while(0);e=c|0;a[e]=-1;a[e+1|0]=0;b[c+2>>1]=0;b[c+4>>1]=0;return}else{if((bJ(d|0,91752,5)|0)==0){e=a[d+5|0]|0;do{if((e-49&255)<=1){if((a[d+6|0]|0)!=32){break}o=d+7|0;f=(a[o]|0)==76;N=f?d+8|0:o;o=(a[N]|0)==82;O=(((f&1)<<1|e&1|(o&1)<<2)^1)&255;if(f|o){if((a[o?N+1|0:N]|0)==0){L=2;M=O;break L12668}}N=c|0;a[N]=-1;a[N+1|0]=0;b[c+2>>1]=O;b[c+4>>1]=0;return}}while(0);e=c|0;a[e]=-1;a[e+1|0]=0;b[c+2>>1]=0;b[c+4>>1]=0;return}if((bJ(d|0,88256,11)|0)==0){e=d+11|0;O=(bJ(e|0,85112,12)|0)==0;N=(O&1)<<4;o=N&255;do{if(O){f=d+23|0;P=a[f]|0;if((P<<24>>24|0)==0){Q=f;R=12;break}else if((P<<24>>24|0)==32){Q=d+24|0;R=12;break}P=c|0;a[P]=-1;a[P+1|0]=0;b[c+2>>1]=o;b[c+4>>1]=0;return}else{Q=e;R=0}}while(0);e=(bJ(Q|0,81664,4)|0)==0;if(e){o=Q+4|0;S=(a[o]|0)==43?Q+5|0:o;T=4}else{S=Q;T=R}o=(bJ(S|0,78072,6)|0)==0;if(o){O=S+6|0;U=(a[O]|0)==43?S+7|0:O;V=6}else{U=S;V=T}O=(bJ(U|0,75016,11)|0)==0;if(O){P=U+11|0;W=(a[P]|0)==43?U+12|0:P;X=11}else{W=U;X=V}P=(bJ(W|0,71976,5)|0)==0;f=(e&1|N|(o&1)<<1|(O&1)<<2|(P&1)<<3)&255;O=P?W+5|0:W;do{if(!((X|0)==0&(P^1))){if((a[O]|0)!=0){break}if((a[O-1|0]|0)!=43){L=3;M=f;break L12668}}}while(0);O=c|0;a[O]=-1;a[O+1|0]=0;b[c+2>>1]=f;b[c+4>>1]=0;return}if((bJ(d|0,69792,9)|0)!=0){if((bJ(d|0,66880,8)|0)!=0){L=-1;M=0;break}O=d+8|0;P=(bJ(O|0,64888,6)|0)==0;if(P){N=d+14|0;Y=(a[N]|0)==43?d+15|0:N;Z=6}else{Y=O;Z=0}O=(bJ(Y|0,63184,6)|0)==0;if(O){N=Y+6|0;_=(a[N]|0)==43?Y+7|0:N;$=6}else{_=Y;$=Z}N=(bJ(_|0,61928,10)|0)==0;if(N){o=_+10|0;aa=(a[o]|0)==43?_+11|0:o;ab=10}else{aa=_;ab=$}o=(bJ(aa|0,61064,10)|0)==0;if(o){e=aa+10|0;ac=(a[e]|0)==43?aa+11|0:e;ad=10}else{ac=aa;ad=ab}e=(bJ(ac|0,6e4,10)|0)==0;ae=(O&1)<<1|P&1|(N&1)<<2|(o&1)<<3|(e&1)<<4;o=e?ac+10|0:ac;do{if(!((ad|0)==0&(e^1))){if((a[o]|0)!=0){break}if((a[o-1|0]|0)!=43){L=8;M=ae;break L12668}}}while(0);o=c|0;a[o]=-1;a[o+1|0]=0;b[c+2>>1]=ae;b[c+4>>1]=0;return}o=a[d+9|0]|0;do{if((o-49&255)<=1){if((a[d+10|0]|0)!=32){break}e=d+11|0;f=(bJ(e|0,85112,12)|0)==0;N=((f&1)<<3|o&1)^1;P=N&255;do{if(f){O=d+23|0;af=a[O]|0;if((af<<24>>24|0)==0){ag=O;ah=12;break}else if((af<<24>>24|0)==32){ag=d+24|0;ah=12;break}af=c|0;a[af]=-1;a[af+1|0]=0;b[c+2>>1]=P;b[c+4>>1]=0;return}else{ag=e;ah=0}}while(0);e=(bJ(ag|0,68520,7)|0)==0;if(e){P=ag+7|0;ai=(a[P]|0)==43?ag+8|0:P;aj=7}else{ai=ag;aj=ah}P=(bJ(ai|0,100096,5)|0)==0;f=((e&1)<<1|N|(P&1)<<2)&255;e=P?ai+5|0:ai;do{if(!((aj|0)==0&(P^1))){if((a[e]|0)!=0){break}if((a[e-1|0]|0)!=43){L=4;M=f;break L12668}}}while(0);e=c|0;a[e]=-1;a[e+1|0]=0;b[c+2>>1]=f;b[c+4>>1]=0;return}}while(0);o=c|0;a[o]=-1;a[o+1|0]=0;b[c+2>>1]=0;b[c+4>>1]=0;return}}while(0);aj=c|0;a[aj]=L;a[aj+1|0]=0;b[c+2>>1]=M;b[c+4>>1]=0;return}function jX(d,e){d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0;f=i;g=e;e=i;i=i+6|0;i=i+7>>3<<3;c[e>>2]=c[g>>2];b[e+4>>1]=b[g+4>>1]|0;g=e|0;if((a[g]|0)!=8){i=f;return}h=b[e+2>>1]|0;e=c[59655]|0;j=(h&1)==0;k=(e|0)==(d|0);if(!((e|0)==-1|j|k)){e=c[p>>2]|0;a2(58912,61,1,e|0)|0;i=f;return}e=c[59660]|0;l=(h&2)==0;m=(e|0)==(d|0);if(!((e|0)==-1|l|m)){e=c[p>>2]|0;a2(58320,61,1,e|0)|0;i=f;return}e=c[42374]|0;n=(h&4)==0;o=(e|0)==(d|0);if(!((e|0)==-1|n|o)){e=c[p>>2]|0;a2(57640,65,1,e|0)|0;i=f;return}e=c[127398]|0;q=(h&8)==0;r=(e|0)==(d|0);if(!((e|0)==-1|q|r)){e=c[p>>2]|0;a2(57e3,65,1,e|0)|0;i=f;return}e=c[127396]|0;s=(h&16)==0;h=(e|0)==(d|0);if(!((e|0)==-1|s|h)){e=c[p>>2]|0;a2(56120,65,1,e|0)|0;i=f;return}if(k){c[59655]=-1}if(m){c[59660]=-1}if(o){c[42374]=-1}if(r){c[127398]=-1}if(h){c[127396]=-1}h=503440+(d*6|0)|0;b[h>>1]=b[g>>1]|0;b[h+2>>1]=b[g+2>>1]|0;b[h+4>>1]=b[g+4>>1]|0;if(!j){c[59655]=d}if(!l){c[59660]=d}if(!n){c[42374]=d}if(!q){c[127398]=d}if(s){i=f;return}c[127396]=d;i=f;return}function jY(f,g,h){f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;j=i;k=f;f=i;i=i+6|0;i=i+7>>3<<3;c[f>>2]=c[k>>2];b[f+4>>1]=b[k+4>>1]|0;k=d[f|0]|0;if((k|0)==8){l=b[f+2>>1]|0;if((l&1)!=0){b[119307]=g;b[119308]=h}if((l&2)!=0){b[119317]=g;b[119318]=h}if((l&4)!=0){b[84744]=g;b[84745]=h}if((l&8)!=0){b[254812]=g;b[254808]=h}if((l&16)==0){i=j;return}b[254813]=g;b[254809]=h;i=j;return}else if((k|0)==3){h=a[f+2|0]|0;l=(h&1)==0?0:128;m=(h&2)==0?l:l|64;l=(h&8)==0?m:m|16;m=(h&16)==0?l:l|2;if(g<<16>>16==0){l=~m;a[169492]=d[169492]&l&255;a[169493]=d[169493]&(l|2)&255;i=j;return}l=d[169492]|m;n=l&255;a[169492]=n;do{if((h&4)==0){o=n;p=a[169493]|0}else{q=l^32;r=q&255;a[169492]=r;if((q&32|0)==0){s=a[169493]&63;a[169493]=s;o=r;p=s;break}else{s=(d[169493]|q&192)&255;a[169493]=s;o=r;p=s;break}}}while(0);l=p&255|m&208;a[169493]=l&255;if(!((l&192|0)!=0&(c[3937]|0)==10)){i=j;return}if((o&2)!=0){i=j;return}o=b[84744]|0;l=b[84745]|0;m=(o<<16>>16)+40|0;if((m|0)>295){t=295}else{t=o<<16>>16<0?40:m&65535}m=(e[522243]|0)-1|0;if((m|0)<(l|0)){u=m}else{u=(l|0)<0?0:l}b[522205]=u+1&65535;b[522204]=t;i=j;return}else if((k|0)==2){t=a[f+2|0]|0;u=(t&2)==0?0:64;l=(t&4)==0?u:u|128;if(g<<16>>16==0){u=238618+((t&1)*20|0)|0;a[u]=d[u]&(l^255)&255;i=j;return}else{u=238618+((t&1)*20|0)|0;a[u]=(d[u]|l)&255;i=j;return}}else if((k|0)==4){k=a[f+2|0]|0;f=(k&2)==0?0:128;if((k&8)==0){v=k&1}else{l=k&1;a[509600+l|0]=g<<16>>16!=0|0;v=l}l=((k&4)==0?f:f|32)>>>(v>>>0);if(g<<16>>16==0){a[509608]=d[509608]&(l^255)&255;i=j;return}else{a[509608]=(d[509608]|l)&255;i=j;return}}else{i=j;return}}function jZ(d){d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;e=a[1125520]|0;if(!(d<<24>>24!=0|e<<24>>24==0)){c[3936]=c[1768];c[3937]=c[1769]}if(d<<24>>24==0|e<<24>>24!=0){a[1125520]=d;return}e=a[169492]|0;f=e&32;g=e&2;if(f<<24>>24==0){e=0;do{a[236008+(e<<1)|0]=0;a[236009+(e<<1)|0]=0;h=c[15744+(e<<2)>>2]|0;L12922:do{switch(h|0){case 11:case 12:{a[509608]=a[509608]^8;break};case 10:{i=a[169493]|0;if(i<<24>>24>-1){j=i}else{k=i&-33;a[169493]=k;j=k}if((j&255)<64){l=j}else{k=j&-3|g;a[169493]=k;l=k}a[169494]=l;a[169493]=l&47;break};case 9:case 8:{k=h-8|0;i=238608+(k*20|0)|0;m=b[238614+(k*20|0)>>1]|0;n=238610+(k*20|0)|0;o=b[n>>1]|0;p=m-o&65535;q=p&255;do{if(p<<16>>16<-127){a[i|0]=-1;b[n>>1]=o-127&65535}else{if(p<<16>>16<0){a[i|0]=-q&255|-128;b[n>>1]=m;break}r=i|0;if(p<<16>>16>127){a[r]=127;b[n>>1]=o+127&65535;break}else{a[r]=q;b[n>>1]=m;break}}}while(0);m=b[238616+(k*20|0)>>1]|0;n=238612+(k*20|0)|0;q=b[n>>1]|0;o=m-q&65535;p=o&255;if(o<<16>>16<-127){a[238609+(k*20|0)|0]=-1;b[n>>1]=q-127&65535;break L12922}if(o<<16>>16<0){a[238609+(k*20|0)|0]=-p&255|-128;b[n>>1]=m;break L12922}i=238609+(k*20|0)|0;if(o<<16>>16>127){a[i]=127;b[n>>1]=q+127&65535;break L12922}else{a[i]=p;b[n>>1]=m;break L12922}break};default:{}}}while(0);e=e+1|0;}while((e|0)<2);a[1125520]=d;return}else{e=0;do{a[236008+(e<<1)|0]=0;a[236009+(e<<1)|0]=0;l=c[15744+(e<<2)>>2]|0;L12955:do{switch(l|0){case 9:case 8:{j=l-8|0;h=238608+(j*20|0)|0;m=b[238614+(j*20|0)>>1]|0;n=238610+(j*20|0)|0;p=b[n>>1]|0;i=m-p&65535;q=i&255;do{if(i<<16>>16<-127){a[h|0]=-1;b[n>>1]=p-127&65535}else{if(i<<16>>16<0){a[h|0]=-q&255|-128;b[n>>1]=m;break}o=h|0;if(i<<16>>16>127){a[o]=127;b[n>>1]=p+127&65535;break}else{a[o]=q;b[n>>1]=m;break}}}while(0);m=b[238616+(j*20|0)>>1]|0;n=238612+(j*20|0)|0;q=b[n>>1]|0;p=m-q&65535;i=p&255;if(p<<16>>16<-127){a[238609+(j*20|0)|0]=-1;b[n>>1]=q-127&65535;break L12955}if(p<<16>>16<0){a[238609+(j*20|0)|0]=-i&255|-128;b[n>>1]=m;break L12955}h=238609+(j*20|0)|0;if(p<<16>>16>127){a[h]=127;b[n>>1]=q+127&65535;break L12955}else{a[h]=i;b[n>>1]=m;break L12955}break};case 11:case 12:{a[509608]=a[509608]^8;break};case 10:{m=a[169493]|0;if(m<<24>>24>-1){s=m}else{n=m&-33|f;a[169493]=n;s=n}if((s&255)<64){t=s}else{n=s&-3|g;a[169493]=n;t=n}a[169494]=t;a[169493]=t&-17;break};default:{}}}while(0);e=e+1|0;}while((e|0)<2);a[1125520]=d;return}}function j_(){var e=0,f=0,g=0,h=0,i=0;X2(c[263191]|0,85,131072);X2(c[263194]|0,0,65536);X2(c[263195]|0,0,32768);if((a[799131]|0)!=0){if((a[799132]|0)!=0){X2(c[263192]|0,0,2097152)}a[1394256]=0;a[1394257]=0;a[1394259]=0;a[1394260]=0;a[1394261]=0;X2(1394264,0,109);if((a[1394258]|0)==0){a[1394343]=(a[1125512]|0)!=0?-128:0;if((c[281374]|0)==524288){e=c[263199]|0;f=c[281376]|0;X5(e|0,f|0,524288)|0;a[1394342]=-128;a[1394344]=-128;a[1394345]=-128;a[1394353]=-128;a[1394354]=-128}else{a[1394344]=-128;a[1394346]=-128;a[1394347]=-128}a[1394355]=-128}else{a[1394349]=-128;a[1394348]=-128}jN()}j$();a[1041664]=-1;b[520830]=0;b[520833]=0;b[520834]=0;b[520829]=308;HL();c[59002]=0;a[1125520]=0;a[238618]=a[238618]&-49;a[238638]=a[238638]&-49;a[509608]=a[509608]&-9;b[522214]=0;b[522215]=0;a[1044490]=0;f=0;do{a[1183776+(f*22|0)|0]=1;a[1183777+(f*22|0)|0]=1;a[1183779+(f*22|0)|0]=1;a[1183780+(f*22|0)|0]=1;a[1183781+(f*22|0)|0]=7;a[1183782+(f*22|0)|0]=-1;b[1183784+(f*22|0)>>1]=-1;a[1183786+(f*22|0)|0]=-1;b[1183788+(f*22|0)>>1]=-1;a[1183790+(f*22|0)|0]=-1;b[1183792+(f*22|0)>>1]=-1;a[1183794+(f*22|0)|0]=0;a[1183795+(f*22|0)|0]=127;a[1183796+(f*22|0)|0]=-1;a[1183797+(f*22|0)|0]=0;a[1183778+(f*22|0)|0]=1;f=f+1|0;}while((f|0)<8);jE();if((a[799122]|0)!=0){X2(1182304,0,1452);a[1182304]=1;a[1182305]=1;X2(1181224,0,1076);a[1181224]=1;X2(1130928,0,50296);b[565464]=128;b[565465]=132;c[201850]=1702;X2(1129624,0,1304);a[1129624]=1}if((a[799121]|0)!=0){xY()}if((a[799123]|0)!=0){a[808140]=0;a[808141]=0;c[202033]=0;X2((c[263195]|0)+8704|0,0,512);a[(c[263195]|0)+8704|0]=32;a[(c[263195]|0)+8736|0]=0;a[(c[263195]|0)+8737|0]=1;a[(c[263195]|0)+8738|0]=2;a[(c[263195]|0)+8739|0]=3;a[(c[263195]|0)+8744|0]=-1;b[420459]=0;b[420460]=0;c[210231]=0;f=840928;c[f>>2]=0;c[f+4>>2]=0;a[840916]=0;c[202028]=0}if((a[799125]|0)!=0){TS()}if((a[799126]|0)!=0){T4()}if((a[799124]|0)!=0){X2(c[263197]|0,0,8192)}if((a[799128]|0)!=0){f=0;e=c[263198]|0;do{a[e+f|0]=-1;f=f+1|0;e=c[263198]|0}while((f|0)<8192);b[522257]=(a[e+8181|0]&1)==0?7168:6144;f=e+8182|0;b[522256]=a[f]&127;b[522258]=d[f]<<1&6}if((a[799130]|0)==0){g=c[263191]|0;c[348389]=g;h=c[263193]|0;c[348391]=h;i=c[263195]|0;c[348390]=i;return}c[58916]=2;c[58918]=-1;f=eG(0)|0;a[1041696]=f&255;a[1041697]=f>>>8&255;a[1041698]=f>>>16&255;a[1041699]=f>>>24&255;g=c[263191]|0;c[348389]=g;h=c[263193]|0;c[348391]=h;i=c[263195]|0;c[348390]=i;return}function j$(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;c[348392]=182;c[348393]=-1;c[348394]=0;c[348395]=c[348395]&3;c[348396]=0;a[1393588]=0;c[348398]=0;c[348399]=8;c[348400]=16;c[348401]=8;X2(1393608,0,5);c[348404]=-1;a[1393620]=9;e=c[199750]|0;c[348406]=e;a[1393628]=0;c[260418]=0;a[1041674|0]=0;f=c[263216]|0;L13033:do{if(f>>>0<19){switch(f|0){case 0:{g=HJ(-4)|0;do{if((a[1393610]|0)==0){h=(c[348392]|0)+8|0;c[348392]=h;if((h|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);h=((HJ(-3)|0)&255)<<8|g&255;if((a[1393610]|0)!=0){i=h;break L13033}j=(c[348392]|0)+8|0;c[348392]=j;if((j|0)<(c[348406]|0)){i=h;break L13033}while(1){j1();if((c[348392]|0)<(c[348406]|0)){i=h;break}}break};case 11:{h=Ua(18432)|0;do{if((a[1393610]|0)==0){g=(c[348392]|0)+8|0;c[348392]=g;if((g|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);g=((Ua(18432)|0)&255)<<8|h&255;if((a[1393610]|0)!=0){i=g;break L13033}j=(c[348392]|0)+8|0;c[348392]=j;if((j|0)<(c[348406]|0)){i=g;break L13033}while(1){j1();if((c[348392]|0)<(c[348406]|0)){i=g;break}}break};case 3:{g=c[261136]|0;h=c[261140]|0;j=g&32764;k=d[h+(g>>>0>4094?j|1:g&32765)|0]<<8|d[h+j|0];c[348392]=198;if((e|0)>198){i=k;break L13033}while(1){j1();if((c[348392]|0)<(c[348406]|0)){i=k;break}}break};case 2:case 6:{k=c[274485]|0;j=c[263193]|0;h=k&32764;g=d[j+(k>>>0>4094?h|1:k&32765)|0]<<8|d[j+h|0];c[348392]=198;if((e|0)>198){i=g;break L13033}while(1){j1();if((c[348392]|0)<(c[348406]|0)){i=g;break}}break};case 14:{g=Ht(-4)|0;c[348392]=190;if((e|0)>190){l=1;m=198;n=e}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=(a[1393610]|0)==0;m=o+8|0;n=p}h=((Ht(-3)|0)&255)<<8|g&255;if(!l){i=h;break L13033}c[348392]=m;if((m|0)<(n|0)){i=h;break L13033}while(1){j1();if((c[348392]|0)<(c[348406]|0)){i=h;break}}break};case 7:{h=c[263196]|0;g=d[h+8189|0]<<8|d[h+8188|0];c[348392]=198;if((e|0)>198){i=g;break L13033}while(1){j1();if((c[348392]|0)<(c[348406]|0)){i=g;break}}break};case 16:{c[348392]=190;if((e|0)>190){q=e;r=198}else{do{j1();s=c[348392]|0;t=c[348406]|0;}while((s|0)>=(t|0));if((a[1393610]|0)==0){q=t;r=s+8|0}else{i=0;break L13033}}c[348392]=r;if((r|0)<(q|0)){i=0;break L13033}while(1){j1();if((c[348392]|0)<(c[348406]|0)){i=0;break}}break};case 5:{g=fe[c[276698]&127](-4)|0;do{if((a[1393610]|0)==0){h=(c[348392]|0)+8|0;c[348392]=h;if((h|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);h=((fe[c[276698]&127](-3)|0)&255)<<8|g&255;if((a[1393610]|0)!=0){i=h;break L13033}j=(c[348392]|0)+8|0;c[348392]=j;if((j|0)<(c[348406]|0)){i=h;break L13033}while(1){j1();if((c[348392]|0)<(c[348406]|0)){i=h;break}}break};case 15:{h=fe[c[40480]&127](65532)|0;do{if((a[1393610]|0)==0){g=(c[348392]|0)+8|0;c[348392]=g;if((g|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);g=((fe[c[40480]&127](65533)|0)&255)<<8|h&255;if((a[1393610]|0)!=0){i=g;break L13033}j=(c[348392]|0)+8|0;c[348392]=j;if((j|0)<(c[348406]|0)){i=g;break L13033}while(1){j1();if((c[348392]|0)<(c[348406]|0)){i=g;break}}break};case 10:{g=c[263192]|0;h=a[g+65532|0]|0;c[348392]=190;if((e|0)>190){u=e;v=198;w=d[g+65533|0]<<8|h&255}else{do{j1();x=c[348392]|0;y=c[348406]|0;}while((x|0)>=(y|0));g=d[(c[263192]|0)+65533|0]<<8|h&255;if((a[1393610]|0)==0){u=y;v=x+8|0;w=g}else{i=g;break L13033}}c[348392]=v;if((v|0)<(u|0)){i=w;break L13033}while(1){j1();if((c[348392]|0)<(c[348406]|0)){i=w;break}}break};case 1:{h=HG(-4)|0;do{if((a[1393610]|0)==0){g=(c[348392]|0)+8|0;c[348392]=g;if((g|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);g=((HG(-3)|0)&255)<<8|h&255;if((a[1393610]|0)!=0){i=g;break L13033}j=(c[348392]|0)+8|0;c[348392]=j;if((j|0)<(c[348406]|0)){i=g;break L13033}while(1){j1();if((c[348392]|0)<(c[348406]|0)){i=g;break}}break};case 13:{g=c[263197]|0;h=a[g+40956|0]|0;c[348392]=190;if((e|0)>190){z=e;A=198;B=d[g+40957|0]<<8|h&255}else{do{j1();C=c[348392]|0;D=c[348406]|0;}while((C|0)>=(D|0));g=d[(c[263197]|0)+40957|0]<<8|h&255;if((a[1393610]|0)==0){z=D;A=C+8|0;B=g}else{i=g;break L13033}}c[348392]=A;if((A|0)<(z|0)){i=B;break L13033}while(1){j1();if((c[348392]|0)<(c[348406]|0)){i=B;break}}break};case 17:{c[348392]=190;if((e|0)>190){E=e;F=198}else{do{j1();G=c[348392]|0;H=c[348406]|0;}while((G|0)>=(H|0));if((a[1393610]|0)==0){E=H;F=G+8|0}else{i=0;break L13033}}c[348392]=F;if((F|0)<(E|0)){i=0;break L13033}while(1){j1();if((c[348392]|0)<(c[348406]|0)){i=0;break}}break};case 4:case 12:{h=c[274485]|0;g=c[263193]|0;j=h&8188;k=d[g+(h>>>0>4094?j|1:h&8189)|0]<<8|d[g+j|0];c[348392]=198;if((e|0)>198){i=k;break L13033}while(1){j1();if((c[348392]|0)<(c[348406]|0)){i=k;break}}break};default:{k=d[1044496]|0;j=(k<<8|k)&65535;c[348392]=198;if((e|0)>198){i=j;break L13033}while(1){j1();if((c[348392]|0)<(c[348406]|0)){i=j;break}}}}}else{j=d[f+65533|0]<<8|d[f+65532|0];c[348392]=198;if((e|0)>198){i=j;break}while(1){j1();if((c[348392]|0)<(c[348406]|0)){i=j;break}}}}while(0);b[520836]=i;a[1044496]=(i&65535)>>>8&255;b[520831]=0;a[1041656]=0;a[1041665|0]=1;a[1041664]=(a[1041664]|0)-3&255;a[1041667|0]=0;a[1041669|0]=0;c[276674]=0;i=b[520829]&-317|308;b[520829]=i;a[799004]=0;c[199741]=c[199740];c[199743]=c[199742];c[199748]=65535;c[199749]=538;e=c[260418]|0;f=e&16777215;c[260418]=f;E=e&16711680;c[276676]=E;F=c[1052804+(f>>>12<<2)>>2]|0;f=i&255;do{if((e&4227072|0)==0){if((e+24576&16384|0)!=0){I=8;break}I=(e+16384&32256|0)==0?12:6}else{I=(e&8388608|0)==0?8:c[348401]|0}}while(0);c[348399]=I;c[348400]=I<<1;L13148:do{if(F>>>0<19){c[348396]=0;if((F|0)==18){break}switch(F|0){case 6:{c[348396]=c[263193];break L13148;break};case 10:{I=e&15728640;if((I|0)==13631488){J=c[198898]|0}else if((I|0)==14680064){J=c[198894]|0}else if((I|0)==15728640){J=c[198890]|0}else{J=0}c[348396]=(c[263192]|0)+(J+(e&983040));break L13148;break};case 17:{c[348396]=c[274488];break L13148;break};case 14:{if(((e&65535)-32752&65535)<7){K=0}else{K=(c[263198]|0)-24576|0}c[348396]=K;break L13148;break};case 3:{I=c[261136]|0;if((I&4095|0)!=4095){break L13148}c[348396]=(c[261140]|0)+((I&(E>>>1|e&32767))-(e&65535));break L13148;break};case 7:{c[348396]=(c[263196]|0)+(-24576-(e&32768));break L13148;break};case 4:{I=c[274485]|0;if((I&4095|0)!=4095){break L13148}c[348396]=(c[263193]|0)+((I&(e&32767)-24576+(e>>>3&122880))-(e&65535));break L13148;break};case 13:{if(((e&65535)-32576&65535)<31){L=0}else{L=(c[263197]|0)-24576|0}c[348396]=L;break L13148;break};case 2:{I=c[274485]|0;if((I&4095|0)!=4095){break L13148}c[348396]=(c[263193]|0)+((I&(E>>>1|e&32767))-(e&65535));break L13148;break};default:{break L13148}}}else{c[348396]=F}}while(0);c[276688]=158776;c[276686]=159800;a[1106728]=(f&255)>>>1&1^1;a[1106720]=f&-128;a[1106736]=f&1;a[1106712]=(f&255)>>>6&1;return}function j0(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=c[1052804+((b>>>12&4095)<<2)>>2]|0;do{if((b&4227072|0)==0){if((b+24576&16384|0)!=0){e=8;break}e=(b+16384&32256|0)==0?12:6}else{e=(b&8388608|0)==0?8:c[348401]|0}}while(0);if(d>>>0>=19){f=a[d+(b&65535)|0]|0;if((a[1393610]|0)!=0){g=f;return g|0}h=(c[348392]|0)+e|0;c[348392]=h;if((h|0)<(c[348406]|0)){g=f;return g|0}while(1){j1();if((c[348392]|0)<(c[348406]|0)){g=f;break}}return g|0}switch(d|0){case 7:{d=a[(c[263196]|0)+((b&32767)-24576)|0]|0;if((a[1393610]|0)!=0){g=d;return g|0}f=(c[348392]|0)+e|0;c[348392]=f;if((f|0)<(c[348406]|0)){g=d;return g|0}while(1){j1();if((c[348392]|0)<(c[348406]|0)){g=d;break}}return g|0};case 4:case 12:{d=a[(c[263193]|0)+(c[274485]&(b&32767)-24576+(b>>>3&122880))|0]|0;if((a[1393610]|0)!=0){g=d;return g|0}f=(c[348392]|0)+e|0;c[348392]=f;if((f|0)<(c[348406]|0)){g=d;return g|0}while(1){j1();if((c[348392]|0)<(c[348406]|0)){g=d;break}}return g|0};case 3:{d=a[(c[261140]|0)+(c[261136]&(b>>>1&8355840|b&32767))|0]|0;if((a[1393610]|0)!=0){g=d;return g|0}f=(c[348392]|0)+e|0;c[348392]=f;if((f|0)<(c[348406]|0)){g=d;return g|0}while(1){j1();if((c[348392]|0)<(c[348406]|0)){g=d;break}}return g|0};case 5:{d=fe[c[276698]&127](b&65535)|0;if((a[1393610]|0)!=0){g=d;return g|0}f=(c[348392]|0)+e|0;c[348392]=f;if((f|0)<(c[348406]|0)){g=d;return g|0}while(1){j1();if((c[348392]|0)<(c[348406]|0)){g=d;break}}return g|0};case 11:{d=Ua(18432)|0;if((a[1393610]|0)!=0){g=d;return g|0}f=(c[348392]|0)+e|0;c[348392]=f;if((f|0)<(c[348406]|0)){g=d;return g|0}while(1){j1();if((c[348392]|0)<(c[348406]|0)){g=d;break}}return g|0};case 13:{if((b&65535)<<16>>16==32606){i=0}else{i=a[(c[263197]|0)+((b&65535)-24576)|0]|0}if((a[1393610]|0)!=0){g=i;return g|0}d=(c[348392]|0)+e|0;c[348392]=d;if((d|0)<(c[348406]|0)){g=i;return g|0}while(1){j1();if((c[348392]|0)<(c[348406]|0)){g=i;break}}return g|0};case 16:{do{if((b&65535|0)==14340){i=c[201864]|0;if((i|0)==0){j=-127;break}d=c[201862]|0;f=a[807496+d|0]|0;h=d+1|0;c[201862]=h;if((i|0)!=(h|0)){j=f;break}c[201864]=0;j=f}else{j=0}}while(0);if((a[1393610]|0)!=0){g=j;return g|0}f=(c[348392]|0)+e|0;c[348392]=f;if((f|0)<(c[348406]|0)){g=j;return g|0}while(1){j1();if((c[348392]|0)<(c[348406]|0)){g=j;break}}return g|0};case 10:{j=b&15728640;if((j|0)==14680064){k=c[198894]|0}else if((j|0)==13631488){k=c[198898]|0}else if((j|0)==15728640){k=c[198890]|0}else{k=0}j=a[(c[263192]|0)+(k+(b&1048575))|0]|0;if((a[1393610]|0)!=0){g=j;return g|0}k=(c[348392]|0)+e|0;c[348392]=k;if((k|0)<(c[348406]|0)){g=j;return g|0}while(1){j1();if((c[348392]|0)<(c[348406]|0)){g=j;break}}return g|0};case 1:{do{if((a[1393610]|0)!=0){if((b&65280|0)!=8448){break}g=a[1044496]|0;return g|0}}while(0);j=HG(b&65535)|0;if((a[1393610]|0)!=0){g=j;return g|0}k=(c[348392]|0)+e|0;c[348392]=k;if((k|0)<(c[348406]|0)){g=j;return g|0}while(1){j1();if((c[348392]|0)<(c[348406]|0)){g=j;break}}return g|0};case 17:{j=b&65535;k=b>>>16&255;do{if((k|0)!=0&k>>>0<15){if((b&65535|0)!=20480){l=9620;break}m=a[1394341+k|0]|0}else{l=9620}}while(0);do{if((l|0)==9620){if((k|0)!=192){m=0;break}f=b&65535;do{if((a[1394343]|0)==0){if(j<<16>>16>-1){n=(c[274488]|0)+f|0;break}else{n=(c[274488]|0)+(f-32768)|0;break}}else{n=(c[274488]|0)+f|0}}while(0);h=a[n]|0;if((f|0)==2){m=(a[1394259]|0)==0?h:-128;break}else if((f|0)==21845){m=(a[1394259]|0)==0?h:-128;break}else if((f|0)==65280|(f|0)==65282|(f|0)==65284|(f|0)==65286|(f|0)==65288|(f|0)==65290|(f|0)==65292|(f|0)==65294|(f|0)==65296|(f|0)==65298){if((a[1394261]|0)==0){m=h;break}m=a[15064+(f-65280)|0]|0;break}else{m=h;break}}}while(0);if((a[1393610]|0)!=0){g=m;return g|0}n=(c[348392]|0)+e|0;c[348392]=n;if((n|0)<(c[348406]|0)){g=m;return g|0}while(1){j1();if((c[348392]|0)<(c[348406]|0)){g=m;break}}return g|0};case 14:{m=Ht(b&65535)|0;if((a[1393610]|0)!=0){g=m;return g|0}n=(c[348392]|0)+e|0;c[348392]=n;if((n|0)<(c[348406]|0)){g=m;return g|0}while(1){j1();if((c[348392]|0)<(c[348406]|0)){g=m;break}}return g|0};case 2:case 6:{m=a[(c[263193]|0)+(c[274485]&(b>>>1&8355840|b&32767))|0]|0;if((a[1393610]|0)!=0){g=m;return g|0}n=(c[348392]|0)+e|0;c[348392]=n;if((n|0)<(c[348406]|0)){g=m;return g|0}while(1){j1();if((c[348392]|0)<(c[348406]|0)){g=m;break}}return g|0};case 0:{m=HJ(b&65535)|0;if((a[1393610]|0)!=0){g=m;return g|0}n=(c[348392]|0)+e|0;c[348392]=n;if((n|0)<(c[348406]|0)){g=m;return g|0}while(1){j1();if((c[348392]|0)<(c[348406]|0)){g=m;break}}return g|0};case 15:{m=fe[c[40480]&127](b)|0;if((a[1393610]|0)!=0){g=m;return g|0}b=(c[348392]|0)+e|0;c[348392]=b;if((b|0)<(c[348406]|0)){g=m;return g|0}while(1){j1();if((c[348392]|0)<(c[348406]|0)){g=m;break}}return g|0};default:{m=a[1044496]|0;if((a[1393610]|0)!=0){g=m;return g|0}b=(c[348392]|0)+e|0;c[348392]=b;if((b|0)<(c[348406]|0)){g=m;return g|0}while(1){j1();if((c[348392]|0)<(c[348406]|0)){g=m;break}}return g|0}}return 0}function j1(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0;f=d[1393620]|0;switch(f|0){case 3:{g=b[522197]|0;L13370:do{if((g|0)==(c[199747]|0)){h=(a[1044392]|0)==0;do{if((a[1044391]|0)==0){if(h){break L13370}i=c[348394]|0;j=b[522198]|0}else{if(!h){k=c[348394]|0;l=b[522198]|0;if((k|0)!=(l<<16>>16|0)){i=k;j=l;break}}a[1393588]=a[1393588]|2;c[348398]=c[199754];c[348395]=c[348395]|2048;if((a[1393628]|0)==0){break L13370}a[1393628]=0;b[520836]=(b[520836]|0)+1&65535;break L13370}}while(0);if((i|0)!=(j<<16>>16|0)){break}a[1393588]=a[1393588]|2;c[348398]=c[199754];c[348395]=c[348395]|2048;if((a[1393628]|0)==0){break}a[1393628]=0;b[520836]=(b[520836]|0)+1&65535}}while(0);j=c[199741]|0;i=(g|0)>(c[348406]|0)&(g|0)<(j|0);c[348406]=i?g:j;a[1393620]=i?4:5;i=a[1044491]|0;if(i<<24>>24==0){return}if((c[348394]|0)>(e[522243]|0)){return}a[1393609]=1;a[1393610]=1;a[1393612]=(a[1393608]|0)==0?0:i;j=a[1393611]|0;g=c[348404]|0;c[348392]=(c[348392]|0)+(c[199752]|0);h=1;l=i;i=0;k=1183776;while(1){do{if((h&l)<<24>>24==0){m=l}else{a[1393611]=0;c[348404]=i;n=k+1|0;if((a[n]|0)==0){o=k+16|0;p=k+10|0}else{o=k+12|0;p=k+14|0}q=d[p]|0;r=b[o>>1]|0;s=q<<16;t=1106760+(i<<2)|0;u=c[t>>2]|0;if((u|0)==0){v=xa(s|r&65535)|0;c[t>>2]=v;w=v}else{w=u}u=k+21|0;do{if((a[u]|0)!=0){v=k+6|0;if(!((a[v]|0)!=4|(a[808073]|0)==0)){b[521916]=268;a[1043837]=0}L13406:do{if((a[k|0]|0)==0){x=r&65535;y=k+5|0;if(((c[161888+(d[y]<<2)>>2]|0)+(x&4095)|0)<=4095){do{if((q-126|0)>>>0<2){z=1}else{if((s&4194304|0)!=0){z=0;break}z=(r&65535)<8192|0}}while(0);a[1393611]=z;if((w|0)==0){A=s|x;switch(d[y]|0){case 3:case 7:{HB(j0(A)|0,d[v]|8448);c[348392]=(c[348392]|0)+8;HB(j0(A+1|0)|0,d[v]|8448);c[348392]=(c[348392]|0)+8;HB(j0(A+2|0)|0,(d[v]|0)+8449&65535);c[348392]=(c[348392]|0)+8;HB(j0(A+3|0)|0,(d[v]|0)+8449&65535);c[348392]=(c[348392]|0)+8;B=y;break L13406;break};case 4:{HB(j0(A)|0,d[v]|8448);c[348392]=(c[348392]|0)+8;HB(j0(A+1|0)|0,(d[v]|0)+8449&65535);c[348392]=(c[348392]|0)+8;HB(j0(A+2|0)|0,(d[v]|0)+8450&65535);c[348392]=(c[348392]|0)+8;HB(j0(A+3|0)|0,(d[v]|0)+8451&65535);c[348392]=(c[348392]|0)+8;B=y;break L13406;break};case 0:{HB(j0(A)|0,d[v]|8448);c[348392]=(c[348392]|0)+8;B=y;break L13406;break};case 5:{HB(j0(A)|0,d[v]|8448);c[348392]=(c[348392]|0)+8;HB(j0(A+1|0)|0,(d[v]|0)+8449&65535);c[348392]=(c[348392]|0)+8;C=A+2|0;break};case 1:{C=A;break};case 2:case 6:{HB(j0(A)|0,d[v]|8448);c[348392]=(c[348392]|0)+8;HB(j0(A+1|0)|0,d[v]|8448);c[348392]=(c[348392]|0)+8;B=y;break L13406;break};default:{B=y;break L13406}}A=j0(C)|0;HB(A,d[v]|8448);c[348392]=(c[348392]|0)+8;A=j0(C+1|0)|0;HB(A,(d[v]|0)+8449&65535);c[348392]=(c[348392]|0)+8;B=y;break}else{switch(d[y]|0){case 2:case 6:{HB(a[w]|0,d[v]|8448);c[348392]=(c[348392]|0)+8;HB(a[(c[t>>2]|0)+1|0]|0,d[v]|8448);c[348392]=(c[348392]|0)+8;c[t>>2]=(c[t>>2]|0)+2;B=y;break L13406;break};case 3:case 7:{HB(a[w]|0,d[v]|8448);c[348392]=(c[348392]|0)+8;HB(a[(c[t>>2]|0)+1|0]|0,d[v]|8448);c[348392]=(c[348392]|0)+8;HB(a[(c[t>>2]|0)+2|0]|0,(d[v]|0)+8449&65535);c[348392]=(c[348392]|0)+8;HB(a[(c[t>>2]|0)+3|0]|0,(d[v]|0)+8449&65535);c[348392]=(c[348392]|0)+8;c[t>>2]=(c[t>>2]|0)+4;B=y;break L13406;break};case 0:{c[t>>2]=w+1;HB(a[w]|0,d[v]|8448);c[348392]=(c[348392]|0)+8;B=y;break L13406;break};case 4:{HB(a[w]|0,d[v]|8448);c[348392]=(c[348392]|0)+8;HB(a[(c[t>>2]|0)+1|0]|0,(d[v]|0)+8449&65535);c[348392]=(c[348392]|0)+8;HB(a[(c[t>>2]|0)+2|0]|0,(d[v]|0)+8450&65535);c[348392]=(c[348392]|0)+8;HB(a[(c[t>>2]|0)+3|0]|0,(d[v]|0)+8451&65535);c[348392]=(c[348392]|0)+8;c[t>>2]=(c[t>>2]|0)+4;B=y;break L13406;break};case 5:{HB(a[w]|0,d[v]|8448);c[348392]=(c[348392]|0)+8;HB(a[(c[t>>2]|0)+1|0]|0,(d[v]|0)+8449&65535);c[348392]=(c[348392]|0)+8;A=(c[t>>2]|0)+2|0;c[t>>2]=A;D=A;break};case 1:{D=w;break};default:{B=y;break L13406}}HB(a[D]|0,d[v]|8448);c[348392]=(c[348392]|0)+8;HB(a[(c[t>>2]|0)+1|0]|0,(d[v]|0)+8449&65535);c[348392]=(c[348392]|0)+8;c[t>>2]=(c[t>>2]|0)+2;B=y;break}}c[t>>2]=0;A=(q-126|0)>>>0<2;do{if(A){E=1}else{if((s&4194304|0)!=0){E=0;break}E=(r&65535)<8192|0}}while(0);a[1393611]=E;F=j0(s|x)|0;HB(F,d[v]|8448);c[348392]=(c[348392]|0)+8;switch(d[y]|0){case 5:{do{if(A){G=1}else{if((s&4194304|0)!=0){G=0;break}G=(r+1&65535)<8192|0}}while(0);a[1393611]=G;HB(j0(r+1&65535|s)|0,(d[v]|8448)+1&65535);c[348392]=(c[348392]|0)+8;do{if(A){H=1}else{if((s&4194304|0)!=0){H=0;break}H=(r+2&65535)<8192|0}}while(0);a[1393611]=H;HB(j0(r+2&65535|s)|0,d[v]|8448);c[348392]=(c[348392]|0)+8;do{if(A){I=1}else{if((s&4194304|0)!=0){I=0;break}I=(r+3&65535)<8192|0}}while(0);a[1393611]=I;HB(j0(r+3&65535|s)|0,(d[v]|8448)+1&65535);c[348392]=(c[348392]|0)+8;B=y;break L13406;break};case 2:case 6:{do{if(A){J=1}else{if((s&4194304|0)!=0){J=0;break}J=(r+1&65535)<8192|0}}while(0);a[1393611]=J;HB(j0(r+1&65535|s)|0,d[v]|8448);c[348392]=(c[348392]|0)+8;B=y;break L13406;break};case 3:case 7:{do{if(A){K=1}else{if((s&4194304|0)!=0){K=0;break}K=(r+1&65535)<8192|0}}while(0);a[1393611]=K;HB(j0(r+1&65535|s)|0,d[v]|8448);c[348392]=(c[348392]|0)+8;do{if(A){L=1}else{if((s&4194304|0)!=0){L=0;break}L=(r+2&65535)<8192|0}}while(0);a[1393611]=L;HB(j0(r+2&65535|s)|0,(d[v]|8448)+1&65535);c[348392]=(c[348392]|0)+8;do{if(A){M=1}else{if((s&4194304|0)!=0){M=0;break}M=(r+3&65535)<8192|0}}while(0);a[1393611]=M;HB(j0(r+3&65535|s)|0,(d[v]|8448)+1&65535);c[348392]=(c[348392]|0)+8;B=y;break L13406;break};case 4:{do{if(A){N=1}else{if((s&4194304|0)!=0){N=0;break}N=(r+1&65535)<8192|0}}while(0);a[1393611]=N;HB(j0(r+1&65535|s)|0,(d[v]|8448)+1&65535);c[348392]=(c[348392]|0)+8;do{if(A){O=1}else{if((s&4194304|0)!=0){O=0;break}O=(r+2&65535)<8192|0}}while(0);a[1393611]=O;HB(j0(r+2&65535|s)|0,(d[v]|8448)+2&65535);c[348392]=(c[348392]|0)+8;do{if(A){P=1}else{if((s&4194304|0)!=0){P=0;break}P=(r+3&65535)<8192|0}}while(0);a[1393611]=P;HB(j0(r+3&65535|s)|0,(d[v]|8448)+3&65535);c[348392]=(c[348392]|0)+8;B=y;break L13406;break};case 1:{do{if(A){Q=1}else{if((s&4194304|0)!=0){Q=0;break}Q=(r+1&65535)<8192|0}}while(0);a[1393611]=Q;HB(j0(r+1&65535|s)|0,(d[v]|8448)+1&65535);c[348392]=(c[348392]|0)+8;B=y;break L13406;break};default:{B=y;break L13406}}}else{B=k+5|0}}while(0);v=c[161888+(d[B]<<2)>>2]|0;if((a[n]|0)==0){A=k+16|0;b[A>>1]=(e[A>>1]|0)+v&65535;break}else{A=k+12|0;b[A>>1]=(e[A>>1]|0)+v&65535;break}}}while(0);a[u]=(a[k+18|0]|0)==0|0;n=k+19|0;s=(a[n]|0)-1&255;a[n]=s;if(s<<24>>24!=0){c[348392]=(c[348392]|0)+8;m=l;break}if((xd(i)|0)<<24>>24!=0){m=l;break}a[1044492]=a[1044492]|h;a[u]=0;m=l&~h}}while(0);s=h<<1;if(s<<24>>24==0){break}else{h=s;l=m;i=i+1|0;k=k+22|0}}a[1393609]=0;a[1393610]=a[1393608]|0;a[1393611]=j;c[348404]=g;a[1044491]=m;return};case 2:case 4:case 6:case 8:case 10:case 12:{m=(a[1044392]|0)==0;do{if((a[1044391]|0)==0){if(m){break}R=c[348394]|0;S=b[522198]|0;T=10054}else{if(m){T=10055;break}g=c[348394]|0;j=b[522198]|0;if((g|0)==(j<<16>>16|0)){T=10055}else{R=g;S=j;T=10054}}}while(0);if((T|0)==10054){if((R|0)==(S<<16>>16|0)){T=10055}}do{if((T|0)==10055){a[1393588]=a[1393588]|2;c[348398]=c[199754];c[348395]=c[348395]|2048;if((a[1393628]|0)==0){break}a[1393628]=0;b[520836]=(b[520836]|0)+1&65535}}while(0);switch(f|0){case 1:case 2:{U=c[199747]|0;V=3;break};case 3:case 4:{U=c[199741]|0;V=5;break};case 5:case 6:{U=c[199746]|0;V=7;break};case 7:case 8:{U=c[199750]|0;V=9;break};case 9:case 10:{U=c[199749]|0;V=11;break};case 11:case 12:{U=c[199744]|0;V=1;break};default:{U=0;V=0}}f=b[522197]|0;L13519:do{if((f|0)>(c[348406]|0)&(f|0)<(U|0)){switch(V&255|0){case 3:{W=f;X=2;break L13519;break};case 5:{W=f;X=4;break L13519;break};case 7:{W=f;X=6;break L13519;break};case 9:{W=f;X=8;break L13519;break};case 11:{W=f;X=10;break L13519;break};case 1:{W=f;X=12;break L13519;break};default:{W=f;X=V;break L13519}}}else{W=U;X=V}}while(0);c[348406]=W;a[1393620]=X;return};case 9:{X=c[348394]|0;do{if((X|0)>0){if((X|0)>(e[522243]|0)){break}W=X+255&255;b[1101800+(W<<4)>>1]=(b[520862]|0)+1&65535;b[1101802+(W<<4)>>1]=b[520861]|0;b[1101804+(W<<4)>>1]=(b[520868]|0)+1&65535;b[1101806+(W<<4)>>1]=b[520867]|0;if((a[1041768]|0)==7){b[1097960+(W<<4)>>1]=b[522208]|0;b[1097962+(W<<4)>>1]=b[522209]|0;b[1097964+(W<<4)>>1]=b[522210]|0;b[1097966+(W<<4)>>1]=b[522211]|0;b[1097968+(W<<4)>>1]=b[522212]|0;b[1097970+(W<<4)>>1]=b[522213]|0;b[1097972+(W<<4)>>1]=b[522214]|0;b[1097974+(W<<4)>>1]=b[522215]|0}else{b[1101808+(W<<4)>>1]=(b[520874]|0)+1&65535;b[1101810+(W<<4)>>1]=b[520873]|0;b[1101812+(W<<4)>>1]=(b[520880]|0)+1&65535;b[1101814+(W<<4)>>1]=b[520879]|0}c[276539]=W+1}}while(0);W=b[522197]|0;L13539:do{if((W|0)==(c[199750]|0)){V=(a[1044392]|0)==0;do{if((a[1044391]|0)==0){if(V){break L13539}Y=b[522198]|0}else{if(!V){U=b[522198]|0;if((X|0)!=(U<<16>>16|0)){Y=U;break}}a[1393588]=a[1393588]|2;c[348398]=c[199754];c[348395]=c[348395]|2048;if((a[1393628]|0)==0){break L13539}a[1393628]=0;b[520836]=(b[520836]|0)+1&65535;break L13539}}while(0);if((X|0)!=(Y<<16>>16|0)){break}a[1393588]=a[1393588]|2;c[348398]=c[199754];c[348395]=c[348395]|2048;if((a[1393628]|0)==0){break}a[1393628]=0;b[520836]=(b[520836]|0)+1&65535}}while(0);Y=c[199749]|0;X=(W|0)>(c[348406]|0)&(W|0)<(Y|0);c[348406]=X?W:Y;a[1393620]=X?10:11;return};case 1:{X=b[522197]|0;L13555:do{if((X|0)==(c[199744]|0)){Y=(a[1044392]|0)==0;do{if((a[1044391]|0)==0){if(Y){break L13555}Z=c[348394]|0;_=b[522198]|0}else{if(!Y){W=c[348394]|0;V=b[522198]|0;if((W|0)!=(V<<16>>16|0)){Z=W;_=V;break}}a[1393588]=a[1393588]|2;c[348398]=c[199754];c[348395]=c[348395]|2048;if((a[1393628]|0)==0){break L13555}a[1393628]=0;b[520836]=(b[520836]|0)+1&65535;break L13555}}while(0);if((Z|0)!=(_<<16>>16|0)){break}a[1393588]=a[1393588]|2;c[348398]=c[199754];c[348395]=c[348395]|2048;if((a[1393628]|0)==0){break}a[1393628]=0;b[520836]=(b[520836]|0)+1&65535}}while(0);_=c[199747]|0;Z=(X|0)>(c[348406]|0)&(X|0)<(_|0);c[348406]=Z?X:_;a[1393620]=Z?2:3;return};case 5:{do{if(!((a[799121]|0)==0|a[101712])){Z=c[263195]|0;if((a[Z+12336|0]&32)==0){break}if((a[Z+12346|0]&24)!=24){break}yj()}}while(0);a[101712]=0;Z=c[1502]|0;_=c[59e3]|0;X=ab((c[348392]|0)-_|0,Z)|0;Y=c[42380]|0;V=c[1504]|0;W=((X+Y|0)>>>0)/(V>>>0)|0;X=c[109231]|0;if((X|0)<(W|0)){jD(W);$=c[109231]|0}else{$=X}c[109231]=$-W;c[109233]=(c[109233]|0)+W;W=c[109198]|0;do{if((W|0)<1){$=c[109199]|0;X=-W>>$;U=X+1|0;c[109198]=(U<<$)+W;if((c[109202]|0)==0){break}$=c[109200]|0;f=c[109201]|0;S=X-($+255-f&255)|0;if((S|0)>-1){X=(S|0)/($|0)|0;c[109203]=X+1+(c[109203]|0)&15;aa=S-(ab(X,$)|0)&255}else{aa=f+U&255}c[109201]=aa&255}}while(0);aa=c[109204]|0;do{if((aa|0)<1){W=c[109205]|0;U=-aa>>W;f=U+1|0;c[109204]=(f<<W)+aa;if((c[109208]|0)==0){break}W=c[109206]|0;$=c[109207]|0;X=U-(W+255-$&255)|0;if((X|0)>-1){U=(X|0)/(W|0)|0;c[109209]=U+1+(c[109209]|0)&15;ac=X-(ab(U,W)|0)&255}else{ac=$+f&255}c[109207]=ac&255}}while(0);ac=c[109210]|0;do{if((ac|0)<1){aa=c[109211]|0;f=-ac>>aa;$=f+1|0;c[109210]=($<<aa)+ac;if((c[109214]|0)==0){break}aa=c[109212]|0;W=c[109213]|0;U=f-(aa+255-W&255)|0;if((U|0)>-1){f=(U|0)/(aa|0)|0;c[109215]=f+1+(c[109215]|0)&15;ad=U-(ab(f,aa)|0)&255}else{ad=W+$&255}c[109213]=ad&255}}while(0);ad=c[109230]|0;do{if((ad|0)<0){ac=-29-ad|0;if((ac|0)<=-1){break}$=ac+32&-32;c[109230]=$+ad;jF($)}}while(0);ad=c[109234]|0;if((ad|0)!=0){$=c[109235]|0;ac=c[199290]|0;W=ad>>>0>ac>>>0|ac>>>0>$>>>0;aa=W?$:ac;$=W?ac:797172;ac=ad+(c[109233]>>5<<1<<1)|0;if(ac>>>0<aa>>>0){ad=436948;W=ac;while(1){ac=ad+2|0;b[ad>>1]=b[W>>1]|0;f=W+2|0;if(f>>>0<aa>>>0){ad=ac;W=f}else{ae=ac;break}}}else{ae=436948}if($>>>0>797172>>>0){W=ae;ad=797172;while(1){aa=W+2|0;b[W>>1]=b[ad>>1]|0;ac=ad+2|0;if(ac>>>0<$>>>0){W=aa;ad=ac}else{af=aa;break}}}else{af=ae}c[109236]=af}af=c[348392]|0;c[42380]=(((ab(af-_|0,Z)|0)+Y|0)>>>0)%(V>>>0)|0;c[59e3]=af;V=c[109233]>>5;Y=V<<1;if((Y|0)<128&(a[1728]^1)){ag=af}else{af=V<<2;V=c[59008]|0;Z=c[59006]|0;_=V-Z|0;do{if((_>>1|0)<(Y|0)|(_|0)<(af|0)){a[1728]=1;if((a[799120]|0)!=0){ah=Z;break}ai=Z;aj=c[125858]|0;T=9833}else{ae=c[125858]|0;ad=ae;W=((c[59004]|0)+Z|0)%(V|0)|0;$=V-W|0;aa=(af|0)<($|0)?af:$;$=c[59010]|0;ac=$+W|0;X5(ac|0,ad|0,aa)|0;if((af|0)>(aa|0)){ac=ad+aa|0;ad=af-aa|0;X5($|0,ac|0,ad)|0}ad=Z+af|0;c[59006]=ad;a[1728]=1;if((a[799120]|0)==0){ai=ad;aj=ae;T=9833;break}if((V-ad|0)<(ad|0)){ak=ae;al=ad;T=9834}else{ai=ad;aj=ae;T=9833}}}while(0);if((T|0)==9833){a[1728]=0;ak=aj;al=ai;T=9834}if((T|0)==9834){c[109233]=c[109233]&31;ai=a[17360]|0;aj=ak+((ai?2048:0)<<1)|0;c[109234]=ak;c[109235]=aj;af=c[109236]|0;if(af>>>0>436948>>>0&ai){Z=ak;_=436948;while(1){Y=_+2|0;ae=Z+2|0;b[Z>>1]=b[_>>1]|0;ad=c[109236]|0;ac=ae>>>0<aj>>>0;if(Y>>>0<ad>>>0&ac){Z=ae;_=Y}else{am=ae;an=Y;ao=ac;ap=ad;break}}}else{am=ak;an=436948;ao=ai;ap=af}do{if(ao){aq=aj;ar=am}else{if(an>>>0<ap>>>0){as=797172;at=an}else{aq=797204;ar=797172;break}while(1){af=at+2|0;ai=as+2|0;b[as>>1]=b[at>>1]|0;if(af>>>0<(c[109236]|0)>>>0){as=ai;at=af}else{aq=797204;ar=ai;break}}}}while(0);at=(ar|0)==0;as=at?797172:ar;c[199292]=as;c[199290]=as;c[199291]=as+((at?16:aq-ar>>1)<<1);ah=al}al=c[59356]|0;ar=c[59338]|0;aq=(((ah<<14)-al|0)>>>0)/(ar>>>0)|0;at=aq<<1;as=c[59004]|0;an=c[59010]|0;ap=V>>1;am=as>>1;aj=0;ao=0;ai=al;al=c[59354]|0;af=c[59352]|0;ak=c[59350]|0;_=c[59348]|0;Z=c[59346]|0;ad=c[59344]|0;ac=c[59342]|0;Y=c[59340]|0;L13640:while(1){ae=an+(am<<1)|0;$=an+(am+1<<1)|0;aa=(ao|0)<(V|0);W=ak-al<<14;f=_-af<<14;U=ac-Z<<14;X=Y-ad<<14;S=aj;R=ai;while(1){if(!((S|0)<(at|0)&aa)){break L13640}au=b[ae>>1]|0;av=b[$>>1]|0;if(R>>>0<65537){aw=S;ax=R}else{ay=R;az=S;break}do{m=ax>>>1;j=(ab(m,m)|0)>>>15;g=(ab(j,m)|0)>>>15;k=g<<1;i=j*3|0;l=ab(32768-i+k|0,af)|0;h=(ab(W,m-(j<<1)+g|0)|0)>>15;m=(ab(f,g-j|0)|0)>>15;j=(ab(i-k|0,ak)|0)+l+h+m>>15;if((j|0)>32767){aA=32767}else{aA=(j|0)<-32768?-32768:j&65535}b[910584+(aw<<1)>>1]=aA;j=ax>>>1;m=(ab(j,j)|0)>>>15;h=(ab(m,j)|0)>>>15;l=h<<1;k=m*3|0;i=ab(32768-k+l|0,ad)|0;g=(ab(U,j-(m<<1)+h|0)|0)>>15;j=(ab(X,h-m|0)|0)>>15;m=i+g+(ab(k-l|0,ac)|0)+j>>15;if((m|0)>32767){aB=32767}else{aB=(m|0)<-32768?-32768:m&65535}b[910584+(aw+1<<1)>>1]=aB;aw=aw+2|0;ax=ax+ar|0;}while(ax>>>0<65537&(aw|0)<(at|0));c[59356]=ax;if(ax>>>0>65536){ay=ax;az=aw;break}else{S=aw;R=ax}}R=au<<16>>16;S=av<<16>>16;c[59354]=af;c[59352]=ak;c[59350]=_;c[59348]=R;c[59346]=ad;c[59344]=ac;c[59342]=Y;c[59340]=S;X=ay-65536|0;c[59356]=X;U=am+2|0;am=U-((U|0)<(ap|0)?0:ap)|0;aj=az;ao=ao+2|0;ai=X;al=af;af=ak;ak=_;_=R;Z=ad;ad=ac;ac=Y;Y=S}Y=ao<<1;c[59006]=ah-Y;ah=as+Y|0;c[59004]=ah-((ah|0)<(V|0)?0:V);ft[c[199558]&63](910584,aq&2147483647)|0;ag=c[348392]|0}aq=c[199741]|0;V=ag-aq|0;c[348392]=V;c[59e3]=V;V=c[199748]|0;if(!((V|0)==65535|(V|0)<(aq|0))){c[199748]=V-aq}aq=(c[348394]|0)+1|0;c[348394]=aq;if((aq|0)<(c[199743]|0)){aC=aq}else{c[348394]=0;aq=a[799004]|0;a[799004]=aq^1;V=c[199742]|0;c[199743]=V;if(!((a[1106149]|0)==0|aq<<24>>24!=1)){c[199743]=V+1}V=(c[263195]|0)+8511|0;a[V]=a[V]^-128;a[1044390]=0;a[(c[263195]|0)+16912|0]=2;V=c[348395]&-145;c[199748]=65535;c[276672]=(c[276672]|0)+1;a[1044412]=0;c[348395]=V|16;aC=c[348394]|0}V=c[199740]|0;c[199741]=V;aq=a[1106149]|0;ag=a[799004]|0;if(!((aC|0)!=240|aq<<24>>24!=0|ag<<24>>24==0)){c[199741]=V-4}if((aC|0)==240){if(!(aq<<24>>24==0&ag<<24>>24!=0)){T=9862}}else{T=9862}do{if((T|0)==9862){if((c[199749]|0)==534){c[199749]=538;break}else{c[199749]=534;break}}}while(0);L13677:do{if((b[522197]|0)==0){ag=(a[1044392]|0)==0;do{if((a[1044391]|0)==0){if(ag){break L13677}aD=b[522198]|0}else{if(!ag){aq=b[522198]|0;if((aC|0)!=(aq<<16>>16|0)){aD=aq;break}}a[1393588]=a[1393588]|2;c[348398]=c[199754];c[348395]=c[348395]|2048;if((a[1393628]|0)==0){break L13677}a[1393628]=0;b[520836]=(b[520836]|0)+1&65535;break L13677}}while(0);if((aC|0)!=(aD<<16>>16|0)){break}a[1393588]=a[1393588]|2;c[348398]=c[199754];c[348395]=c[348395]|2048;if((a[1393628]|0)==0){break}a[1393628]=0;b[520836]=(b[520836]|0)+1&65535}}while(0);do{if((aC|0)==((e[522243]|0)+1|0)){if((c[276540]|0)!=(c[276539]|0)){Hy()}b[522205]=1e3;b[522204]=0;L13696:do{if(!((a[807392]|0)!=0|(a[238560]|0)==0)){aD=(a[509601]|0)!=0;ag=a[509608]|0;aq=(ag&255)>>>3&1;V=15752+((a[7744]|0?4:0)<<2)|0;ah=a[7736]|0?14:0;Y=a[7728]&1;as=b[254813]|0;ao=b[254809]|0;ac=(a[509600]|0)!=0;ad=15752+((a[7768]|0?4:0)<<2)|0;Z=a[7760]|0?12:0;_=a[7752]&1;ak=b[254812]|0;af=b[254808]|0;al=ag<<4<<24>>24>>7<<24>>24;ag=0;while(1){ai=c[15744+(ag<<2)>>2]|0;L13700:do{switch(ai|0){case 8:case 9:{az=ai-8|0;if((c[201844]|0)==0){break L13700}aj=a[238625+(az*20|0)|0]|0;if((aj&255)>31){aE=0}else{aE=c[15752+((aj&255)<<2)>>2]|0}HA(aE,a[238626+(az*20|0)|0]|0,a[238627+(az*20|0)|0]|0,b[238614+(az*20|0)>>1]|0,b[238616+(az*20|0)>>1]|0);break};case 12:{if((ag|0)!=1|aD|(c[201844]|0)==0){aF=aq;T=9900;break L13700}HA(c[V>>2]|0,ah,Y,as,ao);aF=aq;T=9900;break};case 11:{aF=al;T=9900;break};case 10:{if((ag|0)!=1){break L13700}if((a[169492]&2)!=0){break L13696}if((d[169493]|0)>63){az=b[84744]|0;aj=b[84745]|0;ap=(az<<16>>16)+40|0;if((ap|0)>295){aG=295}else{aG=az<<16>>16<0?40:ap&65535}ap=(e[522243]|0)-1|0;if((ap|0)<(aj|0)){aH=ap}else{aH=(aj|0)<0?0:aj}b[522205]=aH+1&65535;b[522204]=aG}if((c[201844]|0)==0){break L13700}aj=a[169501]|0;if((aj&255)>31){aI=0}else{aI=c[15752+((aj&255)<<2)>>2]|0}HA(aI,a[169502]|0,a[169503]|0,b[84744]|0,b[84745]|0);break};default:{}}}while(0);do{if((T|0)==9900){T=0;if((ag|0)!=1){break}do{if((aF|0)>-1){if((a[509600+aF|0]|0)!=0){break}ai=b[509624+(aF<<1)>>1]|0;aj=b[509616+(aF<<1)>>1]|0;ap=(ai<<16>>16)+40|0;if((ap|0)>295){aJ=295}else{aJ=ai<<16>>16<0?40:ap&65535}ap=(e[522243]|0)-1|0;if((ap|0)<(aj|0)){aK=ap}else{aK=(aj|0)<0?0:aj}b[522205]=aK+1&65535;b[522204]=aJ}}while(0);if(ac|(c[201844]|0)==0){break}HA(c[ad>>2]|0,Z,_,ak,af)}}while(0);ag=ag+1|0;if((ag|0)>=2){break L13696}}}}while(0);a[238560]=0;ag=c[199789]|0;do{if((ag|0)==1){if((c[276671]|0)!=239){break}c[276671]=224}else if((ag|0)==2){a[1044439]=0;af=a[(c[263191]|0)+62|0]|0;if(!((af<<24>>24|0)==49|(af<<24>>24|0)==(-39|0)|(af<<24>>24|0)==66|(af<<24>>24|0)==67)){break}a[1044439]=1}else if((ag|0)==5){a[1044495]=0;a[17264]=0;af=c[263191]|0;ak=a[af+99|0]|0;_=a[af+14991|0]|0;Z=a[af+186|0]|0;af=ak<<24>>24!=0;if(af){a[1044495]=ak}if(Z<<24>>24==1){a[17264]=1}if(_<<24>>24==1){a[17264]=1}if(!af){break}a[17264]=1}else if((ag|0)==6){if(((a[1041768]|0)-1&255)<2){a[1044439]=1;break}else{a[1044439]=0;break}}}while(0);if(!((a[1108916]|0)!=0&(a[1108917]|0)==0)){ag=c[276670]|0;af=c[276671]|0;if((af|0)==478|(af|0)==448){aL=1024}else{aL=2048}c[277216]=aL;fA[c[42366]&127](c[277212]|0,ag,af,aL)}if(!((a[799144]|0)==0|(c[297188]|0)==0)){af=0;do{do{if((a[1183958+(af<<5)|0]|0)!=0){ag=c[1183952+(af<<5)>>2]|0;_=1183959+(af<<5)|0;if((a[_]|0)==0){a[1183957+(af<<5)|0]=jT(ag)|0;a[_]=1}_=c[1052804+((ag>>>12&4095)<<2)>>2]|0;Z=a[1183956+(af<<5)|0]|0;if(_>>>0<19){jU(Z,ag);break}else{a[_+(ag&65535)|0]=Z;break}}}while(0);af=af+1|0;}while(af>>>0<(c[297188]|0)>>>0)}a[1044491]=0;af=c[263195]|0;Z=(d[af+8448|0]|0)>>>7;a[1044481]=Z;if(Z<<24>>24==0){Z=b[521917]|0;b[521916]=Z;if((a[1043836]|0)==0){aM=0}else{aM=(Z&65535)>>>1&127}if(!((a[1043837]&1)==0&(a[1044388]|0)==aM<<24>>24)){a[1044388]=aM;a[1106088]=1}a[1043837]=0}a[af+16912|0]=-126;if((a[(c[263195]|0)+16896|0]|0)>=0){break}c[348395]=c[348395]|128;c[199748]=12}}while(0);aM=c[348394]|0;do{if((aM|0)==((e[522243]|0)+3|0)){if((a[(c[263195]|0)+16896|0]&1)==0){aN=aM;break}jZ(1);if((a[1125520]|0)!=0){c[3936]=c[1768];c[3937]=c[1769]}a[1125520]=0;aL=0;do{aJ=c[15744+(aL<<2)>>2]|0;switch(aJ|0){case-1:{aK=c[263195]|0;aF=(aL|0)!=0?128:64;T=(d[aK+16915|0]&aF|0)!=0?0:2;aI=aL<<1;aG=aI+16920|0;aH=238600+(aL<<2)+T|0;aE=a[aH]|0;if(aE<<24>>24==-2){a[aK+aG|0]=0;a[(c[263195]|0)+(aG|1)|0]=0}else{a[aK+aG|0]=b[509632+(aE<<24>>24<<1)>>1]&255;a[(c[263195]|0)+(aG|1)|0]=(e[509632+(a[aH]<<1)>>1]|0)>>>8&255}aH=(T|1)+(238600+(aL<<2))|0;T=a[aH]|0;if(T<<24>>24==-2){aG=aI+16924|0;a[(c[263195]|0)+aG|0]=0;a[(c[263195]|0)+(aG|1)|0]=0}else{aG=aI+16924|0;a[(c[263195]|0)+aG|0]=b[509632+(T<<24>>24<<1)>>1]&255;a[(c[263195]|0)+(aG|1)|0]=(e[509632+(a[aH]<<1)>>1]|0)>>>8&255}a[((d[(c[263195]|0)+16915|0]&aF|0)==0)+(236008+(aL<<1))|0]=16;break};case 11:case 12:{a[236008+(aL<<1)|0]=16;aF=aL<<1;a[(c[263195]|0)+(aF+16920)|0]=14;a[(c[263195]|0)+(aF+16921)|0]=0;a[(c[263195]|0)+(aF+16924)|0]=0;a[(c[263195]|0)+(aF+16925)|0]=0;break};case 0:case 1:case 2:case 3:case 4:case 5:case 6:case 7:{a[236008+(aL<<1)|0]=16;aF=b[509632+(aJ<<1)>>1]|0;aH=aL<<1;a[(c[263195]|0)+(aH+16920)|0]=aF&255;a[(c[263195]|0)+(aH+16921)|0]=(aF&65535)>>>8&255;a[(c[263195]|0)+(aH+16924)|0]=0;a[(c[263195]|0)+(aH+16925)|0]=0;break};case 8:case 9:{a[236008+(aL<<1)|0]=16;aH=aL<<1;a[(c[263195]|0)+(aH+16920)|0]=a[238618+((aJ-8|0)*20|0)|0]|0;a[(c[263195]|0)+(aH+16921)|0]=0;a[(c[263195]|0)+(aH+16924)|0]=0;a[(c[263195]|0)+(aH+16925)|0]=0;break};case 10:{a[236008+(aL<<1)|0]=16;aH=aL<<1;a[(c[263195]|0)+(aH+16920)|0]=-1;a[(c[263195]|0)+(aH+16921)|0]=a[169494]|0;a[(c[263195]|0)+(aH+16924)|0]=0;a[(c[263195]|0)+(aH+16925)|0]=0;break};default:{aH=aL<<1;a[(c[263195]|0)+(aH+16920)|0]=0;a[(c[263195]|0)+(aH+16921)|0]=0;a[(c[263195]|0)+(aH+16924)|0]=0;a[(c[263195]|0)+(aH+16925)|0]=0}}aL=aL+1|0;}while((aL|0)<2);aN=c[348394]|0}else{aN=aM}}while(0);if((aN|0)==1){aN=(a[1108917]|0)==0;a[1108917]=aN&1;aM=a[1108916]|0;if(!(aM<<24>>24!=0&aN)){aN=aM-(aM<<24>>24==1)&255;a[1108916]=aN;aM=(c[263195]|0)+8499|0;aL=a[aM]&1;a[1106149]=aL;a[1106150]=a[aM]&2;aH=a[aM]&8;a[1106151]=aH;if((a[807393]|0)==0){aO=0;aP=0}else{aO=aL;aP=((a[1041768]|0)-5&255)<2?1:(aH&255)>>>3}aH=(c[277216]|0)>>>1;c[277222]=aH;c[276670]=256<<(aP&255);aL=aO&255;c[276671]=e[522243]<<aL;a[1106152]=aP;a[1106153]=aO;c[277223]=aH<<aL;a[1108916]=aO+aN&255}a[1044433]=0;a[1044444]=1;c[276539]=0;c[276540]=0;X2(c[277214]|0,0,c[277217]|0);X2(c[277215]|0,0,c[277217]|0)}c[348406]=-1;switch(d[1393620]|0){case 1:case 2:{aQ=c[199747]|0;aR=3;break};case 3:case 4:{aQ=c[199741]|0;aR=5;break};case 5:case 6:{aQ=c[199746]|0;aR=7;break};case 7:case 8:{aQ=c[199750]|0;aR=9;break};case 9:case 10:{aQ=c[199749]|0;aR=11;break};case 11:case 12:{aQ=c[199744]|0;aR=1;break};default:{aQ=0;aR=0}}aN=b[522197]|0;aO=aN<<16>>16;L13834:do{if(aN<<16>>16>-1&(aO|0)<(aQ|0)){switch(aR&255|0){case 3:{aS=aO;aT=2;break L13834;break};case 5:{aS=aO;aT=4;break L13834;break};case 7:{aS=aO;aT=6;break L13834;break};case 9:{aS=aO;aT=8;break L13834;break};case 11:{aS=aO;aT=10;break L13834;break};case 1:{aS=aO;aT=12;break L13834;break};default:{aS=aO;aT=aR;break L13834}}}else{aS=aQ;aT=aR}}while(0);c[348406]=aS;a[1393620]=aT;return};case 7:{aT=b[522197]|0;L13846:do{if((aT|0)==(c[199746]|0)){aS=(a[1044392]|0)==0;do{if((a[1044391]|0)==0){if(aS){break L13846}aU=c[348394]|0;aV=b[522198]|0}else{if(!aS){aR=c[348394]|0;aQ=b[522198]|0;if((aR|0)!=(aQ<<16>>16|0)){aU=aR;aV=aQ;break}}a[1393588]=a[1393588]|2;c[348398]=c[199754];c[348395]=c[348395]|2048;if((a[1393628]|0)==0){break L13846}a[1393628]=0;b[520836]=(b[520836]|0)+1&65535;break L13846}}while(0);if((aU|0)!=(aV<<16>>16|0)){break}a[1393588]=a[1393588]|2;c[348398]=c[199754];c[348395]=c[348395]|2048;if((a[1393628]|0)==0){break}a[1393628]=0;b[520836]=(b[520836]|0)+1&65535}}while(0);aV=c[199750]|0;aU=(aT|0)>(c[348406]|0)&(aT|0)<(aV|0);c[348406]=aU?aT:aV;a[1393620]=aU?8:9;if((c[348394]|0)!=0){return}aU=a[(c[263195]|0)+16908|0]|0;a[1044491]=aU;a[1044492]=0;a[1393609]=1;a[1393610]=1;aV=c[348404]|0;if(aU<<24>>24==0){aW=1;aX=0;aY=0}else{c[348392]=(c[348392]|0)+(c[199752]|0);aW=1;aX=0;aY=aU}while(1){aU=1<<aX;do{if((aU&(aY&255)|0)==0){a[1183797+(aX*22|0)|0]=0}else{c[348404]=aX;b[1183792+(aX*22|0)>>1]=b[1183784+(aX*22|0)>>1]|0;if((xd(aX)|0)<<24>>24!=0){break}a[1044491]=d[1044491]&(aU^255)&255;a[1044492]=(d[1044492]|aU)&255}}while(0);if((aW&255)>=8){break}aU=aW&255;aW=aW+1&255;aX=aU;aY=a[1044491]|0}a[1393609]=0;aY=a[1393608]|0;a[1393610]=aY;a[1393612]=aY<<24>>24==0?0:a[1044491]|0;c[348404]=aV;return};case 11:{aV=b[522197]|0;aY=c[199749]|0;L13876:do{if((aV|0)>=(aY|0)&(aV|0)<(aY+40|0)){aX=(a[1044392]|0)==0;do{if((a[1044391]|0)==0){if(aX){break L13876}aZ=c[348394]|0;a_=b[522198]|0}else{if(!aX){aW=c[348394]|0;aU=b[522198]|0;if((aW|0)!=(aU<<16>>16|0)){aZ=aW;a_=aU;break}}c[348398]=1;break L13876}}while(0);if((aZ|0)!=(a_<<16>>16|0)){break}c[348398]=1}}while(0);c[348392]=(c[348392]|0)+40;L13888:do{if((aV|0)==(aY|0)){a_=(a[1044392]|0)==0;do{if((a[1044391]|0)==0){if(a_){break L13888}a$=c[348394]|0;a0=b[522198]|0}else{if(!a_){aZ=c[348394]|0;aX=b[522198]|0;if((aZ|0)!=(aX<<16>>16|0)){a$=aZ;a0=aX;break}}a[1393588]=a[1393588]|2;c[348398]=c[199754];c[348395]=c[348395]|2048;if((a[1393628]|0)==0){break L13888}a[1393628]=0;b[520836]=(b[520836]|0)+1&65535;break L13888}}while(0);if((a$|0)!=(a0<<16>>16|0)){break}a[1393588]=a[1393588]|2;c[348398]=c[199754];c[348395]=c[348395]|2048;if((a[1393628]|0)==0){break}a[1393628]=0;b[520836]=(b[520836]|0)+1&65535}}while(0);a0=c[199744]|0;a$=(aV|0)>(c[348406]|0)&(aV|0)<(a0|0);c[348406]=a$?aV:a0;a[1393620]=a$?12:1;return};default:{return}}}function j2(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;e=c[1069188+((d>>>12&4095)<<2)>>2]|0;do{if((d&4227072|0)==0){if((d+24576&16384|0)!=0){f=8;break}f=(d+16384&32256|0)==0?12:6}else{f=(d&8388608|0)==0?8:c[348401]|0}}while(0);if(e>>>0>=19){a[e+(d&65535)|0]=b;if((a[1393610]|0)!=0){return}g=(c[348392]|0)+f|0;c[348392]=g;if((g|0)<(c[348406]|0)){return}do{j1();}while((c[348392]|0)>=(c[348406]|0));return}switch(e|0){case 3:{e=c[261136]|0;if((e|0)!=0){a[(c[261140]|0)+(e&(d>>>1&8355840|d&32767))|0]=b}if((a[1393610]|0)!=0){return}e=(c[348392]|0)+f|0;c[348392]=e;if((e|0)<(c[348406]|0)){return}do{j1();}while((c[348392]|0)>=(c[348406]|0));return};case 2:{e=c[274485]|0;if((e|0)!=0){a[(c[263193]|0)+(e&(d>>>1&8355840|d&32767))|0]=b}if((a[1393610]|0)!=0){return}e=(c[348392]|0)+f|0;c[348392]=e;if((e|0)<(c[348406]|0)){return}do{j1();}while((c[348392]|0)>=(c[348406]|0));return};case 1:{do{if((a[1393610]|0)!=0){if((d&65280|0)!=8448){break}return}}while(0);HB(b,d&65535);if((a[1393610]|0)!=0){return}e=(c[348392]|0)+f|0;c[348392]=e;if((e|0)<(c[348406]|0)){return}do{j1();}while((c[348392]|0)>=(c[348406]|0));return};case 4:{e=c[274485]|0;if((e|0)!=0){a[(c[263193]|0)+(e&(d&32767)-24576+(d>>>3&122880))|0]=b}if((a[1393610]|0)!=0){return}e=(c[348392]|0)+f|0;c[348392]=e;if((e|0)<(c[348406]|0)){return}do{j1();}while((c[348392]|0)>=(c[348406]|0));return};case 0:{HH(b,d&65535);if((a[1393610]|0)!=0){return}e=(c[348392]|0)+f|0;c[348392]=e;if((e|0)<(c[348406]|0)){return}do{j1();}while((c[348392]|0)>=(c[348406]|0));return};case 7:{a[(c[263196]|0)+((d&32767)-24576)|0]=b;if((a[1393610]|0)!=0){return}e=(c[348392]|0)+f|0;c[348392]=e;if((e|0)<(c[348406]|0)){return}do{j1();}while((c[348392]|0)>=(c[348406]|0));return};case 6:{a[(c[263193]|0)+(d&65535)|0]=b;if((a[1393610]|0)!=0){return}e=(c[348392]|0)+f|0;c[348392]=e;if((e|0)<(c[348406]|0)){return}do{j1();}while((c[348392]|0)>=(c[348406]|0));return};case 5:{fc[c[201852]&127](b,d&65535);if((a[1393610]|0)!=0){return}e=(c[348392]|0)+f|0;c[348392]=e;if((e|0)<(c[348406]|0)){return}do{j1();}while((c[348392]|0)>=(c[348406]|0));return};case 13:{jQ(b,d&65535);if((a[1393610]|0)!=0){return}e=(c[348392]|0)+f|0;c[348392]=e;if((e|0)<(c[348406]|0)){return}do{j1();}while((c[348392]|0)>=(c[348406]|0));return};case 14:{Hu(b,d&65535);if((a[1393610]|0)!=0){return}e=(c[348392]|0)+f|0;c[348392]=e;if((e|0)<(c[348406]|0)){return}do{j1();}while((c[348392]|0)>=(c[348406]|0));return};case 15:{fc[c[36646]&127](d,b);if((a[1393610]|0)!=0){return}e=(c[348392]|0)+f|0;c[348392]=e;if((e|0)<(c[348406]|0)){return}do{j1();}while((c[348392]|0)>=(c[348406]|0));return};case 16:{TZ(b,d);if((a[1393610]|0)!=0){return}e=(c[348392]|0)+f|0;c[348392]=e;if((e|0)<(c[348406]|0)){return}do{j1();}while((c[348392]|0)>=(c[348406]|0));return};case 17:{jM(b,d);if((a[1393610]|0)!=0){return}d=(c[348392]|0)+f|0;c[348392]=d;if((d|0)<(c[348406]|0)){return}do{j1();}while((c[348392]|0)>=(c[348406]|0));return};default:{if((a[1393610]|0)!=0){return}d=(c[348392]|0)+f|0;c[348392]=d;if((d|0)<(c[348406]|0)){return}do{j1();}while((c[348392]|0)>=(c[348406]|0));return}}}function j3(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=e&4095;if((f&d|0)==(f|0)){if((e|0)==65535){g=(d&65535)+1&65535|d&-65536}else if((e|0)==255){g=((d&255)+1&255|d&65535&-256)&65535|d&-65536}else{g=d+1|0}j2((b&65535)>>>8&255,g);j2(b&255,d);return}g=c[1069188+((d>>>12&4095)<<2)>>2]|0;do{if((d&4227072|0)==0){if((d+24576&16384|0)!=0){h=8;break}h=(d+16384&32256|0)==0?12:6}else{h=(d&8388608|0)==0?8:c[348401]|0}}while(0);if(g>>>0>=19){e=d&65535;a[g+e|0]=b&255;a[g+(e+1)|0]=(b&65535)>>>8&255;if((a[1393610]|0)!=0){return}e=(c[348392]|0)+(h<<1)|0;c[348392]=e;if((e|0)<(c[348406]|0)){return}do{j1();}while((c[348392]|0)>=(c[348406]|0));return}switch(g|0){case 15:{fc[c[36646]&127](d+1|0,(b&65535)>>>8&255);do{if((a[1393610]|0)==0){g=(c[348392]|0)+h|0;c[348392]=g;if((g|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);fc[c[36646]&127](d,b&255);if((a[1393610]|0)!=0){return}g=(c[348392]|0)+h|0;c[348392]=g;if((g|0)<(c[348406]|0)){return}do{j1();}while((c[348392]|0)>=(c[348406]|0));return};case 5:{fc[c[201852]&127]((b&65535)>>>8&255,d+1&65535);do{if((a[1393610]|0)==0){g=(c[348392]|0)+h|0;c[348392]=g;if((g|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);fc[c[201852]&127](b&255,d&65535);if((a[1393610]|0)!=0){return}g=(c[348392]|0)+h|0;c[348392]=g;if((g|0)<(c[348406]|0)){return}do{j1();}while((c[348392]|0)>=(c[348406]|0));return};case 3:{g=c[261136]|0;do{if((g|0)!=0){e=d>>>1&8355840|d&32767;a[(c[261140]|0)+(g&e)|0]=b&255;f=(b&65535)>>>8&255;i=c[261140]|0;if(g>>>0>4094){a[i+((c[261136]&e)+1)|0]=f;break}else{e=d+1|0;a[i+(c[261136]&(e>>>1&8355840|e&32767))|0]=f;break}}}while(0);if((a[1393610]|0)!=0){return}g=(c[348392]|0)+(h<<1)|0;c[348392]=g;if((g|0)<(c[348406]|0)){return}do{j1();}while((c[348392]|0)>=(c[348406]|0));return};case 0:{HH((b&65535)>>>8&255,d+1&65535);do{if((a[1393610]|0)==0){g=(c[348392]|0)+h|0;c[348392]=g;if((g|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);HH(b&255,d&65535);if((a[1393610]|0)!=0){return}g=(c[348392]|0)+h|0;c[348392]=g;if((g|0)<(c[348406]|0)){return}do{j1();}while((c[348392]|0)>=(c[348406]|0));return};case 2:{g=c[274485]|0;do{if((g|0)!=0){f=d>>>1&8355840|d&32767;a[(c[263193]|0)+(g&f)|0]=b&255;e=(b&65535)>>>8&255;i=c[263193]|0;if(g>>>0>4094){a[i+((c[274485]&f)+1)|0]=e;break}else{f=d+1|0;a[i+(c[274485]&(f>>>1&8355840|f&32767))|0]=e;break}}}while(0);if((a[1393610]|0)!=0){return}g=(c[348392]|0)+(h<<1)|0;c[348392]=g;if((g|0)<(c[348406]|0)){return}do{j1();}while((c[348392]|0)>=(c[348406]|0));return};case 16:{TZ((b&65535)>>>8&255,d+1|0);do{if((a[1393610]|0)==0){g=(c[348392]|0)+h|0;c[348392]=g;if((g|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);TZ(b&255,d);if((a[1393610]|0)!=0){return}g=(c[348392]|0)+h|0;c[348392]=g;if((g|0)<(c[348406]|0)){return}do{j1();}while((c[348392]|0)>=(c[348406]|0));return};case 14:{Hu((b&65535)>>>8&255,d+1&65535);do{if((a[1393610]|0)==0){g=(c[348392]|0)+h|0;c[348392]=g;if((g|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);Hu(b&255,d&65535);if((a[1393610]|0)!=0){return}g=(c[348392]|0)+h|0;c[348392]=g;if((g|0)<(c[348406]|0)){return}do{j1();}while((c[348392]|0)>=(c[348406]|0));return};case 4:{g=c[274485]|0;do{if((g|0)!=0){e=(d&32767)-24576+(d>>>3&122880)|0;a[(c[263193]|0)+(g&e)|0]=b&255;f=(b&65535)>>>8&255;i=c[263193]|0;if(g>>>0>4094){a[i+((c[274485]&e)+1)|0]=f;break}else{e=d+1|0;a[i+(c[274485]&(e&32767)-24576+(e>>>3&122880))|0]=f;break}}}while(0);if((a[1393610]|0)!=0){return}g=(c[348392]|0)+(h<<1)|0;c[348392]=g;if((g|0)<(c[348406]|0)){return}do{j1();}while((c[348392]|0)>=(c[348406]|0));return};case 17:{jM((b&65535)>>>8&255,d+1|0);do{if((a[1393610]|0)==0){g=(c[348392]|0)+h|0;c[348392]=g;if((g|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);jM(b&255,d);if((a[1393610]|0)!=0){return}g=(c[348392]|0)+h|0;c[348392]=g;if((g|0)<(c[348406]|0)){return}do{j1();}while((c[348392]|0)>=(c[348406]|0));return};case 13:{jQ((b&65535)>>>8&255,d+1&65535);do{if((a[1393610]|0)==0){g=(c[348392]|0)+h|0;c[348392]=g;if((g|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);jQ(b&255,d&65535);if((a[1393610]|0)!=0){return}g=(c[348392]|0)+h|0;c[348392]=g;if((g|0)<(c[348406]|0)){return}do{j1();}while((c[348392]|0)>=(c[348406]|0));return};case 1:{if((a[1393610]|0)!=0){if((d&65280|0)!=8448){HB(b&255,d&65535)}g=d+1|0;if((g&65280|0)==8448){return}HB((b&65535)>>>8&255,g&65535);return}HB((b&65535)>>>8&255,d+1&65535);do{if((a[1393610]|0)==0){g=(c[348392]|0)+h|0;c[348392]=g;if((g|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);HB(b&255,d&65535);if((a[1393610]|0)!=0){return}g=(c[348392]|0)+h|0;c[348392]=g;if((g|0)<(c[348406]|0)){return}do{j1();}while((c[348392]|0)>=(c[348406]|0));return};case 7:{g=d&32767;a[(c[263196]|0)+(g-24576)|0]=b&255;a[(c[263196]|0)+(g-24575)|0]=(b&65535)>>>8&255;if((a[1393610]|0)!=0){return}g=(c[348392]|0)+(h<<1)|0;c[348392]=g;if((g|0)<(c[348406]|0)){return}do{j1();}while((c[348392]|0)>=(c[348406]|0));return};case 6:{g=d&65535;a[(c[263193]|0)+g|0]=b&255;a[(c[263193]|0)+(g+1)|0]=(b&65535)>>>8&255;if((a[1393610]|0)!=0){return}b=(c[348392]|0)+(h<<1)|0;c[348392]=b;if((b|0)<(c[348406]|0)){return}do{j1();}while((c[348392]|0)>=(c[348406]|0));return};default:{if((a[1393610]|0)!=0){return}b=(c[348392]|0)+(h<<1)|0;c[348392]=b;if((b|0)<(c[348406]|0)){return}do{j1();}while((c[348392]|0)>=(c[348406]|0));return}}}function j4(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=a&16777215;c[260418]=b;d=a&16711680;c[276676]=d;e=c[1052804+(b>>>12<<2)>>2]|0;do{if((a&4227072|0)==0){if((a+24576&16384|0)!=0){f=8;break}f=(a+16384&32256|0)==0?12:6}else{f=(a&8388608|0)==0?8:c[348401]|0}}while(0);c[348399]=f;c[348400]=f<<1;if(e>>>0>=19){c[348396]=e;return}c[348396]=0;if((e|0)==18){return}switch(e|0){case 14:{if(((a&65535)-32752&65535)<7){g=0}else{g=(c[263198]|0)-24576|0}c[348396]=g;return};case 2:{g=c[274485]|0;if((g&4095|0)!=4095){return}c[348396]=(c[263193]|0)+((g&(d>>>1|a&32767))-(a&65535));return};case 17:{c[348396]=c[274488];return};case 13:{if(((a&65535)-32576&65535)<31){h=0}else{h=(c[263197]|0)-24576|0}c[348396]=h;return};case 6:{c[348396]=c[263193];return};case 7:{c[348396]=(c[263196]|0)+(-24576-(a&32768));return};case 4:{h=c[274485]|0;if((h&4095|0)!=4095){return}c[348396]=(c[263193]|0)+((h&(a&32767)-24576+(a>>>3&122880))-(a&65535));return};case 3:{h=c[261136]|0;if((h&4095|0)!=4095){return}c[348396]=(c[261140]|0)+((h&(d>>>1|a&32767))-(a&65535));return};case 10:{d=a&15728640;if((d|0)==14680064){i=c[198894]|0}else if((d|0)==15728640){i=c[198890]|0}else if((d|0)==13631488){i=c[198898]|0}else{i=0}c[348396]=(c[263192]|0)+(i+(a&983040));return};default:{return}}}function j5(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;f=(e|0)==255?255:4095;if((f&b|0)==(f|0)){f=j0(b)|0;a[1044496]=f;if((e|0)==255){g=((j0(((b&255)+1&255|b&65535&-256)&65535|b&-65536)|0)&255)<<8|f&255;return g|0}else if((e|0)==65535){g=((j0((b&65535)+1&65535|b&-65536)|0)&255)<<8|f&255;return g|0}else{g=((j0(b+1|0)|0)&255)<<8|f&255;return g|0}}f=c[1052804+((b>>>12&4095)<<2)>>2]|0;do{if((b&4227072|0)==0){if((b+24576&16384|0)!=0){h=8;break}h=(b+16384&32256|0)==0?12:6}else{h=(b&8388608|0)==0?8:c[348401]|0}}while(0);if(f>>>0>=19){e=b&65535;i=d[f+(e+1)|0]<<8|d[f+e|0];if((a[1393610]|0)!=0){g=i;return g|0}e=(c[348392]|0)+(h<<1)|0;c[348392]=e;if((e|0)<(c[348406]|0)){g=i;return g|0}while(1){j1();if((c[348392]|0)<(c[348406]|0)){g=i;break}}return g|0}switch(f|0){case 17:{f=b&65535;i=b>>>16&255;do{if((i|0)!=0&i>>>0<15){if((b&65535|0)!=20480){j=10497;break}k=a[1394341+i|0]|0}else{j=10497}}while(0);do{if((j|0)==10497){if((i|0)!=192){k=0;break}e=b&65535;do{if((a[1394343]|0)==0){if(f<<16>>16>-1){l=(c[274488]|0)+e|0;break}else{l=(c[274488]|0)+(e-32768)|0;break}}else{l=(c[274488]|0)+e|0}}while(0);m=a[l]|0;if((e|0)==65280|(e|0)==65282|(e|0)==65284|(e|0)==65286|(e|0)==65288|(e|0)==65290|(e|0)==65292|(e|0)==65294|(e|0)==65296|(e|0)==65298){if((a[1394261]|0)==0){k=m;break}k=a[15064+(e-65280)|0]|0;break}else if((e|0)==2){k=(a[1394259]|0)==0?m:-128;break}else if((e|0)==21845){k=(a[1394259]|0)==0?m:-128;break}else{k=m;break}}}while(0);do{if((a[1393610]|0)==0){l=(c[348392]|0)+h|0;c[348392]=l;if((l|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);e=b+1|0;l=e&65535;f=e>>>16&255;do{if((f|0)!=0&f>>>0<15){if((e&65535|0)!=20480){j=10514;break}n=a[1394341+f|0]|0}else{j=10514}}while(0);do{if((j|0)==10514){if((f|0)!=192){n=0;break}i=e&65535;do{if((a[1394343]|0)==0){if(l<<16>>16>-1){o=(c[274488]|0)+i|0;break}else{o=(c[274488]|0)+(i-32768)|0;break}}else{o=(c[274488]|0)+i|0}}while(0);m=a[o]|0;if((i|0)==2){n=(a[1394259]|0)==0?m:-128;break}else if((i|0)==21845){n=(a[1394259]|0)==0?m:-128;break}else if((i|0)==65280|(i|0)==65282|(i|0)==65284|(i|0)==65286|(i|0)==65288|(i|0)==65290|(i|0)==65292|(i|0)==65294|(i|0)==65296|(i|0)==65298){if((a[1394261]|0)==0){n=m;break}n=a[15064+(i-65280)|0]|0;break}else{n=m;break}}}while(0);o=(n&255)<<8|k&255;if((a[1393610]|0)!=0){g=o;return g|0}k=(c[348392]|0)+h|0;c[348392]=k;if((k|0)<(c[348406]|0)){g=o;return g|0}while(1){j1();if((c[348392]|0)<(c[348406]|0)){g=o;break}}return g|0};case 5:{o=fe[c[276698]&127](b&65535)|0;do{if((a[1393610]|0)==0){k=(c[348392]|0)+h|0;c[348392]=k;if((k|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);i=((fe[c[276698]&127](b+1&65535)|0)&255)<<8|o&255;if((a[1393610]|0)!=0){g=i;return g|0}o=(c[348392]|0)+h|0;c[348392]=o;if((o|0)<(c[348406]|0)){g=i;return g|0}while(1){j1();if((c[348392]|0)<(c[348406]|0)){g=i;break}}return g|0};case 16:{do{if((b&65535|0)==14340){i=c[201864]|0;if((i|0)==0){p=-127;break}o=c[201862]|0;k=a[807496+o|0]|0;n=o+1|0;c[201862]=n;if((i|0)!=(n|0)){p=k;break}c[201864]=0;p=k}else{p=0}}while(0);do{if((a[1393610]|0)==0){k=(c[348392]|0)+h|0;c[348392]=k;if((k|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);do{if((b+1&65535|0)==14340){k=c[201864]|0;if((k|0)==0){q=-127;break}n=c[201862]|0;i=a[807496+n|0]|0;o=n+1|0;c[201862]=o;if((k|0)!=(o|0)){q=i;break}c[201864]=0;q=i}else{q=0}}while(0);i=(q&255)<<8|p&255;if((a[1393610]|0)!=0){g=i;return g|0}p=(c[348392]|0)+h|0;c[348392]=p;if((p|0)<(c[348406]|0)){g=i;return g|0}while(1){j1();if((c[348392]|0)<(c[348406]|0)){g=i;break}}return g|0};case 0:{i=HJ(b&65535)|0;do{if((a[1393610]|0)==0){p=(c[348392]|0)+h|0;c[348392]=p;if((p|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);p=((HJ(b+1&65535)|0)&255)<<8|i&255;if((a[1393610]|0)!=0){g=p;return g|0}i=(c[348392]|0)+h|0;c[348392]=i;if((i|0)<(c[348406]|0)){g=p;return g|0}while(1){j1();if((c[348392]|0)<(c[348406]|0)){g=p;break}}return g|0};case 7:{p=c[263196]|0;i=b&32767;q=d[p+(i-24575)|0]<<8|d[p+(i-24576)|0];if((a[1393610]|0)!=0){g=q;return g|0}i=(c[348392]|0)+(h<<1)|0;c[348392]=i;if((i|0)<(c[348406]|0)){g=q;return g|0}while(1){j1();if((c[348392]|0)<(c[348406]|0)){g=q;break}}return g|0};case 3:{q=c[261136]|0;i=c[261140]|0;p=q&(b>>>1&8355840|b&32767);if(q>>>0>4094){r=p+1|0}else{o=b+1|0;r=q&(o>>>1&8355840|o&32767)}o=d[i+r|0]<<8|d[i+p|0];if((a[1393610]|0)!=0){g=o;return g|0}p=(c[348392]|0)+(h<<1)|0;c[348392]=p;if((p|0)<(c[348406]|0)){g=o;return g|0}while(1){j1();if((c[348392]|0)<(c[348406]|0)){g=o;break}}return g|0};case 1:{if((a[1393610]|0)!=0){o=j0(b)|0;a[1044496]=o;g=((j0(b+1|0)|0)&255)<<8|o&255;return g|0}o=HG(b&65535)|0;do{if((a[1393610]|0)==0){p=(c[348392]|0)+h|0;c[348392]=p;if((p|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);p=((HG(b+1&65535)|0)&255)<<8|o&255;if((a[1393610]|0)!=0){g=p;return g|0}o=(c[348392]|0)+h|0;c[348392]=o;if((o|0)<(c[348406]|0)){g=p;return g|0}while(1){j1();if((c[348392]|0)<(c[348406]|0)){g=p;break}}return g|0};case 10:{p=b&15728640;if((p|0)==15728640){s=c[198890]|0}else if((p|0)==14680064){s=c[198894]|0}else if((p|0)==13631488){s=c[198898]|0}else{s=0}p=a[(c[263192]|0)+(s+(b&1048575))|0]|0;do{if((a[1393610]|0)==0){s=(c[348392]|0)+h|0;c[348392]=s;if((s|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);s=b+1|0;o=s&15728640;if((o|0)==14680064){t=c[198894]|0}else if((o|0)==13631488){t=c[198898]|0}else if((o|0)==15728640){t=c[198890]|0}else{t=0}o=d[(c[263192]|0)+(t+(s&1048575))|0]<<8|p&255;if((a[1393610]|0)!=0){g=o;return g|0}p=(c[348392]|0)+h|0;c[348392]=p;if((p|0)<(c[348406]|0)){g=o;return g|0}while(1){j1();if((c[348392]|0)<(c[348406]|0)){g=o;break}}return g|0};case 2:case 6:{o=c[274485]|0;p=c[263193]|0;s=o&(b>>>1&8355840|b&32767);if(o>>>0>4094){u=s+1|0}else{t=b+1|0;u=o&(t>>>1&8355840|t&32767)}t=d[p+u|0]<<8|d[p+s|0];if((a[1393610]|0)!=0){g=t;return g|0}s=(c[348392]|0)+(h<<1)|0;c[348392]=s;if((s|0)<(c[348406]|0)){g=t;return g|0}while(1){j1();if((c[348392]|0)<(c[348406]|0)){g=t;break}}return g|0};case 15:{t=fe[c[40480]&127](b)|0;do{if((a[1393610]|0)==0){s=(c[348392]|0)+h|0;c[348392]=s;if((s|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);s=((fe[c[40480]&127](b+1|0)|0)&255)<<8|t&255;if((a[1393610]|0)!=0){g=s;return g|0}t=(c[348392]|0)+h|0;c[348392]=t;if((t|0)<(c[348406]|0)){g=s;return g|0}while(1){j1();if((c[348392]|0)<(c[348406]|0)){g=s;break}}return g|0};case 4:case 12:{s=c[274485]|0;t=c[263193]|0;p=s&(b&32767)-24576+(b>>>3&122880);if(s>>>0>4094){v=p+1|0}else{u=b+1|0;v=s&(u&32767)-24576+(u>>>3&122880)}u=d[t+v|0]<<8|d[t+p|0];if((a[1393610]|0)!=0){g=u;return g|0}p=(c[348392]|0)+(h<<1)|0;c[348392]=p;if((p|0)<(c[348406]|0)){g=u;return g|0}while(1){j1();if((c[348392]|0)<(c[348406]|0)){g=u;break}}return g|0};case 14:{u=Ht(b&65535)|0;p=a[1393610]|0;do{if(p<<24>>24==0){t=(c[348392]|0)+h|0;c[348392]=t;if((t|0)<(c[348406]|0)){w=0;break}do{j1();}while((c[348392]|0)>=(c[348406]|0));w=a[1393610]|0}else{w=p}}while(0);p=((Ht(b+1&65535)|0)&255)<<8|u&255;if(w<<24>>24!=0){g=p;return g|0}w=(c[348392]|0)+h|0;c[348392]=w;if((w|0)<(c[348406]|0)){g=p;return g|0}while(1){j1();if((c[348392]|0)<(c[348406]|0)){g=p;break}}return g|0};case 11:{p=Ua(18432)|0;do{if((a[1393610]|0)==0){w=(c[348392]|0)+h|0;c[348392]=w;if((w|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);w=((Ua(18432)|0)&255)<<8|p&255;if((a[1393610]|0)!=0){g=w;return g|0}p=(c[348392]|0)+h|0;c[348392]=p;if((p|0)<(c[348406]|0)){g=w;return g|0}while(1){j1();if((c[348392]|0)<(c[348406]|0)){g=w;break}}return g|0};case 13:{if((b&65535)<<16>>16==32606){x=0}else{x=d[(c[263197]|0)+((b&65535)-24576)|0]|0}do{if((a[1393610]|0)==0){w=(c[348392]|0)+h|0;c[348392]=w;if((w|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);w=b+1|0;if((w&65535)<<16>>16==32606){y=0}else{y=d[(c[263197]|0)+((w&65535)-24576)|0]<<8}w=y|x;if((a[1393610]|0)!=0){g=w;return g|0}x=(c[348392]|0)+h|0;c[348392]=x;if((x|0)<(c[348406]|0)){g=w;return g|0}while(1){j1();if((c[348392]|0)<(c[348406]|0)){g=w;break}}return g|0};default:{w=d[1044496]|0;x=(w<<8|w)&65535;if((a[1393610]|0)!=0){g=x;return g|0}w=(c[348392]|0)+(h<<1)|0;c[348392]=w;if((w|0)<(c[348406]|0)){g=x;return g|0}while(1){j1();if((c[348392]|0)<(c[348406]|0)){g=x;break}}return g|0}}return 0}function j6(){var d=0,f=0,g=0,h=0,i=0,j=0;d=(c[348392]|0)+(c[348399]|0)|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}if((b[520829]&256)==0){d=a[1041674|0]|0;f=b[520832]|0;b[520832]=f-1&65535;j2(d,f&65535);j3((b[520836]|0)+1&65535,(e[520832]|0)-1|0,65535);f=b[520832]|0;d=a[1041658]&60|a[1106736]|a[1106720]&-128|((a[1106728]|0)==0)<<1|a[1106712]<<6;a[1041658]=d;b[520832]=f-3&65535;j2(d,f-2&65535);f=a[1041658]|0;a[1044496]=f;a[1041658]=f&-13|4;g=j5(65510,16777215)|0;h=g&65535;j4(h);i=(g&65535)>>>8;j=i&255;a[1044496]=j;return}else{a[1041664]=(a[1041664]|0)-1&255;j3((b[520836]|0)+1&65535,e[520832]|0,255);a[1041664]=(a[1041664]|0)-1&255;f=a[1041658]&60|a[1106736]|a[1106720]&-128|((a[1106728]|0)==0)<<1|a[1106712]<<6;a[1041658]=f;j2(f,e[520832]|0);a[1041664]=(a[1041664]|0)-1&255;f=a[1041658]|0;a[1044496]=f;a[1041658]=f&-13|4;g=j5(65534,16777215)|0;h=g&65535;j4(h);i=(g&65535)>>>8;j=i&255;a[1044496]=j;return}}function j7(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=b[520836]|0;f=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=f;g=(c[348392]|0)+(c[348399]|0)|0;c[348392]=g;h=c[348406]|0;if((g|0)<(h|0)){i=d;j=g;k=h}else{do{j1();l=c[348392]|0;m=c[348406]|0;}while((l|0)>=(m|0));i=b[520836]|0;j=l;k=m}b[520836]=i+1&65535;i=b[520831]|0;m=i+(f&255)&65535;do{if((i&255)<<24>>24==0){n=j;o=k}else{f=j+6|0;c[348392]=f;if((f|0)<(k|0)){n=f;o=k;break}while(1){j1();f=c[348392]|0;l=c[348406]|0;if((f|0)<(l|0)){n=f;o=l;break}}}}while(0);k=(e[520833]|0)+(m&65535)|0;m=n+6|0;c[348392]=m;if((m|0)>=(o|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}o=j5(k&65535,16777215)|0;a[1044496]=(o&65535)>>>8&255;k=j0(c[276674]|o&65535)|0;a[1044496]=k;o=a[1041660]|k;a[1041660]=o;a[1106728]=o;a[1106720]=o;return}function j8(){var d=0,f=0,g=0,h=0,i=0,j=0;d=(c[348392]|0)+(c[348399]|0)|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}if((b[520829]&256)==0){d=a[1041674|0]|0;f=b[520832]|0;b[520832]=f-1&65535;j2(d,f&65535);j3((b[520836]|0)+1&65535,(e[520832]|0)-1|0,65535);f=b[520832]|0;d=a[1041658]&60|a[1106736]|a[1106720]&-128|((a[1106728]|0)==0)<<1|a[1106712]<<6;a[1041658]=d;b[520832]=f-3&65535;j2(d,f-2&65535);f=a[1041658]|0;a[1044496]=f;a[1041658]=f&-13|4;g=j5(65508,16777215)|0;h=g&65535;j4(h);i=(g&65535)>>>8;j=i&255;a[1044496]=j;return}else{a[1041664]=(a[1041664]|0)-1&255;j3((b[520836]|0)+1&65535,e[520832]|0,255);a[1041664]=(a[1041664]|0)-1&255;f=a[1041658]&60|a[1106736]|a[1106720]&-128|((a[1106728]|0)==0)<<1|a[1106712]<<6;a[1041658]=f;j2(f,e[520832]|0);a[1041664]=(a[1041664]|0)-1&255;f=a[1041658]|0;a[1044496]=f;a[1041658]=f&-13|4;g=j5(65524,16777215)|0;h=g&65535;j4(h);i=(g&65535)>>>8;j=i&255;a[1044496]=j;return}}function j9(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}b[520836]=h+1&65535;h=(b[520832]|0)+(e&255)&65535;e=i+6|0;c[348392]=e;if((e|0)<(j|0)){m=h&65535;n=j0(m)|0;a[1044496]=n;o=a[1041660]|0;p=o|n;a[1041660]=p;a[1106728]=p;a[1106720]=p;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));m=h&65535;n=j0(m)|0;a[1044496]=n;o=a[1041660]|0;p=o|n;a[1041660]=p;a[1106728]=p;a[1106720]=p;return}function ka(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}b[520836]=h+1&65535;h=b[520831]|0;l=h+(e&255)&65535;do{if((h&255)<<24>>24!=0){e=i+6|0;c[348392]=e;if((e|0)<(j|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j=l&65535;l=j0(j)|0;i=a[1041660]|0;a[1106728]=i&l;h=i|l;l=(c[348392]|0)+6|0;c[348392]=l;if((l|0)<(c[348406]|0)){j2(h,j);a[1044496]=h;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));j2(h,j);a[1044496]=h;return}function kb(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}b[520836]=h+1&65535;h=b[520831]|0;l=h+(e&255)&65535;do{if((h&255)<<24>>24!=0){e=i+6|0;c[348392]=e;if((e|0)<(j|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j=j0(l&65535)|0;a[1044496]=j;l=a[1041660]|j;a[1041660]=l;a[1106728]=l;a[1106720]=l;return}function kc(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}b[520836]=h+1&65535;h=b[520831]|0;l=h+(e&255)&65535;do{if((h&255)<<24>>24!=0){e=i+6|0;c[348392]=e;if((e|0)<(j|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j=l&65535;l=j0(j)|0;a[1106736]=(l&255)>>>7;i=l<<1;l=(c[348392]|0)+6|0;c[348392]=l;if((l|0)<(c[348406]|0)){j2(i,j);a[1044496]=i;a[1106728]=i;a[1106720]=i;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));j2(i,j);a[1044496]=i;a[1106728]=i;a[1106720]=i;return}function kd(){var b=0,c=0;b=j0(xb()|0)|0;a[1044496]=b;c=a[1041660]|b;a[1041660]=c;a[1106728]=c;a[1106720]=c;return}function ke(){var d=0,e=0,f=0;d=a[1041658]&60|a[1106736]|a[1106720]&-128|((a[1106728]|0)==0)<<1|a[1106712]<<6;a[1041658]=d;e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)<(c[348406]|0)){f=d}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));f=a[1041658]|0}d=b[520832]|0;b[520832]=d-1&65535;j2(f,d&65535);a[1044496]=a[1041658]|0;return}function kf(){var d=0,e=0,f=0,g=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;if((f|0)<(c[348406]|0)){g=d}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));g=b[520836]|0}b[520836]=g+1&65535;g=a[1041660]|e;a[1041660]=g;a[1106728]=g;a[1106720]=g;return}function kg(){var b=0,d=0;b=(c[348392]|0)+6|0;c[348392]=b;if((b|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}b=a[1041660]|0;a[1106736]=(b&255)>>>7;d=b<<1;a[1041660]=d;a[1106728]=d;a[1106720]=d;return}function kh(){var d=0;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}j3(b[520831]|0,(e[520832]|0)-1|0,65535);b[520832]=(b[520832]|0)-2&65535;a[1044496]=a[1041662]|0;return}function ki(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=c[276674]|0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[1044496]=i;i=(c[348392]|0)+(c[348400]|0)|0;c[348392]=i;if((i|0)<(c[348406]|0)){k=g}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));k=b[520836]|0}b[520836]=k+2&65535;k=j&65535|e;e=j0(k)|0;j=a[1041660]|0;a[1106728]=j&e;g=j|e;e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)<(c[348406]|0)){j2(g,k);a[1044496]=g;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));j2(g,k);a[1044496]=g;return}function kj(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=c[276674]|0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[1044496]=i;i=(c[348392]|0)+(c[348400]|0)|0;c[348392]=i;if((i|0)<(c[348406]|0)){k=g}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));k=b[520836]|0}b[520836]=k+2&65535;k=j0(j&65535|e)|0;a[1044496]=k;e=a[1041660]|k;a[1041660]=e;a[1106728]=e;a[1106720]=e;return}function kk(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=c[276674]|0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[1044496]=i;i=(c[348392]|0)+(c[348400]|0)|0;c[348392]=i;if((i|0)<(c[348406]|0)){k=g}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));k=b[520836]|0}b[520836]=k+2&65535;k=j&65535|e;e=j0(k)|0;a[1106736]=(e&255)>>>7;j=e<<1;e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)<(c[348406]|0)){j2(j,k);a[1044496]=j;a[1106728]=j;a[1106720]=j;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));j2(j,k);a[1044496]=j;a[1106728]=j;a[1106720]=j;return}function kl(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[348396]|0;f=b[520836]|0;g=f&65535;h=a[e+(g+2)|0]|0;i=(d[e+(g+1)|0]|0)<<8|(d[e+g|0]|0)|(h&255)<<16;g=(c[348399]|0)+(c[348400]|0)+(c[348392]|0)|0;c[348392]=g;if((g|0)<(c[348406]|0)){j=f}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));j=b[520836]|0}a[1044496]=h;b[520836]=j+3&65535;j=j0(i)|0;a[1044496]=j;i=a[1041660]|j;a[1041660]=i;a[1106728]=i;a[1106720]=i;return}function km(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}l=h+1&65535;b[520836]=l;h=(l&65535)+(e<<24>>24)|0;e=h&65535;k=h&65535;if((a[1106720]|0)<0){return}g=i+6|0;c[348392]=g;if((g|0)<(j|0)){m=l}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));m=b[520836]|0}if(((m&65535^h)&61440|0)==0){b[520836]=k;return}else{j4((c[276676]|0)+e|0);return}}function kn(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=b[520836]|0;g=a[(c[348396]|0)+(f&65535)|0]|0;a[1044496]=g;h=(c[348392]|0)+(c[348399]|0)|0;c[348392]=h;i=c[348406]|0;if((h|0)<(i|0)){j=f;k=h;l=i}else{do{j1();m=c[348392]|0;n=c[348406]|0;}while((m|0)>=(n|0));j=b[520836]|0;k=m;l=n}b[520836]=j+1&65535;j=b[520831]|0;n=j+(g&255)&65535;do{if((j&255)<<24>>24!=0){g=k+6|0;c[348392]=g;if((g|0)<(l|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);l=j5(n&65535,16777215)|0;a[1044496]=(l&65535)>>>8&255;n=c[276674]|l&65535;do{if(((d[1041668]|0)+(n&255)|0)>>>0>255){l=(c[348392]|0)+6|0;c[348392]=l;if((l|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);l=j0((e[520834]|0)+n|0)|0;a[1044496]=l;n=a[1041660]|l;a[1041660]=n;a[1106728]=n;a[1106720]=n;return}function ko(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}b[520836]=h+1&65535;h=b[520831]|0;l=h+(e&255)&65535;do{if((h&255)<<24>>24!=0){e=i+6|0;c[348392]=e;if((e|0)<(j|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j=j5(l&65535,16777215)|0;a[1044496]=(j&65535)>>>8&255;l=j0(c[276674]|j&65535)|0;a[1044496]=l;j=a[1041660]|l;a[1041660]=j;a[1106728]=j;a[1106720]=j;return}function kp(){var d=0,f=0,g=0,h=0,i=0;d=j0(c[260418]|0)|0;a[1044496]=d;b[520836]=(b[520836]|0)+1&65535;f=(b[520832]|0)+(d&255)&65535;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}d=j5(f&65535,16777215)|0;a[1044496]=(d&65535)>>>8&255;f=(e[520834]|0)+(d&65535)+(c[276674]|0)&16777215;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)<(c[348406]|0)){g=j0(f)|0;a[1044496]=g;h=a[1041660]|0;i=h|g;a[1041660]=i;a[1106728]=i;a[1106720]=i;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));g=j0(f)|0;a[1044496]=g;h=a[1041660]|0;i=h|g;a[1041660]=i;a[1106728]=i;a[1106720]=i;return}function kq(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}b[520836]=h+1&65535;h=b[520831]|0;l=h+(e&255)&65535;do{if((h&255)<<24>>24!=0){e=i+6|0;c[348392]=e;if((e|0)<(j|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j=l&65535;l=j0(j)|0;i=a[1041660]|0;a[1106728]=i&l;h=l&~i;i=(c[348392]|0)+6|0;c[348392]=i;if((i|0)<(c[348406]|0)){j2(h,j);a[1044496]=h;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));j2(h,j);a[1044496]=h;return}function kr(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=b[520836]|0;f=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=f;g=(c[348392]|0)+(c[348399]|0)|0;c[348392]=g;h=c[348406]|0;if((g|0)<(h|0)){i=d;j=g;k=h}else{do{j1();l=c[348392]|0;m=c[348406]|0;}while((l|0)>=(m|0));i=b[520836]|0;j=l;k=m}b[520836]=i+1&65535;i=b[520831]|0;m=i+(f&255)&65535;do{if((i&255)<<24>>24==0){n=j;o=k}else{f=j+6|0;c[348392]=f;if((f|0)<(k|0)){n=f;o=k;break}while(1){j1();f=c[348392]|0;l=c[348406]|0;if((f|0)<(l|0)){n=f;o=l;break}}}}while(0);k=(e[520833]|0)+(m&65535)|0;m=n+6|0;c[348392]=m;if((m|0)<(o|0)){p=k&65535;q=j0(p)|0;a[1044496]=q;r=a[1041660]|0;s=r|q;a[1041660]=s;a[1106728]=s;a[1106720]=s;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));p=k&65535;q=j0(p)|0;a[1044496]=q;r=a[1041660]|0;s=r|q;a[1041660]=s;a[1106728]=s;a[1106720]=s;return}function ks(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=b[520836]|0;f=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=f;g=(c[348392]|0)+(c[348399]|0)|0;c[348392]=g;h=c[348406]|0;if((g|0)<(h|0)){i=d;j=g;k=h}else{do{j1();l=c[348392]|0;m=c[348406]|0;}while((l|0)>=(m|0));i=b[520836]|0;j=l;k=m}b[520836]=i+1&65535;i=b[520831]|0;m=i+(f&255)&65535;do{if((i&255)<<24>>24==0){n=j;o=k}else{f=j+6|0;c[348392]=f;if((f|0)<(k|0)){n=f;o=k;break}while(1){j1();f=c[348392]|0;l=c[348406]|0;if((f|0)<(l|0)){n=f;o=l;break}}}}while(0);k=(e[520833]|0)+(m&65535)|0;m=n+6|0;c[348392]=m;if((m|0)>=(o|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}o=k&65535;k=j0(o)|0;a[1106736]=(k&255)>>>7;m=k<<1;k=(c[348392]|0)+6|0;c[348392]=k;if((k|0)<(c[348406]|0)){j2(m,o);a[1044496]=m;a[1106728]=m;a[1106720]=m;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));j2(m,o);a[1044496]=m;a[1106728]=m;a[1106720]=m;return}function kt(){var b=0,c=0;b=xb()|0;c=j0((e[520834]|0)+b|0)|0;a[1044496]=c;b=a[1041660]|c;a[1041660]=b;a[1106728]=b;a[1106720]=b;return}function ku(){var b=0;a[1106736]=0;b=(c[348392]|0)+6|0;c[348392]=b;if((b|0)<(c[348406]|0)){return}do{j1();}while((c[348392]|0)>=(c[348406]|0));return}function kv(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;do{if(((d[1041668]|0)+(l&255)|0)>>>0>255){f=m+6|0;c[348392]=f;if((f|0)<(n|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);n=j0((e[520834]|0)+l|0)|0;a[1044496]=n;l=a[1041660]|n;a[1041660]=l;a[1106728]=l;a[1106720]=l;return}function kw(){var b=0;b=(c[348392]|0)+6|0;c[348392]=b;if((b|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}b=(a[1041660]|0)+1&255;a[1041660]=b;a[1106728]=b;a[1106720]=b;return}function kx(){var d=0;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}b[520832]=b[520830]|0;if((b[520829]&256)==0){return}a[1041665|0]=1;return}function ky(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=c[276674]|0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[1044496]=i;i=(c[348392]|0)+(c[348400]|0)|0;c[348392]=i;if((i|0)<(c[348406]|0)){k=g}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));k=b[520836]|0}b[520836]=k+2&65535;k=j&65535|e;e=j0(k)|0;j=a[1041660]|0;a[1106728]=j&e;g=e&~j;j=(c[348392]|0)+6|0;c[348392]=j;if((j|0)<(c[348406]|0)){j2(g,k);a[1044496]=g;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));j2(g,k);a[1044496]=g;return}function kz(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;do{if(((d[1041666]|0)+(l&255)|0)>>>0>255){f=m+6|0;c[348392]=f;if((f|0)<(n|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);n=j0((e[520833]|0)+l|0)|0;a[1044496]=n;l=a[1041660]|n;a[1041660]=l;a[1106728]=l;a[1106720]=l;return}function kA(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;f=m+6|0;c[348392]=f;if((f|0)>=(n|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}n=(e[520833]|0)+l|0;l=j0(n)|0;a[1106736]=(l&255)>>>7;f=l<<1;l=(c[348392]|0)+6|0;c[348392]=l;if((l|0)<(c[348406]|0)){j2(f,n);a[1044496]=f;a[1106728]=f;a[1106720]=f;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));j2(f,n);a[1044496]=f;a[1106728]=f;a[1106720]=f;return}function kB(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=a[f+(h+2)|0]|0;j=(d[f+(h+1)|0]|0)<<8|(d[f+h|0]|0)|(i&255)<<16;h=(c[348399]|0)+(c[348400]|0)+(c[348392]|0)|0;c[348392]=h;if((h|0)<(c[348406]|0)){k=g}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));k=b[520836]|0}a[1044496]=i;b[520836]=k+3&65535;k=j0((e[520833]|0)+j|0)|0;a[1044496]=k;j=a[1041660]|k;a[1041660]=j;a[1106728]=j;a[1106720]=j;return}function kC(){var a=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;a=c[276674]|0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=(d[f+(h+1)|0]|0)<<8|(d[f+h|0]|0);h=(c[348392]|0)+(c[348400]|0)|0;c[348392]=h;f=c[348406]|0;if((h|0)<(f|0)){j=g;k=h;l=f}else{do{j1();m=c[348392]|0;n=c[348406]|0;}while((m|0)>=(n|0));j=b[520836]|0;k=m;l=n}n=j+2&65535;b[520836]=n;j=i&65535;i=k+6|0;c[348392]=i;if((i|0)<(l|0)){o=n}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));o=b[520836]|0}j3(o-1&65535,(e[520832]|0)-1|0,65535);b[520832]=(b[520832]|0)-2&65535;j4((c[276676]|0)+(j|a&65535)|0);return}function kD(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=b[520836]|0;f=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=f;g=(c[348392]|0)+(c[348399]|0)|0;c[348392]=g;h=c[348406]|0;if((g|0)<(h|0)){i=d;j=g;k=h}else{do{j1();l=c[348392]|0;m=c[348406]|0;}while((l|0)>=(m|0));i=b[520836]|0;j=l;k=m}b[520836]=i+1&65535;i=b[520831]|0;m=i+(f&255)&65535;do{if((i&255)<<24>>24==0){n=j;o=k}else{f=j+6|0;c[348392]=f;if((f|0)<(k|0)){n=f;o=k;break}while(1){j1();f=c[348392]|0;l=c[348406]|0;if((f|0)<(l|0)){n=f;o=l;break}}}}while(0);k=(e[520833]|0)+(m&65535)|0;m=n+6|0;c[348392]=m;if((m|0)>=(o|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}o=j5(k&65535,16777215)|0;a[1044496]=(o&65535)>>>8&255;k=j0(c[276674]|o&65535)|0;a[1044496]=k;o=a[1041660]&k;a[1041660]=o;a[1106728]=o;a[1106720]=o;return}function kE(){var f=0,g=0,h=0,i=0,j=0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=(d[f+(h+1)|0]|0)<<8|(d[f+h|0]|0)|(d[f+(h+2)|0]|0)<<16;h=(c[348399]|0)+(c[348400]|0)+(c[348392]|0)|0;c[348392]=h;if((h|0)<(c[348406]|0)){j=g}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));j=b[520836]|0}b[520836]=j+3&65535;j=a[1041674|0]|0;g=b[520832]|0;b[520832]=g-1&65535;j2(j,g&65535);j3((b[520836]|0)-1&65535,(e[520832]|0)-1|0,65535);b[520832]=(b[520832]|0)-2&65535;j4(i);return}function kF(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}b[520836]=h+1&65535;h=(b[520832]|0)+(e&255)&65535;e=i+6|0;c[348392]=e;if((e|0)<(j|0)){m=h&65535;n=j0(m)|0;a[1044496]=n;o=a[1041660]|0;p=o&n;a[1041660]=p;a[1106728]=p;a[1106720]=p;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));m=h&65535;n=j0(m)|0;a[1044496]=n;o=a[1041660]|0;p=o&n;a[1041660]=p;a[1106728]=p;a[1106720]=p;return}function kG(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}b[520836]=h+1&65535;h=b[520831]|0;l=h+(e&255)&65535;do{if((h&255)<<24>>24!=0){e=i+6|0;c[348392]=e;if((e|0)<(j|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j=j0(l&65535)|0;a[1044496]=j;a[1106712]=(j&255)>>>6&1;a[1106720]=j;a[1106728]=a[1041660]&j;return}function kH(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}b[520836]=h+1&65535;h=b[520831]|0;l=h+(e&255)&65535;do{if((h&255)<<24>>24!=0){e=i+6|0;c[348392]=e;if((e|0)<(j|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j=j0(l&65535)|0;a[1044496]=j;l=a[1041660]&j;a[1041660]=l;a[1106728]=l;a[1106720]=l;return}function kI(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=b[520836]|0;f=a[(c[348396]|0)+(e&65535)|0]|0;a[1044496]=f;g=(c[348392]|0)+(c[348399]|0)|0;c[348392]=g;h=c[348406]|0;if((g|0)<(h|0)){i=e;j=g;k=h}else{do{j1();l=c[348392]|0;m=c[348406]|0;}while((l|0)>=(m|0));i=b[520836]|0;j=l;k=m}b[520836]=i+1&65535;i=b[520831]|0;m=i+(f&255)&65535;do{if((i&255)<<24>>24!=0){f=j+6|0;c[348392]=f;if((f|0)<(k|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);k=m&65535;m=((j0(k)|0)&255)<<1;j=m|(d[1106736]|0);a[1106736]=(j&65535)>255|0;m=(c[348392]|0)+6|0;c[348392]=m;if((m|0)<(c[348406]|0)){n=j&255;j2(n,k);a[1044496]=n;a[1106728]=n;a[1106720]=n;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));n=j&255;j2(n,k);a[1044496]=n;a[1106728]=n;a[1106720]=n;return}function kJ(){var b=0,c=0;b=j0(xb()|0)|0;a[1044496]=b;c=a[1041660]&b;a[1041660]=c;a[1106728]=c;a[1106720]=c;return}function kK(){var d=0,e=0;d=(c[348392]|0)+12|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}d=(b[520832]|0)+1&65535;b[520832]=d;e=j0(d&65535)|0;a[1041658]=e;a[1044496]=e;a[1106728]=(e&255)>>>1&1^1;a[1106720]=e&-128;a[1106736]=e&1;a[1106712]=(e&255)>>>6&1;if((e&16)!=0){a[1041667|0]=0;a[1041669|0]=0}e=b[520829]|0;if((e&256)!=0){c[276688]=158776;c[276686]=159800;return}d=e&255;e=(d&16|0)!=0;if((d&32|0)==0){if(e){c[276688]=156728;c[276686]=160312;return}else{c[276688]=157752;c[276686]=160568;return}}else{if(e){c[276688]=154680;c[276686]=159800;return}else{c[276688]=155704;c[276686]=160056;return}}}function kL(){var d=0,e=0,f=0,g=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;if((f|0)<(c[348406]|0)){g=d}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));g=b[520836]|0}b[520836]=g+1&65535;g=a[1041660]&e;a[1041660]=g;a[1106728]=g;a[1106720]=g;return}function kM(){var b=0,e=0;b=(c[348392]|0)+6|0;c[348392]=b;if((b|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}b=(d[1041660]|0)<<1;e=b|(d[1106736]|0);a[1106736]=(b&65535)>255|0;b=e&255;a[1041660]=b;a[1106728]=b;a[1106720]=b;return}function kN(){var d=0,f=0;d=(c[348392]|0)+12|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}d=j5((e[520832]|0)+1|0,65535)|0;b[520831]=d;b[520832]=(b[520832]|0)+2&65535;a[1106728]=d<<16>>16!=0|0;f=(d&65535)>>>8&255;a[1106720]=f;a[1044496]=f;return}function kO(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=c[276674]|0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[1044496]=i;i=(c[348392]|0)+(c[348400]|0)|0;c[348392]=i;if((i|0)<(c[348406]|0)){k=g}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));k=b[520836]|0}b[520836]=k+2&65535;k=j0(j&65535|e)|0;a[1044496]=k;a[1106712]=(k&255)>>>6&1;a[1106720]=k;a[1106728]=a[1041660]&k;return}function kP(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=c[276674]|0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[1044496]=i;i=(c[348392]|0)+(c[348400]|0)|0;c[348392]=i;if((i|0)<(c[348406]|0)){k=g}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));k=b[520836]|0}b[520836]=k+2&65535;k=j0(j&65535|e)|0;a[1044496]=k;e=a[1041660]&k;a[1041660]=e;a[1106728]=e;a[1106720]=e;return}function kQ(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=c[276674]|0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[1044496]=i;i=(c[348392]|0)+(c[348400]|0)|0;c[348392]=i;if((i|0)<(c[348406]|0)){k=g}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));k=b[520836]|0}b[520836]=k+2&65535;k=j&65535|e;e=((j0(k)|0)&255)<<1;j=e|(d[1106736]|0);a[1106736]=(j&65535)>255|0;e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)<(c[348406]|0)){l=j&255;j2(l,k);a[1044496]=l;a[1106728]=l;a[1106720]=l;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));l=j&255;j2(l,k);a[1044496]=l;a[1106728]=l;a[1106720]=l;return}function kR(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[348396]|0;f=b[520836]|0;g=f&65535;h=a[e+(g+2)|0]|0;i=(d[e+(g+1)|0]|0)<<8|(d[e+g|0]|0)|(h&255)<<16;g=(c[348399]|0)+(c[348400]|0)+(c[348392]|0)|0;c[348392]=g;if((g|0)<(c[348406]|0)){j=f}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));j=b[520836]|0}a[1044496]=h;b[520836]=j+3&65535;j=j0(i)|0;a[1044496]=j;i=a[1041660]&j;a[1041660]=i;a[1106728]=i;a[1106720]=i;return}function kS(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}l=h+1&65535;b[520836]=l;h=(l&65535)+(e<<24>>24)|0;e=h&65535;k=h&65535;if((a[1106720]|0)>=0){return}g=i+6|0;c[348392]=g;if((g|0)<(j|0)){m=l}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));m=b[520836]|0}if(((m&65535^h)&61440|0)==0){b[520836]=k;return}else{j4((c[276676]|0)+e|0);return}}function kT(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=b[520836]|0;g=a[(c[348396]|0)+(f&65535)|0]|0;a[1044496]=g;h=(c[348392]|0)+(c[348399]|0)|0;c[348392]=h;i=c[348406]|0;if((h|0)<(i|0)){j=f;k=h;l=i}else{do{j1();m=c[348392]|0;n=c[348406]|0;}while((m|0)>=(n|0));j=b[520836]|0;k=m;l=n}b[520836]=j+1&65535;j=b[520831]|0;n=j+(g&255)&65535;do{if((j&255)<<24>>24!=0){g=k+6|0;c[348392]=g;if((g|0)<(l|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);l=j5(n&65535,16777215)|0;a[1044496]=(l&65535)>>>8&255;n=c[276674]|l&65535;do{if(((d[1041668]|0)+(n&255)|0)>>>0>255){l=(c[348392]|0)+6|0;c[348392]=l;if((l|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);l=j0((e[520834]|0)+n|0)|0;a[1044496]=l;n=a[1041660]&l;a[1041660]=n;a[1106728]=n;a[1106720]=n;return}function kU(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}b[520836]=h+1&65535;h=b[520831]|0;l=h+(e&255)&65535;do{if((h&255)<<24>>24!=0){e=i+6|0;c[348392]=e;if((e|0)<(j|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j=j5(l&65535,16777215)|0;a[1044496]=(j&65535)>>>8&255;l=j0(c[276674]|j&65535)|0;a[1044496]=l;j=a[1041660]&l;a[1041660]=j;a[1106728]=j;a[1106720]=j;return}function kV(){var d=0,f=0,g=0,h=0,i=0;d=j0(c[260418]|0)|0;a[1044496]=d;b[520836]=(b[520836]|0)+1&65535;f=(b[520832]|0)+(d&255)&65535;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}d=j5(f&65535,16777215)|0;a[1044496]=(d&65535)>>>8&255;f=(e[520834]|0)+(d&65535)+(c[276674]|0)&16777215;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)<(c[348406]|0)){g=j0(f)|0;a[1044496]=g;h=a[1041660]|0;i=h&g;a[1041660]=i;a[1106728]=i;a[1106720]=i;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));g=j0(f)|0;a[1044496]=g;h=a[1041660]|0;i=h&g;a[1041660]=i;a[1106728]=i;a[1106720]=i;return}function kW(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;d=b[520836]|0;f=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=f;g=(c[348392]|0)+(c[348399]|0)|0;c[348392]=g;h=c[348406]|0;if((g|0)<(h|0)){i=d;j=g;k=h}else{do{j1();l=c[348392]|0;m=c[348406]|0;}while((l|0)>=(m|0));i=b[520836]|0;j=l;k=m}b[520836]=i+1&65535;i=b[520831]|0;m=i+(f&255)&65535;do{if((i&255)<<24>>24==0){n=j;o=k}else{f=j+6|0;c[348392]=f;if((f|0)<(k|0)){n=f;o=k;break}while(1){j1();f=c[348392]|0;l=c[348406]|0;if((f|0)<(l|0)){n=f;o=l;break}}}}while(0);k=(e[520833]|0)+(m&65535)|0;m=n+6|0;c[348392]=m;if((m|0)<(o|0)){p=k&65535;q=j0(p)|0;a[1044496]=q;r=(q&255)>>>6;s=r&1;a[1106712]=s;a[1106720]=q;t=a[1041660]|0;u=t&q;a[1106728]=u;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));p=k&65535;q=j0(p)|0;a[1044496]=q;r=(q&255)>>>6;s=r&1;a[1106712]=s;a[1106720]=q;t=a[1041660]|0;u=t&q;a[1106728]=u;return}function kX(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=b[520836]|0;f=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=f;g=(c[348392]|0)+(c[348399]|0)|0;c[348392]=g;h=c[348406]|0;if((g|0)<(h|0)){i=d;j=g;k=h}else{do{j1();l=c[348392]|0;m=c[348406]|0;}while((l|0)>=(m|0));i=b[520836]|0;j=l;k=m}b[520836]=i+1&65535;i=b[520831]|0;m=i+(f&255)&65535;do{if((i&255)<<24>>24==0){n=j;o=k}else{f=j+6|0;c[348392]=f;if((f|0)<(k|0)){n=f;o=k;break}while(1){j1();f=c[348392]|0;l=c[348406]|0;if((f|0)<(l|0)){n=f;o=l;break}}}}while(0);k=(e[520833]|0)+(m&65535)|0;m=n+6|0;c[348392]=m;if((m|0)<(o|0)){p=k&65535;q=j0(p)|0;a[1044496]=q;r=a[1041660]|0;s=r&q;a[1041660]=s;a[1106728]=s;a[1106720]=s;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));p=k&65535;q=j0(p)|0;a[1044496]=q;r=a[1041660]|0;s=r&q;a[1041660]=s;a[1106728]=s;a[1106720]=s;return}function kY(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=b[520836]|0;g=a[(c[348396]|0)+(f&65535)|0]|0;a[1044496]=g;h=(c[348392]|0)+(c[348399]|0)|0;c[348392]=h;i=c[348406]|0;if((h|0)<(i|0)){j=f;k=h;l=i}else{do{j1();m=c[348392]|0;n=c[348406]|0;}while((m|0)>=(n|0));j=b[520836]|0;k=m;l=n}b[520836]=j+1&65535;j=b[520831]|0;n=j+(g&255)&65535;do{if((j&255)<<24>>24==0){o=k;p=l}else{g=k+6|0;c[348392]=g;if((g|0)<(l|0)){o=g;p=l;break}while(1){j1();g=c[348392]|0;m=c[348406]|0;if((g|0)<(m|0)){o=g;p=m;break}}}}while(0);l=(e[520833]|0)+(n&65535)|0;n=o+6|0;c[348392]=n;if((n|0)>=(p|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}p=l&65535;l=((j0(p)|0)&255)<<1;n=l|(d[1106736]|0);a[1106736]=(n&65535)>255|0;l=(c[348392]|0)+6|0;c[348392]=l;if((l|0)<(c[348406]|0)){q=n&255;j2(q,p);a[1044496]=q;a[1106728]=q;a[1106720]=q;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));q=n&255;j2(q,p);a[1044496]=q;a[1106728]=q;a[1106720]=q;return}function kZ(){var b=0,c=0;b=xb()|0;c=j0((e[520834]|0)+b|0)|0;a[1044496]=c;b=a[1041660]&c;a[1041660]=b;a[1106728]=b;a[1106720]=b;return}function k_(){var b=0;a[1106736]=1;b=(c[348392]|0)+6|0;c[348392]=b;if((b|0)<(c[348406]|0)){return}do{j1();}while((c[348392]|0)>=(c[348406]|0));return}function k$(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;do{if(((d[1041668]|0)+(l&255)|0)>>>0>255){f=m+6|0;c[348392]=f;if((f|0)<(n|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);n=j0((e[520834]|0)+l|0)|0;a[1044496]=n;l=a[1041660]&n;a[1041660]=l;a[1106728]=l;a[1106720]=l;return}function k0(){var b=0;b=(c[348392]|0)+6|0;c[348392]=b;if((b|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}b=(a[1041660]|0)-1&255;a[1041660]=b;a[1106728]=b;a[1106720]=b;return}function k1(){var d=0;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}d=b[520832]|0;b[520830]=d;a[1106728]=d<<16>>16!=0|0;a[1106720]=(d&65535)>>>8&255;return}function k2(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;do{if(((d[1041666]|0)+(l&255)|0)>>>0>255){f=m+6|0;c[348392]=f;if((f|0)<(n|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);n=j0((e[520833]|0)+l|0)|0;a[1044496]=n;a[1106712]=(n&255)>>>6&1;a[1106720]=n;a[1106728]=a[1041660]&n;return}function k3(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;do{if(((d[1041666]|0)+(l&255)|0)>>>0>255){f=m+6|0;c[348392]=f;if((f|0)<(n|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);n=j0((e[520833]|0)+l|0)|0;a[1044496]=n;l=a[1041660]&n;a[1041660]=l;a[1106728]=l;a[1106720]=l;return}function k4(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;f=m+6|0;c[348392]=f;if((f|0)>=(n|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}n=(e[520833]|0)+l|0;l=((j0(n)|0)&255)<<1;f=l|(d[1106736]|0);a[1106736]=(f&65535)>255|0;l=(c[348392]|0)+6|0;c[348392]=l;if((l|0)<(c[348406]|0)){q=f&255;j2(q,n);a[1044496]=q;a[1106728]=q;a[1106720]=q;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));q=f&255;j2(q,n);a[1044496]=q;a[1106728]=q;a[1106720]=q;return}function k5(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=a[f+(h+2)|0]|0;j=(d[f+(h+1)|0]|0)<<8|(d[f+h|0]|0)|(i&255)<<16;h=(c[348399]|0)+(c[348400]|0)+(c[348392]|0)|0;c[348392]=h;if((h|0)<(c[348406]|0)){k=g}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));k=b[520836]|0}a[1044496]=i;b[520836]=k+3&65535;k=j0((e[520833]|0)+j|0)|0;a[1044496]=k;j=a[1041660]&k;a[1041660]=j;a[1106728]=j;a[1106720]=j;return}function k6(){var d=0,f=0;d=(c[348392]|0)+12|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}if((b[520829]&256)==0){d=(b[520832]|0)+1&65535;b[520832]=d;f=j0(d&65535)|0;a[1041658]=f;a[1106728]=(f&255)>>>1&1^1;a[1106720]=f&-128;a[1106736]=f&1;a[1106712]=(f&255)>>>6&1;b[520836]=j5((e[520832]|0)+1|0,65535)|0;f=(b[520832]|0)+3&65535;b[520832]=f;d=j0(f&65535)|0;a[1041674|0]=d;a[1044496]=d;c[276676]=(d&255)<<16}else{a[1041664]=(a[1041664]|0)+1&255;d=j0(e[520832]|0)|0;a[1041658]=d;a[1106728]=(d&255)>>>1&1^1;a[1106720]=d&-128;a[1106736]=d&1;a[1106712]=(d&255)>>>6&1;a[1041664]=(a[1041664]|0)+1&255;d=j5(e[520832]|0,255)|0;b[520836]=d;a[1041664]=(a[1041664]|0)+1&255;a[1044496]=(d&65535)>>>8&255;b[520829]=b[520829]|48}j4(c[260418]|0);if((a[1041658]&16)!=0){a[1041667|0]=0;a[1041669|0]=0}d=b[520829]|0;if((d&256)!=0){c[276688]=158776;c[276686]=159800;return}f=d&255;d=(f&16|0)!=0;if((f&32|0)==0){if(d){c[276688]=156728;c[276686]=160312;return}else{c[276688]=157752;c[276686]=160568;return}}else{if(d){c[276688]=154680;c[276686]=159800;return}else{c[276688]=155704;c[276686]=160056;return}}}function k7(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=b[520836]|0;f=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=f;g=(c[348392]|0)+(c[348399]|0)|0;c[348392]=g;h=c[348406]|0;if((g|0)<(h|0)){i=d;j=g;k=h}else{do{j1();l=c[348392]|0;m=c[348406]|0;}while((l|0)>=(m|0));i=b[520836]|0;j=l;k=m}b[520836]=i+1&65535;i=b[520831]|0;m=i+(f&255)&65535;do{if((i&255)<<24>>24==0){n=j;o=k}else{f=j+6|0;c[348392]=f;if((f|0)<(k|0)){n=f;o=k;break}while(1){j1();f=c[348392]|0;l=c[348406]|0;if((f|0)<(l|0)){n=f;o=l;break}}}}while(0);k=(e[520833]|0)+(m&65535)|0;m=n+6|0;c[348392]=m;if((m|0)>=(o|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}o=j5(k&65535,16777215)|0;a[1044496]=(o&65535)>>>8&255;k=j0(c[276674]|o&65535)|0;a[1044496]=k;o=a[1041660]^k;a[1041660]=o;a[1106728]=o;a[1106720]=o;return}function k8(){j5(c[260418]|0,16777215)|0;b[520836]=(b[520836]|0)+1&65535;return}function k9(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}b[520836]=h+1&65535;h=(b[520832]|0)+(e&255)&65535;e=i+6|0;c[348392]=e;if((e|0)<(j|0)){m=h&65535;n=j0(m)|0;a[1044496]=n;o=a[1041660]|0;p=o^n;a[1041660]=p;a[1106728]=p;a[1106720]=p;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));m=h&65535;n=j0(m)|0;a[1044496]=n;o=a[1041660]|0;p=o^n;a[1041660]=p;a[1106728]=p;a[1106720]=p;return}function la(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=b[520836]|0;f=c[348396]|0;g=a[f+(d&65535)|0]|0;h=c[348399]|0;i=(c[348392]|0)+h|0;c[348392]=i;j=c[348406]|0;if((i|0)<(j|0)){k=d;l=f;m=h;n=i;o=j}else{do{j1();p=c[348392]|0;q=c[348406]|0;}while((p|0)>=(q|0));k=b[520836]|0;l=c[348396]|0;m=c[348399]|0;n=p;o=q}q=k+1&65535;b[520836]=q;a[1041656]=g;c[276674]=(g&255)<<16;g=a[l+(q&65535)|0]|0;l=m+n|0;c[348392]=l;if((l|0)<(o|0)){r=q}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));r=b[520836]|0}b[520836]=r+1&65535;a[1044496]=g;r=j0(e[520833]|0|(g&255)<<16)|0;a[1044496]=r;j2(r,(e[520834]|0)+(c[276674]|0)|0);a[1041666]=(a[1041666]|0)-1&255;a[1041668]=(a[1041668]|0)-1&255;r=b[520830]|0;b[520830]=r-1&65535;if(r<<16>>16!=0){b[520836]=(b[520836]|0)-3&65535}r=(c[348392]|0)+12|0;c[348392]=r;if((r|0)<(c[348406]|0)){return}do{j1();}while((c[348392]|0)>=(c[348406]|0));return}function lb(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}b[520836]=h+1&65535;h=b[520831]|0;l=h+(e&255)&65535;do{if((h&255)<<24>>24!=0){e=i+6|0;c[348392]=e;if((e|0)<(j|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j=j0(l&65535)|0;a[1044496]=j;l=a[1041660]^j;a[1041660]=l;a[1106728]=l;a[1106720]=l;return}function lc(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}b[520836]=h+1&65535;h=b[520831]|0;l=h+(e&255)&65535;do{if((h&255)<<24>>24!=0){e=i+6|0;c[348392]=e;if((e|0)<(j|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j=l&65535;l=j0(j)|0;a[1106736]=l&1;i=(l&255)>>>1;l=(c[348392]|0)+6|0;c[348392]=l;if((l|0)<(c[348406]|0)){j2(i,j);a[1044496]=i;a[1106728]=i;a[1106720]=i;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));j2(i,j);a[1044496]=i;a[1106728]=i;a[1106720]=i;return}function ld(){var b=0,c=0;b=j0(xb()|0)|0;a[1044496]=b;c=a[1041660]^b;a[1041660]=c;a[1106728]=c;a[1106720]=c;return}function le(){var d=0,e=0;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}d=a[1041660]|0;e=b[520832]|0;b[520832]=e-1&65535;j2(d,e&65535);a[1044496]=a[1041660]|0;return}function lf(){var d=0,e=0,f=0,g=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;if((f|0)<(c[348406]|0)){g=d}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));g=b[520836]|0}b[520836]=g+1&65535;g=a[1041660]^e;a[1041660]=g;a[1106728]=g;a[1106720]=g;return}function lg(){var b=0,d=0;b=(c[348392]|0)+6|0;c[348392]=b;if((b|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}b=a[1041660]|0;a[1106736]=b&1;d=(b&255)>>>1;a[1041660]=d;a[1106728]=d;a[1106720]=d;return}function lh(){var d=0,e=0;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}d=a[1041674|0]|0;e=b[520832]|0;b[520832]=e-1&65535;j2(d,e&65535);a[1044496]=a[1041674|0]|0;return}function li(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=c[276676]|0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;if((j|0)<(c[348406]|0)){l=h;m=l+2&65535;b[520836]=m;n=k&65535;o=f&65535;p=n|o;q=p+e|0;j4(q);return}do{j1();}while((c[348392]|0)>=(c[348406]|0));l=b[520836]|0;m=l+2&65535;b[520836]=m;n=k&65535;o=f&65535;p=n|o;q=p+e|0;j4(q);return}function lj(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=c[276674]|0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[1044496]=i;i=(c[348392]|0)+(c[348400]|0)|0;c[348392]=i;if((i|0)<(c[348406]|0)){k=g}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));k=b[520836]|0}b[520836]=k+2&65535;k=j0(j&65535|e)|0;a[1044496]=k;e=a[1041660]^k;a[1041660]=e;a[1106728]=e;a[1106720]=e;return}function lk(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=c[276674]|0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[1044496]=i;i=(c[348392]|0)+(c[348400]|0)|0;c[348392]=i;if((i|0)<(c[348406]|0)){k=g}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));k=b[520836]|0}b[520836]=k+2&65535;k=j&65535|e;e=j0(k)|0;a[1106736]=e&1;j=(e&255)>>>1;e=(c[348392]|0)+6|0;c[348392]=e;if((e|0)<(c[348406]|0)){j2(j,k);a[1044496]=j;a[1106728]=j;a[1106720]=j;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));j2(j,k);a[1044496]=j;a[1106728]=j;a[1106720]=j;return}function ll(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[348396]|0;f=b[520836]|0;g=f&65535;h=a[e+(g+2)|0]|0;i=(d[e+(g+1)|0]|0)<<8|(d[e+g|0]|0)|(h&255)<<16;g=(c[348399]|0)+(c[348400]|0)+(c[348392]|0)|0;c[348392]=g;if((g|0)<(c[348406]|0)){j=f}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));j=b[520836]|0}a[1044496]=h;b[520836]=j+3&65535;j=j0(i)|0;a[1044496]=j;i=a[1041660]^j;a[1041660]=i;a[1106728]=i;a[1106720]=i;return}function lm(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}l=h+1&65535;b[520836]=l;h=(l&65535)+(e<<24>>24)|0;e=h&65535;k=h&65535;if((a[1106712]|0)!=0){return}g=i+6|0;c[348392]=g;if((g|0)<(j|0)){m=l}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));m=b[520836]|0}if(((m&65535^h)&61440|0)==0){b[520836]=k;return}else{j4((c[276676]|0)+e|0);return}}function ln(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=b[520836]|0;g=a[(c[348396]|0)+(f&65535)|0]|0;a[1044496]=g;h=(c[348392]|0)+(c[348399]|0)|0;c[348392]=h;i=c[348406]|0;if((h|0)<(i|0)){j=f;k=h;l=i}else{do{j1();m=c[348392]|0;n=c[348406]|0;}while((m|0)>=(n|0));j=b[520836]|0;k=m;l=n}b[520836]=j+1&65535;j=b[520831]|0;n=j+(g&255)&65535;do{if((j&255)<<24>>24!=0){g=k+6|0;c[348392]=g;if((g|0)<(l|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);l=j5(n&65535,16777215)|0;a[1044496]=(l&65535)>>>8&255;n=c[276674]|l&65535;do{if(((d[1041668]|0)+(n&255)|0)>>>0>255){l=(c[348392]|0)+6|0;c[348392]=l;if((l|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);l=j0((e[520834]|0)+n|0)|0;a[1044496]=l;n=a[1041660]^l;a[1041660]=n;a[1106728]=n;a[1106720]=n;return}function lo(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}b[520836]=h+1&65535;h=b[520831]|0;l=h+(e&255)&65535;do{if((h&255)<<24>>24!=0){e=i+6|0;c[348392]=e;if((e|0)<(j|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j=j5(l&65535,16777215)|0;a[1044496]=(j&65535)>>>8&255;l=j0(c[276674]|j&65535)|0;a[1044496]=l;j=a[1041660]^l;a[1041660]=j;a[1106728]=j;a[1106720]=j;return}function lp(){var d=0,f=0,g=0,h=0,i=0;d=j0(c[260418]|0)|0;a[1044496]=d;b[520836]=(b[520836]|0)+1&65535;f=(b[520832]|0)+(d&255)&65535;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}d=j5(f&65535,16777215)|0;a[1044496]=(d&65535)>>>8&255;f=(e[520834]|0)+(d&65535)+(c[276674]|0)&16777215;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)<(c[348406]|0)){g=j0(f)|0;a[1044496]=g;h=a[1041660]|0;i=h^g;a[1041660]=i;a[1106728]=i;a[1106720]=i;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));g=j0(f)|0;a[1044496]=g;h=a[1041660]|0;i=h^g;a[1041660]=i;a[1106728]=i;a[1106720]=i;return}function lq(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=b[520836]|0;f=c[348396]|0;g=a[f+(d&65535)|0]|0;h=c[348399]|0;i=(c[348392]|0)+h|0;c[348392]=i;j=c[348406]|0;if((i|0)<(j|0)){k=d;l=f;m=h;n=i;o=j}else{do{j1();p=c[348392]|0;q=c[348406]|0;}while((p|0)>=(q|0));k=b[520836]|0;l=c[348396]|0;m=c[348399]|0;n=p;o=q}q=k+1&65535;b[520836]=q;a[1041656]=g;c[276674]=(g&255)<<16;g=a[l+(q&65535)|0]|0;l=m+n|0;c[348392]=l;if((l|0)<(o|0)){r=q}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));r=b[520836]|0}b[520836]=r+1&65535;a[1044496]=g;r=j0(e[520833]|0|(g&255)<<16)|0;a[1044496]=r;j2(r,(e[520834]|0)+(c[276674]|0)|0);a[1041666]=(a[1041666]|0)+1&255;a[1041668]=(a[1041668]|0)+1&255;r=b[520830]|0;b[520830]=r-1&65535;if(r<<16>>16!=0){b[520836]=(b[520836]|0)-3&65535}r=(c[348392]|0)+12|0;c[348392]=r;if((r|0)<(c[348406]|0)){return}do{j1();}while((c[348392]|0)>=(c[348406]|0));return}function lr(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;d=b[520836]|0;f=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=f;g=(c[348392]|0)+(c[348399]|0)|0;c[348392]=g;h=c[348406]|0;if((g|0)<(h|0)){i=d;j=g;k=h}else{do{j1();l=c[348392]|0;m=c[348406]|0;}while((l|0)>=(m|0));i=b[520836]|0;j=l;k=m}b[520836]=i+1&65535;i=b[520831]|0;m=i+(f&255)&65535;do{if((i&255)<<24>>24==0){n=j;o=k}else{f=j+6|0;c[348392]=f;if((f|0)<(k|0)){n=f;o=k;break}while(1){j1();f=c[348392]|0;l=c[348406]|0;if((f|0)<(l|0)){n=f;o=l;break}}}}while(0);k=(e[520833]|0)+(m&65535)|0;m=n+6|0;c[348392]=m;if((m|0)<(o|0)){p=k&65535;q=j0(p)|0;a[1044496]=q;r=a[1041660]|0;s=r^q;a[1041660]=s;a[1106728]=s;a[1106720]=s;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));p=k&65535;q=j0(p)|0;a[1044496]=q;r=a[1041660]|0;s=r^q;a[1041660]=s;a[1106728]=s;a[1106720]=s;return}function ls(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=b[520836]|0;f=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=f;g=(c[348392]|0)+(c[348399]|0)|0;c[348392]=g;h=c[348406]|0;if((g|0)<(h|0)){i=d;j=g;k=h}else{do{j1();l=c[348392]|0;m=c[348406]|0;}while((l|0)>=(m|0));i=b[520836]|0;j=l;k=m}b[520836]=i+1&65535;i=b[520831]|0;m=i+(f&255)&65535;do{if((i&255)<<24>>24==0){n=j;o=k}else{f=j+6|0;c[348392]=f;if((f|0)<(k|0)){n=f;o=k;break}while(1){j1();f=c[348392]|0;l=c[348406]|0;if((f|0)<(l|0)){n=f;o=l;break}}}}while(0);k=(e[520833]|0)+(m&65535)|0;m=n+6|0;c[348392]=m;if((m|0)>=(o|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}o=k&65535;k=j0(o)|0;a[1106736]=k&1;m=(k&255)>>>1;k=(c[348392]|0)+6|0;c[348392]=k;if((k|0)<(c[348406]|0)){j2(m,o);a[1044496]=m;a[1106728]=m;a[1106720]=m;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));j2(m,o);a[1044496]=m;a[1106728]=m;a[1106720]=m;return}function lt(){var b=0,c=0;b=xb()|0;c=j0((e[520834]|0)+b|0)|0;a[1044496]=c;b=a[1041660]^c;a[1041660]=b;a[1106728]=b;a[1106720]=b;return}function lu(){var b=0;a[1041658]=a[1041658]&-5;b=(c[348392]|0)+6|0;c[348392]=b;if((b|0)<(c[348406]|0)){return}do{j1();}while((c[348392]|0)>=(c[348406]|0));return}function lv(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;do{if(((d[1041668]|0)+(l&255)|0)>>>0>255){f=m+6|0;c[348392]=f;if((f|0)<(n|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);n=j0((e[520834]|0)+l|0)|0;a[1044496]=n;l=a[1041660]^n;a[1041660]=l;a[1106728]=l;a[1106720]=l;return}function lw(){var d=0,e=0;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}d=a[1041668]|0;e=b[520832]|0;b[520832]=e-1&65535;j2(d,e&65535);a[1044496]=a[1041668]|0;return}function lx(){var d=0;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}d=b[520830]|0;b[520831]=d;a[1106728]=d<<16>>16!=0|0;a[1106720]=(d&65535)>>>8&255;return}function ly(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=c[348396]|0;f=b[520836]|0;g=f&65535;h=a[e+(g+2)|0]|0;i=(d[e+(g+1)|0]|0)<<8|(d[e+g|0]|0)|(h&255)<<16;g=(c[348399]|0)+(c[348400]|0)+(c[348392]|0)|0;c[348392]=g;if((g|0)<(c[348406]|0)){j=f;a[1044496]=h;k=j+3&65535;b[520836]=k;j4(i);return}do{j1();}while((c[348392]|0)>=(c[348406]|0));j=b[520836]|0;a[1044496]=h;k=j+3&65535;b[520836]=k;j4(i);return}function lz(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;do{if(((d[1041666]|0)+(l&255)|0)>>>0>255){f=m+6|0;c[348392]=f;if((f|0)<(n|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);n=j0((e[520833]|0)+l|0)|0;a[1044496]=n;l=a[1041660]^n;a[1041660]=l;a[1106728]=l;a[1106720]=l;return}function lA(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;f=m+6|0;c[348392]=f;if((f|0)>=(n|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}n=(e[520833]|0)+l|0;l=j0(n)|0;a[1106736]=l&1;f=(l&255)>>>1;l=(c[348392]|0)+6|0;c[348392]=l;if((l|0)<(c[348406]|0)){j2(f,n);a[1044496]=f;a[1106728]=f;a[1106720]=f;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));j2(f,n);a[1044496]=f;a[1106728]=f;a[1106720]=f;return}function lB(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=a[f+(h+2)|0]|0;j=(d[f+(h+1)|0]|0)<<8|(d[f+h|0]|0)|(i&255)<<16;h=(c[348399]|0)+(c[348400]|0)+(c[348392]|0)|0;c[348392]=h;if((h|0)<(c[348406]|0)){k=g}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));k=b[520836]|0}a[1044496]=i;b[520836]=k+3&65535;k=j0((e[520833]|0)+j|0)|0;a[1044496]=k;j=a[1041660]^k;a[1041660]=j;a[1106728]=j;a[1106720]=j;return}function lC(){var a=0,d=0,f=0,g=0,h=0;a=(c[348392]|0)+12|0;c[348392]=a;if((a|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}a=j5((e[520832]|0)+1|0,65535)|0;b[520836]=a;b[520832]=(b[520832]|0)+2&65535;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)<(c[348406]|0)){f=a;g=f+1&65535;b[520836]=g;h=c[260418]|0;j4(h);return}do{j1();}while((c[348392]|0)>=(c[348406]|0));f=b[520836]|0;g=f+1&65535;b[520836]=g;h=c[260418]|0;j4(h);return}function lD(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=b[520836]|0;g=a[(c[348396]|0)+(f&65535)|0]|0;a[1044496]=g;h=(c[348392]|0)+(c[348399]|0)|0;c[348392]=h;i=c[348406]|0;if((h|0)<(i|0)){j=f;k=h;l=i}else{do{j1();m=c[348392]|0;n=c[348406]|0;}while((m|0)>=(n|0));j=b[520836]|0;k=m;l=n}b[520836]=j+1&65535;j=b[520831]|0;n=j+(g&255)&65535;do{if((j&255)<<24>>24==0){o=k;p=l}else{g=k+6|0;c[348392]=g;if((g|0)<(l|0)){o=g;p=l;break}while(1){j1();g=c[348392]|0;m=c[348406]|0;if((g|0)<(m|0)){o=g;p=m;break}}}}while(0);l=(e[520833]|0)+(n&65535)|0;n=o+6|0;c[348392]=n;if((n|0)>=(p|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}p=j5(l&65535,16777215)|0;a[1044496]=(p&65535)>>>8&255;l=j0(c[276674]|p&65535)|0;a[1044496]=l;if((a[1041658]&8)==0){p=a[1041660]|0;n=l&255;o=(p&255)+n+(d[1106736]|0)|0;a[1106736]=(o&65280)>>>0>255|0;q=o&255;r=((o^n)&((p^l)&255^128))>>>7&255;s=r&1;a[1106712]=s;a[1041660]=q;a[1106728]=q;a[1106720]=q;return}p=b[520830]|0;n=p&255;o=p&240;p=((a[1106736]|0)+(l&15)&255)+(n&15)&255;if((p&255)>9){t=p+6&15;u=o+16&65535}else{t=p;u=o}o=u+(l&-16&255)&65535;if((o&65535)>144){a[1106736]=1;v=o+96&255&-16}else{a[1106736]=0;v=o&255}o=v|t;q=o;r=((o^l)&(l^-128^n)&255)>>>7;s=r&1;a[1106712]=s;a[1041660]=q;a[1106728]=q;a[1106720]=q;return}function lE(){var f=0,g=0,h=0,i=0,j=0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=(d[f+(h+1)|0]|0)<<8|(d[f+h|0]|0);h=(c[348392]|0)+(c[348400]|0)|0;c[348392]=h;if((h|0)<(c[348406]|0)){j=g}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));j=b[520836]|0}g=j+2&65535;b[520836]=g;j=(g&65535)+(i&65535)|0;j3(j&65535,(e[520832]|0)-1|0,65535);b[520832]=(b[520832]|0)-2&65535;a[1044496]=j&255;return}function lF(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=b[520836]|0;f=a[(c[348396]|0)+(e&65535)|0]|0;a[1044496]=f;g=(c[348392]|0)+(c[348399]|0)|0;c[348392]=g;h=c[348406]|0;if((g|0)<(h|0)){i=e;j=g;k=h}else{do{j1();l=c[348392]|0;m=c[348406]|0;}while((l|0)>=(m|0));i=b[520836]|0;j=l;k=m}b[520836]=i+1&65535;i=(b[520832]|0)+(f&255)&65535;f=j+6|0;c[348392]=f;if((f|0)>=(k|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}k=j0(i&65535)|0;a[1044496]=k;if((a[1041658]&8)==0){i=a[1041660]|0;f=k&255;j=(i&255)+f+(d[1106736]|0)|0;a[1106736]=(j&65280)>>>0>255|0;n=j&255;o=((j^f)&((i^k)&255^128))>>>7&255;p=o&1;a[1106712]=p;a[1041660]=n;a[1106728]=n;a[1106720]=n;return}i=b[520830]|0;f=i&255;j=i&240;i=((a[1106736]|0)+(k&15)&255)+(f&15)&255;if((i&255)>9){q=i+6&15;r=j+16&65535}else{q=i;r=j}j=r+(k&-16&255)&65535;if((j&65535)>144){a[1106736]=1;s=j+96&255&-16}else{a[1106736]=0;s=j&255}j=s|q;n=j;o=((j^k)&(k^-128^f)&255)>>>7;p=o&1;a[1106712]=p;a[1041660]=n;a[1106728]=n;a[1106720]=n;return}function lG(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}b[520836]=h+1&65535;h=b[520831]|0;l=h+(e&255)&65535;if((h&255)<<24>>24==0){m=l&65535;j2(0,m);a[1044496]=0;return}h=i+6|0;c[348392]=h;if((h|0)<(j|0)){m=l&65535;j2(0,m);a[1044496]=0;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));m=l&65535;j2(0,m);a[1044496]=0;return}function lH(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=b[520836]|0;f=a[(c[348396]|0)+(e&65535)|0]|0;a[1044496]=f;g=(c[348392]|0)+(c[348399]|0)|0;c[348392]=g;h=c[348406]|0;if((g|0)<(h|0)){i=e;j=g;k=h}else{do{j1();l=c[348392]|0;m=c[348406]|0;}while((l|0)>=(m|0));i=b[520836]|0;j=l;k=m}b[520836]=i+1&65535;i=b[520831]|0;m=i+(f&255)&65535;do{if((i&255)<<24>>24!=0){f=j+6|0;c[348392]=f;if((f|0)<(k|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);k=j0(m&65535)|0;a[1044496]=k;if((a[1041658]&8)==0){m=a[1041660]|0;j=k&255;i=(m&255)+j+(d[1106736]|0)|0;a[1106736]=(i&65280)>>>0>255|0;n=i&255;o=((i^j)&((m^k)&255^128))>>>7&255;p=o&1;a[1106712]=p;a[1041660]=n;a[1106728]=n;a[1106720]=n;return}m=b[520830]|0;j=m&255;i=m&240;m=((a[1106736]|0)+(k&15)&255)+(j&15)&255;if((m&255)>9){q=m+6&15;r=i+16&65535}else{q=m;r=i}i=r+(k&-16&255)&65535;if((i&65535)>144){a[1106736]=1;s=i+96&255&-16}else{a[1106736]=0;s=i&255}i=s|q;n=i;o=((i^k)&(k^-128^j)&255)>>>7;p=o&1;a[1106712]=p;a[1041660]=n;a[1106728]=n;a[1106720]=n;return}function lI(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=b[520836]|0;f=a[(c[348396]|0)+(e&65535)|0]|0;a[1044496]=f;g=(c[348392]|0)+(c[348399]|0)|0;c[348392]=g;h=c[348406]|0;if((g|0)<(h|0)){i=e;j=g;k=h}else{do{j1();l=c[348392]|0;m=c[348406]|0;}while((l|0)>=(m|0));i=b[520836]|0;j=l;k=m}b[520836]=i+1&65535;i=b[520831]|0;m=i+(f&255)&65535;do{if((i&255)<<24>>24!=0){f=j+6|0;c[348392]=f;if((f|0)<(k|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);k=m&65535;m=j0(k)|0;j=(d[1106736]|0)<<8|m&255;a[1106736]=m&1;m=(j&65535)>>>1;j=(c[348392]|0)+6|0;c[348392]=j;if((j|0)<(c[348406]|0)){n=m&255;j2(n,k);a[1044496]=n;a[1106728]=n;a[1106720]=n;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));n=m&255;j2(n,k);a[1044496]=n;a[1106728]=n;a[1106720]=n;return}function lJ(){var c=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;c=j0(xb()|0)|0;a[1044496]=c;if((a[1041658]&8)==0){e=a[1041660]|0;f=c&255;g=(e&255)+f+(d[1106736]|0)|0;a[1106736]=(g&65280)>>>0>255|0;h=g&255;i=((g^f)&((e^c)&255^128))>>>7&255;j=i&1;a[1106712]=j;a[1041660]=h;a[1106728]=h;a[1106720]=h;return}e=b[520830]|0;f=e&255;g=e&240;e=((a[1106736]|0)+(c&15)&255)+(f&15)&255;if((e&255)>9){k=e+6&15;l=g+16&65535}else{k=e;l=g}g=l+(c&-16&255)&65535;if((g&65535)>144){a[1106736]=1;m=g+96&255&-16}else{a[1106736]=0;m=g&255}g=m|k;h=g;i=((g^c)&(c^-128^f)&255)>>>7;j=i&1;a[1106712]=j;a[1041660]=h;a[1106728]=h;a[1106720]=h;return}function lK(){var d=0,e=0;d=(c[348392]|0)+12|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}d=(b[520832]|0)+1&65535;b[520832]=d;e=j0(d&65535)|0;a[1041660]=e;a[1106728]=e;a[1106720]=e;a[1044496]=e;return}function lL(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=b[520836]|0;f=a[(c[348396]|0)+(e&65535)|0]|0;a[1044496]=f;g=(c[348392]|0)+(c[348399]|0)|0;c[348392]=g;if((g|0)<(c[348406]|0)){h=e}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));h=b[520836]|0}b[520836]=h+1&65535;if((a[1041658]&8)==0){h=a[1041660]|0;e=f&255;g=(h&255)+e+(d[1106736]|0)|0;a[1106736]=(g&65280)>>>0>255|0;i=g&255;j=((g^e)&((h^f)&255^128))>>>7&255;k=j&1;a[1106712]=k;a[1041660]=i;a[1106728]=i;a[1106720]=i;return}h=b[520830]|0;e=h&255;g=h&240;h=((a[1106736]|0)+(f&15)&255)+(e&15)&255;if((h&255)>9){l=h+6&15;m=g+16&65535}else{l=h;m=g}g=m+(f&-16&255)&65535;if((g&65535)>144){a[1106736]=1;n=g+96&255&-16}else{a[1106736]=0;n=g&255}g=n|l;i=g;j=((g^f)&(f^-128^e)&255)>>>7;k=j&1;a[1106712]=k;a[1041660]=i;a[1106728]=i;a[1106720]=i;return}function lM(){var b=0,e=0;b=(c[348392]|0)+6|0;c[348392]=b;if((b|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}b=a[1041660]|0;e=(d[1106736]|0)<<8|b&255;a[1106736]=b&1;b=(e&65535)>>>1&255;a[1041660]=b;a[1106728]=b;a[1106720]=b;return}function lN(){var d=0;d=(c[348392]|0)+12|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}b[520836]=j5((e[520832]|0)+1|0,65535)|0;d=(b[520832]|0)+3&65535;b[520832]=d;a[1041674|0]=j0(d&65535)|0;b[520836]=(b[520836]|0)+1&65535;j4(c[260418]|0);return}function lO(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=c[276676]|0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[1044496]=i;i=(c[348392]|0)+(c[348400]|0)|0;c[348392]=i;if((i|0)<(c[348406]|0)){k=g}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));k=b[520836]|0}b[520836]=k+2&65535;k=j5(j&65535,16777215)|0;a[1044496]=(k&65535)>>>8&255;j4((k&65535)+e|0);return}function lP(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=c[276674]|0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[1044496]=i;i=(c[348392]|0)+(c[348400]|0)|0;c[348392]=i;if((i|0)<(c[348406]|0)){k=g}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));k=b[520836]|0}b[520836]=k+2&65535;k=j0(j&65535|e)|0;a[1044496]=k;if((a[1041658]&8)==0){e=a[1041660]|0;j=k&255;g=(e&255)+j+(d[1106736]|0)|0;a[1106736]=(g&65280)>>>0>255|0;l=g&255;m=((g^j)&((e^k)&255^128))>>>7&255;n=m&1;a[1106712]=n;a[1041660]=l;a[1106728]=l;a[1106720]=l;return}e=b[520830]|0;j=e&255;g=e&240;e=((a[1106736]|0)+(k&15)&255)+(j&15)&255;if((e&255)>9){o=e+6&15;p=g+16&65535}else{o=e;p=g}g=p+(k&-16&255)&65535;if((g&65535)>144){a[1106736]=1;q=g+96&255&-16}else{a[1106736]=0;q=g&255}g=q|o;l=g;m=((g^k)&(k^-128^j)&255)>>>7;n=m&1;a[1106712]=n;a[1041660]=l;a[1106728]=l;a[1106720]=l;return}function lQ(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=c[276674]|0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[1044496]=i;i=(c[348392]|0)+(c[348400]|0)|0;c[348392]=i;if((i|0)<(c[348406]|0)){k=g}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));k=b[520836]|0}b[520836]=k+2&65535;k=j&65535|e;e=j0(k)|0;j=(d[1106736]|0)<<8|e&255;a[1106736]=e&1;e=(j&65535)>>>1;j=(c[348392]|0)+6|0;c[348392]=j;if((j|0)<(c[348406]|0)){l=e&255;j2(l,k);a[1044496]=l;a[1106728]=l;a[1106720]=l;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));l=e&255;j2(l,k);a[1044496]=l;a[1106728]=l;a[1106720]=l;return}function lR(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=c[348396]|0;f=b[520836]|0;g=f&65535;h=a[e+(g+2)|0]|0;i=(d[e+(g+1)|0]|0)<<8|(d[e+g|0]|0)|(h&255)<<16;g=(c[348399]|0)+(c[348400]|0)+(c[348392]|0)|0;c[348392]=g;if((g|0)<(c[348406]|0)){j=f}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));j=b[520836]|0}a[1044496]=h;b[520836]=j+3&65535;j=j0(i)|0;a[1044496]=j;if((a[1041658]&8)==0){i=a[1041660]|0;h=j&255;f=(i&255)+h+(d[1106736]|0)|0;a[1106736]=(f&65280)>>>0>255|0;k=f&255;l=((f^h)&((i^j)&255^128))>>>7&255;m=l&1;a[1106712]=m;a[1041660]=k;a[1106728]=k;a[1106720]=k;return}i=b[520830]|0;h=i&255;f=i&240;i=((a[1106736]|0)+(j&15)&255)+(h&15)&255;if((i&255)>9){n=i+6&15;o=f+16&65535}else{n=i;o=f}f=o+(j&-16&255)&65535;if((f&65535)>144){a[1106736]=1;p=f+96&255&-16}else{a[1106736]=0;p=f&255}f=p|n;k=f;l=((f^j)&(j^-128^h)&255)>>>7;m=l&1;a[1106712]=m;a[1041660]=k;a[1106728]=k;a[1106720]=k;return}function lS(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}l=h+1&65535;b[520836]=l;h=(l&65535)+(e<<24>>24)|0;e=h&65535;k=h&65535;if((a[1106712]|0)==0){return}g=i+6|0;c[348392]=g;if((g|0)<(j|0)){m=l}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));m=b[520836]|0}if(((m&65535^h)&61440|0)==0){b[520836]=k;return}else{j4((c[276676]|0)+e|0);return}}function lT(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;f=b[520836]|0;g=a[(c[348396]|0)+(f&65535)|0]|0;a[1044496]=g;h=(c[348392]|0)+(c[348399]|0)|0;c[348392]=h;i=c[348406]|0;if((h|0)<(i|0)){j=f;k=h;l=i}else{do{j1();m=c[348392]|0;n=c[348406]|0;}while((m|0)>=(n|0));j=b[520836]|0;k=m;l=n}b[520836]=j+1&65535;j=b[520831]|0;n=j+(g&255)&65535;do{if((j&255)<<24>>24!=0){g=k+6|0;c[348392]=g;if((g|0)<(l|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);l=j5(n&65535,16777215)|0;a[1044496]=(l&65535)>>>8&255;n=c[276674]|l&65535;do{if(((d[1041668]|0)+(n&255)|0)>>>0>255){l=(c[348392]|0)+6|0;c[348392]=l;if((l|0)<(c[348406]|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);l=j0((e[520834]|0)+n|0)|0;a[1044496]=l;if((a[1041658]&8)==0){n=a[1041660]|0;k=l&255;j=(n&255)+k+(d[1106736]|0)|0;a[1106736]=(j&65280)>>>0>255|0;o=j&255;p=((j^k)&((n^l)&255^128))>>>7&255;q=p&1;a[1106712]=q;a[1041660]=o;a[1106728]=o;a[1106720]=o;return}n=b[520830]|0;k=n&255;j=n&240;n=((a[1106736]|0)+(l&15)&255)+(k&15)&255;if((n&255)>9){r=n+6&15;s=j+16&65535}else{r=n;s=j}j=s+(l&-16&255)&65535;if((j&65535)>144){a[1106736]=1;t=j+96&255&-16}else{a[1106736]=0;t=j&255}j=t|r;o=j;p=((j^l)&(l^-128^k)&255)>>>7;q=p&1;a[1106712]=q;a[1041660]=o;a[1106728]=o;a[1106720]=o;return}function lU(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=b[520836]|0;f=a[(c[348396]|0)+(e&65535)|0]|0;a[1044496]=f;g=(c[348392]|0)+(c[348399]|0)|0;c[348392]=g;h=c[348406]|0;if((g|0)<(h|0)){i=e;j=g;k=h}else{do{j1();l=c[348392]|0;m=c[348406]|0;}while((l|0)>=(m|0));i=b[520836]|0;j=l;k=m}b[520836]=i+1&65535;i=b[520831]|0;m=i+(f&255)&65535;do{if((i&255)<<24>>24!=0){f=j+6|0;c[348392]=f;if((f|0)<(k|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);k=j5(m&65535,16777215)|0;a[1044496]=(k&65535)>>>8&255;m=j0(c[276674]|k&65535)|0;a[1044496]=m;if((a[1041658]&8)==0){k=a[1041660]|0;j=m&255;i=(k&255)+j+(d[1106736]|0)|0;a[1106736]=(i&65280)>>>0>255|0;n=i&255;o=((i^j)&((k^m)&255^128))>>>7&255;p=o&1;a[1106712]=p;a[1041660]=n;a[1106728]=n;a[1106720]=n;return}k=b[520830]|0;j=k&255;i=k&240;k=((a[1106736]|0)+(m&15)&255)+(j&15)&255;if((k&255)>9){q=k+6&15;r=i+16&65535}else{q=k;r=i}i=r+(m&-16&255)&65535;if((i&65535)>144){a[1106736]=1;s=i+96&255&-16}else{a[1106736]=0;s=i&255}i=s|q;n=i;o=((i^m)&(m^-128^j)&255)>>>7;p=o&1;a[1106712]=p;a[1041660]=n;a[1106728]=n;a[1106720]=n;return}function lV(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=j0(c[260418]|0)|0;a[1044496]=f;b[520836]=(b[520836]|0)+1&65535;g=(b[520832]|0)+(f&255)&65535;f=(c[348392]|0)+6|0;c[348392]=f;if((f|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}f=j5(g&65535,16777215)|0;a[1044496]=(f&65535)>>>8&255;g=(e[520834]|0)+(f&65535)+(c[276674]|0)&16777215;f=(c[348392]|0)+6|0;c[348392]=f;if((f|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}f=j0(g)|0;a[1044496]=f;if((a[1041658]&8)==0){g=a[1041660]|0;h=f&255;i=(g&255)+h+(d[1106736]|0)|0;a[1106736]=(i&65280)>>>0>255|0;j=i&255;k=((i^h)&((g^f)&255^128))>>>7&255;l=k&1;a[1106712]=l;a[1041660]=j;a[1106728]=j;a[1106720]=j;return}g=b[520830]|0;h=g&255;i=g&240;g=((a[1106736]|0)+(f&15)&255)+(h&15)&255;if((g&255)>9){m=g+6&15;n=i+16&65535}else{m=g;n=i}i=n+(f&-16&255)&65535;if((i&65535)>144){a[1106736]=1;o=i+96&255&-16}else{a[1106736]=0;o=i&255}i=o|m;j=i;k=((i^f)&(f^-128^h)&255)>>>7;l=k&1;a[1106712]=l;a[1041660]=j;a[1106728]=j;a[1106720]=j;return}function lW(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;d=b[520836]|0;f=a[(c[348396]|0)+(d&65535)|0]|0;g=(c[348392]|0)+(c[348399]|0)|0;c[348392]=g;h=c[348406]|0;if((g|0)<(h|0)){i=d;j=g;k=h}else{do{j1();l=c[348392]|0;m=c[348406]|0;}while((l|0)>=(m|0));i=b[520836]|0;j=l;k=m}b[520836]=i+1&65535;i=b[520831]|0;m=i+(f&255)&65535;do{if((i&255)<<24>>24==0){n=j;o=k}else{f=j+6|0;c[348392]=f;if((f|0)<(k|0)){n=f;o=k;break}while(1){j1();f=c[348392]|0;l=c[348406]|0;if((f|0)<(l|0)){n=f;o=l;break}}}}while(0);k=(e[520833]|0)+(m&65535)|0;m=n+6|0;c[348392]=m;if((m|0)<(o|0)){p=k&65535;j2(0,p);a[1044496]=0;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));p=k&65535;j2(0,p);a[1044496]=0;return}function lX(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=b[520836]|0;g=a[(c[348396]|0)+(f&65535)|0]|0;a[1044496]=g;h=(c[348392]|0)+(c[348399]|0)|0;c[348392]=h;i=c[348406]|0;if((h|0)<(i|0)){j=f;k=h;l=i}else{do{j1();m=c[348392]|0;n=c[348406]|0;}while((m|0)>=(n|0));j=b[520836]|0;k=m;l=n}b[520836]=j+1&65535;j=b[520831]|0;n=j+(g&255)&65535;do{if((j&255)<<24>>24==0){o=k;p=l}else{g=k+6|0;c[348392]=g;if((g|0)<(l|0)){o=g;p=l;break}while(1){j1();g=c[348392]|0;m=c[348406]|0;if((g|0)<(m|0)){o=g;p=m;break}}}}while(0);l=(e[520833]|0)+(n&65535)|0;n=o+6|0;c[348392]=n;if((n|0)>=(p|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}p=j0(l&65535)|0;a[1044496]=p;if((a[1041658]&8)==0){l=a[1041660]|0;n=p&255;o=(l&255)+n+(d[1106736]|0)|0;a[1106736]=(o&65280)>>>0>255|0;q=o&255;r=((o^n)&((l^p)&255^128))>>>7&255;s=r&1;a[1106712]=s;a[1041660]=q;a[1106728]=q;a[1106720]=q;return}l=b[520830]|0;n=l&255;o=l&240;l=((a[1106736]|0)+(p&15)&255)+(n&15)&255;if((l&255)>9){t=l+6&15;u=o+16&65535}else{t=l;u=o}o=u+(p&-16&255)&65535;if((o&65535)>144){a[1106736]=1;v=o+96&255&-16}else{a[1106736]=0;v=o&255}o=v|t;q=o;r=((o^p)&(p^-128^n)&255)>>>7;s=r&1;a[1106712]=s;a[1041660]=q;a[1106728]=q;a[1106720]=q;return}function lY(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=b[520836]|0;g=a[(c[348396]|0)+(f&65535)|0]|0;a[1044496]=g;h=(c[348392]|0)+(c[348399]|0)|0;c[348392]=h;i=c[348406]|0;if((h|0)<(i|0)){j=f;k=h;l=i}else{do{j1();m=c[348392]|0;n=c[348406]|0;}while((m|0)>=(n|0));j=b[520836]|0;k=m;l=n}b[520836]=j+1&65535;j=b[520831]|0;n=j+(g&255)&65535;do{if((j&255)<<24>>24==0){o=k;p=l}else{g=k+6|0;c[348392]=g;if((g|0)<(l|0)){o=g;p=l;break}while(1){j1();g=c[348392]|0;m=c[348406]|0;if((g|0)<(m|0)){o=g;p=m;break}}}}while(0);l=(e[520833]|0)+(n&65535)|0;n=o+6|0;c[348392]=n;if((n|0)>=(p|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}p=l&65535;l=j0(p)|0;n=(d[1106736]|0)<<8|l&255;a[1106736]=l&1;l=(n&65535)>>>1;n=(c[348392]|0)+6|0;c[348392]=n;if((n|0)<(c[348406]|0)){q=l&255;j2(q,p);a[1044496]=q;a[1106728]=q;a[1106720]=q;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));q=l&255;j2(q,p);a[1044496]=q;a[1106728]=q;a[1106720]=q;return}function lZ(){var c=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;c=xb()|0;f=j0((e[520834]|0)+c|0)|0;a[1044496]=f;if((a[1041658]&8)==0){c=a[1041660]|0;g=f&255;h=(c&255)+g+(d[1106736]|0)|0;a[1106736]=(h&65280)>>>0>255|0;i=h&255;j=((h^g)&((c^f)&255^128))>>>7&255;k=j&1;a[1106712]=k;a[1041660]=i;a[1106728]=i;a[1106720]=i;return}c=b[520830]|0;g=c&255;h=c&240;c=((a[1106736]|0)+(f&15)&255)+(g&15)&255;if((c&255)>9){l=c+6&15;m=h+16&65535}else{l=c;m=h}h=m+(f&-16&255)&65535;if((h&65535)>144){a[1106736]=1;n=h+96&255&-16}else{a[1106736]=0;n=h&255}h=n|l;i=h;j=((h^f)&(f^-128^g)&255)>>>7;k=j&1;a[1106712]=k;a[1041660]=i;a[1106728]=i;a[1106720]=i;return}function l_(){var b=0;a[1041658]=a[1041658]|4;b=(c[348392]|0)+6|0;c[348392]=b;if((b|0)<(c[348406]|0)){return}do{j1();}while((c[348392]|0)>=(c[348406]|0));return}function l$(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;do{if(((d[1041668]|0)+(l&255)|0)>>>0>255){f=m+6|0;c[348392]=f;if((f|0)<(n|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);n=j0((e[520834]|0)+l|0)|0;a[1044496]=n;if((a[1041658]&8)==0){l=a[1041660]|0;m=n&255;f=(l&255)+m+(d[1106736]|0)|0;a[1106736]=(f&65280)>>>0>255|0;q=f&255;r=((f^m)&((l^n)&255^128))>>>7&255;s=r&1;a[1106712]=s;a[1041660]=q;a[1106728]=q;a[1106720]=q;return}l=b[520830]|0;m=l&255;f=l&240;l=((a[1106736]|0)+(n&15)&255)+(m&15)&255;if((l&255)>9){t=l+6&15;u=f+16&65535}else{t=l;u=f}f=u+(n&-16&255)&65535;if((f&65535)>144){a[1106736]=1;v=f+96&255&-16}else{a[1106736]=0;v=f&255}f=v|t;q=f;r=((f^n)&(n^-128^m)&255)>>>7;s=r&1;a[1106712]=s;a[1041660]=q;a[1106728]=q;a[1106720]=q;return}function l0(){var d=0,e=0;d=(c[348392]|0)+12|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}d=(b[520832]|0)+1&65535;b[520832]=d;e=j0(d&65535)|0;a[1041668]=e;a[1106728]=e;a[1106720]=e;a[1044496]=e;return}function l1(){var d=0;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}d=b[520831]|0;b[520830]=d;a[1106728]=d<<16>>16!=0|0;a[1106720]=(d&65535)>>>8&255;return}function l2(){var d=0,e=0,f=0;d=c[276676]|0;e=j5(c[260418]|0,65535)|0;a[1044496]=(e&65535)>>>8&255;b[520836]=(b[520836]|0)+2&65535;f=j5((b[520833]|0)+e&65535|c[276676],65535)|0;a[1044496]=(f&65535)>>>8&255;j4((f&65535)+d|0);return}function l3(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;do{if(((d[1041666]|0)+(l&255)|0)>>>0>255){f=m+6|0;c[348392]=f;if((f|0)<(n|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);n=j0((e[520833]|0)+l|0)|0;a[1044496]=n;if((a[1041658]&8)==0){l=a[1041660]|0;m=n&255;f=(l&255)+m+(d[1106736]|0)|0;a[1106736]=(f&65280)>>>0>255|0;q=f&255;r=((f^m)&((l^n)&255^128))>>>7&255;s=r&1;a[1106712]=s;a[1041660]=q;a[1106728]=q;a[1106720]=q;return}l=b[520830]|0;m=l&255;f=l&240;l=((a[1106736]|0)+(n&15)&255)+(m&15)&255;if((l&255)>9){t=l+6&15;u=f+16&65535}else{t=l;u=f}f=u+(n&-16&255)&65535;if((f&65535)>144){a[1106736]=1;v=f+96&255&-16}else{a[1106736]=0;v=f&255}f=v|t;q=f;r=((f^n)&(n^-128^m)&255)>>>7;s=r&1;a[1106712]=s;a[1041660]=q;a[1106728]=q;a[1106720]=q;return}function l4(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=c[276674]|0;g=c[348396]|0;h=b[520836]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[1044496]=j;j=(c[348392]|0)+(c[348400]|0)|0;c[348392]=j;i=c[348406]|0;if((j|0)<(i|0)){l=h;m=j;n=i}else{do{j1();o=c[348392]|0;p=c[348406]|0;}while((o|0)>=(p|0));l=b[520836]|0;m=o;n=p}b[520836]=l+2&65535;l=k&65535|f;f=m+6|0;c[348392]=f;if((f|0)>=(n|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}n=(e[520833]|0)+l|0;l=j0(n)|0;f=(d[1106736]|0)<<8|l&255;a[1106736]=l&1;l=(f&65535)>>>1;f=(c[348392]|0)+6|0;c[348392]=f;if((f|0)<(c[348406]|0)){q=l&255;j2(q,n);a[1044496]=q;a[1106728]=q;a[1106720]=q;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));q=l&255;j2(q,n);a[1044496]=q;a[1106728]=q;a[1106720]=q;return}function l5(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=a[f+(h+2)|0]|0;j=(d[f+(h+1)|0]|0)<<8|(d[f+h|0]|0)|(i&255)<<16;h=(c[348399]|0)+(c[348400]|0)+(c[348392]|0)|0;c[348392]=h;if((h|0)<(c[348406]|0)){k=g}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));k=b[520836]|0}a[1044496]=i;b[520836]=k+3&65535;k=j0((e[520833]|0)+j|0)|0;a[1044496]=k;if((a[1041658]&8)==0){j=a[1041660]|0;i=k&255;g=(j&255)+i+(d[1106736]|0)|0;a[1106736]=(g&65280)>>>0>255|0;l=g&255;m=((g^i)&((j^k)&255^128))>>>7&255;n=m&1;a[1106712]=n;a[1041660]=l;a[1106728]=l;a[1106720]=l;return}j=b[520830]|0;i=j&255;g=j&240;j=((a[1106736]|0)+(k&15)&255)+(i&15)&255;if((j&255)>9){o=j+6&15;p=g+16&65535}else{o=j;p=g}g=p+(k&-16&255)&65535;if((g&65535)>144){a[1106736]=1;q=g+96&255&-16}else{a[1106736]=0;q=g&255}g=q|o;l=g;m=((g^k)&(k^-128^i)&255)>>>7;n=m&1;a[1106712]=n;a[1041660]=l;a[1106728]=l;a[1106720]=l;return}function l6(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}l=h+1&65535;b[520836]=l;h=(l&65535)+(e<<24>>24)|0;e=h&65535;k=h&65535;g=i+6|0;c[348392]=g;if((g|0)<(j|0)){m=l}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));m=b[520836]|0}if(((m&65535^h)&61440|0)==0){b[520836]=k;return}else{j4((c[276676]|0)+e|0);return}}function l7(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;d=b[520836]|0;f=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=f;g=(c[348392]|0)+(c[348399]|0)|0;c[348392]=g;h=c[348406]|0;if((g|0)<(h|0)){i=d;j=g;k=h}else{do{j1();l=c[348392]|0;m=c[348406]|0;}while((l|0)>=(m|0));i=b[520836]|0;j=l;k=m}b[520836]=i+1&65535;i=b[520831]|0;m=i+(f&255)&65535;do{if((i&255)<<24>>24==0){n=j;o=k}else{f=j+6|0;c[348392]=f;if((f|0)<(k|0)){n=f;o=k;break}while(1){j1();f=c[348392]|0;l=c[348406]|0;if((f|0)<(l|0)){n=f;o=l;break}}}}while(0);k=(e[520833]|0)+(m&65535)|0;m=n+6|0;c[348392]=m;if((m|0)<(o|0)){p=k&65535;q=j5(p,16777215)|0;r=q&65535;s=c[276674]|0;t=s|r;u=a[1041660]|0;j2(u,t);v=a[1041660]|0;a[1044496]=v;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));p=k&65535;q=j5(p,16777215)|0;r=q&65535;s=c[276674]|0;t=s|r;u=a[1041660]|0;j2(u,t);v=a[1041660]|0;a[1044496]=v;return}function l8(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=c[276676]|0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[1044496]=i;i=(c[348392]|0)+(c[348400]|0)|0;c[348392]=i;if((i|0)<(c[348406]|0)){k=g}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));k=b[520836]|0}g=k+2&65535;b[520836]=g;j4(((g&65535)+(j&65535)&65535)+e|0);return}function l9(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}b[520836]=h+1&65535;h=(b[520832]|0)+(e&255)&65535;e=i+6|0;c[348392]=e;if((e|0)<(j|0)){m=h&65535;n=a[1041660]|0;j2(n,m);o=a[1041660]|0;a[1044496]=o;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));m=h&65535;n=a[1041660]|0;j2(n,m);o=a[1041660]|0;a[1044496]=o;return}function ma(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}b[520836]=h+1&65535;h=b[520831]|0;l=h+(e&255)&65535;do{if((h&255)<<24>>24!=0){e=i+6|0;c[348392]=e;if((e|0)<(j|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j2(a[1041668]|0,l&65535);a[1044496]=a[1041668]|0;return}function mb(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}b[520836]=h+1&65535;h=b[520831]|0;l=h+(e&255)&65535;do{if((h&255)<<24>>24!=0){e=i+6|0;c[348392]=e;if((e|0)<(j|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j2(a[1041660]|0,l&65535);a[1044496]=a[1041660]|0;return}function mc(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}b[520836]=h+1&65535;h=b[520831]|0;l=h+(e&255)&65535;do{if((h&255)<<24>>24!=0){e=i+6|0;c[348392]=e;if((e|0)<(j|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j2(a[1041666]|0,l&65535);a[1044496]=a[1041666]|0;return}function md(){var b=0;b=xb()|0;j2(a[1041660|0]|0,b);a[1044496]=a[1041660|0]|0;return}function me(){var b=0;b=(c[348392]|0)+6|0;c[348392]=b;if((b|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}b=(a[1041668]|0)-1&255;a[1041668]=b;a[1106728]=b;a[1106720]=b;return}function mf(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=a[1041660]|0;e=b[520836]|0;f=a[(c[348396]|0)+(e&65535)|0]|0;a[1044496]=f;g=(c[348392]|0)+(c[348399]|0)|0;c[348392]=g;if((g|0)<(c[348406]|0)){h=e;i=h+1&65535;b[520836]=i;j=f&d;a[1106728]=j;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));h=b[520836]|0;i=h+1&65535;b[520836]=i;j=f&d;a[1106728]=j;return}function mg(){var b=0;b=(c[348392]|0)+6|0;c[348392]=b;if((b|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}b=a[1041666]|0;a[1041660]=b;a[1106728]=b;a[1106720]=b;return}function mh(){var d=0,e=0;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}d=a[1041656]|0;e=b[520832]|0;b[520832]=e-1&65535;j2(d,e&65535);a[1044496]=a[1041656]|0;return}function mi(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[276674]|0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=(d[f+(h+1)|0]|0)<<8|(d[f+h|0]|0);h=(c[348392]|0)+(c[348400]|0)|0;c[348392]=h;if((h|0)<(c[348406]|0)){j=g}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));j=b[520836]|0}b[520836]=j+2&65535;j2(a[1041668]|0,i&65535|e);a[1044496]=a[1041668]|0;return}function mj(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[276674]|0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=(d[f+(h+1)|0]|0)<<8|(d[f+h|0]|0);h=(c[348392]|0)+(c[348400]|0)|0;c[348392]=h;if((h|0)<(c[348406]|0)){j=g}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));j=b[520836]|0}b[520836]=j+2&65535;j2(a[1041660]|0,i&65535|e);a[1044496]=a[1041660]|0;return}function mk(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[276674]|0;f=c[348396]|0;g=b[520836]|0;h=g&65535;i=(d[f+(h+1)|0]|0)<<8|(d[f+h|0]|0);h=(c[348392]|0)+(c[348400]|0)|0;c[348392]=h;if((h|0)<(c[348406]|0)){j=g}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));j=b[520836]|0}b[520836]=j+2&65535;j2(a[1041666]|0,i&65535|e);a[1044496]=a[1041666]|0;return}function ml(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=c[348396]|0;f=b[520836]|0;g=f&65535;h=(d[e+(g+1)|0]|0)<<8|(d[e+g|0]|0)|(d[e+(g+2)|0]|0)<<16;g=(c[348399]|0)+(c[348400]|0)+(c[348392]|0)|0;c[348392]=g;if((g|0)<(c[348406]|0)){i=f;j=i+3&65535;b[520836]=j;k=a[1041660]|0;j2(k,h);l=a[1041660]|0;a[1044496]=l;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));i=b[520836]|0;j=i+3&65535;b[520836]=j;k=a[1041660]|0;j2(k,h);l=a[1041660]|0;a[1044496]=l;return}function mm(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}l=h+1&65535;b[520836]=l;h=(l&65535)+(e<<24>>24)|0;e=h&65535;k=h&65535;if((a[1106736]|0)!=0){return}g=i+6|0;c[348392]=g;if((g|0)<(j|0)){m=l}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));m=b[520836]|0}if(((m&65535^h)&61440|0)==0){b[520836]=k;return}else{j4((c[276676]|0)+e|0);return}}function mn(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}b[520836]=h+1&65535;h=b[520831]|0;l=h+(e&255)&65535;do{if((h&255)<<24>>24!=0){e=i+6|0;c[348392]=e;if((e|0)<(j|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j=(j5(l&65535,16777215)|0)&65535;l=c[276674]|j;j=(c[348392]|0)+6|0;c[348392]=j;if((j|0)<(c[348406]|0)){m=b[520834]|0;n=m&65535;o=n+l|0;p=a[1041660]|0;j2(p,o);q=a[1041660]|0;a[1044496]=q;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));m=b[520834]|0;n=m&65535;o=n+l|0;p=a[1041660]|0;j2(p,o);q=a[1041660]|0;a[1044496]=q;return}function mo(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=b[520836]|0;e=a[(c[348396]|0)+(d&65535)|0]|0;a[1044496]=e;f=(c[348392]|0)+(c[348399]|0)|0;c[348392]=f;g=c[348406]|0;if((f|0)<(g|0)){h=d;i=f;j=g}else{do{j1();k=c[348392]|0;l=c[348406]|0;}while((k|0)>=(l|0));h=b[520836]|0;i=k;j=l}b[520836]=h+1&65535;h=b[520831]|0;l=h+(e&255)&65535;do{if((h&255)<<24>>24!=0){e=i+6|0;c[348392]=e;if((e|0)<(j|0)){break}do{j1();}while((c[348392]|0)>=(c[348406]|0))}}while(0);j=(j5(l&65535,16777215)|0)&65535;j2(a[1041660]|0,c[276674]|j);a[1044496]=a[1041660]|0;return}function mp(){var d=0,f=0,g=0,h=0;d=j0(c[260418]|0)|0;a[1044496]=d;b[520836]=(b[520836]|0)+1&65535;f=(b[520832]|0)+(d&255)&65535;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}d=(j5(f&65535,16777215)|0)&65535;f=(e[520834]|0)+d+(c[276674]|0)&16777215;d=(c[348392]|0)+6|0;c[348392]=d;if((d|0)<(c[348406]|0)){g=a[1041660]|0;j2(g,f);h=a[1041660]|0;a[1044496]=h;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));g=a[1041660]|0;j2(g,f);h=a[1041660]|0;a[1044496]=h;return}function mq(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=b[520836]|0;f=a[(c[348396]|0)+(d&65535)|0]|0;g=(c[348392]|0)+(c[348399]|0)|0;c[348392]=g;h=c[348406]|0;if((g|0)<(h|0)){i=d;j=g;k=h}else{do{j1();l=c[348392]|0;m=c[348406]|0;}while((l|0)>=(m|0));i=b[520836]|0;j=l;k=m}b[520836]=i+1&65535;i=b[520831]|0;m=i+(f&255)&65535;do{if((i&255)<<24>>24==0){n=j;o=k}else{f=j+6|0;c[348392]=f;if((f|0)<(k|0)){n=f;o=k;break}while(1){j1();f=c[348392]|0;l=c[348406]|0;if((f|0)<(l|0)){n=f;o=l;break}}}}while(0);k=(e[520833]|0)+(m&65535)|0;m=n+6|0;c[348392]=m;if((m|0)<(o|0)){p=k&65535;q=a[1041668]|0;j2(q,p);r=a[1041668]|0;a[1044496]=r;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));p=k&65535;q=a[1041668]|0;j2(q,p);r=a[1041668]|0;a[1044496]=r;return}function mr(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;d=b[520836]|0;f=a[(c[348396]|0)+(d&65535)|0]|0;g=(c[348392]|0)+(c[348399]|0)|0;c[348392]=g;h=c[348406]|0;if((g|0)<(h|0)){i=d;j=g;k=h}else{do{j1();l=c[348392]|0;m=c[348406]|0;}while((l|0)>=(m|0));i=b[520836]|0;j=l;k=m}b[520836]=i+1&65535;i=b[520831]|0;m=i+(f&255)&65535;do{if((i&255)<<24>>24==0){n=j;o=k}else{f=j+6|0;c[348392]=f;if((f|0)<(k|0)){n=f;o=k;break}while(1){j1();f=c[348392]|0;l=c[348406]|0;if((f|0)<(l|0)){n=f;o=l;break}}}}while(0);k=(e[520833]|0)+(m&65535)|0;m=n+6|0;c[348392]=m;if((m|0)<(o|0)){p=k&65535;q=a[1041660]|0;j2(q,p);r=a[1041660]|0;a[1044496]=r;return}do{j1();}while((c[348392]|0)>=(c[348406]|0));p=k&65535;q=a[1041660]|0;j2(q,p);r=a[1041660]|0;a[1044496]=r;return}
function HB(f,g){f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;do{if((a[1393610]|0)==0){h=g}else{i=c[348404]|0;do{if((i|0)>-1){if((a[1183776+(i*22|0)|0]|0)==0){break}return}}while(0);if((g&65535)<=8703){h=g;break}h=g&255|8448}}while(0);g=h&65535;L9:do{if((g&65472|0)==8512){i=g&3;j=ab((c[348392]|0)-(c[59e3]|0)|0,c[1502]|0)|0;jD(((j+(c[42380]|0)|0)>>>0)/((c[1504]|0)>>>0)|0);a[436864+(i|20)|0]=f;a[437624+(i|244)|0]=f}else{if((h&65535)>=8580){if((a[799121]|0)!=0&(h&65535)>12287&(h&65535)<13056){switch(g|0){case 12336:{i=(c[263195]|0)+12336|0;j=((a[i]^f)&32)==0;a[i]=f;if(j){return}if((f&32)==0|a[101712]){c[276723]=0;c[276722]=0;a[1108308]=0;return}j=c[263195]|0;do{if((a[j+12336|0]&32)!=0){if((a[j+12346|0]&24)!=24){break}yj()}}while(0);a[101712]=1;return};case 12337:case 12339:{a[(c[263195]|0)+g|0]=f;return};case 12340:case 12342:{a[(c[263195]|0)+g|0]=f&127;return};case 12343:{a[(c[263195]|0)+12343|0]=f;return};case 12344:{a[(c[263195]|0)+12344|0]=f;c[277209]=1;return};case 12345:case 12346:{a[(c[263195]|0)+g|0]=f;return};case 12348:{a[(c[263195]|0)+12348|0]=f;j=f&3;c[276721]=j;c[276814]=c[1107268+(j<<2)>>2];return};case 12351:{a[(c[263195]|0)+12351|0]=f;return};case 12319:{a[(c[263195]|0)+12319|0]=f;j=(c[263195]|0)+12336|0;a[j]=a[j]|32;if(a[101712]|0){return}j=c[263195]|0;do{if((a[j+12336|0]&32)!=0){if((a[j+12346|0]&24)!=24){break}yj()}}while(0);a[101712]=1;return};case 12347:{return};default:{a[(c[263195]|0)+g|0]=f;if((h&65535)<=12543){return}if((g&15|0)!=15){return}c[276723]=c[276723]|1<<(g>>>4&31);return}}}if((a[799123]|0)!=0&(h&65535)>8703){if((h&65535)<9216){HW(f,g);return}else{a[(c[263195]|0)+g|0]=f;return}}if((a[799131]|0)!=0&(h&65535)>8583&(h&65535)<8608){switch(g|0){case 8584:{a[1394317]=f;break L9;break};case 8585:{a[1394318]=f;break L9;break};case 8586:{a[1394319]=f;break L9;break};case 8587:{a[1394320]=f;break L9;break};case 8588:{a[1394321]=f;break L9;break};case 8590:{a[1394323]=f;break L9;break};case 8591:{a[1394323]=f-((d[1394323]|0)>>>1)&255;a[1394324]=(f&255)>>>1;a[1394325]=-128;break L9;break};case 8593:{a[1394326]=f;a[1394276]=0;break L9;break};case 8594:{a[1394327]=1;a[1394325]=-128;break L9;break};case 8595:{a[1394328]=f;break L9;break};case 8596:{a[1394329]=f;break L9;break};case 8599:{a[1394332]=f;break L9;break};case 8601:{a[1394334]=f;break L9;break};default:{break L9}}}if(!((a[799130]|0)!=0&h<<16>>16==10241)){break}j=f&15;if((j<<24>>24|0)==13){c[58916]=2;c[58918]=-1;break}else if((j<<24>>24|0)==14){c[58916]=1;break}else if((j<<24>>24|0)==15){break}else{i=c[58916]|0;if((i|0)==1){if(j<<24>>24==0){c[58916]=3;c[58918]=0;break}c[58916]=0;if(j<<24>>24!=4){break}c[58918]=-1;X2(1041680,0,13);break}else if((i|0)!=3){break}i=c[58918]|0;if(i>>>0>=12){break}k=i+1|0;c[58918]=k;a[1041680+i|0]=j;if((k|0)!=12){break}k=((d[1041687]|0)*10|0)+(d[1041686]|0)|0;j=d[1041688]|0;i=(d[1041689]|0)+1e3+((d[1041690]|0)*10|0)+((d[1041691]|0)*100|0)|0;l=i>>>0<1900?1900:i;m=j>>>0>12?12:j;j=(m|0)==0?1:m;m=k>>>0>31?31:k;k=(m|0)==0?1:m;if(l>>>0>1900){m=1900;n=0;do{if((m&3|0)==0){o=((m>>>0)%100|0|0)!=0|((m>>>0)%400|0|0)==0?366:365}else{o=365}n=o+n|0;m=m+1|0;}while(m>>>0<l>>>0);p=i>>>0>1900?i:1900;q=n}else{p=1900;q=0}if(j>>>0>1){l=(((p>>>0)%100|0|0)!=0|((p>>>0)%400|0|0)==0)&1;if((p&3|0)==0){m=1;r=q;while(1){s=m-1|0;t=(c[7592+(s<<2)>>2]|0)+r+((s|0)==1?l:0)|0;s=m+1|0;if(s>>>0<j>>>0){m=s;r=t}else{u=t;break}}}else{r=1;m=q;while(1){l=(c[7592+(r-1<<2)>>2]|0)+m|0;n=r+1|0;if(n>>>0<j>>>0){r=n;m=l}else{u=l;break}}}}else{u=q}c[58918]=13;a[1041692]=(((u+k|0)>>>0)%7|0)&255;break}}m=f&255;r=c[263195]|0;j=(a[r+g|0]|0)!=f<<24>>24;switch(g|0){case 8448:{do{if(j){if((c[276540]|0)!=(c[276539]|0)){Hy()}l=m&15;L126:do{if((d[1044485]|0)!=(l|0)){a[1106089]=1;a[1044485]=l&255;n=7080+(l<<5)|0;c[276541]=n;i=0;t=n;while(1){n=e[1041774+(i<<1)>>1]|0;b[1106168+(i<<1)>>1]=d[t+(n>>>5&31)|0]<<6|d[t+(n&31)|0]<<11|d[t+(n>>>10&31)|0];n=i+1|0;if((n|0)>=256){break L126}i=n;t=c[276541]|0}}}while(0);l=c[263195]|0;if((a[l+8448|0]^f)<<24>>24>=0){v=l;break}a[1044481]=(f&255)>>>7;v=l}else{v=r}}while(0);if((a[v+8448|0]|0)>=0){break L9}if((c[348394]|0)!=((e[522243]|0)+1|0)){break L9}k=b[521917]|0;b[521916]=k;if((a[1043836]|0)==0){w=0}else{w=(k&65535)>>>1&127}if(!((a[1043837]&1)==0&(a[1044388]|0)==w<<24>>24)){a[1044388]=w;a[1106088]=1}a[1043837]=0;break L9;break};case 8449:{if(!j){break L9}if((c[276540]|0)!=(c[276539]|0)){Hy()}b[521913]=m<<14&65535;b[521914]=m>>>3<<13&24576;a[1043830]=(f&255)>>>5;a[1106088]=1;break L9;break};case 8450:{k=d[r+8451|0]<<8&256|m;l=k&65535;b[521916]=l;a[1043837]=2;a[1043838]=0;b[521917]=l;if((a[1043836]|0)==0){break L9}if((d[1044388]|0)==(k>>>1|0)){break L9}a[1044388]=(l&65535)>>>1&127;a[1106088]=1;break L9;break};case 8451:{l=d[r+8450|0]|m<<8&256;k=l&65535;b[521916]=k;t=(f&255)>>>7;a[1043836]=t;i=a[1044388]|0;do{if(t<<24>>24==0){if(i<<24>>24==0){break}a[1044388]=0;a[1106088]=1}else{if((i&255|0)==(l>>>1|0)){break}a[1044388]=(k&65535)>>>1&127;a[1106088]=1}}while(0);a[1043837]=0;a[1043838]=0;b[521917]=k;break L9;break};case 8452:{HE(f);break L9;break};case 8453:{if(!j){break L9}if((c[276540]|0)==(c[276539]|0)){x=r}else{Hy();x=c[263195]|0}a[1041726]=(f&255)>>>4&1;a[1041738]=(f&255)>>>5&1;a[1041750]=(f&255)>>>6&1;a[1041762]=(f&255)>>>7;a[1041768]=f&7;a[1041769]=(m&15|0)==9|0;a[1106149]=a[x+8499|0]&1;break L9;break};case 8454:{if((a[1044438]|0)==0|j^1){break L9}if((c[276540]|0)!=(c[276539]|0)){Hy()}l=c[348394]|0;a[1044433]=l&255;if((l&255)>>>0>(e[522243]|0)>>>0){a[1044433]=0}a[1044432]=((f&255)>>>4)+1&255;a[1044434]=f&1;a[1044435]=f&2;a[1044436]=f&4;a[1044437]=f&8;break L9;break};case 8455:case 8456:case 8457:case 8458:{if(!j){break L9}if((c[276540]|0)!=(c[276539]|0)){Hy()}l=g-8455|0;b[1041730+(l*12|0)>>1]=f&3;b[1041720+(l*12|0)>>1]=m<<8&31744;break L9;break};case 8459:{if(!j){break L9}if((c[276540]|0)!=(c[276539]|0)){Hy()}b[520864]=m<<12&28672;b[520870]=m>>>4<<12&28672;break L9;break};case 8460:{if(!j){break L9}if((c[276540]|0)!=(c[276539]|0)){Hy()}b[520876]=m<<12&28672;b[520882]=m>>>4<<12&28672;break L9;break};case 8461:{l=m<<8;b[520861]=(a[1044489]&248|l|(e[520861]|0)>>>8&7)&65535;b[522214]=(d[1044490]|l)&65535;a[1044489]=f;a[1044490]=f;break L9;break};case 8462:{l=m<<8;b[520862]=(d[1044489]|l)&65535;b[522215]=(d[1044490]|l)&65535;a[1044489]=f;a[1044490]=f;break L9;break};case 8463:{b[520867]=(a[1044489]&248|m<<8|(e[520867]|0)>>>8&7)&65535;a[1044489]=f;break L9;break};case 8464:{b[520868]=(d[1044489]|m<<8)&65535;a[1044489]=f;break L9;break};case 8465:{b[520873]=(a[1044489]&248|m<<8|(e[520873]|0)>>>8&7)&65535;a[1044489]=f;break L9;break};case 8466:{b[520874]=(d[1044489]|m<<8)&65535;a[1044489]=f;break L9;break};case 8467:{b[520879]=(a[1044489]&248|m<<8|(e[520879]|0)>>>8&7)&65535;a[1044489]=f;break L9;break};case 8468:{b[520880]=(d[1044489]|m<<8)&65535;a[1044489]=f;break L9;break};case 8469:{a[1041704]=(f&255)>>>7;l=m&3;if((l|0)==0){a[1041705]=1}else if((l|0)==1){a[1041705]=32}else if((l|0)==2){a[1041705]=-128}else if((l|0)==3){a[1041705]=-128}l=m&12;if((l|0)==0){b[520855]=0;break L9}else{i=l>>>2;l=b[148528+(i<<1)>>1]|0;b[520855]=l;b[520854]=(l<<3)-1&65535;b[520856]=b[148520+(i<<1)>>1]|0;break L9}break};case 8470:{b[520853]=(b[520853]&-256&65535|m)&65535;a[1106148]=1;break L9;break};case 8471:{b[520853]=(b[520853]&255|m<<8)&65535;a[1106148]=1;break L9;break};case 8472:{a[1106148]=1;HC(f);break L9;break};case 8473:{a[1106148]=1;HD(f);break L9;break};case 8474:{if(!j){break L9}if((c[276540]|0)!=(c[276539]|0)){Hy()}i=(f&255)>>>6;a[1044415]=i<<24>>24==1?0:i;a[1044414]=(f&255)>>>1&1;a[1044413]=f&1;break L9;break};case 8475:{b[522208]=(d[1044490]|m<<8)&65535;a[1044488]=1;a[1044490]=f;break L9;break};case 8476:{b[522209]=(d[1044490]|m<<8)&65535;a[1044488]=1;a[1044490]=f;break L9;break};case 8477:{b[522210]=(d[1044490]|m<<8)&65535;a[1044490]=f;break L9;break};case 8478:{b[522211]=(d[1044490]|m<<8)&65535;a[1044490]=f;break L9;break};case 8479:{b[522212]=(d[1044490]|m<<8)&65535;a[1044490]=f;break L9;break};case 8480:{b[522213]=(d[1044490]|m<<8)&65535;a[1044490]=f;break L9;break};case 8481:{a[1041771]=0;a[1041772]=0;a[1041773]=f;break L9;break};case 8482:{HF(f);break L9;break};case 8483:{if(!j){break L9}if((c[276540]|0)!=(c[276539]|0)){Hy()}a[1044457]=(f&255)>>>1&1;a[1044458]=(f&255)>>>5&1;a[1044463]=(f&255)>>>3&1;a[1044464]=(f&255)>>>7;a[1044469]=f&1^1;a[1044470]=(f&255)>>>4&1^1;a[1044475]=(f&255)>>>2&1^1;a[1044476]=(f&255)>>>6&1^1;a[1044444]=1;break L9;break};case 8484:{if(!j){break L9}if((c[276540]|0)!=(c[276539]|0)){Hy()}a[1044459]=(f&255)>>>1&1;a[1044460]=(f&255)>>>5&1;a[1044465]=(f&255)>>>3&1;a[1044466]=(f&255)>>>7;a[1044471]=f&1^1;a[1044472]=(f&255)>>>4&1^1;a[1044477]=(f&255)>>>2&1^1;a[1044478]=(f&255)>>>6&1^1;a[1044444]=1;break L9;break};case 8485:{if(!j){break L9}if((c[276540]|0)!=(c[276539]|0)){Hy()}a[1044461]=(f&255)>>>1&1;a[1044462]=(f&255)>>>5&1;a[1044467]=(f&255)>>>3&1;a[1044468]=(f&255)>>>7;a[1044473]=f&1^1;a[1044474]=(f&255)>>>4&1^1;a[1044479]=(f&255)>>>2&1^1;a[1044480]=(f&255)>>>6&1^1;a[1044444]=1;break L9;break};case 8486:{if(!j){break L9}if((c[276540]|0)!=(c[276539]|0)){Hy()}a[1044440]=f;a[1044444]=1;break L9;break};case 8487:{if(!j){break L9}if((c[276540]|0)!=(c[276539]|0)){Hy()}a[1044441]=f;a[1044444]=1;break L9;break};case 8488:{if(!j){break L9}if((c[276540]|0)!=(c[276539]|0)){Hy()}a[1044442]=f;a[1044444]=1;break L9;break};case 8489:{if(!j){break L9}if((c[276540]|0)!=(c[276539]|0)){Hy()}a[1044443]=f;a[1044444]=1;break L9;break};case 8490:{if(!j){break L9}if((c[276540]|0)!=(c[276539]|0)){Hy()}a[1044451]=f&3;a[1044452]=(f&255)>>>2&3;a[1044453]=(f&255)>>>4&3;a[1044454]=(f&255)>>>6;a[1044444]=1;break L9;break};case 8491:{if(!j){break L9}if((c[276540]|0)!=(c[276539]|0)){Hy()}a[1044455]=f&3;a[1044456]=(f&255)>>>2&3;a[1044444]=1;break L9;break};case 8492:case 8493:case 8494:case 8495:case 8496:{if(!j){break L9}if((c[276540]|0)!=(c[276539]|0)){Hy()}a[1044444]=1;break L9;break};case 8497:{if(!j){break L9}if((c[276540]|0)==(c[276539]|0)){break L9}Hy();break L9;break};case 8498:{if(!j){break L9}if(((c[276540]|0)!=(c[276539]|0)&d[17264]|0)!=0){Hy()}if((m&128|0)!=0){a[1044484]=f&31}if((m&64|0)!=0){a[1044483]=f&31}if((m&32|0)==0){break L9}a[1044482]=f&31;break L9;break};case 8499:{i=a[r+8499|0]|0;if(i<<24>>24==f<<24>>24){break L9}if(((i^f)&8)!=0){if((c[276540]|0)!=(c[276539]|0)){Hy()}a[1106151]=f&8}do{if((m&4|0)==0){b[522243]=224}else{b[522243]=239;if((a[1106153]|0)==0){c[276671]=239;break}else{c[276671]=478;break}}}while(0);r=a[(c[263195]|0)+8499|0]|0;if(((r^f)&3)==0){break L9}if((c[276540]|0)==(c[276539]|0)){y=r}else{Hy();y=a[(c[263195]|0)+8499|0]|0}if(((y^f)&2)!=0){a[1106088]=1}a[1106149]=f&1;a[1106150]=f&2;break L9;break};case 8576:{if((a[1393611]|0)==0){r=c[260429]|0;c[260429]=r+1;a[(c[263191]|0)+r|0]=f}c[260429]=c[260429]&131071;break L9;break};case 8577:{if((a[1393611]|0)!=0){break L9}c[260429]=c[260429]&130816|m;break L9;break};case 8578:{if((a[1393611]|0)!=0){break L9}c[260429]=c[260429]&65791|m<<8;break L9;break};case 8579:{if((a[1393611]|0)!=0){break L9}c[260429]=c[260429]&65535|m<<16&65536;break L9;break};case 8500:case 8501:case 8502:case 8503:case 8504:case 8505:case 8506:case 8507:case 8508:case 8509:case 8510:case 8511:{return};default:{break L9}}}}while(0);a[(c[263195]|0)+g|0]=f;return}function HC(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;g=b[520855]|0;h=b[520853]|0;i=h&65535;if(g<<16>>16==0){j=i<<1&65534;a[(c[263194]|0)+j|0]=f;k=j}else{j=b[520854]|0;l=j&h&65535;h=((j&65535^32767)&i)+(l>>>((e[520856]|0)>>>0))+((l&(g&65535)+536870911)<<3)<<1&65534;a[(c[263194]|0)+h|0]=f;k=h}h=k>>>4;a[(c[276530]|0)+h|0]=0;f=k>>>5;a[(c[276531]|0)+f|0]=0;a[(c[276532]|0)+(k>>>6)|0]=0;a[(c[276533]|0)+h|0]=0;k=h+4095&4095;a[(c[276533]|0)+k|0]=0;a[(c[276534]|0)+h|0]=0;a[(c[276534]|0)+k|0]=0;a[(c[276535]|0)+f|0]=0;k=f+2047&2047;a[(c[276535]|0)+k|0]=0;a[(c[276536]|0)+f|0]=0;a[(c[276536]|0)+k|0]=0;if((a[1041704]|0)!=0){return}b[520853]=(b[520853]|0)+(d[1041705]|0)&65535;return}function HD(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;g=b[520855]|0;h=b[520853]|0;i=h&65535;if(g<<16>>16==0){j=i<<1&65534|1;a[(c[263194]|0)+j|0]=f;k=j}else{j=b[520854]|0;l=j&h&65535;h=((j&65535^32767)&i)+(l>>>((e[520856]|0)>>>0))+((l&(g&65535)+536870911)<<3)<<1&65534|1;a[(c[263194]|0)+h|0]=f;k=h}h=k>>>4;a[(c[276530]|0)+h|0]=0;f=k>>>5;a[(c[276531]|0)+f|0]=0;a[(c[276532]|0)+(k>>>6)|0]=0;a[(c[276533]|0)+h|0]=0;k=h+4095&4095;a[(c[276533]|0)+k|0]=0;a[(c[276534]|0)+h|0]=0;a[(c[276534]|0)+k|0]=0;a[(c[276535]|0)+f|0]=0;k=f+2047&2047;a[(c[276535]|0)+k|0]=0;a[(c[276536]|0)+f|0]=0;a[(c[276536]|0)+k|0]=0;if((a[1041704]|0)==0){return}b[520853]=(b[520853]|0)+(d[1041705]|0)&65535;return}function HE(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=b[521916]|0;h=g&65535;if((h&256|0)!=0){i=a[1043837]|0;j=i&1|h<<1&542;k=f&255;l=1043844+j|0;if((a[l]|0)==f<<24>>24){m=i}else{i=j<<2&124;if((c[276540]|0)!=(c[276539]|0)){Hy()}a[l]=f;a[1106088]=1;l=1042286+(i*12|0)|0;b[l>>1]=b[l>>1]&255|b[161864+((k&1)<<1)>>1];l=i|1;a[1042296+(i*12|0)|0]=f&2;j=1042286+(l*12|0)|0;b[j>>1]=b[j>>1]&255|b[161864+((k>>>2&1)<<1)>>1];j=l+1|0;a[1042296+(l*12|0)|0]=f&8;l=1042286+(j*12|0)|0;b[l>>1]=b[l>>1]&255|b[161864+((k>>>4&1)<<1)>>1];l=i|3;a[1042296+(j*12|0)|0]=f&32;j=1042286+(l*12|0)|0;b[j>>1]=b[j>>1]&255|b[161864+((k>>>6&1)<<1)>>1];a[1042296+(l*12|0)|0]=f&-128;m=a[1043837]|0}l=m^1;a[1043837]=l;if((l&1)==0){l=(b[521916]|0)+1&65535;m=l&511;b[521916]=m;if((a[1043836]|0)==0){return}if((d[1044388]|0)==((m&65535)>>>1|0)){return}a[1044388]=(l&65535)>>>1&127;a[1106088]=1;return}else{if((a[1043836]|0)==0){return}if((b[521916]&1)==0){return}a[1106088]=1;return}}l=a[1043837]|0;m=b[521921]|0;if((l&1)==0){b[521921]=m&-256|f&255;a[1043837]=l|1;if((a[1043836]|0)==0){return}if((g&1)==0){return}a[1106088]=1;return}g=m&255;l=m&255;m=f&255;b[521921]=g|m<<8;k=h<<1;h=1043844+k|0;if((g&65535|0)==(d[h]|0)){if((a[1043844+(k|1)|0]|0)!=f<<24>>24){n=292}}else{n=292}do{if((n|0)==292){if((c[276540]|0)!=(c[276539]|0)){Hy()}a[h]=l;a[1043844+(k|1)|0]=f;a[1106088]=1;if((k&2|0)==0){j=(e[521916]|0)>>>1;i=1042286+(j*12|0)|0;b[i>>1]=b[i>>1]&-256|g;b[1042288+(j*12|0)>>1]=m;break}else{j=(e[521916]|0)>>>1;b[1042292+(j*12|0)>>1]=b[521921]&511;a[1042295+(j*12|0)|0]=(f&255)>>>1&7;a[1042294+(j*12|0)|0]=(f&255)>>>4&3;a[1042290+(j*12|0)|0]=(f&255)>>>6&1;a[1042291+(j*12|0)|0]=(f&255)>>>7;break}}}while(0);a[1043837]=a[1043837]&-2;f=(b[521916]|0)+1&65535;b[521916]=f;if((a[1043836]|0)==0){return}if((d[1044388]|0)==((f&65535)>>>1|0)){return}a[1044388]=(f&65535)>>>1&127;a[1106088]=1;return}function HF(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=f&255;if((a[1041771]|0)==0){f=a[1041773]|0;h=b[1041774+((f&255)<<1)>>1]|0;if((g|0)==(h&255|0)){i=a[1041771]|0;j=i^1;a[1041771]=j;return}if((c[276540]|0)==(c[276539]|0)){k=f;l=h}else{Hy();h=a[1041773]|0;k=h;l=b[1041774+((h&255)<<1)>>1]|0}b[1041774+((k&255)<<1)>>1]=l&32512;l=1041774+(d[1041773]<<1)|0;b[l>>1]=(e[l>>1]|g)&65535;l=c[276541]|0;k=d[1041773]|0;h=e[1041774+(k<<1)>>1]|0;b[1106168+(k<<1)>>1]=d[l+(h>>>5&31)|0]<<6|d[l+(g&31)|0]<<11|d[l+(h>>>10&31)|0];i=a[1041771]|0;j=i^1;a[1041771]=j;return}else{h=g&127;l=a[1041773]|0;k=b[1041774+((l&255)<<1)>>1]|0;if((h|0)==((k&65535)>>>8|0)){m=l}else{if((c[276540]|0)==(c[276539]|0)){n=l;o=k}else{Hy();k=a[1041773]|0;n=k;o=b[1041774+((k&255)<<1)>>1]|0}b[1041774+((n&255)<<1)>>1]=o&255;o=1041774+(d[1041773]<<1)|0;b[o>>1]=(e[o>>1]|h<<8)&65535;h=a[1041773]|0;o=h&255;n=e[1041774+(o<<1)>>1]|0;k=c[276541]|0;b[1106168+(o<<1)>>1]=d[k+(n>>>5&31)|0]<<6|d[k+(n&31)|0]<<11|d[k+(g>>>2&31)|0];m=h}a[1041773]=m+1&255;i=a[1041771]|0;j=i^1;a[1041771]=j;return}}function HG(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;if((f&65535)<8448){g=a[1044496]|0;return g|0}do{if((a[1393610]|0)==0){h=f}else{i=c[348404]|0;do{if((i|0)>-1){if((a[1183776+(i*22|0)|0]|0)!=0){break}g=a[1044496]|0;return g|0}}while(0);if((f&65535)<=8703){h=f;break}h=f&255|8448}}while(0);f=h&65535;if((f&65472|0)==8512){i=ab((c[348392]|0)-(c[59e3]|0)|0,c[1502]|0)|0;jD(((i+(c[42380]|0)|0)>>>0)/((c[1504]|0)>>>0)|0);g=a[436864+(f&3|4)|0]|0;return g|0}if((h&65535)>=8580){if((a[799121]|0)!=0&(h&65535)>12287&(h&65535)<13056){i=c[263195]|0;j=a[i+f|0]|0;if(h<<16>>16!=12337){g=j;return g|0}k=a[1393588]&-5;a[1393588]=k;if(k<<24>>24==0){c[348395]=c[348395]&-2049}a[i+12337|0]=j&127;g=j;return g|0}if((a[799123]|0)!=0&(h&65535)>8703){switch(f|0){case 8972:{g=a[(c[263195]|0)+8972|0]|0;return g|0};case 8973:{j=c[263195]|0;i=a[j+8973|0]|0;if((a[j+8792|0]|0)>=0){g=i;return g|0}HV(1,0);g=i;return g|0};case 8970:{g=c[840932>>2]&255;return g|0};case 8960:{g=a[1393588]&-96|a[(c[263195]|0)+8713|0]&95;return g|0};case 8961:{i=c[263195]|0;g=a[i+8961|0]&-16|a[i+8704|0]&15;return g|0};case 8966:{g=c[210232]&255;return g|0};case 8967:{i=840928;g=((c[i>>2]|0)>>>8|c[i+4>>2]<<24)&255;return g|0};case 8968:{i=840928;g=((c[i>>2]|0)>>>16|c[i+4>>2]<<16)&255;return g|0};case 8969:{i=840928;g=((c[i>>2]|0)>>>24|c[i+4>>2]<<8)&255;return g|0};default:{g=a[(c[263195]|0)+f|0]|0;return g|0}}}if(!((a[799131]|0)!=0&(h&65535)>8583&(h&65535)<8608)){if(!((a[799130]|0)!=0&h<<16>>16==10240)){g=a[1044496]|0;return g|0}if((c[58916]|0)!=2){g=0;return g|0}h=c[58918]|0;if((h|0)<0){i=eG(0)|0;a[1041696]=i&255;a[1041697]=i>>>8&255;a[1041698]=i>>>16&255;a[1041699]=i>>>24&255;c[58918]=(c[58918]|0)+1;g=15;return g|0}if((h|0)>12){c[58918]=-1;g=15;return g|0}else{c[58918]=h+1;g=a[1041680+h|0]|0;return g|0}}switch(f|0){case 8584:{g=a[1394317]|0;return g|0};case 8585:{g=a[1394318]|0;return g|0};case 8586:{g=a[1394319]|0;return g|0};case 8588:{g=a[1394321]|0;return g|0};case 8590:{g=a[1394323]|0;return g|0};case 8591:{g=a[1394324]|0;return g|0};case 8592:{g=a[1394325]|0;return g|0};case 8594:{h=a[1394276]|0;i=h+1&255;a[1394276]=i;j=a[1394373+(h&255)|0]|0;if(i<<24>>24==32){a[1394276]=0}i=(c[348556]|0)+1|0;c[348556]=i;if((i|0)>999){c[348556]=0;i=(c[348558]|0)+1|0;c[348558]=i;l=i}else{l=c[348558]|0}if((l|0)>59){c[348558]=0;i=(c[348560]|0)+1|0;c[348560]=i;m=i;n=0}else{m=c[348560]|0;n=l&255}if((m|0)>59){c[348560]=0;l=(c[348562]|0)+1|0;c[348562]=l;o=l;p=0}else{o=c[348562]|0;p=m&255}if((o|0)>23){c[348562]=0;q=0}else{q=o&255}a[1394383]=n;a[1394384]=p;a[1394385]=q;g=j;return g|0};case 8595:{g=a[1394328]&-13;return g|0};case 8596:{g=a[1394329]|0;return g|0};case 8598:{g=a[1394331]|0;return g|0};case 8599:{g=a[1394332]|0;return g|0};case 8601:{g=a[1394334]|0;return g|0};default:{g=a[1044496]|0;return g|0}}}switch(f|0){case 8511:{j=c[348394]|0;q=b[522205]|0;p=q&65535;do{if((j|0)>(p|0)){r=410}else{if((j|0)!=(p|0)){break}if((c[348392]|0)>=(e[522204]<<2|0)){r=410}}}while(0);if((r|0)==410){p=c[263195]|0;if((a[p+16915|0]|0)<0){a[1044412]=1;b[522203]=q;b[522202]=b[522204]|0;q=p+8511|0;a[q]=a[q]|64}b[522205]=1e3}a[1044402]=0;a[1044403]=0;q=(c[263195]|0)+8511|0;p=a[q]|0;j=a[1044494]&32|p&-64|((a[799146]|0)!=0?16:0)|3;a[q]=p&-65;a[1044494]=j;g=j;return g|0};case 8576:{if((a[1393611]|0)==0){j=c[260429]|0;p=j+1|0;c[260429]=p;q=a[(c[263191]|0)+j|0]|0;c[260429]=p&131071;g=q;return g|0}else{g=a[1044496]|0;return g|0}break};case 8509:{q=c[348394]|0;p=b[522205]|0;j=p&65535;do{if((q|0)>(j|0)){r=397}else{if((q|0)!=(j|0)){break}if((c[348392]|0)>=(e[522204]<<2|0)){r=397}}}while(0);if((r|0)==397){j=c[263195]|0;if((a[j+16915|0]|0)<0){a[1044412]=1;b[522203]=p;b[522202]=b[522204]|0;p=j+8511|0;a[p]=a[p]|64}b[522205]=1e3}p=a[1044403]|0;if(p<<24>>24==0){s=b[522203]&255}else{s=((e[522203]|0)>>>8&1|a[1044494]&254)&255}a[1044403]=p^1;a[1044494]=s;g=s;return g|0};case 8452:case 8453:case 8454:case 8456:case 8457:case 8458:case 8468:case 8469:case 8470:case 8472:case 8473:case 8474:case 8484:case 8485:case 8486:case 8488:case 8489:case 8490:{g=a[1044493]|0;return g|0};case 8500:case 8501:case 8502:{if((a[1044488]|0)!=0){s=ab(b[522209]>>8,b[522208]|0)|0;a[(c[263195]|0)+8500|0]=s&255;a[(c[263195]|0)+8501|0]=s>>>8&255;a[(c[263195]|0)+8502|0]=s>>>16&255;a[1044488]=0}s=a[(c[263195]|0)+f|0]|0;a[1044493]=s;g=s;return g|0};case 8503:{s=c[263195]|0;if((a[s+16915|0]|0)<0){f=c[348392]|0;a[1044412]=1;b[522203]=c[348394]&65535;if((c[199741]|0)==(c[199740]|0)){p=(f|0)>1291?f-2|0:f;t=(p|0)>1307?p-2|0:p}else{t=f}b[522202]=((t|0)/4|0)&65535;t=s+8511|0;a[t]=a[t]|64}t=c[348394]|0;s=e[522205]|0;do{if((t|0)>(s|0)){r=350}else{if((t|0)!=(s|0)){break}if((c[348392]|0)>=(e[522204]<<2|0)){r=350}}}while(0);if((r|0)==350){b[522205]=1e3}g=a[1044496]|0;return g|0};case 8504:{s=b[521916]|0;t=s&65535;f=a[1043837]|0;p=(f&1)!=0;j=t<<1;do{if((t&256|0)==0){if(!p){u=a[1043844+j|0]|0;break}q=a[1043844+(j|1)|0]|0;n=s+1&65535;b[521916]=n;if((a[1043836]|0)==0){u=q;break}if((d[1044388]|0)==((n&65535)>>>1|0)){u=q;break}a[1044388]=(n&65535)>>>1&127;a[1106088]=1;u=q}else{q=j&542;if(!p){u=a[1043844+q|0]|0;break}n=a[1043844+(q|1)|0]|0;q=s+1&65535;o=q&511;b[521916]=o;if((a[1043836]|0)==0){u=n;break}if((d[1044388]|0)==((o&65535)>>>1|0)){u=n;break}a[1044388]=(q&65535)>>>1&127;a[1106088]=1;u=n}}while(0);a[1043837]=f^1;a[1044493]=u;g=u;return g|0};case 8505:{do{if((a[1106148]|0)==0){u=b[520855]|0;f=b[520853]|0;s=f&65535;if(u<<16>>16==0){v=(c[263194]|0)+((s<<1)+65534&65534)|0;w=f;break}else{p=s-1|0;s=e[520854]|0;j=s&p;v=(c[263194]|0)+((((s^2147483647)&p)+(j>>>((e[520856]|0)>>>0))+((j&(u&65535)+536870911)<<3)<<1)+65534&65534)|0;w=f;break}}else{f=b[520853]|0;v=(c[263194]|0)+((f&65535)<<1&65534)|0;w=f}}while(0);f=a[v]|0;if((a[1041704]|0)==0){b[520853]=(d[1041705]|0)+w&65535;a[1106148]=0}a[1044493]=f;g=f;return g|0};case 8506:{do{if((a[1106148]|0)==0){f=b[520855]|0;w=b[520853]|0;v=w&65535;if(f<<16>>16==0){x=(c[263194]|0)+((v<<1)+65535&65535)|0;y=w;break}else{u=v-1|0;v=e[520854]|0;j=v&u;x=(c[263194]|0)+((((v^2147483647)&u)+(j>>>((e[520856]|0)>>>0))+((j&(f&65535)+536870911)<<3)<<1)+65535&65535)|0;y=w;break}}else{w=b[520853]|0;x=(c[263194]|0)+((w&65535)<<1&65534|1)|0;y=w}}while(0);w=a[x]|0;if((a[1041704]|0)!=0){b[520853]=(d[1041705]|0)+y&65535;a[1106148]=0}a[1044493]=w;g=w;return g|0};case 8507:{w=a[1041772]|0;if(w<<24>>24==0){z=b[1041774+(d[1041773]<<1)>>1]&255}else{y=a[1044494]&128;x=a[1041773]|0;a[1041773]=x+1&255;z=((e[1041774+((x&255)<<1)>>1]|0)>>>8&127|y)&255}a[1041772]=w^1;a[1044494]=z;g=z;return g|0};case 8508:{z=c[348394]|0;w=b[522205]|0;y=w&65535;do{if((z|0)>(y|0)){r=387}else{if((z|0)!=(y|0)){break}if((c[348392]|0)>=(e[522204]<<2|0)){r=387}}}while(0);if((r|0)==387){r=c[263195]|0;if((a[r+16915|0]|0)<0){a[1044412]=1;b[522203]=w;b[522202]=b[522204]|0;w=r+8511|0;a[w]=a[w]|64}b[522205]=1e3}w=a[1044402]|0;if(w<<24>>24==0){A=b[522202]&255}else{A=((e[522202]|0)>>>8&1|a[1044494]&254)&255}a[1044402]=w^1;a[1044494]=A;g=A;return g|0};case 8510:{if((c[276540]|0)!=(c[276539]|0)){Hy()}A=a[1044493]&16|a[1044390]|1;a[1044493]=A;g=A;return g|0};default:{g=a[1044496]|0;return g|0}}return 0}function HH(f,g){f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0,cf=0,cg=0,ch=0,ci=0,cj=0,ck=0,cl=0,cm=0,cn=0,co=0,cp=0,cq=0,cr=0,cs=0,ct=0,cu=0,cv=0,cw=0,cx=0,cy=0,cz=0,cA=0,cB=0,cC=0,cD=0,cE=0,cF=0;h=g&65535;L659:do{if((g&65535)<16896){if((h|0)==16406){jZ(f&1);break}else if((h|0)==16407){return}else{break}}else{if((h&65408|0)==17152){if((a[1393610]|0)!=0){return}i=h>>>4&7;switch(h&15|0){case 10:{j=f&127;if((j|0)==0){a[1183795+(i*22|0)|0]=-128;a[1183794+(i*22|0)|0]=(f&255)>>>7;return}else{a[1183795+(i*22|0)|0]=j&255;a[1183794+(i*22|0)|0]=(f&255)>>>7^1;return}break};case 5:{j=1183788+(i*22|0)|0;b[j>>1]=b[j>>1]&-256|f&255;c[1106760+(i<<2)>>2]=0;return};case 6:{j=1183788+(i*22|0)|0;b[j>>1]=b[j>>1]&255|(f&255)<<8;c[1106760+(i<<2)>>2]=0;return};case 7:{a[1183790+(i*22|0)|0]=f;c[1106760+(i<<2)>>2]=0;return};case 3:{j=1183784+(i*22|0)|0;b[j>>1]=b[j>>1]&255|(f&255)<<8;return};case 4:{a[1183786+(i*22|0)|0]=f;c[1106760+(i<<2)>>2]=0;return};case 8:{j=1183792+(i*22|0)|0;b[j>>1]=b[j>>1]&-256|f&255;c[1106760+(i<<2)>>2]=0;return};case 2:{j=1183784+(i*22|0)|0;b[j>>1]=b[j>>1]&-256|f&255;return};case 11:case 15:{a[1183796+(i*22|0)|0]=f;return};case 0:{a[1183776+(i*22|0)|0]=(f&255)>>>7;a[1183777+(i*22|0)|0]=(f&255)>>>6&1;a[1183778+(i*22|0)|0]=(f&255)>>>5&1;a[1183780+(i*22|0)|0]=(f&255)>>>4&1;a[1183779+(i*22|0)|0]=(f&255)>>>3&1;a[1183781+(i*22|0)|0]=f&7;return};case 1:{a[1183782+(i*22|0)|0]=f;return};case 9:{j=1183792+(i*22|0)|0;b[j>>1]=b[j>>1]&255|(f&255)<<8;c[1106760+(i<<2)>>2]=0;return};default:{break L659}}}switch(h|0){case 16896:{i=f&255;a[1044392]=(f&255)>>>5&1;a[1044391]=(f&255)>>>4&1;HI();j=b[522197]|0;k=c[348392]|0;do{if((j|0)>=(c[348393]|0)&(j|0)<(k|0)){l=(c[348394]|0)==(b[522198]|0);m=a[1044392]|0;if((a[1044391]|0)==0){n=547}else{if(!(m<<24>>24==0|l)){n=547}}if((n|0)==547){if(m<<24>>24==0|l^1){break}}a[1393588]=a[1393588]|2;c[348398]=c[199754];c[348395]=c[348395]|2048;if((a[1393628]|0)==0){break}a[1393628]=0;b[520836]=(b[520836]|0)+1&65535}}while(0);do{if((i&48|0)==0){j=a[1393588]&-3;a[1393588]=j;if(j<<24>>24!=0){break}c[348395]=c[348395]&-2049}}while(0);if((i&128|0)==0){break L659}j=c[263195]|0;if((a[j+16896|0]|0)<0){break L659}if((c[348394]|0)<((e[522243]|0)+1|0)){break L659}if((a[j+16912|0]|0)>=0){break L659}c[348395]=c[348395]|128;c[199748]=k+12;break L659;break};case 16906:{j=b[522200]|0;l=j&255|(f&255)<<8&256;b[522200]=l;if(l<<16>>16==j<<16>>16){break L659}HI();break L659;break};case 16907:{if((a[1393610]|0)!=0){return}if(f<<24>>24!=0){c[348392]=(c[348392]|0)+(c[199752]|0)}j=797496;c[j>>2]=0;c[j+4>>2]=0;a[1720]=(a[799125]|a[799126]|a[799123])<<24>>24!=0;j=f&255;if((j&1|0)==0){o=0}else{a[797496]=1;o=1}if((j&2|0)!=0){a[797497]=1}if((j&4|0)!=0){a[797498]=1}if((j&8|0)!=0){a[797499]=1}if((j&16|0)!=0){a[797500]=1}if((j&32|0)!=0){a[797501]=1}if((j&64|0)!=0){a[797502]=1}if((j&128|0)==0){p=1;q=0;r=o}else{a[797503]=1;p=1;q=0;r=o}while(1){j=1183776+(q*22|0)|0;L753:do{if(r<<24>>24==1){a[1393608]=1;a[1393610]=1;c[348404]=q;l=1183786+(q*22|0)|0;m=1183782+(q*22|0)|0;s=a[m]|0;do{if(((a[l]|0)-126&255)<2&s<<24>>24==-128){if((a[j|0]|0)!=0){break}t=1183788+(q*22|0)|0;u=b[t>>1]|0;v=(c[348392]|0)+8|0;c[348392]=v;w=1183784+(q*22|0)|0;x=1<<q;y=u<<16>>16==0?65536:u&65535;z=v;v=c[348406]|0;A=u;while(1){b[t>>1]=A-1&65535;b[w>>1]=(b[w>>1]|0)+1&65535;u=y-1|0;B=z+8|0;c[348392]=B;if((B|0)<(v|0)){C=B;D=v}else{while(1){j1();B=c[348392]|0;E=c[348406]|0;if((B|0)<(E|0)){C=B;D=E;break}}}E=(d[1393612]&x|0)==0;a[1393612]=0;if(!E){a[1393608]=0;a[1393610]=0;c[348404]=-1}if((u|0)==0){break}y=u;z=C;v=D;A=b[t>>1]|0}a[1393608]=0;a[1393610]=0;c[348404]=-1;break L753}else{if((s-24&255)>=2){break}if((c[276540]|0)==(c[276539]|0)){break}Hy()}}while(0);s=1183779+(q*22|0)|0;t=(a[s]|0)==0;if(t){F=(a[1183780+(q*22|0)|0]|0)==0?1:-1}else{F=0}A=1183788+(q*22|0)|0;v=b[A>>1]|0;z=v<<16>>16==0?65536:v&65535;do{if(a[1720]|0){if((a[799125]|0)==0){G=F;H=0}else{L780:do{if(t){I=F;J=0}else{if((a[(c[263195]|0)+18433|0]|0)==0){I=F;J=0;break}v=(a[1183780+(q*22|0)|0]|0)==0?1:-1;y=e[1183784+(q*22|0)>>1]|0;x=HK(d[l]<<16|y)|0;if((x|0)==0){I=v;J=169888;break}w=a[x+y|0]|0;E=w&255;B=E>>>6;K=E&48;if((K|0)==0){c[127546]=448;c[125854]=1}else if((K|0)==16){c[127546]=384;c[125854]=1}else if((K|0)==32){c[127546]=192;c[125854]=1}else if((K|0)==48){c[127546]=384;c[125854]=3}b[254828]=d[x+(y+1)|0]<<3|(w&255)<<11;c[42368]=5;c[127416]=x+(y+2);y=798224;c[y>>2]=0;c[y+4>>2]=0;X2(797552,0,32);X2(797584,0,128);X2(237808,0,32);if((B|0)==3){y=z;x=169888;while(1){w=(TT(0)|0)<<24>>24!=0|0;K=((TT(1)|0)<<24>>24==0?0:2)|w;w=K|((TT(2)|0)<<24>>24==0?0:4);K=w|((TT(3)|0)<<24>>24==0?0:8);w=K|((TT(4)|0)<<24>>24==0?0:16);K=w|((TT(5)|0)<<24>>24==0?0:32);w=K|((TT(6)|0)<<24>>24==0?0:64);a[x]=w|((TT(7)|0)<<24>>24==0?0:-128);w=y-1|0;if((w|0)==0){I=v;J=169888;break}else{y=w;x=x+1|0}}}else if((B|0)==0){x=z;y=169888;while(1){u=(TT(0)|0)<<24>>24==0?0:-128;w=TT(1)|0;K=((TT(0)|0)<<24>>24==0?0:64)|u;u=TT(1)|0;E=K|((TT(0)|0)<<24>>24==0?0:32);K=TT(1)|0;L=E|((TT(0)|0)<<24>>24==0?0:16);E=TT(1)|0;M=L|((TT(0)|0)<<24>>24==0?0:8);L=TT(1)|0;N=M|((TT(0)|0)<<24>>24==0?0:4);M=TT(1)|0;O=N|((TT(0)|0)<<24>>24==0?0:2);N=TT(1)|0;P=O|(TT(0)|0)<<24>>24!=0;O=TT(1)|0;a[y]=P;if((x|0)==1){I=v;J=169888;break L780}a[y+1|0]=(u<<24>>24==0?0:64)|(w<<24>>24==0?0:-128)|(K<<24>>24==0?0:32)|(E<<24>>24==0?0:16)|(L<<24>>24==0?0:8)|(M<<24>>24==0?0:4)|(N<<24>>24==0?0:2)|O<<24>>24!=0;O=x-2|0;if((O|0)==0){I=v;J=169888;break}else{x=O;y=y+2|0}}}else if((B|0)==1){y=0;x=z;O=169888;while(1){N=y+1&255;M=0;L=x;E=O;while(1){K=(TT(y)|0)<<24>>24==0?0:-128;w=TT(N)|0;u=((TT(y)|0)<<24>>24==0?0:64)|K;K=TT(N)|0;P=u|((TT(y)|0)<<24>>24==0?0:32);u=TT(N)|0;Q=P|((TT(y)|0)<<24>>24==0?0:16);P=TT(N)|0;R=Q|((TT(y)|0)<<24>>24==0?0:8);Q=TT(N)|0;S=R|((TT(y)|0)<<24>>24==0?0:4);R=TT(N)|0;T=S|((TT(y)|0)<<24>>24==0?0:2);S=TT(N)|0;U=T|(TT(y)|0)<<24>>24!=0;T=TT(N)|0;a[E]=U;if((L|0)==1){I=v;J=169888;break L780}V=E+2|0;a[E+1|0]=(K<<24>>24==0?0:64)|(w<<24>>24==0?0:-128)|(u<<24>>24==0?0:32)|(P<<24>>24==0?0:16)|(Q<<24>>24==0?0:8)|(R<<24>>24==0?0:4)|(S<<24>>24==0?0:2)|T<<24>>24!=0;W=L-2|0;if((W|0)==0){I=v;J=169888;break L780}T=M+32&255;if(T<<24>>24==0){break}else{M=T;L=W;E=V}}y=y+2&7;x=W;O=V}}else if((B|0)==2){O=0;x=0;y=z;E=169888;while(1){L=O+1&255;M=(TT(O)|0)<<24>>24==0?0:-128;N=TT(L)|0;T=((TT(O)|0)<<24>>24==0?0:64)|M;M=TT(L)|0;S=T|((TT(O)|0)<<24>>24==0?0:32);T=TT(L)|0;R=S|((TT(O)|0)<<24>>24==0?0:16);S=TT(L)|0;Q=R|((TT(O)|0)<<24>>24==0?0:8);R=TT(L)|0;P=Q|((TT(O)|0)<<24>>24==0?0:4);Q=TT(L)|0;u=P|((TT(O)|0)<<24>>24==0?0:2);P=TT(L)|0;w=u|(TT(O)|0)<<24>>24!=0;u=TT(L)|0;a[E]=w;if((y|0)==1){I=v;J=169888;break L780}a[E+1|0]=(M<<24>>24==0?0:64)|(N<<24>>24==0?0:-128)|(T<<24>>24==0?0:32)|(S<<24>>24==0?0:16)|(R<<24>>24==0?0:8)|(Q<<24>>24==0?0:4)|(P<<24>>24==0?0:2)|u<<24>>24!=0;u=y-2|0;if((u|0)==0){I=v;J=169888;break L780}P=x+32&255;O=P<<24>>24==0?O^2:O;x=P;y=u;E=E+2|0}}else{I=v;J=169888;break}}}while(0);a[(c[263195]|0)+18433|0]=0;G=I;H=J}do{if((a[799126]|0)==0){X=G;Y=0}else{E=1183784+(q*22|0)|0;y=b[E>>1]|0;if(y<<16>>16!=18432){if((a[l]|0)!=80){X=G;Y=0;break}}x=b[A>>1]|0;O=x&65535;B=XY(O)|0;if(x<<16>>16==0){Z=O;_=y}else{y=c[199378]|0;O=0;x=c[199384]|0;while(1){do{if((x|0)==0){if((y|0)==0){T2();n=654;break}else if((y|0)==1){T3();n=654;break}else if((y|0)==2){T5();n=654;break}else{$=0;aa=0;break}}else{n=654}}while(0);if((n|0)==654){n=0;u=c[199382]|0;P=a[(c[199386]|0)+u|0]|0;c[199382]=u+1&63;u=(c[199384]|0)-1|0;c[199384]=u;$=P;aa=u}a[B+O|0]=$;u=O+1|0;ac=e[A>>1]|0;if((u|0)<(ac|0)){O=u;x=aa}else{break}}Z=ac;_=b[E>>1]|0}x=(d[237728]<<8|d[237736])-Z|0;a[237736]=x&255;a[237728]=x>>>8&255;b[E>>1]=(_&65535)-z&65535;X=1;Y=B}}while(0);if((a[799123]|0)==0|(a[840917]|0)==0){ad=X;ae=0;af=H;ag=Y;break}if((a[m]|0)!=24){ad=X;ae=0;af=H;ag=Y;break}x=a[l]|0;if((x&-16)<<24>>24!=64){ad=X;ae=0;af=H;ag=Y;break}O=d[(c[263195]|0)+8753|0]|0;y=O>>>2&7;v=1<<y;u=O&3;if((u|0)==0){ah=8}else{ah=(u|0)==1?4:2}u=ah<<3;O=ah<<y;P=u<<y;y=e[1183784+(q*22|0)>>1]|0;Q=(y|0)%(P|0)|0;R=y-Q|0;y=HK(R+((x&255)<<16)|0)|0;x=c[263192]|0;S=x+8323072|0;T=P-Q|0;if((z|0)==0){ad=X;ae=1;af=H;ag=Y;break}Q=ab(ah,ah)|0;N=S;M=797424+(ah<<3)|0;w=797425+(ah<<3)|0;L=797426+(ah<<3)|0;K=797427+(ah<<3)|0;U=797428+(ah<<3)|0;ai=797429+(ah<<3)|0;aj=797430+(ah<<3)|0;ak=797431+(ah<<3)|0;al=(ah|0)==2;am=0;an=T;ao=(T>>>0)/(u>>>0)|0;u=S;S=((y|0)==0?x:y)+R|0;while(1){L839:do{if((ao|0)==0){ap=u}else{R=0;y=u;x=S+(ab(v-ao|0,ah)|0)|0;while(1){if((y-N|0)>=(z|0)){ap=y;break L839}T=d[M]|0;aq=d[w]|0;ar=d[L]|0;as=d[K]|0;at=d[U]|0;au=d[ai]|0;av=d[aj]|0;aw=d[ak]|0;ax=0;ay=y;az=x;while(1){aA=ay+1|0;aB=ay+T|0;aC=ay+aq|0;aD=ay+ar|0;aE=ay+as|0;aF=ay+at|0;aG=ay+au|0;aH=ay+av|0;aI=ay+aw|0;aJ=0;do{aK=a[az+aJ|0]|0;a[ay]=a[aB]<<1|aK&1;a[aA]=a[aC]<<1|(aK&255)>>>1&1;a[ay]=a[aD]<<1|(aK&255)>>>2&1;a[aA]=a[aE]<<1|(aK&255)>>>3&1;a[ay]=a[aF]<<1|(aK&255)>>>4&1;a[aA]=a[aG]<<1|(aK&255)>>>5&1;a[ay]=a[aH]<<1|(aK&255)>>>6&1;a[aA]=a[aI]<<1|(aK&255)>>>7;aJ=aJ+1|0;}while((aJ|0)<(ah|0));aJ=ax+1|0;if((aJ|0)<8){ax=aJ;ay=ay+2|0;az=az+O|0}else{break}}if(al){aL=y+16|0}else{aL=y+Q|0}az=R+1|0;if(az>>>0<ao>>>0){R=az;y=aL;x=x+ah|0}else{ap=aL;break}}}}while(0);B=am+an|0;if((B|0)<(z|0)){am=B;an=P;ao=v;u=ap;S=S+P|0}else{ad=X;ae=1;af=H;ag=Y;break}}}else{ad=F;ae=0;af=0;ag=0}}while(0);t=(c[348392]|0)+8|0;c[348392]=t;L855:do{if((a[j|0]|0)==0){P=1183784+(q*22|0)|0;S=b[P>>1]|0;u=a[l]|0;v=S&65535;ao=HK((u&255)<<16|v)|0;if((a[s]|0)==0){an=v&4095;aM=(a[1183780+(q*22|0)|0]|0)!=0?an+1|0:4096-an|0}else{aM=z}do{if(a[1720]|0){if(ae<<24>>24!=0){aN=(c[263192]|0)+8323072|0;aO=0;aP=z;n=684;break}if((af|0)!=0){aQ=0;aR=af;aS=0;aT=z;aU=0;break}an=(ag|0)==0;aN=an?ao:ag;aO=an?S:0;aP=an?aM:z;n=684}else{aN=ao;aO=S;aP=aM;n=684}}while(0);do{if((n|0)==684){n=0;if(!(ae<<24>>24==0&(af|0)==0&(ag|0)==0)){aQ=0;aR=aN;aS=aO;aT=aP;aU=0;break}if((u-126&255)<2){aQ=1;aR=aN;aS=aO;aT=aP;aU=1;break}if((u&64)!=0){aQ=0;aR=aN;aS=aO;aT=aP;aU=1;break}aQ=(S&65535)<8192|0;aR=aN;aS=aO;aT=aP;aU=1}}while(0);S=1183781+(q*22|0)|0;u=1<<q;ao=aQ;an=aR;v=aS;am=z;Q=0;al=aT;O=aU;ak=t;L872:while(1){aj=ao;ai=an;U=v;K=am;L=Q;w=al;M=ak;while(1){N=(ai|0)==0;B=U;E=K;x=L;y=w;R=M;L876:while(1){aV=(y|0)>(E|0)?E:y;aW=E-aV|0;a[1393611]=aj;aX=a[S]|0;if(N){switch(aX<<24>>24){case 1:case 5:{break};case 3:case 7:case 4:{n=715;break L876;break};case 6:case 2:case 0:{aY=B;aZ=aV;n=693;break L876;break};default:{a_=B;a$=x;a0=R;break L876}}if((x|0)==1){a1=B;a2=aV;n=705}else{a3=B;a4=aV;a5=R}while(1){if((n|0)==705){n=0;az=a1&65535;ay=HM(d[l]<<16|az)|0;HB(ay,(d[m]|0)+8449&65535);b[A>>1]=(b[A>>1]|0)-1&65535;b[P>>1]=(e[P>>1]|0)+ad&65535;ay=az+ad&65535;az=(c[348392]|0)+8|0;c[348392]=az;if((az|0)<(c[348406]|0)){a6=az}else{while(1){j1();az=c[348392]|0;if((az|0)<(c[348406]|0)){a6=az;break}}}az=(d[1393612]&u|0)==0;a[1393612]=0;if(az){a3=ay;a4=a2-1|0;a5=a6;continue}else{a[1393608]=0;a[1393610]=0;a[1393611]=0;c[348404]=-1;a3=ay;a4=a2;a5=a6;continue}}if((a4|0)>1){a7=a3}else{break}while(1){az=a7&65535;ax=HM(d[l]<<16|az)|0;HB(ax,d[m]|8448);b[A>>1]=(b[A>>1]|0)-1&65535;b[P>>1]=(e[P>>1]|0)+ad&65535;a8=az+ad&65535;az=(c[348392]|0)+8|0;c[348392]=az;if((az|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}az=(d[1393612]&u|0)==0;a[1393612]=0;if(az){break}a[1393608]=0;a[1393610]=0;a[1393611]=0;c[348404]=-1;a7=a8}a1=a8;a2=a4-1|0;n=705}ay=(a4|0)==1;az=ay&1;if(!ay){a_=a3;a$=az;a0=a5;break}ay=a3&65535;ax=HM(d[l]<<16|ay)|0;HB(ax,d[m]|8448);b[A>>1]=(b[A>>1]|0)-1&65535;b[P>>1]=(e[P>>1]|0)+ad&65535;ax=ay+ad&65535;ay=(c[348392]|0)+8|0;c[348392]=ay;if((ay|0)<(c[348406]|0)){a9=ay}else{while(1){j1();ay=c[348392]|0;if((ay|0)<(c[348406]|0)){a9=ay;break}}}ay=(d[1393612]&u|0)==0;a[1393612]=0;if(ay){a_=ax;a$=az;a0=a9;break}a[1393608]=0;a[1393610]=0;a[1393611]=0;c[348404]=-1;B=ax;E=aW;x=az;y=1;R=a9;continue}switch(aX<<24>>24){case 6:case 2:case 0:{n=738;break L876;break};case 1:case 5:{break};case 3:case 7:case 4:{n=823;break L876;break};default:{a_=B;a$=x;a0=R;break L876}}ay=a[m]|0;if(ay<<24>>24!=24){if((x|0)==1){ba=B;bb=aV;bc=ay;n=813}else{bd=B;be=aV;bf=R}while(1){if((n|0)==813){n=0;ay=ba&65535;HB(a[ai+ay|0]|0,(bc&255)+8449&65535);b[A>>1]=(b[A>>1]|0)-1&65535;b[P>>1]=(e[P>>1]|0)+ad&65535;aw=ay+ad&65535;ay=(c[348392]|0)+8|0;c[348392]=ay;if((ay|0)<(c[348406]|0)){bg=ay}else{while(1){j1();ay=c[348392]|0;if((ay|0)<(c[348406]|0)){bg=ay;break}}}ay=(d[1393612]&u|0)==0;a[1393612]=0;if(ay){bd=aw;be=bb-1|0;bf=bg;continue}else{a[1393608]=0;a[1393610]=0;a[1393611]=0;c[348404]=-1;bd=aw;be=bb;bf=bg;continue}}if((be|0)>1){bh=bd}else{break}while(1){ay=bh&65535;HB(a[ai+ay|0]|0,d[m]|8448);b[A>>1]=(b[A>>1]|0)-1&65535;b[P>>1]=(e[P>>1]|0)+ad&65535;bi=ay+ad&65535;ay=(c[348392]|0)+8|0;c[348392]=ay;if((ay|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}ay=(d[1393612]&u|0)==0;a[1393612]=0;if(ay){break}a[1393608]=0;a[1393610]=0;a[1393611]=0;c[348404]=-1;bh=bi}ba=bi;bb=be-1|0;bc=a[m]|0;n=813}az=(be|0)==1;ax=az&1;if(!az){a_=bd;a$=ax;a0=bf;break}az=bd&65535;HB(a[ai+az|0]|0,d[m]|8448);b[A>>1]=(b[A>>1]|0)-1&65535;b[P>>1]=(e[P>>1]|0)+ad&65535;aw=az+ad&65535;az=(c[348392]|0)+8|0;c[348392]=az;if((az|0)<(c[348406]|0)){bj=az}else{while(1){j1();az=c[348392]|0;if((az|0)<(c[348406]|0)){bj=az;break}}}az=(d[1393612]&u|0)==0;a[1393612]=0;if(az){a_=aw;a$=ax;a0=bj;break}a[1393608]=0;a[1393610]=0;a[1393611]=0;c[348404]=-1;B=aw;E=aW;x=ax;y=1;R=bj;continue}a[1106148]=1;if((x|0)==1){bk=B;bl=aV;bm=R}else{bn=B;bo=aV;bp=R;n=787}while(1){if((n|0)==787){n=0;if((bo|0)>1){bq=bn}else{break}while(1){az=bq&65535;HC(a[ai+az|0]|0);b[A>>1]=(b[A>>1]|0)-1&65535;b[P>>1]=(e[P>>1]|0)+ad&65535;br=az+ad&65535;az=(c[348392]|0)+8|0;c[348392]=az;if((az|0)<(c[348406]|0)){bs=az}else{while(1){j1();az=c[348392]|0;if((az|0)<(c[348406]|0)){bs=az;break}}}az=(d[1393612]&u|0)==0;a[1393612]=0;if(az){break}a[1393608]=0;a[1393610]=0;a[1393611]=0;c[348404]=-1;bq=br}bk=br;bl=bo-1|0;bm=bs}az=bk&65535;ay=a[ai+az|0]|0;if((a[807365]|0)==0|(a[1044481]|0)!=0){n=795}else{if((c[348394]|0)<((e[522243]|0)+1|0)){bt=bm}else{n=795}}if((n|0)==795){n=0;HD(ay);bt=c[348392]|0}b[A>>1]=(b[A>>1]|0)-1&65535;b[P>>1]=(e[P>>1]|0)+ad&65535;ay=az+ad&65535;az=bt+8|0;c[348392]=az;if((az|0)<(c[348406]|0)){bu=az}else{while(1){j1();az=c[348392]|0;if((az|0)<(c[348406]|0)){bu=az;break}}}az=(d[1393612]&u|0)==0;a[1393612]=0;if(az){bn=ay;bo=bl-1|0;bp=bu;n=787;continue}else{a[1393608]=0;a[1393610]=0;a[1393611]=0;c[348404]=-1;bn=ay;bo=bl;bp=bu;n=787;continue}}ax=(bo|0)==1;aw=ax&1;if(!ax){a_=bn;a$=aw;a0=bp;break}ax=bn&65535;HC(a[ai+ax|0]|0);b[A>>1]=(b[A>>1]|0)-1&65535;b[P>>1]=(e[P>>1]|0)+ad&65535;az=ax+ad&65535;ax=(c[348392]|0)+8|0;c[348392]=ax;if((ax|0)<(c[348406]|0)){bv=ax}else{while(1){j1();ax=c[348392]|0;if((ax|0)<(c[348406]|0)){bv=ax;break}}}ax=(d[1393612]&u|0)==0;a[1393612]=0;if(ax){a_=az;a$=aw;a0=bv;break}a[1393608]=0;a[1393610]=0;a[1393611]=0;c[348404]=-1;B=az;E=aW;x=aw;y=1;R=bv}L969:do{if((n|0)==715){n=0;y=aX<<24>>24==4;E=y?8449:8448;N=y?8451:8449;if((x|0)==1){bw=B;bx=aV;n=722}else if((x|0)==2){by=B;bz=aV;n=727}else if((x|0)==3){bA=B;bB=aV;n=732}else{bC=B;bD=aV;n=716}while(1){if((n|0)==716){n=0;y=bC;while(1){ax=y&65535;av=HM(d[l]<<16|ax)|0;HB(av,d[m]|8448);b[A>>1]=(b[A>>1]|0)-1&65535;b[P>>1]=(e[P>>1]|0)+ad&65535;bE=ax+ad&65535;ax=(c[348392]|0)+8|0;c[348392]=ax;if((ax|0)<(c[348406]|0)){bF=ax}else{while(1){j1();ax=c[348392]|0;if((ax|0)<(c[348406]|0)){bF=ax;break}}}ax=(d[1393612]&u|0)==0;a[1393612]=0;if(ax){break}a[1393608]=0;a[1393610]=0;a[1393611]=0;c[348404]=-1;y=bE}y=bD-1|0;if((y|0)<1){a_=bE;a$=1;a0=bF;break}else{bw=bE;bx=y;n=722;continue}}else if((n|0)==722){n=0;y=bw&65535;ay=HM(d[l]<<16|y)|0;HB(ay,(d[m]|0)+E&65535);b[A>>1]=(b[A>>1]|0)-1&65535;b[P>>1]=(e[P>>1]|0)+ad&65535;ay=y+ad&65535;y=(c[348392]|0)+8|0;c[348392]=y;if((y|0)<(c[348406]|0)){bG=y}else{while(1){j1();y=c[348392]|0;if((y|0)<(c[348406]|0)){bG=y;break}}}y=(d[1393612]&u|0)==0;a[1393612]=0;if(y){y=bx-1|0;if((y|0)<1){a_=ay;a$=2;a0=bG;break}else{by=ay;bz=y;n=727;continue}}else{a[1393608]=0;a[1393610]=0;a[1393611]=0;c[348404]=-1;bC=ay;bD=bx;n=716;continue}}else if((n|0)==727){n=0;y=by&65535;ax=HM(d[l]<<16|y)|0;HB(ax,E+1+(d[m]|0)&65535);b[A>>1]=(b[A>>1]|0)-1&65535;b[P>>1]=(e[P>>1]|0)+ad&65535;ax=y+ad&65535;y=(c[348392]|0)+8|0;c[348392]=y;if((y|0)<(c[348406]|0)){bH=y}else{while(1){j1();y=c[348392]|0;if((y|0)<(c[348406]|0)){bH=y;break}}}ay=(d[1393612]&u|0)==0;a[1393612]=0;if(ay){ay=bz-1|0;if((ay|0)<1){a_=ax;a$=3;a0=bH;break}else{bA=ax;bB=ay;n=732;continue}}else{a[1393608]=0;a[1393610]=0;a[1393611]=0;c[348404]=-1;bC=ax;bD=bz;n=716;continue}}else if((n|0)==732){n=0;ay=bA&65535;y=HM(d[l]<<16|ay)|0;HB(y,(d[m]|0)+N&65535);b[A>>1]=(b[A>>1]|0)-1&65535;b[P>>1]=(e[P>>1]|0)+ad&65535;y=ay+ad&65535;ay=(c[348392]|0)+8|0;c[348392]=ay;if((ay|0)<(c[348406]|0)){bI=ay}else{while(1){j1();ay=c[348392]|0;if((ay|0)<(c[348406]|0)){bI=ay;break}}}ax=(d[1393612]&u|0)==0;a[1393612]=0;if(ax){ax=bB-1|0;if((ax|0)<1){a_=y;a$=0;a0=bI;break}else{bC=y;bD=ax;n=716;continue}}else{a[1393608]=0;a[1393610]=0;a[1393611]=0;c[348404]=-1;bC=y;bD=bB;n=716;continue}}}}else if((n|0)==738){n=0;N=a[m]|0;switch(N&255|0){case 4:{E=B;aw=aV;while(1){az=E&65535;HE(a[ai+az|0]|0);b[A>>1]=(b[A>>1]|0)-1&65535;b[P>>1]=(e[P>>1]|0)+ad&65535;ax=az+ad&65535;az=(c[348392]|0)+8|0;c[348392]=az;if((az|0)<(c[348406]|0)){bJ=az}else{while(1){j1();az=c[348392]|0;if((az|0)<(c[348406]|0)){bJ=az;break}}}y=(d[1393612]&u|0)==0;a[1393612]=0;if(!y){a[1393608]=0;a[1393610]=0;a[1393611]=0;c[348404]=-1}y=aw-1|0;if((y|0)>0){E=ax;aw=y}else{a_=ax;a$=x;a0=bJ;break}}break};case 24:{a[1106148]=1;aw=B;E=aV;y=R;while(1){az=aw&65535;ay=a[ai+az|0]|0;if((a[807365]|0)==0|(a[1044481]|0)!=0){n=747}else{if((c[348394]|0)<((e[522243]|0)+1|0)){bK=y}else{n=747}}if((n|0)==747){n=0;HC(ay);bK=c[348392]|0}b[A>>1]=(b[A>>1]|0)-1&65535;b[P>>1]=(e[P>>1]|0)+ad&65535;ay=az+ad&65535;az=bK+8|0;c[348392]=az;if((az|0)<(c[348406]|0)){bL=az}else{while(1){j1();az=c[348392]|0;if((az|0)<(c[348406]|0)){bL=az;break}}}ax=(d[1393612]&u|0)==0;a[1393612]=0;if(!ax){a[1393608]=0;a[1393610]=0;a[1393611]=0;c[348404]=-1}ax=E-1|0;if((ax|0)>0){aw=ay;E=ax;y=bL}else{a_=ay;a$=x;a0=bL;break}}break};case 25:{a[1106148]=1;y=B;E=aV;aw=R;while(1){ax=y&65535;az=a[ai+ax|0]|0;if((a[807365]|0)==0|(a[1044481]|0)!=0){n=756}else{if((c[348394]|0)<((e[522243]|0)+1|0)){bM=aw}else{n=756}}if((n|0)==756){n=0;HD(az);bM=c[348392]|0}b[A>>1]=(b[A>>1]|0)-1&65535;b[P>>1]=(e[P>>1]|0)+ad&65535;az=ax+ad&65535;ax=bM+8|0;c[348392]=ax;if((ax|0)<(c[348406]|0)){bN=ax}else{while(1){j1();ax=c[348392]|0;if((ax|0)<(c[348406]|0)){bN=ax;break}}}ay=(d[1393612]&u|0)==0;a[1393612]=0;if(!ay){a[1393608]=0;a[1393610]=0;a[1393611]=0;c[348404]=-1}ay=E-1|0;if((ay|0)>0){y=az;E=ay;aw=bN}else{a_=az;a$=x;a0=bN;break}}break};case 34:{aw=B;E=aV;while(1){y=aw&65535;HF(a[ai+y|0]|0);b[A>>1]=(b[A>>1]|0)-1&65535;b[P>>1]=(e[P>>1]|0)+ad&65535;ay=y+ad&65535;y=(c[348392]|0)+8|0;c[348392]=y;if((y|0)<(c[348406]|0)){bO=y}else{while(1){j1();y=c[348392]|0;if((y|0)<(c[348406]|0)){bO=y;break}}}az=(d[1393612]&u|0)==0;a[1393612]=0;if(!az){a[1393608]=0;a[1393610]=0;a[1393611]=0;c[348404]=-1}az=E-1|0;if((az|0)>0){aw=ay;E=az}else{a_=ay;a$=x;a0=bO;break}}break};case 128:{if(aj<<24>>24==0){E=B;aw=aV;while(1){az=E&65535;y=a[ai+az|0]|0;ax=c[260429]|0;c[260429]=ax+1;a[(c[263191]|0)+ax|0]=y;c[260429]=c[260429]&131071;b[A>>1]=(b[A>>1]|0)-1&65535;b[P>>1]=(e[P>>1]|0)+ad&65535;y=az+ad&65535;az=(c[348392]|0)+8|0;c[348392]=az;if((az|0)<(c[348406]|0)){bP=az}else{while(1){j1();az=c[348392]|0;if((az|0)<(c[348406]|0)){bP=az;break}}}ay=(d[1393612]&u|0)==0;a[1393612]=0;if(!ay){a[1393608]=0;a[1393610]=0;a[1393611]=0;c[348404]=-1}ay=aw-1|0;if((ay|0)>0){E=y;aw=ay}else{a_=y;a$=x;a0=bP;break L969}}}aw=B;E=aV;ay=R;az=c[348406]|0;while(1){b[A>>1]=(b[A>>1]|0)-1&65535;b[P>>1]=(e[P>>1]|0)+ad&65535;ax=(aw&65535)+ad&65535;av=ay+8|0;c[348392]=av;if((av|0)<(az|0)){bQ=az;bR=av}else{while(1){j1();av=c[348392]|0;au=c[348406]|0;if((av|0)<(au|0)){bQ=au;bR=av;break}}}y=(d[1393612]&u|0)==0;a[1393612]=0;if(!y){a[1393608]=0;a[1393610]=0;a[1393611]=0;c[348404]=-1}y=E-1|0;if((y|0)>0){aw=ax;E=y;ay=bR;az=bQ}else{a_=ax;a$=x;a0=bR;break}}break};default:{az=B;ay=aV;E=N;while(1){aw=az&65535;HB(a[ai+aw|0]|0,E&255|8448);b[A>>1]=(b[A>>1]|0)-1&65535;b[P>>1]=(e[P>>1]|0)+ad&65535;y=aw+ad&65535;aw=(c[348392]|0)+8|0;c[348392]=aw;if((aw|0)<(c[348406]|0)){bS=aw}else{while(1){j1();aw=c[348392]|0;if((aw|0)<(c[348406]|0)){bS=aw;break}}}ax=(d[1393612]&u|0)==0;a[1393612]=0;if(!ax){a[1393608]=0;a[1393610]=0;a[1393611]=0;c[348404]=-1}ax=ay-1|0;if((ax|0)<=0){a_=y;a$=x;a0=bS;break L969}az=y;ay=ax;E=a[m]|0}}}}else if((n|0)==693){while(1){n=0;E=aY&65535;ay=HM(d[l]<<16|E)|0;HB(ay,d[m]|8448);b[A>>1]=(b[A>>1]|0)-1&65535;b[P>>1]=(e[P>>1]|0)+ad&65535;ay=E+ad&65535;E=(c[348392]|0)+8|0;c[348392]=E;if((E|0)<(c[348406]|0)){bT=E}else{while(1){j1();E=c[348392]|0;if((E|0)<(c[348406]|0)){bT=E;break}}}y=(d[1393612]&u|0)==0;a[1393612]=0;if(!y){a[1393608]=0;a[1393610]=0;a[1393611]=0;c[348404]=-1}y=aZ-1|0;if((y|0)>0){aY=ay;aZ=y;n=693}else{a_=ay;a$=x;a0=bT;break}}}else if((n|0)==823){n=0;y=aX<<24>>24==4;E=y?8449:8448;az=y?8451:8449;if((x|0)==1){bU=B;bV=aV;n=830}else if((x|0)==2){bW=B;bX=aV;n=835}else if((x|0)==3){bY=B;bZ=aV;n=840}else{b_=B;b$=aV;n=824}while(1){if((n|0)==824){n=0;y=b_;while(1){N=y&65535;HB(a[ai+N|0]|0,d[m]|8448);b[A>>1]=(b[A>>1]|0)-1&65535;b[P>>1]=(e[P>>1]|0)+ad&65535;b0=N+ad&65535;N=(c[348392]|0)+8|0;c[348392]=N;if((N|0)<(c[348406]|0)){b1=N}else{while(1){j1();N=c[348392]|0;if((N|0)<(c[348406]|0)){b1=N;break}}}N=(d[1393612]&u|0)==0;a[1393612]=0;if(N){break}a[1393608]=0;a[1393610]=0;a[1393611]=0;c[348404]=-1;y=b0}y=b$-1|0;if((y|0)<1){a_=b0;a$=1;a0=b1;break}else{bU=b0;bV=y;n=830;continue}}else if((n|0)==830){n=0;y=bU&65535;HB(a[ai+y|0]|0,(d[m]|0)+E&65535);b[A>>1]=(b[A>>1]|0)-1&65535;b[P>>1]=(e[P>>1]|0)+ad&65535;ay=y+ad&65535;y=(c[348392]|0)+8|0;c[348392]=y;if((y|0)<(c[348406]|0)){b2=y}else{while(1){j1();y=c[348392]|0;if((y|0)<(c[348406]|0)){b2=y;break}}}y=(d[1393612]&u|0)==0;a[1393612]=0;if(y){y=bV-1|0;if((y|0)<1){a_=ay;a$=2;a0=b2;break}else{bW=ay;bX=y;n=835;continue}}else{a[1393608]=0;a[1393610]=0;a[1393611]=0;c[348404]=-1;b_=ay;b$=bV;n=824;continue}}else if((n|0)==835){n=0;y=bW&65535;HB(a[ai+y|0]|0,E+1+(d[m]|0)&65535);b[A>>1]=(b[A>>1]|0)-1&65535;b[P>>1]=(e[P>>1]|0)+ad&65535;N=y+ad&65535;y=(c[348392]|0)+8|0;c[348392]=y;if((y|0)<(c[348406]|0)){b3=y}else{while(1){j1();y=c[348392]|0;if((y|0)<(c[348406]|0)){b3=y;break}}}ay=(d[1393612]&u|0)==0;a[1393612]=0;if(ay){ay=bX-1|0;if((ay|0)<1){a_=N;a$=3;a0=b3;break}else{bY=N;bZ=ay;n=840;continue}}else{a[1393608]=0;a[1393610]=0;a[1393611]=0;c[348404]=-1;b_=N;b$=bX;n=824;continue}}else if((n|0)==840){n=0;ay=bY&65535;HB(a[ai+ay|0]|0,(d[m]|0)+az&65535);b[A>>1]=(b[A>>1]|0)-1&65535;b[P>>1]=(e[P>>1]|0)+ad&65535;y=ay+ad&65535;ay=(c[348392]|0)+8|0;c[348392]=ay;if((ay|0)<(c[348406]|0)){b4=ay}else{while(1){j1();ay=c[348392]|0;if((ay|0)<(c[348406]|0)){b4=ay;break}}}N=(d[1393612]&u|0)==0;a[1393612]=0;if(N){N=bZ-1|0;if((N|0)<1){a_=y;a$=0;a0=b4;break}else{b_=y;b$=N;n=824;continue}}else{a[1393608]=0;a[1393610]=0;a[1393611]=0;c[348404]=-1;b_=y;b$=bZ;n=824;continue}}}}}while(0);if((aW|0)<1){b5=a0;break L855}B=a[l]|0;x=b[P>>1]|0;R=HK((B&255)<<16|x&65535)|0;if(!O){ao=0;an=R;v=a_;am=aW;Q=a$;al=4096;O=0;ak=a0;continue L872}if((B-126&255)<2){ao=1;an=R;v=a_;am=aW;Q=a$;al=4096;O=1;ak=a0;continue L872}if((B&64)!=0){aj=0;ai=R;U=a_;K=aW;L=a$;w=4096;M=a0;continue}aj=(x&65535)<8192|0;ai=R;U=a_;K=aW;L=a$;w=4096;M=a0}}}else{ak=a[l]|0;if(((a[m]|0)-125&255)<7){if((ak&64)==0){b6=1}else{n=852}}else{n=852}if((n|0)==852){n=0;if(ak<<24>>24==126){b7=1}else{b7=ak<<24>>24==127|0}a[1393611]=b7;b6=0}ak=1183784+(q*22|0)|0;O=1<<q;al=1183781+(q*22|0)|0;Q=z;while(1){if(b6){a[1393611]=(e[ak>>1]|0)<8192|0}am=HG(d[m]|8448)|0;HN(am,d[l]<<16|e[ak>>1]);b[A>>1]=(b[A>>1]|0)-1&65535;b[ak>>1]=(e[ak>>1]|0)+ad&65535;am=(c[348392]|0)+8|0;c[348392]=am;if((am|0)<(c[348406]|0)){b8=am}else{while(1){j1();am=c[348392]|0;if((am|0)<(c[348406]|0)){b8=am;break}}}am=(d[1393612]&O|0)==0;a[1393612]=0;L1155:do{if(am){switch(d[al]|0){case 0:case 2:case 6:{b9=Q-1|0;ca=b8;break L1155;break};case 1:case 5:{v=Q-1|0;if((v|0)==0){b5=b8;break L855}if(b6){a[1393611]=(e[ak>>1]|0)<8192|0}HN(HG((d[m]|0)+8449&65535)|0,d[l]<<16|e[ak>>1]);b[A>>1]=(b[A>>1]|0)-1&65535;b[ak>>1]=(e[ak>>1]|0)+ad&65535;an=(c[348392]|0)+8|0;c[348392]=an;if((an|0)<(c[348406]|0)){cb=an}else{while(1){j1();an=c[348392]|0;if((an|0)<(c[348406]|0)){cb=an;break}}}an=(d[1393612]&O|0)==0;a[1393612]=0;if(an){b9=Q-2|0;ca=cb;break L1155}else{a[1393608]=0;a[1393610]=0;a[1393611]=0;c[348404]=-1;b9=v;ca=cb;break L1155}break};case 3:case 7:{an=Q-1|0;if((an|0)==0){b5=b8;break L855}if(b6){a[1393611]=(e[ak>>1]|0)<8192|0}ao=HG(d[m]|8448)|0;HN(ao,d[l]<<16|e[ak>>1]);b[A>>1]=(b[A>>1]|0)-1&65535;b[ak>>1]=(e[ak>>1]|0)+ad&65535;ao=(c[348392]|0)+8|0;c[348392]=ao;if((ao|0)<(c[348406]|0)){cc=ao}else{while(1){j1();ao=c[348392]|0;if((ao|0)<(c[348406]|0)){cc=ao;break}}}v=(d[1393612]&O|0)==0;a[1393612]=0;if(!v){a[1393608]=0;a[1393610]=0;a[1393611]=0;c[348404]=-1;b9=an;ca=cc;break L1155}v=Q-2|0;if((v|0)==0){b5=cc;break L855}if(b6){a[1393611]=(e[ak>>1]|0)<8192|0}ao=HG((d[m]|0)+8449&65535)|0;HN(ao,d[l]<<16|e[ak>>1]);b[A>>1]=(b[A>>1]|0)-1&65535;b[ak>>1]=(e[ak>>1]|0)+ad&65535;ao=(c[348392]|0)+8|0;c[348392]=ao;if((ao|0)<(c[348406]|0)){cd=ao}else{while(1){j1();ao=c[348392]|0;if((ao|0)<(c[348406]|0)){cd=ao;break}}}an=(d[1393612]&O|0)==0;a[1393612]=0;if(!an){a[1393608]=0;a[1393610]=0;a[1393611]=0;c[348404]=-1;b9=v;ca=cd;break L1155}an=Q-3|0;if((an|0)==0){b5=cd;break L855}if(b6){a[1393611]=(e[ak>>1]|0)<8192|0}ao=HG((d[m]|0)+8449&65535)|0;HN(ao,d[l]<<16|e[ak>>1]);b[A>>1]=(b[A>>1]|0)-1&65535;b[ak>>1]=(e[ak>>1]|0)+ad&65535;ao=(c[348392]|0)+8|0;c[348392]=ao;if((ao|0)<(c[348406]|0)){ce=ao}else{while(1){j1();ao=c[348392]|0;if((ao|0)<(c[348406]|0)){ce=ao;break}}}v=(d[1393612]&O|0)==0;a[1393612]=0;if(v){b9=Q-4|0;ca=ce;break L1155}else{a[1393608]=0;a[1393610]=0;a[1393611]=0;c[348404]=-1;b9=an;ca=ce;break L1155}break};case 4:{v=Q-1|0;if((v|0)==0){b5=b8;break L855}if(b6){a[1393611]=(e[ak>>1]|0)<8192|0}ao=HG((d[m]|0)+8449&65535)|0;HN(ao,d[l]<<16|e[ak>>1]);b[A>>1]=(b[A>>1]|0)-1&65535;b[ak>>1]=(e[ak>>1]|0)+ad&65535;ao=(c[348392]|0)+8|0;c[348392]=ao;if((ao|0)<(c[348406]|0)){cf=ao}else{while(1){j1();ao=c[348392]|0;if((ao|0)<(c[348406]|0)){cf=ao;break}}}an=(d[1393612]&O|0)==0;a[1393612]=0;if(!an){a[1393608]=0;a[1393610]=0;a[1393611]=0;c[348404]=-1;b9=v;ca=cf;break L1155}an=Q-2|0;if((an|0)==0){b5=cf;break L855}if(b6){a[1393611]=(e[ak>>1]|0)<8192|0}ao=HG((d[m]|0)+8450&65535)|0;HN(ao,d[l]<<16|e[ak>>1]);b[A>>1]=(b[A>>1]|0)-1&65535;b[ak>>1]=(e[ak>>1]|0)+ad&65535;ao=(c[348392]|0)+8|0;c[348392]=ao;if((ao|0)<(c[348406]|0)){cg=ao}else{while(1){j1();ao=c[348392]|0;if((ao|0)<(c[348406]|0)){cg=ao;break}}}v=(d[1393612]&O|0)==0;a[1393612]=0;if(!v){a[1393608]=0;a[1393610]=0;a[1393611]=0;c[348404]=-1;b9=an;ca=cg;break L1155}v=Q-3|0;if((v|0)==0){b5=cg;break L855}if(b6){a[1393611]=(e[ak>>1]|0)<8192|0}ao=HG((d[m]|0)+8451&65535)|0;HN(ao,d[l]<<16|e[ak>>1]);b[A>>1]=(b[A>>1]|0)-1&65535;b[ak>>1]=(e[ak>>1]|0)+ad&65535;ao=(c[348392]|0)+8|0;c[348392]=ao;if((ao|0)<(c[348406]|0)){ch=ao}else{while(1){j1();ao=c[348392]|0;if((ao|0)<(c[348406]|0)){ch=ao;break}}}an=(d[1393612]&O|0)==0;a[1393612]=0;if(an){b9=Q-4|0;ca=ch;break L1155}else{a[1393608]=0;a[1393610]=0;a[1393611]=0;c[348404]=-1;b9=v;ca=ch;break L1155}break};default:{b9=Q;ca=b8;break L1155}}}else{a[1393608]=0;a[1393610]=0;a[1393611]=0;c[348404]=-1;b9=Q;ca=b8}}while(0);if((b9|0)==0){b5=ca;break}else{Q=b9}}}}while(0);do{if((c[348395]&128|0)!=0&(c[199748]|0)!=65535){A=(c[199753]|0)+b5|0;c[199748]=A;l=c[199741]|0;if((A|0)<(l|0)){break}c[199748]=A-l}}while(0);if(!((a[799126]|0)==0|(ag|0)==0)){XZ(ag)}a[1393608]=0;a[1393610]=0;a[1393611]=0;c[348404]=-1}}while(0);j=p&255;if((p&255)>=8){break L659}p=p+1&255;q=j;r=a[797496+j|0]|0}break};case 16899:{k=c[263195]|0;i=ab(d[k+16898|0]|0,f&255)|0;a[k+16918|0]=i&255;a[(c[263195]|0)+16919|0]=i>>>8&255;break L659;break};case 16902:{i=c[263195]|0;k=a[i+16900|0]|0;j=a[i+16901|0]|0;l=f&255;if(f<<24>>24==0){ci=j;cj=k;ck=-1;cl=-1}else{A=((j&255)<<8|k&255)&65535;k=(A>>>0)/(l>>>0)|0;ci=0;cj=((A>>>0)%(l>>>0)|0)&255;ck=k&255;cl=(k&65535)>>>8&255}a[i+16916|0]=ck;a[(c[263195]|0)+16917|0]=cl;a[(c[263195]|0)+16918|0]=cj;a[(c[263195]|0)+16919|0]=ci;break L659;break};case 16903:{i=b[522199]|0;k=i&-256|f&255;b[522199]=k;if(k<<16>>16==i<<16>>16){break L659}HI();break L659;break};case 16897:{do{if(f<<24>>24>-1){i=c[263195]|0;if((a[i+16915|0]|0)>=0){n=566;break}k=c[348392]|0;a[1044412]=1;b[522203]=c[348394]&65535;if((c[199741]|0)==(c[199740]|0)){l=(k|0)>1291?k-2|0:k;cm=(l|0)>1307?l-2|0:l}else{cm=k}b[522202]=((cm|0)/4|0)&65535;k=i+8511|0;a[k]=a[k]|64;k=c[348394]|0;i=e[522205]|0;if((k|0)<=(i|0)){if((k|0)!=(i|0)){break}if((c[348392]|0)<(e[522204]<<2|0)){break}}b[522205]=1e3}else{n=566}}while(0);do{if((n|0)==566){i=c[348394]|0;k=b[522205]|0;l=k&65535;if((i|0)<=(l|0)){if((i|0)!=(l|0)){break}if((c[348392]|0)<(e[522204]<<2|0)){break}}l=c[263195]|0;if(f<<24>>24<0){n=571}else{if((a[l+16915|0]|0)<0){n=571}}if((n|0)==571){a[1044412]=1;b[522203]=k;b[522202]=b[522204]|0;k=l+8511|0;a[k]=a[k]|64}b[522205]=1e3}}while(0);a[(c[263195]|0)+16915|0]=f;a[(c[263195]|0)+16897|0]=f;break L659;break};case 16904:{k=b[522199]|0;l=k&255|(f&255)<<8&256;b[522199]=l;if(l<<16>>16==k<<16>>16){break L659}HI();break L659;break};case 16905:{k=b[522200]|0;l=k&-256|f&255;b[522200]=l;if(l<<16>>16==k<<16>>16){break L659}HI();break L659;break};case 16908:{if((a[1393610]|0)==0){a[(c[263195]|0)+16908|0]=f;a[1044491]=~a[1044492]&f;break L659}else{return}break};case 16909:{k=f&1;if((k|0)==(a[(c[263195]|0)+16909|0]&1|0)){break L659}c[348401]=8;if((k|0)==0){break L659}c[348401]=6;break L659;break};case 16898:case 16900:case 16901:{break L659;break};case 16912:case 16913:case 16914:case 16915:case 16916:case 16917:case 16918:case 16919:case 16920:case 16921:case 16922:case 16923:case 16924:case 16925:case 16926:case 16927:{return};default:{if(!((a[799126]|0)!=0&(g&65535)>18431)){if(!((a[799125]|0)!=0&(g&65535)>18435&(g&65535)<18440)){break L659}k=(h<<8)-4716544|0;l=(f&255)<<20&7340032;i=0;while(1){A=(c[263192]|0)+((i<<12)+l)|0;j=i+16|0;m=i;do{c[1052804+(k+m<<2)>>2]=A;m=m+1|0;}while((m|0)<(j|0));if((j|0)<256){i=j}else{break L659}}}if((a[799127]|0)==0&(g&65535)>18495){break L659}if(g<<16>>16==18480){i=f<<24>>24<0?4:12;c[263207]=i;c[263208]=i;c[263975]=i;c[263976]=i}switch(h|0){case 18433:{a[237800]=f;break L659;break};case 18434:{a[237792]=f;break L659;break};case 18435:{a[237784]=f;break L659;break};case 18436:{a[237776]=f;break L659;break};case 18437:{a[237768]=f;break L659;break};case 18438:{a[237760]=f;i=(c[274486]|0)-1048576|0;k=(d[237792]<<8|d[237800]|d[237784]<<16)+(d[237776]<<2)|0;while(1){if(k>>>0<i>>>0){break}else{k=k-i|0}}l=c[263192]|0;m=d[l+(k+1048576)|0]|0;A=d[l+(k+1048578)|0]<<8|d[l+(k+1048577)|0]<<16|d[l+(k+1048579)|0];z=a[237768]|0;t=f&255;c[199378]=m;c[199376]=A;c[199382]=0;c[199380]=0;c[199384]=0;s=0;do{a[797712+(s<<1)|0]=0;a[797713+(s<<1)|0]=0;s=s+1|0;}while(s>>>0<32);s=(z&255|t<<8)<<m;if((m|0)==0){c[42464]=0;c[42466]=0;c[42462]=0;a[169840]=-1;if(i>>>0>A>>>0){cn=A}else{k=A;do{k=k-i|0;}while(k>>>0>=i>>>0);c[199376]=k;cn=k}t=cn+1|0;c[199376]=t;a[169832]=a[l+(cn+1048576)|0]|0;if(t>>>0<i>>>0){co=t}else{z=t;do{z=z-i|0;}while(z>>>0>=i>>>0);c[199376]=z;co=z}c[199376]=co+1;a[169880]=a[l+(co+1048576)|0]|0;c[42468]=8}else if((m|0)==1){c[42444]=0;c[42445]=1;c[42446]=2;c[42447]=3;c[42450]=0;c[42452]=0;c[42448]=0;a[169752]=-1;if(i>>>0>A>>>0){cp=A}else{k=A;do{k=k-i|0;}while(k>>>0>=i>>>0);c[199376]=k;cp=k}z=cp+1|0;c[199376]=z;a[169744]=a[l+(cp+1048576)|0]|0;if(z>>>0<i>>>0){cq=z}else{t=z;do{t=t-i|0;}while(t>>>0>=i>>>0);c[199376]=t;cq=t}c[199376]=cq+1;a[169824]=a[l+(cq+1048576)|0]|0;c[42454]=8}else if((m|0)==2){c[42402]=0;c[42403]=1;c[42404]=2;c[42405]=3;c[42406]=4;c[42407]=5;c[42408]=6;c[42409]=7;c[42410]=8;c[42411]=9;c[42412]=10;c[42413]=11;c[42414]=12;c[42415]=13;c[42416]=14;c[42417]=15;a[169720]=0;c[42422]=0;c[42424]=0;c[42418]=0;c[42420]=0;a[169536]=-1;if(i>>>0>A>>>0){cr=A}else{k=A;do{k=k-i|0;}while(k>>>0>=i>>>0);c[199376]=k;cr=k}A=cr+1|0;c[199376]=A;a[169528]=a[l+(cr+1048576)|0]|0;if(A>>>0<i>>>0){cs=A}else{t=A;do{t=t-i|0;}while(t>>>0>=i>>>0);c[199376]=t;cs=t}c[199376]=cs+1;a[169712]=a[l+(cs+1048576)|0]|0;c[42426]=8}if((s|0)!=0){i=s;k=0;A=0;while(1){z=i-1|0;do{if((k|0)==0){if((m|0)==0){T2();n=973;break}else if((m|0)==1){T3();n=973;break}else if((m|0)==2){T5();n=973;break}else{ct=0;cu=A;break}}else{n=973}}while(0);if((n|0)==973){n=0;j=A+1&63;c[199382]=j;Q=(c[199384]|0)-1|0;c[199384]=Q;ct=Q;cu=j}if((z|0)==0){break}else{i=z;k=ct;A=cu}}}a[237712]=-128;break L659;break};case 18439:{a[237752]=f;break L659;break};case 18440:{a[237744]=f;break L659;break};case 18441:{a[237736]=f;break L659;break};case 18442:{a[237728]=f;break L659;break};case 18443:{a[237720]=f;break L659;break};case 18449:{a[237704]=f;a[237624]=a[237624]|1;break L659;break};case 18450:{a[237696]=f;a[237624]=a[237624]|2;break L659;break};case 18451:{a[237688]=f;a[237624]=a[237624]|4;break L659;break};case 18452:{a[237680]=f;a[237672]=1;if((a[237656]|0)==0){break L659}A=a[237632]|0;k=A&255;if((k&18|0)!=2){break L659}i=k&96;if((i|0)==32){k=(d[237696]<<8|d[237704]|d[237688]<<16)+((A&8)==0?f&255:f<<24>>24)|0;a[237704]=k&255;a[237696]=k>>>8&255;a[237688]=k>>>16&255;break L659}else if((i|0)!=64){break L659}i=d[237664]<<8|f&255;if((A&8)==0){cv=i}else{cv=i<<16>>16}i=(d[237696]<<8|d[237704]|d[237688]<<16)+cv|0;a[237704]=i&255;a[237696]=i>>>8&255;a[237688]=i>>>16&255;break L659;break};case 18453:{a[237664]=f;a[237656]=1;if((a[237672]|0)==0){break L659}i=a[237632]|0;A=i&255;if((A&18|0)!=2){break L659}k=A&96;if((k|0)==32){A=a[237680]|0;m=(d[237696]<<8|d[237704]|d[237688]<<16)+((i&8)==0?A&255:A<<24>>24)|0;a[237704]=m&255;a[237696]=m>>>8&255;a[237688]=m>>>16&255;break L659}else if((k|0)!=64){break L659}k=d[237680]|(f&255)<<8;if((i&8)==0){cw=k}else{cw=k<<16>>16}k=(d[237696]<<8|d[237704]|d[237688]<<16)+cw|0;a[237704]=k&255;a[237696]=k>>>8&255;a[237688]=k>>>16&255;break L659;break};case 18454:{a[237648]=f;break L659;break};case 18455:{a[237640]=f;break L659;break};case 18456:{if((a[237624]|0)!=7){break L659}a[237632]=f;a[237656]=0;a[237672]=0;break L659;break};case 18464:{a[237616]=f;break L659;break};case 18465:{a[237608]=f;break L659;break};case 18466:{a[237600]=f;break L659;break};case 18467:{a[237592]=f;break L659;break};case 18468:{a[237584]=f;break L659;break};case 18469:{a[237576]=f;k=d[237584]|(f&255)<<8;i=d[237608]<<8|d[237616];if((a[237504]&1)==0){m=ab(i&65535,k&65535)|0;a[237552]=m&255;a[237544]=m>>>8&255;cx=m;cy=m>>>16}else{m=ab(i<<16>>16,k<<16>>16)|0;a[237552]=m&255;a[237544]=m>>>8&255;cx=m;cy=m>>>16}a[237536]=cy&255;a[237528]=cx>>>24&255;a[237496]=-128;break L659;break};case 18470:{a[237568]=f;break L659;break};case 18471:{a[237560]=f;m=a[237616]|0;k=a[237608]|0;i=(k&255)<<8|m&255|d[237600]<<16|d[237592]<<24;A=d[237568]|(f&255)<<8;s=A<<16>>16==0;do{if((a[237504]&1)==0){if(s){cz=k;cA=m;cB=0;cC=0;cD=0;cE=0;break}l=A&65535;t=(i>>>0)/(l>>>0)|0;j=(i>>>0)%(l>>>0)|0;cz=(j&65535)>>>8&255;cA=j&255;cB=t>>>24&255;cC=t>>>16&255;cD=t>>>8&255;cE=t&255}else{if(s){cz=k;cA=m;cB=0;cC=0;cD=0;cE=0;break}t=A<<16>>16;j=(i|0)/(t|0)|0;l=(i|0)%(t|0)|0;cz=(l&65535)>>>8&255;cA=l&255;cB=j>>>24&255;cC=j>>>16&255;cD=j>>>8&255;cE=j&255}}while(0);a[237552]=cE;a[237544]=cD;a[237536]=cC;a[237528]=cB;a[237520]=cA;a[237512]=cz;a[237496]=-128;break L659;break};case 18478:{a[237592]=0;a[237600]=0;a[237608]=0;a[237616]=0;a[237560]=0;a[237568]=0;a[237576]=0;a[237584]=0;a[237528]=0;a[237536]=0;a[237544]=0;a[237552]=0;a[237512]=0;a[237520]=0;a[237504]=f;break L659;break};case 18480:{a[237488]=f;break L659;break};case 18481:{a[237480]=f;i=(c[274486]|0)-1048576|0;A=(f&255)<<20&7340032;while(1){if(A>>>0<i>>>0){break}else{A=A-i|0}}c[198898]=A+1048576;break L659;break};case 18482:{a[237472]=f;i=(c[274486]|0)-1048576|0;m=(f&255)<<20&7340032;while(1){if(m>>>0<i>>>0){break}else{m=m-i|0}}c[198894]=m+1048576;break L659;break};case 18483:{a[237464]=f;i=(c[274486]|0)-1048576|0;A=(f&255)<<20&7340032;while(1){if(A>>>0<i>>>0){break}else{A=A-i|0}}c[198890]=A+1048576;break L659;break};case 18484:{a[237456]=f;break L659;break};case 18496:{a[237448]=f;if((f&1)==0){c[58912]=0;i=eG(0)|0;a[1041696]=i&255;a[1041697]=i>>>8&255;a[1041698]=i>>>16&255;a[1041699]=i>>>24&255;break L659}else{a[237432]=-128;c[58912]=1;break L659}break};case 18497:{a[237440]=f;i=c[58912]|0;if((i|0)==1){if(!((f<<24>>24|0)==3|(f<<24>>24|0)==12)){break L659}a[237432]=-128;c[58912]=2;c[58914]=f&255;c[58920]=0;break L659}else if((i|0)==2){a[237432]=-128;c[58920]=f&15;if((c[58914]|0)!=3){break L659}c[58912]=3;break L659}else if((i|0)==3){a[237432]=-128;i=c[58920]|0;if((i|0)==13){m=f&255;if((m&2|0)!=0){k=(eG(0)|0)-1|0;a[1041696]=k&255;a[1041697]=k>>>8&255;a[1041698]=k>>>16&255;a[1041699]=k>>>24&255}do{if((m&8|0)!=0){k=eG(0)|0;a[1041696]=k&255;a[1041697]=k>>>8&255;a[1041698]=k>>>16&255;a[1041699]=k>>>24&255;k=((d[1041681]|0)*10|0)+(d[1041680]|0)|0;a[1041680]=0;a[1041681]=0;if(k>>>0<=29){break}k=(eG(0)|0)-60|0;a[1041696]=k&255;a[1041697]=k>>>8&255;a[1041698]=k>>>16&255;a[1041699]=k>>>24&255}}while(0);cF=c[58920]|0}else{cF=i}do{if((cF|0)==15){m=f&255;do{if((m&1|0)!=0){if((a[1041695]&1)!=0){break}A=eG(0)|0;a[1041696]=A&255;a[1041697]=A>>>8&255;a[1041698]=A>>>16&255;a[1041699]=A>>>24&255;a[1041680]=0;a[1041681]=0}}while(0);if((m&2|0)==0){break}if((a[1041695]&2)!=0){break}z=eG(0)|0;a[1041696]=z&255;a[1041697]=z>>>8&255;a[1041698]=z>>>16&255;a[1041699]=z>>>24&255}}while(0);i=c[58920]|0;a[1041680+i|0]=f&15;c[58920]=i+1&15;break L659}else{break L659}break};default:{break L659}}}}}}while(0);a[(c[263195]|0)+h|0]=f;return}function HI(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=b[522199]|0;do{if((a[1044391]|0)==0){f=20;g=e}else{if(e<<16>>16==0){f=20;g=0;break}h=e<<2;b[522197]=h;do{if((c[199741]|0)==(c[199740]|0)&(e&65535)>322){i=h|2;b[522197]=i;if((e&65535)<=326){j=i;break}k=i+2&65535;b[522197]=k;j=k}else{j=h}}while(0);f=j+24&65535;g=e}}while(0);b[522197]=f;e=b[522200]|0;b[522198]=e;j=f<<16>>16;h=c[199741]|0;do{if((j|0)>=(h|0)&(g&65535)<340){k=j-h&65535;b[522197]=k;i=e+1&65535;b[522198]=i;if((i<<16>>16|0)<(c[199743]|0)){l=k;break}b[522198]=0;l=k}else{l=f}}while(0);f=l<<16>>16;if((f|0)<(c[348392]|0)){switch(d[1393620]|0){case 8:{a[1393620]=9;c[348406]=c[199750];return};case 12:{a[1393620]=1;c[348406]=c[199744];return};case 10:{a[1393620]=11;c[348406]=c[199749];return};case 6:{a[1393620]=7;c[348406]=c[199746];return};case 2:{a[1393620]=3;c[348406]=c[199747];return};case 4:{a[1393620]=5;c[348406]=h;return};default:{return}}}l=c[348406]|0;e=a[1393620]|0;do{if((f|0)>=(l|0)){if((e&1)==0&(f|0)==(l|0)){break}switch(e&255|0){case 2:{a[1393620]=3;c[348406]=c[199747];return};case 4:{a[1393620]=5;c[348406]=h;return};case 12:{a[1393620]=1;c[348406]=c[199744];return};case 6:{a[1393620]=7;c[348406]=c[199746];return};case 8:{a[1393620]=9;c[348406]=c[199750];return};case 10:{a[1393620]=11;c[348406]=c[199749];return};default:{return}}}}while(0);c[348406]=f;switch(e&255|0){case 7:{a[1393620]=6;return};case 9:{a[1393620]=8;return};case 11:{a[1393620]=10;return};case 1:{a[1393620]=12;return};case 3:{a[1393620]=2;return};case 5:{a[1393620]=4;return};default:{return}}}function HJ(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;g=f&65535;if((f&65535)>=16896){if((g&65408|0)!=17152){switch(g|0){case 16912:{h=(c[263195]|0)+16912|0;i=a[h]|0;a[h]=2;j=i&-128|a[1044496]&112|2;return j|0};case 16913:{i=a[1393588]|0;h=i&-3;a[1393588]=h;if(h<<24>>24==0){c[348395]=c[348395]&-2049}j=a[1044496]&127|i<<6&-128;return j|0};case 16914:{i=c[348394]|0;h=e[522243]|0;k=h+1|0;l=(i|0)>=(k|0)&(i|0)<(h+4|0)&1;h=c[348392]|0;m=(h|0)>=(c[199745]|0)&(h|0)<(c[199744]|0)?l:l|64;j=((i|0)<(k|0)?m:m|-128)|a[1044496]&62;return j|0};case 16920:case 16921:case 16922:case 16923:case 16924:case 16925:case 16926:case 16927:{j=a[(c[263195]|0)+g|0]|0;return j|0};case 16915:{j=a[(c[263195]|0)+16915|0]|0;return j|0};case 16916:case 16917:case 16918:case 16919:{j=a[(c[263195]|0)+g|0]|0;return j|0};default:{m=(f&65535)>18431;if((a[799126]|0)!=0&m){j=Ua(f)|0;return j|0}if((a[799125]|0)!=0&m&(f&65535)<18440){j=a[(c[263195]|0)+g|0]|0;return j|0}else{j=a[1044496]|0;return j|0}}}}if((a[1393610]|0)!=0){j=a[1044496]|0;return j|0}m=g>>>4&7;switch(g&15|0){case 3:{j=(e[1183784+(m*22|0)>>1]|0)>>>8&255;return j|0};case 9:{j=(e[1183792+(m*22|0)>>1]|0)>>>8&255;return j|0};case 10:{j=((a[1183794+(m*22|0)|0]|0)!=0?0:-128)^a[1183795+(m*22|0)|0];return j|0};case 11:case 15:{j=a[1183796+(m*22|0)|0]|0;return j|0};case 0:{j=((a[1183777+(m*22|0)|0]|0)!=0?64:0)|((a[1183776+(m*22|0)|0]|0)!=0?-128:0)|((a[1183778+(m*22|0)|0]|0)!=0?32:0)|((a[1183780+(m*22|0)|0]|0)!=0?16:0)|((a[1183779+(m*22|0)|0]|0)!=0?8:0)|a[1183781+(m*22|0)|0]&7;return j|0};case 1:{j=a[1183782+(m*22|0)|0]|0;return j|0};case 2:{j=b[1183784+(m*22|0)>>1]&255;return j|0};case 4:{j=a[1183786+(m*22|0)|0]|0;return j|0};case 5:{j=b[1183788+(m*22|0)>>1]&255;return j|0};case 6:{j=(e[1183788+(m*22|0)>>1]|0)>>>8&255;return j|0};case 7:{j=a[1183790+(m*22|0)|0]|0;return j|0};case 8:{j=b[1183792+(m*22|0)>>1]&255;return j|0};default:{j=a[1044496]|0;return j|0}}}m=g-16406|0;if(m>>>0>=2){j=a[1044496]|0;return j|0}k=(f&65535)>1?m:g;g=a[1044496]&-4|((k|0)==1?28:0);m=c[15744+(k<<2)>>2]|0;if((a[1125520]|0)!=0){switch(m|0){case-1:{j=g|2;return j|0};case 0:case 1:case 2:case 3:case 4:case 5:case 6:case 7:{j=(e[509632+(m<<1)>>1]|0)>>>15&255|g;return j|0};case 8:case 9:{f=238618+((m-8|0)*20|0)|0;i=(a[f]|0)+16&255;a[f]=(i&48)==48?i&-49:i;j=g;return j|0};case 10:{j=(d[169494]|0)>>>7|g;return j|0};default:{j=g;return j|0}}}switch(m|0){case 12:{i=236008+(k<<1)|0;f=a[i]|0;l=f&255;if((f&255)<24){a[i]=f+1&255;j=(11169792>>>(l>>>0)&1|g&255)&255;return j|0}if((f&255)<32){h=d[509608]|0;a[i]=f+1&255;j=(h&-2147483648>>>(l>>>0)|0)!=0|g;return j|0}else{a[i]=f+1&255;j=g|1;return j|0}break};case 10:{f=236008+(k<<1)|0;i=a[f]|0;if((i&255)<8){l=d[169494]|0;a[f]=i+1&255;j=(l&128>>>((i&255)>>>0)|0)!=0|g;return j|0}else{a[f]=i+1&255;j=g|1;return j|0}break};case 11:{i=236008+(k<<1)|0;f=a[i]|0;l=f&255;if((f&255)<24){a[i]=f+1&255;j=(11169792>>>(l>>>0)&1|g&255)&255;return j|0}if((f&255)<32){h=d[509608]|0;a[i]=f+1&255;j=(-2147483648>>>(l>>>0)&168&h|0)!=0|g;return j|0}else{a[i]=f+1&255;j=g|1;return j|0}break};case-1:{f=d[(c[263195]|0)+16915|0]&((k|0)!=0?128:64);i=((f|0)==0)+(236008+(k<<1))|0;h=a[i]|0;a[i]=h+1&255;i=(f|0)!=0?0:2;f=(h&255)>15;l=32768>>>((h&255)>>>0);h=a[238600+(k<<2)+i|0]|0;n=h<<24>>24;do{if(h<<24>>24==-2){o=g}else{if(f){o=g|1;break}else{o=(e[509632+(n<<1)>>1]&l|0)!=0|g;break}}}while(0);n=a[(i|1)+(238600+(k<<2))|0]|0;if(n<<24>>24==-2){j=o;return j|0}if(f){j=o|2;return j|0}else{j=((e[509632+(n<<24>>24<<1)>>1]&l|0)!=0)<<1|o;return j|0}break};case 0:case 1:case 2:case 3:case 4:case 5:case 6:case 7:{o=236008+(k<<1)|0;l=a[o]|0;if((l&255)>15){a[o]=l+1&255;j=g|1;return j|0}else{n=e[509632+(m<<1)>>1]|0;a[o]=l+1&255;j=(n&32768>>>((l&255)>>>0)|0)!=0|g;return j|0}break};case 8:case 9:{l=236008+(k<<1)|0;n=a[l]|0;o=n&255;if((n&255)<8){a[l]=n+1&255;j=g;return j|0}if((n&255)<16){f=d[238618+((m-8|0)*20|0)|0]|0;a[l]=n+1&255;j=(f&32768>>>(o>>>0)|0)!=0|g;return j|0}if((n&255)<24){f=d[238609+((m-8|0)*20|0)|0]|0;a[l]=n+1&255;j=(f&8388608>>>(o>>>0)|0)!=0|g;return j|0}if((n&255)<32){f=d[238608+((m-8|0)*20|0)|0]|0;a[l]=n+1&255;j=(f&-2147483648>>>(o>>>0)|0)!=0|g;return j|0}else{a[l]=n+1&255;j=g|1;return j|0}break};default:{n=236008+(k<<1)|0;a[n]=(a[n]|0)+1&255;j=g;return j|0}}return 0}function HK(a){a=a|0;var b=0,d=0,e=0;b=c[1052804+((a>>>12&4095)<<2)>>2]|0;if(b>>>0>=19){d=b;return d|0}switch(b|0){case 2:{b=c[274485]|0;if((b&4095|0)!=4095){d=0;return d|0}d=(c[263193]|0)+((b&(a>>>1&8355840|a&32767))-(a&65535))|0;return d|0};case 3:{b=c[261136]|0;if((b&4095|0)!=4095){d=0;return d|0}d=(c[261140]|0)+((b&(a>>>1&8355840|a&32767))-(a&65535))|0;return d|0};case 4:{b=c[274485]|0;if((b&4095|0)!=4095){d=0;return d|0}d=(c[263193]|0)+((b&(a&32767)-24576+(a>>>3&122880))-(a&65535))|0;return d|0};case 7:{d=(c[263196]|0)+(-24576-(a&32768))|0;return d|0};case 6:{d=c[263193]|0;return d|0};case 10:{b=a&15728640;if((b|0)==13631488){e=c[198898]|0}else if((b|0)==14680064){e=c[198894]|0}else if((b|0)==15728640){e=c[198890]|0}else{e=0}d=(c[263192]|0)+(e+(a&983040))|0;return d|0};case 13:{if(((a&65535)-32576&65535)<31){d=0;return d|0}d=(c[263197]|0)-24576|0;return d|0};case 14:{if(((a&65535)-32752&65535)<7){d=0;return d|0}d=(c[263198]|0)-24576|0;return d|0};default:{d=0;return d|0}}return 0}function HL(){var f=0,g=0,h=0;c[59002]=0;a[1125520]=0;a[1041704]=0;a[1041705]=1;b[520853]=0;b[520855]=0;b[520856]=0;a[1041771]=0;a[1041772]=0;a[1041773]=0;X2(1041716,0,11);X2(1041728,0,11);X2(1041740,0,11);X2(1041752,0,11);X2(1041764,0,6);f=0;while(1){b[1041774+(f<<1)>>1]=(f>>>3<<7&896|f<<2&28|f>>>6<<13&16384)&65535;g=f+1|0;if((g|0)<256){f=g}else{h=0;break}}while(1){f=h+1|0;X2(1042286+(h*12|0)|0,0,11);if((f|0)<128){h=f}else{break}}a[1043822]=0;a[1043823]=0;a[1043824]=0;X2(1043826,0,5);X2(1043832,0,7);X2(1043840,0,549);a[1044389]=127;a[1044390]=0;a[1044391]=0;a[1044392]=0;b[522197]=(c[199741]|0)+1&65535;b[522198]=(c[199743]|0)+1&65535;b[522199]=511;b[522200]=511;h=1044402;f=h|0;x=0;b[f>>1]=x&65535;b[f+2>>1]=x>>16;f=h+4|0;x=0;b[f>>1]=x&65535;b[f+2>>1]=x>>16;b[522205]=1e3;a[1044432]=0;X2(1044412,0,16);x=0;b[522217]=x&65535;b[1044436>>1]=x>>16;a[1044440]=1;a[1044441]=0;a[1044442]=1;a[1044443]=0;a[1044444]=1;a[1044445]=0;a[1044451]=0;a[1044457]=0;a[1044463]=0;a[1044469]=1;a[1044475]=1;a[1044446]=0;a[1044452]=0;a[1044458]=0;a[1044464]=0;a[1044470]=1;a[1044476]=1;a[1044447]=0;a[1044453]=0;a[1044459]=0;a[1044465]=0;a[1044471]=1;a[1044477]=1;a[1044448]=0;a[1044454]=0;a[1044460]=0;a[1044466]=0;a[1044472]=1;a[1044478]=1;a[1044449]=0;a[1044455]=0;a[1044461]=0;a[1044467]=0;a[1044473]=1;a[1044479]=1;a[1044450]=0;a[1044456]=0;a[1044462]=0;a[1044468]=0;a[1044474]=1;a[1044480]=1;a[1044481]=1;x=0;b[522241]=x&65535;b[1044484>>1]=x>>16;b[522243]=224;a[1044488]=0;a[1044489]=0;x=0;a[1044491]=x&255;x=x>>8;a[1044492|0]=x&255;x=x>>8;a[1044493|0]=x&255;x=x>>8;a[1044494|0]=x&255;X2(1105704,0,32);X2(1105896,0,32);a[1106088]=1;a[1106089]=1;X2(c[276530]|0,0,4096);X2(c[276531]|0,0,2048);X2(c[276532]|0,0,1024);X2(c[276533]|0,0,4096);X2(c[276534]|0,0,4096);X2(c[276535]|0,0,2048);X2(c[276536]|0,0,2048);a[1106148]=0;a[1106149]=0;a[1106150]=0;a[1106152]=0;a[1106153]=0;c[276539]=0;c[276540]=0;c[276541]=0;f=0;do{b[1106168+(f<<1)>>1]=f&65535;f=f+1|0;}while((f|0)<256);c[276670]=256;c[276671]=224;f=7080+((d[1044485]|0)<<5)|0;c[276541]=f;h=0;g=f;while(1){f=e[1041774+(h<<1)>>1]|0;b[1106168+(h<<1)>>1]=(d[g+(f>>>5&31)|0]|0)<<6|(d[g+(f&31)|0]|0)<<11|(d[g+(f>>>10&31)|0]|0);f=h+1|0;if((f|0)>=256){break}h=f;g=c[276541]|0}g=0;h=c[263195]|0;do{X2(h+g|0,g>>>8&255|0,256);g=g+256|0;h=c[263195]|0}while((g|0)<32768);X2(h+8448|0,0,256);X2((c[263195]|0)+16896|0,0,256);X2((c[263195]|0)+16384|0,0,256);X2((c[263195]|0)+4096|0,0,4096);a[(c[263195]|0)+16915|0]=-1;a[(c[263195]|0)+16897|0]=-1;return}function HM(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=c[1052804+((b>>>12&4095)<<2)>>2]|0;do{if((b&4227072|0)==0){if((b+24576&16384|0)!=0){e=8;break}e=(b+16384&32256|0)==0?12:6}else{e=(b&8388608|0)==0?8:c[348401]|0}}while(0);if(d>>>0>=19){f=a[d+(b&65535)|0]|0;if((a[1393610]|0)!=0){g=f;return g|0}h=(c[348392]|0)+e|0;c[348392]=h;if((h|0)<(c[348406]|0)){g=f;return g|0}while(1){j1();if((c[348392]|0)<(c[348406]|0)){g=f;break}}return g|0}switch(d|0){case 0:{d=HJ(b&65535)|0;if((a[1393610]|0)!=0){g=d;return g|0}f=(c[348392]|0)+e|0;c[348392]=f;if((f|0)<(c[348406]|0)){g=d;return g|0}while(1){j1();if((c[348392]|0)<(c[348406]|0)){g=d;break}}return g|0};case 1:{do{if((a[1393610]|0)!=0){if((b&65280|0)!=8448){break}g=a[1044496]|0;return g|0}}while(0);d=HG(b&65535)|0;if((a[1393610]|0)!=0){g=d;return g|0}f=(c[348392]|0)+e|0;c[348392]=f;if((f|0)<(c[348406]|0)){g=d;return g|0}while(1){j1();if((c[348392]|0)<(c[348406]|0)){g=d;break}}return g|0};case 2:case 6:{d=a[(c[263193]|0)+(c[274485]&(b>>>1&8355840|b&32767))|0]|0;if((a[1393610]|0)!=0){g=d;return g|0}f=(c[348392]|0)+e|0;c[348392]=f;if((f|0)<(c[348406]|0)){g=d;return g|0}while(1){j1();if((c[348392]|0)<(c[348406]|0)){g=d;break}}return g|0};case 3:{d=a[(c[261140]|0)+(c[261136]&(b>>>1&8355840|b&32767))|0]|0;if((a[1393610]|0)!=0){g=d;return g|0}f=(c[348392]|0)+e|0;c[348392]=f;if((f|0)<(c[348406]|0)){g=d;return g|0}while(1){j1();if((c[348392]|0)<(c[348406]|0)){g=d;break}}return g|0};case 4:case 12:{d=a[(c[263193]|0)+(c[274485]&(b&32767)-24576+(b>>>3&122880))|0]|0;if((a[1393610]|0)!=0){g=d;return g|0}f=(c[348392]|0)+e|0;c[348392]=f;if((f|0)<(c[348406]|0)){g=d;return g|0}while(1){j1();if((c[348392]|0)<(c[348406]|0)){g=d;break}}return g|0};case 7:{d=a[(c[263196]|0)+((b&32767)-24576)|0]|0;if((a[1393610]|0)!=0){g=d;return g|0}f=(c[348392]|0)+e|0;c[348392]=f;if((f|0)<(c[348406]|0)){g=d;return g|0}while(1){j1();if((c[348392]|0)<(c[348406]|0)){g=d;break}}return g|0};case 5:{d=fe[c[276698]&127](b&65535)|0;if((a[1393610]|0)!=0){g=d;return g|0}f=(c[348392]|0)+e|0;c[348392]=f;if((f|0)<(c[348406]|0)){g=d;return g|0}while(1){j1();if((c[348392]|0)<(c[348406]|0)){g=d;break}}return g|0};case 10:{d=b&15728640;if((d|0)==13631488){i=c[198898]|0}else if((d|0)==14680064){i=c[198894]|0}else if((d|0)==15728640){i=c[198890]|0}else{i=0}d=a[(c[263192]|0)+(i+(b&1048575))|0]|0;if((a[1393610]|0)!=0){g=d;return g|0}i=(c[348392]|0)+e|0;c[348392]=i;if((i|0)<(c[348406]|0)){g=d;return g|0}while(1){j1();if((c[348392]|0)<(c[348406]|0)){g=d;break}}return g|0};case 11:{d=Ua(18432)|0;if((a[1393610]|0)!=0){g=d;return g|0}i=(c[348392]|0)+e|0;c[348392]=i;if((i|0)<(c[348406]|0)){g=d;return g|0}while(1){j1();if((c[348392]|0)<(c[348406]|0)){g=d;break}}return g|0};case 13:{if((b&65535)<<16>>16==32606){j=0}else{j=a[(c[263197]|0)+((b&65535)-24576)|0]|0}if((a[1393610]|0)!=0){g=j;return g|0}d=(c[348392]|0)+e|0;c[348392]=d;if((d|0)<(c[348406]|0)){g=j;return g|0}while(1){j1();if((c[348392]|0)<(c[348406]|0)){g=j;break}}return g|0};case 14:{j=Ht(b&65535)|0;if((a[1393610]|0)!=0){g=j;return g|0}d=(c[348392]|0)+e|0;c[348392]=d;if((d|0)<(c[348406]|0)){g=j;return g|0}while(1){j1();if((c[348392]|0)<(c[348406]|0)){g=j;break}}return g|0};case 15:{j=fe[c[40480]&127](b)|0;if((a[1393610]|0)!=0){g=j;return g|0}d=(c[348392]|0)+e|0;c[348392]=d;if((d|0)<(c[348406]|0)){g=j;return g|0}while(1){j1();if((c[348392]|0)<(c[348406]|0)){g=j;break}}return g|0};case 16:{do{if((b&65535|0)==14340){j=c[201864]|0;if((j|0)==0){k=-127;break}d=c[201862]|0;i=a[807496+d|0]|0;f=d+1|0;c[201862]=f;if((j|0)!=(f|0)){k=i;break}c[201864]=0;k=i}else{k=0}}while(0);if((a[1393610]|0)!=0){g=k;return g|0}i=(c[348392]|0)+e|0;c[348392]=i;if((i|0)<(c[348406]|0)){g=k;return g|0}while(1){j1();if((c[348392]|0)<(c[348406]|0)){g=k;break}}return g|0};case 17:{k=b&65535;i=b>>>16&255;do{if((i|0)!=0&i>>>0<15){if((b&65535|0)!=20480){l=1367;break}m=a[1394341+i|0]|0}else{l=1367}}while(0);do{if((l|0)==1367){if((i|0)!=192){m=0;break}f=b&65535;do{if((a[1394343]|0)==0){if(k<<16>>16>-1){n=(c[274488]|0)+f|0;break}else{n=(c[274488]|0)+(f-32768)|0;break}}else{n=(c[274488]|0)+f|0}}while(0);j=a[n]|0;if((f|0)==2){m=(a[1394259]|0)==0?j:-128;break}else if((f|0)==21845){m=(a[1394259]|0)==0?j:-128;break}else if((f|0)==65280|(f|0)==65282|(f|0)==65284|(f|0)==65286|(f|0)==65288|(f|0)==65290|(f|0)==65292|(f|0)==65294|(f|0)==65296|(f|0)==65298){if((a[1394261]|0)==0){m=j;break}m=a[15064+(f-65280)|0]|0;break}else{m=j;break}}}while(0);if((a[1393610]|0)!=0){g=m;return g|0}n=(c[348392]|0)+e|0;c[348392]=n;if((n|0)<(c[348406]|0)){g=m;return g|0}while(1){j1();if((c[348392]|0)<(c[348406]|0)){g=m;break}}return g|0};default:{m=a[1044496]|0;if((a[1393610]|0)!=0){g=m;return g|0}n=(c[348392]|0)+e|0;c[348392]=n;if((n|0)<(c[348406]|0)){g=m;return g|0}while(1){j1();if((c[348392]|0)<(c[348406]|0)){g=m;break}}return g|0}}return 0}function HN(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;e=c[1069188+((d>>>12&4095)<<2)>>2]|0;do{if((d&4227072|0)==0){if((d+24576&16384|0)!=0){f=8;break}f=(d+16384&32256|0)==0?12:6}else{f=(d&8388608|0)==0?8:c[348401]|0}}while(0);if(e>>>0>=19){a[e+(d&65535)|0]=b;if((a[1393610]|0)!=0){return}g=(c[348392]|0)+f|0;c[348392]=g;if((g|0)<(c[348406]|0)){return}do{j1();}while((c[348392]|0)>=(c[348406]|0));return}switch(e|0){case 0:{HH(b,d&65535);if((a[1393610]|0)!=0){return}e=(c[348392]|0)+f|0;c[348392]=e;if((e|0)<(c[348406]|0)){return}do{j1();}while((c[348392]|0)>=(c[348406]|0));return};case 1:{do{if((a[1393610]|0)!=0){if((d&65280|0)!=8448){break}return}}while(0);HB(b,d&65535);if((a[1393610]|0)!=0){return}e=(c[348392]|0)+f|0;c[348392]=e;if((e|0)<(c[348406]|0)){return}do{j1();}while((c[348392]|0)>=(c[348406]|0));return};case 2:{e=c[274485]|0;if((e|0)!=0){a[(c[263193]|0)+(e&(d>>>1&8355840|d&32767))|0]=b}if((a[1393610]|0)!=0){return}e=(c[348392]|0)+f|0;c[348392]=e;if((e|0)<(c[348406]|0)){return}do{j1();}while((c[348392]|0)>=(c[348406]|0));return};case 3:{e=c[261136]|0;if((e|0)!=0){a[(c[261140]|0)+(e&(d>>>1&8355840|d&32767))|0]=b}if((a[1393610]|0)!=0){return}e=(c[348392]|0)+f|0;c[348392]=e;if((e|0)<(c[348406]|0)){return}do{j1();}while((c[348392]|0)>=(c[348406]|0));return};case 4:{e=c[274485]|0;if((e|0)!=0){a[(c[263193]|0)+(e&(d&32767)-24576+(d>>>3&122880))|0]=b}if((a[1393610]|0)!=0){return}e=(c[348392]|0)+f|0;c[348392]=e;if((e|0)<(c[348406]|0)){return}do{j1();}while((c[348392]|0)>=(c[348406]|0));return};case 7:{a[(c[263196]|0)+((d&32767)-24576)|0]=b;if((a[1393610]|0)!=0){return}e=(c[348392]|0)+f|0;c[348392]=e;if((e|0)<(c[348406]|0)){return}do{j1();}while((c[348392]|0)>=(c[348406]|0));return};case 6:{a[(c[263193]|0)+(d&65535)|0]=b;if((a[1393610]|0)!=0){return}e=(c[348392]|0)+f|0;c[348392]=e;if((e|0)<(c[348406]|0)){return}do{j1();}while((c[348392]|0)>=(c[348406]|0));return};case 5:{fc[c[201852]&127](b,d&65535);if((a[1393610]|0)!=0){return}e=(c[348392]|0)+f|0;c[348392]=e;if((e|0)<(c[348406]|0)){return}do{j1();}while((c[348392]|0)>=(c[348406]|0));return};case 13:{jQ(b,d&65535);if((a[1393610]|0)!=0){return}e=(c[348392]|0)+f|0;c[348392]=e;if((e|0)<(c[348406]|0)){return}do{j1();}while((c[348392]|0)>=(c[348406]|0));return};case 14:{Hu(b,d&65535);if((a[1393610]|0)!=0){return}e=(c[348392]|0)+f|0;c[348392]=e;if((e|0)<(c[348406]|0)){return}do{j1();}while((c[348392]|0)>=(c[348406]|0));return};case 15:{fc[c[36646]&127](d,b);if((a[1393610]|0)!=0){return}e=(c[348392]|0)+f|0;c[348392]=e;if((e|0)<(c[348406]|0)){return}do{j1();}while((c[348392]|0)>=(c[348406]|0));return};case 16:{TZ(b,d);if((a[1393610]|0)!=0){return}e=(c[348392]|0)+f|0;c[348392]=e;if((e|0)<(c[348406]|0)){return}do{j1();}while((c[348392]|0)>=(c[348406]|0));return};case 17:{jM(b,d);if((a[1393610]|0)!=0){return}d=(c[348392]|0)+f|0;c[348392]=d;if((d|0)<(c[348406]|0)){return}do{j1();}while((c[348392]|0)>=(c[348406]|0));return};default:{if((a[1393610]|0)!=0){return}d=(c[348392]|0)+f|0;c[348392]=d;if((d|0)<(c[348406]|0)){return}do{j1();}while((c[348392]|0)>=(c[348406]|0));return}}}function HO(f){f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0;g=(a[1106152]|0)!=0?2:1;a[1394504]=(a[1108917]|0)!=0?8:0;a[1108908]=2;h=c[277230]|0;i=c[277231]|0;if(h>>>0>i>>>0){return}j=c[277223]|0;k=g<<3;l=0;m=0;n=ab(j,h)|0;o=h;h=j;j=i;while(1){i=a[1109196+(o*68|0)|0]|0;if(i<<24>>24>-1){p=l;q=m;r=0;s=b[1109194+(o*68|0)>>1]|0;t=i;while(1){i=t<<24>>24;u=(d[1109057+i|0]|0)+s|0;L2089:do{if((u|0)<1){v=q;w=p}else{x=d[1109196+(o*68|0)+(r<<1)+1|0]|0;y=e[1042292+(i*12|0)>>1]|0;z=1042295+(i*12|0)|0;A=d[z]<<10|y&256|(y&240)+(x<<1)&240;B=x<<3&56;if((a[1042290+(i*12|0)|0]|0)==0){C=1;D=y;E=A}else{C=-1;D=y-1+((d[1108929+i|0]|0)>>>3)|0;E=A|16384}a[1108909]=(d[1042294+(i*12|0)|0]<<2)+f&255;A=1042286+(i*12|0)|0;y=b[A>>1]|0;x=y<<16>>16;F=y<<16>>16==-256?256:x;if((F|0)>=257){v=q;w=p;break}y=1108929+i|0;if((F|0)>=((d[y]|0)+x|0)){v=q;w=p;break}x=F;G=-1e3;H=0;I=3;J=q;K=p;L=(ab(F,g)|0)+n|0;F=u;M=D;while(1){N=M&15;L2098:do{if((x|0)<-7){O=G;P=H;Q=I;R=J;S=K;T=F}else{U=F-1|0;if((U|0)<0|(x|0)==256){O=G;P=H;Q=I;R=J;S=K;T=U;break}V=x+8|0;W=N|E;X=x;Y=K;Z=J;_=I;$=H;aa=G;while(1){L2103:do{if((X|0)<(aa|0)){ac=aa;ad=$;ae=_;af=Z;ag=Y}else{ah=c[277297]|0;ai=d[ah+128|0]|0;aj=$;while(1){if((aj|0)>=(ai|0)){ak=0;break}if((e[ah+136+(aj<<1)>>1]|0)>(X|0)){ak=1;break}else{aj=aj+1|0}}do{if((aj|0)!=0){ai=aj-1|0;al=e[ah+148+(ai<<1)>>1]|0;if((X|0)>=(al|0)){break}am=a[ah+129+ai|0]|0;ai=am&255;a[1108928]=am&1^1;do{if((a[1394512]|0)!=0){if((a[z]&4)==0){break}if((ai&2|0)==0){break}ac=al;ad=aj;ae=ai;af=c[281365]|0;ag=c[281363]|0;break L2103}}while(0);ac=al;ad=aj;ae=ai;af=c[281366]|0;ag=c[281364]|0;break L2103}}while(0);if(!ak){ac=1e3;ad=aj;ae=0;af=Z;ag=Y;break}ac=e[ah+136+(aj<<1)>>1]|0;ad=aj;ae=0;af=Z;ag=Y}}while(0);am=(V|0)<(ac|0);if((X|0)==(x|0)&am){break}an=am?V:ac;if((ae|0)==0){ao=0}else{fu[af&255](W,L,X-x|0,an-X|0,B,1);ao=ae}if((an|0)<(V|0)){X=an;Y=ag;Z=af;_=ao;$=ad;aa=ac}else{O=ac;P=ad;Q=ao;R=af;S=ag;T=U;break L2098}}if((ae|0)==0){O=ac;P=ad;Q=0;R=af;S=ag;T=U;break}fA[ag&127](W,L,B,1);O=ac;P=ad;Q=ae;R=af;S=ag;T=U}}while(0);aa=x+8|0;if((aa|0)>=257){v=R;w=S;break L2089}if((aa|0)<((d[y]|0)+(b[A>>1]|0)|0)){x=aa;G=O;H=P;I=Q;J=R;K=S;L=L+k|0;F=T;M=N+C|0}else{v=R;w=S;break}}}}while(0);i=r+1|0;M=a[1109196+(o*68|0)+(i<<1)|0]|0;if(M<<24>>24>-1&(i|0)<32){p=w;q=v;r=i;s=u;t=M}else{break}}ap=w;aq=v;ar=c[277223]|0;as=c[277231]|0}else{ap=l;aq=m;ar=h;as=j}t=o+1|0;if(t>>>0>as>>>0){break}else{l=ap;m=aq;n=ar+n|0;o=t;h=ar;j=as}}return}function HP(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0;c[348604]=e[1041728+(f*12|0)>>1]<<1;i=e[1041720+(f*12|0)>>1]<<1;j=c[263194]|0;k=j+i|0;l=b[1041730+(f*12|0)>>1]|0;m=(l&1)!=0;n=m?j+(i+2048)|0:k;i=j+65536|0;j=n>>>0<i>>>0?n:n-65536|0;n=(l&2)==0?k:j+2048|0;l=n>>>0<i>>>0?n:n-65536|0;n=m?l+2048|0:l;m=n>>>0<i>>>0?n:n-65536|0;n=(c[348614]|0)==16?1023:511;i=(c[348612]|0)==16?4:3;o=(a[1106152]|0)!=0;p=o?2:1;q=(a[1106149]|0)==0?0:o&1;o=c[277297]|0;if((a[o+(f<<5)|0]|0)==0){return}r=(q|0)==0;s=p<<3;t=0;u=o;while(1){o=u+(f<<5)+1+t|0;a[1108928]=a[o]&1^1;if((a[1394512]|0)==0){v=1584}else{if((a[o]&2)==0){v=1584}else{w=1125452;x=1125460}}if((v|0)==1584){v=0;w=1125456;x=1125464}o=c[w>>2]|0;y=c[x>>2]|0;z=c[277230]|0;A=c[277231]|0;if(z>>>0>A>>>0){B=u}else{C=z;z=A;do{if(r){D=C}else{D=(d[1108917]|0)+(C<<1)|0}A=(e[1101800+(C<<4)+(f<<2)>>1]|0)+q|0;E=b[1101800+(C<<4)+(f<<2)+2>>1]|0;F=E&65535;G=A+D|0;H=(G&7)>>>(q>>>0);I=(c[277224]|0)-H|0;J=1;while(1){K=J+C|0;if(J>>>0>=I>>>0){break}if((A|0)!=(e[1101800+(K<<4)+(f<<2)>>1]|0)){break}if(E<<16>>16==(b[1101800+(K<<4)+(f<<2)+2>>1]|0)){J=J+1|0}else{break}}if(K>>>0>z>>>0){L=z+1-C|0}else{L=J}E=H<<3;A=G>>>(i>>>0);a[1394504]=G<<3&8;I=G<<1&16;M=I^16;N=(A&32|0)==0;O=N?k:l;P=N?j:m;N=A<<5&992;A=O+(N<<1)|0;Q=P+(N<<1)|0;R=c[277297]|0;S=e[R+(f<<5)+8+(t<<1)>>1]|0;T=e[R+(f<<5)+20+(t<<1)>>1]|0;R=ab(S,p)|0;U=(ab(c[277223]|0,C)|0)+R|0;R=S+F|0;V=R&n;W=V>>>3;X=(c[348614]|0)==8;do{if(X){if(V>>>0>255){Y=P+((W&31|N)<<1)|0;break}else{Y=O+(W+N<<1)|0;break}}else{if(V>>>0>511){Y=P+((R>>>4&31|N)<<1)|0;break}else{Y=O+((V>>>4)+N<<1)|0;break}}}while(0);N=T-S|0;V=R&7;if((V|0)==0){Z=Y;_=N;$=W;aa=U}else{O=8-V|0;P=O>>>0>N>>>0?N:O;O=U-(ab(V,p)|0)|0;F=Y;G=d[F+1|0]<<8;H=G|d[F];F=(G&8192|0)!=0?g:h;a[1108909]=F;a[1108908]=F;if((c[348612]|0)==16){ac=((G&32768|0)!=0?M:I)+H&1023|G&64512}else{ac=H}do{if(X){fu[y&255](ac,O,V,P,E,L);if((W|0)==31){ad=Q;break}ad=(W|0)==63?A:Y+2|0}else{H=ac&64512;G=W&1;if((ac&16384|0)==0){fu[y&255](ac+G&1023|H,O,V,P,E,L)}else{fu[y&255](ac+(G^1)&1023|H,O,V,P,E,L)}if((W|0)==63){ad=Q;break}ad=(W|0)==127?A:Y+(G<<1)|0}}while(0);Z=ad;_=N-P|0;$=W+1|0;aa=O+s|0}if(_>>>0>7){V=aa;X=$;U=_;R=Z;while(1){S=R;T=d[S+1|0]<<8;G=T|d[S];S=(T&8192|0)!=0?g:h;a[1108909]=S;a[1108908]=S;if((c[348612]|0)==16){ae=((T&32768|0)!=0?M:I)+G&1023|T&64512}else{ae=G}do{if((c[348614]|0)==8){fA[o&127](ae,V,E,L);if((X|0)==31){af=Q;break}af=(X|0)==63?A:R+2|0}else{G=ae&64512;T=X&1;if((ae&16384|0)==0){fA[o&127](ae+T&1023|G,V,E,L)}else{fA[o&127](ae+(T^1)&1023|G,V,E,L)}if((X|0)==63){af=Q;break}af=(X|0)==127?A:R+(T<<1)|0}}while(0);T=X+1|0;G=V+s|0;S=U-8|0;if(S>>>0>7){V=G;X=T;U=S;R=af}else{ag=G;ah=T;ai=S;aj=af;break}}}else{ag=aa;ah=$;ai=_;aj=Z}do{if((ai|0)!=0){R=aj;U=d[R+1|0]<<8;X=U|d[R];R=(U&8192|0)!=0?g:h;a[1108909]=R;a[1108908]=R;if((c[348612]|0)==16){ak=((U&32768|0)!=0?M:I)+X&1023|U&64512}else{ak=X}if((c[348614]|0)==8){fu[y&255](ak,ag,0,ai,E,L);break}X=ak&64512;U=ah&1;if((ak&16384|0)==0){fu[y&255](ak+U&1023|X,ag,0,ai,E,L);break}else{fu[y&255](ak+(U^1)&1023|X,ag,0,ai,E,L);break}}}while(0);C=L+C|0;z=c[277231]|0;}while(C>>>0<=z>>>0);B=c[277297]|0}z=t+1|0;if((z|0)<(d[B+(f<<5)|0]|0)){t=z;u=B}else{break}}return}function HQ(f,g,h,i){f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0;c[348604]=e[1041728+(f*12|0)>>1]<<1;j=e[520872]<<1;k=c[263194]|0;l=k+j|0;m=b[520877]|0;n=(m&1)!=0;o=n?k+(j+2048)|0:l;j=k+65536|0;p=o>>>0<j>>>0?o:o-65536|0;o=(m&2)==0?l:p+2048|0;m=o>>>0<j>>>0?o:o-65536|0;o=n?m+2048|0:m;n=o>>>0<j>>>0?o:o-65536|0;o=e[1041720+(f*12|0)>>1]<<1;q=k+o|0;r=b[1041730+(f*12|0)>>1]|0;s=(r&1)!=0;t=s?k+(o+2048)|0:q;o=t>>>0<j>>>0?t:t-65536|0;t=(r&2)==0?q:o+2048|0;r=t>>>0<j>>>0?t:t-65536|0;t=s?r+2048|0:r;s=t>>>0<j>>>0?t:t-65536|0;t=(c[348614]|0)==16?1023:511;j=(c[348612]|0)==16?4:3;k=(c[348610]|0)==16?1016:504;u=(c[348608]|0)==16?4:3;v=8192<<f;w=(a[1106152]|0)!=0;x=w?2:1;y=(a[1106149]|0)==0?0:w&1;w=c[277297]|0;if((a[w+(f<<5)|0]|0)==0){return}z=(y|0)==0;A=(i|0)==0;B=x<<3;C=0;D=w;while(1){w=D+(f<<5)+1+C|0;a[1108928]=a[w]&1^1;if((a[1394512]|0)==0){E=1643}else{if((a[w]&2)==0){E=1643}else{F=1125460}}if((E|0)==1643){E=0;F=1125464}w=c[F>>2]|0;G=c[277230]|0;H=c[277231]|0;if(G>>>0>H>>>0){I=D}else{J=G;G=H;while(1){if(z){K=J}else{K=(d[1108917]|0)+(J<<1)|0}H=(e[1101808+(J<<4)>>1]|0)-1|0;L=H>>>(u>>>0);M=(H+i|0)>>>(u>>>0);H=(L&32|0)==0;N=H?l:m;O=H?p:n;H=L<<5&992;L=((M&32|0)!=0?m:l)+((M<<5&992)<<1)-(N+(H<<1))>>1;M=c[277297]|0;P=b[M+(f<<5)+8+(C<<1)>>1]|0;Q=P&65535;R=b[M+(f<<5)+20+(C<<1)>>1]|0;M=R&65535;S=e[1101800+(J<<4)+(f<<2)+2>>1]|0;T=S&7;if((P&65535)<(R&65535)){R=ab(c[277223]|0,J)|0;P=ab(Q,x)|0;U=(e[1101810+(J<<4)>>1]|0)+1023|0;V=1101800+(J<<4)+(f<<2)|0;W=K+y|0;X=Q;Y=R+P|0;P=M-Q|0;R=Q>>>0>=(8-T|0)>>>0;while(1){do{if(R){Q=U+X|0;Z=Q&k;_=Z>>>3;do{if((c[348610]|0)==8){if(Z>>>0>248){$=O+((_&31|H)<<1)|0;break}else{$=N+(_+H<<1)|0;break}}else{if(Z>>>0>504){$=O+((Q>>>4&31|H)<<1)|0;break}else{$=N+((Z>>>4)+H<<1)|0;break}}}while(0);Z=$;Q=d[Z+1|0]<<8;_=Q|d[Z];if(A){Z=Q<<16>>16<0;aa=Z?_:0;ac=Z?0:_}else{Z=$+(L<<1)|0;aa=d[Z+1|0]<<8|d[Z];ac=_}_=aa&65535;if((_&v|0)==0){ad=e[V>>1]|0}else{ad=_+1|0}_=ac&65535;if((_&v|0)==0){ae=S;af=ad;break}ae=_&65528|T;af=ad}else{ae=S;af=e[V>>1]|0}}while(0);_=W+af|0;Z=(_&7)>>>(y>>>0)<<3;Q=_>>>(j>>>0);a[1394504]=_<<3&8;ag=_<<1&16;_=ag^16;ah=(Q&32|0)==0;ai=ah?q:r;aj=ah?o:s;ah=Q<<5&992;Q=ae+X|0;ak=Q&t;al=ak>>>3;am=(c[348614]|0)==8;do{if(am){if(ak>>>0>255){an=aj+((al&31|ah)<<1)|0;break}else{an=ai+(ah+al<<1)|0;break}}else{if(ak>>>0>511){an=aj+((ah|Q>>>4&31)<<1)|0;break}else{an=ai+(ah+(ak>>>4)<<1)|0;break}}}while(0);ak=Q&7;ah=8-ak|0;ai=ah>>>0>P>>>0?P:ah;ah=Y-(ab(ak,x)|0)|0;aj=an;ao=d[aj+1|0]<<8;ap=ao|d[aj];aj=(ao&8192|0)!=0?g:h;a[1108909]=aj;a[1108908]=aj;if((c[348612]|0)==16){aq=((ao&32768|0)!=0?_:ag)+ap&1023|ao&64512}else{aq=ap}do{if(am){fu[w&255](aq,ah,ak,ai,Z,1)}else{ap=aq&64512;ao=al&1;if((aq&16384|0)==0){fu[w&255](aq+ao&1023|ap,ah,ak,ai,Z,1);break}else{fu[w&255](aq+(ao^1)&1023|ap,ah,ak,ai,Z,1);break}}}while(0);Z=ai+X|0;if(Z>>>0<M>>>0){X=Z;Y=ah+B|0;P=P-ai|0;R=1}else{break}}ar=c[277231]|0}else{ar=G}R=J+1|0;if(R>>>0>ar>>>0){break}else{J=R;G=ar}}I=c[277297]|0}G=C+1|0;if((G|0)<(d[I+(f<<5)|0]|0)){C=G;D=I}else{break}}return}function HR(a){a=a|0;var b=0,d=0,e=0;b=a&16777215;c[202024]=b;d=a&16711680;c[202031]=d;e=c[808144+(b>>>12<<2)>>2]|0;if(e>>>0>=19){c[202034]=e;return}b=e;if((b|0)==2){e=c[274485]|0;if((e&4095|0)==4095){c[202034]=(c[263193]|0)+((e&(d>>>1|a&32767))-(a&65535));return}else{c[202034]=0;return}}else if((b|0)==4){d=c[274485]|0;if((d&4095|0)==4095){c[202034]=(c[263193]|0)+((d&(a&32767)-24576+(a>>>3&122880))-(a&65535));return}else{c[202034]=0;return}}else if((b|0)==7){c[202034]=(c[210228]|0)+(-24576-(a&32768));return}else if((b|0)==6){c[202034]=c[263193];return}else{c[202034]=0;return}}function HS(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0;c[348604]=e[1041728+(f*12|0)>>1]<<1;i=e[1041720+(f*12|0)>>1]<<1;j=c[263194]|0;k=j+i|0;l=b[1041730+(f*12|0)>>1]|0;m=(l&1)!=0;n=m?j+(i+2048)|0:k;i=j+65536|0;j=n>>>0<i>>>0?n:n-65536|0;n=(l&2)==0?k:j+2048|0;l=n>>>0<i>>>0?n:n-65536|0;n=m?l+2048|0:l;m=n>>>0<i>>>0?n:n-65536|0;n=(c[348614]|0)==16?1023:511;i=(c[348612]|0)==16?4:3;o=(a[1106152]|0)!=0;p=o?2:1;q=(a[1106149]|0)==0?0:o&1;o=c[277297]|0;if((a[o+(f<<5)|0]|0)==0){return}r=a[1044432]|0;s=(((c[277230]|0)-(d[1044433]|0)|0)>>>0)%((r&255)>>>0)|0;t=0;u=o;o=r;while(1){r=u+(f<<5)+1+t|0;a[1108928]=a[r]&1^1;if((a[1394512]|0)==0){v=1713}else{if((a[r]&2)==0){v=1713}else{w=1125468}}if((v|0)==1713){v=0;w=1125472}r=c[w>>2]|0;x=(c[277230]|0)-s|0;y=c[277231]|0;if(x>>>0>y>>>0){z=s;A=o;B=u}else{C=s;D=x;x=y;y=o;while(1){E=e[1101800+(D<<4)+(f<<2)+2>>1]|0;F=y&255;if((D+F|0)>>>0>x>>>0){G=x+1-D|0}else{G=F}H=G-C|0;I=(D<<q)+q+(e[1101800+(D<<4)+(f<<2)>>1]|0)|0;J=(I&7)>>>(q>>>0)<<3;K=I>>>(i>>>0);a[1394504]=I<<3&8;L=I<<1&16;I=L^16;M=(K&32|0)==0;N=M?k:l;O=M?j:m;M=K<<5&992;K=N+(M<<1)|0;P=O+(M<<1)|0;Q=c[277297]|0;R=b[Q+(f<<5)+8+(t<<1)>>1]|0;S=R&65535;T=b[Q+(f<<5)+20+(t<<1)>>1]|0;Q=T&65535;U=ab(S,p)|0;V=(ab(c[277223]|0,C+D|0)|0)+U|0;U=S+E-((S>>>0)%(F>>>0)|0)|0;E=U&n;W=E>>>3;do{if((c[348614]|0)==8){if(E>>>0>255){X=O+((W&31|M)<<1)|0;break}else{X=N+(W+M<<1)|0;break}}else{if(E>>>0>511){X=O+((U>>>4&31|M)<<1)|0;break}else{X=N+((E>>>4)+M<<1)|0;break}}}while(0);if((R&65535)<(T&65535)){M=S;E=V;N=U&7;O=W;Y=Q-S|0;Z=X;_=F;while(1){$=_-((M>>>0)%(_>>>0)|0)|0;aa=$>>>0>Y>>>0?Y:$;$=Z;ac=d[$+1|0]<<8;ad=ac|d[$];$=(ac&8192|0)!=0?g:h;a[1108909]=$;a[1108908]=$;if((c[348612]|0)==16){ae=((ac&32768|0)!=0?I:L)+ad&1023|ac&64512}else{ae=ad}do{if((c[348614]|0)==8){fu[r&255](ae,E,J,N&7,aa,H)}else{ad=ae&64512;ac=O&1;if((ae&16384|0)==0){fu[r&255](ae+ac&1023|ad,E,J,N&7,aa,H);break}else{fu[r&255](ae+(ac^1)&1023|ad,E,J,N&7,aa,H);break}}}while(0);af=a[1044432]|0;ag=af&255;ad=ag+N|0;if(ad>>>0>7){if((c[348614]|0)==8){ac=ad;$=O;ah=Z;while(1){ai=ac-8|0;if(($|0)==31){aj=P}else{aj=($|0)==63?K:ah+2|0}ak=$+1|0;if(ai>>>0>7){ac=ai;$=ak;ah=aj}else{al=ai;am=ak;an=aj;break}}}else{ah=ad;$=O;ac=Z;while(1){ak=ah-8|0;if(($|0)==63){ao=P}else{ao=($|0)==127?K:ac+(($&1)<<1)|0}ai=$+1|0;if(ak>>>0>7){ah=ak;$=ai;ac=ao}else{al=ak;am=ai;an=ao;break}}}}else{al=ad;am=O;an=Z}ac=aa+M|0;if(ac>>>0>=Q>>>0){break}M=ac;E=(ab(aa,p)|0)+E|0;N=al;O=am;Y=Y-aa|0;Z=an;_=ag}ap=ag;aq=af;ar=c[277231]|0}else{ap=F;aq=y;ar=x}_=ap+D|0;if(_>>>0>ar>>>0){break}else{C=0;D=_;x=ar;y=aq}}z=0;A=aq;B=c[277297]|0}y=t+1|0;if((y|0)<(d[B+(f<<5)|0]|0)){s=z;t=y;u=B;o=A}else{break}}return}function HT(f,g,h,i){f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0;c[348604]=e[1041728+(f*12|0)>>1]<<1;j=e[520872]<<1;k=c[263194]|0;l=k+j|0;m=b[520877]|0;n=(m&1)!=0;o=n?k+(j+2048)|0:l;j=k+65536|0;p=o>>>0<j>>>0?o:o-65536|0;o=(m&2)==0?l:p+2048|0;m=o>>>0<j>>>0?o:o-65536|0;o=n?m+2048|0:m;n=o>>>0<j>>>0?o:o-65536|0;o=e[1041720+(f*12|0)>>1]<<1;q=k+o|0;r=b[1041730+(f*12|0)>>1]|0;s=(r&1)!=0;t=s?k+(o+2048)|0:q;o=t>>>0<j>>>0?t:t-65536|0;t=(r&2)==0?q:o+2048|0;r=t>>>0<j>>>0?t:t-65536|0;t=s?r+2048|0:r;s=t>>>0<j>>>0?t:t-65536|0;t=(c[348614]|0)==16?1023:511;j=(c[348612]|0)==16?4:3;k=(c[348610]|0)==16?1016:504;u=(c[348608]|0)==16?4:3;v=8192<<f;w=(a[1106152]|0)!=0;x=w?2:1;y=c[277297]|0;if((a[y+(f<<5)|0]|0)==0){return}z=a[1044432]|0;A=(a[1106149]|0)==0?0:w&1;w=(i|0)==0;B=(((c[277230]|0)-(d[1044433]|0)|0)>>>0)%((z&255)>>>0)|0;C=0;D=y;y=z;while(1){z=D+(f<<5)+1+C|0;a[1108928]=a[z]&1^1;if((a[1394512]|0)==0){E=1754}else{if((a[z]&2)==0){E=1754}else{F=1125468}}if((E|0)==1754){E=0;F=1125472}z=c[F>>2]|0;G=(c[277230]|0)-B|0;H=c[277231]|0;if(G>>>0>H>>>0){I=B;J=y;K=D}else{L=B;M=G;G=H;H=y;while(1){N=(e[1101808+(M<<4)>>1]|0)-1|0;O=e[1101810+(M<<4)>>1]|0;P=H&255;if((M+P|0)>>>0>G>>>0){Q=G+1-M|0}else{Q=P}P=Q-L|0;R=N>>>(u>>>0);S=(N+i|0)>>>(u>>>0);N=(R&32|0)==0;T=N?l:m;U=N?p:n;N=R<<5&992;R=((S&32|0)!=0?m:l)+((S<<5&992)<<1)-(T+(N<<1))>>1;S=c[277297]|0;V=b[S+(f<<5)+8+(C<<1)>>1]|0;W=V&65535;X=b[S+(f<<5)+20+(C<<1)>>1]|0;S=X&65535;Y=e[1101800+(M<<4)+(f<<2)+2>>1]|0;Z=Y&7;if((V&65535)<(X&65535)){X=ab(c[277223]|0,L+M|0)|0;V=O+1023|0;O=1101800+(M<<4)+(f<<2)|0;_=(M<<A)+A|0;$=W;aa=X+(ab(W,x)|0)|0;X=S-W|0;ac=W>>>0>=(8-Z|0)>>>0;while(1){do{if(ac){W=V+$|0;ad=W&k;ae=ad>>>3;do{if((c[348610]|0)==8){if(ad>>>0>248){af=U+((ae&31|N)<<1)|0;break}else{af=T+(ae+N<<1)|0;break}}else{if(ad>>>0>504){af=U+((W>>>4&31|N)<<1)|0;break}else{af=T+((ad>>>4)+N<<1)|0;break}}}while(0);ad=af;W=d[ad+1|0]<<8;ae=W|d[ad];if(w){ad=W<<16>>16<0;ag=ad?ae:0;ah=ad?0:ae}else{ad=af+(R<<1)|0;ag=d[ad+1|0]<<8|d[ad];ah=ae}ae=ag&65535;if((ae&v|0)==0){ai=e[O>>1]|0}else{ai=ae+1|0}ae=ah&65535;if((ae&v|0)==0){aj=Y;ak=ai;break}aj=ae&65528|Z;ak=ai}else{aj=Y;ak=e[O>>1]|0}}while(0);ae=_+ak|0;ad=(ae&7)>>>(A>>>0)<<3;W=ae>>>(j>>>0);a[1394504]=ae<<3&8;al=ae<<1&16;ae=al^16;am=(W&32|0)==0;an=am?q:r;ao=am?o:s;am=W<<5&992;W=d[1044432]|0;ap=($>>>0)%(W>>>0)|0;aq=aj+$-ap|0;ar=aq&t;as=ar>>>3;at=(c[348614]|0)==8;do{if(at){if(ar>>>0>255){au=ao+((as&31|am)<<1)|0;break}else{au=an+(as+am<<1)|0;break}}else{if(ar>>>0>511){au=ao+((aq>>>4&31|am)<<1)|0;break}else{au=an+((ar>>>4)+am<<1)|0;break}}}while(0);am=W-ap|0;ar=am>>>0>X>>>0?X:am;am=au;an=d[am+1|0]<<8;ao=an|d[am];am=(an&8192|0)!=0?g:h;a[1108909]=am;a[1108908]=am;if((c[348612]|0)==16){av=((an&32768|0)!=0?ae:al)+ao&1023|an&64512}else{av=ao}do{if(at){fu[z&255](av,aa,ad,aq&7,ar,P)}else{if((av&16384|0)==0){fu[z&255](av+(as&1)&1023|av&64512,aa,ad,aq&7,ar,P);break}if((av&32768|0)!=0){break}fu[z&255](av+(as&1^1)&1023|av&64512,aa,ad,aq&7,ar,P)}}while(0);aq=ar+$|0;ad=(ab(ar,x)|0)+aa|0;if(aq>>>0<S>>>0){$=aq;aa=ad;X=X-ar|0;ac=1}else{break}}aw=a[1044432]|0;ax=c[277231]|0}else{aw=H;ax=G}ac=(aw&255)+M|0;if(ac>>>0>ax>>>0){break}else{L=0;M=ac;G=ax;H=aw}}I=0;J=aw;K=c[277297]|0}H=C+1|0;if((H|0)<(d[K+(f<<5)|0]|0)){B=I;C=H;D=K;y=J}else{break}}return}function HU(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0;b=a&255;if((b&128|0)==0){a=0;do{d=a+2054|0;c[808144+(d<<2)>>2]=7;e=a|6;c[808144+(e<<2)>>2]=7;f=a+2055|0;c[808144+(f<<2)>>2]=7;g=a|7;c[808144+(g<<2)>>2]=7;c[824528+(d<<2)>>2]=7;c[824528+(e<<2)>>2]=7;c[824528+(f<<2)>>2]=7;c[824528+(g<<2)>>2]=7;a=a+16|0;}while((a|0)<1024);h=(c[263193]|0)+(b<<13&57344)|0;c[210228]=h;return}else{a=0;do{g=a+2054|0;c[808144+(g<<2)>>2]=9;f=a|6;c[808144+(f<<2)>>2]=9;e=a+2055|0;c[808144+(e<<2)>>2]=9;d=a|7;c[808144+(d<<2)>>2]=9;c[824528+(g<<2)>>2]=9;c[824528+(f<<2)>>2]=9;c[824528+(e<<2)>>2]=9;c[824528+(d<<2)>>2]=9;a=a+16|0;}while((a|0)<1024);h=(c[263193]|0)+(b<<11&260096)|0;c[210228]=h;return}}function HV(b,e){b=b|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0;f=c[263195]|0;g=(d[f+8794|0]|0)<<8|(d[f+8793|0]|0)|(d[f+8795|0]|0)<<16;h=a[f+8792|0]&15;if(e<<24>>24==0){i=h<<24>>24==0?16:h}else{i=0}h=(a[840937]|0)+i&255;if((h&255)>15){j=h&15;k=((h&255)>>>4<<1)+g|0}else{j=h;k=g}g=TP(k)|0;a[808104]=g;h=(((TP(k+1|0)|0)&255)<<8|g&255)&65535;g=TP(k+2|0)|0;a[808104]=g;e=(((((TP(k+3|0)|0)&255)<<8|g&255)&65535)<<16|h)>>>((j&255)>>>0);a[(c[263195]|0)+8972|0]=e&255;a[(c[263195]|0)+8973|0]=e>>>8&255;if(b<<24>>24==0){return}a[840937]=(a[840937]|0)+i&15;a[(c[263195]|0)+8793|0]=k&255;a[(c[263195]|0)+8794|0]=k>>>8&255;a[(c[263195]|0)+8795|0]=k>>>16&255;return}function HW(e,f){e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;L2461:do{switch(f|0){case 8754:case 8755:case 8756:{a[(c[263195]|0)+f|0]=e;g=1931;break};case 8757:{a[(c[263195]|0)+8757|0]=e;break};case 8758:{a[(c[263195]|0)+8758|0]=e;h=c[263195]|0;i=d[h+8752|0]|0;if((i&164|0)==128){HX();break L2461}if((i&176|0)!=176){break L2461}i=h+8960|0;a[i]=a[i]|32;do{if((a[(c[263195]|0)+8705|0]&32)!=0){a[1393588]=a[1393588]|32;c[348398]=c[199754];c[348395]=c[348395]|2048;if((a[1393628]|0)==0){break}a[1393628]=0;b[520836]=(b[520836]|0)+1&65535}}while(0);a[840917]=1;g=1931;break};case 8736:case 8737:case 8738:case 8739:{i=f-8736|0;h=(i<<8)+3072|0;j=(e&255)<<20&7340032;k=0;while(1){l=(c[263192]|0)+((k<<12)+j)|0;m=k+16|0;n=k;do{o=h+n|0;c[808144+(o<<2)>>2]=l;c[1052804+(o<<2)>>2]=l;n=n+1|0;}while((n|0)<(m|0));if((m|0)<256){k=m}else{break}}k=i<<9;h=i>>>0>1?k+1024|0:k;k=j-32768|0;n=h|1;l=h|2;o=h|3;p=0;while(1){q=(c[263192]|0)+(k+(p<<11))|0;r=p|8;s=p+16|0;if((r|0)<(s|0)){t=r+h|0;c[808144+(t<<2)>>2]=q;c[1052804+(t<<2)>>2]=q;t=p|9;r=t+h|0;c[808144+(r<<2)>>2]=q;c[1052804+(r<<2)>>2]=q;r=t+n|0;c[808144+(r<<2)>>2]=q;c[1052804+(r<<2)>>2]=q;r=p|11;t=r+h|0;c[808144+(t<<2)>>2]=q;c[1052804+(t<<2)>>2]=q;t=r+n|0;c[808144+(t<<2)>>2]=q;c[1052804+(t<<2)>>2]=q;t=r+l|0;c[808144+(t<<2)>>2]=q;c[1052804+(t<<2)>>2]=q;t=r+o|0;c[808144+(t<<2)>>2]=q;c[1052804+(t<<2)>>2]=q;t=(p|15)+h|0;c[808144+(t<<2)>>2]=q;c[1052804+(t<<2)>>2]=q}if((s|0)<512){p=s}else{g=1931;break}}break};case 8706:{p=e&255;do{if((p&128|0)!=0){h=(c[263195]|0)+8960|0;a[h]=a[h]&127;h=a[1393588]&127;a[1393588]=h;if(h<<24>>24!=0){break}c[348395]=c[348395]&-2049}}while(0);if((p&32|0)==0){g=1931;break L2461}h=(c[263195]|0)+8960|0;a[h]=a[h]&-33;h=a[1393588]&-33;a[1393588]=h;if(h<<24>>24!=0){g=1931;break L2461}c[348395]=c[348395]&-2049;g=1931;break};case 8714:{h=c[263195]|0;o=h+8714|0;l=a[o]|0;do{if((l^e)<<24>>24<0){if((a[h+8961|0]&e)<<24>>24>=0){u=l;break}c[202033]=c[202033]|2048;a[808140]=a[808140]|-128;u=a[o]|0}else{u=l}}while(0);do{if(((u^e)&64)==0){v=u}else{if((e&64&a[h+8961|0])<<24>>24==0){v=u;break}c[202033]=c[202033]|2048;a[808140]=a[808140]|64;v=a[o]|0}}while(0);do{if(((v^e)&32)==0){w=v}else{if((e&32&a[h+8961|0])<<24>>24==0){w=v;break}c[202033]=c[202033]|2048;a[808140]=a[808140]|32;w=a[o]|0}}while(0);if(((w^e)&16)==0){g=1931;break L2461}if((e&16&a[h+8961|0])<<24>>24==0){g=1931;break L2461}c[202033]=c[202033]|128;g=1931;break};case 8705:{o=c[263195]|0;l=o+8705|0;do{if((a[l]^e)<<24>>24<0){if((a[o+8960|0]&e)<<24>>24>=0){break}a[1393588]=a[1393588]|-128;c[348398]=c[199754];c[348395]=c[348395]|2048;if((a[1393628]|0)==0){break}a[1393628]=0;b[520836]=(b[520836]|0)+1&65535}}while(0);if(((a[l]^e)&32)==0){g=1931;break L2461}if((e&32&a[o+8960|0])<<24>>24==0){g=1931;break L2461}a[1393588]=a[1393588]|32;c[348398]=c[199754];c[348395]=c[348395]|2048;if((a[1393628]|0)==0){g=1931;break L2461}a[1393628]=0;b[520836]=(b[520836]|0)+1&65535;g=1931;break};case 8740:{c[263196]=(c[263193]|0)+((e&255)<<13&57344);break};case 8741:{if((a[(c[263195]|0)+8741|0]|0)==e<<24>>24){break L2461}HU(e);break};case 8753:{if(e<<24>>24>=0){break L2461}a[840917]=0;break};case 8715:{h=e&255;if((h&128|0)!=0){a[808140]=a[808140]&127;p=(c[263195]|0)+8961|0;a[p]=a[p]&127}if((h&64|0)!=0){a[808140]=a[808140]&-65;p=(c[263195]|0)+8961|0;a[p]=a[p]&-65}if((h&32|0)!=0){a[808140]=a[808140]&-33;p=(c[263195]|0)+8961|0;a[p]=a[p]&-33}if((h&16|0)!=0){h=(c[263195]|0)+8961|0;a[h]=a[h]&-17}if((a[808140]|0)!=0){g=1931;break L2461}c[202033]=c[202033]&-2049;g=1931;break};case 8704:{h=e&255;do{if((h&32|0)==0){p=c[263195]|0;if((a[p+8704|0]&32)==0){break}c[202024]=0;a[808098|0]=0;b[404048]=d[p+8708|0]<<8|d[p+8707|0];b[404043]=0;a[808080]=0;a[808089|0]=1;a[808088]=-1;a[808091|0]=0;a[808093|0]=0;c[202031]=0;c[202032]=0;b[404041]=308;a[808141]=0;c[202034]=0;HR(c[202024]|0);c[202028]=149560;c[202029]=159800;p=a[808082]|0;a[808121]=(p&255)>>>1&1^1;a[808122]=p&-128;a[808120]=p&1;a[808123]=(p&255)>>>6&1;p=b[404041]|0;do{if((p&256)==0){n=p&255;k=(n&16|0)!=0;if((n&32|0)==0){if(k){c[202028]=151608;c[202029]=160312;break}else{c[202028]=152632;c[202029]=160568;break}}else{if(k){c[202028]=149560;c[202029]=159800;break}else{c[202028]=150584;c[202029]=160056;break}}}else{c[202028]=149560;c[202029]=159800}}while(0);c[210228]=c[263193];a[(c[263195]|0)+8741|0]=0}}while(0);do{if((h&128|0)!=0){o=(c[263195]|0)+8961|0;a[o]=a[o]|-128;if((a[(c[263195]|0)+8714|0]|0)>=0){break}c[202033]=c[202033]|2048;a[808140]=a[808140]|-128}}while(0);if((h&16|0)==0){g=1931;break L2461}o=(c[263195]|0)+8961|0;a[o]=a[o]|16;if((a[(c[263195]|0)+8714|0]&16)==0){g=1931;break L2461}c[202033]=c[202033]|128;g=1931;break};case 8759:{a[(c[263195]|0)+8759|0]=e;if((a[(c[263195]|0)+8752|0]&-92)<<24>>24!=-124){break L2461}HX();break};case 8760:case 8761:{a[(c[263195]|0)+f|0]=e;g=1931;break};case 8767:{a[840936]=(e<<24>>24>>7)+4&255&-2;break};case 8782:case 8781:case 8780:case 8779:case 8778:case 8777:case 8776:case 8775:case 8774:case 8773:case 8772:case 8771:case 8768:case 8769:case 8770:{a[(c[263195]|0)+f|0]=e;g=1931;break};case 8783:{a[(c[263195]|0)+8783|0]=e;o=c[263195]|0;if((a[o+8752|0]&-80)<<24>>24!=-96){break L2461}X9((c[263192]|0)+(d[840917]<<4|8323072)|0,o+8768|0,16);o=(a[840917]|0)+1&255;l=o&7;a[840917]=l;if((o&3)!=0){break L2461}o=c[263195]|0;p=d[o+8757|0]|0;m=d[o+8758|0]<<8;k=l<<24>>24==0|0;l=a[o+8753|0]&3;if((l|0)==0){n=0;j=(c[263192]|0)+(k<<6|8323072)|0;i=o+((p|m&1792|12288)+(-k&64))|0;while(1){s=i+1|0;q=i+16|0;t=i+17|0;r=i+32|0;x=i+33|0;y=i+48|0;z=i+49|0;A=0;B=a[i]|0;C=a[s]|0;D=a[q]|0;E=a[t]|0;G=a[r]|0;H=a[x]|0;I=a[y]|0;J=a[z]|0;do{K=a[j+A|0]|0;B=K&1|B<<1;a[i]=B;C=(K&255)>>>1&1|C<<1;a[s]=C;D=(K&255)>>>2&1|D<<1;a[q]=D;E=(K&255)>>>3&1|E<<1;a[t]=E;G=(K&255)>>>4&1|G<<1;a[r]=G;H=(K&255)>>>5&1|H<<1;a[x]=H;I=(K&255)>>>6&1|I<<1;a[y]=I;J=(K&255)>>>7|J<<1;a[z]=J;A=A+1|0;}while((A|0)<8);A=n+1|0;if((A|0)<8){n=A;j=j+8|0;i=i+2|0}else{g=1931;break L2461}}}i=(l|0)==1;j=o+(((i?32:16)&-k)+(p|m&1792|12288))|0;n=(c[263192]|0)+(k<<6|8323072)|0;if(i){L=0;M=n;N=j}else{i=0;h=n;n=j;while(1){j=n+1|0;A=a[h]|0;J=a[n]<<1|A&1;a[n]=J;z=a[j]<<1|(A&255)>>>1&1;a[j]=z;A=a[h+1|0]|0;I=J<<1|A&1;a[n]=I;J=z<<1|(A&255)>>>1&1;a[j]=J;A=a[h+2|0]|0;z=I<<1|A&1;a[n]=z;I=J<<1|(A&255)>>>1&1;a[j]=I;A=a[h+3|0]|0;J=z<<1|A&1;a[n]=J;z=I<<1|(A&255)>>>1&1;a[j]=z;A=a[h+4|0]|0;I=J<<1|A&1;a[n]=I;J=z<<1|(A&255)>>>1&1;a[j]=J;A=a[h+5|0]|0;z=I<<1|A&1;a[n]=z;I=J<<1|(A&255)>>>1&1;a[j]=I;A=a[h+6|0]|0;J=z<<1|A&1;a[n]=J;z=I<<1|(A&255)>>>1&1;a[j]=z;A=a[h+7|0]|0;a[n]=J<<1|A&1;a[j]=z<<1|(A&255)>>>1&1;A=i+1|0;if((A|0)<8){i=A;h=h+8|0;n=n+2|0}else{g=1931;break L2461}}}while(1){n=N+1|0;h=N+16|0;i=N+17|0;k=0;m=a[N]|0;p=a[n]|0;o=a[h]|0;l=a[i]|0;do{A=a[M+k|0]|0;m=A&1|m<<1;a[N]=m;p=(A&255)>>>1&1|p<<1;a[n]=p;o=(A&255)>>>2&1|o<<1;a[h]=o;l=(A&255)>>>3&1|l<<1;a[i]=l;k=k+1|0;}while((k|0)<8);k=L+1|0;if((k|0)<8){L=k;M=M+8|0;N=N+2|0}else{g=1931;break}}break};case 8713:{a[(c[263195]|0)+8713|0]=e;if(e<<24>>24<=-1){k=(c[263195]|0)+8960|0;a[k]=a[k]|-128}if((a[(c[263195]|0)+8705|0]&e)<<24>>24>=0){g=1931;break L2461}a[1393588]=a[1393588]|-128;c[348398]=c[199754];c[348395]=c[348395]|2048;if((a[1393628]|0)==0){g=1931;break L2461}a[1393628]=0;b[520836]=(b[520836]|0)+1&65535;g=1931;break};case 8784:{k=e&255;if((k&2|0)!=0){l=840928;c[l>>2]=0;c[l+4>>2]=0}c[210231]=k&3;g=1931;break};case 8785:{b[420459]=b[420459]&-256|e&255;break};case 8786:{b[420459]=b[420459]&255|(e&255)<<8;break};case 8787:{b[420460]=b[420460]&-256|e&255;break};case 8788:{k=b[420460]&255|(e&255)<<8;b[420460]=k;l=c[210231]|0;if((l|0)==0){i=ab(b[420459]|0,k<<16>>16)|0;o=840928;c[o>>2]=i;c[o+4>>2]=(i|0)<0?-1:0;break L2461}else if((l|0)==1){l=b[420459]|0;if(k<<16>>16==0){i=l<<16;o=840928;c[o>>2]=i;c[o+4>>2]=(i|0)<0?-1:0;break L2461}else{i=k&65535;o=((l|0)%(i|0)|0)<<16|((l|0)/(i|0)|0);i=840928;c[i>>2]=o;c[i+4>>2]=(o|0)<0?-1:0;g=1931;break L2461}}else{o=ab(b[420459]|0,k<<16>>16)|0;k=840928;i=Ye(o,(o|0)<0?-1:0,c[k>>2]|0,c[k+4>>2]|0)|0;k=F;o=840928;c[o>>2]=i;c[o+4>>2]=k;if((i&0|0)==0&(k&16777215|0)==0){g=1931;break L2461}a[840916]=1;g=1931;break L2461}break};case 8792:{a[(c[263195]|0)+8792|0]=e;HV(1,0);return};case 8795:case 8794:case 8793:{a[(c[263195]|0)+f|0]=e;a[840937]=0;HV(0,1);return};default:{g=1931}}}while(0);do{if((g|0)==1931){if((f-8704|0)>>>0<256){break}return}}while(0);a[(c[263195]|0)+f|0]=e;return}function HX(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;b=c[263195]|0;e=(d[b+8755|0]|0)<<8|(d[b+8754|0]|0);f=e|(d[b+8756|0]|0)<<16;g=(d[b+8758|0]|0)<<8|(d[b+8757|0]|0);h=g|(d[b+8759|0]|0)<<16;i=(d[b+8761|0]|0)<<8|(d[b+8760|0]|0);j=a[b+8752|0]|0;k=j&3;do{if((k|0)==1){l=c[274485]|0;m=(c[263193]|0)+(l&f)|0;n=l&i}else if((k|0)==0){l=c[808144+(f>>>12<<2)>>2]|0;if(l>>>0<19){m=(c[263192]|0)+e|0;n=i;break}else{m=l+e|0;n=i;break}}else{m=b+(e&1023|12288)|0;n=i&1023}}while(0);if((j&4)==0){o=b+(g&1023|12288)|0;p=1023}else{g=c[274485]|0;o=(c[263193]|0)+(g&h)|0;p=g}X9(o|0,m|0,p&n|0);n=(c[263195]|0)+8961|0;a[n]=a[n]|32;if((a[(c[263195]|0)+8714|0]&32)==0){return}c[202033]=c[202033]|2048;a[808140]=a[808140]|32;return}function HY(b,e){b=b|0;e=e|0;var f=0,g=0,h=0;f=c[824528+((e>>>12&4095)<<2)>>2]|0;if(f>>>0>=19){a[f+(e&65535)|0]=b;return}switch(f|0){case 8:{f=e-6291456|0;if((a[840936]|0)==2){g=(c[263193]|0)+(f>>>2&65535)|0;h=f<<1&6;a[g]=(d[g]&(3<<h^255)|(b&3)<<h)&255;return}else{h=(c[263193]|0)+(f>>>1&65535)|0;g=f<<2&4;a[h]=(d[h]&(15<<g^255)|(b&15)<<g)&255;return}break};case 7:{a[(c[210228]|0)+((e&32767)-24576)|0]=b;return};case 2:case 6:{a[(c[263193]|0)+(e&65535)|0]=b;return};case 9:{g=(e&65535)-24576|0;if((a[840936]|0)==2){h=(c[210228]|0)+(g>>>2&65535)|0;f=e<<1&6;a[h]=(d[h]&(3<<f^255)|(b&3)<<f)&255;return}else{f=(c[210228]|0)+(g>>>1&65535)|0;g=e<<2&4;a[f]=(d[f]&(15<<g^255)|(b&15)<<g)&255;return}break};case 1:{HW(b,e&65535);return};default:{return}}}function HZ(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;if((b[404041]&256)==0){f=a[808098|0]|0;g=b[404044]|0;b[404044]=g-1&65535;HY(f,g&65535);g=(b[404048]|0)+1&65535;f=(e[404044]|0)-1|0;HY((g&65535)>>>8&255,(f&65535)+1&65535|f&-65536);HY(g&255,f);f=b[404044]|0;g=a[808082]&60|a[808120]|a[808122]&-128|((a[808121]|0)==0)<<1|a[808123]<<6;a[808082]=g;b[404044]=f-3&65535;HY(g,f-2&65535);f=a[808082]|0;a[808104]=f;a[808082]=f&-13|4;g=c[202051]|0;L2696:do{if(g>>>0<19){h=g;L2699:do{switch(h|0){case 1:{i=c[263195]|0;j=a[i+65510|0]|0;a[808104]=j;k=j&255;l=i;m=1991;break};case 2:case 6:{n=a[(c[263193]|0)+65510|0]|0;m=1988;break};case 7:{i=c[210228]|0;j=a[i+8166|0]|0;a[808104]=j;o=j&255;p=i;m=1993;break};case 8:{i=c[263193]|0;if((a[840936]|0)==2){q=i+16377|0;m=1986;break L2699}else{n=a[i+32755|0]&15;m=1988;break L2699}break};case 9:{i=c[210228]|0;if((a[840936]|0)==2){q=i+10233|0;m=1986;break L2699}else{n=a[i+20467|0]&15;m=1988;break L2699}break};default:{n=f;m=1988}}}while(0);if((m|0)==1986){n=(d[q]|0)>>>4&3;m=1988}L2713:do{if((m|0)==1988){a[808104]=n;i=n&255;switch(h|0){case 1:{k=i;l=c[263195]|0;m=1991;break L2713;break};case 7:{o=i;p=c[210228]|0;m=1993;break L2713;break};case 2:case 6:{r=a[(c[263193]|0)+65511|0]|0;s=i;break L2696;break};case 8:{j=c[263193]|0;if((a[840936]|0)==2){r=(d[j+16377|0]|0)>>>6;s=i;break L2696}else{r=(d[j+32755|0]|0)>>>4;s=i;break L2696}break};case 9:{j=c[210228]|0;if((a[840936]|0)==2){r=(d[j+10233|0]|0)>>>6;s=i;break L2696}else{r=(d[j+20467|0]|0)>>>4;s=i;break L2696}break};default:{r=n;s=i;break L2696}}}}while(0);if((m|0)==1991){r=a[l+65511|0]|0;s=k;break}else if((m|0)==1993){r=a[p+8167|0]|0;s=o;break}}else{h=a[g+65510|0]|0;a[808104]=h;r=a[g+65511|0]|0;s=h&255}}while(0);t=(r&255)<<8|s;u=t&65535;HR(u);v=(t&65535)>>>8;w=v&255;a[808104]=w;return}else{a[808088]=(a[808088]|0)-1&255;s=(b[404048]|0)+1&65535;r=b[404044]|0;HY((s&65535)>>>8&255,((r&255)+1&255|r&-256)&65535);HY(s&255,r&65535);a[808088]=(a[808088]|0)-1&255;r=a[808082]&60|a[808120]|a[808122]&-128|((a[808121]|0)==0)<<1|a[808123]<<6;a[808082]=r;HY(r,e[404044]|0);a[808088]=(a[808088]|0)-1&255;r=a[808082]|0;a[808104]=r;a[808082]=r&-13|4;s=c[202051]|0;L2659:do{if(s>>>0<19){g=s;L2661:do{switch(g|0){case 1:{o=c[263195]|0;p=a[o+65534|0]|0;a[808104]=p;x=p&255;y=o;m=2017;break};case 2:case 6:{z=a[(c[263193]|0)+65534|0]|0;m=2014;break};case 7:{o=c[210228]|0;p=a[o+8190|0]|0;a[808104]=p;A=p&255;B=o;m=2019;break};case 8:{o=c[263193]|0;if((a[840936]|0)==2){C=o+16383|0;m=2012;break L2661}else{z=a[o+32767|0]&15;m=2014;break L2661}break};case 9:{o=c[210228]|0;if((a[840936]|0)==2){C=o+10239|0;m=2012;break L2661}else{z=a[o+20479|0]&15;m=2014;break L2661}break};default:{z=r;m=2014}}}while(0);if((m|0)==2012){z=(d[C]|0)>>>4&3;m=2014}L2675:do{if((m|0)==2014){a[808104]=z;o=z&255;switch(g|0){case 1:{x=o;y=c[263195]|0;m=2017;break L2675;break};case 7:{A=o;B=c[210228]|0;m=2019;break L2675;break};case 2:case 6:{D=a[(c[263193]|0)+65535|0]|0;E=o;break L2659;break};case 8:{p=c[263193]|0;if((a[840936]|0)==2){D=(d[p+16383|0]|0)>>>6;E=o;break L2659}else{D=(d[p+32767|0]|0)>>>4;E=o;break L2659}break};case 9:{p=c[210228]|0;if((a[840936]|0)==2){D=(d[p+10239|0]|0)>>>6;E=o;break L2659}else{D=(d[p+20479|0]|0)>>>4;E=o;break L2659}break};default:{D=z;E=o;break L2659}}}}while(0);if((m|0)==2017){D=a[y+65535|0]|0;E=x;break}else if((m|0)==2019){D=a[B+8191|0]|0;E=A;break}}else{g=a[s+65534|0]|0;a[808104]=g;D=a[s+65535|0]|0;E=g&255}}while(0);t=(D&255)<<8|E;u=t&65535;HR(u);v=(t&65535)>>>8;w=v&255;a[808104]=w;return}}function H_(){var d=0,f=0,g=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=((b[404043]|0)+(f&255)&65535)+(e[404045]|0)&65535;f=TP(d)|0;a[808104]=f;g=TP(d+1|0)|0;a[808104]=g;d=TP(((g&255)<<8|f&255)&65535|c[202032])|0;a[808104]=d;f=a[808084]|d;a[808084]=f;a[808121]=f;a[808122]=f;return}function H$(){var b=0,c=0;b=a[808084|0]|0;a[808120|0]=(b&255)>>>7;c=b<<1;a[808084|0]=c;a[808121|0]=c;a[808122|0]=c;return}function H0(){var d=0,e=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=e;b[404048]=d+1&65535;d=a[808084]|e;a[808084]=d;a[808121]=d;a[808122]=d;return}function H1(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;if((b[404041]&256)==0){f=a[808098|0]|0;g=b[404044]|0;b[404044]=g-1&65535;HY(f,g&65535);g=(b[404048]|0)+1&65535;f=(e[404044]|0)-1|0;HY((g&65535)>>>8&255,(f&65535)+1&65535|f&-65536);HY(g&255,f);f=b[404044]|0;g=a[808082]&60|a[808120]|a[808122]&-128|((a[808121]|0)==0)<<1|a[808123]<<6;a[808082]=g;b[404044]=f-3&65535;HY(g,f-2&65535);f=a[808082]|0;a[808104]=f;a[808082]=f&-13|4;g=c[202051]|0;L2775:do{if(g>>>0<19){h=g;L2778:do{switch(h|0){case 8:{i=c[263193]|0;if((a[840936]|0)==2){j=i+16377|0;k=2045;break L2778}else{l=a[i+32754|0]&15;k=2047;break L2778}break};case 7:{i=c[210228]|0;m=a[i+8164|0]|0;a[808104]=m;n=m&255;o=i;k=2052;break};case 2:case 6:{l=a[(c[263193]|0)+65508|0]|0;k=2047;break};case 9:{i=c[210228]|0;if((a[840936]|0)==2){j=i+10233|0;k=2045;break L2778}else{l=a[i+20466|0]&15;k=2047;break L2778}break};case 1:{i=c[263195]|0;m=a[i+65508|0]|0;a[808104]=m;p=m&255;q=i;k=2050;break};default:{l=f;k=2047}}}while(0);if((k|0)==2045){l=a[j]&3;k=2047}L2792:do{if((k|0)==2047){a[808104]=l;i=l&255;switch(h|0){case 1:{p=i;q=c[263195]|0;k=2050;break L2792;break};case 7:{n=i;o=c[210228]|0;k=2052;break L2792;break};case 2:case 6:{r=a[(c[263193]|0)+65509|0]|0;s=i;break L2775;break};case 8:{m=c[263193]|0;if((a[840936]|0)==2){r=(d[m+16377|0]|0)>>>2&3;s=i;break L2775}else{r=(d[m+32754|0]|0)>>>4;s=i;break L2775}break};case 9:{m=c[210228]|0;if((a[840936]|0)==2){r=(d[m+10233|0]|0)>>>2&3;s=i;break L2775}else{r=(d[m+20466|0]|0)>>>4;s=i;break L2775}break};default:{r=l;s=i;break L2775}}}}while(0);if((k|0)==2050){r=a[q+65509|0]|0;s=p;break}else if((k|0)==2052){r=a[o+8165|0]|0;s=n;break}}else{h=a[g+65508|0]|0;a[808104]=h;r=a[g+65509|0]|0;s=h&255}}while(0);t=(r&255)<<8|s;u=t&65535;HR(u);v=(t&65535)>>>8;w=v&255;a[808104]=w;return}else{a[808088]=(a[808088]|0)-1&255;s=(b[404048]|0)+1&65535;r=b[404044]|0;HY((s&65535)>>>8&255,((r&255)+1&255|r&-256)&65535);HY(s&255,r&65535);a[808088]=(a[808088]|0)-1&255;r=a[808082]&60|a[808120]|a[808122]&-128|((a[808121]|0)==0)<<1|a[808123]<<6;a[808082]=r;HY(r,e[404044]|0);a[808088]=(a[808088]|0)-1&255;r=a[808082]|0;a[808104]=r;a[808082]=r&-13|4;s=c[202051]|0;L2738:do{if(s>>>0<19){g=s;L2740:do{switch(g|0){case 1:{n=c[263195]|0;o=a[n+65524|0]|0;a[808104]=o;x=o&255;y=n;k=2076;break};case 2:case 6:{z=a[(c[263193]|0)+65524|0]|0;k=2073;break};case 7:{n=c[210228]|0;o=a[n+8180|0]|0;a[808104]=o;A=o&255;B=n;k=2078;break};case 8:{n=c[263193]|0;if((a[840936]|0)==2){C=n+16381|0;k=2071;break L2740}else{z=a[n+32762|0]&15;k=2073;break L2740}break};case 9:{n=c[210228]|0;if((a[840936]|0)==2){C=n+10237|0;k=2071;break L2740}else{z=a[n+20474|0]&15;k=2073;break L2740}break};default:{z=r;k=2073}}}while(0);if((k|0)==2071){z=a[C]&3;k=2073}L2754:do{if((k|0)==2073){a[808104]=z;n=z&255;switch(g|0){case 1:{x=n;y=c[263195]|0;k=2076;break L2754;break};case 7:{A=n;B=c[210228]|0;k=2078;break L2754;break};case 2:case 6:{D=a[(c[263193]|0)+65525|0]|0;E=n;break L2738;break};case 8:{o=c[263193]|0;if((a[840936]|0)==2){D=(d[o+16381|0]|0)>>>2&3;E=n;break L2738}else{D=(d[o+32762|0]|0)>>>4;E=n;break L2738}break};case 9:{o=c[210228]|0;if((a[840936]|0)==2){D=(d[o+10237|0]|0)>>>2&3;E=n;break L2738}else{D=(d[o+20474|0]|0)>>>4;E=n;break L2738}break};default:{D=z;E=n;break L2738}}}}while(0);if((k|0)==2076){D=a[y+65525|0]|0;E=x;break}else if((k|0)==2078){D=a[B+8181|0]|0;E=A;break}}else{g=a[s+65524|0]|0;a[808104]=g;D=a[s+65525|0]|0;E=g&255}}while(0);t=(D&255)<<8|E;u=t&65535;HR(u);v=(t&65535)>>>8;w=v&255;a[808104]=w;return}}function H2(){var d=0,e=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=e;b[404048]=d+1&65535;d=TP((b[404044]|0)+(e&255)&65535)|0;a[808104]=d;e=a[808084]|d;a[808084]=e;a[808121]=e;a[808122]=e;return}function H3(){var d=0,e=0,f=0,g=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=e;b[404048]=d+1&65535;d=(b[404043]|0)+(e&255)&65535;e=TP(d)|0;f=a[808084|0]|0;a[808121|0]=f&e;g=f|e;HY(g,d);a[808104]=g;return}function H4(){var d=0,e=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=e;b[404048]=d+1&65535;d=TP((b[404043]|0)+(e&255)&65535)|0;a[808104]=d;e=a[808084]|d;a[808084]=e;a[808121]=e;a[808122]=e;return}function H5(){var d=0,e=0,f=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=e;b[404048]=d+1&65535;d=(b[404043]|0)+(e&255)&65535;e=TP(d)|0;a[808120|0]=(e&255)>>>7;f=e<<1;HY(f,d);a[808104]=f;a[808121|0]=f;a[808122|0]=f;return}function H6(){var d=0,e=0,f=0,g=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=e;b[404048]=d+1&65535;d=(b[404043]|0)+(e&255)&65535;e=TP(d)|0;a[808104]=e;f=TP(d+1|0)|0;a[808104]=f;g=TP(d+2|0)|0;a[808104]=g;d=TP(((f&255)<<8|e&255)&65535|(g&255)<<16)|0;a[808104]=d;g=a[808084]|d;a[808084]=g;a[808121]=g;a[808122]=g;return}function H7(){var c=0,d=0;c=a[808082]&60|a[808120]|a[808122]&-128|((a[808121]|0)==0)<<1|a[808123]<<6;a[808082]=c;d=b[404044]|0;b[404044]=d-1&65535;HY(c,d&65535);a[808104]=a[808082]|0;return}function H8(){var c=0,d=0;c=b[404043]|0;d=(e[404044]|0)-1|0;HY((c&65535)>>>8&255,(d&65535)+1&65535|d&-65536);HY(c&255,d);b[404044]=(b[404044]|0)-2&65535;a[808104]=a[808086]|0;return}function H9(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[202032]|0;f=c[202034]|0;g=b[404048]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[808104]=i;b[404048]=g+2&65535;g=j&65535|e;e=TP(g)|0;j=a[808084]|0;a[808121]=j&e;i=j|e;HY(i,g);a[808104]=i;return}function Ia(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[202032]|0;f=c[202034]|0;g=b[404048]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[808104]=i;b[404048]=g+2&65535;g=TP(j&65535|e)|0;a[808104]=g;e=a[808084]|g;a[808084]=e;a[808121]=e;a[808122]=e;return}function Ib(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[202032]|0;f=c[202034]|0;g=b[404048]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[808104]=i;b[404048]=g+2&65535;g=j&65535|e;e=TP(g)|0;a[808120]=(e&255)>>>7;j=e<<1;HY(j,g);a[808104]=j;a[808121]=j;a[808122]=j;return}function Ic(){var e=0,f=0,g=0,h=0,i=0;e=c[202034]|0;f=b[404048]|0;g=f&65535;h=a[e+(g+2)|0]|0;i=(d[e+(g+1)|0]|0)<<8|(d[e+g|0]|0)|(h&255)<<16;a[808104]=h;b[404048]=f+3&65535;f=TP(i)|0;a[808104]=f;i=a[808084]|f;a[808084]=i;a[808121]=i;a[808122]=i;return}function Id(){var d=0,e=0,f=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=e;f=d+1&65535;b[404048]=f;d=f&65535;f=(e<<24>>24)+d|0;if((a[808122]|0)<0){return}if(((f^d)&61440|0)==0){b[404048]=f&65535;return}else{HR((c[202031]|0)+(f&65535)|0);return}}function Ie(){var d=0,f=0,g=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=(b[404043]|0)+(f&255)&65535;f=TP(d)|0;a[808104]=f;g=TP(d+1|0)|0;a[808104]=g;d=TP((((g&255)<<8|f&255)&65535|c[202032])+(e[404046]|0)|0)|0;a[808104]=d;f=a[808084]|d;a[808084]=f;a[808121]=f;a[808122]=f;return}function If(){var d=0,e=0,f=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=e;b[404048]=d+1&65535;d=(b[404043]|0)+(e&255)&65535;e=TP(d)|0;a[808104]=e;f=TP(d+1|0)|0;a[808104]=f;d=TP(((f&255)<<8|e&255)&65535|c[202032])|0;a[808104]=d;e=a[808084]|d;a[808084]=e;a[808121]=e;a[808122]=e;return}function Ig(){var d=0,f=0,g=0;d=TP(c[202024]|0)|0;a[808104]=d;b[404048]=(b[404048]|0)+1&65535;f=(b[404044]|0)+(d&255)&65535;d=TP(f)|0;a[808104]=d;g=TP(f+1|0)|0;a[808104]=g;f=TP((c[202032]|0)+(e[404046]|0)+(((g&255)<<8|d&255)&65535)&16777215)|0;a[808104]=f;d=a[808084]|f;a[808084]=d;a[808121]=d;a[808122]=d;return}function Ih(){var d=0,e=0,f=0,g=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=e;b[404048]=d+1&65535;d=(b[404043]|0)+(e&255)&65535;e=TP(d)|0;f=a[808084|0]|0;a[808121|0]=f&e;g=e&~f;HY(g,d);a[808104]=g;return}function Ii(){var d=0,f=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=TP(((b[404043]|0)+(f&255)&65535)+(e[404045]|0)&65535)|0;a[808104]=d;f=a[808084]|d;a[808084]=f;a[808121]=f;a[808122]=f;return}function Ij(){var d=0,f=0,g=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=((b[404043]|0)+(f&255)&65535)+(e[404045]|0)&65535;f=TP(d)|0;a[808120]=(f&255)>>>7;g=f<<1;HY(g,d);a[808104]=g;a[808121]=g;a[808122]=g;return}function Ik(){a[808120|0]=0;return}function Il(){var b=0;b=(a[808084|0]|0)+1&255;a[808084|0]=b;a[808121|0]=b;a[808122|0]=b;return}function Im(){b[404044]=b[404042]|0;if((b[404041]&256)==0){return}a[808089|0]=1;return}function In(){var b=0,c=0;b=(d[808084]|0)<<1;c=b|(d[808120]|0);a[808120]=(b&65535)>255|0;b=c&255;a[808084]=b;a[808121]=b;a[808122]=b;return}function Io(){var d=0,e=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=e;b[404048]=d+1&65535;d=a[808084]&e;a[808084]=d;a[808121]=d;a[808122]=d;return}function Ip(){var d=0,f=0,g=0,h=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=(b[404043]|0)+(f&255)&65535;f=TP(d)|0;a[808104]=f;g=TP(d+1|0)|0;a[808104]=g;h=TP(d+2|0)|0;a[808104]=h;d=TP((((g&255)<<8|f&255)&65535|(h&255)<<16)+(e[404046]|0)|0)|0;a[808104]=d;h=a[808084]|d;a[808084]=h;a[808121]=h;a[808122]=h;return}function Iq(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=TP((k&65535|f)+(e[404046]|0)|0)|0;a[808104]=h;f=a[808084]|h;a[808084]=f;a[808121]=f;a[808122]=f;return}function Ir(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[202032]|0;f=c[202034]|0;g=b[404048]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[808104]=i;b[404048]=g+2&65535;g=j&65535|e;e=TP(g)|0;j=a[808084]|0;a[808121]=j&e;i=e&~j;HY(i,g);a[808104]=i;return}function Is(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=TP((k&65535|f)+(e[404045]|0)|0)|0;a[808104]=h;f=a[808084]|h;a[808084]=f;a[808121]=f;a[808122]=f;return}function It(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=(k&65535|f)+(e[404045]|0)|0;f=TP(h)|0;a[808120]=(f&255)>>>7;k=f<<1;HY(k,h);a[808104]=k;a[808121]=k;a[808122]=k;return}function Iu(){var f=0,g=0,h=0,i=0,j=0;f=c[202034]|0;g=b[404048]|0;h=g&65535;i=a[f+(h+2)|0]|0;j=(d[f+(h+1)|0]|0)<<8|(d[f+h|0]|0)|(i&255)<<16;a[808104]=i;b[404048]=g+3&65535;g=TP(j+(e[404045]|0)|0)|0;a[808104]=g;j=a[808084]|g;a[808084]=j;a[808121]=j;a[808122]=j;return}function Iv(){var a=0,f=0,g=0,h=0,i=0;a=c[202032]|0;f=c[202034]|0;g=b[404048]|0;h=g&65535;i=(d[f+(h+1)|0]|0)<<8|(d[f+h|0]|0);b[404048]=g+2&65535;h=g+1&65535;g=(e[404044]|0)-1|0;HY((h&65535)>>>8&255,(g&65535)+1&65535|g&-65536);HY(h&255,g);b[404044]=(b[404044]|0)-2&65535;HR((c[202031]|0)+(i&65535|a&65535)|0);return}function Iw(){var d=0,f=0,g=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=((b[404043]|0)+(f&255)&65535)+(e[404045]|0)&65535;f=TP(d)|0;a[808104]=f;g=TP(d+1|0)|0;a[808104]=g;d=TP(((g&255)<<8|f&255)&65535|c[202032])|0;a[808104]=d;f=a[808084]&d;a[808084]=f;a[808121]=f;a[808122]=f;return}function Ix(){var f=0,g=0,h=0,i=0;f=c[202034]|0;g=b[404048]|0;h=g&65535;i=(d[f+(h+1)|0]|0)<<8|(d[f+h|0]|0)|(d[f+(h+2)|0]|0)<<16;b[404048]=g+3&65535;g=a[808098|0]|0;h=b[404044]|0;b[404044]=h-1&65535;HY(g,h&65535);h=(b[404048]|0)-1&65535;g=(e[404044]|0)-1|0;HY((h&65535)>>>8&255,(g&65535)+1&65535|g&-65536);HY(h&255,g);b[404044]=(b[404044]|0)-2&65535;HR(i);return}function Iy(){var d=0,e=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=e;b[404048]=d+1&65535;d=TP((b[404044]|0)+(e&255)&65535)|0;a[808104]=d;e=a[808084]&d;a[808084]=e;a[808121]=e;a[808122]=e;return}function Iz(){var d=0,e=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=e;b[404048]=d+1&65535;d=TP((b[404043]|0)+(e&255)&65535)|0;a[808104]=d;a[808123]=(d&255)>>>6&1;a[808122]=d;a[808121]=a[808084]&d;return}function IA(){var d=0,e=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=e;b[404048]=d+1&65535;d=TP((b[404043]|0)+(e&255)&65535)|0;a[808104]=d;e=a[808084]&d;a[808084]=e;a[808121]=e;a[808122]=e;return}function IB(){var e=0,f=0,g=0;e=b[404048]|0;f=a[(c[202034]|0)+(e&65535)|0]|0;a[808104]=f;b[404048]=e+1&65535;e=(b[404043]|0)+(f&255)&65535;f=((TP(e)|0)&255)<<1;g=f|(d[808120]|0);a[808120]=(g&65535)>255|0;f=g&255;HY(f,e);a[808104]=f;a[808121]=f;a[808122]=f;return}function IC(){var d=0,e=0,f=0,g=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=e;b[404048]=d+1&65535;d=(b[404043]|0)+(e&255)&65535;e=TP(d)|0;a[808104]=e;f=TP(d+1|0)|0;a[808104]=f;g=TP(d+2|0)|0;a[808104]=g;d=TP(((f&255)<<8|e&255)&65535|(g&255)<<16)|0;a[808104]=d;g=a[808084]&d;a[808084]=g;a[808121]=g;a[808122]=g;return}function ID(){var d=0,e=0;d=(b[404044]|0)+1&65535;b[404044]=d;e=TP(d&65535)|0;a[808082]=e;a[808104]=e;a[808121]=(e&255)>>>1&1^1;a[808122]=e&-128;a[808120]=e&1;a[808123]=(e&255)>>>6&1;if((e&16)!=0){a[808091|0]=0;a[808093|0]=0}e=b[404041]|0;if((e&256)!=0){c[202028]=149560;c[202029]=159800;return}d=e&255;e=(d&16|0)!=0;if((d&32|0)==0){if(e){c[202028]=151608;c[202029]=160312;return}else{c[202028]=152632;c[202029]=160568;return}}else{if(e){c[202028]=149560;c[202029]=159800;return}else{c[202028]=150584;c[202029]=160056;return}}}function IE(){var c=0,d=0,f=0;c=(e[404044]|0)+1|0;d=TP(c)|0;a[808104]=d;f=TP((c&65535)+1&65535|c&2147418112)|0;c=(f&255)<<8|d&255;b[404043]=c;b[404044]=(b[404044]|0)+2&65535;a[808121]=c<<16>>16!=0|0;a[808122]=f;a[808104]=f;return}function IF(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[202032]|0;f=c[202034]|0;g=b[404048]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[808104]=i;b[404048]=g+2&65535;g=TP(j&65535|e)|0;a[808104]=g;a[808123]=(g&255)>>>6&1;a[808122]=g;a[808121]=a[808084]&g;return}function IG(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[202032]|0;f=c[202034]|0;g=b[404048]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[808104]=i;b[404048]=g+2&65535;g=TP(j&65535|e)|0;a[808104]=g;e=a[808084]&g;a[808084]=e;a[808121]=e;a[808122]=e;return}function IH(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[202032]|0;f=c[202034]|0;g=b[404048]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[808104]=i;b[404048]=g+2&65535;g=j&65535|e;e=((TP(g)|0)&255)<<1;j=e|(d[808120]|0);a[808120]=(j&65535)>255|0;e=j&255;HY(e,g);a[808104]=e;a[808121]=e;a[808122]=e;return}function II(){var e=0,f=0,g=0,h=0,i=0;e=c[202034]|0;f=b[404048]|0;g=f&65535;h=a[e+(g+2)|0]|0;i=(d[e+(g+1)|0]|0)<<8|(d[e+g|0]|0)|(h&255)<<16;a[808104]=h;b[404048]=f+3&65535;f=TP(i)|0;a[808104]=f;i=a[808084]&f;a[808084]=i;a[808121]=i;a[808122]=i;return}function IJ(){var d=0,e=0,f=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=e;f=d+1&65535;b[404048]=f;d=f&65535;f=(e<<24>>24)+d|0;if((a[808122]|0)>=0){return}if(((f^d)&61440|0)==0){b[404048]=f&65535;return}else{HR((c[202031]|0)+(f&65535)|0);return}}function IK(){var d=0,f=0,g=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=(b[404043]|0)+(f&255)&65535;f=TP(d)|0;a[808104]=f;g=TP(d+1|0)|0;a[808104]=g;d=TP((((g&255)<<8|f&255)&65535|c[202032])+(e[404046]|0)|0)|0;a[808104]=d;f=a[808084]&d;a[808084]=f;a[808121]=f;a[808122]=f;return}function IL(){var d=0,e=0,f=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=e;b[404048]=d+1&65535;d=(b[404043]|0)+(e&255)&65535;e=TP(d)|0;a[808104]=e;f=TP(d+1|0)|0;a[808104]=f;d=TP(((f&255)<<8|e&255)&65535|c[202032])|0;a[808104]=d;e=a[808084]&d;a[808084]=e;a[808121]=e;a[808122]=e;return}function IM(){var d=0,f=0,g=0;d=TP(c[202024]|0)|0;a[808104]=d;b[404048]=(b[404048]|0)+1&65535;f=(b[404044]|0)+(d&255)&65535;d=TP(f)|0;a[808104]=d;g=TP(f+1|0)|0;a[808104]=g;f=TP((c[202032]|0)+(e[404046]|0)+(((g&255)<<8|d&255)&65535)&16777215)|0;a[808104]=f;d=a[808084]&f;a[808084]=d;a[808121]=d;a[808122]=d;return}function IN(){var d=0,f=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=TP(((b[404043]|0)+(f&255)&65535)+(e[404045]|0)&65535)|0;a[808104]=d;a[808123]=(d&255)>>>6&1;a[808122]=d;a[808121]=a[808084]&d;return}function IO(){var d=0,f=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=TP(((b[404043]|0)+(f&255)&65535)+(e[404045]|0)&65535)|0;a[808104]=d;f=a[808084]&d;a[808084]=f;a[808121]=f;a[808122]=f;return}function IP(){var f=0,g=0,h=0;f=b[404048]|0;g=a[(c[202034]|0)+(f&65535)|0]|0;a[808104]=g;b[404048]=f+1&65535;f=((b[404043]|0)+(g&255)&65535)+(e[404045]|0)&65535;g=((TP(f)|0)&255)<<1;h=g|(d[808120]|0);a[808120]=(h&65535)>255|0;g=h&255;HY(g,f);a[808104]=g;a[808121]=g;a[808122]=g;return}function IQ(){a[808120|0]=1;return}function IR(){var b=0;b=(a[808084|0]|0)-1&255;a[808084|0]=b;a[808121|0]=b;a[808122|0]=b;return}function IS(){var c=0;c=b[404044]|0;b[404042]=c;a[808121|0]=c<<16>>16!=0|0;a[808122|0]=(c&65535)>>>8&255;return}function IT(){var b=0,c=0;b=a[808084|0]|0;a[808120|0]=b&1;c=(b&255)>>>1;a[808084|0]=c;a[808121|0]=c;a[808122|0]=c;return}function IU(){var d=0,e=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=e;b[404048]=d+1&65535;d=a[808084]^e;a[808084]=d;a[808121]=d;a[808122]=d;return}function IV(){var d=0,f=0,g=0,h=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=(b[404043]|0)+(f&255)&65535;f=TP(d)|0;a[808104]=f;g=TP(d+1|0)|0;a[808104]=g;h=TP(d+2|0)|0;a[808104]=h;d=TP((((g&255)<<8|f&255)&65535|(h&255)<<16)+(e[404046]|0)|0)|0;a[808104]=d;h=a[808084]&d;a[808084]=h;a[808121]=h;a[808122]=h;return}function IW(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=TP((k&65535|f)+(e[404046]|0)|0)|0;a[808104]=h;f=a[808084]&h;a[808084]=f;a[808121]=f;a[808122]=f;return}function IX(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=TP((k&65535|f)+(e[404045]|0)|0)|0;a[808104]=h;a[808123]=(h&255)>>>6&1;a[808122]=h;a[808121]=a[808084]&h;return}function IY(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=TP((k&65535|f)+(e[404045]|0)|0)|0;a[808104]=h;f=a[808084]&h;a[808084]=f;a[808121]=f;a[808122]=f;return}function IZ(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=(k&65535|f)+(e[404045]|0)|0;f=((TP(h)|0)&255)<<1;k=f|(d[808120]|0);a[808120]=(k&65535)>255|0;f=k&255;HY(f,h);a[808104]=f;a[808121]=f;a[808122]=f;return}function I_(){var f=0,g=0,h=0,i=0,j=0;f=c[202034]|0;g=b[404048]|0;h=g&65535;i=a[f+(h+2)|0]|0;j=(d[f+(h+1)|0]|0)<<8|(d[f+h|0]|0)|(i&255)<<16;a[808104]=i;b[404048]=g+3&65535;g=TP(j+(e[404045]|0)|0)|0;a[808104]=g;j=a[808084]&g;a[808084]=j;a[808121]=j;a[808122]=j;return}function I$(){var d=0,f=0,g=0;if((b[404041]&256)==0){d=(b[404044]|0)+1&65535;b[404044]=d;f=TP(d&65535)|0;a[808082]=f;a[808121]=(f&255)>>>1&1^1;a[808122]=f&-128;a[808120]=f&1;a[808123]=(f&255)>>>6&1;f=(e[404044]|0)+1|0;d=TP(f)|0;a[808104]=d;b[404048]=((TP((f&65535)+1&65535|f&2147418112)|0)&255)<<8|d&255;d=(b[404044]|0)+3&65535;b[404044]=d;f=TP(d&65535)|0;a[808098|0]=f;a[808104]=f;c[202031]=(f&255)<<16}else{a[808088]=(a[808088]|0)+1&255;f=TP(e[404044]|0)|0;a[808082]=f;a[808121]=(f&255)>>>1&1^1;a[808122]=f&-128;a[808120]=f&1;a[808123]=(f&255)>>>6&1;a[808088]=(a[808088]|0)+1&255;f=b[404044]|0;d=TP(f&65535)|0;a[808104]=d;g=TP(((f&255)+1&255|f&-256)&65535)|0;b[404048]=(g&255)<<8|d&255;a[808088]=(a[808088]|0)+1&255;a[808104]=g;b[404041]=b[404041]|48}HR(c[202024]|0);if((a[808082]&16)!=0){a[808091|0]=0;a[808093|0]=0}g=b[404041]|0;if((g&256)!=0){c[202028]=149560;c[202029]=159800;return}d=g&255;g=(d&16|0)!=0;if((d&32|0)==0){if(g){c[202028]=151608;c[202029]=160312;return}else{c[202028]=152632;c[202029]=160568;return}}else{if(g){c[202028]=149560;c[202029]=159800;return}else{c[202028]=150584;c[202029]=160056;return}}}function I0(){var d=0,f=0,g=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=((b[404043]|0)+(f&255)&65535)+(e[404045]|0)&65535;f=TP(d)|0;a[808104]=f;g=TP(d+1|0)|0;a[808104]=g;d=TP(((g&255)<<8|f&255)&65535|c[202032])|0;a[808104]=d;f=a[808084]^d;a[808084]=f;a[808121]=f;a[808122]=f;return}function I1(){var d=0;d=c[202024]|0;a[808104]=TP(d)|0;TP(d+1|0)|0;b[404048]=(b[404048]|0)+1&65535;return}function I2(){var d=0,e=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=e;b[404048]=d+1&65535;d=TP((b[404044]|0)+(e&255)&65535)|0;a[808104]=d;e=a[808084]^d;a[808084]=e;a[808121]=e;a[808122]=e;return}function I3(){var d=0,f=0,g=0,h=0;d=b[404048]|0;f=c[202034]|0;g=a[f+(d&65535)|0]|0;h=d+1&65535;b[404048]=h;a[808080]=g;c[202032]=(g&255)<<16;g=a[f+(h&65535)|0]|0;b[404048]=d+2&65535;a[808104]=g;d=TP((g&255)<<16|(e[404045]|0))|0;a[808104]=d;HY(d,(e[404046]|0)+(c[202032]|0)|0);a[808090]=(a[808090]|0)-1&255;a[808092]=(a[808092]|0)-1&255;d=b[404042]|0;b[404042]=d-1&65535;if(d<<16>>16==0){return}b[404048]=(b[404048]|0)-3&65535;return}function I4(){var d=0,e=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=e;b[404048]=d+1&65535;d=TP((b[404043]|0)+(e&255)&65535)|0;a[808104]=d;e=a[808084]^d;a[808084]=e;a[808121]=e;a[808122]=e;return}function I5(){var d=0,e=0,f=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=e;b[404048]=d+1&65535;d=(b[404043]|0)+(e&255)&65535;e=TP(d)|0;a[808120|0]=e&1;f=(e&255)>>>1;HY(f,d);a[808104]=f;a[808121|0]=f;a[808122|0]=f;return}function I6(){var d=0,e=0,f=0,g=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=e;b[404048]=d+1&65535;d=(b[404043]|0)+(e&255)&65535;e=TP(d)|0;a[808104]=e;f=TP(d+1|0)|0;a[808104]=f;g=TP(d+2|0)|0;a[808104]=g;d=TP(((f&255)<<8|e&255)&65535|(g&255)<<16)|0;a[808104]=d;g=a[808084]^d;a[808084]=g;a[808121]=g;a[808122]=g;return}function I7(){var c=0,d=0;c=a[808084|0]|0;d=b[404044]|0;b[404044]=d-1&65535;HY(c,d&65535);a[808104]=a[808084|0]|0;return}function I8(){var c=0,d=0;c=a[808098|0]|0;d=b[404044]|0;b[404044]=d-1&65535;HY(c,d&65535);a[808104]=a[808098|0]|0;return}function I9(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0;e=c[202031]|0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;HR((k&65535|f&65535)+e|0);return}function Ja(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[202032]|0;f=c[202034]|0;g=b[404048]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[808104]=i;b[404048]=g+2&65535;g=TP(j&65535|e)|0;a[808104]=g;e=a[808084]^g;a[808084]=e;a[808121]=e;a[808122]=e;return}function Jb(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[202032]|0;f=c[202034]|0;g=b[404048]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[808104]=i;b[404048]=g+2&65535;g=j&65535|e;e=TP(g)|0;a[808120]=e&1;j=(e&255)>>>1;HY(j,g);a[808104]=j;a[808121]=j;a[808122]=j;return}function Jc(){var e=0,f=0,g=0,h=0,i=0;e=c[202034]|0;f=b[404048]|0;g=f&65535;h=a[e+(g+2)|0]|0;i=(d[e+(g+1)|0]|0)<<8|(d[e+g|0]|0)|(h&255)<<16;a[808104]=h;b[404048]=f+3&65535;f=TP(i)|0;a[808104]=f;i=a[808084]^f;a[808084]=i;a[808121]=i;a[808122]=i;return}function Jd(){var d=0,e=0,f=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=e;f=d+1&65535;b[404048]=f;d=f&65535;f=(e<<24>>24)+d|0;if((a[808123]|0)!=0){return}if(((f^d)&61440|0)==0){b[404048]=f&65535;return}else{HR((c[202031]|0)+(f&65535)|0);return}}function Je(){var d=0,f=0,g=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=(b[404043]|0)+(f&255)&65535;f=TP(d)|0;a[808104]=f;g=TP(d+1|0)|0;a[808104]=g;d=TP((((g&255)<<8|f&255)&65535|c[202032])+(e[404046]|0)|0)|0;a[808104]=d;f=a[808084]^d;a[808084]=f;a[808121]=f;a[808122]=f;return}function Jf(){var d=0,e=0,f=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=e;b[404048]=d+1&65535;d=(b[404043]|0)+(e&255)&65535;e=TP(d)|0;a[808104]=e;f=TP(d+1|0)|0;a[808104]=f;d=TP(((f&255)<<8|e&255)&65535|c[202032])|0;a[808104]=d;e=a[808084]^d;a[808084]=e;a[808121]=e;a[808122]=e;return}function Jg(){var d=0,f=0,g=0;d=TP(c[202024]|0)|0;a[808104]=d;b[404048]=(b[404048]|0)+1&65535;f=(b[404044]|0)+(d&255)&65535;d=TP(f)|0;a[808104]=d;g=TP(f+1|0)|0;a[808104]=g;f=TP((c[202032]|0)+(e[404046]|0)+(((g&255)<<8|d&255)&65535)&16777215)|0;a[808104]=f;d=a[808084]^f;a[808084]=d;a[808121]=d;a[808122]=d;return}function Jh(){var d=0,f=0,g=0,h=0;d=b[404048]|0;f=c[202034]|0;g=a[f+(d&65535)|0]|0;h=d+1&65535;b[404048]=h;a[808080]=g;c[202032]=(g&255)<<16;g=a[f+(h&65535)|0]|0;b[404048]=d+2&65535;a[808104]=g;d=TP((g&255)<<16|(e[404045]|0))|0;a[808104]=d;HY(d,(e[404046]|0)+(c[202032]|0)|0);a[808090]=(a[808090]|0)+1&255;a[808092]=(a[808092]|0)+1&255;d=b[404042]|0;b[404042]=d-1&65535;if(d<<16>>16==0){return}b[404048]=(b[404048]|0)-3&65535;return}function Ji(){var d=0,f=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=TP(((b[404043]|0)+(f&255)&65535)+(e[404045]|0)&65535)|0;a[808104]=d;f=a[808084]^d;a[808084]=f;a[808121]=f;a[808122]=f;return}function Jj(){a[808082]=a[808082]&-5;return}function Jk(){var c=0;c=b[404042]|0;b[404043]=c;a[808121|0]=c<<16>>16!=0|0;a[808122|0]=(c&65535)>>>8&255;return}function Jl(){var b=0,c=0;b=a[808084]|0;c=(d[808120]|0)<<8|b&255;a[808120]=b&1;b=(c&65535)>>>1&255;a[808084]=b;a[808121]=b;a[808122]=b;return}function Jm(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=b[404048]|0;f=a[(c[202034]|0)+(e&65535)|0]|0;a[808104]=f;b[404048]=e+1&65535;if((a[808082]&8)==0){e=a[808084]|0;g=f&255;h=(e&255)+g+(d[808120]|0)|0;a[808120]=(h&65280)>>>0>255|0;i=h&255;j=((h^g)&((e^f)&255^128))>>>7&255;k=j&1;a[808123]=k;a[808084]=i;a[808121]=i;a[808122]=i;return}e=b[404042]|0;g=e&255;h=e&240;e=((a[808120]|0)+(f&15)&255)+(g&15)&255;if((e&255)>9){l=e+6&15;m=h+16&65535}else{l=e;m=h}h=m+(f&-16&255)&65535;if((h&65535)>144){a[808120]=1;n=h+96&255&-16}else{a[808120]=0;n=h&255}h=n|l;i=h;j=((h^f)&(f^-128^g)&255)>>>7;k=j&1;a[808123]=k;a[808084]=i;a[808121]=i;a[808122]=i;return}function Jn(){var d=0,f=0,g=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=((b[404043]|0)+(f&255)&65535)+(e[404045]|0)&65535;f=TP(d)|0;a[808120]=f&1;g=(f&255)>>>1;HY(g,d);a[808104]=g;a[808121]=g;a[808122]=g;return}function Jo(){var d=0,f=0,g=0,h=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=(b[404043]|0)+(f&255)&65535;f=TP(d)|0;a[808104]=f;g=TP(d+1|0)|0;a[808104]=g;h=TP(d+2|0)|0;a[808104]=h;d=TP((((g&255)<<8|f&255)&65535|(h&255)<<16)+(e[404046]|0)|0)|0;a[808104]=d;h=a[808084]^d;a[808084]=h;a[808121]=h;a[808122]=h;return}function Jp(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=TP((k&65535|f)+(e[404046]|0)|0)|0;a[808104]=h;f=a[808084]^h;a[808084]=f;a[808121]=f;a[808122]=f;return}function Jq(){var c=0,d=0;c=a[808092|0]|0;d=b[404044]|0;b[404044]=d-1&65535;HY(c,d&65535);a[808104]=a[808092|0]|0;return}function Jr(){var e=0,f=0,g=0,h=0,i=0;e=c[202034]|0;f=b[404048]|0;g=f&65535;h=a[e+(g+2)|0]|0;i=(d[e+(g+1)|0]|0)<<8|(d[e+g|0]|0)|(h&255)<<16;a[808104]=h;b[404048]=f+3&65535;HR(i);return}function Js(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=TP((k&65535|f)+(e[404045]|0)|0)|0;a[808104]=h;f=a[808084]^h;a[808084]=f;a[808121]=f;a[808122]=f;return}function Jt(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=(k&65535|f)+(e[404045]|0)|0;f=TP(h)|0;a[808120]=f&1;k=(f&255)>>>1;HY(k,h);a[808104]=k;a[808121]=k;a[808122]=k;return}function Ju(){var f=0,g=0,h=0,i=0,j=0;f=c[202034]|0;g=b[404048]|0;h=g&65535;i=a[f+(h+2)|0]|0;j=(d[f+(h+1)|0]|0)<<8|(d[f+h|0]|0)|(i&255)<<16;a[808104]=i;b[404048]=g+3&65535;g=TP(j+(e[404045]|0)|0)|0;a[808104]=g;j=a[808084]^g;a[808084]=j;a[808121]=j;a[808122]=j;return}function Jv(){var d=0,f=0,g=0;d=(e[404044]|0)+1|0;f=TP(d)|0;a[808104]=f;g=((TP((d&65535)+1&65535|d&2147418112)|0)&255)<<8|f&255;b[404044]=(b[404044]|0)+2&65535;b[404048]=g+1&65535;HR(c[202024]|0);return}function Jw(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=b[404048]|0;g=a[(c[202034]|0)+(f&65535)|0]|0;a[808104]=g;b[404048]=f+1&65535;f=((b[404043]|0)+(g&255)&65535)+(e[404045]|0)&65535;g=TP(f)|0;a[808104]=g;h=TP(f+1|0)|0;a[808104]=h;f=TP(((h&255)<<8|g&255)&65535|c[202032])|0;a[808104]=f;if((a[808082]&8)==0){g=a[808084]|0;h=f&255;i=(g&255)+h+(d[808120]|0)|0;a[808120]=(i&65280)>>>0>255|0;j=i&255;k=((i^h)&((g^f)&255^128))>>>7&255;l=k&1;a[808123]=l;a[808084]=j;a[808121]=j;a[808122]=j;return}g=b[404042]|0;h=g&255;i=g&240;g=((a[808120]|0)+(f&15)&255)+(h&15)&255;if((g&255)>9){m=g+6&15;n=i+16&65535}else{m=g;n=i}i=n+(f&-16&255)&65535;if((i&65535)>144){a[808120]=1;o=i+96&255&-16}else{a[808120]=0;o=i&255}i=o|m;j=i;k=((i^f)&(f^-128^h)&255)>>>7;l=k&1;a[808123]=l;a[808084]=j;a[808121]=j;a[808122]=j;return}function Jx(){var f=0,g=0,h=0,i=0;f=c[202034]|0;g=b[404048]|0;h=g&65535;i=(d[f+(h+1)|0]|0)<<8|(d[f+h|0]|0);h=g+2&65535;b[404048]=h;g=(i&65535)+(h&65535)|0;h=(e[404044]|0)-1|0;HY((g&65535)>>>8&255,(h&65535)+1&65535|h&-65536);i=g&255;HY(i,h);b[404044]=(b[404044]|0)-2&65535;a[808104]=i;return}function Jy(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=b[404048]|0;f=a[(c[202034]|0)+(e&65535)|0]|0;a[808104]=f;b[404048]=e+1&65535;e=TP((b[404044]|0)+(f&255)&65535)|0;a[808104]=e;if((a[808082]&8)==0){f=a[808084]|0;g=e&255;h=(f&255)+g+(d[808120]|0)|0;a[808120]=(h&65280)>>>0>255|0;i=h&255;j=((h^g)&((f^e)&255^128))>>>7&255;k=j&1;a[808123]=k;a[808084]=i;a[808121]=i;a[808122]=i;return}f=b[404042]|0;g=f&255;h=f&240;f=((a[808120]|0)+(e&15)&255)+(g&15)&255;if((f&255)>9){l=f+6&15;m=h+16&65535}else{l=f;m=h}h=m+(e&-16&255)&65535;if((h&65535)>144){a[808120]=1;n=h+96&255&-16}else{a[808120]=0;n=h&255}h=n|l;i=h;j=((h^e)&(e^-128^g)&255)>>>7;k=j&1;a[808123]=k;a[808084]=i;a[808121]=i;a[808122]=i;return}function Jz(){var d=0,e=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;b[404048]=d+1&65535;HY(0,(b[404043]|0)+(e&255)&65535);a[808104]=0;return}function JA(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=b[404048]|0;f=a[(c[202034]|0)+(e&65535)|0]|0;a[808104]=f;b[404048]=e+1&65535;e=TP((b[404043]|0)+(f&255)&65535)|0;a[808104]=e;if((a[808082]&8)==0){f=a[808084]|0;g=e&255;h=(f&255)+g+(d[808120]|0)|0;a[808120]=(h&65280)>>>0>255|0;i=h&255;j=((h^g)&((f^e)&255^128))>>>7&255;k=j&1;a[808123]=k;a[808084]=i;a[808121]=i;a[808122]=i;return}f=b[404042]|0;g=f&255;h=f&240;f=((a[808120]|0)+(e&15)&255)+(g&15)&255;if((f&255)>9){l=f+6&15;m=h+16&65535}else{l=f;m=h}h=m+(e&-16&255)&65535;if((h&65535)>144){a[808120]=1;n=h+96&255&-16}else{a[808120]=0;n=h&255}h=n|l;i=h;j=((h^e)&(e^-128^g)&255)>>>7;k=j&1;a[808123]=k;a[808084]=i;a[808121]=i;a[808122]=i;return}function JB(){var e=0,f=0,g=0;e=b[404048]|0;f=a[(c[202034]|0)+(e&65535)|0]|0;a[808104]=f;b[404048]=e+1&65535;e=(b[404043]|0)+(f&255)&65535;f=TP(e)|0;g=(d[808120]|0)<<8|f&255;a[808120]=f&1;f=(g&65535)>>>1&255;HY(f,e);a[808104]=f;a[808121]=f;a[808122]=f;return}function JC(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=b[404048]|0;f=a[(c[202034]|0)+(e&65535)|0]|0;a[808104]=f;b[404048]=e+1&65535;e=(b[404043]|0)+(f&255)&65535;f=TP(e)|0;a[808104]=f;g=TP(e+1|0)|0;a[808104]=g;h=TP(e+2|0)|0;a[808104]=h;e=TP(((g&255)<<8|f&255)&65535|(h&255)<<16)|0;a[808104]=e;if((a[808082]&8)==0){h=a[808084]|0;f=e&255;g=(h&255)+f+(d[808120]|0)|0;a[808120]=(g&65280)>>>0>255|0;i=g&255;j=((g^f)&((h^e)&255^128))>>>7&255;k=j&1;a[808123]=k;a[808084]=i;a[808121]=i;a[808122]=i;return}h=b[404042]|0;f=h&255;g=h&240;h=((a[808120]|0)+(e&15)&255)+(f&15)&255;if((h&255)>9){l=h+6&15;m=g+16&65535}else{l=h;m=g}g=m+(e&-16&255)&65535;if((g&65535)>144){a[808120]=1;n=g+96&255&-16}else{a[808120]=0;n=g&255}g=n|l;i=g;j=((g^e)&(e^-128^f)&255)>>>7;k=j&1;a[808123]=k;a[808084]=i;a[808121]=i;a[808122]=i;return}function JD(){var c=0,d=0;c=(b[404044]|0)+1&65535;b[404044]=c;d=TP(c&65535)|0;a[808084|0]=d;a[808121|0]=d;a[808122|0]=d;a[808104]=d;return}function JE(){var d=0,f=0;d=(e[404044]|0)+1|0;f=TP(d)|0;a[808104]=f;b[404048]=((TP((d&65535)+1&65535|d&2147418112)|0)&255)<<8|f&255;f=(b[404044]|0)+3&65535;b[404044]=f;a[808098|0]=TP(f&65535)|0;b[404048]=(b[404048]|0)+1&65535;HR(c[202024]|0);return}function JF(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[202031]|0;f=c[202034]|0;g=b[404048]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[808104]=i;b[404048]=g+2&65535;g=j&65535;j=TP(g)|0;a[808104]=j;i=TP(g+1|0)|0;a[808104]=i;HR((((i&255)<<8|j&255)&65535)+e|0);return}function JG(){a[808082]=a[808082]|4;return}function JH(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=c[202032]|0;f=c[202034]|0;g=b[404048]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[808104]=i;b[404048]=g+2&65535;g=TP(j&65535|e)|0;a[808104]=g;if((a[808082]&8)==0){e=a[808084]|0;j=g&255;i=(e&255)+j+(d[808120]|0)|0;a[808120]=(i&65280)>>>0>255|0;k=i&255;l=((i^j)&((e^g)&255^128))>>>7&255;m=l&1;a[808123]=m;a[808084]=k;a[808121]=k;a[808122]=k;return}e=b[404042]|0;j=e&255;i=e&240;e=((a[808120]|0)+(g&15)&255)+(j&15)&255;if((e&255)>9){n=e+6&15;o=i+16&65535}else{n=e;o=i}i=o+(g&-16&255)&65535;if((i&65535)>144){a[808120]=1;p=i+96&255&-16}else{a[808120]=0;p=i&255}i=p|n;k=i;l=((i^g)&(g^-128^j)&255)>>>7;m=l&1;a[808123]=m;a[808084]=k;a[808121]=k;a[808122]=k;return}function JI(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[202032]|0;f=c[202034]|0;g=b[404048]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[808104]=i;b[404048]=g+2&65535;g=j&65535|e;e=TP(g)|0;j=(d[808120]|0)<<8|e&255;a[808120]=e&1;e=(j&65535)>>>1&255;HY(e,g);a[808104]=e;a[808121]=e;a[808122]=e;return}function JJ(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=c[202034]|0;f=b[404048]|0;g=f&65535;h=a[e+(g+2)|0]|0;i=(d[e+(g+1)|0]|0)<<8|(d[e+g|0]|0)|(h&255)<<16;a[808104]=h;b[404048]=f+3&65535;f=TP(i)|0;a[808104]=f;if((a[808082]&8)==0){i=a[808084]|0;h=f&255;g=(i&255)+h+(d[808120]|0)|0;a[808120]=(g&65280)>>>0>255|0;j=g&255;k=((g^h)&((i^f)&255^128))>>>7&255;l=k&1;a[808123]=l;a[808084]=j;a[808121]=j;a[808122]=j;return}i=b[404042]|0;h=i&255;g=i&240;i=((a[808120]|0)+(f&15)&255)+(h&15)&255;if((i&255)>9){m=i+6&15;n=g+16&65535}else{m=i;n=g}g=n+(f&-16&255)&65535;if((g&65535)>144){a[808120]=1;o=g+96&255&-16}else{a[808120]=0;o=g&255}g=o|m;j=g;k=((g^f)&(f^-128^h)&255)>>>7;l=k&1;a[808123]=l;a[808084]=j;a[808121]=j;a[808122]=j;return}function JK(){var d=0,e=0,f=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=e;f=d+1&65535;b[404048]=f;d=f&65535;f=(e<<24>>24)+d|0;if((a[808123]|0)==0){return}if(((f^d)&61440|0)==0){b[404048]=f&65535;return}else{HR((c[202031]|0)+(f&65535)|0);return}}function JL(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=b[404048]|0;g=a[(c[202034]|0)+(f&65535)|0]|0;a[808104]=g;b[404048]=f+1&65535;f=(b[404043]|0)+(g&255)&65535;g=TP(f)|0;a[808104]=g;h=TP(f+1|0)|0;a[808104]=h;f=TP((((h&255)<<8|g&255)&65535|c[202032])+(e[404046]|0)|0)|0;a[808104]=f;if((a[808082]&8)==0){g=a[808084]|0;h=f&255;i=(g&255)+h+(d[808120]|0)|0;a[808120]=(i&65280)>>>0>255|0;j=i&255;k=((i^h)&((g^f)&255^128))>>>7&255;l=k&1;a[808123]=l;a[808084]=j;a[808121]=j;a[808122]=j;return}g=b[404042]|0;h=g&255;i=g&240;g=((a[808120]|0)+(f&15)&255)+(h&15)&255;if((g&255)>9){m=g+6&15;n=i+16&65535}else{m=g;n=i}i=n+(f&-16&255)&65535;if((i&65535)>144){a[808120]=1;o=i+96&255&-16}else{a[808120]=0;o=i&255}i=o|m;j=i;k=((i^f)&(f^-128^h)&255)>>>7;l=k&1;a[808123]=l;a[808084]=j;a[808121]=j;a[808122]=j;return}function JM(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=b[404048]|0;f=a[(c[202034]|0)+(e&65535)|0]|0;a[808104]=f;b[404048]=e+1&65535;e=(b[404043]|0)+(f&255)&65535;f=TP(e)|0;a[808104]=f;g=TP(e+1|0)|0;a[808104]=g;e=TP(((g&255)<<8|f&255)&65535|c[202032])|0;a[808104]=e;if((a[808082]&8)==0){f=a[808084]|0;g=e&255;h=(f&255)+g+(d[808120]|0)|0;a[808120]=(h&65280)>>>0>255|0;i=h&255;j=((h^g)&((f^e)&255^128))>>>7&255;k=j&1;a[808123]=k;a[808084]=i;a[808121]=i;a[808122]=i;return}f=b[404042]|0;g=f&255;h=f&240;f=((a[808120]|0)+(e&15)&255)+(g&15)&255;if((f&255)>9){l=f+6&15;m=h+16&65535}else{l=f;m=h}h=m+(e&-16&255)&65535;if((h&65535)>144){a[808120]=1;n=h+96&255&-16}else{a[808120]=0;n=h&255}h=n|l;i=h;j=((h^e)&(e^-128^g)&255)>>>7;k=j&1;a[808123]=k;a[808084]=i;a[808121]=i;a[808122]=i;return}function JN(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=TP(c[202024]|0)|0;a[808104]=f;b[404048]=(b[404048]|0)+1&65535;g=(b[404044]|0)+(f&255)&65535;f=TP(g)|0;a[808104]=f;h=TP(g+1|0)|0;a[808104]=h;g=TP((c[202032]|0)+(e[404046]|0)+(((h&255)<<8|f&255)&65535)&16777215)|0;a[808104]=g;if((a[808082]&8)==0){f=a[808084]|0;h=g&255;i=(f&255)+h+(d[808120]|0)|0;a[808120]=(i&65280)>>>0>255|0;j=i&255;k=((i^h)&((f^g)&255^128))>>>7&255;l=k&1;a[808123]=l;a[808084]=j;a[808121]=j;a[808122]=j;return}f=b[404042]|0;h=f&255;i=f&240;f=((a[808120]|0)+(g&15)&255)+(h&15)&255;if((f&255)>9){m=f+6&15;n=i+16&65535}else{m=f;n=i}i=n+(g&-16&255)&65535;if((i&65535)>144){a[808120]=1;o=i+96&255&-16}else{a[808120]=0;o=i&255}i=o|m;j=i;k=((i^g)&(g^-128^h)&255)>>>7;l=k&1;a[808123]=l;a[808084]=j;a[808121]=j;a[808122]=j;return}function JO(){var d=0,f=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;b[404048]=d+1&65535;HY(0,((b[404043]|0)+(f&255)&65535)+(e[404045]|0)&65535);a[808104]=0;return}function JP(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=b[404048]|0;g=a[(c[202034]|0)+(f&65535)|0]|0;a[808104]=g;b[404048]=f+1&65535;f=TP(((b[404043]|0)+(g&255)&65535)+(e[404045]|0)&65535)|0;a[808104]=f;if((a[808082]&8)==0){g=a[808084]|0;h=f&255;i=(g&255)+h+(d[808120]|0)|0;a[808120]=(i&65280)>>>0>255|0;j=i&255;k=((i^h)&((g^f)&255^128))>>>7&255;l=k&1;a[808123]=l;a[808084]=j;a[808121]=j;a[808122]=j;return}g=b[404042]|0;h=g&255;i=g&240;g=((a[808120]|0)+(f&15)&255)+(h&15)&255;if((g&255)>9){m=g+6&15;n=i+16&65535}else{m=g;n=i}i=n+(f&-16&255)&65535;if((i&65535)>144){a[808120]=1;o=i+96&255&-16}else{a[808120]=0;o=i&255}i=o|m;j=i;k=((i^f)&(f^-128^h)&255)>>>7;l=k&1;a[808123]=l;a[808084]=j;a[808121]=j;a[808122]=j;return}function JQ(){var f=0,g=0,h=0;f=b[404048]|0;g=a[(c[202034]|0)+(f&65535)|0]|0;a[808104]=g;b[404048]=f+1&65535;f=((b[404043]|0)+(g&255)&65535)+(e[404045]|0)&65535;g=TP(f)|0;h=(d[808120]|0)<<8|g&255;a[808120]=g&1;g=(h&65535)>>>1&255;HY(g,f);a[808104]=g;a[808121]=g;a[808122]=g;return}function JR(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=b[404048]|0;g=a[(c[202034]|0)+(f&65535)|0]|0;a[808104]=g;b[404048]=f+1&65535;f=(b[404043]|0)+(g&255)&65535;g=TP(f)|0;a[808104]=g;h=TP(f+1|0)|0;a[808104]=h;i=TP(f+2|0)|0;a[808104]=i;f=TP((((h&255)<<8|g&255)&65535|(i&255)<<16)+(e[404046]|0)|0)|0;a[808104]=f;if((a[808082]&8)==0){i=a[808084]|0;g=f&255;h=(i&255)+g+(d[808120]|0)|0;a[808120]=(h&65280)>>>0>255|0;j=h&255;k=((h^g)&((i^f)&255^128))>>>7&255;l=k&1;a[808123]=l;a[808084]=j;a[808121]=j;a[808122]=j;return}i=b[404042]|0;g=i&255;h=i&240;i=((a[808120]|0)+(f&15)&255)+(g&15)&255;if((i&255)>9){m=i+6&15;n=h+16&65535}else{m=i;n=h}h=n+(f&-16&255)&65535;if((h&65535)>144){a[808120]=1;o=h+96&255&-16}else{a[808120]=0;o=h&255}h=o|m;j=h;k=((h^f)&(f^-128^g)&255)>>>7;l=k&1;a[808123]=l;a[808084]=j;a[808121]=j;a[808122]=j;return}function JS(){var b=0;b=a[808090|0]|0;a[808084|0]=b;a[808121|0]=b;a[808122|0]=b;return}function JT(){var c=0;c=b[404043]|0;b[404042]=c;a[808121|0]=c<<16>>16!=0|0;a[808122|0]=(c&65535)>>>8&255;return}function JU(){var b=0;b=(a[808092|0]|0)-1&255;a[808092|0]=b;a[808121|0]=b;a[808122|0]=b;return}function JV(){var d=0,e=0,f=0;d=a[808084|0]|0;e=b[404048]|0;f=a[(c[202034]|0)+(e&65535)|0]|0;a[808104]=f;b[404048]=e+1&65535;a[808121|0]=f&d;return}function JW(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=TP((k&65535|f)+(e[404046]|0)|0)|0;a[808104]=h;if((a[808082]&8)==0){f=a[808084]|0;k=h&255;j=(f&255)+k+(d[808120]|0)|0;a[808120]=(j&65280)>>>0>255|0;l=j&255;m=((j^k)&((f^h)&255^128))>>>7&255;n=m&1;a[808123]=n;a[808084]=l;a[808121]=l;a[808122]=l;return}f=b[404042]|0;k=f&255;j=f&240;f=((a[808120]|0)+(h&15)&255)+(k&15)&255;if((f&255)>9){o=f+6&15;p=j+16&65535}else{o=f;p=j}j=p+(h&-16&255)&65535;if((j&65535)>144){a[808120]=1;q=j+96&255&-16}else{a[808120]=0;q=j&255}j=q|o;l=j;m=((j^h)&(h^-128^k)&255)>>>7;n=m&1;a[808123]=n;a[808084]=l;a[808121]=l;a[808122]=l;return}function JX(){var c=0,d=0;c=(b[404044]|0)+1&65535;b[404044]=c;d=TP(c&65535)|0;a[808092|0]=d;a[808121|0]=d;a[808122|0]=d;a[808104]=d;return}function JY(){var d=0,e=0,f=0,g=0,h=0;d=c[202031]|0;e=c[202024]|0;f=TP(e)|0;a[808104]=f;g=TP((e&65535)+1&65535|e&-65536)|0;a[808104]=g;b[404048]=(b[404048]|0)+2&65535;e=c[202031]|0;h=((g&255)<<8|f&255)+(b[404045]|0)&65535|e;f=TP(h)|0;a[808104]=f;g=TP((h&65535)+1&65535|e&-65536)|0;a[808104]=g;HR((((g&255)<<8|f&255)&65535)+d|0);return}function JZ(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=TP((k&65535|f)+(e[404045]|0)|0)|0;a[808104]=h;if((a[808082]&8)==0){f=a[808084]|0;k=h&255;j=(f&255)+k+(d[808120]|0)|0;a[808120]=(j&65280)>>>0>255|0;l=j&255;m=((j^k)&((f^h)&255^128))>>>7&255;n=m&1;a[808123]=n;a[808084]=l;a[808121]=l;a[808122]=l;return}f=b[404042]|0;k=f&255;j=f&240;f=((a[808120]|0)+(h&15)&255)+(k&15)&255;if((f&255)>9){o=f+6&15;p=j+16&65535}else{o=f;p=j}j=p+(h&-16&255)&65535;if((j&65535)>144){a[808120]=1;q=j+96&255&-16}else{a[808120]=0;q=j&255}j=q|o;l=j;m=((j^h)&(h^-128^k)&255)>>>7;n=m&1;a[808123]=n;a[808084]=l;a[808121]=l;a[808122]=l;return}function J_(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=(k&65535|f)+(e[404045]|0)|0;f=TP(h)|0;k=(d[808120]|0)<<8|f&255;a[808120]=f&1;f=(k&65535)>>>1&255;HY(f,h);a[808104]=f;a[808121]=f;a[808122]=f;return}function J$(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=c[202034]|0;g=b[404048]|0;h=g&65535;i=a[f+(h+2)|0]|0;j=(d[f+(h+1)|0]|0)<<8|(d[f+h|0]|0)|(i&255)<<16;a[808104]=i;b[404048]=g+3&65535;g=TP(j+(e[404045]|0)|0)|0;a[808104]=g;if((a[808082]&8)==0){j=a[808084]|0;i=g&255;h=(j&255)+i+(d[808120]|0)|0;a[808120]=(h&65280)>>>0>255|0;k=h&255;l=((h^i)&((j^g)&255^128))>>>7&255;m=l&1;a[808123]=m;a[808084]=k;a[808121]=k;a[808122]=k;return}j=b[404042]|0;i=j&255;h=j&240;j=((a[808120]|0)+(g&15)&255)+(i&15)&255;if((j&255)>9){n=j+6&15;o=h+16&65535}else{n=j;o=h}h=o+(g&-16&255)&65535;if((h&65535)>144){a[808120]=1;p=h+96&255&-16}else{a[808120]=0;p=h&255}h=p|n;k=h;l=((h^g)&(g^-128^i)&255)>>>7;m=l&1;a[808123]=m;a[808084]=k;a[808121]=k;a[808122]=k;return}function J0(){var d=0,e=0,f=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=e;f=d+1&65535;b[404048]=f;d=f&65535;f=(e<<24>>24)+d|0;if(((f^d)&61440|0)==0){b[404048]=f&65535;return}else{HR((c[202031]|0)+(f&65535)|0);return}}function J1(){var d=0,f=0,g=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=((b[404043]|0)+(f&255)&65535)+(e[404045]|0)&65535;f=TP(d)|0;a[808104]=f;g=(((TP(d+1|0)|0)&255)<<8|f&255)&65535;HY(a[808084]|0,g|c[202032]);a[808104]=a[808084]|0;return}function J2(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[202031]|0;f=c[202034]|0;g=b[404048]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[808104]=i;i=g+2&65535;b[404048]=i;HR(((j&65535)+(i&65535)&65535)+e|0);return}function J3(){var d=0,e=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;b[404048]=d+1&65535;HY(a[808084|0]|0,(b[404044]|0)+(e&255)&65535);a[808104]=a[808084|0]|0;return}function J4(){var d=0,e=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;b[404048]=d+1&65535;HY(a[808092|0]|0,(b[404043]|0)+(e&255)&65535);a[808104]=a[808092|0]|0;return}function J5(){var d=0,e=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;b[404048]=d+1&65535;HY(a[808084|0]|0,(b[404043]|0)+(e&255)&65535);a[808104]=a[808084|0]|0;return}function J6(){var d=0,e=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;b[404048]=d+1&65535;HY(a[808090|0]|0,(b[404043]|0)+(e&255)&65535);a[808104]=a[808090|0]|0;return}function J7(){var d=0,e=0,f=0,g=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=e;b[404048]=d+1&65535;d=(b[404043]|0)+(e&255)&65535;e=TP(d)|0;a[808104]=e;f=TP(d+1|0)|0;a[808104]=f;g=TP(d+2|0)|0;a[808104]=g;HY(a[808084|0]|0,((f&255)<<8|e&255)&65535|(g&255)<<16);a[808104]=a[808084|0]|0;return}function J8(){var c=0,d=0;c=a[808080|0]|0;d=b[404044]|0;b[404044]=d-1&65535;HY(c,d&65535);a[808104]=a[808080|0]|0;return}function J9(){var e=0,f=0,g=0,h=0,i=0;e=c[202032]|0;f=c[202034]|0;g=b[404048]|0;h=g&65535;i=(d[f+(h+1)|0]|0)<<8|(d[f+h|0]|0);b[404048]=g+2&65535;HY(a[808092]|0,i&65535|e);a[808104]=a[808092]|0;return}function Ka(){var e=0,f=0,g=0,h=0,i=0;e=c[202032]|0;f=c[202034]|0;g=b[404048]|0;h=g&65535;i=(d[f+(h+1)|0]|0)<<8|(d[f+h|0]|0);b[404048]=g+2&65535;HY(a[808084]|0,i&65535|e);a[808104]=a[808084]|0;return}function Kb(){var e=0,f=0,g=0,h=0,i=0;e=c[202032]|0;f=c[202034]|0;g=b[404048]|0;h=g&65535;i=(d[f+(h+1)|0]|0)<<8|(d[f+h|0]|0);b[404048]=g+2&65535;HY(a[808090]|0,i&65535|e);a[808104]=a[808090]|0;return}function Kc(){var e=0,f=0,g=0,h=0;e=c[202034]|0;f=b[404048]|0;g=f&65535;h=(d[e+(g+1)|0]|0)<<8|(d[e+g|0]|0)|(d[e+(g+2)|0]|0)<<16;b[404048]=f+3&65535;HY(a[808084]|0,h);a[808104]=a[808084]|0;return}function Kd(){var d=0,e=0,f=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=e;f=d+1&65535;b[404048]=f;d=f&65535;f=(e<<24>>24)+d|0;if((a[808120]|0)!=0){return}if(((f^d)&61440|0)==0){b[404048]=f&65535;return}else{HR((c[202031]|0)+(f&65535)|0);return}}function Ke(){var d=0,f=0,g=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=(b[404043]|0)+(f&255)&65535;f=TP(d)|0;a[808104]=f;g=(((TP(d+1|0)|0)&255)<<8|f&255)&65535;HY(a[808084]|0,(g|c[202032])+(e[404046]|0)|0);a[808104]=a[808084]|0;return}function Kf(){var d=0,e=0,f=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=e;b[404048]=d+1&65535;d=(b[404043]|0)+(e&255)&65535;e=TP(d)|0;a[808104]=e;f=(((TP(d+1|0)|0)&255)<<8|e&255)&65535;HY(a[808084]|0,f|c[202032]);a[808104]=a[808084]|0;return}function Kg(){var d=0,f=0,g=0;d=TP(c[202024]|0)|0;a[808104]=d;b[404048]=(b[404048]|0)+1&65535;f=(b[404044]|0)+(d&255)&65535;d=TP(f)|0;a[808104]=d;g=(((TP(f+1|0)|0)&255)<<8|d&255)&65535;HY(a[808084]|0,(c[202032]|0)+(e[404046]|0)+g&16777215);a[808104]=a[808084]|0;return}function Kh(){var d=0,f=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;b[404048]=d+1&65535;HY(a[808092]|0,((b[404043]|0)+(f&255)&65535)+(e[404045]|0)&65535);a[808104]=a[808092]|0;return}function Ki(){var d=0,f=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;b[404048]=d+1&65535;HY(a[808084]|0,((b[404043]|0)+(f&255)&65535)+(e[404045]|0)&65535);a[808104]=a[808084]|0;return}function Kj(){var d=0,f=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;b[404048]=d+1&65535;HY(a[808090]|0,((b[404043]|0)+(f&255)&65535)+(e[404046]|0)&65535);a[808104]=a[808090]|0;return}function Kk(){a[808123|0]=0;return}function Kl(){var b=0;b=a[808092|0]|0;a[808084|0]=b;a[808121|0]=b;a[808122|0]=b;return}function Km(){var b=0;b=a[808090|0]|0;a[808092|0]=b;a[808121|0]=b;a[808122|0]=b;return}function Kn(){var b=0;b=a[808084|0]|0;a[808092|0]=b;a[808121|0]=b;a[808122|0]=b;return}function Ko(){var b=0;b=a[808084|0]|0;a[808090|0]=b;a[808121|0]=b;a[808122|0]=b;return}function Kp(){var b=0;b=a[808088|0]|0;a[808090|0]=b;a[808121|0]=b;a[808122|0]=b;return}function Kq(){var b=0;b=a[808092|0]|0;a[808090|0]=b;a[808121|0]=b;a[808122|0]=b;return}function Kr(){b[404044]=b[404045]|0;if((b[404041]&256)==0){return}a[808089|0]=1;return}function Ks(){var d=0,e=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=e;b[404048]=d+1&65535;a[808092|0]=e;a[808121|0]=e;a[808122|0]=e;return}function Kt(){var d=0,e=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=e;b[404048]=d+1&65535;a[808090|0]=e;a[808121|0]=e;a[808122|0]=e;return}function Ku(){var d=0,e=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=e;b[404048]=d+1&65535;a[808084|0]=e;a[808121|0]=e;a[808122|0]=e;return}function Kv(){var e=0,f=0,g=0;e=d[808092]|0;f=b[404048]|0;g=a[(c[202034]|0)+(f&65535)|0]|0;a[808104]=g;b[404048]=f+1&65535;f=e-(g&255)&65535;a[808120]=(f&65535)>>>15&255^1;g=f&255;a[808121]=g;a[808122]=g;return}function Kw(){var d=0,f=0,g=0,h=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=(b[404043]|0)+(f&255)&65535;f=TP(d)|0;a[808104]=f;g=TP(d+1|0)|0;a[808104]=g;h=TP(d+2|0)|0;a[808104]=h;HY(a[808084]|0,(((g&255)<<8|f&255)&65535|(h&255)<<16)+(e[404046]|0)|0);a[808104]=a[808084]|0;return}function Kx(){var f=0,g=0,h=0,i=0,j=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=(d[g+(i+1)|0]|0)<<8|(d[g+i|0]|0);b[404048]=h+2&65535;HY(a[808084]|0,(j&65535|f)+(e[404046]|0)|0);a[808104]=a[808084]|0;return}function Ky(){var e=0,f=0,g=0,h=0,i=0;e=c[202032]|0;f=c[202034]|0;g=b[404048]|0;h=g&65535;i=(d[f+(h+1)|0]|0)<<8|(d[f+h|0]|0);b[404048]=g+2&65535;HY(0,i&65535|e);a[808104]=0;return}function Kz(){var f=0,g=0,h=0,i=0,j=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=(d[g+(i+1)|0]|0)<<8|(d[g+i|0]|0);b[404048]=h+2&65535;HY(a[808084]|0,(j&65535|f)+(e[404045]|0)|0);a[808104]=a[808084]|0;return}function KA(){var f=0,g=0,h=0,i=0,j=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=(d[g+(i+1)|0]|0)<<8|(d[g+i|0]|0);b[404048]=h+2&65535;HY(0,(j&65535|f)+(e[404045]|0)|0);a[808104]=0;return}function KB(){var f=0,g=0,h=0,i=0;f=c[202034]|0;g=b[404048]|0;h=g&65535;i=(d[f+(h+1)|0]|0)<<8|(d[f+h|0]|0)|(d[f+(h+2)|0]|0)<<16;b[404048]=g+3&65535;HY(a[808084]|0,i+(e[404045]|0)|0);a[808104]=a[808084]|0;return}function KC(){var d=0,f=0,g=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=((b[404043]|0)+(f&255)&65535)+(e[404045]|0)&65535;f=TP(d)|0;a[808104]=f;g=TP(d+1|0)|0;a[808104]=g;d=TP(((g&255)<<8|f&255)&65535|c[202032])|0;a[808104]=d;a[808084]=d;a[808121]=d;a[808122]=d;return}function KD(){var d=0,e=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=e;b[404048]=d+1&65535;d=TP((b[404044]|0)+(e&255)&65535)|0;a[808104]=d;a[808084|0]=d;a[808121|0]=d;a[808122|0]=d;return}function KE(){var d=0,e=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=e;b[404048]=d+1&65535;d=TP((b[404043]|0)+(e&255)&65535)|0;a[808104]=d;a[808092|0]=d;a[808121|0]=d;a[808122|0]=d;return}function KF(){var d=0,e=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=e;b[404048]=d+1&65535;d=TP((b[404043]|0)+(e&255)&65535)|0;a[808104]=d;a[808084|0]=d;a[808121|0]=d;a[808122|0]=d;return}function KG(){var d=0,e=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=e;b[404048]=d+1&65535;d=TP((b[404043]|0)+(e&255)&65535)|0;a[808104]=d;a[808090|0]=d;a[808121|0]=d;a[808122|0]=d;return}function KH(){var d=0,e=0,f=0,g=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=e;b[404048]=d+1&65535;d=(b[404043]|0)+(e&255)&65535;e=TP(d)|0;a[808104]=e;f=TP(d+1|0)|0;a[808104]=f;g=TP(d+2|0)|0;a[808104]=g;d=TP(((f&255)<<8|e&255)&65535|(g&255)<<16)|0;a[808104]=d;a[808084|0]=d;a[808121|0]=d;a[808122|0]=d;return}function KI(){var d=0,e=0;d=(b[404044]|0)+1&65535;b[404044]=d;e=TP(d&65535)|0;a[808080|0]=e;a[808121|0]=e;a[808122|0]=e;c[202032]=(e&255)<<16;a[808104]=e;return}function KJ(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[202032]|0;f=c[202034]|0;g=b[404048]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[808104]=i;b[404048]=g+2&65535;g=TP(j&65535|e)|0;a[808104]=g;a[808092]=g;a[808121]=g;a[808122]=g;return}function KK(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[202032]|0;f=c[202034]|0;g=b[404048]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[808104]=i;b[404048]=g+2&65535;g=TP(j&65535|e)|0;a[808104]=g;a[808084]=g;a[808121]=g;a[808122]=g;return}function KL(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[202032]|0;f=c[202034]|0;g=b[404048]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[808104]=i;b[404048]=g+2&65535;g=TP(j&65535|e)|0;a[808104]=g;a[808090]=g;a[808121]=g;a[808122]=g;return}function KM(){var e=0,f=0,g=0,h=0,i=0;e=c[202034]|0;f=b[404048]|0;g=f&65535;h=a[e+(g+2)|0]|0;i=(d[e+(g+1)|0]|0)<<8|(d[e+g|0]|0)|(h&255)<<16;a[808104]=h;b[404048]=f+3&65535;f=TP(i)|0;a[808104]=f;a[808084]=f;a[808121]=f;a[808122]=f;return}function KN(){var d=0,e=0,f=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=e;f=d+1&65535;b[404048]=f;d=f&65535;f=(e<<24>>24)+d|0;if((a[808120]|0)==0){return}if(((f^d)&61440|0)==0){b[404048]=f&65535;return}else{HR((c[202031]|0)+(f&65535)|0);return}}function KO(){var d=0,f=0,g=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=(b[404043]|0)+(f&255)&65535;f=TP(d)|0;a[808104]=f;g=TP(d+1|0)|0;a[808104]=g;d=TP((((g&255)<<8|f&255)&65535|c[202032])+(e[404046]|0)|0)|0;a[808104]=d;a[808084]=d;a[808121]=d;a[808122]=d;return}function KP(){var d=0,e=0,f=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=e;b[404048]=d+1&65535;d=(b[404043]|0)+(e&255)&65535;e=TP(d)|0;a[808104]=e;f=TP(d+1|0)|0;a[808104]=f;d=TP(((f&255)<<8|e&255)&65535|c[202032])|0;a[808104]=d;a[808084]=d;a[808121]=d;a[808122]=d;return}function KQ(){var d=0,f=0,g=0;d=TP(c[202024]|0)|0;a[808104]=d;b[404048]=(b[404048]|0)+1&65535;f=(b[404044]|0)+(d&255)&65535;d=TP(f)|0;a[808104]=d;g=TP(f+1|0)|0;a[808104]=g;f=TP((c[202032]|0)+(e[404046]|0)+(((g&255)<<8|d&255)&65535)&16777215)|0;a[808104]=f;a[808084]=f;a[808121]=f;a[808122]=f;return}function KR(){var d=0,f=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=TP(((b[404043]|0)+(f&255)&65535)+(e[404045]|0)&65535)|0;a[808104]=d;a[808092]=d;a[808121]=d;a[808122]=d;return}function KS(){var d=0,f=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=TP(((b[404043]|0)+(f&255)&65535)+(e[404045]|0)&65535)|0;a[808104]=d;a[808084]=d;a[808121]=d;a[808122]=d;return}function KT(){var d=0,f=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=TP(((b[404043]|0)+(f&255)&65535)+(e[404046]|0)&65535)|0;a[808104]=d;a[808090]=d;a[808121]=d;a[808122]=d;return}function KU(){var d=0,f=0,g=0,h=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=(b[404043]|0)+(f&255)&65535;f=TP(d)|0;a[808104]=f;g=TP(d+1|0)|0;a[808104]=g;h=TP(d+2|0)|0;a[808104]=h;d=TP((((g&255)<<8|f&255)&65535|(h&255)<<16)+(e[404046]|0)|0)|0;a[808104]=d;a[808084]=d;a[808121]=d;a[808122]=d;return}function KV(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=TP((k&65535|f)+(e[404046]|0)|0)|0;a[808104]=h;a[808084]=h;a[808121]=h;a[808122]=h;return}function KW(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=TP((k&65535|f)+(e[404045]|0)|0)|0;a[808104]=h;a[808092]=h;a[808121]=h;a[808122]=h;return}function KX(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=TP((k&65535|f)+(e[404045]|0)|0)|0;a[808104]=h;a[808084]=h;a[808121]=h;a[808122]=h;return}function KY(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=TP((k&65535|f)+(e[404046]|0)|0)|0;a[808104]=h;a[808090]=h;a[808121]=h;a[808122]=h;return}function KZ(){var f=0,g=0,h=0,i=0,j=0;f=c[202034]|0;g=b[404048]|0;h=g&65535;i=a[f+(h+2)|0]|0;j=(d[f+(h+1)|0]|0)<<8|(d[f+h|0]|0)|(i&255)<<16;a[808104]=i;b[404048]=g+3&65535;g=TP(j+(e[404045]|0)|0)|0;a[808104]=g;a[808084]=g;a[808121]=g;a[808122]=g;return}function K_(){var b=0;b=(a[808092|0]|0)+1&255;a[808092|0]=b;a[808121|0]=b;a[808122|0]=b;return}function K$(){var b=0;b=(a[808090|0]|0)-1&255;a[808090|0]=b;a[808121|0]=b;a[808122|0]=b;return}function K0(){a[808141|0]=1;b[404048]=(b[404048]|0)-1&65535;return}function K1(){a[808082]=a[808082]&-9;return}function K2(){b[404048]=(b[404048]|0)-1&65535;c[202033]=c[202033]|4097;return}function K3(){var d=0,e=0,f=0,g=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=e;b[404048]=d+1&65535;d=~e;a[808082]=a[808082]&d;a[808120]=a[808120]&d;a[808123]=a[808123]&(d&255)>>>6;a[808122]=a[808122]&d;a[808121]=a[808121]|d&2^2;d=b[404041]|0;if((d&256)==0){f=d&255;g=d}else{e=d|48;b[404041]=e;f=e&255;g=e}if((f&16)!=0){a[808091|0]=0;a[808093|0]=0}if((g&256)!=0){c[202028]=149560;c[202029]=159800;return}f=g&255;g=(f&16|0)!=0;if((f&32|0)==0){if(g){c[202028]=151608;c[202029]=160312;return}else{c[202028]=152632;c[202029]=160568;return}}else{if(g){c[202028]=149560;c[202029]=159800;return}else{c[202028]=150584;c[202029]=160056;return}}}function K4(){var e=0,f=0,g=0;e=d[808084]|0;f=b[404048]|0;g=a[(c[202034]|0)+(f&65535)|0]|0;a[808104]=g;b[404048]=f+1&65535;f=e-(g&255)&65535;a[808120]=(f&65535)>>>15&255^1;g=f&255;a[808121]=g;a[808122]=g;return}function K5(){var f=0,g=0,h=0;f=b[404048]|0;g=a[(c[202034]|0)+(f&65535)|0]|0;a[808104]=g;b[404048]=f+1&65535;f=((b[404043]|0)+(g&255)&65535)+(e[404045]|0)&65535;g=TP(f)|0;a[808104]=g;h=TP(f+1|0)|0;a[808104]=h;f=TP(((h&255)<<8|g&255)&65535|c[202032])|0;a[808104]=f;g=(d[808084]|0)-(f&255)&65535;a[808120]=(g&65535)>>>15&255^1;f=g&255;a[808121]=f;a[808122]=f;return}function K6(){var e=0,f=0;e=b[404048]|0;f=a[(c[202034]|0)+(e&65535)|0]|0;a[808104]=f;b[404048]=e+1&65535;e=TP((b[404044]|0)+(f&255)&65535)|0;a[808104]=e;f=(d[808084]|0)-(e&255)&65535;a[808120]=(f&65535)>>>15&255^1;e=f&255;a[808121]=e;a[808122]=e;return}function K7(){var e=0,f=0;e=b[404048]|0;f=a[(c[202034]|0)+(e&65535)|0]|0;a[808104]=f;b[404048]=e+1&65535;e=TP((b[404043]|0)+(f&255)&65535)|0;a[808104]=e;f=(d[808092]|0)-(e&255)&65535;a[808120]=(f&65535)>>>15&255^1;e=f&255;a[808121]=e;a[808122]=e;return}function K8(){var e=0,f=0;e=b[404048]|0;f=a[(c[202034]|0)+(e&65535)|0]|0;a[808104]=f;b[404048]=e+1&65535;e=TP((b[404043]|0)+(f&255)&65535)|0;a[808104]=e;f=(d[808084]|0)-(e&255)&65535;a[808120]=(f&65535)>>>15&255^1;e=f&255;a[808121]=e;a[808122]=e;return}function K9(){var d=0,e=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=e;b[404048]=d+1&65535;d=(b[404043]|0)+(e&255)&65535;e=(TP(d)|0)-1&255;HY(e,d);a[808104]=e;a[808121|0]=e;a[808122|0]=e;return}function La(){var e=0,f=0,g=0,h=0;e=b[404048]|0;f=a[(c[202034]|0)+(e&65535)|0]|0;a[808104]=f;b[404048]=e+1&65535;e=(b[404043]|0)+(f&255)&65535;f=TP(e)|0;a[808104]=f;g=TP(e+1|0)|0;a[808104]=g;h=TP(e+2|0)|0;a[808104]=h;e=TP(((g&255)<<8|f&255)&65535|(h&255)<<16)|0;a[808104]=e;h=(d[808084]|0)-(e&255)&65535;a[808120]=(h&65535)>>>15&255^1;e=h&255;a[808121]=e;a[808122]=e;return}function Lb(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[202032]|0;f=c[202034]|0;g=b[404048]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[808104]=i;b[404048]=g+2&65535;g=TP(j&65535|e)|0;a[808104]=g;e=(d[808092]|0)-(g&255)&65535;a[808120]=(e&65535)>>>15&255^1;g=e&255;a[808121]=g;a[808122]=g;return}function Lc(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[202032]|0;f=c[202034]|0;g=b[404048]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[808104]=i;b[404048]=g+2&65535;g=TP(j&65535|e)|0;a[808104]=g;e=(d[808084]|0)-(g&255)&65535;a[808120]=(e&65535)>>>15&255^1;g=e&255;a[808121]=g;a[808122]=g;return}function Ld(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[202032]|0;f=c[202034]|0;g=b[404048]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[808104]=i;b[404048]=g+2&65535;g=j&65535|e;e=(TP(g)|0)-1&255;HY(e,g);a[808104]=e;a[808121]=e;a[808122]=e;return}function Le(){var e=0,f=0,g=0,h=0,i=0;e=c[202034]|0;f=b[404048]|0;g=f&65535;h=a[e+(g+2)|0]|0;i=(d[e+(g+1)|0]|0)<<8|(d[e+g|0]|0)|(h&255)<<16;a[808104]=h;b[404048]=f+3&65535;f=TP(i)|0;a[808104]=f;i=(d[808084]|0)-(f&255)&65535;a[808120]=(i&65535)>>>15&255^1;f=i&255;a[808121]=f;a[808122]=f;return}function Lf(){var d=0,e=0,f=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=e;f=d+1&65535;b[404048]=f;d=f&65535;f=(e<<24>>24)+d|0;if((a[808121]|0)==0){return}if(((f^d)&61440|0)==0){b[404048]=f&65535;return}else{HR((c[202031]|0)+(f&65535)|0);return}}function Lg(){var f=0,g=0,h=0;f=b[404048]|0;g=a[(c[202034]|0)+(f&65535)|0]|0;a[808104]=g;b[404048]=f+1&65535;f=(b[404043]|0)+(g&255)&65535;g=TP(f)|0;a[808104]=g;h=TP(f+1|0)|0;a[808104]=h;f=TP((((h&255)<<8|g&255)&65535|c[202032])+(e[404046]|0)|0)|0;a[808104]=f;g=(d[808084]|0)-(f&255)&65535;a[808120]=(g&65535)>>>15&255^1;f=g&255;a[808121]=f;a[808122]=f;return}function Lh(){var e=0,f=0,g=0;e=b[404048]|0;f=a[(c[202034]|0)+(e&65535)|0]|0;a[808104]=f;b[404048]=e+1&65535;e=(b[404043]|0)+(f&255)&65535;f=TP(e)|0;a[808104]=f;g=TP(e+1|0)|0;a[808104]=g;e=TP(((g&255)<<8|f&255)&65535|c[202032])|0;a[808104]=e;f=(d[808084]|0)-(e&255)&65535;a[808120]=(f&65535)>>>15&255^1;e=f&255;a[808121]=e;a[808122]=e;return}function Li(){var f=0,g=0,h=0;f=TP(c[202024]|0)|0;a[808104]=f;b[404048]=(b[404048]|0)+1&65535;g=(b[404044]|0)+(f&255)&65535;f=TP(g)|0;a[808104]=f;h=TP(g+1|0)|0;a[808104]=h;g=TP((c[202032]|0)+(e[404046]|0)+(((h&255)<<8|f&255)&65535)&16777215)|0;a[808104]=g;f=(d[808084]|0)-(g&255)&65535;a[808120]=(f&65535)>>>15&255^1;g=f&255;a[808121]=g;a[808122]=g;return}function Lj(){var d=0,f=0,g=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=(b[404043]|0)+(f&255)&65535;f=TP(d)|0;a[808104]=f;g=(((TP(d+1|0)|0)&255)<<8|f&255)&65535;f=g|c[202032];g=(e[404044]|0)-1|0;HY((f&65535)>>>8&255,(g&65535)+1&65535|g&-65536);d=f&255;HY(d,g);b[404044]=(b[404044]|0)-2&65535;a[808104]=d;return}function Lk(){var f=0,g=0;f=b[404048]|0;g=a[(c[202034]|0)+(f&65535)|0]|0;a[808104]=g;b[404048]=f+1&65535;f=TP(((b[404043]|0)+(g&255)&65535)+(e[404045]|0)&65535)|0;a[808104]=f;g=(d[808084]|0)-(f&255)&65535;a[808120]=(g&65535)>>>15&255^1;f=g&255;a[808121]=f;a[808122]=f;return}function Ll(){var d=0,f=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=((b[404043]|0)+(f&255)&65535)+(e[404045]|0)&65535;f=(TP(d)|0)-1&255;HY(f,d);a[808104]=f;a[808121]=f;a[808122]=f;return}function Lm(){var f=0,g=0,h=0,i=0;f=b[404048]|0;g=a[(c[202034]|0)+(f&65535)|0]|0;a[808104]=g;b[404048]=f+1&65535;f=(b[404043]|0)+(g&255)&65535;g=TP(f)|0;a[808104]=g;h=TP(f+1|0)|0;a[808104]=h;i=TP(f+2|0)|0;a[808104]=i;f=TP((((h&255)<<8|g&255)&65535|(i&255)<<16)+(e[404046]|0)|0)|0;a[808104]=f;i=(d[808084]|0)-(f&255)&65535;a[808120]=(i&65535)>>>15&255^1;f=i&255;a[808121]=f;a[808122]=f;return}function Ln(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=TP((k&65535|f)+(e[404046]|0)|0)|0;a[808104]=h;f=(d[808084]|0)-(h&255)&65535;a[808120]=(f&65535)>>>15&255^1;h=f&255;a[808121]=h;a[808122]=h;return}function Lo(){var c=0,d=0;c=a[808090|0]|0;d=b[404044]|0;b[404044]=d-1&65535;HY(c,d&65535);a[808104]=a[808090|0]|0;return}function Lp(){var e=0,f=0,g=0,h=0,i=0;e=c[202034]|0;f=b[404048]|0;g=f&65535;h=a[e+(g+1)|0]|0;i=(h&255)<<8|(d[e+g|0]|0);a[808104]=h;b[404048]=f+2&65535;f=i&65535;i=TP(f)|0;a[808104]=i;h=TP(f+1|0)|0;a[808104]=h;g=TP(f+2|0)|0;a[808104]=g;HR(((h&255)<<8|i&255)&65535|(g&255)<<16);return}function Lq(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=TP((k&65535|f)+(e[404045]|0)|0)|0;a[808104]=h;f=(d[808084]|0)-(h&255)&65535;a[808120]=(f&65535)>>>15&255^1;h=f&255;a[808121]=h;a[808122]=h;return}function Lr(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=(k&65535|f)+(e[404045]|0)|0;f=(TP(h)|0)-1&255;HY(f,h);a[808104]=f;a[808121]=f;a[808122]=f;return}function Ls(){var f=0,g=0,h=0,i=0,j=0;f=c[202034]|0;g=b[404048]|0;h=g&65535;i=a[f+(h+2)|0]|0;j=(d[f+(h+1)|0]|0)<<8|(d[f+h|0]|0)|(i&255)<<16;a[808104]=i;b[404048]=g+3&65535;g=TP(j+(e[404045]|0)|0)|0;a[808104]=g;j=(d[808084]|0)-(g&255)&65535;a[808120]=(j&65535)>>>15&255^1;g=j&255;a[808121]=g;a[808122]=g;return}function Lt(){return}function Lu(){var b=0,c=0;b=a[808084]|0;c=a[808085|0]|0;a[808084]=c;a[808085|0]=b;a[808121]=c;a[808122]=c;return}function Lv(){var b=0;b=(a[808090|0]|0)+1&255;a[808090|0]=b;a[808121|0]=b;a[808122|0]=b;return}function Lw(){var e=0,f=0,g=0;e=d[808090]|0;f=b[404048]|0;g=a[(c[202034]|0)+(f&65535)|0]|0;a[808104]=g;b[404048]=f+1&65535;f=e-(g&255)&65535;a[808120]=(f&65535)>>>15&255^1;g=f&255;a[808121]=g;a[808122]=g;return}function Lx(){var d=0,e=0,f=0,g=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=e;b[404048]=d+1&65535;a[808082]=a[808082]|e;a[808120]=a[808120]|e&1;a[808123]=a[808123]|(e&255)>>>6&1;a[808122]=a[808122]|e;if((e&2)!=0){a[808121]=0}e=b[404041]|0;if((e&256)==0){f=e&255;g=e}else{d=e|48;b[404041]=d;f=d&255;g=d}if((f&16)!=0){a[808091|0]=0;a[808093|0]=0}if((g&256)!=0){c[202028]=149560;c[202029]=159800;return}f=g&255;g=(f&16|0)!=0;if((f&32|0)==0){if(g){c[202028]=151608;c[202029]=160312;return}else{c[202028]=152632;c[202029]=160568;return}}else{if(g){c[202028]=149560;c[202029]=159800;return}else{c[202028]=150584;c[202029]=160056;return}}}function Ly(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=b[404048]|0;f=a[(c[202034]|0)+(e&65535)|0]|0;a[808104]=f;b[404048]=e+1&65535;if((a[808082]&8)==0){e=a[808084]|0;g=((e&255)+~(f&255)&65535)+(d[808120]|0)&65535;a[808120]=(g&65535)>>>15&255^1;h=g&255;i=h;j=(h^e)&(e^f);k=(j&255)>>>7;a[808123]=k;a[808084]=i;a[808121]=i;a[808122]=i;return}e=b[404042]|0;h=e&255;g=((h&15)-(f&15)&255)-((a[808120]|0)==0)&255;l=(e&240)-(f&-16&255)&65535;if((g&255)>15){m=g+10&15;n=l-16&65535}else{m=g;n=l}if((n&65535)>240){a[808120]=0;o=n+160&255&-16}else{a[808120]=1;o=n&255}n=o|m;i=n;j=(n^h)&(h^f);k=(j&255)>>>7;a[808123]=k;a[808084]=i;a[808121]=i;a[808122]=i;return}function Lz(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=b[404048]|0;g=a[(c[202034]|0)+(f&65535)|0]|0;a[808104]=g;b[404048]=f+1&65535;f=((b[404043]|0)+(g&255)&65535)+(e[404045]|0)&65535;g=TP(f)|0;a[808104]=g;h=TP(f+1|0)|0;a[808104]=h;f=TP(((h&255)<<8|g&255)&65535|c[202032])|0;a[808104]=f;if((a[808082]&8)==0){g=a[808084]|0;h=((g&255)+~(f&255)&65535)+(d[808120]|0)&65535;a[808120]=(h&65535)>>>15&255^1;i=h&255;j=i;k=(i^g)&(g^f);l=(k&255)>>>7;a[808123]=l;a[808084]=j;a[808121]=j;a[808122]=j;return}g=b[404042]|0;i=g&255;h=((i&15)-(f&15)&255)-((a[808120]|0)==0)&255;m=(g&240)-(f&-16&255)&65535;if((h&255)>15){n=h+10&15;o=m-16&65535}else{n=h;o=m}if((o&65535)>240){a[808120]=0;p=o+160&255&-16}else{a[808120]=1;p=o&255}o=p|n;j=o;k=(o^i)&(i^f);l=(k&255)>>>7;a[808123]=l;a[808084]=j;a[808121]=j;a[808122]=j;return}function LA(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=b[404048]|0;f=a[(c[202034]|0)+(e&65535)|0]|0;a[808104]=f;b[404048]=e+1&65535;e=TP((b[404044]|0)+(f&255)&65535)|0;a[808104]=e;if((a[808082]&8)==0){f=a[808084]|0;g=((f&255)+~(e&255)&65535)+(d[808120]|0)&65535;a[808120]=(g&65535)>>>15&255^1;h=g&255;i=h;j=(h^f)&(f^e);k=(j&255)>>>7;a[808123]=k;a[808084]=i;a[808121]=i;a[808122]=i;return}f=b[404042]|0;h=f&255;g=((h&15)-(e&15)&255)-((a[808120]|0)==0)&255;l=(f&240)-(e&-16&255)&65535;if((g&255)>15){m=g+10&15;n=l-16&65535}else{m=g;n=l}if((n&65535)>240){a[808120]=0;o=n+160&255&-16}else{a[808120]=1;o=n&255}n=o|m;i=n;j=(n^h)&(h^e);k=(j&255)>>>7;a[808123]=k;a[808084]=i;a[808121]=i;a[808122]=i;return}function LB(){var e=0,f=0;e=b[404048]|0;f=a[(c[202034]|0)+(e&65535)|0]|0;a[808104]=f;b[404048]=e+1&65535;e=TP((b[404043]|0)+(f&255)&65535)|0;a[808104]=e;f=(d[808090]|0)-(e&255)&65535;a[808120]=(f&65535)>>>15&255^1;e=f&255;a[808121]=e;a[808122]=e;return}function LC(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=b[404048]|0;f=a[(c[202034]|0)+(e&65535)|0]|0;a[808104]=f;b[404048]=e+1&65535;e=TP((b[404043]|0)+(f&255)&65535)|0;a[808104]=e;if((a[808082]&8)==0){f=a[808084]|0;g=((f&255)+~(e&255)&65535)+(d[808120]|0)&65535;a[808120]=(g&65535)>>>15&255^1;h=g&255;i=h;j=(h^f)&(f^e);k=(j&255)>>>7;a[808123]=k;a[808084]=i;a[808121]=i;a[808122]=i;return}f=b[404042]|0;h=f&255;g=((h&15)-(e&15)&255)-((a[808120]|0)==0)&255;l=(f&240)-(e&-16&255)&65535;if((g&255)>15){m=g+10&15;n=l-16&65535}else{m=g;n=l}if((n&65535)>240){a[808120]=0;o=n+160&255&-16}else{a[808120]=1;o=n&255}n=o|m;i=n;j=(n^h)&(h^e);k=(j&255)>>>7;a[808123]=k;a[808084]=i;a[808121]=i;a[808122]=i;return}function LD(){var d=0,e=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=e;b[404048]=d+1&65535;d=(b[404043]|0)+(e&255)&65535;e=(TP(d)|0)+1&255;HY(e,d);a[808104]=e;a[808121|0]=e;a[808122|0]=e;return}function LE(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=b[404048]|0;f=a[(c[202034]|0)+(e&65535)|0]|0;a[808104]=f;b[404048]=e+1&65535;e=(b[404043]|0)+(f&255)&65535;f=TP(e)|0;a[808104]=f;g=TP(e+1|0)|0;a[808104]=g;h=TP(e+2|0)|0;a[808104]=h;e=TP(((g&255)<<8|f&255)&65535|(h&255)<<16)|0;a[808104]=e;if((a[808082]&8)==0){h=a[808084]|0;f=((h&255)+~(e&255)&65535)+(d[808120]|0)&65535;a[808120]=(f&65535)>>>15&255^1;g=f&255;i=g;j=(g^h)&(h^e);k=(j&255)>>>7;a[808123]=k;a[808084]=i;a[808121]=i;a[808122]=i;return}h=b[404042]|0;g=h&255;f=((g&15)-(e&15)&255)-((a[808120]|0)==0)&255;l=(h&240)-(e&-16&255)&65535;if((f&255)>15){m=f+10&15;n=l-16&65535}else{m=f;n=l}if((n&65535)>240){a[808120]=0;o=n+160&255&-16}else{a[808120]=1;o=n&255}n=o|m;i=n;j=(n^g)&(g^e);k=(j&255)>>>7;a[808123]=k;a[808084]=i;a[808121]=i;a[808122]=i;return}function LF(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[202032]|0;f=c[202034]|0;g=b[404048]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[808104]=i;b[404048]=g+2&65535;g=TP(j&65535|e)|0;a[808104]=g;e=(d[808090]|0)-(g&255)&65535;a[808120]=(e&65535)>>>15&255^1;g=e&255;a[808121]=g;a[808122]=g;return}function LG(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;e=c[202032]|0;f=c[202034]|0;g=b[404048]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|d[f+h|0];a[808104]=i;b[404048]=g+2&65535;g=TP(j&65535|e)|0;a[808104]=g;if((a[808082]&8)==0){e=a[808084]|0;j=((e&255)+~(g&255)&65535)+(d[808120]|0)&65535;a[808120]=(j&65535)>>>15&255^1;i=j&255;k=i;l=(i^e)&(e^g);m=(l&255)>>>7;a[808123]=m;a[808084]=k;a[808121]=k;a[808122]=k;return}e=b[404042]|0;i=e&255;j=((i&15)-(g&15)&255)-((a[808120]|0)==0)&255;h=(e&240)-(g&-16&255)&65535;if((j&255)>15){n=j+10&15;o=h-16&65535}else{n=j;o=h}if((o&65535)>240){a[808120]=0;p=o+160&255&-16}else{a[808120]=1;p=o&255}o=p|n;k=o;l=(o^i)&(i^g);m=(l&255)>>>7;a[808123]=m;a[808084]=k;a[808121]=k;a[808122]=k;return}function LH(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[202032]|0;f=c[202034]|0;g=b[404048]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[808104]=i;b[404048]=g+2&65535;g=j&65535|e;e=(TP(g)|0)+1&255;HY(e,g);a[808104]=e;a[808121]=e;a[808122]=e;return}function LI(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=c[202034]|0;f=b[404048]|0;g=f&65535;h=a[e+(g+2)|0]|0;i=d[e+(g+1)|0]<<8|d[e+g|0]|(h&255)<<16;a[808104]=h;b[404048]=f+3&65535;f=TP(i)|0;a[808104]=f;if((a[808082]&8)==0){i=a[808084]|0;h=((i&255)+~(f&255)&65535)+(d[808120]|0)&65535;a[808120]=(h&65535)>>>15&255^1;g=h&255;j=g;k=(g^i)&(i^f);l=(k&255)>>>7;a[808123]=l;a[808084]=j;a[808121]=j;a[808122]=j;return}i=b[404042]|0;g=i&255;h=((g&15)-(f&15)&255)-((a[808120]|0)==0)&255;e=(i&240)-(f&-16&255)&65535;if((h&255)>15){m=h+10&15;n=e-16&65535}else{m=h;n=e}if((n&65535)>240){a[808120]=0;o=n+160&255&-16}else{a[808120]=1;o=n&255}n=o|m;j=n;k=(n^g)&(g^f);l=(k&255)>>>7;a[808123]=l;a[808084]=j;a[808121]=j;a[808122]=j;return}function LJ(){a[808082]=a[808082]|8;return}function LK(){var d=0,e=0,f=0,g=0;d=a[808120]|0;a[808120]=a[808083|0]&1;a[808083|0]=d;d=b[404041]|0;if((d&256)==0){e=d&255;f=d}else{g=d|48;b[404041]=g;a[808089|0]=1;e=g&255;f=g}if((e&16)!=0){a[808091|0]=0;a[808093|0]=0}if((f&256)!=0){c[202028]=149560;c[202029]=159800;return}e=f&255;f=(e&16|0)!=0;if((e&32|0)==0){if(f){c[202028]=151608;c[202029]=160312;return}else{c[202028]=152632;c[202029]=160568;return}}else{if(f){c[202028]=149560;c[202029]=159800;return}else{c[202028]=150584;c[202029]=160056;return}}}function LL(){var d=0,e=0,f=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=e;f=d+1&65535;b[404048]=f;d=f&65535;f=(e<<24>>24)+d|0;if((a[808121]|0)!=0){return}if(((f^d)&61440|0)==0){b[404048]=f&65535;return}else{HR((c[202031]|0)+(f&65535)|0);return}}function LM(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=b[404048]|0;g=a[(c[202034]|0)+(f&65535)|0]|0;a[808104]=g;b[404048]=f+1&65535;f=(b[404043]|0)+(g&255)&65535;g=TP(f)|0;a[808104]=g;h=TP(f+1|0)|0;a[808104]=h;f=TP((((h&255)<<8|g&255)&65535|c[202032])+(e[404046]|0)|0)|0;a[808104]=f;if((a[808082]&8)==0){g=a[808084]|0;h=((g&255)+~(f&255)&65535)+(d[808120]|0)&65535;a[808120]=(h&65535)>>>15&255^1;i=h&255;j=i;k=(i^g)&(g^f);l=(k&255)>>>7;a[808123]=l;a[808084]=j;a[808121]=j;a[808122]=j;return}g=b[404042]|0;i=g&255;h=((i&15)-(f&15)&255)-((a[808120]|0)==0)&255;m=(g&240)-(f&-16&255)&65535;if((h&255)>15){n=h+10&15;o=m-16&65535}else{n=h;o=m}if((o&65535)>240){a[808120]=0;p=o+160&255&-16}else{a[808120]=1;p=o&255}o=p|n;j=o;k=(o^i)&(i^f);l=(k&255)>>>7;a[808123]=l;a[808084]=j;a[808121]=j;a[808122]=j;return}function LN(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=b[404048]|0;f=a[(c[202034]|0)+(e&65535)|0]|0;a[808104]=f;b[404048]=e+1&65535;e=(b[404043]|0)+(f&255)&65535;f=TP(e)|0;a[808104]=f;g=TP(e+1|0)|0;a[808104]=g;e=TP(((g&255)<<8|f&255)&65535|c[202032])|0;a[808104]=e;if((a[808082]&8)==0){f=a[808084]|0;g=((f&255)+~(e&255)&65535)+(d[808120]|0)&65535;a[808120]=(g&65535)>>>15&255^1;h=g&255;i=h;j=(h^f)&(f^e);k=(j&255)>>>7;a[808123]=k;a[808084]=i;a[808121]=i;a[808122]=i;return}f=b[404042]|0;h=f&255;g=((h&15)-(e&15)&255)-((a[808120]|0)==0)&255;l=(f&240)-(e&-16&255)&65535;if((g&255)>15){m=g+10&15;n=l-16&65535}else{m=g;n=l}if((n&65535)>240){a[808120]=0;o=n+160&255&-16}else{a[808120]=1;o=n&255}n=o|m;i=n;j=(n^h)&(h^e);k=(j&255)>>>7;a[808123]=k;a[808084]=i;a[808121]=i;a[808122]=i;return}function LO(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=TP(c[202024]|0)|0;a[808104]=f;b[404048]=(b[404048]|0)+1&65535;g=(b[404044]|0)+(f&255)&65535;f=TP(g)|0;a[808104]=f;h=TP(g+1|0)|0;a[808104]=h;g=TP((c[202032]|0)+(e[404046]|0)+(((h&255)<<8|f&255)&65535)&16777215)|0;a[808104]=g;if((a[808082]&8)==0){f=a[808084]|0;h=((f&255)+~(g&255)&65535)+(d[808120]|0)&65535;a[808120]=(h&65535)>>>15&255^1;i=h&255;j=i;k=(i^f)&(f^g);l=(k&255)>>>7;a[808123]=l;a[808084]=j;a[808121]=j;a[808122]=j;return}f=b[404042]|0;i=f&255;h=((i&15)-(g&15)&255)-((a[808120]|0)==0)&255;m=(f&240)-(g&-16&255)&65535;if((h&255)>15){n=h+10&15;o=m-16&65535}else{n=h;o=m}if((o&65535)>240){a[808120]=0;p=o+160&255&-16}else{a[808120]=1;p=o&255}o=p|n;j=o;k=(o^i)&(i^g);l=(k&255)>>>7;a[808123]=l;a[808084]=j;a[808121]=j;a[808122]=j;return}function LP(){var f=0,g=0,h=0,i=0,j=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=(d[g+(i+1)|0]|0)<<8|(d[g+i|0]|0);b[404048]=h+2&65535;h=j&65535|f;f=(e[404044]|0)-1|0;HY((h&65535)>>>8&255,(f&65535)+1&65535|f&-65536);j=h&255;HY(j,f);b[404044]=(b[404044]|0)-2&65535;a[808104]=j;return}function LQ(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=b[404048]|0;g=a[(c[202034]|0)+(f&65535)|0]|0;a[808104]=g;b[404048]=f+1&65535;f=TP(((b[404043]|0)+(g&255)&65535)+(e[404045]|0)&65535)|0;a[808104]=f;if((a[808082]&8)==0){g=a[808084]|0;h=((g&255)+~(f&255)&65535)+(d[808120]|0)&65535;a[808120]=(h&65535)>>>15&255^1;i=h&255;j=i;k=(i^g)&(g^f);l=(k&255)>>>7;a[808123]=l;a[808084]=j;a[808121]=j;a[808122]=j;return}g=b[404042]|0;i=g&255;h=((i&15)-(f&15)&255)-((a[808120]|0)==0)&255;m=(g&240)-(f&-16&255)&65535;if((h&255)>15){n=h+10&15;o=m-16&65535}else{n=h;o=m}if((o&65535)>240){a[808120]=0;p=o+160&255&-16}else{a[808120]=1;p=o&255}o=p|n;j=o;k=(o^i)&(i^f);l=(k&255)>>>7;a[808123]=l;a[808084]=j;a[808121]=j;a[808122]=j;return}function LR(){var d=0,f=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=((b[404043]|0)+(f&255)&65535)+(e[404045]|0)&65535;f=(TP(d)|0)+1&255;HY(f,d);a[808104]=f;a[808121]=f;a[808122]=f;return}function LS(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=b[404048]|0;g=a[(c[202034]|0)+(f&65535)|0]|0;a[808104]=g;b[404048]=f+1&65535;f=(b[404043]|0)+(g&255)&65535;g=TP(f)|0;a[808104]=g;h=TP(f+1|0)|0;a[808104]=h;i=TP(f+2|0)|0;a[808104]=i;f=TP((((h&255)<<8|g&255)&65535|(i&255)<<16)+(e[404046]|0)|0)|0;a[808104]=f;if((a[808082]&8)==0){i=a[808084]|0;g=((i&255)+~(f&255)&65535)+(d[808120]|0)&65535;a[808120]=(g&65535)>>>15&255^1;h=g&255;j=h;k=(h^i)&(i^f);l=(k&255)>>>7;a[808123]=l;a[808084]=j;a[808121]=j;a[808122]=j;return}i=b[404042]|0;h=i&255;g=((h&15)-(f&15)&255)-((a[808120]|0)==0)&255;m=(i&240)-(f&-16&255)&65535;if((g&255)>15){n=g+10&15;o=m-16&65535}else{n=g;o=m}if((o&65535)>240){a[808120]=0;p=o+160&255&-16}else{a[808120]=1;p=o&255}o=p|n;j=o;k=(o^h)&(h^f);l=(k&255)>>>7;a[808123]=l;a[808084]=j;a[808121]=j;a[808122]=j;return}function LT(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|d[g+i|0];a[808104]=j;b[404048]=h+2&65535;h=TP((k&65535|f)+(e[404046]|0)|0)|0;a[808104]=h;if((a[808082]&8)==0){f=a[808084]|0;k=((f&255)+~(h&255)&65535)+(d[808120]|0)&65535;a[808120]=(k&65535)>>>15&255^1;j=k&255;l=j;m=(j^f)&(f^h);n=(m&255)>>>7;a[808123]=n;a[808084]=l;a[808121]=l;a[808122]=l;return}f=b[404042]|0;j=f&255;k=((j&15)-(h&15)&255)-((a[808120]|0)==0)&255;i=(f&240)-(h&-16&255)&65535;if((k&255)>15){o=k+10&15;p=i-16&65535}else{o=k;p=i}if((p&65535)>240){a[808120]=0;q=p+160&255&-16}else{a[808120]=1;q=p&255}p=q|o;l=p;m=(p^j)&(j^h);n=(m&255)>>>7;a[808123]=n;a[808084]=l;a[808121]=l;a[808122]=l;return}function LU(){var c=0,d=0;c=(b[404044]|0)+1&65535;b[404044]=c;d=TP(c&65535)|0;a[808090|0]=d;a[808121|0]=d;a[808122|0]=d;a[808104]=d;return}function LV(){var d=0,f=0,g=0,h=0;d=c[202024]|0;f=TP(d)|0;a[808104]=f;g=TP((d&65535)+1&65535|d&-65536)|0;a[808104]=g;b[404048]=(b[404048]|0)+2&65535;d=c[202031]|0;h=((g&255)<<8|f&255)+(b[404045]|0)&65535|d;f=TP(h)|0;a[808104]=f;g=TP((h&65535)+1&65535|d&-65536)|0;a[808104]=g;d=(b[404048]|0)-1&65535;h=(e[404044]|0)-1|0;HY((d&65535)>>>8&255,(h&65535)+1&65535|h&-65536);HY(d&255,h);b[404044]=(b[404044]|0)-2&65535;HR((c[202031]|0)+(((g&255)<<8|f&255)&65535)|0);return}function LW(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|d[g+i|0];a[808104]=j;b[404048]=h+2&65535;h=TP((k&65535|f)+(e[404045]|0)|0)|0;a[808104]=h;if((a[808082]&8)==0){f=a[808084]|0;k=((f&255)+~(h&255)&65535)+(d[808120]|0)&65535;a[808120]=(k&65535)>>>15&255^1;j=k&255;l=j;m=(j^f)&(f^h);n=(m&255)>>>7;a[808123]=n;a[808084]=l;a[808121]=l;a[808122]=l;return}f=b[404042]|0;j=f&255;k=((j&15)-(h&15)&255)-((a[808120]|0)==0)&255;i=(f&240)-(h&-16&255)&65535;if((k&255)>15){o=k+10&15;p=i-16&65535}else{o=k;p=i}if((p&65535)>240){a[808120]=0;q=p+160&255&-16}else{a[808120]=1;q=p&255}p=q|o;l=p;m=(p^j)&(j^h);n=(m&255)>>>7;a[808123]=n;a[808084]=l;a[808121]=l;a[808122]=l;return}function LX(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=(k&65535|f)+(e[404045]|0)|0;f=(TP(h)|0)+1&255;HY(f,h);a[808104]=f;a[808121]=f;a[808122]=f;return}function LY(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=c[202034]|0;g=b[404048]|0;h=g&65535;i=a[f+(h+2)|0]|0;j=d[f+(h+1)|0]<<8|d[f+h|0]|(i&255)<<16;a[808104]=i;b[404048]=g+3&65535;g=TP(j+(e[404045]|0)|0)|0;a[808104]=g;if((a[808082]&8)==0){j=a[808084]|0;i=((j&255)+~(g&255)&65535)+(d[808120]|0)&65535;a[808120]=(i&65535)>>>15&255^1;h=i&255;k=h;l=(h^j)&(j^g);m=(l&255)>>>7;a[808123]=m;a[808084]=k;a[808121]=k;a[808122]=k;return}j=b[404042]|0;h=j&255;i=((h&15)-(g&15)&255)-((a[808120]|0)==0)&255;f=(j&240)-(g&-16&255)&65535;if((i&255)>15){n=i+10&15;o=f-16&65535}else{n=i;o=f}if((o&65535)>240){a[808120]=0;p=o+160&255&-16}else{a[808120]=1;p=o&255}o=p|n;k=o;l=(o^h)&(h^g);m=(l&255)>>>7;a[808123]=m;a[808084]=k;a[808121]=k;a[808122]=k;return}function LZ(){var d=0,f=0,g=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=(b[404043]|0)+(f&255)&65535;f=TP(d)|0;a[808104]=f;g=TP(d+1|0)|0;a[808104]=g;d=TP((((g&255)<<8|f&255)&65535|c[202032])+(e[404046]|0)|0)|0;a[808104]=d;f=a[808084]|d;a[808084]=f;a[808121]=f;a[808122]=f;return}function L_(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=TP((k&65535|f)+(e[404046]|0)|0)|0;a[808104]=h;f=a[808084]|h;a[808084]=f;a[808121]=f;a[808122]=f;return}function L$(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=TP((k&65535|f)+(e[404045]|0)|0)|0;a[808104]=h;f=a[808084]|h;a[808084]=f;a[808121]=f;a[808122]=f;return}function L0(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=(k&65535|f)+(e[404045]|0)|0;f=TP(h)|0;a[808120]=(f&255)>>>7;k=f<<1;HY(k,h);a[808104]=k;a[808121]=k;a[808122]=k;return}function L1(){var d=0,f=0,g=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=(b[404043]|0)+(f&255)&65535;f=TP(d)|0;a[808104]=f;g=TP(d+1|0)|0;a[808104]=g;d=TP((((g&255)<<8|f&255)&65535|c[202032])+(e[404046]|0)|0)|0;a[808104]=d;f=a[808084]&d;a[808084]=f;a[808121]=f;a[808122]=f;return}function L2(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=TP((k&65535|f)+(e[404046]|0)|0)|0;a[808104]=h;f=a[808084]&h;a[808084]=f;a[808121]=f;a[808122]=f;return}function L3(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=TP((k&65535|f)+(e[404045]|0)|0)|0;a[808104]=h;a[808123]=(h&255)>>>6&1;a[808122]=h;a[808121]=a[808084]&h;return}function L4(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=TP((k&65535|f)+(e[404045]|0)|0)|0;a[808104]=h;f=a[808084]&h;a[808084]=f;a[808121]=f;a[808122]=f;return}function L5(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=(k&65535|f)+(e[404045]|0)|0;f=((TP(h)|0)&255)<<1;k=f|(d[808120]|0);a[808120]=(k&65535)>255|0;f=k&255;HY(f,h);a[808104]=f;a[808121]=f;a[808122]=f;return}function L6(){var d=0,f=0,g=0,h=0;d=b[404048]|0;f=c[202034]|0;g=a[f+(d&65535)|0]|0;h=d+1&65535;b[404048]=h;a[808080]=g;c[202032]=(g&255)<<16;g=a[f+(h&65535)|0]|0;b[404048]=d+2&65535;a[808104]=g;d=TP((g&255)<<16|(e[404045]|0))|0;a[808104]=d;HY(d,(e[404046]|0)+(c[202032]|0)|0);b[404045]=(b[404045]|0)-1&65535;b[404046]=(b[404046]|0)-1&65535;d=b[404042]|0;b[404042]=d-1&65535;if(d<<16>>16==0){return}b[404048]=(b[404048]|0)-3&65535;return}function L7(){var d=0,f=0,g=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=(b[404043]|0)+(f&255)&65535;f=TP(d)|0;a[808104]=f;g=TP(d+1|0)|0;a[808104]=g;d=TP((((g&255)<<8|f&255)&65535|c[202032])+(e[404046]|0)|0)|0;a[808104]=d;f=a[808084]^d;a[808084]=f;a[808121]=f;a[808122]=f;return}function L8(){var d=0,f=0,g=0,h=0;d=b[404048]|0;f=c[202034]|0;g=a[f+(d&65535)|0]|0;h=d+1&65535;b[404048]=h;a[808080]=g;c[202032]=(g&255)<<16;g=a[f+(h&65535)|0]|0;b[404048]=d+2&65535;a[808104]=g;d=TP((g&255)<<16|(e[404045]|0))|0;a[808104]=d;HY(d,(e[404046]|0)+(c[202032]|0)|0);b[404045]=(b[404045]|0)+1&65535;b[404046]=(b[404046]|0)+1&65535;d=b[404042]|0;b[404042]=d-1&65535;if(d<<16>>16==0){return}b[404048]=(b[404048]|0)-3&65535;return}function L9(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=TP((k&65535|f)+(e[404046]|0)|0)|0;a[808104]=h;f=a[808084]^h;a[808084]=f;a[808121]=f;a[808122]=f;return}function Ma(){var c=0,d=0;c=b[404046]|0;d=(e[404044]|0)-1|0;HY((c&65535)>>>8&255,(d&65535)+1&65535|d&-65536);HY(c&255,d);b[404044]=(b[404044]|0)-2&65535;a[808104]=a[808092]|0;return}function Mb(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=TP((k&65535|f)+(e[404045]|0)|0)|0;a[808104]=h;f=a[808084]^h;a[808084]=f;a[808121]=f;a[808122]=f;return}function Mc(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=(k&65535|f)+(e[404045]|0)|0;f=TP(h)|0;a[808120]=f&1;k=(f&255)>>>1;HY(k,h);a[808104]=k;a[808121]=k;a[808122]=k;return}function Md(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=b[404048]|0;g=a[(c[202034]|0)+(f&65535)|0]|0;a[808104]=g;b[404048]=f+1&65535;f=(b[404043]|0)+(g&255)&65535;g=TP(f)|0;a[808104]=g;h=TP(f+1|0)|0;a[808104]=h;f=TP((((h&255)<<8|g&255)&65535|c[202032])+(e[404046]|0)|0)|0;a[808104]=f;if((a[808082]&8)==0){g=a[808084]|0;h=f&255;i=(g&255)+h+(d[808120]|0)|0;a[808120]=(i&65280)>>>0>255|0;j=i&255;k=((i^h)&((g^f)&255^128))>>>7&255;l=k&1;a[808123]=l;a[808084]=j;a[808121]=j;a[808122]=j;return}g=b[404042]|0;h=g&255;i=g&240;g=((a[808120]|0)+(f&15)&255)+(h&15)&255;if((g&255)>9){m=g+6&15;n=i+16&65535}else{m=g;n=i}i=n+(f&-16&255)&65535;if((i&65535)>144){a[808120]=1;o=i+96&255&-16}else{a[808120]=0;o=i&255}i=o|m;j=i;k=((i^f)&(f^-128^h)&255)>>>7;l=k&1;a[808123]=l;a[808084]=j;a[808121]=j;a[808122]=j;return}function Me(){var c=0;c=(b[404046]|0)-1&65535;b[404046]=c;a[808121|0]=c<<16>>16!=0|0;a[808122|0]=(c&65535)>>>8&255;return}function Mf(){var c=0;c=b[404045]|0;b[404046]=c;a[808121|0]=c<<16>>16!=0|0;a[808122|0]=(c&65535)>>>8&255;return}function Mg(){var c=0;c=b[404042]|0;b[404046]=c;a[808121|0]=c<<16>>16!=0|0;a[808122|0]=(c&65535)>>>8&255;return}function Mh(){var c=0;c=b[404042]|0;b[404045]=c;a[808121|0]=c<<16>>16!=0|0;a[808122|0]=(c&65535)>>>8&255;return}function Mi(){var c=0;c=b[404044]|0;b[404045]=c;a[808121|0]=c<<16>>16!=0|0;a[808122|0]=(c&65535)>>>8&255;return}function Mj(){var c=0;c=b[404046]|0;b[404045]=c;a[808121|0]=c<<16>>16!=0|0;a[808122|0]=(c&65535)>>>8&255;return}function Mk(){var e=0,f=0,g=0,h=0,i=0;e=c[202034]|0;f=b[404048]|0;g=f&65535;h=a[e+(g+1)|0]|0;i=(h&255)<<8|(d[e+g|0]|0);a[808104]=h;b[404048]=f+2&65535;b[404046]=i;a[808121]=i<<16>>16!=0|0;a[808122]=h;return}function Ml(){var e=0,f=0,g=0,h=0,i=0;e=c[202034]|0;f=b[404048]|0;g=f&65535;h=a[e+(g+1)|0]|0;i=(h&255)<<8|(d[e+g|0]|0);a[808104]=h;b[404048]=f+2&65535;b[404045]=i;a[808121]=i<<16>>16!=0|0;a[808122]=h;return}function Mm(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=TP((k&65535|f)+(e[404046]|0)|0)|0;a[808104]=h;if((a[808082]&8)==0){f=a[808084]|0;k=h&255;j=(f&255)+k+(d[808120]|0)|0;a[808120]=(j&65280)>>>0>255|0;l=j&255;m=((j^k)&((f^h)&255^128))>>>7&255;n=m&1;a[808123]=n;a[808084]=l;a[808121]=l;a[808122]=l;return}f=b[404042]|0;k=f&255;j=f&240;f=((a[808120]|0)+(h&15)&255)+(k&15)&255;if((f&255)>9){o=f+6&15;p=j+16&65535}else{o=f;p=j}j=p+(h&-16&255)&65535;if((j&65535)>144){a[808120]=1;q=j+96&255&-16}else{a[808120]=0;q=j&255}j=q|o;l=j;m=((j^h)&(h^-128^k)&255)>>>7;n=m&1;a[808123]=n;a[808084]=l;a[808121]=l;a[808122]=l;return}function Mn(){var c=0,d=0,f=0;c=(e[404044]|0)+1|0;d=TP(c)|0;a[808104]=d;f=TP((c&65535)+1&65535|c&2147418112)|0;c=(f&255)<<8|d&255;b[404046]=c;b[404044]=(b[404044]|0)+2&65535;a[808121]=c<<16>>16!=0|0;a[808122]=f;a[808104]=f;return}function Mo(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=TP((k&65535|f)+(e[404045]|0)|0)|0;a[808104]=h;if((a[808082]&8)==0){f=a[808084]|0;k=h&255;j=(f&255)+k+(d[808120]|0)|0;a[808120]=(j&65280)>>>0>255|0;l=j&255;m=((j^k)&((f^h)&255^128))>>>7&255;n=m&1;a[808123]=n;a[808084]=l;a[808121]=l;a[808122]=l;return}f=b[404042]|0;k=f&255;j=f&240;f=((a[808120]|0)+(h&15)&255)+(k&15)&255;if((f&255)>9){o=f+6&15;p=j+16&65535}else{o=f;p=j}j=p+(h&-16&255)&65535;if((j&65535)>144){a[808120]=1;q=j+96&255&-16}else{a[808120]=0;q=j&255}j=q|o;l=j;m=((j^h)&(h^-128^k)&255)>>>7;n=m&1;a[808123]=n;a[808084]=l;a[808121]=l;a[808122]=l;return}function Mp(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=(k&65535|f)+(e[404045]|0)|0;f=TP(h)|0;k=(d[808120]|0)<<8|f&255;a[808120]=f&1;f=(k&65535)>>>1&255;HY(f,h);a[808104]=f;a[808121]=f;a[808122]=f;return}function Mq(){var d=0,e=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;b[404048]=d+1&65535;d=(b[404043]|0)+(e&255)&65535;e=b[404046]|0;HY(e&255,d&65535);HY((e&65535)>>>8&255,d+1&65535);a[808104]=a[808093|0]|0;return}function Mr(){var d=0,e=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;b[404048]=d+1&65535;d=(b[404043]|0)+(e&255)&65535;e=b[404045]|0;HY(e&255,d&65535);HY((e&65535)>>>8&255,d+1&65535);a[808104]=a[808091|0]|0;return}function Ms(){var e=0,f=0,g=0,h=0,i=0;e=c[202032]|0;f=c[202034]|0;g=b[404048]|0;h=g&65535;i=(d[f+(h+1)|0]|0)<<8|(d[f+h|0]|0);b[404048]=g+2&65535;g=i&65535|e;i=b[404046]|0;HY(i&255,g);HY((i&65535)>>>8&255,(g&65535)+1&65535|e&-65536);a[808104]=a[808093|0]|0;return}function Mt(){var e=0,f=0,g=0,h=0,i=0;e=c[202032]|0;f=c[202034]|0;g=b[404048]|0;h=g&65535;i=(d[f+(h+1)|0]|0)<<8|(d[f+h|0]|0);b[404048]=g+2&65535;g=i&65535|e;i=b[404045]|0;HY(i&255,g);HY((i&65535)>>>8&255,(g&65535)+1&65535|e&-65536);a[808104]=a[808091|0]|0;return}function Mu(){var d=0,f=0,g=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=(b[404043]|0)+(f&255)&65535;f=TP(d)|0;a[808104]=f;g=(((TP(d+1|0)|0)&255)<<8|f&255)&65535;HY(a[808084]|0,(g|c[202032])+(e[404046]|0)|0);a[808104]=a[808084]|0;return}function Mv(){var d=0,f=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;b[404048]=d+1&65535;d=((b[404043]|0)+(f&255)&65535)+(e[404045]|0)|0;f=b[404046]|0;HY(f&255,d&65535);HY((f&65535)>>>8&255,(d&65535)+1&65535);a[808104]=a[808093|0]|0;return}function Mw(){var d=0,f=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;b[404048]=d+1&65535;d=((b[404043]|0)+(f&255)&65535)+(e[404046]|0)|0;f=b[404045]|0;HY(f&255,d&65535);HY((f&65535)>>>8&255,(d&65535)+1&65535);a[808104]=a[808091|0]|0;return}function Mx(){var f=0,g=0,h=0,i=0,j=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=(d[g+(i+1)|0]|0)<<8|(d[g+i|0]|0);b[404048]=h+2&65535;HY(a[808084]|0,(j&65535|f)+(e[404046]|0)|0);a[808104]=a[808084]|0;return}function My(){var f=0,g=0,h=0,i=0,j=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=(d[g+(i+1)|0]|0)<<8|(d[g+i|0]|0);b[404048]=h+2&65535;HY(a[808084]|0,(j&65535|f)+(e[404045]|0)|0);a[808104]=a[808084]|0;return}function Mz(){var f=0,g=0,h=0,i=0,j=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=(d[g+(i+1)|0]|0)<<8|(d[g+i|0]|0);b[404048]=h+2&65535;HY(0,(j&65535|f)+(e[404045]|0)|0);a[808104]=0;return}function MA(){var d=0,e=0,f=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=e;b[404048]=d+1&65535;d=(b[404043]|0)+(e&255)&65535;e=TP(d&65535)|0;a[808104]=e;f=TP(d+1&65535)|0;d=(f&255)<<8|e&255;a[808104]=f;b[404046]=d;a[808121|0]=d<<16>>16!=0|0;a[808122|0]=f;return}function MB(){var d=0,e=0,f=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=e;b[404048]=d+1&65535;d=(b[404043]|0)+(e&255)&65535;e=TP(d&65535)|0;a[808104]=e;f=TP(d+1&65535)|0;d=(f&255)<<8|e&255;a[808104]=f;b[404045]=d;a[808121|0]=d<<16>>16!=0|0;a[808122|0]=f;return}function MC(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[202032]|0;f=c[202034]|0;g=b[404048]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[808104]=i;b[404048]=g+2&65535;g=j&65535|e;j=TP(g)|0;a[808104]=j;i=TP((g&65535)+1&65535|e&-65536)|0;e=(i&255)<<8|j&255;a[808104]=i;b[404046]=e;a[808121]=e<<16>>16!=0|0;a[808122]=i;return}function MD(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[202032]|0;f=c[202034]|0;g=b[404048]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[808104]=i;b[404048]=g+2&65535;g=j&65535|e;j=TP(g)|0;a[808104]=j;i=TP((g&65535)+1&65535|e&-65536)|0;e=(i&255)<<8|j&255;a[808104]=i;b[404045]=e;a[808121]=e<<16>>16!=0|0;a[808122]=i;return}function ME(){var d=0,f=0,g=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=(b[404043]|0)+(f&255)&65535;f=TP(d)|0;a[808104]=f;g=TP(d+1|0)|0;a[808104]=g;d=TP((((g&255)<<8|f&255)&65535|c[202032])+(e[404046]|0)|0)|0;a[808104]=d;a[808084]=d;a[808121]=d;a[808122]=d;return}function MF(){var d=0,f=0,g=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=((b[404043]|0)+(f&255)&65535)+(e[404045]|0)|0;f=TP(d&65535)|0;a[808104]=f;g=TP((d&65535)+1&65535)|0;d=(g&255)<<8|f&255;a[808104]=g;b[404046]=d;a[808121]=d<<16>>16!=0|0;a[808122]=g;return}function MG(){var d=0,f=0,g=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=((b[404043]|0)+(f&255)&65535)+(e[404046]|0)|0;f=TP(d&65535)|0;a[808104]=f;g=TP((d&65535)+1&65535)|0;d=(g&255)<<8|f&255;a[808104]=g;b[404045]=d;a[808121]=d<<16>>16!=0|0;a[808122]=g;return}function MH(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=TP((k&65535|f)+(e[404046]|0)|0)|0;a[808104]=h;a[808084]=h;a[808121]=h;a[808122]=h;return}function MI(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=(k&65535|f)+(e[404045]|0)|0;f=TP(h)|0;a[808104]=f;k=TP((h&65535)+1&65535|h&-65536)|0;h=(k&255)<<8|f&255;a[808104]=k;b[404046]=h;a[808121]=h<<16>>16!=0|0;a[808122]=k;return}function MJ(){var c=0;c=(b[404046]|0)+1&65535;b[404046]=c;a[808121|0]=c<<16>>16!=0|0;a[808122|0]=(c&65535)>>>8&255;return}function MK(){var c=0;c=(b[404045]|0)-1&65535;b[404045]=c;a[808121|0]=c<<16>>16!=0|0;a[808122|0]=(c&65535)>>>8&255;return}function ML(){var c=0;c=(b[404045]|0)+1&65535;b[404045]=c;a[808121|0]=c<<16>>16!=0|0;a[808122|0]=(c&65535)>>>8&255;return}function MM(){var f=0,g=0,h=0,i=0,j=0,k=0;f=e[404046]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=f-(k&65535)|0;a[808120]=h>>>31&255^1;a[808121]=(h&65535|0)!=0|0;a[808122]=h>>>8&255;return}function MN(){var f=0,g=0,h=0,i=0,j=0,k=0;f=e[404045]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=f-(k&65535)|0;a[808120]=h>>>31&255^1;a[808121]=(h&65535|0)!=0|0;a[808122]=h>>>8&255;return}function MO(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=TP((k&65535|f)+(e[404045]|0)|0)|0;a[808104]=h;a[808084]=h;a[808121]=h;a[808122]=h;return}function MP(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=(k&65535|f)+(e[404046]|0)|0;f=TP(h)|0;a[808104]=f;k=TP((h&65535)+1&65535|h&-65536)|0;h=(k&255)<<8|f&255;a[808104]=k;b[404045]=h;a[808121]=h<<16>>16!=0|0;a[808122]=k;return}function MQ(){var d=0,f=0,g=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=(b[404043]|0)+(f&255)&65535;f=TP(d&65535)|0;a[808104]=f;g=TP(d+1&65535)|0;a[808104]=g;d=(e[404046]|0)-(((g&255)<<8|f&255)&65535)|0;a[808120]=d>>>31&255^1;a[808121]=(d&65535|0)!=0|0;a[808122]=d>>>8&255;return}function MR(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=k&65535|f;f=TP(h)|0;a[808104]=f;k=TP(h+1|0)|0;a[808104]=k;h=(e[404046]|0)-(((k&255)<<8|f&255)&65535)|0;a[808120]=h>>>31&255^1;a[808121]=(h&65535|0)!=0|0;a[808122]=h>>>8&255;return}function MS(){var f=0,g=0,h=0;f=b[404048]|0;g=a[(c[202034]|0)+(f&65535)|0]|0;a[808104]=g;b[404048]=f+1&65535;f=(b[404043]|0)+(g&255)&65535;g=TP(f)|0;a[808104]=g;h=TP(f+1|0)|0;a[808104]=h;f=TP((((h&255)<<8|g&255)&65535|c[202032])+(e[404046]|0)|0)|0;a[808104]=f;g=(d[808084]|0)-(f&255)&65535;a[808120]=(g&65535)>>>15&255^1;f=g&255;a[808121]=f;a[808122]=f;return}function MT(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=TP((k&65535|f)+(e[404046]|0)|0)|0;a[808104]=h;f=(d[808084]|0)-(h&255)&65535;a[808120]=(f&65535)>>>15&255^1;h=f&255;a[808121]=h;a[808122]=h;return}function MU(){var c=0,d=0;c=b[404045]|0;d=(e[404044]|0)-1|0;HY((c&65535)>>>8&255,(d&65535)+1&65535|d&-65536);HY(c&255,d);b[404044]=(b[404044]|0)-2&65535;a[808104]=a[808090]|0;return}function MV(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=TP((k&65535|f)+(e[404045]|0)|0)|0;a[808104]=h;f=(d[808084]|0)-(h&255)&65535;a[808120]=(f&65535)>>>15&255^1;h=f&255;a[808121]=h;a[808122]=h;return}function MW(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=(k&65535|f)+(e[404045]|0)|0;f=(TP(h)|0)-1&255;HY(f,h);a[808104]=f;a[808121]=f;a[808122]=f;return}function MX(){var d=0,f=0,g=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=(b[404043]|0)+(f&255)&65535;f=TP(d&65535)|0;a[808104]=f;g=TP(d+1&65535)|0;a[808104]=g;d=(e[404045]|0)-(((g&255)<<8|f&255)&65535)|0;a[808120]=d>>>31&255^1;a[808121]=(d&65535|0)!=0|0;a[808122]=d>>>8&255;return}function MY(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=k&65535|f;f=TP(h)|0;a[808104]=f;k=TP(h+1|0)|0;a[808104]=k;h=(e[404045]|0)-(((k&255)<<8|f&255)&65535)|0;a[808120]=h>>>31&255^1;a[808121]=(h&65535|0)!=0|0;a[808122]=h>>>8&255;return}function MZ(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=b[404048]|0;g=a[(c[202034]|0)+(f&65535)|0]|0;a[808104]=g;b[404048]=f+1&65535;f=(b[404043]|0)+(g&255)&65535;g=TP(f)|0;a[808104]=g;h=TP(f+1|0)|0;a[808104]=h;f=TP((((h&255)<<8|g&255)&65535|c[202032])+(e[404046]|0)|0)|0;a[808104]=f;if((a[808082]&8)==0){g=a[808084]|0;h=((g&255)+~(f&255)&65535)+(d[808120]|0)&65535;a[808120]=(h&65535)>>>15&255^1;i=h&255;j=i;k=(i^g)&(g^f);l=(k&255)>>>7;a[808123]=l;a[808084]=j;a[808121]=j;a[808122]=j;return}g=b[404042]|0;i=g&255;h=((i&15)-(f&15)&255)-((a[808120]|0)==0)&255;m=(g&240)-(f&-16&255)&65535;if((h&255)>15){n=h+10&15;o=m-16&65535}else{n=h;o=m}if((o&65535)>240){a[808120]=0;p=o+160&255&-16}else{a[808120]=1;p=o&255}o=p|n;j=o;k=(o^i)&(i^f);l=(k&255)>>>7;a[808123]=l;a[808084]=j;a[808121]=j;a[808122]=j;return}function M_(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|d[g+i|0];a[808104]=j;b[404048]=h+2&65535;h=TP((k&65535|f)+(e[404046]|0)|0)|0;a[808104]=h;if((a[808082]&8)==0){f=a[808084]|0;k=((f&255)+~(h&255)&65535)+(d[808120]|0)&65535;a[808120]=(k&65535)>>>15&255^1;j=k&255;l=j;m=(j^f)&(f^h);n=(m&255)>>>7;a[808123]=n;a[808084]=l;a[808121]=l;a[808122]=l;return}f=b[404042]|0;j=f&255;k=((j&15)-(h&15)&255)-((a[808120]|0)==0)&255;i=(f&240)-(h&-16&255)&65535;if((k&255)>15){o=k+10&15;p=i-16&65535}else{o=k;p=i}if((p&65535)>240){a[808120]=0;q=p+160&255&-16}else{a[808120]=1;q=p&255}p=q|o;l=p;m=(p^j)&(j^h);n=(m&255)>>>7;a[808123]=n;a[808084]=l;a[808121]=l;a[808122]=l;return}function M$(){var c=0,d=0,f=0;c=(e[404044]|0)+1|0;d=TP(c)|0;a[808104]=d;f=TP((c&65535)+1&65535|c&2147418112)|0;c=(f&255)<<8|d&255;b[404045]=c;b[404044]=(b[404044]|0)+2&65535;a[808121]=c<<16>>16!=0|0;a[808122]=f;a[808104]=f;return}function M0(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|d[g+i|0];a[808104]=j;b[404048]=h+2&65535;h=TP((k&65535|f)+(e[404045]|0)|0)|0;a[808104]=h;if((a[808082]&8)==0){f=a[808084]|0;k=((f&255)+~(h&255)&65535)+(d[808120]|0)&65535;a[808120]=(k&65535)>>>15&255^1;j=k&255;l=j;m=(j^f)&(f^h);n=(m&255)>>>7;a[808123]=n;a[808084]=l;a[808121]=l;a[808122]=l;return}f=b[404042]|0;j=f&255;k=((j&15)-(h&15)&255)-((a[808120]|0)==0)&255;i=(f&240)-(h&-16&255)&65535;if((k&255)>15){o=k+10&15;p=i-16&65535}else{o=k;p=i}if((p&65535)>240){a[808120]=0;q=p+160&255&-16}else{a[808120]=1;q=p&255}p=q|o;l=p;m=(p^j)&(j^h);n=(m&255)>>>7;a[808123]=n;a[808084]=l;a[808121]=l;a[808122]=l;return}function M1(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=(k&65535|f)+(e[404045]|0)|0;f=(TP(h)|0)+1&255;HY(f,h);a[808104]=f;a[808121]=f;a[808122]=f;return}function M2(){var d=0,f=0,g=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=((b[404043]|0)+(f&255)&65535)+(e[404045]|0)&65535;f=TP(d)|0;a[808104]=f;g=TP(d+1|0)|0;a[808104]=g;d=((g&255)<<8|f&255)&65535|c[202032];f=TP(d)|0;a[808104]=f;g=TP(d+1|0)|0;a[808104]=g;d=b[404042]|f&255|(g&255)<<8;b[404042]=d;a[808121]=d<<16>>16!=0|0;a[808122]=(d&65535)>>>8&255;return}function M3(){var d=0,e=0,f=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=e;b[404048]=d+1&65535;d=(b[404044]|0)+(e&255)&65535;e=TP(d)|0;a[808104]=e;f=TP(d+1|0)|0;a[808104]=f;d=b[404042]|e&255|(f&255)<<8;b[404042]=d;a[808121]=d<<16>>16!=0|0;a[808122]=(d&65535)>>>8&255;return}function M4(){var c=0,e=0;a[808120]=(d[808085|0]|0)>>>7;c=b[404042]|0;e=c<<1;b[404042]=e;a[808121]=e<<16>>16!=0|0;a[808122]=(c&65535)>>>7&255;return}function M5(){var c=0;c=(b[404042]|0)+1&65535;b[404042]=c;a[808121|0]=c<<16>>16!=0|0;a[808122|0]=(c&65535)>>>8&255;return}function M6(){var e=0,f=0,g=0,h=0,i=0;e=c[202034]|0;f=b[404048]|0;g=f&65535;h=d[e+g|0]|0;i=a[e+(g+1)|0]|0;a[808104]=i;b[404048]=f+2&65535;f=b[404042]|h|(i&255)<<8;b[404042]=f;a[808121]=f<<16>>16!=0|0;a[808122]=(f&65535)>>>8&255;return}function M7(){var d=0,e=0,f=0,g=0,h=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=e;b[404048]=d+1&65535;d=(b[404043]|0)+(e&255)&65535;e=d&65535;f=TP(e)|0;a[808104]=f;g=d+1&65535;d=((TP(g)|0)&255)<<8|f&255;f=b[404042]|0;a[808121|0]=(d&f)<<16>>16!=0|0;h=d|f;HY((h&65535)>>>8&255,g);g=h&255;HY(g,e);a[808104]=g;return}function M8(){var d=0,e=0,f=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=e;b[404048]=d+1&65535;d=(b[404043]|0)+(e&255)&65535;e=TP(d&65535)|0;a[808104]=e;f=TP(d+1&65535)|0;a[808104]=f;d=b[404042]|e&255|(f&255)<<8;b[404042]=d;a[808121]=d<<16>>16!=0|0;a[808122]=(d&65535)>>>8&255;return}function M9(){var d=0,e=0,f=0,g=0,h=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=e;b[404048]=d+1&65535;d=(b[404043]|0)+(e&255)&65535;e=d&65535;f=TP(e)|0;a[808104]=f;g=d+1&65535;d=TP(g)|0;h=(d&255)<<8|f&255;a[808120|0]=(d&255)>>>7;d=h<<1;f=(h&65535)>>>7&255;HY(f,g);g=d&255;HY(g,e);a[808104]=g;a[808121|0]=d<<16>>16!=0|0;a[808122|0]=f;return}function Na(){var d=0,e=0,f=0,g=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=e;b[404048]=d+1&65535;d=(b[404043]|0)+(e&255)&65535;e=TP(d)|0;a[808104]=e;f=TP(d+1|0)|0;a[808104]=f;g=TP(d+2|0)|0;a[808104]=g;d=((f&255)<<8|e&255)&65535|(g&255)<<16;g=TP(d)|0;a[808104]=g;e=TP(d+1|0)|0;a[808104]=e;d=b[404042]|g&255|(e&255)<<8;b[404042]=d;a[808121]=d<<16>>16!=0|0;a[808122]=(d&65535)>>>8&255;return}function Nb(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[202032]|0;f=c[202034]|0;g=b[404048]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[808104]=i;b[404048]=g+2&65535;g=j&65535|e;j=TP(g)|0;a[808104]=j;i=(g&65535)+1&65535|e&-65536;e=((TP(i)|0)&255)<<8|j&255;j=b[404042]|0;a[808121]=(e&j)<<16>>16!=0|0;h=e|j;HY((h&65535)>>>8&255,i);i=h&255;HY(i,g);a[808104]=i;return}function Nc(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[202032]|0;f=c[202034]|0;g=b[404048]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[808104]=i;b[404048]=g+2&65535;g=j&65535|e;e=TP(g)|0;a[808104]=e;j=TP(g+1|0)|0;a[808104]=j;g=b[404042]|e&255|(j&255)<<8;b[404042]=g;a[808121]=g<<16>>16!=0|0;a[808122]=(g&65535)>>>8&255;return}function Nd(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[202032]|0;f=c[202034]|0;g=b[404048]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[808104]=i;b[404048]=g+2&65535;g=j&65535|e;e=TP(g)|0;a[808104]=e;j=g+1|0;i=TP(j)|0;h=(i&255)<<8|e&255;a[808120]=(i&255)>>>7;i=h<<1;e=(h&65535)>>>7&255;HY(e,j);j=i&255;HY(j,g);a[808104]=j;a[808121]=i<<16>>16!=0|0;a[808122]=e;return}function Ne(){var e=0,f=0,g=0,h=0,i=0;e=c[202034]|0;f=b[404048]|0;g=f&65535;h=a[e+(g+2)|0]|0;i=(d[e+(g+1)|0]|0)<<8|(d[e+g|0]|0)|(h&255)<<16;a[808104]=h;b[404048]=f+3&65535;f=TP(i)|0;a[808104]=f;h=TP(i+1|0)|0;a[808104]=h;i=b[404042]|f&255|(h&255)<<8;b[404042]=i;a[808121]=i<<16>>16!=0|0;a[808122]=(i&65535)>>>8&255;return}function Nf(){var d=0,f=0,g=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=(b[404043]|0)+(f&255)&65535;f=TP(d)|0;a[808104]=f;g=TP(d+1|0)|0;a[808104]=g;d=(((g&255)<<8|f&255)&65535|c[202032])+(e[404046]|0)|0;f=TP(d)|0;a[808104]=f;g=TP(d+1|0)|0;a[808104]=g;d=b[404042]|f&255|(g&255)<<8;b[404042]=d;a[808121]=d<<16>>16!=0|0;a[808122]=(d&65535)>>>8&255;return}function Ng(){var d=0,e=0,f=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=e;b[404048]=d+1&65535;d=(b[404043]|0)+(e&255)&65535;e=TP(d)|0;a[808104]=e;f=TP(d+1|0)|0;a[808104]=f;d=((f&255)<<8|e&255)&65535|c[202032];e=TP(d)|0;a[808104]=e;f=TP(d+1|0)|0;a[808104]=f;d=b[404042]|e&255|(f&255)<<8;b[404042]=d;a[808121]=d<<16>>16!=0|0;a[808122]=(d&65535)>>>8&255;return}function Nh(){var d=0,f=0,g=0;d=TP(c[202024]|0)|0;a[808104]=d;b[404048]=(b[404048]|0)+1&65535;f=(b[404044]|0)+(d&255)&65535;d=TP(f)|0;a[808104]=d;g=TP(f+1|0)|0;a[808104]=g;f=(c[202032]|0)+(e[404046]|0)+(((g&255)<<8|d&255)&65535)&16777215;d=TP(f)|0;a[808104]=d;g=TP(f+1|0)|0;a[808104]=g;f=b[404042]|d&255|(g&255)<<8;b[404042]=f;a[808121]=f<<16>>16!=0|0;a[808122]=(f&65535)>>>8&255;return}function Ni(){var d=0,e=0,f=0,g=0,h=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=e;b[404048]=d+1&65535;d=(b[404043]|0)+(e&255)&65535;e=d&65535;f=TP(e)|0;a[808104]=f;g=d+1&65535;d=((TP(g)|0)&255)<<8|f&255;f=b[404042]|0;a[808121|0]=(d&f)<<16>>16!=0|0;h=d&~f;HY((h&65535)>>>8&255,g);g=h&255;HY(g,e);a[808104]=g;return}function Nj(){var d=0,f=0,g=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=((b[404043]|0)+(f&255)&65535)+(e[404045]|0)|0;f=TP(d&65535)|0;a[808104]=f;g=TP((d&65535)+1&65535)|0;a[808104]=g;d=b[404042]|f&255|(g&255)<<8;b[404042]=d;a[808121]=d<<16>>16!=0|0;a[808122]=(d&65535)>>>8&255;return}function Nk(){var d=0,f=0,g=0,h=0,i=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=((b[404043]|0)+(f&255)&65535)+(e[404045]|0)|0;f=d&65535;g=TP(f)|0;a[808104]=g;h=(d&65535)+1&65535;d=TP(h)|0;i=(d&255)<<8|g&255;a[808120]=(d&255)>>>7;d=i<<1;g=(i&65535)>>>7&255;HY(g,h);h=d&255;HY(h,f);a[808104]=h;a[808121]=d<<16>>16!=0|0;a[808122]=g;return}function Nl(){var d=0,f=0,g=0,h=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=(b[404043]|0)+(f&255)&65535;f=TP(d)|0;a[808104]=f;g=TP(d+1|0)|0;a[808104]=g;h=TP(d+2|0)|0;a[808104]=h;d=(((g&255)<<8|f&255)&65535|(h&255)<<16)+(e[404046]|0)|0;h=TP(d)|0;a[808104]=h;f=TP(d+1|0)|0;a[808104]=f;d=b[404042]|h&255|(f&255)<<8;b[404042]=d;a[808121]=d<<16>>16!=0|0;a[808122]=(d&65535)>>>8&255;return}function Nm(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=(k&65535|f)+(e[404046]|0)|0;f=TP(h)|0;a[808104]=f;k=TP(h+1|0)|0;a[808104]=k;h=b[404042]|f&255|(k&255)<<8;b[404042]=h;a[808121]=h<<16>>16!=0|0;a[808122]=(h&65535)>>>8&255;return}function Nn(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[202032]|0;f=c[202034]|0;g=b[404048]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[808104]=i;b[404048]=g+2&65535;g=j&65535|e;j=TP(g)|0;a[808104]=j;i=(g&65535)+1&65535|e&-65536;e=((TP(i)|0)&255)<<8|j&255;j=b[404042]|0;a[808121]=(e&j)<<16>>16!=0|0;h=e&~j;HY((h&65535)>>>8&255,i);i=h&255;HY(i,g);a[808104]=i;return}function No(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=(k&65535|f)+(e[404045]|0)|0;f=TP(h)|0;a[808104]=f;k=TP(h+1|0)|0;a[808104]=k;h=b[404042]|f&255|(k&255)<<8;b[404042]=h;a[808121]=h<<16>>16!=0|0;a[808122]=(h&65535)>>>8&255;return}function Np(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=(k&65535|f)+(e[404045]|0)|0;f=TP(h)|0;a[808104]=f;k=h+1|0;j=TP(k)|0;i=(j&255)<<8|f&255;a[808120]=(j&255)>>>7;j=i<<1;f=(i&65535)>>>7&255;HY(f,k);k=j&255;HY(k,h);a[808104]=k;a[808121]=j<<16>>16!=0|0;a[808122]=f;return}function Nq(){var f=0,g=0,h=0,i=0,j=0;f=c[202034]|0;g=b[404048]|0;h=g&65535;i=a[f+(h+2)|0]|0;j=(d[f+(h+1)|0]|0)<<8|(d[f+h|0]|0)|(i&255)<<16;a[808104]=i;b[404048]=g+3&65535;g=j+(e[404045]|0)|0;j=TP(g)|0;a[808104]=j;i=TP(g+1|0)|0;a[808104]=i;g=b[404042]|j&255|(i&255)<<8;b[404042]=g;a[808121]=g<<16>>16!=0|0;a[808122]=(g&65535)>>>8&255;return}function Nr(){var d=0,f=0,g=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=((b[404043]|0)+(f&255)&65535)+(e[404045]|0)&65535;f=TP(d)|0;a[808104]=f;g=TP(d+1|0)|0;a[808104]=g;d=((g&255)<<8|f&255)&65535|c[202032];f=TP(d)|0;a[808104]=f;g=TP(d+1|0)|0;a[808104]=g;d=((g&255)<<8|f&255)&b[404042];b[404042]=d;a[808121]=d<<16>>16!=0|0;a[808122]=(d&65535)>>>8&255;return}function Ns(){var d=0,e=0,f=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=e;b[404048]=d+1&65535;d=(b[404044]|0)+(e&255)&65535;e=TP(d)|0;a[808104]=e;f=TP(d+1|0)|0;a[808104]=f;d=((f&255)<<8|e&255)&b[404042];b[404042]=d;a[808121]=d<<16>>16!=0|0;a[808122]=(d&65535)>>>8&255;return}function Nt(){var c=0,f=0;c=(e[404042]|0)<<1|(d[808120]|0);a[808120]=c>>>0>65535|0;f=c&65535;b[404042]=f;a[808121]=(c&65535|0)!=0|0;a[808122]=(f&65535)>>>8&255;return}function Nu(){var c=0;c=(b[404042]|0)-1&65535;b[404042]=c;a[808121|0]=c<<16>>16!=0|0;a[808122|0]=(c&65535)>>>8&255;return}function Nv(){var e=0,f=0,g=0,h=0,i=0;e=c[202034]|0;f=b[404048]|0;g=f&65535;h=a[e+(g+1)|0]|0;i=(h&255)<<8|(d[e+g|0]|0);a[808104]=h;b[404048]=f+2&65535;f=i&b[404042];b[404042]=f;a[808121]=f<<16>>16!=0|0;a[808122]=(f&65535)>>>8&255;return}function Nw(){var d=0,e=0,f=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=e;b[404048]=d+1&65535;d=(b[404043]|0)+(e&255)&65535;e=TP(d&65535)|0;a[808104]=e;f=TP(d+1&65535)|0;a[808104]=f;a[808123]=(f&255)>>>6&1;a[808122]=f;a[808121]=(((f&255)<<8|e&255)&b[404042])<<16>>16!=0|0;return}function Nx(){var d=0,e=0,f=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=e;b[404048]=d+1&65535;d=(b[404043]|0)+(e&255)&65535;e=TP(d&65535)|0;a[808104]=e;f=TP(d+1&65535)|0;a[808104]=f;d=((f&255)<<8|e&255)&b[404042];b[404042]=d;a[808121]=d<<16>>16!=0|0;a[808122]=(d&65535)>>>8&255;return}function Ny(){var e=0,f=0,g=0,h=0,i=0;e=b[404048]|0;f=a[(c[202034]|0)+(e&65535)|0]|0;a[808104]=f;b[404048]=e+1&65535;e=(b[404043]|0)+(f&255)&65535;f=e&65535;g=TP(f)|0;a[808104]=g;h=e+1&65535;e=((TP(h)|0)&255)<<8|g&255;g=(e&65535)<<1|(d[808120]|0);a[808120]=g>>>0>65535|0;i=(e&65535)>>>7&255;HY(i,h);h=g&255;HY(h,f);a[808104]=h;a[808121]=(g&65535|0)!=0|0;a[808122]=i;return}function Nz(){var d=0,e=0,f=0,g=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=e;b[404048]=d+1&65535;d=(b[404043]|0)+(e&255)&65535;e=TP(d)|0;a[808104]=e;f=TP(d+1|0)|0;a[808104]=f;g=TP(d+2|0)|0;a[808104]=g;d=((f&255)<<8|e&255)&65535|(g&255)<<16;g=TP(d)|0;a[808104]=g;e=TP(d+1|0)|0;a[808104]=e;d=((e&255)<<8|g&255)&b[404042];b[404042]=d;a[808121]=d<<16>>16!=0|0;a[808122]=(d&65535)>>>8&255;return}function NA(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[202032]|0;f=c[202034]|0;g=b[404048]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[808104]=i;b[404048]=g+2&65535;g=j&65535|e;e=TP(g)|0;a[808104]=e;j=TP(g+1|0)|0;a[808104]=j;a[808123]=(j&255)>>>6&1;a[808122]=j;a[808121]=(((j&255)<<8|e&255)&b[404042])<<16>>16!=0|0;return}function NB(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[202032]|0;f=c[202034]|0;g=b[404048]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[808104]=i;b[404048]=g+2&65535;g=j&65535|e;e=TP(g)|0;a[808104]=e;j=TP(g+1|0)|0;a[808104]=j;g=((j&255)<<8|e&255)&b[404042];b[404042]=g;a[808121]=g<<16>>16!=0|0;a[808122]=(g&65535)>>>8&255;return}function NC(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[202032]|0;f=c[202034]|0;g=b[404048]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[808104]=i;b[404048]=g+2&65535;g=j&65535|e;e=TP(g)|0;a[808104]=e;j=g+1|0;i=((TP(j)|0)&255)<<8|e&255;e=(i&65535)<<1|(d[808120]|0);a[808120]=e>>>0>65535|0;h=(i&65535)>>>7&255;HY(h,j);j=e&255;HY(j,g);a[808104]=j;a[808121]=(e&65535|0)!=0|0;a[808122]=h;return}function ND(){var e=0,f=0,g=0,h=0,i=0;e=c[202034]|0;f=b[404048]|0;g=f&65535;h=a[e+(g+2)|0]|0;i=(d[e+(g+1)|0]|0)<<8|(d[e+g|0]|0)|(h&255)<<16;a[808104]=h;b[404048]=f+3&65535;f=TP(i)|0;a[808104]=f;h=TP(i+1|0)|0;a[808104]=h;i=((h&255)<<8|f&255)&b[404042];b[404042]=i;a[808121]=i<<16>>16!=0|0;a[808122]=(i&65535)>>>8&255;return}function NE(){var d=0,f=0,g=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=(b[404043]|0)+(f&255)&65535;f=TP(d)|0;a[808104]=f;g=TP(d+1|0)|0;a[808104]=g;d=(((g&255)<<8|f&255)&65535|c[202032])+(e[404046]|0)|0;f=TP(d)|0;a[808104]=f;g=TP(d+1|0)|0;a[808104]=g;d=((g&255)<<8|f&255)&b[404042];b[404042]=d;a[808121]=d<<16>>16!=0|0;a[808122]=(d&65535)>>>8&255;return}function NF(){var d=0,e=0,f=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=e;b[404048]=d+1&65535;d=(b[404043]|0)+(e&255)&65535;e=TP(d)|0;a[808104]=e;f=TP(d+1|0)|0;a[808104]=f;d=((f&255)<<8|e&255)&65535|c[202032];e=TP(d)|0;a[808104]=e;f=TP(d+1|0)|0;a[808104]=f;d=((f&255)<<8|e&255)&b[404042];b[404042]=d;a[808121]=d<<16>>16!=0|0;a[808122]=(d&65535)>>>8&255;return}function NG(){var d=0,f=0,g=0;d=TP(c[202024]|0)|0;a[808104]=d;b[404048]=(b[404048]|0)+1&65535;f=(b[404044]|0)+(d&255)&65535;d=TP(f)|0;a[808104]=d;g=TP(f+1|0)|0;a[808104]=g;f=(c[202032]|0)+(e[404046]|0)+(((g&255)<<8|d&255)&65535)&16777215;d=TP(f)|0;a[808104]=d;g=TP(f+1|0)|0;a[808104]=g;f=((g&255)<<8|d&255)&b[404042];b[404042]=f;a[808121]=f<<16>>16!=0|0;a[808122]=(f&65535)>>>8&255;return}function NH(){var d=0,f=0,g=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=((b[404043]|0)+(f&255)&65535)+(e[404045]|0)|0;f=TP(d&65535)|0;a[808104]=f;g=TP((d&65535)+1&65535)|0;a[808104]=g;a[808123]=(g&255)>>>6&1;a[808122]=g;a[808121]=(((g&255)<<8|f&255)&b[404042])<<16>>16!=0|0;return}function NI(){var d=0,f=0,g=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=((b[404043]|0)+(f&255)&65535)+(e[404045]|0)|0;f=TP(d&65535)|0;a[808104]=f;g=TP((d&65535)+1&65535)|0;a[808104]=g;d=((g&255)<<8|f&255)&b[404042];b[404042]=d;a[808121]=d<<16>>16!=0|0;a[808122]=(d&65535)>>>8&255;return}function NJ(){var f=0,g=0,h=0,i=0,j=0;f=b[404048]|0;g=a[(c[202034]|0)+(f&65535)|0]|0;a[808104]=g;b[404048]=f+1&65535;f=((b[404043]|0)+(g&255)&65535)+(e[404045]|0)|0;g=f&65535;h=TP(g)|0;a[808104]=h;i=(f&65535)+1&65535;f=((TP(i)|0)&255)<<8|h&255;h=(f&65535)<<1|(d[808120]|0);a[808120]=h>>>0>65535|0;j=(f&65535)>>>7&255;HY(j,i);i=h&255;HY(i,g);a[808104]=i;a[808121]=(h&65535|0)!=0|0;a[808122]=j;return}function NK(){var d=0,f=0,g=0,h=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=(b[404043]|0)+(f&255)&65535;f=TP(d)|0;a[808104]=f;g=TP(d+1|0)|0;a[808104]=g;h=TP(d+2|0)|0;a[808104]=h;d=(((g&255)<<8|f&255)&65535|(h&255)<<16)+(e[404046]|0)|0;h=TP(d)|0;a[808104]=h;f=TP(d+1|0)|0;a[808104]=f;d=((f&255)<<8|h&255)&b[404042];b[404042]=d;a[808121]=d<<16>>16!=0|0;a[808122]=(d&65535)>>>8&255;return}function NL(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=(k&65535|f)+(e[404046]|0)|0;f=TP(h)|0;a[808104]=f;k=TP(h+1|0)|0;a[808104]=k;h=((k&255)<<8|f&255)&b[404042];b[404042]=h;a[808121]=h<<16>>16!=0|0;a[808122]=(h&65535)>>>8&255;return}function NM(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=(k&65535|f)+(e[404045]|0)|0;f=TP(h)|0;a[808104]=f;k=TP(h+1|0)|0;a[808104]=k;a[808123]=(k&255)>>>6&1;a[808122]=k;a[808121]=(((k&255)<<8|f&255)&b[404042])<<16>>16!=0|0;return}function NN(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=(k&65535|f)+(e[404045]|0)|0;f=TP(h)|0;a[808104]=f;k=TP(h+1|0)|0;a[808104]=k;h=((k&255)<<8|f&255)&b[404042];b[404042]=h;a[808121]=h<<16>>16!=0|0;a[808122]=(h&65535)>>>8&255;return}function NO(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=(k&65535|f)+(e[404045]|0)|0;f=TP(h)|0;a[808104]=f;k=h+1|0;j=((TP(k)|0)&255)<<8|f&255;f=(j&65535)<<1|(d[808120]|0);a[808120]=f>>>0>65535|0;i=(j&65535)>>>7&255;HY(i,k);k=f&255;HY(k,h);a[808104]=k;a[808121]=(f&65535|0)!=0|0;a[808122]=i;return}function NP(){var f=0,g=0,h=0,i=0,j=0;f=c[202034]|0;g=b[404048]|0;h=g&65535;i=a[f+(h+2)|0]|0;j=(d[f+(h+1)|0]|0)<<8|(d[f+h|0]|0)|(i&255)<<16;a[808104]=i;b[404048]=g+3&65535;g=j+(e[404045]|0)|0;j=TP(g)|0;a[808104]=j;i=TP(g+1|0)|0;a[808104]=i;g=((i&255)<<8|j&255)&b[404042];b[404042]=g;a[808121]=g<<16>>16!=0|0;a[808122]=(g&65535)>>>8&255;return}function NQ(){var d=0,f=0,g=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=((b[404043]|0)+(f&255)&65535)+(e[404045]|0)&65535;f=TP(d)|0;a[808104]=f;g=TP(d+1|0)|0;a[808104]=g;d=((g&255)<<8|f&255)&65535|c[202032];f=TP(d)|0;a[808104]=f;g=TP(d+1|0)|0;d=(g&255)<<8|f&255;a[808104]=g;g=b[404042]|0;f=d^g;b[404042]=f;a[808121]=g<<16>>16!=d<<16>>16|0;a[808122]=(f&65535)>>>8&255;return}function NR(){var c=0,d=0;c=b[404042]|0;a[808120|0]=c&1;d=(c&65535)>>>1;b[404042]=d;a[808121|0]=d<<16>>16!=0|0;a[808122|0]=(c&65535)>>>9&255;return}function NS(){var e=0,f=0,g=0,h=0,i=0;e=c[202034]|0;f=b[404048]|0;g=f&65535;h=a[e+(g+1)|0]|0;i=(h&255)<<8|(d[e+g|0]|0);a[808104]=h;b[404048]=f+2&65535;f=b[404042]|0;h=i^f;b[404042]=h;a[808121]=f<<16>>16!=i<<16>>16|0;a[808122]=(h&65535)>>>8&255;return}function NT(){var d=0,e=0,f=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=e;b[404048]=d+1&65535;d=(b[404044]|0)+(e&255)&65535;e=TP(d)|0;a[808104]=e;f=TP(d+1|0)|0;d=(f&255)<<8|e&255;a[808104]=f;f=b[404042]|0;e=d^f;b[404042]=e;a[808121|0]=f<<16>>16!=d<<16>>16|0;a[808122|0]=(e&65535)>>>8&255;return}function NU(){var d=0,e=0,f=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=e;b[404048]=d+1&65535;d=(b[404043]|0)+(e&255)&65535;e=TP(d&65535)|0;a[808104]=e;f=TP(d+1&65535)|0;d=(f&255)<<8|e&255;a[808104]=f;f=b[404042]|0;e=d^f;b[404042]=e;a[808121|0]=f<<16>>16!=d<<16>>16|0;a[808122|0]=(e&65535)>>>8&255;return}function NV(){var d=0,e=0,f=0,g=0,h=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=e;b[404048]=d+1&65535;d=(b[404043]|0)+(e&255)&65535;e=d&65535;f=TP(e)|0;a[808104]=f;g=d+1&65535;d=TP(g)|0;a[808120|0]=f&1;h=(((d&255)<<8|f&255)&65535)>>>1;f=(d&255)>>>1;HY(f,g);g=h&255;HY(g,e);a[808104]=g;a[808121|0]=h<<16>>16!=0|0;a[808122|0]=f;return}function NW(){var d=0,e=0,f=0,g=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=e;b[404048]=d+1&65535;d=(b[404043]|0)+(e&255)&65535;e=TP(d)|0;a[808104]=e;f=TP(d+1|0)|0;a[808104]=f;g=TP(d+2|0)|0;a[808104]=g;d=((f&255)<<8|e&255)&65535|(g&255)<<16;g=TP(d)|0;a[808104]=g;e=TP(d+1|0)|0;d=(e&255)<<8|g&255;a[808104]=e;e=b[404042]|0;g=d^e;b[404042]=g;a[808121|0]=e<<16>>16!=d<<16>>16|0;a[808122|0]=(g&65535)>>>8&255;return}function NX(){var c=0,d=0;c=b[404042]|0;d=(e[404044]|0)-1|0;HY((c&65535)>>>8&255,(d&65535)+1&65535|d&-65536);HY(c&255,d);b[404044]=(b[404044]|0)-2&65535;a[808104]=a[808084]|0;return}function NY(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[202032]|0;f=c[202034]|0;g=b[404048]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[808104]=i;b[404048]=g+2&65535;g=j&65535|e;e=TP(g)|0;a[808104]=e;j=TP(g+1|0)|0;g=(j&255)<<8|e&255;a[808104]=j;j=b[404042]|0;e=g^j;b[404042]=e;a[808121]=j<<16>>16!=g<<16>>16|0;a[808122]=(e&65535)>>>8&255;return}function NZ(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[202032]|0;f=c[202034]|0;g=b[404048]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[808104]=i;b[404048]=g+2&65535;g=j&65535|e;e=TP(g)|0;a[808104]=e;j=g+1|0;i=TP(j)|0;a[808120]=e&1;h=(((i&255)<<8|e&255)&65535)>>>1;e=(i&255)>>>1;HY(e,j);j=h&255;HY(j,g);a[808104]=j;a[808121]=h<<16>>16!=0|0;a[808122]=e;return}function N_(){var e=0,f=0,g=0,h=0,i=0;e=c[202034]|0;f=b[404048]|0;g=f&65535;h=a[e+(g+2)|0]|0;i=(d[e+(g+1)|0]|0)<<8|(d[e+g|0]|0)|(h&255)<<16;a[808104]=h;b[404048]=f+3&65535;f=TP(i)|0;a[808104]=f;h=TP(i+1|0)|0;i=(h&255)<<8|f&255;a[808104]=h;h=b[404042]|0;f=i^h;b[404042]=f;a[808121]=h<<16>>16!=i<<16>>16|0;a[808122]=(f&65535)>>>8&255;return}function N$(){var d=0,f=0,g=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=(b[404043]|0)+(f&255)&65535;f=TP(d)|0;a[808104]=f;g=TP(d+1|0)|0;a[808104]=g;d=(((g&255)<<8|f&255)&65535|c[202032])+(e[404046]|0)|0;f=TP(d)|0;a[808104]=f;g=TP(d+1|0)|0;d=(g&255)<<8|f&255;a[808104]=g;g=b[404042]|0;f=d^g;b[404042]=f;a[808121]=g<<16>>16!=d<<16>>16|0;a[808122]=(f&65535)>>>8&255;return}function N0(){var d=0,e=0,f=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=e;b[404048]=d+1&65535;d=(b[404043]|0)+(e&255)&65535;e=TP(d)|0;a[808104]=e;f=TP(d+1|0)|0;a[808104]=f;d=((f&255)<<8|e&255)&65535|c[202032];e=TP(d)|0;a[808104]=e;f=TP(d+1|0)|0;d=(f&255)<<8|e&255;a[808104]=f;f=b[404042]|0;e=d^f;b[404042]=e;a[808121]=f<<16>>16!=d<<16>>16|0;a[808122]=(e&65535)>>>8&255;return}function N1(){var d=0,f=0,g=0;d=TP(c[202024]|0)|0;a[808104]=d;b[404048]=(b[404048]|0)+1&65535;f=(b[404044]|0)+(d&255)&65535;d=TP(f)|0;a[808104]=d;g=TP(f+1|0)|0;a[808104]=g;f=(c[202032]|0)+(e[404046]|0)+(((g&255)<<8|d&255)&65535)&16777215;d=TP(f)|0;a[808104]=d;g=TP(f+1|0)|0;f=(g&255)<<8|d&255;a[808104]=g;g=b[404042]|0;d=f^g;b[404042]=d;a[808121]=g<<16>>16!=f<<16>>16|0;a[808122]=(d&65535)>>>8&255;return}function N2(){var d=0,f=0,g=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=((b[404043]|0)+(f&255)&65535)+(e[404045]|0)|0;f=TP(d&65535)|0;a[808104]=f;g=TP((d&65535)+1&65535)|0;d=(g&255)<<8|f&255;a[808104]=g;g=b[404042]|0;f=d^g;b[404042]=f;a[808121]=g<<16>>16!=d<<16>>16|0;a[808122]=(f&65535)>>>8&255;return}function N3(){var d=0,f=0,g=0,h=0,i=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=((b[404043]|0)+(f&255)&65535)+(e[404045]|0)|0;f=d&65535;g=TP(f)|0;a[808104]=g;h=(d&65535)+1&65535;d=TP(h)|0;a[808120]=g&1;i=(((d&255)<<8|g&255)&65535)>>>1;g=(d&255)>>>1;HY(g,h);h=i&255;HY(h,f);a[808104]=h;a[808121]=i<<16>>16!=0|0;a[808122]=g;return}function N4(){var d=0,f=0,g=0,h=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=(b[404043]|0)+(f&255)&65535;f=TP(d)|0;a[808104]=f;g=TP(d+1|0)|0;a[808104]=g;h=TP(d+2|0)|0;a[808104]=h;d=(((g&255)<<8|f&255)&65535|(h&255)<<16)+(e[404046]|0)|0;h=TP(d)|0;a[808104]=h;f=TP(d+1|0)|0;d=(f&255)<<8|h&255;a[808104]=f;f=b[404042]|0;h=d^f;b[404042]=h;a[808121]=f<<16>>16!=d<<16>>16|0;a[808122]=(h&65535)>>>8&255;return}function N5(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=(k&65535|f)+(e[404046]|0)|0;f=TP(h)|0;a[808104]=f;k=TP(h+1|0)|0;h=(k&255)<<8|f&255;a[808104]=k;k=b[404042]|0;f=h^k;b[404042]=f;a[808121]=k<<16>>16!=h<<16>>16|0;a[808122]=(f&65535)>>>8&255;return}function N6(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=(k&65535|f)+(e[404045]|0)|0;f=TP(h)|0;a[808104]=f;k=TP(h+1|0)|0;h=(k&255)<<8|f&255;a[808104]=k;k=b[404042]|0;f=h^k;b[404042]=f;a[808121]=k<<16>>16!=h<<16>>16|0;a[808122]=(f&65535)>>>8&255;return}function N7(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=(k&65535|f)+(e[404045]|0)|0;f=TP(h)|0;a[808104]=f;k=h+1|0;j=TP(k)|0;a[808120]=f&1;i=(((j&255)<<8|f&255)&65535)>>>1;f=(j&255)>>>1;HY(f,k);k=i&255;HY(k,h);a[808104]=k;a[808121]=i<<16>>16!=0|0;a[808122]=f;return}function N8(){var f=0,g=0,h=0,i=0,j=0;f=c[202034]|0;g=b[404048]|0;h=g&65535;i=a[f+(h+2)|0]|0;j=(d[f+(h+1)|0]|0)<<8|(d[f+h|0]|0)|(i&255)<<16;a[808104]=i;b[404048]=g+3&65535;g=j+(e[404045]|0)|0;j=TP(g)|0;a[808104]=j;i=TP(g+1|0)|0;g=(i&255)<<8|j&255;a[808104]=i;i=b[404042]|0;j=g^i;b[404042]=j;a[808121]=i<<16>>16!=g<<16>>16|0;a[808122]=(j&65535)>>>8&255;return}function N9(){var d=0,f=0,g=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=((b[404043]|0)+(f&255)&65535)+(e[404045]|0)&65535;f=TP(d)|0;a[808104]=f;g=TP(d+1|0)|0;a[808104]=g;d=((g&255)<<8|f&255)&65535|c[202032];f=TP(d)|0;a[808104]=f;g=TP(d+1|0)|0;a[808104]=g;TR((g&255)<<8|f&255);return}function Oa(){var d=0,e=0,f=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=e;b[404048]=d+1&65535;d=(b[404044]|0)+(e&255)&65535;e=TP(d)|0;a[808104]=e;f=TP(d+1|0)|0;a[808104]=f;TR((f&255)<<8|e&255);return}function Ob(){var d=0,e=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;b[404048]=d+1&65535;d=(b[404043]|0)+(e&255)&65535;HY(0,d&65535);HY(0,d+1&65535);a[808104]=0;return}function Oc(){var d=0,e=0,f=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=e;b[404048]=d+1&65535;d=(b[404043]|0)+(e&255)&65535;e=TP(d&65535)|0;a[808104]=e;f=TP(d+1&65535)|0;a[808104]=f;TR((f&255)<<8|e&255);return}function Od(){var e=0,f=0,g=0,h=0,i=0;e=b[404048]|0;f=a[(c[202034]|0)+(e&65535)|0]|0;a[808104]=f;b[404048]=e+1&65535;e=(b[404043]|0)+(f&255)&65535;f=e&65535;g=TP(f)|0;a[808104]=g;h=e+1&65535;e=(((TP(h)|0)&255)<<8|g&255)&65535;i=e|(d[808120]|0)<<16;a[808120]=g&1;g=i>>>1;e=i>>>9&255;HY(e,h);h=g&255;HY(h,f);a[808104]=h;a[808121]=(g&65535|0)!=0|0;a[808122]=e;return}function Oe(){var d=0,e=0,f=0,g=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=e;b[404048]=d+1&65535;d=(b[404043]|0)+(e&255)&65535;e=TP(d)|0;a[808104]=e;f=TP(d+1|0)|0;a[808104]=f;g=TP(d+2|0)|0;a[808104]=g;d=((f&255)<<8|e&255)&65535|(g&255)<<16;g=TP(d)|0;a[808104]=g;e=TP(d+1|0)|0;a[808104]=e;TR((e&255)<<8|g&255);return}function Of(){var c=0,e=0;c=b[404042]|0;e=(d[808120]|0)<<16|c&65535;a[808120]=c&1;c=e>>>1;b[404042]=c&65535;a[808121]=(c&65535|0)!=0|0;a[808122]=e>>>9&255;return}function Og(){var c=0;c=b[404045]|0;b[404042]=c;a[808121|0]=c<<16>>16!=0|0;a[808122|0]=(c&65535)>>>8&255;return}function Oh(){var e=0,f=0,g=0,h=0,i=0,j=0;e=b[404042]|0;f=c[202034]|0;g=b[404048]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[808104]=i;b[404048]=g+2&65535;a[808121]=(j&e)<<16>>16!=0|0;return}function Oi(){var c=0,d=0,f=0;c=(e[404044]|0)+1|0;d=TP(c)|0;a[808104]=d;f=TP((c&65535)+1&65535|c&2147418112)|0;c=(f&255)<<8|d&255;b[404042]=c;b[404044]=(b[404044]|0)+2&65535;a[808121]=c<<16>>16!=0|0;a[808122]=f;a[808104]=f;return}function Oj(){var e=0,f=0,g=0,h=0,i=0;e=c[202034]|0;f=b[404048]|0;g=f&65535;h=a[e+(g+1)|0]|0;i=(h&255)<<8|(d[e+g|0]|0);a[808104]=h;b[404048]=f+2&65535;TR(i);return}function Ok(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[202032]|0;f=c[202034]|0;g=b[404048]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[808104]=i;b[404048]=g+2&65535;g=j&65535|e;e=TP(g)|0;a[808104]=e;j=TP(g+1|0)|0;a[808104]=j;TR((j&255)<<8|e&255);return}function Ol(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[202032]|0;f=c[202034]|0;g=b[404048]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[808104]=i;b[404048]=g+2&65535;g=j&65535|e;e=TP(g)|0;a[808104]=e;j=g+1|0;i=(((TP(j)|0)&255)<<8|e&255)&65535;h=i|(d[808120]|0)<<16;a[808120]=e&1;e=h>>>1;i=h>>>9&255;HY(i,j);j=e&255;HY(j,g);a[808104]=j;a[808121]=(e&65535|0)!=0|0;a[808122]=i;return}function Om(){var e=0,f=0,g=0,h=0,i=0;e=c[202034]|0;f=b[404048]|0;g=f&65535;h=a[e+(g+2)|0]|0;i=(d[e+(g+1)|0]|0)<<8|(d[e+g|0]|0)|(h&255)<<16;a[808104]=h;b[404048]=f+3&65535;f=TP(i)|0;a[808104]=f;h=TP(i+1|0)|0;a[808104]=h;TR((h&255)<<8|f&255);return}function On(){var d=0,f=0,g=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=(b[404043]|0)+(f&255)&65535;f=TP(d)|0;a[808104]=f;g=TP(d+1|0)|0;a[808104]=g;d=(((g&255)<<8|f&255)&65535|c[202032])+(e[404046]|0)|0;f=TP(d)|0;a[808104]=f;g=TP(d+1|0)|0;a[808104]=g;TR((g&255)<<8|f&255);return}function Oo(){var d=0,e=0,f=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=e;b[404048]=d+1&65535;d=(b[404043]|0)+(e&255)&65535;e=TP(d)|0;a[808104]=e;f=TP(d+1|0)|0;a[808104]=f;d=((f&255)<<8|e&255)&65535|c[202032];e=TP(d)|0;a[808104]=e;f=TP(d+1|0)|0;a[808104]=f;TR((f&255)<<8|e&255);return}function Op(){var d=0,f=0,g=0;d=TP(c[202024]|0)|0;a[808104]=d;b[404048]=(b[404048]|0)+1&65535;f=(b[404044]|0)+(d&255)&65535;d=TP(f)|0;a[808104]=d;g=TP(f+1|0)|0;a[808104]=g;f=(c[202032]|0)+(e[404046]|0)+(((g&255)<<8|d&255)&65535)&16777215;d=TP(f)|0;a[808104]=d;g=TP(f+1|0)|0;a[808104]=g;TR((g&255)<<8|d&255);return}function Oq(){var d=0,f=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;b[404048]=d+1&65535;d=((b[404043]|0)+(f&255)&65535)+(e[404045]|0)|0;HY(0,d&65535);HY(0,(d&65535)+1&65535);a[808104]=0;return}function Or(){var d=0,f=0,g=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=((b[404043]|0)+(f&255)&65535)+(e[404045]|0)|0;f=TP(d&65535)|0;a[808104]=f;g=TP((d&65535)+1&65535)|0;a[808104]=g;TR((g&255)<<8|f&255);return}function Os(){var f=0,g=0,h=0,i=0,j=0;f=b[404048]|0;g=a[(c[202034]|0)+(f&65535)|0]|0;a[808104]=g;b[404048]=f+1&65535;f=((b[404043]|0)+(g&255)&65535)+(e[404045]|0)|0;g=f&65535;h=TP(g)|0;a[808104]=h;i=(f&65535)+1&65535;f=(((TP(i)|0)&255)<<8|h&255)&65535;j=f|(d[808120]|0)<<16;a[808120]=h&1;h=j>>>1;f=j>>>9&255;HY(f,i);i=h&255;HY(i,g);a[808104]=i;a[808121]=(h&65535|0)!=0|0;a[808122]=f;return}function Ot(){var d=0,f=0,g=0,h=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=(b[404043]|0)+(f&255)&65535;f=TP(d)|0;a[808104]=f;g=TP(d+1|0)|0;a[808104]=g;h=TP(d+2|0)|0;a[808104]=h;d=(((g&255)<<8|f&255)&65535|(h&255)<<16)+(e[404046]|0)|0;h=TP(d)|0;a[808104]=h;f=TP(d+1|0)|0;a[808104]=f;TR((f&255)<<8|h&255);return}function Ou(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=(k&65535|f)+(e[404046]|0)|0;f=TP(h)|0;a[808104]=f;k=TP(h+1|0)|0;a[808104]=k;TR((k&255)<<8|f&255);return}function Ov(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=(k&65535|f)+(e[404045]|0)|0;f=TP(h)|0;a[808104]=f;k=TP(h+1|0)|0;a[808104]=k;TR((k&255)<<8|f&255);return}function Ow(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=(k&65535|f)+(e[404045]|0)|0;f=TP(h)|0;a[808104]=f;k=h+1|0;j=(((TP(k)|0)&255)<<8|f&255)&65535;i=j|(d[808120]|0)<<16;a[808120]=f&1;f=i>>>1;j=i>>>9&255;HY(j,k);k=f&255;HY(k,h);a[808104]=k;a[808121]=(f&65535|0)!=0|0;a[808122]=j;return}function Ox(){var f=0,g=0,h=0,i=0,j=0;f=c[202034]|0;g=b[404048]|0;h=g&65535;i=a[f+(h+2)|0]|0;j=(d[f+(h+1)|0]|0)<<8|(d[f+h|0]|0)|(i&255)<<16;a[808104]=i;b[404048]=g+3&65535;g=j+(e[404045]|0)|0;j=TP(g)|0;a[808104]=j;i=TP(g+1|0)|0;a[808104]=i;TR((i&255)<<8|j&255);return}function Oy(){var d=0,f=0,g=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=((b[404043]|0)+(f&255)&65535)+(e[404045]|0)&65535;f=TP(d)|0;a[808104]=f;g=(((TP(d+1|0)|0)&255)<<8|f&255)&65535;f=g|c[202032];g=b[404042]|0;HY(g&255,f);HY((g&65535)>>>8&255,f+1|0);a[808104]=a[808085|0]|0;return}function Oz(){var d=0,e=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;b[404048]=d+1&65535;d=(b[404044]|0)+(e&255)&65535;e=b[404042]|0;HY(e&255,d);HY((e&65535)>>>8&255,d+1|0);a[808104]=a[808085|0]|0;return}function OA(){var d=0,e=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;b[404048]=d+1&65535;d=(b[404043]|0)+(e&255)&65535;e=b[404042]|0;HY(e&255,d&65535);HY((e&65535)>>>8&255,d+1&65535);a[808104]=a[808085|0]|0;return}function OB(){var d=0,e=0,f=0,g=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=e;b[404048]=d+1&65535;d=(b[404043]|0)+(e&255)&65535;e=TP(d)|0;a[808104]=e;f=TP(d+1|0)|0;a[808104]=f;g=TP(d+2|0)|0;a[808104]=g;d=((f&255)<<8|e&255)&65535|(g&255)<<16;g=b[404042]|0;HY(g&255,d);HY((g&65535)>>>8&255,d+1|0);a[808104]=a[808085|0]|0;return}function OC(){var e=0,f=0,g=0,h=0,i=0;e=c[202032]|0;f=c[202034]|0;g=b[404048]|0;h=g&65535;i=(d[f+(h+1)|0]|0)<<8|(d[f+h|0]|0);b[404048]=g+2&65535;g=i&65535|e;e=b[404042]|0;HY(e&255,g);HY((e&65535)>>>8&255,g+1|0);a[808104]=a[808085|0]|0;return}function OD(){var e=0,f=0,g=0,h=0;e=c[202034]|0;f=b[404048]|0;g=f&65535;h=(d[e+(g+1)|0]|0)<<8|(d[e+g|0]|0)|(d[e+(g+2)|0]|0)<<16;b[404048]=f+3&65535;f=b[404042]|0;HY(f&255,h);HY((f&65535)>>>8&255,h+1|0);a[808104]=a[808085|0]|0;return}function OE(){var d=0,f=0,g=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=(b[404043]|0)+(f&255)&65535;f=TP(d)|0;a[808104]=f;g=(((TP(d+1|0)|0)&255)<<8|f&255)&65535;f=(g|c[202032])+(e[404046]|0)|0;g=b[404042]|0;HY(g&255,f);HY((g&65535)>>>8&255,f+1|0);a[808104]=a[808085|0]|0;return}function OF(){var d=0,e=0,f=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=e;b[404048]=d+1&65535;d=(b[404043]|0)+(e&255)&65535;e=TP(d)|0;a[808104]=e;f=(((TP(d+1|0)|0)&255)<<8|e&255)&65535;e=f|c[202032];f=b[404042]|0;HY(f&255,e);HY((f&65535)>>>8&255,e+1|0);a[808104]=a[808085|0]|0;return}function OG(){var d=0,f=0,g=0;d=TP(c[202024]|0)|0;a[808104]=d;b[404048]=(b[404048]|0)+1&65535;f=(b[404044]|0)+(d&255)&65535;d=TP(f)|0;a[808104]=d;g=(((TP(f+1|0)|0)&255)<<8|d&255)&65535;d=(c[202032]|0)+(e[404046]|0)+g&16777215;g=b[404042]|0;HY(g&255,d);HY((g&65535)>>>8&255,d+1|0);a[808104]=a[808085|0]|0;return}function OH(){var d=0,f=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;b[404048]=d+1&65535;d=((b[404043]|0)+(f&255)&65535)+(e[404045]|0)|0;f=b[404042]|0;HY(f&255,d&65535);HY((f&65535)>>>8&255,(d&65535)+1&65535);a[808104]=a[808085|0]|0;return}function OI(){var c=0;c=b[404046]|0;b[404042]=c;a[808121|0]=c<<16>>16!=0|0;a[808122|0]=(c&65535)>>>8&255;return}function OJ(){var e=0,f=0,g=0,h=0,i=0;e=c[202034]|0;f=b[404048]|0;g=f&65535;h=a[e+(g+1)|0]|0;i=(h&255)<<8|(d[e+g|0]|0);a[808104]=h;b[404048]=f+2&65535;b[404042]=i;a[808121]=i<<16>>16!=0|0;a[808122]=h;return}function OK(){var d=0,f=0,g=0,h=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=(b[404043]|0)+(f&255)&65535;f=TP(d)|0;a[808104]=f;g=TP(d+1|0)|0;a[808104]=g;h=TP(d+2|0)|0;a[808104]=h;d=(((g&255)<<8|f&255)&65535|(h&255)<<16)+(e[404046]|0)|0;h=b[404042]|0;HY(h&255,d);HY((h&65535)>>>8&255,d+1|0);a[808104]=a[808085|0]|0;return}function OL(){var f=0,g=0,h=0,i=0,j=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=(d[g+(i+1)|0]|0)<<8|(d[g+i|0]|0);b[404048]=h+2&65535;h=(j&65535|f)+(e[404046]|0)|0;f=b[404042]|0;HY(f&255,h);HY((f&65535)>>>8&255,h+1|0);a[808104]=a[808085|0]|0;return}function OM(){var e=0,f=0,g=0,h=0,i=0;e=c[202032]|0;f=c[202034]|0;g=b[404048]|0;h=g&65535;i=(d[f+(h+1)|0]|0)<<8|(d[f+h|0]|0);b[404048]=g+2&65535;g=i&65535|e;HY(0,g);HY(0,g+1|0);a[808104]=0;return}function ON(){var f=0,g=0,h=0,i=0,j=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=(d[g+(i+1)|0]|0)<<8|(d[g+i|0]|0);b[404048]=h+2&65535;h=(j&65535|f)+(e[404045]|0)|0;f=b[404042]|0;HY(f&255,h);HY((f&65535)>>>8&255,h+1|0);a[808104]=a[808085|0]|0;return}function OO(){var f=0,g=0,h=0,i=0,j=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=(d[g+(i+1)|0]|0)<<8|(d[g+i|0]|0);b[404048]=h+2&65535;h=(j&65535|f)+(e[404045]|0)|0;HY(0,h);HY(0,h+1|0);a[808104]=0;return}function OP(){var f=0,g=0,h=0,i=0;f=c[202034]|0;g=b[404048]|0;h=g&65535;i=(d[f+(h+1)|0]|0)<<8|(d[f+h|0]|0)|(d[f+(h+2)|0]|0)<<16;b[404048]=g+3&65535;g=i+(e[404045]|0)|0;i=b[404042]|0;HY(i&255,g);HY((i&65535)>>>8&255,g+1|0);a[808104]=a[808085|0]|0;return}function OQ(){var d=0,f=0,g=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=((b[404043]|0)+(f&255)&65535)+(e[404045]|0)&65535;f=TP(d)|0;a[808104]=f;g=TP(d+1|0)|0;a[808104]=g;d=((g&255)<<8|f&255)&65535|c[202032];f=TP(d)|0;a[808104]=f;g=TP(d+1|0)|0;d=(g&255)<<8|f&255;a[808104]=g;b[404042]=d;a[808121]=d<<16>>16!=0|0;a[808122]=g;return}function OR(){var d=0,e=0,f=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=e;b[404048]=d+1&65535;d=(b[404044]|0)+(e&255)&65535;e=TP(d)|0;a[808104]=e;f=TP(d+1|0)|0;d=(f&255)<<8|e&255;a[808104]=f;b[404042]=d;a[808121|0]=d<<16>>16!=0|0;a[808122|0]=f;return}function OS(){var d=0,e=0,f=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=e;b[404048]=d+1&65535;d=(b[404043]|0)+(e&255)&65535;e=TP(d&65535)|0;a[808104]=e;f=TP(d+1&65535)|0;d=(f&255)<<8|e&255;a[808104]=f;b[404042]=d;a[808121|0]=d<<16>>16!=0|0;a[808122|0]=f;return}function OT(){var d=0,e=0,f=0,g=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=e;b[404048]=d+1&65535;d=(b[404043]|0)+(e&255)&65535;e=TP(d)|0;a[808104]=e;f=TP(d+1|0)|0;a[808104]=f;g=TP(d+2|0)|0;a[808104]=g;d=((f&255)<<8|e&255)&65535|(g&255)<<16;g=TP(d)|0;a[808104]=g;e=TP(d+1|0)|0;d=(e&255)<<8|g&255;a[808104]=e;b[404042]=d;a[808121|0]=d<<16>>16!=0|0;a[808122|0]=e;return}function OU(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[202032]|0;f=c[202034]|0;g=b[404048]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[808104]=i;b[404048]=g+2&65535;g=j&65535|e;e=TP(g)|0;a[808104]=e;j=TP(g+1|0)|0;g=(j&255)<<8|e&255;a[808104]=j;b[404042]=g;a[808121]=g<<16>>16!=0|0;a[808122]=j;return}function OV(){var e=0,f=0,g=0,h=0,i=0;e=c[202034]|0;f=b[404048]|0;g=f&65535;h=a[e+(g+2)|0]|0;i=(d[e+(g+1)|0]|0)<<8|(d[e+g|0]|0)|(h&255)<<16;a[808104]=h;b[404048]=f+3&65535;f=TP(i)|0;a[808104]=f;h=TP(i+1|0)|0;i=(h&255)<<8|f&255;a[808104]=h;b[404042]=i;a[808121]=i<<16>>16!=0|0;a[808122]=h;return}function OW(){var d=0,f=0,g=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=(b[404043]|0)+(f&255)&65535;f=TP(d)|0;a[808104]=f;g=TP(d+1|0)|0;a[808104]=g;d=(((g&255)<<8|f&255)&65535|c[202032])+(e[404046]|0)|0;f=TP(d)|0;a[808104]=f;g=TP(d+1|0)|0;d=(g&255)<<8|f&255;a[808104]=g;b[404042]=d;a[808121]=d<<16>>16!=0|0;a[808122]=g;return}function OX(){var d=0,e=0,f=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=e;b[404048]=d+1&65535;d=(b[404043]|0)+(e&255)&65535;e=TP(d)|0;a[808104]=e;f=TP(d+1|0)|0;a[808104]=f;d=((f&255)<<8|e&255)&65535|c[202032];e=TP(d)|0;a[808104]=e;f=TP(d+1|0)|0;d=(f&255)<<8|e&255;a[808104]=f;b[404042]=d;a[808121]=d<<16>>16!=0|0;a[808122]=f;return}function OY(){var d=0,f=0,g=0;d=TP(c[202024]|0)|0;a[808104]=d;b[404048]=(b[404048]|0)+1&65535;f=(b[404044]|0)+(d&255)&65535;d=TP(f)|0;a[808104]=d;g=TP(f+1|0)|0;a[808104]=g;f=(c[202032]|0)+(e[404046]|0)+(((g&255)<<8|d&255)&65535)&16777215;d=TP(f)|0;a[808104]=d;g=TP(f+1|0)|0;f=(g&255)<<8|d&255;a[808104]=g;b[404042]=f;a[808121]=f<<16>>16!=0|0;a[808122]=g;return}function OZ(){var d=0,f=0,g=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=((b[404043]|0)+(f&255)&65535)+(e[404045]|0)|0;f=TP(d&65535)|0;a[808104]=f;g=TP((d&65535)+1&65535)|0;d=(g&255)<<8|f&255;a[808104]=g;b[404042]=d;a[808121]=d<<16>>16!=0|0;a[808122]=g;return}function O_(){var d=0,f=0,g=0,h=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=(b[404043]|0)+(f&255)&65535;f=TP(d)|0;a[808104]=f;g=TP(d+1|0)|0;a[808104]=g;h=TP(d+2|0)|0;a[808104]=h;d=(((g&255)<<8|f&255)&65535|(h&255)<<16)+(e[404046]|0)|0;h=TP(d)|0;a[808104]=h;f=TP(d+1|0)|0;d=(f&255)<<8|h&255;a[808104]=f;b[404042]=d;a[808121]=d<<16>>16!=0|0;a[808122]=f;return}function O$(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=(k&65535|f)+(e[404046]|0)|0;f=TP(h)|0;a[808104]=f;k=TP(h+1|0)|0;h=(k&255)<<8|f&255;a[808104]=k;b[404042]=h;a[808121]=h<<16>>16!=0|0;a[808122]=k;return}function O0(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=(k&65535|f)+(e[404045]|0)|0;f=TP(h)|0;a[808104]=f;k=TP(h+1|0)|0;h=(k&255)<<8|f&255;a[808104]=k;b[404042]=h;a[808121]=h<<16>>16!=0|0;a[808122]=k;return}function O1(){var f=0,g=0,h=0,i=0,j=0;f=c[202034]|0;g=b[404048]|0;h=g&65535;i=a[f+(h+2)|0]|0;j=(d[f+(h+1)|0]|0)<<8|(d[f+h|0]|0)|(i&255)<<16;a[808104]=i;b[404048]=g+3&65535;g=j+(e[404045]|0)|0;j=TP(g)|0;a[808104]=j;i=TP(g+1|0)|0;g=(i&255)<<8|j&255;a[808104]=i;b[404042]=g;a[808121]=g<<16>>16!=0|0;a[808122]=i;return}function O2(){var d=0,f=0,g=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=((b[404043]|0)+(f&255)&65535)+(e[404045]|0)&65535;f=TP(d)|0;a[808104]=f;g=TP(d+1|0)|0;a[808104]=g;d=((g&255)<<8|f&255)&65535|c[202032];f=TP(d)|0;a[808104]=f;g=TP(d+1|0)|0;a[808104]=g;d=(e[404042]|0)-(((g&255)<<8|f&255)&65535)|0;a[808120]=d>>>31&255^1;a[808121]=(d&65535|0)!=0|0;a[808122]=d>>>8&255;return}function O3(){var d=0,f=0,g=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=(b[404044]|0)+(f&255)&65535;f=TP(d)|0;a[808104]=f;g=TP(d+1|0)|0;a[808104]=g;d=(e[404042]|0)-(((g&255)<<8|f&255)&65535)|0;a[808120]=d>>>31&255^1;a[808121]=(d&65535|0)!=0|0;a[808122]=d>>>8&255;return}function O4(){var d=0,f=0,g=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=(b[404043]|0)+(f&255)&65535;f=TP(d&65535)|0;a[808104]=f;g=TP(d+1&65535)|0;a[808104]=g;d=(e[404042]|0)-(((g&255)<<8|f&255)&65535)|0;a[808120]=d>>>31&255^1;a[808121]=(d&65535|0)!=0|0;a[808122]=d>>>8&255;return}function O5(){var d=0,e=0,f=0,g=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=e;b[404048]=d+1&65535;d=(b[404043]|0)+(e&255)&65535;e=d&65535;f=TP(e)|0;a[808104]=f;g=d+1&65535;d=(((TP(g)|0)&255)<<8|f&255)-1&65535;f=(d&65535)>>>8&255;HY(f,g);g=d&255;HY(g,e);a[808104]=g;a[808121|0]=d<<16>>16!=0|0;a[808122|0]=f;return}function O6(){var f=0,g=0,h=0,i=0,j=0,k=0;f=e[404042]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=f-(k&65535)|0;a[808120]=h>>>31&255^1;a[808121]=(h&65535|0)!=0|0;a[808122]=h>>>8&255;return}function O7(){var d=0,f=0,g=0,h=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=(b[404043]|0)+(f&255)&65535;f=TP(d)|0;a[808104]=f;g=TP(d+1|0)|0;a[808104]=g;h=TP(d+2|0)|0;a[808104]=h;d=((g&255)<<8|f&255)&65535|(h&255)<<16;h=TP(d)|0;a[808104]=h;f=TP(d+1|0)|0;a[808104]=f;d=(e[404042]|0)-(((f&255)<<8|h&255)&65535)|0;a[808120]=d>>>31&255^1;a[808121]=(d&65535|0)!=0|0;a[808122]=d>>>8&255;return}function O8(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=k&65535|f;f=TP(h)|0;a[808104]=f;k=TP(h+1|0)|0;a[808104]=k;h=(e[404042]|0)-(((k&255)<<8|f&255)&65535)|0;a[808120]=h>>>31&255^1;a[808121]=(h&65535|0)!=0|0;a[808122]=h>>>8&255;return}function O9(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[202032]|0;f=c[202034]|0;g=b[404048]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[808104]=i;b[404048]=g+2&65535;g=j&65535|e;e=TP(g)|0;a[808104]=e;j=g+1|0;i=(((TP(j)|0)&255)<<8|e&255)-1&65535;e=(i&65535)>>>8&255;HY(e,j);j=i&255;HY(j,g);a[808104]=j;a[808121]=i<<16>>16!=0|0;a[808122]=e;return}function Pa(){var f=0,g=0,h=0,i=0,j=0;f=c[202034]|0;g=b[404048]|0;h=g&65535;i=a[f+(h+2)|0]|0;j=(d[f+(h+1)|0]|0)<<8|(d[f+h|0]|0)|(i&255)<<16;a[808104]=i;b[404048]=g+3&65535;g=TP(j)|0;a[808104]=g;i=TP(j+1|0)|0;a[808104]=i;j=(e[404042]|0)-(((i&255)<<8|g&255)&65535)|0;a[808120]=j>>>31&255^1;a[808121]=(j&65535|0)!=0|0;a[808122]=j>>>8&255;return}function Pb(){var d=0,f=0,g=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=(b[404043]|0)+(f&255)&65535;f=TP(d)|0;a[808104]=f;g=TP(d+1|0)|0;a[808104]=g;d=(((g&255)<<8|f&255)&65535|c[202032])+(e[404046]|0)|0;f=TP(d)|0;a[808104]=f;g=TP(d+1|0)|0;a[808104]=g;d=(e[404042]|0)-(((g&255)<<8|f&255)&65535)|0;a[808120]=d>>>31&255^1;a[808121]=(d&65535|0)!=0|0;a[808122]=d>>>8&255;return}function Pc(){var d=0,f=0,g=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=(b[404043]|0)+(f&255)&65535;f=TP(d)|0;a[808104]=f;g=TP(d+1|0)|0;a[808104]=g;d=((g&255)<<8|f&255)&65535|c[202032];f=TP(d)|0;a[808104]=f;g=TP(d+1|0)|0;a[808104]=g;d=(e[404042]|0)-(((g&255)<<8|f&255)&65535)|0;a[808120]=d>>>31&255^1;a[808121]=(d&65535|0)!=0|0;a[808122]=d>>>8&255;return}function Pd(){var d=0,f=0,g=0;d=TP(c[202024]|0)|0;a[808104]=d;b[404048]=(b[404048]|0)+1&65535;f=(b[404044]|0)+(d&255)&65535;d=TP(f)|0;a[808104]=d;g=TP(f+1|0)|0;a[808104]=g;f=(c[202032]|0)+(e[404046]|0)+(((g&255)<<8|d&255)&65535)&16777215;d=TP(f)|0;a[808104]=d;g=TP(f+1|0)|0;a[808104]=g;f=(e[404042]|0)-(((g&255)<<8|d&255)&65535)|0;a[808120]=f>>>31&255^1;a[808121]=(f&65535|0)!=0|0;a[808122]=f>>>8&255;return}function Pe(){var d=0,f=0,g=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=((b[404043]|0)+(f&255)&65535)+(e[404045]|0)|0;f=TP(d&65535)|0;a[808104]=f;g=TP((d&65535)+1&65535)|0;a[808104]=g;d=(e[404042]|0)-(((g&255)<<8|f&255)&65535)|0;a[808120]=d>>>31&255^1;a[808121]=(d&65535|0)!=0|0;a[808122]=d>>>8&255;return}function Pf(){var d=0,f=0,g=0,h=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=((b[404043]|0)+(f&255)&65535)+(e[404045]|0)|0;f=d&65535;g=TP(f)|0;a[808104]=g;h=(d&65535)+1&65535;d=(((TP(h)|0)&255)<<8|g&255)-1&65535;g=(d&65535)>>>8&255;HY(g,h);h=d&255;HY(h,f);a[808104]=h;a[808121]=d<<16>>16!=0|0;a[808122]=g;return}function Pg(){var d=0,f=0,g=0,h=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=(b[404043]|0)+(f&255)&65535;f=TP(d)|0;a[808104]=f;g=TP(d+1|0)|0;a[808104]=g;h=TP(d+2|0)|0;a[808104]=h;d=(((g&255)<<8|f&255)&65535|(h&255)<<16)+(e[404046]|0)|0;h=TP(d)|0;a[808104]=h;f=TP(d+1|0)|0;a[808104]=f;d=(e[404042]|0)-(((f&255)<<8|h&255)&65535)|0;a[808120]=d>>>31&255^1;a[808121]=(d&65535|0)!=0|0;a[808122]=d>>>8&255;return}function Ph(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=(k&65535|f)+(e[404046]|0)|0;f=TP(h)|0;a[808104]=f;k=TP(h+1|0)|0;a[808104]=k;h=(e[404042]|0)-(((k&255)<<8|f&255)&65535)|0;a[808120]=h>>>31&255^1;a[808121]=(h&65535|0)!=0|0;a[808122]=h>>>8&255;return}function Pi(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=(k&65535|f)+(e[404045]|0)|0;f=TP(h)|0;a[808104]=f;k=TP(h+1|0)|0;a[808104]=k;h=(e[404042]|0)-(((k&255)<<8|f&255)&65535)|0;a[808120]=h>>>31&255^1;a[808121]=(h&65535|0)!=0|0;a[808122]=h>>>8&255;return}function Pj(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=(k&65535|f)+(e[404045]|0)|0;f=TP(h)|0;a[808104]=f;k=h+1|0;j=(((TP(k)|0)&255)<<8|f&255)-1&65535;f=(j&65535)>>>8&255;HY(f,k);k=j&255;HY(k,h);a[808104]=k;a[808121]=j<<16>>16!=0|0;a[808122]=f;return}function Pk(){var f=0,g=0,h=0,i=0,j=0;f=c[202034]|0;g=b[404048]|0;h=g&65535;i=a[f+(h+2)|0]|0;j=(d[f+(h+1)|0]|0)<<8|(d[f+h|0]|0)|(i&255)<<16;a[808104]=i;b[404048]=g+3&65535;g=j+(e[404045]|0)|0;j=TP(g)|0;a[808104]=j;i=TP(g+1|0)|0;a[808104]=i;g=(e[404042]|0)-(((i&255)<<8|j&255)&65535)|0;a[808120]=g>>>31&255^1;a[808121]=(g&65535|0)!=0|0;a[808122]=g>>>8&255;return}function Pl(){var d=0,f=0,g=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=((b[404043]|0)+(f&255)&65535)+(e[404045]|0)&65535;f=TP(d)|0;a[808104]=f;g=TP(d+1|0)|0;a[808104]=g;d=((g&255)<<8|f&255)&65535|c[202032];f=TP(d)|0;a[808104]=f;g=TP(d+1|0)|0;a[808104]=g;TQ((g&255)<<8|f&255);return}function Pm(){var d=0,e=0,f=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=e;b[404048]=d+1&65535;d=(b[404044]|0)+(e&255)&65535;e=TP(d)|0;a[808104]=e;f=TP(d+1|0)|0;a[808104]=f;TQ((f&255)<<8|e&255);return}function Pn(){var d=0,e=0,f=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=e;b[404048]=d+1&65535;d=(b[404043]|0)+(e&255)&65535;e=TP(d&65535)|0;a[808104]=e;f=TP(d+1&65535)|0;a[808104]=f;TQ((f&255)<<8|e&255);return}function Po(){var d=0,e=0,f=0,g=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=e;b[404048]=d+1&65535;d=(b[404043]|0)+(e&255)&65535;e=d&65535;f=TP(e)|0;a[808104]=f;g=d+1&65535;d=(((TP(g)|0)&255)<<8|f&255)+1&65535;f=(d&65535)>>>8&255;HY(f,g);g=d&255;HY(g,e);a[808104]=g;a[808121|0]=d<<16>>16!=0|0;a[808122|0]=f;return}function Pp(){var d=0,e=0,f=0,g=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=e;b[404048]=d+1&65535;d=(b[404043]|0)+(e&255)&65535;e=TP(d)|0;a[808104]=e;f=TP(d+1|0)|0;a[808104]=f;g=TP(d+2|0)|0;a[808104]=g;d=((f&255)<<8|e&255)&65535|(g&255)<<16;g=TP(d)|0;a[808104]=g;e=TP(d+1|0)|0;a[808104]=e;TQ((e&255)<<8|g&255);return}function Pq(){var e=0,f=0,g=0,h=0,i=0;e=c[202034]|0;f=b[404048]|0;g=f&65535;h=a[e+(g+1)|0]|0;i=(h&255)<<8|(d[e+g|0]|0);a[808104]=h;b[404048]=f+2&65535;TQ(i);return}function Pr(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[202032]|0;f=c[202034]|0;g=b[404048]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[808104]=i;b[404048]=g+2&65535;g=j&65535|e;e=TP(g)|0;a[808104]=e;j=TP(g+1|0)|0;a[808104]=j;TQ((j&255)<<8|e&255);return}function Ps(){var e=0,f=0,g=0,h=0,i=0,j=0;e=c[202032]|0;f=c[202034]|0;g=b[404048]|0;h=g&65535;i=a[f+(h+1)|0]|0;j=(i&255)<<8|(d[f+h|0]|0);a[808104]=i;b[404048]=g+2&65535;g=j&65535|e;e=TP(g)|0;a[808104]=e;j=g+1|0;i=(((TP(j)|0)&255)<<8|e&255)+1&65535;e=(i&65535)>>>8&255;HY(e,j);j=i&255;HY(j,g);a[808104]=j;a[808121]=i<<16>>16!=0|0;a[808122]=e;return}function Pt(){var e=0,f=0,g=0,h=0,i=0;e=c[202034]|0;f=b[404048]|0;g=f&65535;h=a[e+(g+2)|0]|0;i=(d[e+(g+1)|0]|0)<<8|(d[e+g|0]|0)|(h&255)<<16;a[808104]=h;b[404048]=f+3&65535;f=TP(i)|0;a[808104]=f;h=TP(i+1|0)|0;a[808104]=h;TQ((h&255)<<8|f&255);return}function Pu(){var d=0,f=0,g=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=(b[404043]|0)+(f&255)&65535;f=TP(d)|0;a[808104]=f;g=TP(d+1|0)|0;a[808104]=g;d=(((g&255)<<8|f&255)&65535|c[202032])+(e[404046]|0)|0;f=TP(d)|0;a[808104]=f;g=TP(d+1|0)|0;a[808104]=g;TQ((g&255)<<8|f&255);return}function Pv(){var d=0,e=0,f=0;d=b[404048]|0;e=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=e;b[404048]=d+1&65535;d=(b[404043]|0)+(e&255)&65535;e=TP(d)|0;a[808104]=e;f=TP(d+1|0)|0;a[808104]=f;d=((f&255)<<8|e&255)&65535|c[202032];e=TP(d)|0;a[808104]=e;f=TP(d+1|0)|0;a[808104]=f;TQ((f&255)<<8|e&255);return}function Pw(){var d=0,f=0,g=0;d=TP(c[202024]|0)|0;a[808104]=d;b[404048]=(b[404048]|0)+1&65535;f=(b[404044]|0)+(d&255)&65535;d=TP(f)|0;a[808104]=d;g=TP(f+1|0)|0;a[808104]=g;f=(c[202032]|0)+(e[404046]|0)+(((g&255)<<8|d&255)&65535)&16777215;d=TP(f)|0;a[808104]=d;g=TP(f+1|0)|0;a[808104]=g;TQ((g&255)<<8|d&255);return}function Px(){var d=0,f=0,g=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=((b[404043]|0)+(f&255)&65535)+(e[404045]|0)|0;f=TP(d&65535)|0;a[808104]=f;g=TP((d&65535)+1&65535)|0;a[808104]=g;TQ((g&255)<<8|f&255);return}function Py(){var d=0,f=0,g=0,h=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=((b[404043]|0)+(f&255)&65535)+(e[404045]|0)|0;f=d&65535;g=TP(f)|0;a[808104]=g;h=(d&65535)+1&65535;d=(((TP(h)|0)&255)<<8|g&255)+1&65535;g=(d&65535)>>>8&255;HY(g,h);h=d&255;HY(h,f);a[808104]=h;a[808121]=d<<16>>16!=0|0;a[808122]=g;return}function Pz(){var d=0,f=0,g=0,h=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=(b[404043]|0)+(f&255)&65535;f=TP(d)|0;a[808104]=f;g=TP(d+1|0)|0;a[808104]=g;h=TP(d+2|0)|0;a[808104]=h;d=(((g&255)<<8|f&255)&65535|(h&255)<<16)+(e[404046]|0)|0;h=TP(d)|0;a[808104]=h;f=TP(d+1|0)|0;a[808104]=f;TQ((f&255)<<8|h&255);return}function PA(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=(k&65535|f)+(e[404046]|0)|0;f=TP(h)|0;a[808104]=f;k=TP(h+1|0)|0;a[808104]=k;TQ((k&255)<<8|f&255);return}function PB(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=(k&65535|f)+(e[404045]|0)|0;f=TP(h)|0;a[808104]=f;k=TP(h+1|0)|0;a[808104]=k;TQ((k&255)<<8|f&255);return}function PC(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=(k&65535|f)+(e[404045]|0)|0;f=TP(h)|0;a[808104]=f;k=h+1|0;j=(((TP(k)|0)&255)<<8|f&255)+1&65535;f=(j&65535)>>>8&255;HY(f,k);k=j&255;HY(k,h);a[808104]=k;a[808121]=j<<16>>16!=0|0;a[808122]=f;return}function PD(){var f=0,g=0,h=0,i=0,j=0;f=c[202034]|0;g=b[404048]|0;h=g&65535;i=a[f+(h+2)|0]|0;j=(d[f+(h+1)|0]|0)<<8|(d[f+h|0]|0)|(i&255)<<16;a[808104]=i;b[404048]=g+3&65535;g=j+(e[404045]|0)|0;j=TP(g)|0;a[808104]=j;i=TP(g+1|0)|0;a[808104]=i;TQ((i&255)<<8|j&255);return}function PE(){var d=0,f=0,g=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=(b[404043]|0)+(f&255)&65535;f=TP(d)|0;a[808104]=f;g=TP(d+1|0)|0;a[808104]=g;d=(((g&255)<<8|f&255)&65535|c[202032])+(e[404046]|0)|0;f=TP(d)|0;a[808104]=f;g=TP(d+1|0)|0;a[808104]=g;d=b[404042]|f&255|(g&255)<<8;b[404042]=d;a[808121]=d<<16>>16!=0|0;a[808122]=(d&65535)>>>8&255;return}function PF(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=(k&65535|f)+(e[404046]|0)|0;f=TP(h)|0;a[808104]=f;k=TP(h+1|0)|0;a[808104]=k;h=b[404042]|f&255|(k&255)<<8;b[404042]=h;a[808121]=h<<16>>16!=0|0;a[808122]=(h&65535)>>>8&255;return}function PG(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=(k&65535|f)+(e[404045]|0)|0;f=TP(h)|0;a[808104]=f;k=TP(h+1|0)|0;a[808104]=k;h=b[404042]|f&255|(k&255)<<8;b[404042]=h;a[808121]=h<<16>>16!=0|0;a[808122]=(h&65535)>>>8&255;return}function PH(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=(k&65535|f)+(e[404045]|0)|0;f=TP(h)|0;a[808104]=f;k=h+1|0;j=TP(k)|0;i=(j&255)<<8|f&255;a[808120]=(j&255)>>>7;j=i<<1;f=(i&65535)>>>7&255;HY(f,k);k=j&255;HY(k,h);a[808104]=k;a[808121]=j<<16>>16!=0|0;a[808122]=f;return}function PI(){var d=0,f=0,g=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=(b[404043]|0)+(f&255)&65535;f=TP(d)|0;a[808104]=f;g=TP(d+1|0)|0;a[808104]=g;d=(((g&255)<<8|f&255)&65535|c[202032])+(e[404046]|0)|0;f=TP(d)|0;a[808104]=f;g=TP(d+1|0)|0;a[808104]=g;d=((g&255)<<8|f&255)&b[404042];b[404042]=d;a[808121]=d<<16>>16!=0|0;a[808122]=(d&65535)>>>8&255;return}function PJ(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=(k&65535|f)+(e[404046]|0)|0;f=TP(h)|0;a[808104]=f;k=TP(h+1|0)|0;a[808104]=k;h=((k&255)<<8|f&255)&b[404042];b[404042]=h;a[808121]=h<<16>>16!=0|0;a[808122]=(h&65535)>>>8&255;return}function PK(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=(k&65535|f)+(e[404045]|0)|0;f=TP(h)|0;a[808104]=f;k=TP(h+1|0)|0;a[808104]=k;a[808123]=(k&255)>>>6&1;a[808122]=k;a[808121]=(((k&255)<<8|f&255)&b[404042])<<16>>16!=0|0;return}function PL(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=(k&65535|f)+(e[404045]|0)|0;f=TP(h)|0;a[808104]=f;k=TP(h+1|0)|0;a[808104]=k;h=((k&255)<<8|f&255)&b[404042];b[404042]=h;a[808121]=h<<16>>16!=0|0;a[808122]=(h&65535)>>>8&255;return}function PM(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=(k&65535|f)+(e[404045]|0)|0;f=TP(h)|0;a[808104]=f;k=h+1|0;j=((TP(k)|0)&255)<<8|f&255;f=(j&65535)<<1|(d[808120]|0);a[808120]=f>>>0>65535|0;i=(j&65535)>>>7&255;HY(i,k);k=f&255;HY(k,h);a[808104]=k;a[808121]=(f&65535|0)!=0|0;a[808122]=i;return}function PN(){var d=0,f=0,g=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=(b[404043]|0)+(f&255)&65535;f=TP(d)|0;a[808104]=f;g=TP(d+1|0)|0;a[808104]=g;d=(((g&255)<<8|f&255)&65535|c[202032])+(e[404046]|0)|0;f=TP(d)|0;a[808104]=f;g=TP(d+1|0)|0;d=(g&255)<<8|f&255;a[808104]=g;g=b[404042]|0;f=d^g;b[404042]=f;a[808121]=g<<16>>16!=d<<16>>16|0;a[808122]=(f&65535)>>>8&255;return}function PO(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=(k&65535|f)+(e[404046]|0)|0;f=TP(h)|0;a[808104]=f;k=TP(h+1|0)|0;h=(k&255)<<8|f&255;a[808104]=k;k=b[404042]|0;f=h^k;b[404042]=f;a[808121]=k<<16>>16!=h<<16>>16|0;a[808122]=(f&65535)>>>8&255;return}function PP(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=(k&65535|f)+(e[404045]|0)|0;f=TP(h)|0;a[808104]=f;k=TP(h+1|0)|0;h=(k&255)<<8|f&255;a[808104]=k;k=b[404042]|0;f=h^k;b[404042]=f;a[808121]=k<<16>>16!=h<<16>>16|0;a[808122]=(f&65535)>>>8&255;return}function PQ(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=(k&65535|f)+(e[404045]|0)|0;f=TP(h)|0;a[808104]=f;k=h+1|0;j=TP(k)|0;a[808120]=f&1;i=(((j&255)<<8|f&255)&65535)>>>1;f=(j&255)>>>1;HY(f,k);k=i&255;HY(k,h);a[808104]=k;a[808121]=i<<16>>16!=0|0;a[808122]=f;return}function PR(){var d=0,f=0,g=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=(b[404043]|0)+(f&255)&65535;f=TP(d)|0;a[808104]=f;g=TP(d+1|0)|0;a[808104]=g;d=(((g&255)<<8|f&255)&65535|c[202032])+(e[404046]|0)|0;f=TP(d)|0;a[808104]=f;g=TP(d+1|0)|0;a[808104]=g;TR((g&255)<<8|f&255);return}function PS(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=(k&65535|f)+(e[404046]|0)|0;f=TP(h)|0;a[808104]=f;k=TP(h+1|0)|0;a[808104]=k;TR((k&255)<<8|f&255);return}function PT(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=(k&65535|f)+(e[404045]|0)|0;f=TP(h)|0;a[808104]=f;k=TP(h+1|0)|0;a[808104]=k;TR((k&255)<<8|f&255);return}function PU(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=(k&65535|f)+(e[404045]|0)|0;f=TP(h)|0;a[808104]=f;k=h+1|0;j=(((TP(k)|0)&255)<<8|f&255)&65535;i=j|(d[808120]|0)<<16;a[808120]=f&1;f=i>>>1;j=i>>>9&255;HY(j,k);k=f&255;HY(k,h);a[808104]=k;a[808121]=(f&65535|0)!=0|0;a[808122]=j;return}function PV(){var d=0,f=0,g=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=(b[404043]|0)+(f&255)&65535;f=TP(d)|0;a[808104]=f;g=(((TP(d+1|0)|0)&255)<<8|f&255)&65535;f=(g|c[202032])+(e[404046]|0)|0;g=b[404042]|0;HY(g&255,f);HY((g&65535)>>>8&255,f+1|0);a[808104]=a[808085|0]|0;return}function PW(){var f=0,g=0,h=0,i=0,j=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=(d[g+(i+1)|0]|0)<<8|(d[g+i|0]|0);b[404048]=h+2&65535;h=(j&65535|f)+(e[404046]|0)|0;f=b[404042]|0;HY(f&255,h);HY((f&65535)>>>8&255,h+1|0);a[808104]=a[808085|0]|0;return}function PX(){var f=0,g=0,h=0,i=0,j=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=(d[g+(i+1)|0]|0)<<8|(d[g+i|0]|0);b[404048]=h+2&65535;h=(j&65535|f)+(e[404045]|0)|0;f=b[404042]|0;HY(f&255,h);HY((f&65535)>>>8&255,h+1|0);a[808104]=a[808085|0]|0;return}function PY(){var f=0,g=0,h=0,i=0,j=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=(d[g+(i+1)|0]|0)<<8|(d[g+i|0]|0);b[404048]=h+2&65535;h=(j&65535|f)+(e[404045]|0)|0;HY(0,h);HY(0,h+1|0);a[808104]=0;return}function PZ(){var d=0,f=0,g=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=(b[404043]|0)+(f&255)&65535;f=TP(d)|0;a[808104]=f;g=TP(d+1|0)|0;a[808104]=g;d=(((g&255)<<8|f&255)&65535|c[202032])+(e[404046]|0)|0;f=TP(d)|0;a[808104]=f;g=TP(d+1|0)|0;d=(g&255)<<8|f&255;a[808104]=g;b[404042]=d;a[808121]=d<<16>>16!=0|0;a[808122]=g;return}function P_(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=(k&65535|f)+(e[404046]|0)|0;f=TP(h)|0;a[808104]=f;k=TP(h+1|0)|0;h=(k&255)<<8|f&255;a[808104]=k;b[404042]=h;a[808121]=h<<16>>16!=0|0;a[808122]=k;return}function P$(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=(k&65535|f)+(e[404045]|0)|0;f=TP(h)|0;a[808104]=f;k=TP(h+1|0)|0;h=(k&255)<<8|f&255;a[808104]=k;b[404042]=h;a[808121]=h<<16>>16!=0|0;a[808122]=k;return}function P0(){var d=0,f=0,g=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=(b[404043]|0)+(f&255)&65535;f=TP(d)|0;a[808104]=f;g=TP(d+1|0)|0;a[808104]=g;d=(((g&255)<<8|f&255)&65535|c[202032])+(e[404046]|0)|0;f=TP(d)|0;a[808104]=f;g=TP(d+1|0)|0;a[808104]=g;d=(e[404042]|0)-(((g&255)<<8|f&255)&65535)|0;a[808120]=d>>>31&255^1;a[808121]=(d&65535|0)!=0|0;a[808122]=d>>>8&255;return}function P1(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=(k&65535|f)+(e[404046]|0)|0;f=TP(h)|0;a[808104]=f;k=TP(h+1|0)|0;a[808104]=k;h=(e[404042]|0)-(((k&255)<<8|f&255)&65535)|0;a[808120]=h>>>31&255^1;a[808121]=(h&65535|0)!=0|0;a[808122]=h>>>8&255;return}function P2(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=(k&65535|f)+(e[404045]|0)|0;f=TP(h)|0;a[808104]=f;k=TP(h+1|0)|0;a[808104]=k;h=(e[404042]|0)-(((k&255)<<8|f&255)&65535)|0;a[808120]=h>>>31&255^1;a[808121]=(h&65535|0)!=0|0;a[808122]=h>>>8&255;return}function P3(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=(k&65535|f)+(e[404045]|0)|0;f=TP(h)|0;a[808104]=f;k=h+1|0;j=(((TP(k)|0)&255)<<8|f&255)-1&65535;f=(j&65535)>>>8&255;HY(f,k);k=j&255;HY(k,h);a[808104]=k;a[808121]=j<<16>>16!=0|0;a[808122]=f;return}function P4(){var d=0,f=0,g=0;d=b[404048]|0;f=a[(c[202034]|0)+(d&65535)|0]|0;a[808104]=f;b[404048]=d+1&65535;d=(b[404043]|0)+(f&255)&65535;f=TP(d)|0;a[808104]=f;g=TP(d+1|0)|0;a[808104]=g;d=(((g&255)<<8|f&255)&65535|c[202032])+(e[404046]|0)|0;f=TP(d)|0;a[808104]=f;g=TP(d+1|0)|0;a[808104]=g;TQ((g&255)<<8|f&255);return}function P5(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=(k&65535|f)+(e[404046]|0)|0;f=TP(h)|0;a[808104]=f;k=TP(h+1|0)|0;a[808104]=k;TQ((k&255)<<8|f&255);return}function P6(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=(k&65535|f)+(e[404045]|0)|0;f=TP(h)|0;a[808104]=f;k=TP(h+1|0)|0;a[808104]=k;TQ((k&255)<<8|f&255);return}function P7(){var f=0,g=0,h=0,i=0,j=0,k=0;f=c[202032]|0;g=c[202034]|0;h=b[404048]|0;i=h&65535;j=a[g+(i+1)|0]|0;k=(j&255)<<8|(d[g+i|0]|0);a[808104]=j;b[404048]=h+2&65535;h=(k&65535|f)+(e[404045]|0)|0;f=TP(h)|0;a[808104]=f;k=h+1|0;j=(((TP(k)|0)&255)<<8|f&255)+1&65535;f=(j&65535)>>>8&255;HY(f,k);k=j&255;HY(k,h);a[808104]=k;a[808121]=j<<16>>16!=0|0;a[808122]=f;return}function P8(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=(a[808082]&32)==0;e=TP(c[202024]|0)|0;a[808104]=e;b[404048]=(b[404048]|0)+1&65535;f=b[404043]|0;g=f+(e&255)&65535;e=(g&65535)>>>8;h=(b[404041]&256)==0;i=f&255;if(i<<24>>24==0&(h^1)){j=((a[808090]|0)+(g&255)&255|e<<8)&65535;k=3146}else{f=(b[404045]|0)+(e<<8|g&255)&65535;if(h){l=65535;m=f}else{j=f;k=3146}}if((k|0)==3146){l=i<<24>>24!=0?65535:255;m=j}j=TV(m,l)|0;a[808104]=(j&65535)>>>8&255;l=c[202032]|j&65535;if(d){d=TP(l)|0;a[808104]=d;j=TP(l+1|0)|0;a[808104]=j;m=b[404042]|d&255|(j&255)<<8;b[404042]=m;a[808121]=m<<16>>16!=0|0;n=(m&65535)>>>8&255;a[808122]=n;return}else{m=TP(l)|0;a[808104]=m;l=a[808084]|m;a[808084]=l;a[808121]=l;n=l;a[808122]=n;return}}function P9(){var d=0,e=0,f=0,g=0,h=0;d=(a[808082]&32)==0;e=TP(c[202024]|0)|0;a[808104]=e;b[404048]=(b[404048]|0)+1&65535;f=(b[404044]|0)+(e&255)&65535;if(d){d=TP(f)|0;a[808104]=d;e=TP(f+1|0)|0;a[808104]=e;g=b[404042]|d&255|(e&255)<<8;b[404042]=g;a[808121]=g<<16>>16!=0|0;h=(g&65535)>>>8&255;a[808122]=h;return}else{g=TP(f)|0;a[808104]=g;f=a[808084]|g;a[808084]=f;a[808121]=f;h=f;a[808122]=h;return}}function Qa(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=(a[808082]&32)==0;e=TP(c[202024]|0)|0;a[808104]=e;b[404048]=(b[404048]|0)+1&65535;f=(b[404043]|0)+(e&255)&65535;e=f&65535;g=TP(e)|0;if(d){a[808104]=g;d=f+1&65535;f=((TP(d)|0)&255)<<8|g&255;h=b[404042]|0;a[808121]=(f&h)<<16>>16!=0|0;i=f|h;HY((i&65535)>>>8&255,d);d=i&255;HY(d,e);j=d;a[808104]=j;return}else{d=a[808084]|0;a[808121]=d&g;i=d|g;HY(i,e);j=i;a[808104]=j;return}}function Qb(){var d=0,e=0,f=0,g=0,h=0;d=(a[808082]&32)==0;e=TP(c[202024]|0)|0;a[808104]=e;b[404048]=(b[404048]|0)+1&65535;f=(b[404043]|0)+(e&255)&65535;e=f&65535;if(d){d=TP(e)|0;a[808104]=d;g=TP(f+1&65535)|0;a[808104]=g;f=b[404042]|d&255|(g&255)<<8;b[404042]=f;a[808121]=f<<16>>16!=0|0;h=(f&65535)>>>8&255;a[808122]=h;return}else{f=TP(e)|0;a[808104]=f;e=a[808084]|f;a[808084]=e;a[808121]=e;h=e;a[808122]=h;return}}function Qc(){var c=0,e=0,f=0;if((a[808082]&32)==0){a[808120]=(d[808085|0]|0)>>>7;c=b[404042]|0;e=c<<1;b[404042]=e;a[808121]=e<<16>>16!=0|0;f=(c&65535)>>>7&255;a[808122]=f;return}else{c=a[808084]|0;a[808120]=(c&255)>>>7;e=c<<1;a[808084]=e;a[808121]=e;f=e;a[808122]=f;return}}function Qd(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=(a[808082]&32)==0;e=TP(c[202024]|0)|0;a[808104]=e;b[404048]=(b[404048]|0)+1&65535;f=(b[404043]|0)+(e&255)&65535;e=f&65535;g=TP(e)|0;if(d){a[808104]=g;d=f+1&65535;f=TP(d)|0;h=(f&255)<<8|g&255;a[808120]=(f&255)>>>7;f=h<<1;i=(h&65535)>>>7&255;HY(i,d);d=f&255;HY(d,e);a[808104]=d;j=i;k=f<<16>>16!=0|0;a[808121]=k;a[808122]=j;return}else{a[808120]=(g&255)>>>7;f=g<<1;HY(f,e);a[808104]=f;j=f;k=f;a[808121]=k;a[808122]=j;return}}function Qe(){var d=0,e=0,f=0,g=0,h=0,i=0;d=(a[808082]&32)==0;e=TP(c[202024]|0)|0;a[808104]=e;b[404048]=(b[404048]|0)+1&65535;f=(b[404043]|0)+(e&255)&65535;e=TP(f)|0;a[808104]=e;g=TP(f+1|0)|0;a[808104]=g;h=TP(f+2|0)|0;a[808104]=h;f=((g&255)<<8|e&255)&65535|(h&255)<<16;if(d){d=TP(f)|0;a[808104]=d;h=TP(f+1|0)|0;a[808104]=h;e=b[404042]|d&255|(h&255)<<8;b[404042]=e;a[808121]=e<<16>>16!=0|0;i=(e&65535)>>>8&255;a[808122]=i;return}else{e=TP(f)|0;a[808104]=e;f=a[808084]|e;a[808084]=f;a[808121]=f;i=f;a[808122]=i;return}}function Qf(){var c=0,d=0,e=0;c=a[808082]&60|a[808120]|a[808122]&-128|((a[808121]|0)==0)<<1|a[808123]<<6;a[808082]=c;d=b[404044]|0;if((b[404041]&256)==0){b[404044]=d-1&65535;HY(c,d&65535);e=a[808082]|0;a[808104]=e;return}else{HY(c,d&65535);a[808088]=(a[808088]|0)-1&255;e=a[808082]|0;a[808104]=e;return}}function Qg(){var d=0,e=0,f=0,g=0;d=(a[808082]&32)==0;e=c[202024]|0;f=TP(e)|0;a[808104]=f;if(d){d=TP((e&65535)+1&65535|e&-65536)|0;a[808104]=d;b[404048]=(b[404048]|0)+2&65535;e=(d&255)<<8|f&255|b[404042];b[404042]=e;a[808121]=e<<16>>16!=0|0;g=(e&65535)>>>8&255;a[808122]=g;return}else{b[404048]=(b[404048]|0)+1&65535;e=a[808084]|f;a[808084]=e;a[808121]=e;g=e;a[808122]=g;return}}function Qh(){var c=0,d=0;c=b[404043]|0;d=(e[404044]|0)-1|0;HY((c&65535)>>>8&255,(d&65535)+1&65535|d&-65536);HY(c&255,d);b[404044]=(b[404044]|0)-2&65535;a[808104]=a[808086]|0;if((b[404041]&256)==0){return}a[808089|0]=1;return}function Qi(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=(a[808082]&32)==0;e=c[202032]|0;f=c[202024]|0;g=TP(f)|0;a[808104]=g;h=TP((f&65535)+1&65535|f&-65536)|0;a[808104]=h;b[404048]=(b[404048]|0)+2&65535;f=((h&255)<<8|g&255)&65535|e;g=TP(f)|0;if(d){a[808104]=g;d=(f&65535)+1&65535|e&-65536;e=((TP(d)|0)&255)<<8|g&255;h=b[404042]|0;a[808121]=(e&h)<<16>>16!=0|0;i=e|h;HY((i&65535)>>>8&255,d);d=i&255;HY(d,f);j=d;a[808104]=j;return}else{d=a[808084]|0;a[808121]=d&g;i=d|g;HY(i,f);j=i;a[808104]=j;return}}function Qj(){var d=0,e=0,f=0,g=0,h=0,i=0;d=(a[808082]&32)==0;e=c[202032]|0;f=c[202024]|0;g=TP(f)|0;a[808104]=g;h=TP((f&65535)+1&65535|f&-65536)|0;a[808104]=h;b[404048]=(b[404048]|0)+2&65535;f=((h&255)<<8|g&255)&65535|e;if(d){d=TP(f)|0;a[808104]=d;e=TP(f+1|0)|0;a[808104]=e;g=b[404042]|d&255|(e&255)<<8;b[404042]=g;a[808121]=g<<16>>16!=0|0;i=(g&65535)>>>8&255;a[808122]=i;return}else{g=TP(f)|0;a[808104]=g;f=a[808084]|g;a[808084]=f;a[808121]=f;i=f;a[808122]=i;return}}function Qk(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=(a[808082]&32)==0;e=c[202032]|0;f=c[202024]|0;g=TP(f)|0;a[808104]=g;h=TP((f&65535)+1&65535|f&-65536)|0;a[808104]=h;b[404048]=(b[404048]|0)+2&65535;f=((h&255)<<8|g&255)&65535|e;e=TP(f)|0;if(d){a[808104]=e;d=f+1|0;g=TP(d)|0;h=(g&255)<<8|e&255;a[808120]=(g&255)>>>7;g=h<<1;i=(h&65535)>>>7&255;HY(i,d);d=g&255;HY(d,f);a[808104]=d;j=i;k=g<<16>>16!=0|0;a[808121]=k;a[808122]=j;return}else{a[808120]=(e&255)>>>7;g=e<<1;HY(g,f);a[808104]=g;j=g;k=g;a[808121]=k;a[808122]=j;return}}function Ql(){var d=0,e=0,f=0,g=0,h=0,i=0;d=(a[808082]&32)==0;e=c[202024]|0;f=TP(e)|0;a[808104]=f;g=TP((e&65535)+1&65535|e&-65536)|0;a[808104]=g;b[404048]=(b[404048]|0)+2&65535;e=TP(c[202024]|0)|0;a[808104]=e;b[404048]=(b[404048]|0)+1&65535;h=(e&255)<<16|((g&255)<<8|f&255)&65535;if(d){d=TP(h)|0;a[808104]=d;f=TP(h+1|0)|0;a[808104]=f;g=b[404042]|d&255|(f&255)<<8;b[404042]=g;a[808121]=g<<16>>16!=0|0;i=(g&65535)>>>8&255;a[808122]=i;return}else{g=TP(h)|0;a[808104]=g;h=a[808084]|g;a[808084]=h;a[808121]=h;i=h;a[808122]=i;return}}function Qm(){var d=0,e=0,f=0;d=TP(c[202024]|0)|0;a[808104]=d;e=(b[404048]|0)+1&65535;b[404048]=e;f=e&65535;e=f+(d<<24>>24)|0;if((a[808122]|0)<0){return}if(((e^f)&61440|0)==0){b[404048]=e&65535;return}else{HR((c[202031]|0)+(e&65535)|0);return}}function Qn(){var d=0,f=0,g=0,h=0,i=0,j=0;d=(a[808082]&32)==0;f=TP(c[202024]|0)|0;a[808104]=f;b[404048]=(b[404048]|0)+1&65535;g=b[404043]|0;if((b[404041]&256)==0){h=65535}else{h=(g&255)<<24>>24!=0?65535:255}i=TV(g+(f&255)&65535,h)|0;a[808104]=(i&65535)>>>8&255;h=(e[404046]|0)+(c[202032]|i&65535)|0;if(d){d=TP(h)|0;a[808104]=d;i=TP(h+1|0)|0;a[808104]=i;f=b[404042]|d&255|(i&255)<<8;b[404042]=f;a[808121]=f<<16>>16!=0|0;j=(f&65535)>>>8&255;a[808122]=j;return}else{f=TP(h)|0;a[808104]=f;h=a[808084]|f;a[808084]=h;a[808121]=h;j=h;a[808122]=j;return}}function Qo(){var d=0,e=0,f=0,g=0,h=0,i=0;d=(a[808082]&32)==0;e=TP(c[202024]|0)|0;a[808104]=e;b[404048]=(b[404048]|0)+1&65535;f=b[404043]|0;if((b[404041]&256)==0){g=65535}else{g=(f&255)<<24>>24!=0?65535:255}h=TV(f+(e&255)&65535,g)|0;a[808104]=(h&65535)>>>8&255;g=c[202032]|h&65535;if(d){d=TP(g)|0;a[808104]=d;h=TP(g+1|0)|0;a[808104]=h;e=b[404042]|d&255|(h&255)<<8;b[404042]=e;a[808121]=e<<16>>16!=0|0;i=(e&65535)>>>8&255;a[808122]=i;return}else{e=TP(g)|0;a[808104]=e;g=a[808084]|e;a[808084]=g;a[808121]=g;i=g;a[808122]=i;return}}function Qp(){var d=0,f=0,g=0,h=0,i=0;d=(a[808082]&32)==0;f=TP(c[202024]|0)|0;a[808104]=f;b[404048]=(b[404048]|0)+1&65535;g=(b[404044]|0)+(f&255)&65535;f=TP(g)|0;a[808104]=f;h=TP(g+1|0)|0;a[808104]=h;g=(c[202032]|0)+(e[404046]|0)+(((h&255)<<8|f&255)&65535)&16777215;if(d){d=TP(g)|0;a[808104]=d;f=TP(g+1|0)|0;a[808104]=f;h=b[404042]|d&255|(f&255)<<8;b[404042]=h;a[808121]=h<<16>>16!=0|0;i=(h&65535)>>>8&255;a[808122]=i;return}else{h=TP(g)|0;a[808104]=h;g=a[808084]|h;a[808084]=g;a[808121]=g;i=g;a[808122]=i;return}}function Qq(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=(a[808082]&32)==0;e=TP(c[202024]|0)|0;a[808104]=e;b[404048]=(b[404048]|0)+1&65535;f=(b[404043]|0)+(e&255)&65535;e=f&65535;g=TP(e)|0;if(d){a[808104]=g;d=f+1&65535;f=((TP(d)|0)&255)<<8|g&255;h=b[404042]|0;a[808121]=(f&h)<<16>>16!=0|0;i=f&~h;HY((i&65535)>>>8&255,d);d=i&255;HY(d,e);j=d;a[808104]=j;return}else{d=a[808084]|0;a[808121]=d&g;i=g&~d;HY(i,e);j=i;a[808104]=j;return}}function Qr(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=(a[808082]&32)==0;e=TP(c[202024]|0)|0;a[808104]=e;b[404048]=(b[404048]|0)+1&65535;f=b[404043]|0;g=f+(e&255)&65535;e=g&255;h=(g&65535)>>>8;i=h&255;do{if((b[404041]&256)==0){j=3268}else{if((f&255)<<24>>24!=0){j=3268;break}k=(a[808090]|0)+e&255;l=i}}while(0);if((j|0)==3268){j=(b[404045]|0)+(h<<8|g&255)&65535;k=j&255;l=(j&65535)>>>8&255}j=(l&255)<<8|k&255;k=j&65535;if(d){d=TP(k)|0;a[808104]=d;l=TP(j+1&65535)|0;a[808104]=l;j=b[404042]|d&255|(l&255)<<8;b[404042]=j;a[808121]=j<<16>>16!=0|0;m=(j&65535)>>>8&255;a[808122]=m;return}else{j=TP(k)|0;a[808104]=j;k=a[808084]|j;a[808084]=k;a[808121]=k;m=k;a[808122]=m;return}}function Qs(){var c=0,d=0;if((a[808082]&32)==0){c=(b[404042]|0)+1&65535;b[404042]=c;a[808121]=c<<16>>16!=0|0;d=(c&65535)>>>8&255;a[808122]=d;return}else{c=(a[808084]|0)+1&255;a[808084]=c;a[808121]=c;d=c;a[808122]=d;return}}function Qt(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=(a[808082]&32)==0;e=TP(c[202024]|0)|0;a[808104]=e;b[404048]=(b[404048]|0)+1&65535;f=b[404043]|0;g=f+(e&255)&65535;e=g&255;h=(g&65535)>>>8;i=h&255;do{if((b[404041]&256)==0){j=3284}else{if((f&255)<<24>>24!=0){j=3284;break}k=(a[808090]|0)+e&255;l=i}}while(0);if((j|0)==3284){j=(b[404045]|0)+(h<<8|g&255)&65535;k=j&255;l=(j&65535)>>>8&255}j=(l&255)<<8|k&255;k=j&65535;l=TP(k)|0;if(d){a[808104]=l;d=j+1&65535;j=TP(d)|0;g=(j&255)<<8|l&255;a[808120]=(j&255)>>>7;j=g<<1;h=(g&65535)>>>7&255;HY(h,d);d=j&255;HY(d,k);a[808104]=d;m=h;n=j<<16>>16!=0|0;a[808121]=n;a[808122]=m;return}else{a[808120]=(l&255)>>>7;j=l<<1;HY(j,k);a[808104]=j;m=j;n=j;a[808121]=n;a[808122]=m;return}}function Qu(){var d=0,f=0,g=0,h=0,i=0,j=0;d=(a[808082]&32)==0;f=TP(c[202024]|0)|0;a[808104]=f;b[404048]=(b[404048]|0)+1&65535;g=(b[404043]|0)+(f&255)&65535;f=TP(g)|0;a[808104]=f;h=TP(g+1|0)|0;a[808104]=h;i=TP(g+2|0)|0;a[808104]=i;g=(((h&255)<<8|f&255)&65535|(i&255)<<16)+(e[404046]|0)|0;if(d){d=TP(g)|0;a[808104]=d;i=TP(g+1|0)|0;a[808104]=i;f=b[404042]|d&255|(i&255)<<8;b[404042]=f;a[808121]=f<<16>>16!=0|0;j=(f&65535)>>>8&255;a[808122]=j;return}else{f=TP(g)|0;a[808104]=f;g=a[808084]|f;a[808084]=g;a[808121]=g;j=g;a[808122]=j;return}}function Qv(){var d=0,f=0,g=0,h=0,i=0,j=0;d=(a[808082]&32)==0;f=c[202032]|0;g=c[202024]|0;h=TP(g)|0;a[808104]=h;i=TP((g&65535)+1&65535|g&-65536)|0;a[808104]=i;b[404048]=(b[404048]|0)+2&65535;g=(((i&255)<<8|h&255)&65535|f)+(e[404046]|0)|0;if(d){d=TP(g)|0;a[808104]=d;f=TP(g+1|0)|0;a[808104]=f;h=b[404042]|d&255|(f&255)<<8;b[404042]=h;a[808121]=h<<16>>16!=0|0;j=(h&65535)>>>8&255;a[808122]=j;return}else{h=TP(g)|0;a[808104]=h;g=a[808084]|h;a[808084]=g;a[808121]=g;j=g;a[808122]=j;return}}function Qw(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=(a[808082]&32)==0;e=c[202032]|0;f=c[202024]|0;g=TP(f)|0;a[808104]=g;h=TP((f&65535)+1&65535|f&-65536)|0;a[808104]=h;b[404048]=(b[404048]|0)+2&65535;f=((h&255)<<8|g&255)&65535|e;g=TP(f)|0;if(d){a[808104]=g;d=(f&65535)+1&65535|e&-65536;e=((TP(d)|0)&255)<<8|g&255;h=b[404042]|0;a[808121]=(e&h)<<16>>16!=0|0;i=e&~h;HY((i&65535)>>>8&255,d);d=i&255;HY(d,f);j=d;a[808104]=j;return}else{d=a[808084]|0;a[808121]=d&g;i=g&~d;HY(i,f);j=i;a[808104]=j;return}}function Qx(){var d=0,f=0,g=0,h=0,i=0,j=0;d=(a[808082]&32)==0;f=c[202032]|0;g=c[202024]|0;h=TP(g)|0;a[808104]=h;i=TP((g&65535)+1&65535|g&-65536)|0;a[808104]=i;b[404048]=(b[404048]|0)+2&65535;g=(((i&255)<<8|h&255)&65535|f)+(e[404045]|0)|0;if(d){d=TP(g)|0;a[808104]=d;f=TP(g+1|0)|0;a[808104]=f;h=b[404042]|d&255|(f&255)<<8;b[404042]=h;a[808121]=h<<16>>16!=0|0;j=(h&65535)>>>8&255;a[808122]=j;return}else{h=TP(g)|0;a[808104]=h;g=a[808084]|h;a[808084]=g;a[808121]=g;j=g;a[808122]=j;return}}function Qy(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=(a[808082]&32)==0;f=c[202032]|0;g=c[202024]|0;h=TP(g)|0;a[808104]=h;i=TP((g&65535)+1&65535|g&-65536)|0;a[808104]=i;b[404048]=(b[404048]|0)+2&65535;g=(((i&255)<<8|h&255)&65535|f)+(e[404045]|0)|0;f=TP(g)|0;if(d){a[808104]=f;d=g+1|0;h=TP(d)|0;i=(h&255)<<8|f&255;a[808120]=(h&255)>>>7;h=i<<1;j=(i&65535)>>>7&255;HY(j,d);d=h&255;HY(d,g);a[808104]=d;k=j;l=h<<16>>16!=0|0;a[808121]=l;a[808122]=k;return}else{a[808120]=(f&255)>>>7;h=f<<1;HY(h,g);a[808104]=h;k=h;l=h;a[808121]=l;a[808122]=k;return}}function Qz(){var d=0,f=0,g=0,h=0,i=0,j=0;d=(a[808082]&32)==0;f=c[202024]|0;g=TP(f)|0;a[808104]=g;h=TP((f&65535)+1&65535|f&-65536)|0;a[808104]=h;b[404048]=(b[404048]|0)+2&65535;f=TP(c[202024]|0)|0;a[808104]=f;b[404048]=(b[404048]|0)+1&65535;i=(e[404045]|0)+((f&255)<<16|((h&255)<<8|g&255)&65535)|0;if(d){d=TP(i)|0;a[808104]=d;g=TP(i+1|0)|0;a[808104]=g;h=b[404042]|d&255|(g&255)<<8;b[404042]=h;a[808121]=h<<16>>16!=0|0;j=(h&65535)>>>8&255;a[808122]=j;return}else{h=TP(i)|0;a[808104]=h;i=a[808084]|h;a[808084]=i;a[808121]=i;j=i;a[808122]=j;return}}function QA(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=c[202032]|0;f=c[202024]|0;g=TP(f)|0;a[808104]=g;h=((TP((f&65535)+1&65535|f&-65536)|0)&255)<<8|g&255;g=b[404048]|0;b[404048]=g+2&65535;f=h&65535;if((b[404041]&256)==0){h=g+1&65535;i=(e[404044]|0)-1|0;HY((h&65535)>>>8&255,(i&65535)+1&65535|i&-65536);HY(h&255,i);b[404044]=(b[404044]|0)-2&65535;j=c[202031]|0;k=d&65535;l=f|k;m=j+l|0;HR(m);return}else{a[808088]=(a[808088]|0)-1&255;i=g+1&65535;g=b[404044]|0;HY((i&65535)>>>8&255,((g&255)+1&255|g&-256)&65535);HY(i&255,g&65535);a[808088]=(a[808088]|0)-1&255;j=c[202031]|0;k=d&65535;l=f|k;m=j+l|0;HR(m);return}}function QB(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=(a[808082]&32)==0;e=TP(c[202024]|0)|0;a[808104]=e;b[404048]=(b[404048]|0)+1&65535;f=b[404043]|0;g=f+(e&255)&65535;e=(g&65535)>>>8;h=(b[404041]&256)==0;i=f&255;if(i<<24>>24==0&(h^1)){j=((a[808090]|0)+(g&255)&255|e<<8)&65535;k=3337}else{f=(b[404045]|0)+(e<<8|g&255)&65535;if(h){l=65535;m=f}else{j=f;k=3337}}if((k|0)==3337){l=i<<24>>24!=0?65535:255;m=j}j=TV(m,l)|0;a[808104]=(j&65535)>>>8&255;l=c[202032]|j&65535;if(d){d=TP(l)|0;a[808104]=d;j=TP(l+1|0)|0;a[808104]=j;m=((j&255)<<8|d&255)&b[404042];b[404042]=m;a[808121]=m<<16>>16!=0|0;n=(m&65535)>>>8&255;a[808122]=n;return}else{m=TP(l)|0;a[808104]=m;l=a[808084]&m;a[808084]=l;a[808121]=l;n=l;a[808122]=n;return}}function QC(){var d=0,f=0,g=0;d=c[202024]|0;f=TP(d)|0;a[808104]=f;g=((TP((d&65535)+1&65535|d&-65536)|0)&255)<<8|f&255;b[404048]=(b[404048]|0)+2&65535;a[808104]=a[808098|0]|0;f=TP(c[202024]|0)|0;b[404048]=(b[404048]|0)+1&65535;d=(f&255)<<16|g&65535;g=a[808098|0]|0;f=b[404044]|0;b[404044]=f-1&65535;HY(g,f&65535);f=(b[404048]|0)-1&65535;g=(e[404044]|0)-1|0;HY((f&65535)>>>8&255,(g&65535)+1&65535|g&-65536);HY(f&255,g);b[404044]=(b[404044]|0)-2&65535;if((b[404041]&256)==0){HR(d);return}a[808089|0]=1;HR(d);return}function QD(){var d=0,e=0,f=0,g=0,h=0;d=(a[808082]&32)==0;e=TP(c[202024]|0)|0;a[808104]=e;b[404048]=(b[404048]|0)+1&65535;f=(b[404044]|0)+(e&255)&65535;if(d){d=TP(f)|0;a[808104]=d;e=TP(f+1|0)|0;a[808104]=e;g=((e&255)<<8|d&255)&b[404042];b[404042]=g;a[808121]=g<<16>>16!=0|0;h=(g&65535)>>>8&255;a[808122]=h;return}else{g=TP(f)|0;a[808104]=g;f=a[808084]&g;a[808084]=f;a[808121]=f;h=f;a[808122]=h;return}}function QE(){var d=0,e=0,f=0,g=0,h=0;d=(a[808082]&32)==0;e=TP(c[202024]|0)|0;a[808104]=e;b[404048]=(b[404048]|0)+1&65535;f=(b[404043]|0)+(e&255)&65535;e=f&65535;if(d){d=TP(e)|0;a[808104]=d;g=TP(f+1&65535)|0;a[808104]=g;a[808123]=(g&255)>>>6&1;a[808122]=g;h=(((g&255)<<8|d&255)&b[404042])<<16>>16!=0|0;a[808121]=h;return}else{d=TP(e)|0;a[808104]=d;a[808123]=(d&255)>>>6&1;a[808122]=d;h=a[808084]&d;a[808121]=h;return}}function QF(){var d=0,e=0,f=0,g=0,h=0;d=(a[808082]&32)==0;e=TP(c[202024]|0)|0;a[808104]=e;b[404048]=(b[404048]|0)+1&65535;f=(b[404043]|0)+(e&255)&65535;e=f&65535;if(d){d=TP(e)|0;a[808104]=d;g=TP(f+1&65535)|0;a[808104]=g;f=((g&255)<<8|d&255)&b[404042];b[404042]=f;a[808121]=f<<16>>16!=0|0;h=(f&65535)>>>8&255;a[808122]=h;return}else{f=TP(e)|0;a[808104]=f;e=a[808084]&f;a[808084]=e;a[808121]=e;h=e;a[808122]=h;return}}function QG(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=(a[808082]&32)==0;f=TP(c[202024]|0)|0;a[808104]=f;b[404048]=(b[404048]|0)+1&65535;g=(b[404043]|0)+(f&255)&65535;f=g&65535;h=TP(f)|0;if(e){a[808104]=h;e=g+1&65535;g=((TP(e)|0)&255)<<8|h&255;i=(g&65535)<<1|(d[808120]|0);a[808120]=i>>>0>65535|0;j=(g&65535)>>>7&255;HY(j,e);e=i&255;HY(e,f);a[808104]=e;k=j;l=(i&65535|0)!=0|0;a[808121]=l;a[808122]=k;return}else{i=d[808120]|0|(h&255)<<1;a[808120]=(i&65535)>255|0;h=i&255;HY(h,f);a[808104]=h;k=h;l=h;a[808121]=l;a[808122]=k;return}}function QH(){var c=0,f=0,g=0;if((a[808082]&32)==0){c=(e[404042]|0)<<1|(d[808120]|0);a[808120]=c>>>0>65535|0;f=c&65535;b[404042]=f;a[808121]=(c&65535|0)!=0|0;g=(f&65535)>>>8&255;a[808122]=g;return}else{f=(d[808084]|0)<<1;c=f|(d[808120]|0);a[808120]=(f&65535)>255|0;f=c&255;a[808084]=f;a[808121]=f;g=f;a[808122]=g;return}}function QI(){var d=0,e=0,f=0,g=0,h=0,i=0;d=(a[808082]&32)==0;e=TP(c[202024]|0)|0;a[808104]=e;b[404048]=(b[404048]|0)+1&65535;f=(b[404043]|0)+(e&255)&65535;e=TP(f)|0;a[808104]=e;g=TP(f+1|0)|0;a[808104]=g;h=TP(f+2|0)|0;a[808104]=h;f=((g&255)<<8|e&255)&65535|(h&255)<<16;if(d){d=TP(f)|0;a[808104]=d;h=TP(f+1|0)|0;a[808104]=h;e=((h&255)<<8|d&255)&b[404042];b[404042]=e;a[808121]=e<<16>>16!=0|0;i=(e&65535)>>>8&255;a[808122]=i;return}else{e=TP(f)|0;a[808104]=e;f=a[808084]&e;a[808084]=f;a[808121]=f;i=f;a[808122]=i;return}}function QJ(){var d=0,f=0,g=0;if((b[404041]&256)==0){d=(b[404044]|0)+1&65535;b[404044]=d;f=TP(d&65535)|0;a[808082]=f;a[808104]=f;g=f}else{a[808088]=(a[808088]|0)+1&255;f=TP(e[404044]|0)|0;a[808082]=f;a[808104]=f;f=b[404041]|48;b[404041]=f;g=f&255}a[808121]=(g&255)>>>1&1^1;a[808122]=g&-128;a[808120]=g&1;a[808123]=(g&255)>>>6&1;if((g&16)!=0){a[808091|0]=0;a[808093|0]=0}g=b[404041]|0;if((g&256)!=0){c[202028]=149560;c[202029]=159800;return}f=g&255;g=(f&16|0)!=0;if((f&32|0)==0){if(g){c[202028]=151608;c[202029]=160312;return}else{c[202028]=152632;c[202029]=160568;return}}else{if(g){c[202028]=149560;c[202029]=159800;return}else{c[202028]=150584;c[202029]=160056;return}}}function QK(){var d=0,e=0,f=0,g=0;d=(a[808082]&32)==0;e=c[202024]|0;f=TP(e)|0;a[808104]=f;if(d){d=TP((e&65535)+1&65535|e&-65536)|0;a[808104]=d;b[404048]=(b[404048]|0)+2&65535;e=((d&255)<<8|f&255)&b[404042];b[404042]=e;a[808121]=e<<16>>16!=0|0;g=(e&65535)>>>8&255;a[808122]=g;return}else{b[404048]=(b[404048]|0)+1&65535;e=a[808084]&f;a[808084]=e;a[808121]=e;g=e;a[808122]=g;return}}function QL(){var c=0,d=0,f=0;c=(e[404044]|0)+1|0;d=TP(c)|0;a[808104]=d;f=TP((c&65535)+1&65535|c&2147418112)|0;c=(f&255)<<8|d&255;b[404043]=c;b[404044]=(b[404044]|0)+2&65535;a[808121]=c<<16>>16!=0|0;a[808122]=f;a[808104]=f;if((b[404041]&256)==0){return}a[808089|0]=1;return}function QM(){var d=0,e=0,f=0,g=0,h=0,i=0;d=(a[808082]&32)==0;e=c[202032]|0;f=c[202024]|0;g=TP(f)|0;a[808104]=g;h=TP((f&65535)+1&65535|f&-65536)|0;a[808104]=h;b[404048]=(b[404048]|0)+2&65535;f=((h&255)<<8|g&255)&65535|e;if(d){d=TP(f)|0;a[808104]=d;e=TP(f+1|0)|0;a[808104]=e;a[808123]=(e&255)>>>6&1;a[808122]=e;i=(((e&255)<<8|d&255)&b[404042])<<16>>16!=0|0;a[808121]=i;return}else{d=TP(f)|0;a[808104]=d;a[808123]=(d&255)>>>6&1;a[808122]=d;i=a[808084]&d;a[808121]=i;return}}function QN(){var d=0,e=0,f=0,g=0,h=0,i=0;d=(a[808082]&32)==0;e=c[202032]|0;f=c[202024]|0;g=TP(f)|0;a[808104]=g;h=TP((f&65535)+1&65535|f&-65536)|0;a[808104]=h;b[404048]=(b[404048]|0)+2&65535;f=((h&255)<<8|g&255)&65535|e;if(d){d=TP(f)|0;a[808104]=d;e=TP(f+1|0)|0;a[808104]=e;g=((e&255)<<8|d&255)&b[404042];b[404042]=g;a[808121]=g<<16>>16!=0|0;i=(g&65535)>>>8&255;a[808122]=i;return}else{g=TP(f)|0;a[808104]=g;f=a[808084]&g;a[808084]=f;a[808121]=f;i=f;a[808122]=i;return}}function QO(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=(a[808082]&32)==0;f=c[202032]|0;g=c[202024]|0;h=TP(g)|0;a[808104]=h;i=TP((g&65535)+1&65535|g&-65536)|0;a[808104]=i;b[404048]=(b[404048]|0)+2&65535;g=((i&255)<<8|h&255)&65535|f;f=TP(g)|0;if(e){a[808104]=f;e=g+1|0;h=((TP(e)|0)&255)<<8|f&255;i=(h&65535)<<1|(d[808120]|0);a[808120]=i>>>0>65535|0;j=(h&65535)>>>7&255;HY(j,e);e=i&255;HY(e,g);a[808104]=e;k=j;l=(i&65535|0)!=0|0;a[808121]=l;a[808122]=k;return}else{i=d[808120]|0|(f&255)<<1;a[808120]=(i&65535)>255|0;f=i&255;HY(f,g);a[808104]=f;k=f;l=f;a[808121]=l;a[808122]=k;return}}function QP(){var d=0,e=0,f=0,g=0,h=0,i=0;d=(a[808082]&32)==0;e=c[202024]|0;f=TP(e)|0;a[808104]=f;g=TP((e&65535)+1&65535|e&-65536)|0;a[808104]=g;b[404048]=(b[404048]|0)+2&65535;e=TP(c[202024]|0)|0;a[808104]=e;b[404048]=(b[404048]|0)+1&65535;h=(e&255)<<16|((g&255)<<8|f&255)&65535;if(d){d=TP(h)|0;a[808104]=d;f=TP(h+1|0)|0;a[808104]=f;g=((f&255)<<8|d&255)&b[404042];b[404042]=g;a[808121]=g<<16>>16!=0|0;i=(g&65535)>>>8&255;a[808122]=i;return}else{g=TP(h)|0;a[808104]=g;h=a[808084]&g;a[808084]=h;a[808121]=h;i=h;a[808122]=i;return}}function QQ(){var d=0,e=0,f=0;d=TP(c[202024]|0)|0;a[808104]=d;e=(b[404048]|0)+1&65535;b[404048]=e;f=e&65535;e=f+(d<<24>>24)|0;if((a[808122]|0)>=0){return}if(((e^f)&61440|0)==0){b[404048]=e&65535;return}else{HR((c[202031]|0)+(e&65535)|0);return}}function QR(){var d=0,f=0,g=0,h=0,i=0,j=0;d=(a[808082]&32)==0;f=TP(c[202024]|0)|0;a[808104]=f;b[404048]=(b[404048]|0)+1&65535;g=b[404043]|0;if((b[404041]&256)==0){h=65535}else{h=(g&255)<<24>>24!=0?65535:255}i=TV(g+(f&255)&65535,h)|0;a[808104]=(i&65535)>>>8&255;h=(e[404046]|0)+(c[202032]|i&65535)|0;if(d){d=TP(h)|0;a[808104]=d;i=TP(h+1|0)|0;a[808104]=i;f=((i&255)<<8|d&255)&b[404042];b[404042]=f;a[808121]=f<<16>>16!=0|0;j=(f&65535)>>>8&255;a[808122]=j;return}else{f=TP(h)|0;a[808104]=f;h=a[808084]&f;a[808084]=h;a[808121]=h;j=h;a[808122]=j;return}}function QS(){var d=0,e=0,f=0,g=0,h=0,i=0;d=(a[808082]&32)==0;e=TP(c[202024]|0)|0;a[808104]=e;b[404048]=(b[404048]|0)+1&65535;f=b[404043]|0;if((b[404041]&256)==0){g=65535}else{g=(f&255)<<24>>24!=0?65535:255}h=TV(f+(e&255)&65535,g)|0;a[808104]=(h&65535)>>>8&255;g=c[202032]|h&65535;if(d){d=TP(g)|0;a[808104]=d;h=TP(g+1|0)|0;a[808104]=h;e=((h&255)<<8|d&255)&b[404042];b[404042]=e;a[808121]=e<<16>>16!=0|0;i=(e&65535)>>>8&255;a[808122]=i;return}else{e=TP(g)|0;a[808104]=e;g=a[808084]&e;a[808084]=g;a[808121]=g;i=g;a[808122]=i;return}}function QT(){var d=0,f=0,g=0,h=0,i=0;d=(a[808082]&32)==0;f=TP(c[202024]|0)|0;a[808104]=f;b[404048]=(b[404048]|0)+1&65535;g=(b[404044]|0)+(f&255)&65535;f=TP(g)|0;a[808104]=f;h=TP(g+1|0)|0;a[808104]=h;g=(c[202032]|0)+(e[404046]|0)+(((h&255)<<8|f&255)&65535)&16777215;if(d){d=TP(g)|0;a[808104]=d;f=TP(g+1|0)|0;a[808104]=f;h=((f&255)<<8|d&255)&b[404042];b[404042]=h;a[808121]=h<<16>>16!=0|0;i=(h&65535)>>>8&255;a[808122]=i;return}else{h=TP(g)|0;a[808104]=h;g=a[808084]&h;a[808084]=g;a[808121]=g;i=g;a[808122]=i;return}}function QU(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=(a[808082]&32)==0;e=TP(c[202024]|0)|0;a[808104]=e;b[404048]=(b[404048]|0)+1&65535;f=b[404043]|0;g=f+(e&255)&65535;e=g&255;h=(g&65535)>>>8;i=h&255;do{if((b[404041]&256)==0){j=3472}else{if((f&255)<<24>>24!=0){j=3472;break}k=(a[808090]|0)+e&255;l=i}}while(0);if((j|0)==3472){j=(b[404045]|0)+(h<<8|g&255)&65535;k=j&255;l=(j&65535)>>>8&255}j=(l&255)<<8|k&255;k=j&65535;if(d){d=TP(k)|0;a[808104]=d;l=TP(j+1&65535)|0;a[808104]=l;a[808123]=(l&255)>>>6&1;a[808122]=l;m=(((l&255)<<8|d&255)&b[404042])<<16>>16!=0|0;a[808121]=m;return}else{d=TP(k)|0;a[808104]=d;a[808123]=(d&255)>>>6&1;a[808122]=d;m=a[808084]&d;a[808121]=m;return}}function QV(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=(a[808082]&32)==0;e=TP(c[202024]|0)|0;a[808104]=e;b[404048]=(b[404048]|0)+1&65535;f=b[404043]|0;g=f+(e&255)&65535;e=g&255;h=(g&65535)>>>8;i=h&255;do{if((b[404041]&256)==0){j=3482}else{if((f&255)<<24>>24!=0){j=3482;break}k=(a[808090]|0)+e&255;l=i}}while(0);if((j|0)==3482){j=(b[404045]|0)+(h<<8|g&255)&65535;k=j&255;l=(j&65535)>>>8&255}j=(l&255)<<8|k&255;k=j&65535;if(d){d=TP(k)|0;a[808104]=d;l=TP(j+1&65535)|0;a[808104]=l;j=((l&255)<<8|d&255)&b[404042];b[404042]=j;a[808121]=j<<16>>16!=0|0;m=(j&65535)>>>8&255;a[808122]=m;return}else{j=TP(k)|0;a[808104]=j;k=a[808084]&j;a[808084]=k;a[808121]=k;m=k;a[808122]=m;return}}function QW(){var c=0,d=0;if((a[808082]&32)==0){c=(b[404042]|0)-1&65535;b[404042]=c;a[808121]=c<<16>>16!=0|0;d=(c&65535)>>>8&255;a[808122]=d;return}else{c=(a[808084]|0)-1&255;a[808084]=c;a[808121]=c;d=c;a[808122]=d;return}}function QX(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=(a[808082]&32)==0;f=TP(c[202024]|0)|0;a[808104]=f;b[404048]=(b[404048]|0)+1&65535;g=b[404043]|0;h=g+(f&255)&65535;f=h&255;i=(h&65535)>>>8;j=i&255;do{if((b[404041]&256)==0){k=3498}else{if((g&255)<<24>>24!=0){k=3498;break}l=(a[808090]|0)+f&255;m=j}}while(0);if((k|0)==3498){k=(b[404045]|0)+(i<<8|h&255)&65535;l=k&255;m=(k&65535)>>>8&255}k=(m&255)<<8|l&255;l=k&65535;m=TP(l)|0;if(e){a[808104]=m;e=k+1&65535;k=((TP(e)|0)&255)<<8|m&255;h=(k&65535)<<1|(d[808120]|0);a[808120]=h>>>0>65535|0;i=(k&65535)>>>7&255;HY(i,e);e=h&255;HY(e,l);a[808104]=e;n=i;o=(h&65535|0)!=0|0;a[808121]=o;a[808122]=n;return}else{h=d[808120]|0|(m&255)<<1;a[808120]=(h&65535)>255|0;m=h&255;HY(m,l);a[808104]=m;n=m;o=m;a[808121]=o;a[808122]=n;return}}function QY(){var d=0,f=0,g=0,h=0,i=0,j=0;d=(a[808082]&32)==0;f=TP(c[202024]|0)|0;a[808104]=f;b[404048]=(b[404048]|0)+1&65535;g=(b[404043]|0)+(f&255)&65535;f=TP(g)|0;a[808104]=f;h=TP(g+1|0)|0;a[808104]=h;i=TP(g+2|0)|0;a[808104]=i;g=(((h&255)<<8|f&255)&65535|(i&255)<<16)+(e[404046]|0)|0;if(d){d=TP(g)|0;a[808104]=d;i=TP(g+1|0)|0;a[808104]=i;f=((i&255)<<8|d&255)&b[404042];b[404042]=f;a[808121]=f<<16>>16!=0|0;j=(f&65535)>>>8&255;a[808122]=j;return}else{f=TP(g)|0;a[808104]=f;g=a[808084]&f;a[808084]=g;a[808121]=g;j=g;a[808122]=j;return}}function QZ(){var d=0,f=0,g=0,h=0,i=0,j=0;d=(a[808082]&32)==0;f=c[202032]|0;g=c[202024]|0;h=TP(g)|0;a[808104]=h;i=TP((g&65535)+1&65535|g&-65536)|0;a[808104]=i;b[404048]=(b[404048]|0)+2&65535;g=(((i&255)<<8|h&255)&65535|f)+(e[404046]|0)|0;if(d){d=TP(g)|0;a[808104]=d;f=TP(g+1|0)|0;a[808104]=f;h=((f&255)<<8|d&255)&b[404042];b[404042]=h;a[808121]=h<<16>>16!=0|0;j=(h&65535)>>>8&255;a[808122]=j;return}else{h=TP(g)|0;a[808104]=h;g=a[808084]&h;a[808084]=g;a[808121]=g;j=g;a[808122]=j;return}}function Q_(){var d=0,f=0,g=0,h=0,i=0,j=0;d=(a[808082]&32)==0;f=c[202032]|0;g=c[202024]|0;h=TP(g)|0;a[808104]=h;i=TP((g&65535)+1&65535|g&-65536)|0;a[808104]=i;b[404048]=(b[404048]|0)+2&65535;g=(((i&255)<<8|h&255)&65535|f)+(e[404045]|0)|0;if(d){d=TP(g)|0;a[808104]=d;f=TP(g+1|0)|0;a[808104]=f;a[808123]=(f&255)>>>6&1;a[808122]=f;j=(((f&255)<<8|d&255)&b[404042])<<16>>16!=0|0;a[808121]=j;return}else{d=TP(g)|0;a[808104]=d;a[808123]=(d&255)>>>6&1;a[808122]=d;j=a[808084]&d;a[808121]=j;return}}function Q$(){var d=0,f=0,g=0,h=0,i=0,j=0;d=(a[808082]&32)==0;f=c[202032]|0;g=c[202024]|0;h=TP(g)|0;a[808104]=h;i=TP((g&65535)+1&65535|g&-65536)|0;a[808104]=i;b[404048]=(b[404048]|0)+2&65535;g=(((i&255)<<8|h&255)&65535|f)+(e[404045]|0)|0;if(d){d=TP(g)|0;a[808104]=d;f=TP(g+1|0)|0;a[808104]=f;h=((f&255)<<8|d&255)&b[404042];b[404042]=h;a[808121]=h<<16>>16!=0|0;j=(h&65535)>>>8&255;a[808122]=j;return}else{h=TP(g)|0;a[808104]=h;g=a[808084]&h;a[808084]=g;a[808121]=g;j=g;a[808122]=j;return}}function Q0(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=(a[808082]&32)==0;g=c[202032]|0;h=c[202024]|0;i=TP(h)|0;a[808104]=i;j=TP((h&65535)+1&65535|h&-65536)|0;a[808104]=j;b[404048]=(b[404048]|0)+2&65535;h=(((j&255)<<8|i&255)&65535|g)+(e[404045]|0)|0;g=TP(h)|0;if(f){a[808104]=g;f=h+1|0;i=((TP(f)|0)&255)<<8|g&255;j=(i&65535)<<1|(d[808120]|0);a[808120]=j>>>0>65535|0;k=(i&65535)>>>7&255;HY(k,f);f=j&255;HY(f,h);a[808104]=f;l=k;m=(j&65535|0)!=0|0;a[808121]=m;a[808122]=l;return}else{j=d[808120]|0|(g&255)<<1;a[808120]=(j&65535)>255|0;g=j&255;HY(g,h);a[808104]=g;l=g;m=g;a[808121]=m;a[808122]=l;return}}function Q1(){var d=0,f=0,g=0,h=0,i=0,j=0;d=(a[808082]&32)==0;f=c[202024]|0;g=TP(f)|0;a[808104]=g;h=TP((f&65535)+1&65535|f&-65536)|0;a[808104]=h;b[404048]=(b[404048]|0)+2&65535;f=TP(c[202024]|0)|0;a[808104]=f;b[404048]=(b[404048]|0)+1&65535;i=(e[404045]|0)+((f&255)<<16|((h&255)<<8|g&255)&65535)|0;if(d){d=TP(i)|0;a[808104]=d;g=TP(i+1|0)|0;a[808104]=g;h=((g&255)<<8|d&255)&b[404042];b[404042]=h;a[808121]=h<<16>>16!=0|0;j=(h&65535)>>>8&255;a[808122]=j;return}else{h=TP(i)|0;a[808104]=h;i=a[808084]&h;a[808084]=i;a[808121]=i;j=i;a[808122]=j;return}}function Q2(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=(a[808082]&32)==0;e=TP(c[202024]|0)|0;a[808104]=e;b[404048]=(b[404048]|0)+1&65535;f=b[404043]|0;g=f+(e&255)&65535;e=(g&65535)>>>8;h=(b[404041]&256)==0;i=f&255;if(i<<24>>24==0&(h^1)){j=((a[808090]|0)+(g&255)&255|e<<8)&65535;k=3545}else{f=(b[404045]|0)+(e<<8|g&255)&65535;if(h){l=65535;m=f}else{j=f;k=3545}}if((k|0)==3545){l=i<<24>>24!=0?65535:255;m=j}j=TV(m,l)|0;a[808104]=(j&65535)>>>8&255;l=c[202032]|j&65535;if(d){d=TP(l)|0;a[808104]=d;j=TP(l+1|0)|0;m=(j&255)<<8|d&255;a[808104]=j;j=b[404042]|0;d=m^j;b[404042]=d;a[808121]=j<<16>>16!=m<<16>>16|0;n=(d&65535)>>>8&255;a[808122]=n;return}else{d=TP(l)|0;a[808104]=d;l=a[808084]^d;a[808084]=l;a[808121]=l;n=l;a[808122]=n;return}}function Q3(){var d=0,e=0,f=0,g=0,h=0;d=(a[808082]&32)==0;e=TP(c[202024]|0)|0;a[808104]=e;b[404048]=(b[404048]|0)+1&65535;f=(b[404044]|0)+(e&255)&65535;if(d){d=TP(f)|0;a[808104]=d;e=TP(f+1|0)|0;g=(e&255)<<8|d&255;a[808104]=e;e=b[404042]|0;d=g^e;b[404042]=d;a[808121]=e<<16>>16!=g<<16>>16|0;h=(d&65535)>>>8&255;a[808122]=h;return}else{d=TP(f)|0;a[808104]=d;f=a[808084]^d;a[808084]=f;a[808121]=f;h=f;a[808122]=h;return}}function Q4(){var d=0,f=0;d=TP(c[202024]|0)|0;b[404048]=(b[404048]|0)+1&65535;a[808080]=d;a[808104]=d;c[202032]=(d&255)<<16;d=TP(c[202024]|0)|0;b[404048]=(b[404048]|0)+1&65535;a[808104]=d;f=TP(e[404045]|0|(d&255)<<16)|0;a[808104]=f;HY(f,(e[404046]|0)+(c[202032]|0)|0);if((a[808082]&16)==0){b[404045]=(b[404045]|0)-1&65535;b[404046]=(b[404046]|0)-1&65535}else{a[808090]=(a[808090]|0)-1&255;a[808092]=(a[808092]|0)-1&255}f=b[404042]|0;b[404042]=f-1&65535;if(f<<16>>16==0){return}b[404048]=(b[404048]|0)-3&65535;return}function Q5(){var d=0,e=0,f=0,g=0,h=0;d=(a[808082]&32)==0;e=TP(c[202024]|0)|0;a[808104]=e;b[404048]=(b[404048]|0)+1&65535;f=(b[404043]|0)+(e&255)&65535;e=f&65535;if(d){d=TP(e)|0;a[808104]=d;g=TP(f+1&65535)|0;f=(g&255)<<8|d&255;a[808104]=g;g=b[404042]|0;d=f^g;b[404042]=d;a[808121]=g<<16>>16!=f<<16>>16|0;h=(d&65535)>>>8&255;a[808122]=h;return}else{d=TP(e)|0;a[808104]=d;e=a[808084]^d;a[808084]=e;a[808121]=e;h=e;a[808122]=h;return}}function Q6(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=(a[808082]&32)==0;e=TP(c[202024]|0)|0;a[808104]=e;b[404048]=(b[404048]|0)+1&65535;f=(b[404043]|0)+(e&255)&65535;e=f&65535;g=TP(e)|0;if(d){a[808104]=g;d=f+1&65535;f=TP(d)|0;a[808120]=g&1;h=(((f&255)<<8|g&255)&65535)>>>1;i=(f&255)>>>1;HY(i,d);d=h&255;HY(d,e);a[808104]=d;j=i;k=h<<16>>16!=0|0;a[808121]=k;a[808122]=j;return}else{a[808120]=g&1;h=(g&255)>>>1;HY(h,e);a[808104]=h;j=h;k=h;a[808121]=k;a[808122]=j;return}}function Q7(){var d=0,e=0,f=0,g=0,h=0,i=0;d=(a[808082]&32)==0;e=TP(c[202024]|0)|0;a[808104]=e;b[404048]=(b[404048]|0)+1&65535;f=(b[404043]|0)+(e&255)&65535;e=TP(f)|0;a[808104]=e;g=TP(f+1|0)|0;a[808104]=g;h=TP(f+2|0)|0;a[808104]=h;f=((g&255)<<8|e&255)&65535|(h&255)<<16;if(d){d=TP(f)|0;a[808104]=d;h=TP(f+1|0)|0;e=(h&255)<<8|d&255;a[808104]=h;h=b[404042]|0;d=e^h;b[404042]=d;a[808121]=h<<16>>16!=e<<16>>16|0;i=(d&65535)>>>8&255;a[808122]=i;return}else{d=TP(f)|0;a[808104]=d;f=a[808084]^d;a[808084]=f;a[808121]=f;i=f;a[808122]=i;return}}function Q8(){var c=0,d=0,f=0;c=b[404041]|0;if((c&256)!=0){HY(a[808084]|0,e[404044]|0);a[808088]=(a[808088]|0)-1&255;d=a[808084]|0;a[808104]=d;return}if((c&32)==0){c=b[404042]|0;f=(e[404044]|0)-1|0;HY((c&65535)>>>8&255,(f&65535)+1&65535|f&-65536);HY(c&255,f);b[404044]=(b[404044]|0)-2&65535;d=a[808084]|0;a[808104]=d;return}else{f=a[808084]|0;c=b[404044]|0;b[404044]=c-1&65535;HY(f,c&65535);d=a[808084]|0;a[808104]=d;return}}function Q9(){var c=0,d=0,e=0;if((a[808082]&32)==0){c=b[404042]|0;a[808120]=c&1;d=(c&65535)>>>1;b[404042]=d;a[808121]=d<<16>>16!=0|0;e=(c&65535)>>>9&255;a[808122]=e;return}else{c=a[808084]|0;a[808120]=c&1;d=(c&255)>>>1;a[808084]=d;a[808121]=d;e=d;a[808122]=e;return}}function Ra(){var d=0,e=0,f=0,g=0,h=0;d=(a[808082]&32)==0;e=c[202024]|0;f=TP(e)|0;a[808104]=f;if(d){d=TP((e&65535)+1&65535|e&-65536)|0;e=(d&255)<<8|f&255;a[808104]=d;b[404048]=(b[404048]|0)+2&65535;d=b[404042]|0;g=e^d;b[404042]=g;a[808121]=d<<16>>16!=e<<16>>16|0;h=(g&65535)>>>8&255;a[808122]=h;return}else{b[404048]=(b[404048]|0)+1&65535;g=a[808084]^f;a[808084]=g;a[808121]=g;h=g;a[808122]=h;return}}function Rb(){var c=0,d=0,e=0;c=a[808098|0]|0;d=b[404044]|0;if((b[404041]&256)==0){b[404044]=d-1&65535;HY(c,d&65535);e=a[808098|0]|0;a[808104]=e;return}else{HY(c,d&65535);a[808088]=(a[808088]|0)-1&255;e=a[808098|0]|0;a[808104]=e;return}}function Rc(){var d=0,e=0,f=0,g=0,h=0;d=c[202031]|0;e=c[202032]|0;f=c[202024]|0;g=TP(f)|0;a[808104]=g;h=TP((f&65535)+1&65535|f&-65536)|0;a[808104]=h;b[404048]=(b[404048]|0)+2&65535;HR((((h&255)<<8|g&255)&65535|e&65535)+d|0);return}function Rd(){var d=0,e=0,f=0,g=0,h=0,i=0;d=(a[808082]&32)==0;e=c[202032]|0;f=c[202024]|0;g=TP(f)|0;a[808104]=g;h=TP((f&65535)+1&65535|f&-65536)|0;a[808104]=h;b[404048]=(b[404048]|0)+2&65535;f=((h&255)<<8|g&255)&65535|e;if(d){d=TP(f)|0;a[808104]=d;e=TP(f+1|0)|0;g=(e&255)<<8|d&255;a[808104]=e;e=b[404042]|0;d=g^e;b[404042]=d;a[808121]=e<<16>>16!=g<<16>>16|0;i=(d&65535)>>>8&255;a[808122]=i;return}else{d=TP(f)|0;a[808104]=d;f=a[808084]^d;a[808084]=f;a[808121]=f;i=f;a[808122]=i;return}}function Re(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0;d=(a[808082]&32)==0;e=c[202032]|0;f=c[202024]|0;g=TP(f)|0;a[808104]=g;h=TP((f&65535)+1&65535|f&-65536)|0;a[808104]=h;b[404048]=(b[404048]|0)+2&65535;f=((h&255)<<8|g&255)&65535|e;e=TP(f)|0;if(d){a[808104]=e;d=f+1|0;g=TP(d)|0;a[808120]=e&1;h=(((g&255)<<8|e&255)&65535)>>>1;i=(g&255)>>>1;HY(i,d);d=h&255;HY(d,f);a[808104]=d;j=i;k=h<<16>>16!=0|0;a[808121]=k;a[808122]=j;return}else{a[808120]=e&1;h=(e&255)>>>1;HY(h,f);a[808104]=h;j=h;k=h;a[808121]=k;a[808122]=j;return}}function Rf(){var d=0,e=0,f=0,g=0,h=0,i=0;d=(a[808082]&32)==0;e=c[202024]|0;f=TP(e)|0;a[808104]=f;g=TP((e&65535)+1&65535|e&-65536)|0;a[808104]=g;b[404048]=(b[404048]|0)+2&65535;e=TP(c[202024]|0)|0;a[808104]=e;b[404048]=(b[404048]|0)+1&65535;h=(e&255)<<16|((g&255)<<8|f&255)&65535;if(d){d=TP(h)|0;a[808104]=d;f=TP(h+1|0)|0;g=(f&255)<<8|d&255;a[808104]=f;f=b[404042]|0;d=g^f;b[404042]=d;a[808121]=f<<16>>16!=g<<16>>16|0;i=(d&65535)>>>8&255;a[808122]=i;return}else{d=TP(h)|0;a[808104]=d;h=a[808084]^d;a[808084]=h;a[808121]=h;i=h;a[808122]=i;return}}function Rg(){var d=0,e=0,f=0;d=TP(c[202024]|0)|0;a[808104]=d;e=(b[404048]|0)+1&65535;b[404048]=e;f=e&65535;e=f+(d<<24>>24)|0;if((a[808123]|0)!=0){return}if(((e^f)&61440|0)==0){b[404048]=e&65535;return}else{HR((c[202031]|0)+(e&65535)|0);return}}function Rh(){var d=0,f=0,g=0,h=0,i=0,j=0;d=(a[808082]&32)==0;f=TP(c[202024]|0)|0;a[808104]=f;b[404048]=(b[404048]|0)+1&65535;g=b[404043]|0;if((b[404041]&256)==0){h=65535}else{h=(g&255)<<24>>24!=0?65535:255}i=TV(g+(f&255)&65535,h)|0;a[808104]=(i&65535)>>>8&255;h=(e[404046]|0)+(c[202032]|i&65535)|0;if(d){d=TP(h)|0;a[808104]=d;i=TP(h+1|0)|0;f=(i&255)<<8|d&255;a[808104]=i;i=b[404042]|0;d=f^i;b[404042]=d;a[808121]=i<<16>>16!=f<<16>>16|0;j=(d&65535)>>>8&255;a[808122]=j;return}else{d=TP(h)|0;a[808104]=d;h=a[808084]^d;a[808084]=h;a[808121]=h;j=h;a[808122]=j;return}}function Ri(){var d=0,e=0,f=0,g=0,h=0,i=0;d=(a[808082]&32)==0;e=TP(c[202024]|0)|0;a[808104]=e;b[404048]=(b[404048]|0)+1&65535;f=b[404043]|0;if((b[404041]&256)==0){g=65535}else{g=(f&255)<<24>>24!=0?65535:255}h=TV(f+(e&255)&65535,g)|0;a[808104]=(h&65535)>>>8&255;g=c[202032]|h&65535;if(d){d=TP(g)|0;a[808104]=d;h=TP(g+1|0)|0;e=(h&255)<<8|d&255;a[808104]=h;h=b[404042]|0;d=e^h;b[404042]=d;a[808121]=h<<16>>16!=e<<16>>16|0;i=(d&65535)>>>8&255;a[808122]=i;return}else{d=TP(g)|0;a[808104]=d;g=a[808084]^d;a[808084]=g;a[808121]=g;i=g;a[808122]=i;return}}function Rj(){var d=0,f=0,g=0,h=0,i=0;d=(a[808082]&32)==0;f=TP(c[202024]|0)|0;a[808104]=f;b[404048]=(b[404048]|0)+1&65535;g=(b[404044]|0)+(f&255)&65535;f=TP(g)|0;a[808104]=f;h=TP(g+1|0)|0;a[808104]=h;g=(c[202032]|0)+(e[404046]|0)+(((h&255)<<8|f&255)&65535)&16777215;if(d){d=TP(g)|0;a[808104]=d;f=TP(g+1|0)|0;h=(f&255)<<8|d&255;a[808104]=f;f=b[404042]|0;d=h^f;b[404042]=d;a[808121]=f<<16>>16!=h<<16>>16|0;i=(d&65535)>>>8&255;a[808122]=i;return}else{d=TP(g)|0;a[808104]=d;g=a[808084]^d;a[808084]=g;a[808121]=g;i=g;a[808122]=i;return}}function Rk(){var d=0,f=0;d=TP(c[202024]|0)|0;b[404048]=(b[404048]|0)+1&65535;a[808080]=d;a[808104]=d;c[202032]=(d&255)<<16;d=TP(c[202024]|0)|0;b[404048]=(b[404048]|0)+1&65535;a[808104]=d;f=TP(e[404045]|0|(d&255)<<16)|0;a[808104]=f;HY(f,(e[404046]|0)+(c[202032]|0)|0);if((a[808082]&16)==0){b[404045]=(b[404045]|0)+1&65535;b[404046]=(b[404046]|0)+1&65535}else{a[808090]=(a[808090]|0)+1&255;a[808092]=(a[808092]|0)+1&255}f=b[404042]|0;b[404042]=f-1&65535;if(f<<16>>16==0){return}b[404048]=(b[404048]|0)-3&65535;return}function Rl(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;d=(a[808082]&32)==0;e=TP(c[202024]|0)|0;a[808104]=e;b[404048]=(b[404048]|0)+1&65535;f=b[404043]|0;g=f+(e&255)&65535;e=g&255;h=(g&65535)>>>8;i=h&255;do{if((b[404041]&256)==0){j=3670}else{if((f&255)<<24>>24!=0){j=3670;break}k=(a[808090]|0)+e&255;l=i}}while(0);if((j|0)==3670){j=(b[404045]|0)+(h<<8|g&255)&65535;k=j&255;l=(j&65535)>>>8&255}j=(l&255)<<8|k&255;k=j&65535;if(d){d=TP(k)|0;a[808104]=d;l=TP(j+1&65535)|0;j=(l&255)<<8|d&255;a[808104]=l;l=b[404042]|0;d=j^l;b[404042]=d;a[808121]=l<<16>>16!=j<<16>>16|0;m=(d&65535)>>>8&255;a[808122]=m;return}else{d=TP(k)|0;a[808104]=d;k=a[808084]^d;a[808084]=k;a[808121]=k;m=k;a[808122]=m;return}}function Rm(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=(a[808082]&32)==0;e=TP(c[202024]|0)|0;a[808104]=e;b[404048]=(b[404048]|0)+1&65535;f=b[404043]|0;g=f+(e&255)&65535;e=g&255;h=(g&65535)>>>8;i=h&255;do{if((b[404041]&256)==0){j=3680}else{if((f&255)<<24>>24!=0){j=3680;break}k=(a[808090]|0)+e&255;l=i}}while(0);if((j|0)==3680){j=(b[404045]|0)+(h<<8|g&255)&65535;k=j&255;l=(j&65535)>>>8&255}j=(l&255)<<8|k&255;k=j&65535;l=TP(k)|0;if(d){a[808104]=l;d=j+1&65535;j=TP(d)|0;a[808120]=l&1;g=(((j&255)<<8|l&255)&65535)>>>1;h=(j&255)>>>1;HY(h,d);d=g&255;HY(d,k);a[808104]=d;m=h;n=g<<16>>16!=0|0;a[808121]=n;a[808122]=m;return}else{a[808120]=l&1;g=(l&255)>>>1;HY(g,k);a[808104]=g;m=g;n=g;a[808121]=n;a[808122]=m;return}}function Rn(){var d=0,f=0,g=0,h=0,i=0,j=0;d=(a[808082]&32)==0;f=TP(c[202024]|0)|0;a[808104]=f;b[404048]=(b[404048]|0)+1&65535;g=(b[404043]|0)+(f&255)&65535;f=TP(g)|0;a[808104]=f;h=TP(g+1|0)|0;a[808104]=h;i=TP(g+2|0)|0;a[808104]=i;g=(((h&255)<<8|f&255)&65535|(i&255)<<16)+(e[404046]|0)|0;if(d){d=TP(g)|0;a[808104]=d;i=TP(g+1|0)|0;f=(i&255)<<8|d&255;a[808104]=i;i=b[404042]|0;d=f^i;b[404042]=d;a[808121]=i<<16>>16!=f<<16>>16|0;j=(d&65535)>>>8&255;a[808122]=j;return}else{d=TP(g)|0;a[808104]=d;g=a[808084]^d;a[808084]=g;a[808121]=g;j=g;a[808122]=j;return}}function Ro(){var d=0,f=0,g=0,h=0,i=0,j=0;d=(a[808082]&32)==0;f=c[202032]|0;g=c[202024]|0;h=TP(g)|0;a[808104]=h;i=TP((g&65535)+1&65535|g&-65536)|0;a[808104]=i;b[404048]=(b[404048]|0)+2&65535;g=(((i&255)<<8|h&255)&65535|f)+(e[404046]|0)|0;if(d){d=TP(g)|0;a[808104]=d;f=TP(g+1|0)|0;h=(f&255)<<8|d&255;a[808104]=f;f=b[404042]|0;d=h^f;b[404042]=d;a[808121]=f<<16>>16!=h<<16>>16|0;j=(d&65535)>>>8&255;a[808122]=j;return}else{d=TP(g)|0;a[808104]=d;g=a[808084]^d;a[808084]=g;a[808121]=g;j=g;a[808122]=j;return}}function Rp(){var c=0,d=0,f=0;c=b[404041]|0;if((c&256)!=0){HY(a[808092]|0,e[404044]|0);a[808088]=(a[808088]|0)-1&255;d=a[808092]|0;a[808104]=d;return}if((c&16)==0){c=b[404046]|0;f=(e[404044]|0)-1|0;HY((c&65535)>>>8&255,(f&65535)+1&65535|f&-65536);HY(c&255,f);b[404044]=(b[404044]|0)-2&65535;d=a[808092]|0;a[808104]=d;return}else{f=a[808092]|0;c=b[404044]|0;b[404044]=c-1&65535;HY(f,c&65535);d=a[808092]|0;a[808104]=d;return}}function Rq(){var d=0,e=0,f=0;d=c[202024]|0;e=TP(d)|0;a[808104]=e;f=TP((d&65535)+1&65535|d&-65536)|0;a[808104]=f;b[404048]=(b[404048]|0)+2&65535;d=TP(c[202024]|0)|0;a[808104]=d;b[404048]=(b[404048]|0)+1&65535;HR((d&255)<<16|((f&255)<<8|e&255)&65535);return}function Rr(){var d=0,f=0,g=0,h=0,i=0,j=0;d=(a[808082]&32)==0;f=c[202032]|0;g=c[202024]|0;h=TP(g)|0;a[808104]=h;i=TP((g&65535)+1&65535|g&-65536)|0;a[808104]=i;b[404048]=(b[404048]|0)+2&65535;g=(((i&255)<<8|h&255)&65535|f)+(e[404045]|0)|0;if(d){d=TP(g)|0;a[808104]=d;f=TP(g+1|0)|0;h=(f&255)<<8|d&255;a[808104]=f;f=b[404042]|0;d=h^f;b[404042]=d;a[808121]=f<<16>>16!=h<<16>>16|0;j=(d&65535)>>>8&255;a[808122]=j;return}else{d=TP(g)|0;a[808104]=d;g=a[808084]^d;a[808084]=g;a[808121]=g;j=g;a[808122]=j;return}}function Rs(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=(a[808082]&32)==0;f=c[202032]|0;g=c[202024]|0;h=TP(g)|0;a[808104]=h;i=TP((g&65535)+1&65535|g&-65536)|0;a[808104]=i;b[404048]=(b[404048]|0)+2&65535;g=(((i&255)<<8|h&255)&65535|f)+(e[404045]|0)|0;f=TP(g)|0;if(d){a[808104]=f;d=g+1|0;h=TP(d)|0;a[808120]=f&1;i=(((h&255)<<8|f&255)&65535)>>>1;j=(h&255)>>>1;HY(j,d);d=i&255;HY(d,g);a[808104]=d;k=j;l=i<<16>>16!=0|0;a[808121]=l;a[808122]=k;return}else{a[808120]=f&1;i=(f&255)>>>1;HY(i,g);a[808104]=i;k=i;l=i;a[808121]=l;a[808122]=k;return}}function Rt(){var d=0,f=0,g=0,h=0,i=0,j=0;d=(a[808082]&32)==0;f=c[202024]|0;g=TP(f)|0;a[808104]=g;h=TP((f&65535)+1&65535|f&-65536)|0;a[808104]=h;b[404048]=(b[404048]|0)+2&65535;f=TP(c[202024]|0)|0;a[808104]=f;b[404048]=(b[404048]|0)+1&65535;i=(e[404045]|0)+((f&255)<<16|((h&255)<<8|g&255)&65535)|0;if(d){d=TP(i)|0;a[808104]=d;g=TP(i+1|0)|0;h=(g&255)<<8|d&255;a[808104]=g;g=b[404042]|0;d=h^g;b[404042]=d;a[808121]=g<<16>>16!=h<<16>>16|0;j=(d&65535)>>>8&255;a[808122]=j;return}else{d=TP(i)|0;a[808104]=d;i=a[808084]^d;a[808084]=i;a[808121]=i;j=i;a[808122]=j;return}}function Ru(){var d=0,f=0,g=0,h=0,i=0,j=0;if((b[404041]&256)==0){d=(e[404044]|0)+1|0;f=TP(d)|0;a[808104]=f;g=((TP((d&65535)+1&65535|d&2147418112)|0)&255)<<8|f&255;b[404048]=g;b[404044]=(b[404044]|0)+2&65535;h=g;i=h+1&65535;b[404048]=i;j=c[202024]|0;HR(j);return}else{a[808088]=(a[808088]|0)+1&255;g=b[404044]|0;f=TP(g&65535)|0;a[808104]=f;d=((TP(((g&255)+1&255|g&-256)&65535)|0)&255)<<8|f&255;b[404048]=d;a[808088]=(a[808088]|0)+1&255;h=d;i=h+1&65535;b[404048]=i;j=c[202024]|0;HR(j);return}}function Rv(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=(a[808082]&32)==0;f=TP(c[202024]|0)|0;a[808104]=f;b[404048]=(b[404048]|0)+1&65535;g=b[404043]|0;h=g+(f&255)&65535;f=(h&65535)>>>8;i=(b[404041]&256)==0;j=g&255;if(j<<24>>24==0&(i^1)){k=((a[808090]|0)+(h&255)&255|f<<8)&65535;l=3737}else{g=(b[404045]|0)+(f<<8|h&255)&65535;if(i){m=65535;n=g}else{k=g;l=3737}}if((l|0)==3737){m=j<<24>>24!=0?65535:255;n=k}k=TV(n,m)|0;a[808104]=(k&65535)>>>8&255;m=c[202032]|k&65535;if(e){e=TP(m)|0;a[808104]=e;k=TP(m+1|0)|0;a[808104]=k;TR((k&255)<<8|e&255);return}e=TP(m)|0;a[808104]=e;if((a[808082]&8)==0){m=a[808084]|0;k=e&255;n=(m&255)+k+(d[808120]|0)|0;a[808120]=(n&65280)>>>0>255|0;o=n&255;p=((n^k)&((m^e)&255^128))>>>7&255}else{m=b[404042]|0;k=m&255;n=m&240;m=((a[808120]|0)+(e&15)&255)+(k&15)&255;if((m&255)>9){q=m+6&15;r=n+16&65535}else{q=m;r=n}n=r+(e&-16&255)&65535;if((n&65535)>144){a[808120]=1;s=n+96&255&-16}else{a[808120]=0;s=n&255}n=s|q;o=n;p=((n^e)&(e^-128^k)&255)>>>7}a[808123]=p&1;a[808084]=o;a[808121]=o;a[808122]=o;return}function Rw(){var d=0,f=0,g=0;d=c[202024]|0;f=TP(d)|0;a[808104]=f;g=((TP((d&65535)+1&65535|d&-65536)|0)&255)<<8|f&255;f=(b[404048]|0)+2&65535;b[404048]=f;d=(g&65535)+(f&65535)|0;f=(e[404044]|0)-1|0;HY((d&65535)>>>8&255,(f&65535)+1&65535|f&-65536);g=d&255;HY(g,f);b[404044]=(b[404044]|0)-2&65535;a[808104]=g;if((b[404041]&256)==0){return}a[808089|0]=1;return}function Rx(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=(a[808082]&32)==0;f=TP(c[202024]|0)|0;a[808104]=f;b[404048]=(b[404048]|0)+1&65535;g=(b[404044]|0)+(f&255)&65535;if(e){e=TP(g)|0;a[808104]=e;f=TP(g+1|0)|0;a[808104]=f;TR((f&255)<<8|e&255);return}e=TP(g)|0;a[808104]=e;if((a[808082]&8)==0){g=a[808084]|0;f=e&255;h=(g&255)+f+(d[808120]|0)|0;a[808120]=(h&65280)>>>0>255|0;i=h&255;j=((h^f)&((g^e)&255^128))>>>7&255}else{g=b[404042]|0;f=g&255;h=g&240;g=((a[808120]|0)+(e&15)&255)+(f&15)&255;if((g&255)>9){k=g+6&15;l=h+16&65535}else{k=g;l=h}h=l+(e&-16&255)&65535;if((h&65535)>144){a[808120]=1;m=h+96&255&-16}else{a[808120]=0;m=h&255}h=m|k;i=h;j=((h^e)&(e^-128^f)&255)>>>7}a[808123]=j&1;a[808084]=i;a[808121]=i;a[808122]=i;return}function Ry(){var d=0,e=0,f=0;d=(a[808082]&32)==0;e=TP(c[202024]|0)|0;b[404048]=(b[404048]|0)+1&65535;f=(b[404043]|0)+(e&255)&65535;HY(0,f&65535);if(!d){a[808104]=0;return}HY(0,f+1&65535);a[808104]=0;return}function Rz(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=(a[808082]&32)==0;f=TP(c[202024]|0)|0;a[808104]=f;b[404048]=(b[404048]|0)+1&65535;g=(b[404043]|0)+(f&255)&65535;f=g&65535;if(e){e=TP(f)|0;a[808104]=e;h=TP(g+1&65535)|0;a[808104]=h;TR((h&255)<<8|e&255);return}e=TP(f)|0;a[808104]=e;if((a[808082]&8)==0){f=a[808084]|0;h=e&255;g=(f&255)+h+(d[808120]|0)|0;a[808120]=(g&65280)>>>0>255|0;i=g&255;j=((g^h)&((f^e)&255^128))>>>7&255}else{f=b[404042]|0;h=f&255;g=f&240;f=((a[808120]|0)+(e&15)&255)+(h&15)&255;if((f&255)>9){k=f+6&15;l=g+16&65535}else{k=f;l=g}g=l+(e&-16&255)&65535;if((g&65535)>144){a[808120]=1;m=g+96&255&-16}else{a[808120]=0;m=g&255}g=m|k;i=g;j=((g^e)&(e^-128^h)&255)>>>7}a[808123]=j&1;a[808084]=i;a[808121]=i;a[808122]=i;return}function RA(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=(a[808082]&32)==0;f=TP(c[202024]|0)|0;a[808104]=f;b[404048]=(b[404048]|0)+1&65535;g=(b[404043]|0)+(f&255)&65535;f=g&65535;h=TP(f)|0;if(e){a[808104]=h;e=g+1&65535;g=(((TP(e)|0)&255)<<8|h&255)&65535;i=g|(d[808120]|0)<<16;a[808120]=h&1;g=i>>>1;j=i>>>9&255;HY(j,e);e=g&255;HY(e,f);a[808104]=e;k=j;l=(g&65535|0)!=0|0;a[808121]=l;a[808122]=k;return}else{g=(d[808120]|0)<<8|h&255;a[808120]=h&1;h=(g&65535)>>>1&255;HY(h,f);a[808104]=h;k=h;l=h;a[808121]=l;a[808122]=k;return}}function RB(){var c=0,e=0,f=0;if((a[808082]&32)==0){c=b[404042]|0;e=(d[808120]|0)<<16|c&65535;a[808120]=c&1;c=e>>>1;b[404042]=c&65535;a[808121]=(c&65535|0)!=0|0;f=e>>>9&255;a[808122]=f;return}else{e=a[808084]|0;c=(d[808120]|0)<<8|e&255;a[808120]=e&1;e=(c&65535)>>>1&255;a[808084]=e;a[808121]=e;f=e;a[808122]=f;return}}function RC(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=(a[808082]&32)==0;f=TP(c[202024]|0)|0;a[808104]=f;b[404048]=(b[404048]|0)+1&65535;g=(b[404043]|0)+(f&255)&65535;f=TP(g)|0;a[808104]=f;h=TP(g+1|0)|0;a[808104]=h;i=TP(g+2|0)|0;a[808104]=i;g=((h&255)<<8|f&255)&65535|(i&255)<<16;if(e){e=TP(g)|0;a[808104]=e;i=TP(g+1|0)|0;a[808104]=i;TR((i&255)<<8|e&255);return}e=TP(g)|0;a[808104]=e;if((a[808082]&8)==0){g=a[808084]|0;i=e&255;f=(g&255)+i+(d[808120]|0)|0;a[808120]=(f&65280)>>>0>255|0;j=f&255;k=((f^i)&((g^e)&255^128))>>>7&255}else{g=b[404042]|0;i=g&255;f=g&240;g=((a[808120]|0)+(e&15)&255)+(i&15)&255;if((g&255)>9){l=g+6&15;m=f+16&65535}else{l=g;m=f}f=m+(e&-16&255)&65535;if((f&65535)>144){a[808120]=1;n=f+96&255&-16}else{a[808120]=0;n=f&255}f=n|l;j=f;k=((f^e)&(e^-128^i)&255)>>>7}a[808123]=k&1;a[808084]=j;a[808121]=j;a[808122]=j;return}function RD(){var c=0,d=0,f=0,g=0;c=b[404041]|0;if((c&256)!=0){a[808088]=(a[808088]|0)+1&255;d=TP(e[404044]|0)|0;a[808084]=d;a[808121]=d;a[808122]=d;a[808104]=d;return}d=b[404044]|0;if((c&32)==0){c=(d&65535)+1|0;f=TP(c)|0;a[808104]=f;g=TP((c&65535)+1&65535|c&2147418112)|0;c=(g&255)<<8|f&255;b[404042]=c;b[404044]=(b[404044]|0)+2&65535;a[808121]=c<<16>>16!=0|0;a[808122]=g;a[808104]=g;return}else{g=d+1&65535;b[404044]=g;d=TP(g&65535)|0;a[808084]=d;a[808121]=d;a[808122]=d;a[808104]=d;return}}function RE(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=(a[808082]&32)==0;f=c[202024]|0;g=TP(f)|0;a[808104]=g;if(e){e=TP((f&65535)+1&65535|f&-65536)|0;a[808104]=e;b[404048]=(b[404048]|0)+2&65535;TR((e&255)<<8|g&255);return}b[404048]=(b[404048]|0)+1&65535;if((a[808082]&8)==0){e=a[808084]|0;f=g&255;h=(e&255)+f+(d[808120]|0)|0;a[808120]=(h&65280)>>>0>255|0;i=h&255;j=((h^f)&((e^g)&255^128))>>>7&255}else{e=b[404042]|0;f=e&255;h=e&240;e=((a[808120]|0)+(g&15)&255)+(f&15)&255;if((e&255)>9){k=e+6&15;l=h+16&65535}else{k=e;l=h}h=l+(g&-16&255)&65535;if((h&65535)>144){a[808120]=1;m=h+96&255&-16}else{a[808120]=0;m=h&255}h=m|k;i=h;j=((h^g)&(g^-128^f)&255)>>>7}a[808123]=j&1;a[808084]=i;a[808121]=i;a[808122]=i;return}function RF(){var d=0,f=0,g=0,h=0,i=0;d=(e[404044]|0)+1|0;f=TP(d)|0;a[808104]=f;b[404048]=((TP((d&65535)+1&65535|d&2147418112)|0)&255)<<8|f&255;f=(b[404044]|0)+3&65535;b[404044]=f;a[808098|0]=TP(f&65535)|0;if((b[404041]&256)==0){g=b[404048]|0;h=g+1&65535;b[404048]=h;i=c[202024]|0;HR(i);return}a[808089|0]=1;g=b[404048]|0;h=g+1&65535;b[404048]=h;i=c[202024]|0;HR(i);return}function RG(){var d=0,e=0,f=0,g=0;d=c[202031]|0;e=c[202024]|0;f=TP(e)|0;a[808104]=f;g=TP((e&65535)+1&65535|e&-65536)|0;a[808104]=g;b[404048]=(b[404048]|0)+2&65535;e=((g&255)<<8|f&255)&65535;f=TP(e)|0;a[808104]=f;g=TP(e+1|0)|0;a[808104]=g;HR((((g&255)<<8|f&255)&65535)+d|0);return}function RH(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=(a[808082]&32)==0;f=c[202032]|0;g=c[202024]|0;h=TP(g)|0;a[808104]=h;i=TP((g&65535)+1&65535|g&-65536)|0;a[808104]=i;b[404048]=(b[404048]|0)+2&65535;g=((i&255)<<8|h&255)&65535|f;if(e){e=TP(g)|0;a[808104]=e;f=TP(g+1|0)|0;a[808104]=f;TR((f&255)<<8|e&255);return}e=TP(g)|0;a[808104]=e;if((a[808082]&8)==0){g=a[808084]|0;f=e&255;h=(g&255)+f+(d[808120]|0)|0;a[808120]=(h&65280)>>>0>255|0;j=h&255;k=((h^f)&((g^e)&255^128))>>>7&255}else{g=b[404042]|0;f=g&255;h=g&240;g=((a[808120]|0)+(e&15)&255)+(f&15)&255;if((g&255)>9){l=g+6&15;m=h+16&65535}else{l=g;m=h}h=m+(e&-16&255)&65535;if((h&65535)>144){a[808120]=1;n=h+96&255&-16}else{a[808120]=0;n=h&255}h=n|l;j=h;k=((h^e)&(e^-128^f)&255)>>>7}a[808123]=k&1;a[808084]=j;a[808121]=j;a[808122]=j;return}function RI(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;e=(a[808082]&32)==0;f=c[202032]|0;g=c[202024]|0;h=TP(g)|0;a[808104]=h;i=TP((g&65535)+1&65535|g&-65536)|0;a[808104]=i;b[404048]=(b[404048]|0)+2&65535;g=((i&255)<<8|h&255)&65535|f;f=TP(g)|0;if(e){a[808104]=f;e=g+1|0;h=(((TP(e)|0)&255)<<8|f&255)&65535;i=h|(d[808120]|0)<<16;a[808120]=f&1;h=i>>>1;j=i>>>9&255;HY(j,e);e=h&255;HY(e,g);a[808104]=e;k=j;l=(h&65535|0)!=0|0;a[808121]=l;a[808122]=k;return}else{h=(d[808120]|0)<<8|f&255;a[808120]=f&1;f=(h&65535)>>>1&255;HY(f,g);a[808104]=f;k=f;l=f;a[808121]=l;a[808122]=k;return}}function RJ(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=(a[808082]&32)==0;f=c[202024]|0;g=TP(f)|0;a[808104]=g;h=TP((f&65535)+1&65535|f&-65536)|0;a[808104]=h;b[404048]=(b[404048]|0)+2&65535;f=TP(c[202024]|0)|0;a[808104]=f;b[404048]=(b[404048]|0)+1&65535;i=(f&255)<<16|((h&255)<<8|g&255)&65535;if(e){e=TP(i)|0;a[808104]=e;g=TP(i+1|0)|0;a[808104]=g;TR((g&255)<<8|e&255);return}e=TP(i)|0;a[808104]=e;if((a[808082]&8)==0){i=a[808084]|0;g=e&255;h=(i&255)+g+(d[808120]|0)|0;a[808120]=(h&65280)>>>0>255|0;j=h&255;k=((h^g)&((i^e)&255^128))>>>7&255}else{i=b[404042]|0;g=i&255;h=i&240;i=((a[808120]|0)+(e&15)&255)+(g&15)&255;if((i&255)>9){l=i+6&15;m=h+16&65535}else{l=i;m=h}h=m+(e&-16&255)&65535;if((h&65535)>144){a[808120]=1;n=h+96&255&-16}else{a[808120]=0;n=h&255}h=n|l;j=h;k=((h^e)&(e^-128^g)&255)>>>7}a[808123]=k&1;a[808084]=j;a[808121]=j;a[808122]=j;return}function RK(){var d=0,e=0,f=0;d=TP(c[202024]|0)|0;a[808104]=d;e=(b[404048]|0)+1&65535;b[404048]=e;f=e&65535;e=f+(d<<24>>24)|0;if((a[808123]|0)==0){return}if(((e^f)&61440|0)==0){b[404048]=e&65535;return}else{HR((c[202031]|0)+(e&65535)|0);return}}function RL(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=(a[808082]&32)==0;g=TP(c[202024]|0)|0;a[808104]=g;b[404048]=(b[404048]|0)+1&65535;h=b[404043]|0;if((b[404041]&256)==0){i=65535}else{i=(h&255)<<24>>24!=0?65535:255}j=TV(h+(g&255)&65535,i)|0;a[808104]=(j&65535)>>>8&255;i=(e[404046]|0)+(c[202032]|j&65535)|0;if(f){f=TP(i)|0;a[808104]=f;j=TP(i+1|0)|0;a[808104]=j;TR((j&255)<<8|f&255);return}f=TP(i)|0;a[808104]=f;if((a[808082]&8)==0){i=a[808084]|0;j=f&255;g=(i&255)+j+(d[808120]|0)|0;a[808120]=(g&65280)>>>0>255|0;k=g&255;l=((g^j)&((i^f)&255^128))>>>7&255}else{i=b[404042]|0;j=i&255;g=i&240;i=((a[808120]|0)+(f&15)&255)+(j&15)&255;if((i&255)>9){m=i+6&15;n=g+16&65535}else{m=i;n=g}g=n+(f&-16&255)&65535;if((g&65535)>144){a[808120]=1;o=g+96&255&-16}else{a[808120]=0;o=g&255}g=o|m;k=g;l=((g^f)&(f^-128^j)&255)>>>7}a[808123]=l&1;a[808084]=k;a[808121]=k;a[808122]=k;return}function RM(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=(a[808082]&32)==0;f=TP(c[202024]|0)|0;a[808104]=f;b[404048]=(b[404048]|0)+1&65535;g=b[404043]|0;if((b[404041]&256)==0){h=65535}else{h=(g&255)<<24>>24!=0?65535:255}i=TV(g+(f&255)&65535,h)|0;a[808104]=(i&65535)>>>8&255;h=c[202032]|i&65535;if(e){e=TP(h)|0;a[808104]=e;i=TP(h+1|0)|0;a[808104]=i;TR((i&255)<<8|e&255);return}e=TP(h)|0;a[808104]=e;if((a[808082]&8)==0){h=a[808084]|0;i=e&255;f=(h&255)+i+(d[808120]|0)|0;a[808120]=(f&65280)>>>0>255|0;j=f&255;k=((f^i)&((h^e)&255^128))>>>7&255}else{h=b[404042]|0;i=h&255;f=h&240;h=((a[808120]|0)+(e&15)&255)+(i&15)&255;if((h&255)>9){l=h+6&15;m=f+16&65535}else{l=h;m=f}f=m+(e&-16&255)&65535;if((f&65535)>144){a[808120]=1;n=f+96&255&-16}else{a[808120]=0;n=f&255}f=n|l;j=f;k=((f^e)&(e^-128^i)&255)>>>7}a[808123]=k&1;a[808084]=j;a[808121]=j;a[808122]=j;return}function RN(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;f=(a[808082]&32)==0;g=TP(c[202024]|0)|0;a[808104]=g;b[404048]=(b[404048]|0)+1&65535;h=(b[404044]|0)+(g&255)&65535;g=TP(h)|0;a[808104]=g;i=TP(h+1|0)|0;a[808104]=i;h=(c[202032]|0)+(e[404046]|0)+(((i&255)<<8|g&255)&65535)&16777215;if(f){f=TP(h)|0;a[808104]=f;g=TP(h+1|0)|0;a[808104]=g;TR((g&255)<<8|f&255);return}f=TP(h)|0;a[808104]=f;if((a[808082]&8)==0){h=a[808084]|0;g=f&255;i=(h&255)+g+(d[808120]|0)|0;a[808120]=(i&65280)>>>0>255|0;j=i&255;k=((i^g)&((h^f)&255^128))>>>7&255}else{h=b[404042]|0;g=h&255;i=h&240;h=((a[808120]|0)+(f&15)&255)+(g&15)&255;if((h&255)>9){l=h+6&15;m=i+16&65535}else{l=h;m=i}i=m+(f&-16&255)&65535;if((i&65535)>144){a[808120]=1;n=i+96&255&-16}else{a[808120]=0;n=i&255}i=n|l;j=i;k=((i^f)&(f^-128^g)&255)>>>7}a[808123]=k&1;a[808084]=j;a[808121]=j;a[808122]=j;return}function RO(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;d=(a[808082]&32)==0;e=TP(c[202024]|0)|0;b[404048]=(b[404048]|0)+1&65535;f=b[404043]|0;g=f+(e&255)&65535;e=g&255;h=(g&65535)>>>8;i=h&255;do{if((b[404041]&256)==0){j=3935}else{if((f&255)<<24>>24!=0){j=3935;break}k=(a[808090]|0)+e&255;l=i}}while(0);if((j|0)==3935){j=(b[404045]|0)+(h<<8|g&255)&65535;k=j&255;l=(j&65535)>>>8&255}j=(l&255)<<8|k&255;HY(0,j&65535);if(!d){a[808104]=0;return}HY(0,j+1&65535);a[808104]=0;return}function RP(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=(a[808082]&32)==0;f=TP(c[202024]|0)|0;a[808104]=f;b[404048]=(b[404048]|0)+1&65535;g=b[404043]|0;h=g+(f&255)&65535;f=h&255;i=(h&65535)>>>8;j=i&255;do{if((b[404041]&256)==0){k=3944}else{if((g&255)<<24>>24!=0){k=3944;break}l=(a[808090]|0)+f&255;m=j}}while(0);if((k|0)==3944){k=(b[404045]|0)+(i<<8|h&255)&65535;l=k&255;m=(k&65535)>>>8&255}k=(m&255)<<8|l&255;l=k&65535;if(e){e=TP(l)|0;a[808104]=e;m=TP(k+1&65535)|0;a[808104]=m;TR((m&255)<<8|e&255);return}e=TP(l)|0;a[808104]=e;if((a[808082]&8)==0){l=a[808084]|0;m=e&255;k=(l&255)+m+(d[808120]|0)|0;a[808120]=(k&65280)>>>0>255|0;n=k&255;o=((k^m)&((l^e)&255^128))>>>7&255}else{l=b[404042]|0;m=l&255;k=l&240;l=((a[808120]|0)+(e&15)&255)+(m&15)&255;if((l&255)>9){p=l+6&15;q=k+16&65535}else{p=l;q=k}k=q+(e&-16&255)&65535;if((k&65535)>144){a[808120]=1;r=k+96&255&-16}else{a[808120]=0;r=k&255}k=r|p;n=k;o=((k^e)&(e^-128^m)&255)>>>7}a[808123]=o&1;a[808084]=n;a[808121]=n;a[808122]=n;return}function RQ(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;e=(a[808082]&32)==0;f=TP(c[202024]|0)|0;a[808104]=f;b[404048]=(b[404048]|0)+1&65535;g=b[404043]|0;h=g+(f&255)&65535;f=h&255;i=(h&65535)>>>8;j=i&255;do{if((b[404041]&256)==0){k=3962}else{if((g&255)<<24>>24!=0){k=3962;break}l=(a[808090]|0)+f&255;m=j}}while(0);if((k|0)==3962){k=(b[404045]|0)+(i<<8|h&255)&65535;l=k&255;m=(k&65535)>>>8&255}k=(m&255)<<8|l&255;l=k&65535;m=TP(l)|0;if(e){a[808104]=m;e=k+1&65535;k=(((TP(e)|0)&255)<<8|m&255)&65535;h=k|(d[808120]|0)<<16;a[808120]=m&1;k=h>>>1;i=h>>>9&255;HY(i,e);e=k&255;HY(e,l);a[808104]=e;n=i;o=(k&65535|0)!=0|0;a[808121]=o;a[808122]=n;return}else{k=(d[808120]|0)<<8|m&255;a[808120]=m&1;m=(k&65535)>>>1&255;HY(m,l);a[808104]=m;n=m;o=m;a[808121]=o;a[808122]=n;return}}function RR(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=(a[808082]&32)==0;g=TP(c[202024]|0)|0;a[808104]=g;b[404048]=(b[404048]|0)+1&65535;h=(b[404043]|0)+(g&255)&65535;g=TP(h)|0;a[808104]=g;i=TP(h+1|0)|0;a[808104]=i;j=TP(h+2|0)|0;a[808104]=j;h=(((i&255)<<8|g&255)&65535|(j&255)<<16)+(e[404046]|0)|0;if(f){f=TP(h)|0;a[808104]=f;j=TP(h+1|0)|0;a[808104]=j;TR((j&255)<<8|f&255);return}f=TP(h)|0;a[808104]=f;if((a[808082]&8)==0){h=a[808084]|0;j=f&255;g=(h&255)+j+(d[808120]|0)|0;a[808120]=(g&65280)>>>0>255|0;k=g&255;l=((g^j)&((h^f)&255^128))>>>7&255}else{h=b[404042]|0;j=h&255;g=h&240;h=((a[808120]|0)+(f&15)&255)+(j&15)&255;if((h&255)>9){m=h+6&15;n=g+16&65535}else{m=h;n=g}g=n+(f&-16&255)&65535;if((g&65535)>144){a[808120]=1;o=g+96&255&-16}else{a[808120]=0;o=g&255}g=o|m;k=g;l=((g^f)&(f^-128^j)&255)>>>7}a[808123]=l&1;a[808084]=k;a[808121]=k;a[808122]=k;return}function RS(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=(a[808082]&32)==0;g=c[202032]|0;h=c[202024]|0;i=TP(h)|0;a[808104]=i;j=TP((h&65535)+1&65535|h&-65536)|0;a[808104]=j;b[404048]=(b[404048]|0)+2&65535;h=(((j&255)<<8|i&255)&65535|g)+(e[404046]|0)|0;if(f){f=TP(h)|0;a[808104]=f;g=TP(h+1|0)|0;a[808104]=g;TR((g&255)<<8|f&255);return}f=TP(h)|0;a[808104]=f;if((a[808082]&8)==0){h=a[808084]|0;g=f&255;i=(h&255)+g+(d[808120]|0)|0;a[808120]=(i&65280)>>>0>255|0;k=i&255;l=((i^g)&((h^f)&255^128))>>>7&255}else{h=b[404042]|0;g=h&255;i=h&240;h=((a[808120]|0)+(f&15)&255)+(g&15)&255;if((h&255)>9){m=h+6&15;n=i+16&65535}else{m=h;n=i}i=n+(f&-16&255)&65535;if((i&65535)>144){a[808120]=1;o=i+96&255&-16}else{a[808120]=0;o=i&255}i=o|m;k=i;l=((i^f)&(f^-128^g)&255)>>>7}a[808123]=l&1;a[808084]=k;a[808121]=k;a[808122]=k;return}function RT(){var c=0,d=0,f=0,g=0;c=b[404041]|0;if((c&256)!=0){a[808088]=(a[808088]|0)+1&255;d=TP(e[404044]|0)|0;a[808092]=d;a[808121]=d;a[808122]=d;a[808104]=d;return}d=b[404044]|0;if((c&16)==0){c=(d&65535)+1|0;f=TP(c)|0;a[808104]=f;g=TP((c&65535)+1&65535|c&2147418112)|0;c=(g&255)<<8|f&255;b[404046]=c;b[404044]=(b[404044]|0)+2&65535;a[808121]=c<<16>>16!=0|0;a[808122]=g;a[808104]=g;return}else{g=d+1&65535;b[404044]=g;d=TP(g&65535)|0;a[808092]=d;a[808121]=d;a[808122]=d;a[808104]=d;return}}function RU(){var d=0,e=0,f=0,g=0,h=0;d=c[202031]|0;e=c[202024]|0;f=TP(e)|0;a[808104]=f;g=TP((e&65535)+1&65535|e&-65536)|0;a[808104]=g;b[404048]=(b[404048]|0)+2&65535;e=c[202031]|0;h=((g&255)<<8|f&255)+(b[404045]|0)&65535|e;f=TP(h)|0;a[808104]=f;g=TP((h&65535)+1&65535|e&-65536)|0;a[808104]=g;HR((((g&255)<<8|f&255)&65535)+d|0);return}function RV(){var c=0,d=0;if((a[808082]&16)==0){c=(b[404046]|0)-1&65535;b[404046]=c;a[808121]=c<<16>>16!=0|0;d=(c&65535)>>>8&255;a[808122]=d;return}else{c=(a[808092]|0)-1&255;a[808092]=c;a[808121]=c;d=c;a[808122]=d;return}}function RW(){var c=0,d=0;if((a[808082]&32)==0){c=b[404045]|0;b[404042]=c;a[808121]=c<<16>>16!=0|0;d=(c&65535)>>>8&255;a[808122]=d;return}else{c=a[808090]|0;a[808084]=c;a[808121]=c;d=c;a[808122]=d;return}}function RX(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=(a[808082]&32)==0;g=c[202032]|0;h=c[202024]|0;i=TP(h)|0;a[808104]=i;j=TP((h&65535)+1&65535|h&-65536)|0;a[808104]=j;b[404048]=(b[404048]|0)+2&65535;h=(((j&255)<<8|i&255)&65535|g)+(e[404045]|0)|0;if(f){f=TP(h)|0;a[808104]=f;g=TP(h+1|0)|0;a[808104]=g;TR((g&255)<<8|f&255);return}f=TP(h)|0;a[808104]=f;if((a[808082]&8)==0){h=a[808084]|0;g=f&255;i=(h&255)+g+(d[808120]|0)|0;a[808120]=(i&65280)>>>0>255|0;k=i&255;l=((i^g)&((h^f)&255^128))>>>7&255}else{h=b[404042]|0;g=h&255;i=h&240;h=((a[808120]|0)+(f&15)&255)+(g&15)&255;if((h&255)>9){m=h+6&15;n=i+16&65535}else{m=h;n=i}i=n+(f&-16&255)&65535;if((i&65535)>144){a[808120]=1;o=i+96&255&-16}else{a[808120]=0;o=i&255}i=o|m;k=i;l=((i^f)&(f^-128^g)&255)>>>7}a[808123]=l&1;a[808084]=k;a[808121]=k;a[808122]=k;return}function RY(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;f=(a[808082]&32)==0;g=c[202032]|0;h=c[202024]|0;i=TP(h)|0;a[808104]=i;j=TP((h&65535)+1&65535|h&-65536)|0;a[808104]=j;b[404048]=(b[404048]|0)+2&65535;h=(((j&255)<<8|i&255)&65535|g)+(e[404045]|0)|0;g=TP(h)|0;if(f){a[808104]=g;f=h+1|0;i=(((TP(f)|0)&255)<<8|g&255)&65535;j=i|(d[808120]|0)<<16;a[808120]=g&1;i=j>>>1;k=j>>>9&255;HY(k,f);f=i&255;HY(f,h);a[808104]=f;l=k;m=(i&65535|0)!=0|0;a[808121]=m;a[808122]=l;return}else{i=(d[808120]|0)<<8|g&255;a[808120]=g&1;g=(i&65535)>>>1&255;HY(g,h);a[808104]=g;l=g;m=g;a[808121]=m;a[808122]=l;return}}function RZ(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=(a[808082]&32)==0;g=c[202024]|0;h=TP(g)|0;a[808104]=h;i=TP((g&65535)+1&65535|g&-65536)|0;a[808104]=i;b[404048]=(b[404048]|0)+2&65535;g=TP(c[202024]|0)|0;a[808104]=g;b[404048]=(b[404048]|0)+1&65535;j=(e[404045]|0)+((g&255)<<16|((i&255)<<8|h&255)&65535)|0;if(f){f=TP(j)|0;a[808104]=f;h=TP(j+1|0)|0;a[808104]=h;TR((h&255)<<8|f&255);return}f=TP(j)|0;a[808104]=f;if((a[808082]&8)==0){j=a[808084]|0;h=f&255;i=(j&255)+h+(d[808120]|0)|0;a[808120]=(i&65280)>>>0>255|0;k=i&255;l=((i^h)&((j^f)&255^128))>>>7&255}else{j=b[404042]|0;h=j&255;i=j&240;j=((a[808120]|0)+(f&15)&255)+(h&15)&255;if((j&255)>9){m=j+6&15;n=i+16&65535}else{m=j;n=i}i=n+(f&-16&255)&65535;if((i&65535)>144){a[808120]=1;o=i+96&255&-16}else{a[808120]=0;o=i&255}i=o|m;k=i;l=((i^f)&(f^-128^h)&255)>>>7}a[808123]=l&1;a[808084]=k;a[808121]=k;a[808122]=k;return}function R_(){var d=0,e=0,f=0;d=TP(c[202024]|0)|0;a[808104]=d;e=(b[404048]|0)+1&65535;b[404048]=e;f=e&65535;e=f+(d<<24>>24)|0;if(((e^f)&61440|0)==0){b[404048]=e&65535;return}else{HR((c[202031]|0)+(e&65535)|0);return}}function R$(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=(a[808082]&32)==0;e=TP(c[202024]|0)|0;a[808104]=e;b[404048]=(b[404048]|0)+1&65535;f=b[404043]|0;g=f+(e&255)&65535;e=(g&65535)>>>8;h=(b[404041]&256)==0;i=f&255;if(i<<24>>24==0&(h^1)){j=((a[808090]|0)+(g&255)&255|e<<8)&65535;k=4063}else{f=(b[404045]|0)+(e<<8|g&255)&65535;if(h){l=65535;m=f}else{j=f;k=4063}}if((k|0)==4063){l=i<<24>>24!=0?65535:255;m=j}j=(TV(m,l)|0)&65535;l=c[202032]|j;if(d){d=b[404042]|0;HY(d&255,l);HY((d&65535)>>>8&255,l+1|0);n=808085|0;o=a[n]|0;a[808104]=o;return}else{HY(a[808084]|0,l);n=808084;o=a[n]|0;a[808104]=o;return}}function R0(){var d=0,e=0,f=0,g=0;d=c[202031]|0;e=c[202024]|0;f=TP(e)|0;a[808104]=f;g=TP((e&65535)+1&65535|e&-65536)|0;a[808104]=g;e=(b[404048]|0)+2&65535;b[404048]=e;HR(((((g&255)<<8|f&255)&65535)+(e&65535)&65535)+d|0);return}function R1(){var d=0,e=0,f=0,g=0,h=0;d=(a[808082]&32)==0;e=TP(c[202024]|0)|0;b[404048]=(b[404048]|0)+1&65535;f=(b[404044]|0)+(e&255)&65535;if(d){d=b[404042]|0;HY(d&255,f);HY((d&65535)>>>8&255,f+1|0);g=808085|0;h=a[g]|0;a[808104]=h;return}else{HY(a[808084]|0,f);g=808084;h=a[g]|0;a[808104]=h;return}}function R2(){var d=0,e=0,f=0,g=0,h=0;d=(a[808082]&16)==0;e=TP(c[202024]|0)|0;b[404048]=(b[404048]|0)+1&65535;f=(b[404043]|0)+(e&255)&65535;e=f&65535;if(d){d=b[404046]|0;HY(d&255,e);HY((d&65535)>>>8&255,f+1&65535);g=808093|0;h=a[g]|0;a[808104]=h;return}else{HY(a[808092]|0,e);g=808092;h=a[g]|0;a[808104]=h;return}}function R3(){var d=0,e=0,f=0,g=0,h=0;d=(a[808082]&32)==0;e=TP(c[202024]|0)|0;b[404048]=(b[404048]|0)+1&65535;f=(b[404043]|0)+(e&255)&65535;e=f&65535;if(d){d=b[404042]|0;HY(d&255,e);HY((d&65535)>>>8&255,f+1&65535);g=808085|0;h=a[g]|0;a[808104]=h;return}else{HY(a[808084]|0,e);g=808084;h=a[g]|0;a[808104]=h;return}}function R4(){var d=0,e=0,f=0,g=0,h=0;d=(a[808082]&16)==0;e=TP(c[202024]|0)|0;b[404048]=(b[404048]|0)+1&65535;f=(b[404043]|0)+(e&255)&65535;e=f&65535;if(d){d=b[404045]|0;HY(d&255,e);HY((d&65535)>>>8&255,f+1&65535);g=808091|0;h=a[g]|0;a[808104]=h;return}else{HY(a[808090]|0,e);g=808090;h=a[g]|0;a[808104]=h;return}}function R5(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=(a[808082]&32)==0;e=TP(c[202024]|0)|0;a[808104]=e;b[404048]=(b[404048]|0)+1&65535;f=(b[404043]|0)+(e&255)&65535;e=TP(f)|0;a[808104]=e;g=TP(f+1|0)|0;a[808104]=g;h=TP(f+2|0)|0;a[808104]=h;f=((g&255)<<8|e&255)&65535|(h&255)<<16;if(d){d=b[404042]|0;HY(d&255,f);HY((d&65535)>>>8&255,f+1|0);i=808085|0;j=a[i]|0;a[808104]=j;return}else{HY(a[808084]|0,f);i=808084;j=a[i]|0;a[808104]=j;return}}function R6(){var d=0,e=0,f=0,g=0,h=0;if((a[808082]&32)==0){d=b[404042]|0;e=c[202024]|0;f=TP(e)|0;a[808104]=f;g=TP((e&65535)+1&65535|e&-65536)|0;a[808104]=g;b[404048]=(b[404048]|0)+2&65535;h=(((g&255)<<8|f&255)&d)<<16>>16!=0|0;a[808121]=h;return}else{d=a[808084]|0;f=TP(c[202024]|0)|0;a[808104]=f;b[404048]=(b[404048]|0)+1&65535;h=f&d;a[808121]=h;return}}function R7(){var c=0,d=0,e=0;c=a[808080]|0;d=b[404044]|0;if((b[404041]&256)==0){b[404044]=d-1&65535;HY(c,d&65535);e=a[808080]|0;a[808104]=e;return}else{HY(c,d&65535);a[808088]=(a[808088]|0)-1&255;e=a[808080]|0;a[808104]=e;return}}function R8(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=(a[808082]&16)==0;e=c[202032]|0;f=c[202024]|0;g=TP(f)|0;a[808104]=g;h=((TP((f&65535)+1&65535|f&-65536)|0)&255)<<8|g&255;b[404048]=(b[404048]|0)+2&65535;g=h&65535|e;if(d){d=b[404046]|0;HY(d&255,g);HY((d&65535)>>>8&255,(g&65535)+1&65535|e&-65536);i=808093|0;j=a[i]|0;a[808104]=j;return}else{HY(a[808092]|0,g);i=808092;j=a[i]|0;a[808104]=j;return}}function R9(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=(a[808082]&32)==0;e=c[202032]|0;f=c[202024]|0;g=TP(f)|0;a[808104]=g;h=((TP((f&65535)+1&65535|f&-65536)|0)&255)<<8|g&255;b[404048]=(b[404048]|0)+2&65535;g=h&65535|e;if(d){d=b[404042]|0;HY(d&255,g);HY((d&65535)>>>8&255,g+1|0);i=808085|0;j=a[i]|0;a[808104]=j;return}else{HY(a[808084]|0,g);i=808084;j=a[i]|0;a[808104]=j;return}}function Sa(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=(a[808082]&16)==0;e=c[202032]|0;f=c[202024]|0;g=TP(f)|0;a[808104]=g;h=((TP((f&65535)+1&65535|f&-65536)|0)&255)<<8|g&255;b[404048]=(b[404048]|0)+2&65535;g=h&65535|e;if(d){d=b[404045]|0;HY(d&255,g);HY((d&65535)>>>8&255,(g&65535)+1&65535|e&-65536);i=808091|0;j=a[i]|0;a[808104]=j;return}else{HY(a[808090]|0,g);i=808090;j=a[i]|0;a[808104]=j;return}}function Sb(){var c=0,d=0;if((a[808082]&32)==0){c=b[404046]|0;b[404042]=c;a[808121]=c<<16>>16!=0|0;d=(c&65535)>>>8&255;a[808122]=d;return}else{c=a[808092]|0;a[808084]=c;a[808121]=c;d=c;a[808122]=d;return}}function Sc(){var c=0,d=0;if((a[808082]&16)==0){c=b[404045]|0;b[404046]=c;a[808121]=c<<16>>16!=0|0;d=(c&65535)>>>8&255;a[808122]=d;return}else{c=a[808090]|0;a[808092]=c;a[808121]=c;d=c;a[808122]=d;return}}function Sd(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=(a[808082]&32)==0;e=c[202024]|0;f=TP(e)|0;a[808104]=f;g=TP((e&65535)+1&65535|e&-65536)|0;a[808104]=g;b[404048]=(b[404048]|0)+2&65535;e=TP(c[202024]|0)|0;b[404048]=(b[404048]|0)+1&65535;h=(e&255)<<16|((g&255)<<8|f&255)&65535;if(d){d=b[404042]|0;HY(d&255,h);HY((d&65535)>>>8&255,h+1|0);i=808085|0;j=a[i]|0;a[808104]=j;return}else{HY(a[808084]|0,h);i=808084;j=a[i]|0;a[808104]=j;return}}function Se(){var d=0,e=0,f=0;d=TP(c[202024]|0)|0;a[808104]=d;e=(b[404048]|0)+1&65535;b[404048]=e;f=e&65535;e=f+(d<<24>>24)|0;if((a[808120]|0)!=0){return}if(((e^f)&61440|0)==0){b[404048]=e&65535;return}else{HR((c[202031]|0)+(e&65535)|0);return}}function Sf(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0;d=(a[808082]&32)==0;f=TP(c[202024]|0)|0;a[808104]=f;b[404048]=(b[404048]|0)+1&65535;g=b[404043]|0;if((b[404041]&256)==0){h=65535}else{h=(g&255)<<24>>24!=0?65535:255}i=(TV(g+(f&255)&65535,h)|0)&65535;h=(e[404046]|0)+(c[202032]|i)|0;if(d){d=b[404042]|0;HY(d&255,h);HY((d&65535)>>>8&255,h+1|0);j=808085|0;k=a[j]|0;a[808104]=k;return}else{HY(a[808084]|0,h);j=808084;k=a[j]|0;a[808104]=k;return}}function Sg(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=(a[808082]&32)==0;e=TP(c[202024]|0)|0;a[808104]=e;b[404048]=(b[404048]|0)+1&65535;f=b[404043]|0;if((b[404041]&256)==0){g=65535}else{g=(f&255)<<24>>24!=0?65535:255}h=(TV(f+(e&255)&65535,g)|0)&65535;g=c[202032]|h;if(d){d=b[404042]|0;HY(d&255,g);HY((d&65535)>>>8&255,g+1|0);i=808085|0;j=a[i]|0;a[808104]=j;return}else{HY(a[808084]|0,g);i=808084;j=a[i]|0;a[808104]=j;return}}function Sh(){var d=0,f=0,g=0,h=0,i=0,j=0;d=(a[808082]&32)==0;f=TP(c[202024]|0)|0;a[808104]=f;b[404048]=(b[404048]|0)+1&65535;g=(b[404044]|0)+(f&255)&65535;f=TP(g)|0;a[808104]=f;h=(((TP(g+1|0)|0)&255)<<8|f&255)&65535;f=(c[202032]|0)+(e[404046]|0)+h&16777215;if(d){d=b[404042]|0;HY(d&255,f);HY((d&65535)>>>8&255,f+1|0);i=808085|0;j=a[i]|0;a[808104]=j;return}else{HY(a[808084]|0,f);i=808084;j=a[i]|0;a[808104]=j;return}}function Si(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=(a[808082]&16)==0;e=TP(c[202024]|0)|0;b[404048]=(b[404048]|0)+1&65535;f=b[404043]|0;g=f+(e&255)&65535;e=g&255;h=(g&65535)>>>8;i=h&255;do{if((b[404041]&256)==0){j=4181}else{if((f&255)<<24>>24!=0){j=4181;break}k=(a[808090]|0)+e&255;l=i}}while(0);if((j|0)==4181){j=(b[404045]|0)+(h<<8|g&255)&65535;k=j&255;l=(j&65535)>>>8&255}j=(l&255)<<8|k&255;k=j&65535;if(d){d=b[404046]|0;HY(d&255,k);HY((d&65535)>>>8&255,j+1&65535);m=808093|0;n=a[m]|0;a[808104]=n;return}else{HY(a[808092]|0,k);m=808092;n=a[m]|0;a[808104]=n;return}}function Sj(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=(a[808082]&32)==0;e=TP(c[202024]|0)|0;b[404048]=(b[404048]|0)+1&65535;f=b[404043]|0;g=f+(e&255)&65535;e=g&255;h=(g&65535)>>>8;i=h&255;do{if((b[404041]&256)==0){j=4191}else{if((f&255)<<24>>24!=0){j=4191;break}k=(a[808090]|0)+e&255;l=i}}while(0);if((j|0)==4191){j=(b[404045]|0)+(h<<8|g&255)&65535;k=j&255;l=(j&65535)>>>8&255}j=(l&255)<<8|k&255;k=j&65535;if(d){d=b[404042]|0;HY(d&255,k);HY((d&65535)>>>8&255,j+1&65535);m=808085|0;n=a[m]|0;a[808104]=n;return}else{HY(a[808084]|0,k);m=808084;n=a[m]|0;a[808104]=n;return}}function Sk(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=(a[808082]&16)==0;e=TP(c[202024]|0)|0;b[404048]=(b[404048]|0)+1&65535;f=b[404043]|0;g=f+(e&255)&65535;e=g&255;h=(g&65535)>>>8;i=h&255;do{if((b[404041]&256)==0){j=4201}else{if((f&255)<<24>>24!=0){j=4201;break}k=(a[808092]|0)+e&255;l=i}}while(0);if((j|0)==4201){j=(b[404046]|0)+(h<<8|g&255)&65535;k=j&255;l=(j&65535)>>>8&255}j=(l&255)<<8|k&255;k=j&65535;if(d){d=b[404045]|0;HY(d&255,k);HY((d&65535)>>>8&255,j+1&65535);m=808091|0;n=a[m]|0;a[808104]=n;return}else{HY(a[808090]|0,k);m=808090;n=a[m]|0;a[808104]=n;return}}function Sl(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0;d=(a[808082]&32)==0;f=TP(c[202024]|0)|0;a[808104]=f;b[404048]=(b[404048]|0)+1&65535;g=(b[404043]|0)+(f&255)&65535;f=TP(g)|0;a[808104]=f;h=TP(g+1|0)|0;a[808104]=h;i=TP(g+2|0)|0;a[808104]=i;g=(((h&255)<<8|f&255)&65535|(i&255)<<16)+(e[404046]|0)|0;if(d){d=b[404042]|0;HY(d&255,g);HY((d&65535)>>>8&255,g+1|0);j=808085|0;k=a[j]|0;a[808104]=k;return}else{HY(a[808084]|0,g);j=808084;k=a[j]|0;a[808104]=k;return}}function Sm(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0;d=(a[808082]&32)==0;f=c[202032]|0;g=c[202024]|0;h=TP(g)|0;a[808104]=h;i=((TP((g&65535)+1&65535|g&-65536)|0)&255)<<8|h&255;b[404048]=(b[404048]|0)+2&65535;h=(i&65535|f)+(e[404046]|0)|0;if(d){d=b[404042]|0;HY(d&255,h);HY((d&65535)>>>8&255,h+1|0);j=808085|0;k=a[j]|0;a[808104]=k;return}else{HY(a[808084]|0,h);j=808084;k=a[j]|0;a[808104]=k;return}}function Sn(){var d=0,e=0,f=0,g=0,h=0;d=(a[808082]&32)==0;e=c[202032]|0;f=c[202024]|0;g=TP(f)|0;a[808104]=g;h=((TP((f&65535)+1&65535|f&-65536)|0)&255)<<8|g&255;b[404048]=(b[404048]|0)+2&65535;g=h&65535|e;HY(0,g);if(!d){a[808104]=0;return}HY(0,g+1|0);a[808104]=0;return}function So(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0;d=(a[808082]&32)==0;f=c[202032]|0;g=c[202024]|0;h=TP(g)|0;a[808104]=h;i=((TP((g&65535)+1&65535|g&-65536)|0)&255)<<8|h&255;b[404048]=(b[404048]|0)+2&65535;h=(i&65535|f)+(e[404045]|0)|0;if(d){d=b[404042]|0;HY(d&255,h);HY((d&65535)>>>8&255,h+1|0);j=808085|0;k=a[j]|0;a[808104]=k;return}else{HY(a[808084]|0,h);j=808084;k=a[j]|0;a[808104]=k;return}}function Sp(){var d=0,f=0,g=0,h=0,i=0;d=(a[808082]&32)==0;f=c[202032]|0;g=c[202024]|0;h=TP(g)|0;a[808104]=h;i=((TP((g&65535)+1&65535|g&-65536)|0)&255)<<8|h&255;b[404048]=(b[404048]|0)+2&65535;h=(i&65535|f)+(e[404045]|0)|0;HY(0,h);if(!d){a[808104]=0;return}HY(0,h+1|0);a[808104]=0;return}function Sq(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0;d=(a[808082]&32)==0;f=c[202024]|0;g=TP(f)|0;a[808104]=g;h=TP((f&65535)+1&65535|f&-65536)|0;a[808104]=h;b[404048]=(b[404048]|0)+2&65535;f=TP(c[202024]|0)|0;b[404048]=(b[404048]|0)+1&65535;i=(e[404045]|0)+((f&255)<<16|((h&255)<<8|g&255)&65535)|0;if(d){d=b[404042]|0;HY(d&255,i);HY((d&65535)>>>8&255,i+1|0);j=808085|0;k=a[j]|0;a[808104]=k;return}else{HY(a[808084]|0,i);j=808084;k=a[j]|0;a[808104]=k;return}}function Sr(){var d=0,e=0,f=0,g=0,h=0;d=(a[808082]&16)==0;e=c[202024]|0;f=TP(e)|0;a[808104]=f;if(d){d=TP((e&65535)+1&65535|e&-65536)|0;e=(d&255)<<8|f&255;a[808104]=d;b[404048]=(b[404048]|0)+2&65535;b[404046]=e;g=d;h=e<<16>>16!=0|0;a[808121]=h;a[808122]=g;return}else{b[404048]=(b[404048]|0)+1&65535;a[808092]=f;g=f;h=f;a[808121]=h;a[808122]=g;return}}function Ss(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;d=(a[808082]&32)==0;e=TP(c[202024]|0)|0;a[808104]=e;b[404048]=(b[404048]|0)+1&65535;f=b[404043]|0;g=f+(e&255)&65535;e=(g&65535)>>>8;h=(b[404041]&256)==0;i=f&255;if(i<<24>>24==0&(h^1)){j=((a[808090]|0)+(g&255)&255|e<<8)&65535;k=4252}else{f=(b[404045]|0)+(e<<8|g&255)&65535;if(h){l=65535;m=f}else{j=f;k=4252}}if((k|0)==4252){l=i<<24>>24!=0?65535:255;m=j}j=TV(m,l)|0;a[808104]=(j&65535)>>>8&255;l=c[202032]|j&65535;if(d){d=TP(l)|0;a[808104]=d;j=TP(l+1|0)|0;m=(j&255)<<8|d&255;a[808104]=j;b[404042]=m;n=j;o=m<<16>>16!=0|0;a[808121]=o;a[808122]=n;return}else{m=TP(l)|0;a[808104]=m;a[808084]=m;n=m;o=m;a[808121]=o;a[808122]=n;return}}function St(){var d=0,e=0,f=0,g=0,h=0;d=(a[808082]&16)==0;e=c[202024]|0;f=TP(e)|0;a[808104]=f;if(d){d=TP((e&65535)+1&65535|e&-65536)|0;e=(d&255)<<8|f&255;a[808104]=d;b[404048]=(b[404048]|0)+2&65535;b[404045]=e;g=d;h=e<<16>>16!=0|0;a[808121]=h;a[808122]=g;return}else{b[404048]=(b[404048]|0)+1&65535;a[808090]=f;g=f;h=f;a[808121]=h;a[808122]=g;return}}function Su(){var c=0,d=0;if((a[808082]&16)==0){c=b[404042]|0;b[404046]=c;a[808121]=c<<16>>16!=0|0;d=(c&65535)>>>8&255;a[808122]=d;return}else{c=a[808084]|0;a[808092]=c;a[808121]=c;d=c;a[808122]=d;return}}function Sv(){var c=0,d=0;if((a[808082]&16)==0){c=b[404042]|0;b[404045]=c;a[808121]=c<<16>>16!=0|0;d=(c&65535)>>>8&255;a[808122]=d;return}else{c=a[808084]|0;a[808090]=c;a[808121]=c;d=c;a[808122]=d;return}}function Sw(){var d=0,e=0,f=0,g=0,h=0,i=0;d=(a[808082]&32)==0;e=TP(c[202024]|0)|0;a[808104]=e;b[404048]=(b[404048]|0)+1&65535;f=(b[404044]|0)+(e&255)&65535;if(d){d=TP(f)|0;a[808104]=d;e=TP(f+1|0)|0;g=(e&255)<<8|d&255;a[808104]=e;b[404042]=g;h=e;i=g<<16>>16!=0|0;a[808121]=i;a[808122]=h;return}else{g=TP(f)|0;a[808104]=g;a[808084]=g;h=g;i=g;a[808121]=i;a[808122]=h;return}}function Sx(){var d=0,e=0,f=0,g=0,h=0,i=0;d=(a[808082]&16)==0;e=TP(c[202024]|0)|0;a[808104]=e;b[404048]=(b[404048]|0)+1&65535;f=(b[404043]|0)+(e&255)&65535;e=f&65535;if(d){d=TP(e)|0;a[808104]=d;g=TP(f+1&65535)|0;f=(g&255)<<8|d&255;a[808104]=g;b[404046]=f;h=g;i=f<<16>>16!=0|0;a[808121]=i;a[808122]=h;return}else{f=TP(e)|0;a[808104]=f;a[808092]=f;h=f;i=f;a[808121]=i;a[808122]=h;return}}function Sy(){var d=0,e=0,f=0,g=0,h=0,i=0;d=(a[808082]&32)==0;e=TP(c[202024]|0)|0;a[808104]=e;b[404048]=(b[404048]|0)+1&65535;f=(b[404043]|0)+(e&255)&65535;e=f&65535;if(d){d=TP(e)|0;a[808104]=d;g=TP(f+1&65535)|0;f=(g&255)<<8|d&255;a[808104]=g;b[404042]=f;h=g;i=f<<16>>16!=0|0;a[808121]=i;a[808122]=h;return}else{f=TP(e)|0;a[808104]=f;a[808084]=f;h=f;i=f;a[808121]=i;a[808122]=h;return}}function Sz(){var d=0,e=0,f=0,g=0,h=0,i=0;d=(a[808082]&16)==0;e=TP(c[202024]|0)|0;a[808104]=e;b[404048]=(b[404048]|0)+1&65535;f=(b[404043]|0)+(e&255)&65535;e=f&65535;if(d){d=TP(e)|0;a[808104]=d;g=TP(f+1&65535)|0;f=(g&255)<<8|d&255;a[808104]=g;b[404045]=f;h=g;i=f<<16>>16!=0|0;a[808121]=i;a[808122]=h;return}else{f=TP(e)|0;a[808104]=f;a[808090]=f;h=f;i=f;a[808121]=i;a[808122]=h;return}}function SA(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=(a[808082]&32)==0;e=TP(c[202024]|0)|0;a[808104]=e;b[404048]=(b[404048]|0)+1&65535;f=(b[404043]|0)+(e&255)&65535;e=TP(f)|0;a[808104]=e;g=TP(f+1|0)|0;a[808104]=g;h=TP(f+2|0)|0;a[808104]=h;f=((g&255)<<8|e&255)&65535|(h&255)<<16;if(d){d=TP(f)|0;a[808104]=d;h=TP(f+1|0)|0;e=(h&255)<<8|d&255;a[808104]=h;b[404042]=e;i=h;j=e<<16>>16!=0|0;a[808121]=j;a[808122]=i;return}else{e=TP(f)|0;a[808104]=e;a[808084]=e;i=e;j=e;a[808121]=j;a[808122]=i;return}}function SB(){var d=0,e=0,f=0,g=0,h=0;d=(a[808082]&32)==0;e=c[202024]|0;f=TP(e)|0;a[808104]=f;if(d){d=TP((e&65535)+1&65535|e&-65536)|0;e=(d&255)<<8|f&255;a[808104]=d;b[404048]=(b[404048]|0)+2&65535;b[404042]=e;g=d;h=e<<16>>16!=0|0;a[808121]=h;a[808122]=g;return}else{b[404048]=(b[404048]|0)+1&65535;a[808084]=f;g=f;h=f;a[808121]=h;a[808122]=g;return}}function SC(){var d=0,f=0;if((b[404041]&256)==0){d=(b[404044]|0)+1&65535;b[404044]=d;f=TP(d&65535)|0}else{a[808088]=(a[808088]|0)+1&255;f=TP(e[404044]|0)|0}a[808080]=f;a[808121]=f;a[808122]=f;c[202032]=(f&255)<<16;a[808104]=f;return}function SD(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=(a[808082]&16)==0;e=c[202032]|0;f=c[202024]|0;g=TP(f)|0;a[808104]=g;h=TP((f&65535)+1&65535|f&-65536)|0;a[808104]=h;b[404048]=(b[404048]|0)+2&65535;f=((h&255)<<8|g&255)&65535|e;if(d){d=TP(f)|0;a[808104]=d;g=TP((f&65535)+1&65535|e&-65536)|0;e=(g&255)<<8|d&255;a[808104]=g;b[404046]=e;i=g;j=e<<16>>16!=0|0;a[808121]=j;a[808122]=i;return}else{e=TP(f)|0;a[808104]=e;a[808092]=e;i=e;j=e;a[808121]=j;a[808122]=i;return}}function SE(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=(a[808082]&32)==0;e=c[202032]|0;f=c[202024]|0;g=TP(f)|0;a[808104]=g;h=TP((f&65535)+1&65535|f&-65536)|0;a[808104]=h;b[404048]=(b[404048]|0)+2&65535;f=((h&255)<<8|g&255)&65535|e;if(d){d=TP(f)|0;a[808104]=d;e=TP(f+1|0)|0;g=(e&255)<<8|d&255;a[808104]=e;b[404042]=g;i=e;j=g<<16>>16!=0|0;a[808121]=j;a[808122]=i;return}else{g=TP(f)|0;a[808104]=g;a[808084]=g;i=g;j=g;a[808121]=j;a[808122]=i;return}}function SF(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=(a[808082]&16)==0;e=c[202032]|0;f=c[202024]|0;g=TP(f)|0;a[808104]=g;h=TP((f&65535)+1&65535|f&-65536)|0;a[808104]=h;b[404048]=(b[404048]|0)+2&65535;f=((h&255)<<8|g&255)&65535|e;if(d){d=TP(f)|0;a[808104]=d;g=TP((f&65535)+1&65535|e&-65536)|0;e=(g&255)<<8|d&255;a[808104]=g;b[404045]=e;i=g;j=e<<16>>16!=0|0;a[808121]=j;a[808122]=i;return}else{e=TP(f)|0;a[808104]=e;a[808090]=e;i=e;j=e;a[808121]=j;a[808122]=i;return}}function SG(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=(a[808082]&32)==0;e=c[202024]|0;f=TP(e)|0;a[808104]=f;g=TP((e&65535)+1&65535|e&-65536)|0;a[808104]=g;b[404048]=(b[404048]|0)+2&65535;e=TP(c[202024]|0)|0;a[808104]=e;b[404048]=(b[404048]|0)+1&65535;h=(e&255)<<16|((g&255)<<8|f&255)&65535;if(d){d=TP(h)|0;a[808104]=d;f=TP(h+1|0)|0;g=(f&255)<<8|d&255;a[808104]=f;b[404042]=g;i=f;j=g<<16>>16!=0|0;a[808121]=j;a[808122]=i;return}else{g=TP(h)|0;a[808104]=g;a[808084]=g;i=g;j=g;a[808121]=j;a[808122]=i;return}}function SH(){var d=0,e=0,f=0;d=TP(c[202024]|0)|0;a[808104]=d;e=(b[404048]|0)+1&65535;b[404048]=e;f=e&65535;e=f+(d<<24>>24)|0;if((a[808120]|0)==0){return}if(((e^f)&61440|0)==0){b[404048]=e&65535;return}else{HR((c[202031]|0)+(e&65535)|0);return}}function SI(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0;d=(a[808082]&32)==0;f=TP(c[202024]|0)|0;a[808104]=f;b[404048]=(b[404048]|0)+1&65535;g=b[404043]|0;if((b[404041]&256)==0){h=65535}else{h=(g&255)<<24>>24!=0?65535:255}i=TV(g+(f&255)&65535,h)|0;a[808104]=(i&65535)>>>8&255;h=(e[404046]|0)+(c[202032]|i&65535)|0;if(d){d=TP(h)|0;a[808104]=d;i=TP(h+1|0)|0;f=(i&255)<<8|d&255;a[808104]=i;b[404042]=f;j=i;k=f<<16>>16!=0|0;a[808121]=k;a[808122]=j;return}else{f=TP(h)|0;a[808104]=f;a[808084]=f;j=f;k=f;a[808121]=k;a[808122]=j;return}}function SJ(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=(a[808082]&32)==0;e=TP(c[202024]|0)|0;a[808104]=e;b[404048]=(b[404048]|0)+1&65535;f=b[404043]|0;if((b[404041]&256)==0){g=65535}else{g=(f&255)<<24>>24!=0?65535:255}h=TV(f+(e&255)&65535,g)|0;a[808104]=(h&65535)>>>8&255;g=c[202032]|h&65535;if(d){d=TP(g)|0;a[808104]=d;h=TP(g+1|0)|0;e=(h&255)<<8|d&255;a[808104]=h;b[404042]=e;i=h;j=e<<16>>16!=0|0;a[808121]=j;a[808122]=i;return}else{e=TP(g)|0;a[808104]=e;a[808084]=e;i=e;j=e;a[808121]=j;a[808122]=i;return}}function SK(){var d=0,f=0,g=0,h=0,i=0,j=0;d=(a[808082]&32)==0;f=TP(c[202024]|0)|0;a[808104]=f;b[404048]=(b[404048]|0)+1&65535;g=(b[404044]|0)+(f&255)&65535;f=TP(g)|0;a[808104]=f;h=TP(g+1|0)|0;a[808104]=h;g=(c[202032]|0)+(e[404046]|0)+(((h&255)<<8|f&255)&65535)&16777215;if(d){d=TP(g)|0;a[808104]=d;f=TP(g+1|0)|0;h=(f&255)<<8|d&255;a[808104]=f;b[404042]=h;i=f;j=h<<16>>16!=0|0;a[808121]=j;a[808122]=i;return}else{h=TP(g)|0;a[808104]=h;a[808084]=h;i=h;j=h;a[808121]=j;a[808122]=i;return}}function SL(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=(a[808082]&16)==0;e=TP(c[202024]|0)|0;a[808104]=e;b[404048]=(b[404048]|0)+1&65535;f=b[404043]|0;g=f+(e&255)&65535;e=g&255;h=(g&65535)>>>8;i=h&255;do{if((b[404041]&256)==0){j=4373}else{if((f&255)<<24>>24!=0){j=4373;break}k=(a[808090]|0)+e&255;l=i}}while(0);if((j|0)==4373){j=(b[404045]|0)+(h<<8|g&255)&65535;k=j&255;l=(j&65535)>>>8&255}j=(l&255)<<8|k&255;k=j&65535;if(d){d=TP(k)|0;a[808104]=d;l=TP(j+1&65535)|0;j=(l&255)<<8|d&255;a[808104]=l;b[404046]=j;m=l;n=j<<16>>16!=0|0;a[808121]=n;a[808122]=m;return}else{j=TP(k)|0;a[808104]=j;a[808092]=j;m=j;n=j;a[808121]=n;a[808122]=m;return}}function SM(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=(a[808082]&32)==0;e=TP(c[202024]|0)|0;a[808104]=e;b[404048]=(b[404048]|0)+1&65535;f=b[404043]|0;g=f+(e&255)&65535;e=g&255;h=(g&65535)>>>8;i=h&255;do{if((b[404041]&256)==0){j=4383}else{if((f&255)<<24>>24!=0){j=4383;break}k=(a[808090]|0)+e&255;l=i}}while(0);if((j|0)==4383){j=(b[404045]|0)+(h<<8|g&255)&65535;k=j&255;l=(j&65535)>>>8&255}j=(l&255)<<8|k&255;k=j&65535;if(d){d=TP(k)|0;a[808104]=d;l=TP(j+1&65535)|0;j=(l&255)<<8|d&255;a[808104]=l;b[404042]=j;m=l;n=j<<16>>16!=0|0;a[808121]=n;a[808122]=m;return}else{j=TP(k)|0;a[808104]=j;a[808084]=j;m=j;n=j;a[808121]=n;a[808122]=m;return}}function SN(){var c=0,d=0;if((a[808082]&16)==0){c=b[404044]|0;b[404045]=c;a[808121]=c<<16>>16!=0|0;d=(c&65535)>>>8&255;a[808122]=d;return}else{c=a[808088]|0;a[808090]=c;a[808121]=c;d=c;a[808122]=d;return}}function SO(){var c=0,d=0;if((a[808082]&16)==0){c=b[404046]|0;b[404045]=c;a[808121]=c<<16>>16!=0|0;d=(c&65535)>>>8&255;a[808122]=d;return}else{c=a[808092]|0;a[808090]=c;a[808121]=c;d=c;a[808122]=d;return}}function SP(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=(a[808082]&16)==0;e=TP(c[202024]|0)|0;a[808104]=e;b[404048]=(b[404048]|0)+1&65535;f=b[404043]|0;g=f+(e&255)&65535;e=g&255;h=(g&65535)>>>8;i=h&255;do{if((b[404041]&256)==0){j=4405}else{if((f&255)<<24>>24!=0){j=4405;break}k=(a[808092]|0)+e&255;l=i}}while(0);if((j|0)==4405){j=(b[404046]|0)+(h<<8|g&255)&65535;k=j&255;l=(j&65535)>>>8&255}j=(l&255)<<8|k&255;k=j&65535;if(d){d=TP(k)|0;a[808104]=d;l=TP(j+1&65535)|0;j=(l&255)<<8|d&255;a[808104]=l;b[404045]=j;m=l;n=j<<16>>16!=0|0;a[808121]=n;a[808122]=m;return}else{j=TP(k)|0;a[808104]=j;a[808090]=j;m=j;n=j;a[808121]=n;a[808122]=m;return}}function SQ(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0;d=(a[808082]&32)==0;f=TP(c[202024]|0)|0;a[808104]=f;b[404048]=(b[404048]|0)+1&65535;g=(b[404043]|0)+(f&255)&65535;f=TP(g)|0;a[808104]=f;h=TP(g+1|0)|0;a[808104]=h;i=TP(g+2|0)|0;a[808104]=i;g=(((h&255)<<8|f&255)&65535|(i&255)<<16)+(e[404046]|0)|0;if(d){d=TP(g)|0;a[808104]=d;i=TP(g+1|0)|0;f=(i&255)<<8|d&255;a[808104]=i;b[404042]=f;j=i;k=f<<16>>16!=0|0;a[808121]=k;a[808122]=j;return}else{f=TP(g)|0;a[808104]=f;a[808084]=f;j=f;k=f;a[808121]=k;a[808122]=j;return}}function SR(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0;d=(a[808082]&32)==0;f=c[202032]|0;g=c[202024]|0;h=TP(g)|0;a[808104]=h;i=TP((g&65535)+1&65535|g&-65536)|0;a[808104]=i;b[404048]=(b[404048]|0)+2&65535;g=(((i&255)<<8|h&255)&65535|f)+(e[404046]|0)|0;if(d){d=TP(g)|0;a[808104]=d;f=TP(g+1|0)|0;h=(f&255)<<8|d&255;a[808104]=f;b[404042]=h;j=f;k=h<<16>>16!=0|0;a[808121]=k;a[808122]=j;return}else{h=TP(g)|0;a[808104]=h;a[808084]=h;j=h;k=h;a[808121]=k;a[808122]=j;return}}function SS(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0;d=(a[808082]&16)==0;f=c[202032]|0;g=c[202024]|0;h=TP(g)|0;a[808104]=h;i=TP((g&65535)+1&65535|g&-65536)|0;a[808104]=i;b[404048]=(b[404048]|0)+2&65535;g=(((i&255)<<8|h&255)&65535|f)+(e[404045]|0)|0;if(d){d=TP(g)|0;a[808104]=d;f=TP((g&65535)+1&65535|g&-65536)|0;h=(f&255)<<8|d&255;a[808104]=f;b[404046]=h;j=f;k=h<<16>>16!=0|0;a[808121]=k;a[808122]=j;return}else{h=TP(g)|0;a[808104]=h;a[808092]=h;j=h;k=h;a[808121]=k;a[808122]=j;return}}function ST(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0;d=(a[808082]&32)==0;f=c[202032]|0;g=c[202024]|0;h=TP(g)|0;a[808104]=h;i=TP((g&65535)+1&65535|g&-65536)|0;a[808104]=i;b[404048]=(b[404048]|0)+2&65535;g=(((i&255)<<8|h&255)&65535|f)+(e[404045]|0)|0;if(d){d=TP(g)|0;a[808104]=d;f=TP(g+1|0)|0;h=(f&255)<<8|d&255;a[808104]=f;b[404042]=h;j=f;k=h<<16>>16!=0|0;a[808121]=k;a[808122]=j;return}else{h=TP(g)|0;a[808104]=h;a[808084]=h;j=h;k=h;a[808121]=k;a[808122]=j;return}}function SU(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0;d=(a[808082]&16)==0;f=c[202032]|0;g=c[202024]|0;h=TP(g)|0;a[808104]=h;i=TP((g&65535)+1&65535|g&-65536)|0;a[808104]=i;b[404048]=(b[404048]|0)+2&65535;g=(((i&255)<<8|h&255)&65535|f)+(e[404046]|0)|0;if(d){d=TP(g)|0;a[808104]=d;f=TP((g&65535)+1&65535|g&-65536)|0;h=(f&255)<<8|d&255;a[808104]=f;b[404045]=h;j=f;k=h<<16>>16!=0|0;a[808121]=k;a[808122]=j;return}else{h=TP(g)|0;a[808104]=h;a[808090]=h;j=h;k=h;a[808121]=k;a[808122]=j;return}}function SV(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0;d=(a[808082]&32)==0;f=c[202024]|0;g=TP(f)|0;a[808104]=g;h=TP((f&65535)+1&65535|f&-65536)|0;a[808104]=h;b[404048]=(b[404048]|0)+2&65535;f=TP(c[202024]|0)|0;a[808104]=f;b[404048]=(b[404048]|0)+1&65535;i=(e[404045]|0)+((f&255)<<16|((h&255)<<8|g&255)&65535)|0;if(d){d=TP(i)|0;a[808104]=d;g=TP(i+1|0)|0;h=(g&255)<<8|d&255;a[808104]=g;b[404042]=h;j=g;k=h<<16>>16!=0|0;a[808121]=k;a[808122]=j;return}else{h=TP(i)|0;a[808104]=h;a[808084]=h;j=h;k=h;a[808121]=k;a[808122]=j;return}}function SW(){var f=0,g=0,h=0,i=0,j=0;if((a[808082]&16)==0){f=e[404046]|0;g=c[202024]|0;h=TP(g)|0;a[808104]=h;i=TP((g&65535)+1&65535|g&-65536)|0;a[808104]=i;b[404048]=(b[404048]|0)+2&65535;g=f-(((i&255)<<8|h&255)&65535)|0;a[808120]=g>>>31&255^1;a[808121]=(g&65535|0)!=0|0;j=g>>>8&255;a[808122]=j;return}else{g=d[808092]|0;h=TP(c[202024]|0)|0;a[808104]=h;b[404048]=(b[404048]|0)+1&65535;i=g-(h&255)&65535;a[808120]=(i&65535)>>>15&255^1;h=i&255;a[808121]=h;j=h;a[808122]=j;return}}function SX(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0;f=(a[808082]&32)==0;g=TP(c[202024]|0)|0;a[808104]=g;b[404048]=(b[404048]|0)+1&65535;h=b[404043]|0;i=h+(g&255)&65535;g=(i&65535)>>>8;j=(b[404041]&256)==0;k=h&255;if(k<<24>>24==0&(j^1)){l=((a[808090]|0)+(i&255)&255|g<<8)&65535;m=4458}else{h=(b[404045]|0)+(g<<8|i&255)&65535;if(j){n=65535;o=h}else{l=h;m=4458}}if((m|0)==4458){n=k<<24>>24!=0?65535:255;o=l}l=TV(o,n)|0;a[808104]=(l&65535)>>>8&255;n=c[202032]|l&65535;if(f){f=TP(n)|0;a[808104]=f;l=TP(n+1|0)|0;a[808104]=l;o=(e[404042]|0)-(((l&255)<<8|f&255)&65535)|0;a[808120]=o>>>31&255^1;a[808121]=(o&65535|0)!=0|0;p=o>>>8&255;a[808122]=p;return}else{o=TP(n)|0;a[808104]=o;n=(d[808084]|0)-(o&255)&65535;a[808120]=(n&65535)>>>15&255^1;o=n&255;a[808121]=o;p=o;a[808122]=p;return}}function SY(){var d=0,e=0,f=0,g=0;d=TP(c[202024]|0)|0;a[808104]=d;b[404048]=(b[404048]|0)+1&65535;e=~d;a[808082]=a[808082]&e;a[808120]=a[808120]&e;a[808123]=a[808123]&(e&255)>>>6;a[808122]=a[808122]&e;a[808121]=a[808121]|e&2^2;e=b[404041]|0;if((e&256)==0){f=e&255;g=e}else{d=e|48;b[404041]=d;f=d&255;g=d}if((f&16)!=0){a[808091|0]=0;a[808093|0]=0}if((g&256)!=0){c[202028]=149560;c[202029]=159800;return}f=g&255;g=(f&16|0)!=0;if((f&32|0)==0){if(g){c[202028]=151608;c[202029]=160312;return}else{c[202028]=152632;c[202029]=160568;return}}else{if(g){c[202028]=149560;c[202029]=159800;return}else{c[202028]=150584;c[202029]=160056;return}}}function SZ(){var f=0,g=0,h=0,i=0,j=0;f=(a[808082]&32)==0;g=TP(c[202024]|0)|0;a[808104]=g;b[404048]=(b[404048]|0)+1&65535;h=(b[404044]|0)+(g&255)&65535;if(f){f=TP(h)|0;a[808104]=f;g=TP(h+1|0)|0;a[808104]=g;i=(e[404042]|0)-(((g&255)<<8|f&255)&65535)|0;a[808120]=i>>>31&255^1;a[808121]=(i&65535|0)!=0|0;j=i>>>8&255;a[808122]=j;return}else{i=TP(h)|0;a[808104]=i;h=(d[808084]|0)-(i&255)&65535;a[808120]=(h&65535)>>>15&255^1;i=h&255;a[808121]=i;j=i;a[808122]=j;return}}function S_(){var f=0,g=0,h=0,i=0,j=0;f=(a[808082]&16)==0;g=TP(c[202024]|0)|0;a[808104]=g;b[404048]=(b[404048]|0)+1&65535;h=(b[404043]|0)+(g&255)&65535;g=h&65535;if(f){f=TP(g)|0;a[808104]=f;i=TP(h+1&65535)|0;a[808104]=i;h=(e[404046]|0)-(((i&255)<<8|f&255)&65535)|0;a[808120]=h>>>31&255^1;a[808121]=(h&65535|0)!=0|0;j=h>>>8&255;a[808122]=j;return}else{h=TP(g)|0;a[808104]=h;g=(d[808092]|0)-(h&255)&65535;a[808120]=(g&65535)>>>15&255^1;h=g&255;a[808121]=h;j=h;a[808122]=j;return}}function S$(){var f=0,g=0,h=0,i=0,j=0;f=(a[808082]&32)==0;g=TP(c[202024]|0)|0;a[808104]=g;b[404048]=(b[404048]|0)+1&65535;h=(b[404043]|0)+(g&255)&65535;g=h&65535;if(f){f=TP(g)|0;a[808104]=f;i=TP(h+1&65535)|0;a[808104]=i;h=(e[404042]|0)-(((i&255)<<8|f&255)&65535)|0;a[808120]=h>>>31&255^1;a[808121]=(h&65535|0)!=0|0;j=h>>>8&255;a[808122]=j;return}else{h=TP(g)|0;a[808104]=h;g=(d[808084]|0)-(h&255)&65535;a[808120]=(g&65535)>>>15&255^1;h=g&255;a[808121]=h;j=h;a[808122]=j;return}}function S0(){var c=0,d=0;if((a[808082]&16)==0){c=(b[404046]|0)-1&65535;b[404046]=c;a[808121]=c<<16>>16!=0|0;d=(c&65535)>>>8&255;a[808122]=d;return}else{c=(a[808092]|0)-1&255;a[808092]=c;a[808121]=c;d=c;a[808122]=d;return}}function S1(){var c=0,d=0;if((a[808082]&16)==0){c=(b[404045]|0)-1&65535;b[404045]=c;a[808121]=c<<16>>16!=0|0;d=(c&65535)>>>8&255;a[808122]=d;return}else{c=(a[808090]|0)-1&255;a[808090]=c;a[808121]=c;d=c;a[808122]=d;return}}function S2(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=(a[808082]&32)==0;e=TP(c[202024]|0)|0;a[808104]=e;b[404048]=(b[404048]|0)+1&65535;f=(b[404043]|0)+(e&255)&65535;e=f&65535;g=TP(e)|0;if(d){a[808104]=g;d=f+1&65535;f=(((TP(d)|0)&255)<<8|g&255)-1&65535;h=(f&65535)>>>8&255;HY(h,d);d=f&255;HY(d,e);a[808104]=d;i=h;j=f<<16>>16!=0|0;a[808121]=j;a[808122]=i;return}else{f=g-1&255;HY(f,e);a[808104]=f;i=f;j=f;a[808121]=j;a[808122]=i;return}}function S3(){var f=0,g=0,h=0,i=0,j=0,k=0;f=(a[808082]&32)==0;g=TP(c[202024]|0)|0;a[808104]=g;b[404048]=(b[404048]|0)+1&65535;h=(b[404043]|0)+(g&255)&65535;g=TP(h)|0;a[808104]=g;i=TP(h+1|0)|0;a[808104]=i;j=TP(h+2|0)|0;a[808104]=j;h=((i&255)<<8|g&255)&65535|(j&255)<<16;if(f){f=TP(h)|0;a[808104]=f;j=TP(h+1|0)|0;a[808104]=j;g=(e[404042]|0)-(((j&255)<<8|f&255)&65535)|0;a[808120]=g>>>31&255^1;a[808121]=(g&65535|0)!=0|0;k=g>>>8&255;a[808122]=k;return}else{g=TP(h)|0;a[808104]=g;h=(d[808084]|0)-(g&255)&65535;a[808120]=(h&65535)>>>15&255^1;g=h&255;a[808121]=g;k=g;a[808122]=k;return}}function S4(){var f=0,g=0,h=0,i=0,j=0;if((a[808082]&32)==0){f=e[404042]|0;g=c[202024]|0;h=TP(g)|0;a[808104]=h;i=TP((g&65535)+1&65535|g&-65536)|0;a[808104]=i;b[404048]=(b[404048]|0)+2&65535;g=f-(((i&255)<<8|h&255)&65535)|0;a[808120]=g>>>31&255^1;a[808121]=(g&65535|0)!=0|0;j=g>>>8&255;a[808122]=j;return}else{g=d[808084]|0;h=TP(c[202024]|0)|0;a[808104]=h;b[404048]=(b[404048]|0)+1&65535;i=g-(h&255)&65535;a[808120]=(i&65535)>>>15&255^1;h=i&255;a[808121]=h;j=h;a[808122]=j;return}}function S5(){var f=0,g=0,h=0,i=0,j=0,k=0;f=(a[808082]&16)==0;g=c[202032]|0;h=c[202024]|0;i=TP(h)|0;a[808104]=i;j=TP((h&65535)+1&65535|h&-65536)|0;a[808104]=j;b[404048]=(b[404048]|0)+2&65535;h=((j&255)<<8|i&255)&65535|g;if(f){f=TP(h)|0;a[808104]=f;g=TP(h+1|0)|0;a[808104]=g;i=(e[404046]|0)-(((g&255)<<8|f&255)&65535)|0;a[808120]=i>>>31&255^1;a[808121]=(i&65535|0)!=0|0;k=i>>>8&255;a[808122]=k;return}else{i=TP(h)|0;a[808104]=i;h=(d[808092]|0)-(i&255)&65535;a[808120]=(h&65535)>>>15&255^1;i=h&255;a[808121]=i;k=i;a[808122]=k;return}}function S6(){var f=0,g=0,h=0,i=0,j=0,k=0;f=(a[808082]&32)==0;g=c[202032]|0;h=c[202024]|0;i=TP(h)|0;a[808104]=i;j=TP((h&65535)+1&65535|h&-65536)|0;a[808104]=j;b[404048]=(b[404048]|0)+2&65535;h=((j&255)<<8|i&255)&65535|g;if(f){f=TP(h)|0;a[808104]=f;g=TP(h+1|0)|0;a[808104]=g;i=(e[404042]|0)-(((g&255)<<8|f&255)&65535)|0;a[808120]=i>>>31&255^1;a[808121]=(i&65535|0)!=0|0;k=i>>>8&255;a[808122]=k;return}else{i=TP(h)|0;a[808104]=i;h=(d[808084]|0)-(i&255)&65535;a[808120]=(h&65535)>>>15&255^1;i=h&255;a[808121]=i;k=i;a[808122]=k;return}}function S7(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=(a[808082]&32)==0;e=c[202032]|0;f=c[202024]|0;g=TP(f)|0;a[808104]=g;h=TP((f&65535)+1&65535|f&-65536)|0;a[808104]=h;b[404048]=(b[404048]|0)+2&65535;f=((h&255)<<8|g&255)&65535|e;e=TP(f)|0;if(d){a[808104]=e;d=f+1|0;g=(((TP(d)|0)&255)<<8|e&255)-1&65535;h=(g&65535)>>>8&255;HY(h,d);d=g&255;HY(d,f);a[808104]=d;i=h;j=g<<16>>16!=0|0;a[808121]=j;a[808122]=i;return}else{g=e-1&255;HY(g,f);a[808104]=g;i=g;j=g;a[808121]=j;a[808122]=i;return}}function S8(){var f=0,g=0,h=0,i=0,j=0,k=0;f=(a[808082]&32)==0;g=c[202024]|0;h=TP(g)|0;a[808104]=h;i=TP((g&65535)+1&65535|g&-65536)|0;a[808104]=i;b[404048]=(b[404048]|0)+2&65535;g=TP(c[202024]|0)|0;a[808104]=g;b[404048]=(b[404048]|0)+1&65535;j=(g&255)<<16|((i&255)<<8|h&255)&65535;if(f){f=TP(j)|0;a[808104]=f;h=TP(j+1|0)|0;a[808104]=h;i=(e[404042]|0)-(((h&255)<<8|f&255)&65535)|0;a[808120]=i>>>31&255^1;a[808121]=(i&65535|0)!=0|0;k=i>>>8&255;a[808122]=k;return}else{i=TP(j)|0;a[808104]=i;j=(d[808084]|0)-(i&255)&65535;a[808120]=(j&65535)>>>15&255^1;i=j&255;a[808121]=i;k=i;a[808122]=k;return}}function S9(){var d=0,e=0,f=0;d=TP(c[202024]|0)|0;a[808104]=d;e=(b[404048]|0)+1&65535;b[404048]=e;f=e&65535;e=f+(d<<24>>24)|0;if((a[808121]|0)==0){return}if(((e^f)&61440|0)==0){b[404048]=e&65535;return}else{HR((c[202031]|0)+(e&65535)|0);return}}function Ta(){var f=0,g=0,h=0,i=0,j=0,k=0;f=(a[808082]&32)==0;g=TP(c[202024]|0)|0;a[808104]=g;b[404048]=(b[404048]|0)+1&65535;h=b[404043]|0;if((b[404041]&256)==0){i=65535}else{i=(h&255)<<24>>24!=0?65535:255}j=TV(h+(g&255)&65535,i)|0;a[808104]=(j&65535)>>>8&255;i=(e[404046]|0)+(c[202032]|j&65535)|0;if(f){f=TP(i)|0;a[808104]=f;j=TP(i+1|0)|0;a[808104]=j;g=(e[404042]|0)-(((j&255)<<8|f&255)&65535)|0;a[808120]=g>>>31&255^1;a[808121]=(g&65535|0)!=0|0;k=g>>>8&255;a[808122]=k;return}else{g=TP(i)|0;a[808104]=g;i=(d[808084]|0)-(g&255)&65535;a[808120]=(i&65535)>>>15&255^1;g=i&255;a[808121]=g;k=g;a[808122]=k;return}}function Tb(){var f=0,g=0,h=0,i=0,j=0,k=0;f=(a[808082]&32)==0;g=TP(c[202024]|0)|0;a[808104]=g;b[404048]=(b[404048]|0)+1&65535;h=b[404043]|0;if((b[404041]&256)==0){i=65535}else{i=(h&255)<<24>>24!=0?65535:255}j=TV(h+(g&255)&65535,i)|0;a[808104]=(j&65535)>>>8&255;i=c[202032]|j&65535;if(f){f=TP(i)|0;a[808104]=f;j=TP(i+1|0)|0;a[808104]=j;g=(e[404042]|0)-(((j&255)<<8|f&255)&65535)|0;a[808120]=g>>>31&255^1;a[808121]=(g&65535|0)!=0|0;k=g>>>8&255;a[808122]=k;return}else{g=TP(i)|0;a[808104]=g;i=(d[808084]|0)-(g&255)&65535;a[808120]=(i&65535)>>>15&255^1;g=i&255;a[808121]=g;k=g;a[808122]=k;return}}function Tc(){var f=0,g=0,h=0,i=0,j=0;f=(a[808082]&32)==0;g=TP(c[202024]|0)|0;a[808104]=g;b[404048]=(b[404048]|0)+1&65535;h=(b[404044]|0)+(g&255)&65535;g=TP(h)|0;a[808104]=g;i=TP(h+1|0)|0;a[808104]=i;h=(c[202032]|0)+(e[404046]|0)+(((i&255)<<8|g&255)&65535)&16777215;if(f){f=TP(h)|0;a[808104]=f;g=TP(h+1|0)|0;a[808104]=g;i=(e[404042]|0)-(((g&255)<<8|f&255)&65535)|0;a[808120]=i>>>31&255^1;a[808121]=(i&65535|0)!=0|0;j=i>>>8&255;a[808122]=j;return}else{i=TP(h)|0;a[808104]=i;h=(d[808084]|0)-(i&255)&65535;a[808120]=(h&65535)>>>15&255^1;i=h&255;a[808121]=i;j=i;a[808122]=j;return}}function Td(){var d=0,f=0,g=0,h=0;d=TP(c[202024]|0)|0;a[808104]=d;b[404048]=(b[404048]|0)+1&65535;f=b[404043]|0;if((b[404041]&256)==0){g=65535}else{g=(f&255)<<24>>24!=0?65535:255}h=(TV(f+(d&255)&65535,g)|0)&65535;g=c[202032]|h;h=(e[404044]|0)-1|0;HY((g&65535)>>>8&255,(h&65535)+1&65535|h&-65536);d=g&255;HY(d,h);b[404044]=(b[404044]|0)-2&65535;a[808104]=d;if((b[404041]&256)==0){return}a[808089|0]=1;return}function Te(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=(a[808082]&32)==0;g=TP(c[202024]|0)|0;a[808104]=g;b[404048]=(b[404048]|0)+1&65535;h=b[404043]|0;i=h+(g&255)&65535;g=i&255;j=(i&65535)>>>8;k=j&255;do{if((b[404041]&256)==0){l=4595}else{if((h&255)<<24>>24!=0){l=4595;break}m=(a[808090]|0)+g&255;n=k}}while(0);if((l|0)==4595){l=(b[404045]|0)+(j<<8|i&255)&65535;m=l&255;n=(l&65535)>>>8&255}l=(n&255)<<8|m&255;m=l&65535;if(f){f=TP(m)|0;a[808104]=f;n=TP(l+1&65535)|0;a[808104]=n;l=(e[404042]|0)-(((n&255)<<8|f&255)&65535)|0;a[808120]=l>>>31&255^1;a[808121]=(l&65535|0)!=0|0;o=l>>>8&255;a[808122]=o;return}else{l=TP(m)|0;a[808104]=l;m=(d[808084]|0)-(l&255)&65535;a[808120]=(m&65535)>>>15&255^1;l=m&255;a[808121]=l;o=l;a[808122]=o;return}}function Tf(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=(a[808082]&32)==0;e=TP(c[202024]|0)|0;a[808104]=e;b[404048]=(b[404048]|0)+1&65535;f=b[404043]|0;g=f+(e&255)&65535;e=g&255;h=(g&65535)>>>8;i=h&255;do{if((b[404041]&256)==0){j=4605}else{if((f&255)<<24>>24!=0){j=4605;break}k=(a[808090]|0)+e&255;l=i}}while(0);if((j|0)==4605){j=(b[404045]|0)+(h<<8|g&255)&65535;k=j&255;l=(j&65535)>>>8&255}j=(l&255)<<8|k&255;k=j&65535;l=TP(k)|0;if(d){a[808104]=l;d=j+1&65535;j=(((TP(d)|0)&255)<<8|l&255)-1&65535;g=(j&65535)>>>8&255;HY(g,d);d=j&255;HY(d,k);a[808104]=d;m=g;n=j<<16>>16!=0|0;a[808121]=n;a[808122]=m;return}else{j=l-1&255;HY(j,k);a[808104]=j;m=j;n=j;a[808121]=n;a[808122]=m;return}}function Tg(){var f=0,g=0,h=0,i=0,j=0,k=0;f=(a[808082]&32)==0;g=TP(c[202024]|0)|0;a[808104]=g;b[404048]=(b[404048]|0)+1&65535;h=(b[404043]|0)+(g&255)&65535;g=TP(h)|0;a[808104]=g;i=TP(h+1|0)|0;a[808104]=i;j=TP(h+2|0)|0;a[808104]=j;h=(((i&255)<<8|g&255)&65535|(j&255)<<16)+(e[404046]|0)|0;if(f){f=TP(h)|0;a[808104]=f;j=TP(h+1|0)|0;a[808104]=j;g=(e[404042]|0)-(((j&255)<<8|f&255)&65535)|0;a[808120]=g>>>31&255^1;a[808121]=(g&65535|0)!=0|0;k=g>>>8&255;a[808122]=k;return}else{g=TP(h)|0;a[808104]=g;h=(d[808084]|0)-(g&255)&65535;a[808120]=(h&65535)>>>15&255^1;g=h&255;a[808121]=g;k=g;a[808122]=k;return}}function Th(){var f=0,g=0,h=0,i=0,j=0,k=0;f=(a[808082]&32)==0;g=c[202032]|0;h=c[202024]|0;i=TP(h)|0;a[808104]=i;j=TP((h&65535)+1&65535|h&-65536)|0;a[808104]=j;b[404048]=(b[404048]|0)+2&65535;h=(((j&255)<<8|i&255)&65535|g)+(e[404046]|0)|0;if(f){f=TP(h)|0;a[808104]=f;g=TP(h+1|0)|0;a[808104]=g;i=(e[404042]|0)-(((g&255)<<8|f&255)&65535)|0;a[808120]=i>>>31&255^1;a[808121]=(i&65535|0)!=0|0;k=i>>>8&255;a[808122]=k;return}else{i=TP(h)|0;a[808104]=i;h=(d[808084]|0)-(i&255)&65535;a[808120]=(h&65535)>>>15&255^1;i=h&255;a[808121]=i;k=i;a[808122]=k;return}}function Ti(){var c=0,d=0,f=0;c=b[404041]|0;if((c&256)!=0){HY(a[808090]|0,e[404044]|0);a[808088]=(a[808088]|0)-1&255;d=a[808090]|0;a[808104]=d;return}if((c&16)==0){c=b[404045]|0;f=(e[404044]|0)-1|0;HY((c&65535)>>>8&255,(f&65535)+1&65535|f&-65536);HY(c&255,f);b[404044]=(b[404044]|0)-2&65535;d=a[808090]|0;a[808104]=d;return}else{f=a[808090]|0;c=b[404044]|0;b[404044]=c-1&65535;HY(f,c&65535);d=a[808090]|0;a[808104]=d;return}}function Tj(){var d=0,e=0,f=0,g=0;d=c[202024]|0;e=TP(d)|0;a[808104]=e;f=TP((d&65535)+1&65535|d&-65536)|0;a[808104]=f;b[404048]=(b[404048]|0)+2&65535;d=((f&255)<<8|e&255)&65535;e=TP(d)|0;a[808104]=e;f=TP(d+1|0)|0;a[808104]=f;g=TP(d+2|0)|0;a[808104]=g;HR(((f&255)<<8|e&255)&65535|(g&255)<<16);return}function Tk(){var f=0,g=0,h=0,i=0,j=0,k=0;f=(a[808082]&32)==0;g=c[202032]|0;h=c[202024]|0;i=TP(h)|0;a[808104]=i;j=TP((h&65535)+1&65535|h&-65536)|0;a[808104]=j;b[404048]=(b[404048]|0)+2&65535;h=(((j&255)<<8|i&255)&65535|g)+(e[404045]|0)|0;if(f){f=TP(h)|0;a[808104]=f;g=TP(h+1|0)|0;a[808104]=g;i=(e[404042]|0)-(((g&255)<<8|f&255)&65535)|0;a[808120]=i>>>31&255^1;a[808121]=(i&65535|0)!=0|0;k=i>>>8&255;a[808122]=k;return}else{i=TP(h)|0;a[808104]=i;h=(d[808084]|0)-(i&255)&65535;a[808120]=(h&65535)>>>15&255^1;i=h&255;a[808121]=i;k=i;a[808122]=k;return}}function Tl(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0;d=(a[808082]&32)==0;f=c[202032]|0;g=c[202024]|0;h=TP(g)|0;a[808104]=h;i=TP((g&65535)+1&65535|g&-65536)|0;a[808104]=i;b[404048]=(b[404048]|0)+2&65535;g=(((i&255)<<8|h&255)&65535|f)+(e[404045]|0)|0;f=TP(g)|0;if(d){a[808104]=f;d=g+1|0;h=(((TP(d)|0)&255)<<8|f&255)-1&65535;i=(h&65535)>>>8&255;HY(i,d);d=h&255;HY(d,g);a[808104]=d;j=i;k=h<<16>>16!=0|0;a[808121]=k;a[808122]=j;return}else{h=f-1&255;HY(h,g);a[808104]=h;j=h;k=h;a[808121]=k;a[808122]=j;return}}function Tm(){var f=0,g=0,h=0,i=0,j=0,k=0;f=(a[808082]&32)==0;g=c[202024]|0;h=TP(g)|0;a[808104]=h;i=TP((g&65535)+1&65535|g&-65536)|0;a[808104]=i;b[404048]=(b[404048]|0)+2&65535;g=TP(c[202024]|0)|0;a[808104]=g;b[404048]=(b[404048]|0)+1&65535;j=(e[404045]|0)+((g&255)<<16|((i&255)<<8|h&255)&65535)|0;if(f){f=TP(j)|0;a[808104]=f;h=TP(j+1|0)|0;a[808104]=h;i=(e[404042]|0)-(((h&255)<<8|f&255)&65535)|0;a[808120]=i>>>31&255^1;a[808121]=(i&65535|0)!=0|0;k=i>>>8&255;a[808122]=k;return}else{i=TP(j)|0;a[808104]=i;j=(d[808084]|0)-(i&255)&65535;a[808120]=(j&65535)>>>15&255^1;i=j&255;a[808121]=i;k=i;a[808122]=k;return}}function Tn(){var f=0,g=0,h=0,i=0,j=0;if((a[808082]&16)==0){f=e[404045]|0;g=c[202024]|0;h=TP(g)|0;a[808104]=h;i=TP((g&65535)+1&65535|g&-65536)|0;a[808104]=i;b[404048]=(b[404048]|0)+2&65535;g=f-(((i&255)<<8|h&255)&65535)|0;a[808120]=g>>>31&255^1;a[808121]=(g&65535|0)!=0|0;j=g>>>8&255;a[808122]=j;return}else{g=d[808090]|0;h=TP(c[202024]|0)|0;a[808104]=h;b[404048]=(b[404048]|0)+1&65535;i=g-(h&255)&65535;a[808120]=(i&65535)>>>15&255^1;h=i&255;a[808121]=h;j=h;a[808122]=j;return}}function To(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;e=(a[808082]&32)==0;f=TP(c[202024]|0)|0;a[808104]=f;b[404048]=(b[404048]|0)+1&65535;g=b[404043]|0;h=g+(f&255)&65535;f=(h&65535)>>>8;i=(b[404041]&256)==0;j=g&255;if(j<<24>>24==0&(i^1)){k=((a[808090]|0)+(h&255)&255|f<<8)&65535;l=4662}else{g=(b[404045]|0)+(f<<8|h&255)&65535;if(i){m=65535;n=g}else{k=g;l=4662}}if((l|0)==4662){m=j<<24>>24!=0?65535:255;n=k}k=TV(n,m)|0;a[808104]=(k&65535)>>>8&255;m=c[202032]|k&65535;if(e){e=TP(m)|0;a[808104]=e;k=TP(m+1|0)|0;a[808104]=k;TQ((k&255)<<8|e&255);return}e=TP(m)|0;a[808104]=e;if((a[808082]&8)==0){m=a[808084]|0;k=((m&255)+~(e&255)&65535)+(d[808120]|0)&65535;a[808120]=(k&65535)>>>15&255^1;n=k&255;o=n;p=(n^m)&(m^e)}else{m=b[404042]|0;n=m&255;k=((n&15)-(e&15)&255)-((a[808120]|0)==0)&255;j=(m&240)-(e&-16&255)&65535;if((k&255)>15){q=k+10&15;r=j-16&65535}else{q=k;r=j}if((r&65535)>240){a[808120]=0;s=r+160&255&-16}else{a[808120]=1;s=r&255}r=s|q;o=r;p=(r^n)&(n^e)}a[808123]=(p&255)>>>7;a[808084]=o;a[808121]=o;a[808122]=o;return}function Tp(){var d=0,e=0,f=0,g=0;d=TP(c[202024]|0)|0;a[808104]=d;b[404048]=(b[404048]|0)+1&65535;a[808082]=a[808082]|d;a[808120]=a[808120]|d&1;a[808123]=a[808123]|(d&255)>>>6&1;a[808122]=a[808122]|d;if((d&2)!=0){a[808121]=0}d=b[404041]|0;if((d&256)==0){e=d&255;f=d}else{g=d|48;b[404041]=g;e=g&255;f=g}if((e&16)!=0){a[808091|0]=0;a[808093|0]=0}if((f&256)!=0){c[202028]=149560;c[202029]=159800;return}e=f&255;f=(e&16|0)!=0;if((e&32|0)==0){if(f){c[202028]=151608;c[202029]=160312;return}else{c[202028]=152632;c[202029]=160568;return}}else{if(f){c[202028]=149560;c[202029]=159800;return}else{c[202028]=150584;c[202029]=160056;return}}}function Tq(){var c=0,d=0;if((a[808082]&16)==0){c=(b[404045]|0)+1&65535;b[404045]=c;a[808121]=c<<16>>16!=0|0;d=(c&65535)>>>8&255;a[808122]=d;return}else{c=(a[808090]|0)+1&255;a[808090]=c;a[808121]=c;d=c;a[808122]=d;return}}function Tr(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=(a[808082]&32)==0;f=TP(c[202024]|0)|0;a[808104]=f;b[404048]=(b[404048]|0)+1&65535;g=(b[404044]|0)+(f&255)&65535;if(e){e=TP(g)|0;a[808104]=e;f=TP(g+1|0)|0;a[808104]=f;TQ((f&255)<<8|e&255);return}e=TP(g)|0;a[808104]=e;if((a[808082]&8)==0){g=a[808084]|0;f=((g&255)+~(e&255)&65535)+(d[808120]|0)&65535;a[808120]=(f&65535)>>>15&255^1;h=f&255;i=h;j=(h^g)&(g^e)}else{g=b[404042]|0;h=g&255;f=((h&15)-(e&15)&255)-((a[808120]|0)==0)&255;k=(g&240)-(e&-16&255)&65535;if((f&255)>15){l=f+10&15;m=k-16&65535}else{l=f;m=k}if((m&65535)>240){a[808120]=0;n=m+160&255&-16}else{a[808120]=1;n=m&255}m=n|l;i=m;j=(m^h)&(h^e)}a[808123]=(j&255)>>>7;a[808084]=i;a[808121]=i;a[808122]=i;return}function Ts(){var f=0,g=0,h=0,i=0,j=0;f=(a[808082]&16)==0;g=TP(c[202024]|0)|0;a[808104]=g;b[404048]=(b[404048]|0)+1&65535;h=(b[404043]|0)+(g&255)&65535;g=h&65535;if(f){f=TP(g)|0;a[808104]=f;i=TP(h+1&65535)|0;a[808104]=i;h=(e[404045]|0)-(((i&255)<<8|f&255)&65535)|0;a[808120]=h>>>31&255^1;a[808121]=(h&65535|0)!=0|0;j=h>>>8&255;a[808122]=j;return}else{h=TP(g)|0;a[808104]=h;g=(d[808090]|0)-(h&255)&65535;a[808120]=(g&65535)>>>15&255^1;h=g&255;a[808121]=h;j=h;a[808122]=j;return}}function Tt(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=(a[808082]&32)==0;f=TP(c[202024]|0)|0;a[808104]=f;b[404048]=(b[404048]|0)+1&65535;g=(b[404043]|0)+(f&255)&65535;f=g&65535;if(e){e=TP(f)|0;a[808104]=e;h=TP(g+1&65535)|0;a[808104]=h;TQ((h&255)<<8|e&255);return}e=TP(f)|0;a[808104]=e;if((a[808082]&8)==0){f=a[808084]|0;h=((f&255)+~(e&255)&65535)+(d[808120]|0)&65535;a[808120]=(h&65535)>>>15&255^1;g=h&255;i=g;j=(g^f)&(f^e)}else{f=b[404042]|0;g=f&255;h=((g&15)-(e&15)&255)-((a[808120]|0)==0)&255;k=(f&240)-(e&-16&255)&65535;if((h&255)>15){l=h+10&15;m=k-16&65535}else{l=h;m=k}if((m&65535)>240){a[808120]=0;n=m+160&255&-16}else{a[808120]=1;n=m&255}m=n|l;i=m;j=(m^g)&(g^e)}a[808123]=(j&255)>>>7;a[808084]=i;a[808121]=i;a[808122]=i;return}function Tu(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=(a[808082]&32)==0;e=TP(c[202024]|0)|0;a[808104]=e;b[404048]=(b[404048]|0)+1&65535;f=(b[404043]|0)+(e&255)&65535;e=f&65535;g=TP(e)|0;if(d){a[808104]=g;d=f+1&65535;f=(((TP(d)|0)&255)<<8|g&255)+1&65535;h=(f&65535)>>>8&255;HY(h,d);d=f&255;HY(d,e);a[808104]=d;i=h;j=f<<16>>16!=0|0;a[808121]=j;a[808122]=i;return}else{f=g+1&255;HY(f,e);a[808104]=f;i=f;j=f;a[808121]=j;a[808122]=i;return}}function Tv(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=(a[808082]&32)==0;f=TP(c[202024]|0)|0;a[808104]=f;b[404048]=(b[404048]|0)+1&65535;g=(b[404043]|0)+(f&255)&65535;f=TP(g)|0;a[808104]=f;h=TP(g+1|0)|0;a[808104]=h;i=TP(g+2|0)|0;a[808104]=i;g=((h&255)<<8|f&255)&65535|(i&255)<<16;if(e){e=TP(g)|0;a[808104]=e;i=TP(g+1|0)|0;a[808104]=i;TQ((i&255)<<8|e&255);return}e=TP(g)|0;a[808104]=e;if((a[808082]&8)==0){g=a[808084]|0;i=((g&255)+~(e&255)&65535)+(d[808120]|0)&65535;a[808120]=(i&65535)>>>15&255^1;f=i&255;j=f;k=(f^g)&(g^e)}else{g=b[404042]|0;f=g&255;i=((f&15)-(e&15)&255)-((a[808120]|0)==0)&255;h=(g&240)-(e&-16&255)&65535;if((i&255)>15){l=i+10&15;m=h-16&65535}else{l=i;m=h}if((m&65535)>240){a[808120]=0;n=m+160&255&-16}else{a[808120]=1;n=m&255}m=n|l;j=m;k=(m^f)&(f^e)}a[808123]=(k&255)>>>7;a[808084]=j;a[808121]=j;a[808122]=j;return}function Tw(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=(a[808082]&32)==0;f=c[202024]|0;g=TP(f)|0;a[808104]=g;if(e){e=TP((f&65535)+1&65535|f&-65536)|0;a[808104]=e;b[404048]=(b[404048]|0)+2&65535;TQ((e&255)<<8|g&255);return}b[404048]=(b[404048]|0)+1&65535;if((a[808082]&8)==0){e=a[808084]|0;f=((e&255)+~(g&255)&65535)+(d[808120]|0)&65535;a[808120]=(f&65535)>>>15&255^1;h=f&255;i=h;j=(h^e)&(e^g)}else{e=b[404042]|0;h=e&255;f=((h&15)-(g&15)&255)-((a[808120]|0)==0)&255;k=(e&240)-(g&-16&255)&65535;if((f&255)>15){l=f+10&15;m=k-16&65535}else{l=f;m=k}if((m&65535)>240){a[808120]=0;n=m+160&255&-16}else{a[808120]=1;n=m&255}m=n|l;i=m;j=(m^h)&(h^g)}a[808123]=(j&255)>>>7;a[808084]=i;a[808121]=i;a[808122]=i;return}function Tx(){var f=0,g=0,h=0,i=0,j=0,k=0;f=(a[808082]&16)==0;g=c[202032]|0;h=c[202024]|0;i=TP(h)|0;a[808104]=i;j=TP((h&65535)+1&65535|h&-65536)|0;a[808104]=j;b[404048]=(b[404048]|0)+2&65535;h=((j&255)<<8|i&255)&65535|g;if(f){f=TP(h)|0;a[808104]=f;g=TP(h+1|0)|0;a[808104]=g;i=(e[404045]|0)-(((g&255)<<8|f&255)&65535)|0;a[808120]=i>>>31&255^1;a[808121]=(i&65535|0)!=0|0;k=i>>>8&255;a[808122]=k;return}else{i=TP(h)|0;a[808104]=i;h=(d[808090]|0)-(i&255)&65535;a[808120]=(h&65535)>>>15&255^1;i=h&255;a[808121]=i;k=i;a[808122]=k;return}}function Ty(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=(a[808082]&32)==0;f=c[202032]|0;g=c[202024]|0;h=TP(g)|0;a[808104]=h;i=TP((g&65535)+1&65535|g&-65536)|0;a[808104]=i;b[404048]=(b[404048]|0)+2&65535;g=((i&255)<<8|h&255)&65535|f;if(e){e=TP(g)|0;a[808104]=e;f=TP(g+1|0)|0;a[808104]=f;TQ((f&255)<<8|e&255);return}e=TP(g)|0;a[808104]=e;if((a[808082]&8)==0){g=a[808084]|0;f=((g&255)+~(e&255)&65535)+(d[808120]|0)&65535;a[808120]=(f&65535)>>>15&255^1;h=f&255;j=h;k=(h^g)&(g^e)}else{g=b[404042]|0;h=g&255;f=((h&15)-(e&15)&255)-((a[808120]|0)==0)&255;i=(g&240)-(e&-16&255)&65535;if((f&255)>15){l=f+10&15;m=i-16&65535}else{l=f;m=i}if((m&65535)>240){a[808120]=0;n=m+160&255&-16}else{a[808120]=1;n=m&255}m=n|l;j=m;k=(m^h)&(h^e)}a[808123]=(k&255)>>>7;a[808084]=j;a[808121]=j;a[808122]=j;return}function Tz(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0;d=(a[808082]&32)==0;e=c[202032]|0;f=c[202024]|0;g=TP(f)|0;a[808104]=g;h=TP((f&65535)+1&65535|f&-65536)|0;a[808104]=h;b[404048]=(b[404048]|0)+2&65535;f=((h&255)<<8|g&255)&65535|e;e=TP(f)|0;if(d){a[808104]=e;d=f+1|0;g=(((TP(d)|0)&255)<<8|e&255)+1&65535;h=(g&65535)>>>8&255;HY(h,d);d=g&255;HY(d,f);a[808104]=d;i=h;j=g<<16>>16!=0|0;a[808121]=j;a[808122]=i;return}else{g=e+1&255;HY(g,f);a[808104]=g;i=g;j=g;a[808121]=j;a[808122]=i;return}}function TA(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=(a[808082]&32)==0;f=c[202024]|0;g=TP(f)|0;a[808104]=g;h=TP((f&65535)+1&65535|f&-65536)|0;a[808104]=h;b[404048]=(b[404048]|0)+2&65535;f=TP(c[202024]|0)|0;a[808104]=f;b[404048]=(b[404048]|0)+1&65535;i=(f&255)<<16|((h&255)<<8|g&255)&65535;if(e){e=TP(i)|0;a[808104]=e;g=TP(i+1|0)|0;a[808104]=g;TQ((g&255)<<8|e&255);return}e=TP(i)|0;a[808104]=e;if((a[808082]&8)==0){i=a[808084]|0;g=((i&255)+~(e&255)&65535)+(d[808120]|0)&65535;a[808120]=(g&65535)>>>15&255^1;h=g&255;j=h;k=(h^i)&(i^e)}else{i=b[404042]|0;h=i&255;g=((h&15)-(e&15)&255)-((a[808120]|0)==0)&255;f=(i&240)-(e&-16&255)&65535;if((g&255)>15){l=g+10&15;m=f-16&65535}else{l=g;m=f}if((m&65535)>240){a[808120]=0;n=m+160&255&-16}else{a[808120]=1;n=m&255}m=n|l;j=m;k=(m^h)&(h^e)}a[808123]=(k&255)>>>7;a[808084]=j;a[808121]=j;a[808122]=j;return}function TB(){var d=0,e=0,f=0;d=TP(c[202024]|0)|0;a[808104]=d;e=(b[404048]|0)+1&65535;b[404048]=e;f=e&65535;e=f+(d<<24>>24)|0;if((a[808121]|0)!=0){return}if(((e^f)&61440|0)==0){b[404048]=e&65535;return}else{HR((c[202031]|0)+(e&65535)|0);return}}function TC(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=(a[808082]&32)==0;g=TP(c[202024]|0)|0;a[808104]=g;b[404048]=(b[404048]|0)+1&65535;h=b[404043]|0;if((b[404041]&256)==0){i=65535}else{i=(h&255)<<24>>24!=0?65535:255}j=TV(h+(g&255)&65535,i)|0;a[808104]=(j&65535)>>>8&255;i=(e[404046]|0)+(c[202032]|j&65535)|0;if(f){f=TP(i)|0;a[808104]=f;j=TP(i+1|0)|0;a[808104]=j;TQ((j&255)<<8|f&255);return}f=TP(i)|0;a[808104]=f;if((a[808082]&8)==0){i=a[808084]|0;j=((i&255)+~(f&255)&65535)+(d[808120]|0)&65535;a[808120]=(j&65535)>>>15&255^1;g=j&255;k=g;l=(g^i)&(i^f)}else{i=b[404042]|0;g=i&255;j=((g&15)-(f&15)&255)-((a[808120]|0)==0)&255;h=(i&240)-(f&-16&255)&65535;if((j&255)>15){m=j+10&15;n=h-16&65535}else{m=j;n=h}if((n&65535)>240){a[808120]=0;o=n+160&255&-16}else{a[808120]=1;o=n&255}n=o|m;k=n;l=(n^g)&(g^f)}a[808123]=(l&255)>>>7;a[808084]=k;a[808121]=k;a[808122]=k;return}function TD(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;e=(a[808082]&32)==0;f=TP(c[202024]|0)|0;a[808104]=f;b[404048]=(b[404048]|0)+1&65535;g=b[404043]|0;if((b[404041]&256)==0){h=65535}else{h=(g&255)<<24>>24!=0?65535:255}i=TV(g+(f&255)&65535,h)|0;a[808104]=(i&65535)>>>8&255;h=c[202032]|i&65535;if(e){e=TP(h)|0;a[808104]=e;i=TP(h+1|0)|0;a[808104]=i;TQ((i&255)<<8|e&255);return}e=TP(h)|0;a[808104]=e;if((a[808082]&8)==0){h=a[808084]|0;i=((h&255)+~(e&255)&65535)+(d[808120]|0)&65535;a[808120]=(i&65535)>>>15&255^1;f=i&255;j=f;k=(f^h)&(h^e)}else{h=b[404042]|0;f=h&255;i=((f&15)-(e&15)&255)-((a[808120]|0)==0)&255;g=(h&240)-(e&-16&255)&65535;if((i&255)>15){l=i+10&15;m=g-16&65535}else{l=i;m=g}if((m&65535)>240){a[808120]=0;n=m+160&255&-16}else{a[808120]=1;n=m&255}m=n|l;j=m;k=(m^f)&(f^e)}a[808123]=(k&255)>>>7;a[808084]=j;a[808121]=j;a[808122]=j;return}function TE(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=(a[808082]&32)==0;g=TP(c[202024]|0)|0;a[808104]=g;b[404048]=(b[404048]|0)+1&65535;h=(b[404044]|0)+(g&255)&65535;g=TP(h)|0;a[808104]=g;i=TP(h+1|0)|0;a[808104]=i;h=(c[202032]|0)+(e[404046]|0)+(((i&255)<<8|g&255)&65535)&16777215;if(f){f=TP(h)|0;a[808104]=f;g=TP(h+1|0)|0;a[808104]=g;TQ((g&255)<<8|f&255);return}f=TP(h)|0;a[808104]=f;if((a[808082]&8)==0){h=a[808084]|0;g=((h&255)+~(f&255)&65535)+(d[808120]|0)&65535;a[808120]=(g&65535)>>>15&255^1;i=g&255;j=i;k=(i^h)&(h^f)}else{h=b[404042]|0;i=h&255;g=((i&15)-(f&15)&255)-((a[808120]|0)==0)&255;l=(h&240)-(f&-16&255)&65535;if((g&255)>15){m=g+10&15;n=l-16&65535}else{m=g;n=l}if((n&65535)>240){a[808120]=0;o=n+160&255&-16}else{a[808120]=1;o=n&255}n=o|m;j=n;k=(n^i)&(i^f)}a[808123]=(k&255)>>>7;a[808084]=j;a[808121]=j;a[808122]=j;return}function TF(){var d=0,f=0,g=0,h=0;d=c[202032]|0;f=c[202024]|0;g=TP(f)|0;a[808104]=g;h=((TP((f&65535)+1&65535|f&-65536)|0)&255)<<8|g&255;b[404048]=(b[404048]|0)+2&65535;g=h&65535|d;d=(e[404044]|0)-1|0;HY((g&65535)>>>8&255,(d&65535)+1&65535|d&-65536);h=g&255;HY(h,d);b[404044]=(b[404044]|0)-2&65535;a[808104]=h;if((b[404041]&256)==0){return}a[808089|0]=1;return}function TG(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;e=(a[808082]&32)==0;f=TP(c[202024]|0)|0;a[808104]=f;b[404048]=(b[404048]|0)+1&65535;g=b[404043]|0;h=g+(f&255)&65535;f=h&255;i=(h&65535)>>>8;j=i&255;do{if((b[404041]&256)==0){k=4873}else{if((g&255)<<24>>24!=0){k=4873;break}l=(a[808090]|0)+f&255;m=j}}while(0);if((k|0)==4873){k=(b[404045]|0)+(i<<8|h&255)&65535;l=k&255;m=(k&65535)>>>8&255}k=(m&255)<<8|l&255;l=k&65535;if(e){e=TP(l)|0;a[808104]=e;m=TP(k+1&65535)|0;a[808104]=m;TQ((m&255)<<8|e&255);return}e=TP(l)|0;a[808104]=e;if((a[808082]&8)==0){l=a[808084]|0;m=((l&255)+~(e&255)&65535)+(d[808120]|0)&65535;a[808120]=(m&65535)>>>15&255^1;k=m&255;n=k;o=(k^l)&(l^e)}else{l=b[404042]|0;k=l&255;m=((k&15)-(e&15)&255)-((a[808120]|0)==0)&255;h=(l&240)-(e&-16&255)&65535;if((m&255)>15){p=m+10&15;q=h-16&65535}else{p=m;q=h}if((q&65535)>240){a[808120]=0;r=q+160&255&-16}else{a[808120]=1;r=q&255}q=r|p;n=q;o=(q^k)&(k^e)}a[808123]=(o&255)>>>7;a[808084]=n;a[808121]=n;a[808122]=n;return}function TH(){var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;d=(a[808082]&32)==0;e=TP(c[202024]|0)|0;a[808104]=e;b[404048]=(b[404048]|0)+1&65535;f=b[404043]|0;g=f+(e&255)&65535;e=g&255;h=(g&65535)>>>8;i=h&255;do{if((b[404041]&256)==0){j=4891}else{if((f&255)<<24>>24!=0){j=4891;break}k=(a[808090]|0)+e&255;l=i}}while(0);if((j|0)==4891){j=(b[404045]|0)+(h<<8|g&255)&65535;k=j&255;l=(j&65535)>>>8&255}j=(l&255)<<8|k&255;k=j&65535;l=TP(k)|0;if(d){a[808104]=l;d=j+1&65535;j=(((TP(d)|0)&255)<<8|l&255)+1&65535;g=(j&65535)>>>8&255;HY(g,d);d=j&255;HY(d,k);a[808104]=d;m=g;n=j<<16>>16!=0|0;a[808121]=n;a[808122]=m;return}else{j=l+1&255;HY(j,k);a[808104]=j;m=j;n=j;a[808121]=n;a[808122]=m;return}}function TI(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=(a[808082]&32)==0;g=TP(c[202024]|0)|0;a[808104]=g;b[404048]=(b[404048]|0)+1&65535;h=(b[404043]|0)+(g&255)&65535;g=TP(h)|0;a[808104]=g;i=TP(h+1|0)|0;a[808104]=i;j=TP(h+2|0)|0;a[808104]=j;h=(((i&255)<<8|g&255)&65535|(j&255)<<16)+(e[404046]|0)|0;if(f){f=TP(h)|0;a[808104]=f;j=TP(h+1|0)|0;a[808104]=j;TQ((j&255)<<8|f&255);return}f=TP(h)|0;a[808104]=f;if((a[808082]&8)==0){h=a[808084]|0;j=((h&255)+~(f&255)&65535)+(d[808120]|0)&65535;a[808120]=(j&65535)>>>15&255^1;g=j&255;k=g;l=(g^h)&(h^f)}else{h=b[404042]|0;g=h&255;j=((g&15)-(f&15)&255)-((a[808120]|0)==0)&255;i=(h&240)-(f&-16&255)&65535;if((j&255)>15){m=j+10&15;n=i-16&65535}else{m=j;n=i}if((n&65535)>240){a[808120]=0;o=n+160&255&-16}else{a[808120]=1;o=n&255}n=o|m;k=n;l=(n^g)&(g^f)}a[808123]=(l&255)>>>7;a[808084]=k;a[808121]=k;a[808122]=k;return}function TJ(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=(a[808082]&32)==0;g=c[202032]|0;h=c[202024]|0;i=TP(h)|0;a[808104]=i;j=TP((h&65535)+1&65535|h&-65536)|0;a[808104]=j;b[404048]=(b[404048]|0)+2&65535;h=(((j&255)<<8|i&255)&65535|g)+(e[404046]|0)|0;if(f){f=TP(h)|0;a[808104]=f;g=TP(h+1|0)|0;a[808104]=g;TQ((g&255)<<8|f&255);return}f=TP(h)|0;a[808104]=f;if((a[808082]&8)==0){h=a[808084]|0;g=((h&255)+~(f&255)&65535)+(d[808120]|0)&65535;a[808120]=(g&65535)>>>15&255^1;i=g&255;k=i;l=(i^h)&(h^f)}else{h=b[404042]|0;i=h&255;g=((i&15)-(f&15)&255)-((a[808120]|0)==0)&255;j=(h&240)-(f&-16&255)&65535;if((g&255)>15){m=g+10&15;n=j-16&65535}else{m=g;n=j}if((n&65535)>240){a[808120]=0;o=n+160&255&-16}else{a[808120]=1;o=n&255}n=o|m;k=n;l=(n^i)&(i^f)}a[808123]=(l&255)>>>7;a[808084]=k;a[808121]=k;a[808122]=k;return}function TK(){var c=0,d=0,f=0,g=0;c=b[404041]|0;if((c&256)!=0){a[808088]=(a[808088]|0)+1&255;d=TP(e[404044]|0)|0;a[808090]=d;a[808121]=d;a[808122]=d;a[808104]=d;return}d=b[404044]|0;if((c&16)==0){c=(d&65535)+1|0;f=TP(c)|0;a[808104]=f;g=TP((c&65535)+1&65535|c&2147418112)|0;c=(g&255)<<8|f&255;b[404045]=c;b[404044]=(b[404044]|0)+2&65535;a[808121]=c<<16>>16!=0|0;a[808122]=g;a[808104]=g;return}else{g=d+1&65535;b[404044]=g;d=TP(g&65535)|0;a[808090]=d;a[808121]=d;a[808122]=d;a[808104]=d;return}}function TL(){var d=0,f=0,g=0,h=0,i=0,j=0;d=c[202024]|0;a[808104]=TP(d)|0;a[808104]=TP((d&65535)+1&65535|d&-65536)|0;b[404048]=(b[404048]|0)+2&65535;d=TP(c[202024]|0)|0;f=(b[404048]|0)+1&65535;b[404048]=f;a[808104]=f&255;f=TP(c[202024]|0)|0;a[808104]=f;b[404048]=(b[404048]|0)+1&65535;g=c[202031]|0;h=((f&255)<<8|d&255)+(b[404045]|0)&65535|g;d=TP(h)|0;a[808104]=d;f=TP((h&65535)+1&65535|g&-65536)|0;g=((f&255)<<8|d&255)&65535;a[808104]=f;f=(b[404048]|0)-1&65535;d=(e[404044]|0)-1|0;HY((f&65535)>>>8&255,(d&65535)+1&65535|d&-65536);HY(f&255,d);b[404044]=(b[404044]|0)-2&65535;if((b[404041]&256)==0){i=c[202031]|0;j=i+g|0;HR(j);return}a[808089|0]=1;i=c[202031]|0;j=i+g|0;HR(j);return}function TM(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=(a[808082]&32)==0;g=c[202032]|0;h=c[202024]|0;i=TP(h)|0;a[808104]=i;j=TP((h&65535)+1&65535|h&-65536)|0;a[808104]=j;b[404048]=(b[404048]|0)+2&65535;h=(((j&255)<<8|i&255)&65535|g)+(e[404045]|0)|0;if(f){f=TP(h)|0;a[808104]=f;g=TP(h+1|0)|0;a[808104]=g;TQ((g&255)<<8|f&255);return}f=TP(h)|0;a[808104]=f;if((a[808082]&8)==0){h=a[808084]|0;g=((h&255)+~(f&255)&65535)+(d[808120]|0)&65535;a[808120]=(g&65535)>>>15&255^1;i=g&255;k=i;l=(i^h)&(h^f)}else{h=b[404042]|0;i=h&255;g=((i&15)-(f&15)&255)-((a[808120]|0)==0)&255;j=(h&240)-(f&-16&255)&65535;if((g&255)>15){m=g+10&15;n=j-16&65535}else{m=g;n=j}if((n&65535)>240){a[808120]=0;o=n+160&255&-16}else{a[808120]=1;o=n&255}n=o|m;k=n;l=(n^i)&(i^f)}a[808123]=(l&255)>>>7;a[808084]=k;a[808121]=k;a[808122]=k;return}function TN(){var d=0,f=0,g=0,h=0,i=0,j=0,k=0;d=(a[808082]&32)==0;f=c[202032]|0;g=c[202024]|0;h=TP(g)|0;a[808104]=h;i=TP((g&65535)+1&65535|g&-65536)|0;a[808104]=i;b[404048]=(b[404048]|0)+2&65535;g=(((i&255)<<8|h&255)&65535|f)+(e[404045]|0)|0;f=TP(g)|0;if(d){a[808104]=f;d=g+1|0;h=(((TP(d)|0)&255)<<8|f&255)+1&65535;i=(h&65535)>>>8&255;HY(i,d);d=h&255;HY(d,g);a[808104]=d;j=i;k=h<<16>>16!=0|0;a[808121]=k;a[808122]=j;return}else{h=f+1&255;HY(h,g);a[808104]=h;j=h;k=h;a[808121]=k;a[808122]=j;return}}function TO(){var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0;f=(a[808082]&32)==0;g=c[202024]|0;h=TP(g)|0;a[808104]=h;i=TP((g&65535)+1&65535|g&-65536)|0;a[808104]=i;b[404048]=(b[404048]|0)+2&65535;g=TP(c[202024]|0)|0;a[808104]=g;b[404048]=(b[404048]|0)+1&65535;j=(e[404045]|0)+((g&255)<<16|((i&255)<<8|h&255)&65535)|0;if(f){f=TP(j)|0;a[808104]=f;h=TP(j+1|0)|0;a[808104]=h;TQ((h&255)<<8|f&255);return}f=TP(j)|0;a[808104]=f;if((a[808082]&8)==0){j=a[808084]|0;h=((j&255)+~(f&255)&65535)+(d[808120]|0)&65535;a[808120]=(h&65535)>>>15&255^1;i=h&255;k=i;l=(i^j)&(j^f)}else{j=b[404042]|0;i=j&255;h=((i&15)-(f&15)&255)-((a[808120]|0)==0)&255;g=(j&240)-(f&-16&255)&65535;if((h&255)>15){m=h+10&15;n=g-16&65535}else{m=h;n=g}if((n&65535)>240){a[808120]=0;o=n+160&255&-16}else{a[808120]=1;o=n&255}n=o|m;k=n;l=(n^i)&(i^f)}a[808123]=(l&255)>>>7;a[808084]=k;a[808121]=k;a[808122]=k;return}function TP(b){b=b|0;var e=0,f=0,g=0;e=c[808144+((b>>>12&4095)<<2)>>2]|0;if(e>>>0>=19){f=a[e+(b&65535)|0]|0;return f|0}switch(e|0){case 7:{f=a[(c[210228]|0)+((b&32767)-24576)|0]|0;return f|0};case 8:{e=b-6291456|0;if((a[840936]|0)==2){f=(d[(c[263193]|0)+(e>>>2&65535)|0]|0)>>>((e<<1&6)>>>0)&3;return f|0}else{f=(d[(c[263193]|0)+(e>>>1&65535)|0]|0)>>>((e<<2&4)>>>0)&15;return f|0}break};case 9:{e=(b&65535)-24576|0;if((a[840936]|0)==2){f=(d[(c[210228]|0)+(e>>>2&65535)|0]|0)>>>((b<<1&6)>>>0)&3;return f|0}else{f=(d[(c[210228]|0)+(e>>>1&65535)|0]|0)>>>((b<<2&4)>>>0)&15;return f|0}break};case 2:case 6:{f=a[(c[263193]|0)+(b&65535)|0]|0;return f|0};case 1:{e=b&65535;switch(e|0){case 8970:{f=c[840932>>2]&255;return f|0};case 8961:{b=c[263195]|0;f=a[b+8961|0]&-16|a[b+8704|0]&15;return f|0};case 8968:{b=840928;f=((c[b>>2]|0)>>>16|c[b+4>>2]<<16)&255;return f|0};case 8972:{f=a[(c[263195]|0)+8972|0]|0;return f|0};case 8967:{b=840928;f=((c[b>>2]|0)>>>8|c[b+4>>2]<<24)&255;return f|0};case 8973:{b=c[263195]|0;g=a[b+8973|0]|0;if((a[b+8792|0]|0)>=0){f=g;return f|0}HV(1,0);f=g;return f|0};case 8966:{f=c[210232]&255;return f|0};case 8960:{f=a[1393588]&-96|a[(c[263195]|0)+8713|0]&95;return f|0};case 8969:{g=840928;f=((c[g>>2]|0)>>>24|c[g+4>>2]<<8)&255;return f|0};default:{f=a[(c[263195]|0)+e|0]|0;return f|0}}break};default:{f=a[808104]|0;return f|0}}return 0}function TQ(c){c=c|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;e=b[404042]|0;f=e&65535;if((a[808082]&8)==0){g=(d[808120]|0)+(f-(c&65535))|0;h=g+65535|0;a[808120]=(g|0)>0|0;i=h&65535;j=(h^f)&((e^c)&65535);k=j>>>15;l=k&255;m=l&1;a[808123]=m;b[404042]=i;n=i<<16>>16!=0;o=n&1;a[808121]=o;p=(i&65535)>>>8;q=p&255;a[808122]=q;return}h=((e&15)-(c&15)&65535)-((a[808120]|0)==0)&65535;g=(e&240)-(c&240)&65535;r=(e&3840)-(c&3840)&65535;s=(f&61440)-(c&-4096&65535)|0;if((h&65535)>15){t=h+10&15;u=g-16&65535}else{t=h;u=g}if((u&65535)>240){v=u+160&240;w=r-256&65535}else{v=u;w=r}if((w&65535)>3840){x=w+2560&3840;y=s-4096|0}else{x=w;y=s}if(y>>>0>61440){z=y+40960&61440;A=0}else{z=y;A=1}a[808120]=A;A=z|(v|t|x)&65535;i=A&65535;j=(A^f)&((e^c)&65535);k=j>>>15;l=k&255;m=l&1;a[808123]=m;b[404042]=i;n=i<<16>>16!=0;o=n&1;a[808121]=o;p=(i&65535)>>>8;q=p&255;a[808122]=q;return}function TR(c){c=c|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;e=b[404042]|0;f=e&65535;if((a[808082]&8)==0){g=c&65535;h=f+g+(d[808120]|0)|0;a[808120]=h>>>0>65535|0;i=h&65535;j=(h^g)&((e^c)&65535^32768);k=j>>>15;l=k&255;m=l&1;a[808123]=m;b[404042]=i;n=i<<16>>16!=0;o=n&1;a[808121]=o;p=(i&65535)>>>8;q=p&255;a[808122]=q;return}g=e&240;h=e&3840;r=f&61440;f=((e&15)+(c&15)&65535)+(d[808120]|0)&65535;if((f&65535)>9){s=f+6&15;t=g+16&65535}else{s=f;t=g}g=t+(c&240)&65535;if((g&65535)>144){u=g+96&240;v=h+256&65535}else{u=g;v=h}h=v+(c&3840)&65535;if((h&65535)>2304){w=h+1536&3840;x=r+4096|0}else{w=h;x=r}r=x+(c&-4096&65535)|0;if(r>>>0>36864){y=r+24576&61440;z=1}else{y=r;z=0}a[808120]=z;z=y|(u|s|w)&65535;i=z&65535;j=(z^c&65535)&((e^c)&65535^32768);k=j>>>15;l=k&255;m=l&1;a[808123]=m;b[404042]=i;n=i<<16>>16!=0;o=n&1;a[808121]=o;p=(i&65535)>>>8;q=p&255;a[808122]=q;return}function TS(){var b=0,d=0,e=0,f=0,g=0;b=(c[263195]|0)+18432|0;x=0;a[b]=x&255;x=x>>8;a[b+1|0]=x&255;x=x>>8;a[b+2|0]=x&255;x=x>>8;a[b+3|0]=x&255;a[(c[263195]|0)+18436|0]=0;b=0;while(1){d=(c[263192]|0)+(b<<12)|0;e=b+16|0;f=b;do{c[1052804+(f+3072<<2)>>2]=d;f=f+1|0;}while((f|0)<(e|0));if((e|0)<256){b=e}else{break}}a[(c[263195]|0)+18437|0]=1;b=0;while(1){f=(c[263192]|0)+((b<<12)+1048576)|0;d=b+16|0;g=b;do{c[1052804+(g+3328<<2)>>2]=f;g=g+1|0;}while((g|0)<(d|0));if((d|0)<256){b=d}else{break}}a[(c[263195]|0)+18438|0]=2;b=0;while(1){g=(c[263192]|0)+((b<<12)+2097152)|0;f=b+16|0;e=b;do{c[1052804+(e+3584<<2)>>2]=g;e=e+1|0;}while((e|0)<(f|0));if((f|0)<256){b=f}else{break}}a[(c[263195]|0)+18439|0]=3;b=0;while(1){e=(c[263192]|0)+((b<<12)+3145728)|0;g=b+16|0;d=b;do{c[1052804+(d+3840<<2)>>2]=e;d=d+1|0;}while((d|0)<(g|0));if((g|0)<256){b=g}else{break}}return}function TT(e){e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;f=e&255;e=237808+(f<<2)|0;g=c[e>>2]|0;h=((c[127546]&g)>>>5|f<<4&16|c[125854]&g)&255;f=797552+h|0;i=a[f]|0;j=i&255;k=d[15320+(j*3|0)|0]|0;l=798224+k|0;m=a[l]|0;if(m<<24>>24==0){n=c[42368]|0;if((n|0)==0){o=c[127416]|0;c[127416]=o+1;p=b[254828]|(d[o]|0);b[254828]=p;c[42368]=8;q=7;r=p}else{q=n-1|0;r=b[254828]|0}c[42368]=q;n=r<<1^-32768;b[254828]=n;r=n&65535;if((r&32768|0)==0){n=r<<k;b[254828]=n&65535;p=q-k|0;c[42368]=p;if((p|0)<0){q=c[127416]|0;c[127416]=q+1;b[254828]=((d[q]|0)<<-p|n)&65535;c[42368]=p+8}s=a[1776+(r>>>8|127>>>(k>>>0)&255)|0]|0}else{s=(1<<k)+128&255}a[l]=s;t=s}else{t=m}a[l]=t-1&255;if((t<<24>>24|0)==1){a[f]=a[15322+(j*3|0)|0]|0;m=797584+(h<<2)|0;s=c[m>>2]^1;if((i&255)<2){c[m>>2]=s;u=s&255;v=g<<1;w=u&255;x=w|v;c[e>>2]=x;return u|0}else{u=s&255;v=g<<1;w=u&255;x=w|v;c[e>>2]=x;return u|0}}else if((t<<24>>24|0)==(-127|0)){a[l]=0;a[f]=a[15321+(j*3|0)|0]|0}u=c[797584+(h<<2)>>2]&255;v=g<<1;w=u&255;x=w|v;c[e>>2]=x;return u|0}function TU(b){b=b|0;var d=0,e=0;do{if((b&524288|0)==0){d=-128}else{e=b&4095;if((e|0)==32){d=a[808064]|0;break}else if((e|0)==33){d=a[808065]|0;break}else{d=a[(c[263193]|0)+(c[274485]&b)|0]|0;break}}}while(0);return d|0}function TV(b,c){b=b|0;c=c|0;var d=0,e=0;d=TP(b)|0;a[808104]=d;if((c|0)==255){e=((TP(((b&255)+1&255|b&65535&-256)&65535|b&-65536)|0)&255)<<8|d&255;return e|0}else if((c|0)==65535){e=((TP((b&65535)+1&65535|b&-65536)|0)&255)<<8|d&255;return e|0}else{e=((TP(b+1|0)|0)&255)<<8|d&255;return e|0}return 0}function TW(e,f){e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0;g=i;i=i+64|0;h=g|0;if((e&524288|0)==0){a[808066]=1;i=g;return}j=e&4095;k=(a[808066]|0)==0;if(!((j|0)!=32|k)){a[808064]=f}if((j|0)!=33|k){a[(c[263193]|0)+(c[274485]&e)|0]=f;l=a[808065]|0}else{a[808065]=f;l=f}if(l<<24>>24>=0){i=g;return}L6164:do{switch(d[808064]|0){case 8:{l=c[263193]|0;f=d[l+1|0]<<8|d[l];e=(d[l+3|0]<<8|d[l+2|0])<<16>>16;k=(d[l+5|0]<<8|d[l+4|0])&65535;j=b[146616+(k>>>8<<1)>>1]|0;m=(ab(e,j)|0)>>>15;n=f<<16>>16;f=b[146616+(((k+16384|0)>>>8&255)<<1)>>1]|0;k=((ab(f,n)|0)>>>15)+m|0;m=((ab(f,e)|0)>>>15)-((ab(j,n)|0)>>>15)|0;a[l+16|0]=k&255;a[(c[263193]|0)+17|0]=(k&65535)>>>8&255;a[(c[263193]|0)+18|0]=m&255;a[(c[263193]|0)+19|0]=(m&65535)>>>8&255;break};case 1:{m=c[263193]|0;a[m+6|0]=a[m+2|0]|0;m=c[263193]|0;a[m+7|0]=a[m+3|0]|0;m=c[263193]|0;k=d[m+1|0]<<8;l=k|d[m];n=d[m+3|0]<<8;j=n|d[m+2|0];e=j<<16>>16<0;do{if((n&k)<<16>>16<0){o=-32768;p=-j&65535;q=-l&65535}else{if(l<<16>>16<0){o=-16384;p=-l&65535;q=j;break}else{o=n<<16>>16>>15&16384;p=e?l:j;q=e?-j&65535:l;break}}}while(0);l=p;j=q;L6174:while(1){do{if(l<<16>>16>31){if(j<<16>>16<=1){r=j;break}r=j<<16>>16>>>1&65535}else{if(l<<16>>16<=1){s=j;t=5138;break L6174}if(j<<16>>16<=31){u=j;break L6174}r=j<<16>>16>>>1&65535}}while(0);l=l<<16>>16>>>1&65535;j=r}if((t|0)==5138){while(1){t=0;if(s<<16>>16>31){s=s<<16>>16>>>1&65535;t=5138}else{u=s;break}}}j=l<<16>>16==0?o+16384&65535:o;e=d[(u<<16>>16)+(147480+(l<<16>>16<<5))|0]<<8^j;a[m]=u&255;a[(c[263193]|0)+1|0]=(u&65535)>>>8&255;a[(c[263193]|0)+2|0]=l&255;a[(c[263193]|0)+3|0]=(l&65535)>>>8&255;a[(c[263193]|0)+4|0]=0;a[(c[263193]|0)+5|0]=(j&65535)>>>8&255;a[(c[263193]|0)+16|0]=0;a[(c[263193]|0)+17|0]=(e&65535)>>>8&255;break};case 2:{e=c[263193]|0;j=d[e+37|0]<<8|d[e+36|0];n=j&65535;if(j<<16>>16==0){break L6164}else{v=0;w=0}while(1){b[h+(w<<1)>>1]=d[e+(v+65)|0]<<8|d[e+(v+64)|0];k=w+1|0;if((k|0)<(n|0)){v=v+2|0;w=k}else{break}}l=e+128|0;if((j&65535)>1){m=j;while(1){k=(m&65535)-1|0;f=1;x=0;L6194:while(1){y=x;while(1){if((y|0)>=(k|0)){break L6194}z=h+(y<<1)|0;A=b[z>>1]|0;B=y+1|0;C=h+(B<<1)|0;D=b[C>>1]|0;if((A&65535)<(D&65535)){break}else{y=B}}b[C>>1]=A;b[z>>1]=D;E=l+(B<<1)|0;F=b[E>>1]|0;G=l+(y<<1)|0;b[E>>1]=b[G>>1]|0;b[G>>1]=F;f=0;x=B}if(f<<24>>24==0){m=m-1&65535}else{H=0;I=0;break}}}else{H=0;I=0}while(1){m=b[h+(I<<1)>>1]|0;a[(c[263193]|0)+(H+64)|0]=m&255;a[(c[263193]|0)+(H+65)|0]=(m&65535)>>>8&255;m=I+1|0;if((m|0)>=(n|0)){break L6164}H=H+2|0;I=m}break};case 3:{n=c[263193]|0;m=d[n+3|0]<<8|d[n+2|0];l=(d[n+5|0]<<8|d[n+4|0])<<16>>16<<1;j=ab((d[n+1|0]<<8|d[n])<<16>>16,l)|0;e=ab(m<<16>>16,l)|0;a[n+16|0]=j&255;a[(c[263193]|0)+17|0]=j>>>8&255;a[(c[263193]|0)+18|0]=j>>>16&255;a[(c[263193]|0)+19|0]=j>>>24&255;a[(c[263193]|0)+20|0]=e&255;a[(c[263193]|0)+21|0]=e>>>8&255;a[(c[263193]|0)+22|0]=e>>>16&255;a[(c[263193]|0)+23|0]=e>>>24&255;break};case 6:{e=c[263193]|0;j=ab((d[e+3|0]<<8|d[e+2|0])<<16>>16,(d[e+1|0]<<8|d[e])<<16>>16<<1)|0;a[e+16|0]=j&255;a[(c[263193]|0)+17|0]=j>>>8&255;a[(c[263193]|0)+18|0]=j>>>16&255;a[(c[263193]|0)+19|0]=j>>>24&255;break};case 7:{j=c[263193]|0;e=(d[j+1|0]<<8|d[j])&65535;n=b[146616+(((e+16384|0)>>>8&255)<<1)>>1]|0;l=b[146616+(e>>>8<<1)>>1]|0;e=0;m=0;x=j;while(1){j=b[147128+(m<<1)>>1]|0;k=ab(j,n)|0;F=k>>>15&255;a[x+(e+240)|0]=F;G=k>>>23&255;a[(c[263193]|0)+(e+241)|0]=G;a[(c[263193]|0)+(e+1296)|0]=F;a[(c[263193]|0)+(e+1297)|0]=G;G=ab(j,l)|0;j=G>>>15;F=j&65535;k=j&255;a[(c[263193]|0)+(e+592)|0]=k;j=G>>>23&255;a[(c[263193]|0)+(e+593)|0]=j;if(F<<16>>16==0){J=j;K=k}else{k=~F;J=(k&65535)>>>8&255;K=k&255}a[(c[263193]|0)+(e+944)|0]=K;a[(c[263193]|0)+(e+945)|0]=J;k=m+1|0;if((k|0)>=176){break}e=e+2|0;m=k;x=c[263193]|0}x=c[263193]|0;a[x]=a[x+1|0]|0;a[(c[263193]|0)+1|0]=0;break};case 4:{x=c[263193]|0;m=d[x+1|0]<<8|d[x];e=(d[x+3|0]<<8|d[x+2|0])<<16>>16;l=ab(e,e)|0;e=m<<16>>16;m=~~+R(+(+(l+(ab(e,e)|0)|0)));a[x+16|0]=m&255;a[(c[263193]|0)+17|0]=(m&65535)>>>8&255;break};case 5:{m=c[263193]|0;x=a[m+193|0]|0;e=a[m+192|0]|0;l=a[m+195|0]|0;n=a[m+194|0]|0;k=d[m+197|0]<<8|d[m+196|0]|d[m+198|0]<<16|d[m+199|0]<<24;F=d[m+201|0]<<8|d[m+200|0]|d[m+202|0]<<16|d[m+203|0]<<24;j=d[m+205|0]<<8|d[m+204|0];G=d[m+213|0]<<8|d[m+212|0];E=d[m+215|0]<<8|d[m+214|0];L=d[m+217|0]<<8|d[m+216|0];M=d[m+219|0]<<8|d[m+218|0];N=a[m+221|0]|0;O=a[m+220|0]|0;P=a[m+223|0]|0;Q=a[m+222|0]|0;S=a[m+225|0]|0;T=a[m+224|0]|0;U=((l&255)<<8|n&255)<<16>>16;V=U-(F>>>16)|0;W=((x&255)<<8|e&255)<<16>>16;X=W-(k>>>16)|0;a[m+210|0]=-1;a[(c[263193]|0)+211|0]=-1;a[(c[263193]|0)+218|0]=0;a[(c[263193]|0)+219|0]=0;m=X&65535;Y=V&65535;Z=Y<<16>>16<0;do{if((V&X&65535)<<16>>16<0){_=-32768;$=-Y&65535;aa=-m&65535}else{if(m<<16>>16<0){_=-16384;$=-m&65535;aa=Y;break}else{_=Y<<16>>16>>15&16384;$=Z?m:Y;aa=Z?-Y&65535:m;break}}}while(0);m=$;Y=aa;L6223:while(1){do{if(m<<16>>16>31){if(Y<<16>>16<=1){ac=Y;break}ac=Y<<16>>16>>>1&65535}else{if(m<<16>>16<=1){ad=Y;t=5154;break L6223}if(Y<<16>>16<=31){ae=Y;break L6223}ac=Y<<16>>16>>>1&65535}}while(0);m=m<<16>>16>>>1&65535;Y=ac}if((t|0)==5154){while(1){t=0;if(ad<<16>>16>31){ad=ad<<16>>16>>>1&65535;t=5154}else{ae=ad;break}}}Y=d[(ae<<16>>16)+(147480+(m<<16>>16<<5))|0]<<8^(m<<16>>16==0?_+16384&65535:_);f=(Y&65535)-(j&65535)|0;if((((f|0)>-1?f:-f|0)|0)>32768){af=j^-32768;ag=1;ah=Y^-32768}else{af=j;ag=0;ah=Y}Y=ah&65535;f=af&65535;Z=Y-f|0;X=(Z|0)>-1?Z:-Z|0;do{if((X|0)==32768){ai=256}else{if((X|0)>4095){ai=(G&65535)-(X>>>4)&65535;break}else{V=E+G&65535;ai=(V&65535)>(L&65535)?L:V;break}}}while(0);L=(G&65535)-(ai&65535)|0;if((((L|0)>-1?L:-L|0)|0)>32768){aj=(G&65535)<(ai&65535)?0:-256}else{aj=ai}L=(ah&65535)>(af&65535);do{if(L&(Z|0)>128){t=5168}else{if((ah&65535)>=(af&65535)){ak=af;break}if((f-Y|0)>127){t=5168}else{ak=af}}}while(0);do{if((t|0)==5168){if((ah&65535)<(af&65535)){ak=af-640&65535;break}else{ak=L?af+640&65535:af;break}}}while(0);L=ag<<24>>24==0?ak:ak^-32768;Y=(U<<16)-F>>16;f=(W<<16)-k>>16;do{if(M<<16>>16==0){if((Y+8|0)>>>0>=15){al=O;am=l;an=n;ao=x;ap=e;break}if((f+128|0)>>>0<255){t=5176}else{al=O;am=l;an=n;ao=x;ap=e}}else{if((f+8|0)>>>0>=15){al=O;am=l;an=n;ao=x;ap=e;break}if((Y+128|0)>>>0<255){t=5176}else{al=O;am=l;an=n;ao=x;ap=e}}}while(0);if((t|0)==5176){al=O|8;am=S&127;an=T;ao=P;ap=Q}e=L&65535;x=(aj&65535)>>>8;n=x<<1;l=F-(ab(b[146616+(((e+16384|0)>>>8&255)<<1)>>1]>>5,n)|0)|0;Y=k-(ab(b[146616+(e>>>8<<1)>>1]>>5,n)|0)|0;a[(c[263193]|0)+192|0]=ap;a[(c[263193]|0)+193|0]=ao;a[(c[263193]|0)+194|0]=an;a[(c[263193]|0)+195|0]=am;a[(c[263193]|0)+196|0]=Y&255;a[(c[263193]|0)+197|0]=Y>>>8&255;a[(c[263193]|0)+198|0]=Y>>>16&255;a[(c[263193]|0)+199|0]=Y>>>24&31;a[(c[263193]|0)+200|0]=l&255;a[(c[263193]|0)+201|0]=l>>>8&255;a[(c[263193]|0)+202|0]=l>>>16&255;a[(c[263193]|0)+203|0]=l>>>24&31;a[(c[263193]|0)+204|0]=L&255;a[(c[263193]|0)+205|0]=(L&65535)>>>8&255;a[(c[263193]|0)+212|0]=aj&255;a[(c[263193]|0)+213|0]=x&255;a[(c[263193]|0)+220|0]=al;a[(c[263193]|0)+221|0]=N;break};default:{}}}while(0);a[808064]=0;a[808065]=0;i=g;return}function TX(b){b=b|0;var d=0,e=0;d=b&65535;if((d|0)==1){e=-1;return e|0}e=a[(c[263193]|0)+d|0]|0;return e|0}function TY(b,e){b=b|0;e=e|0;var f=0,g=0;if(!(a[148512]|0)){a[146608]=1;a[148512]=1}f=b&65535;a[(c[263193]|0)+f|0]=e;L6276:do{if((f|0)==0){if(!(a[146608]|0)){b=(c[202002]|0)+1|0;c[202002]=b;g=b;break}a[146608]=0;a[808024]=e;c[202002]=0;switch(e&255|0){case 2:{c[202004]=4;g=0;break L6276;break};case 5:{c[202004]=0;g=0;break L6276;break};case 1:{c[202004]=128;g=0;break L6276;break};case 6:{c[202004]=0;g=0;break L6276;break};case 7:{c[202004]=0;g=0;break L6276;break};case 4:{c[202004]=0;g=0;break L6276;break};case 14:{c[202004]=0;g=0;break L6276;break};default:{a[146608]=1;g=0;break L6276}}}else{g=c[202002]|0}}while(0);if((c[202004]|0)!=(g|0)){return}a[146608]=1;g=d[808024]|0;if((g|0)==4){a[(c[263193]|0)+300|0]=0;a[(c[263193]|0)+302|0]=0;return}else if((g|0)==5){a[(c[263193]|0)+300|0]=0;a[(c[263193]|0)+302|0]=0;return}else if((g|0)==14){a[(c[263193]|0)+300|0]=0;a[(c[263193]|0)+301|0]=0;return}else{return}}function TZ(b,d){b=b|0;d=d|0;var e=0,f=0;if(!(a[148504]|0)){a[146600]=1;a[807488]=0;a[148504]=1}e=d&65535;a[(c[263193]|0)+e|0]=b;do{if((e|0)==14338){c[201866]=(c[201866]|0)+1}else if((e|0)==14340){d=a[146600]|0;f=a[807488]|0;if(!(d&f<<24>>24==2)){if(!d){break}a[807488]=f+1&255;c[201868]=c[201868]<<8|b&255;break}a[146600]=0;c[201866]=0;c[201862]=0;a[807488]=0;a[807480]=0;f=c[201868]<<8|b&255;c[201868]=f;d=f&16777215;if((d|0)==256){a[146592]=0;break}else if((d|0)==65280){a[146592]=0;break}else{a[146600]=1;break}}}while(0);if((a[146592]&1|0)!=(c[201866]|0)){return}a[146600]=1;c[201866]=0;c[201862]=0;b=c[201868]|0;if((b|0)==256){a[146600]=0;e=a[807480]|0;d=e+1&255;a[807480]=d;if(e<<24>>24==0){a[146592]=1;c[201864]=2;a[807496]=-127;a[807497]=-127;return}c[201864]=3;a[807498]=-127;if(d<<24>>24!=3){return}a[146600]=1;return}else if((b|0)==65280){a[146600]=0;b=a[807480]|0;d=b+1&255;a[807480]=d;if(b<<24>>24==0){a[146592]=1;c[201864]=2;a[807496]=-127;a[807497]=-127;return}c[201864]=3;a[807498]=-127;if(d<<24>>24!=3){return}a[146600]=1;return}else{return}}
function fB(a){a=a|0;var b=0;b=i;i=i+a|0;i=i+7>>3<<3;return b|0}function fC(){return i|0}function fD(a){a=a|0;i=a}function fE(a,b){a=a|0;b=b|0;if((s|0)==0){s=a;t=b}}function fF(b){b=b|0;a[k]=a[b];a[k+1|0]=a[b+1|0];a[k+2|0]=a[b+2|0];a[k+3|0]=a[b+3|0]}function fG(b){b=b|0;a[k]=a[b];a[k+1|0]=a[b+1|0];a[k+2|0]=a[b+2|0];a[k+3|0]=a[b+3|0];a[k+4|0]=a[b+4|0];a[k+5|0]=a[b+5|0];a[k+6|0]=a[b+6|0];a[k+7|0]=a[b+7|0]}function fH(a){a=a|0;F=a}function fI(a){a=a|0;G=a}function fJ(a){a=a|0;H=a}function fK(a){a=a|0;I=a}function fL(a){a=a|0;J=a}function fM(a){a=a|0;K=a}function fN(a){a=a|0;L=a}function fO(a){a=a|0;M=a}function fP(a){a=a|0;N=a}function fQ(a){a=a|0;O=a}function fR(){}function fS(b,d){b=b|0;d=d|0;var e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0.0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;e=i;i=i+20480|0;f=e|0;h=e+12288|0;e0(800,600);X2(535e3,0,102384);j=c[198610]|0;if((j|0)!=0){aQ(j|0)|0}X2(637400,0,158120);a[637402]=1;a[637401]=1;c[160384]=0;c[159351]=1;c[159352]=1;c[159353]=1;c[159354]=1;c[159355]=1;c[159356]=1;c[159357]=1;c[159358]=1;f$();j=f9(b,d)|0;if((j|0)!=0){k=j;i=e;return k|0}j=e+16384|0;d=XY(113728)|0;b=(d|0)==0;do{if(!b){if((c[d-4>>2]&3|0)==0){break}X2(d|0,0,113728)}}while(0);l=d;c[d+28>>2]=244792;c[d+32>>2]=640;c[d+4152>>2]=17392;m=4096;n=d+54|0;o=633281;while(1){q=m-1|0;if((q|0)==0){r=10;break}s=a[o]|0;a[n]=s;if(s<<24>>24==0){break}else{m=q;n=n+1|0;o=o+1|0}}do{if((r|0)==10){a[n]=0;if((a[o]|0)==0){break}else{t=o}do{t=t+1|0;}while((a[t]|0)!=0)}}while(0);t=XY(12)|0;o=(t|0)==0;do{if(!o){if((c[t-4>>2]&3|0)==0){break}X2(t|0,0,12)}}while(0);c[d+40>>2]=t;n=XY(12)|0;do{if((n|0)!=0){if((c[n-4>>2]&3|0)==0){break}X2(n|0,0,12)}}while(0);c[d+44>>2]=n;if(!o){o=t+8|0;n=t+4|0;m=c[n>>2]|0;if((c[o>>2]|0)>>>0<m>>>0){u=t}else{q=(m<<1)+2|0;c[n>>2]=q;n=t;c[n>>2]=X_(c[n>>2]|0,q*12|0)|0;u=n}n=dq(798256)|0;c[(c[u>>2]|0)+((c[o>>2]|0)*12|0)>>2]=n;c[(c[u>>2]|0)+((c[o>>2]|0)*12|0)+4>>2]=4;c[(c[u>>2]|0)+((c[o>>2]|0)*12|0)+8>>2]=0;c[o>>2]=(c[o>>2]|0)+1}c[d+48>>2]=0;il(l);o=c[199308]|0;do{if((o|0)==0){v=1.3333333730697632}else{if(!((c[198598]|0)==0|(c[198599]|0)==0)){v=1.3333333730697632;break}fc[c[(c[199305]|0)+44>>2]&127](o,794384);v=+((c[198598]|0)>>>0>>>0)/+((c[198599]|0)>>>0>>>0)}}while(0);g[4961]=v;c[58922]=l;if(b){b=c[198610]|0;l=(b|0)!=0?b:c[p>>2]|0;a2(72144,48,1,l|0)|0;l=c[198610]|0;b=(l|0)!=0?l:c[p>>2]|0;aY(b|0)|0;if((a[794445]&1)==0){b=c[198610]|0;l=(b|0)!=0?b:c[p>>2]|0;ec(l|0,63392,(w=i,i=i+16|0,c[w>>2]=62024,c[w+8>>2]=827,w)|0)|0;i=w;l=c[198610]|0;b=(l|0)!=0?l:c[p>>2]|0;aY(b|0)|0;cd(2);return 0}else{a[794447]=109;a[794448]=101;a[794449]=110;a[794450]=117;a[794451]=95;a[794452]=105;a[794453]=110;a[794454]=105;a[794455]=116;a[794456]=40;a[794457]=41;a[794458]=0;eC(795472,1);return 0}}X2(d|0,0,17);a[d+36|0]=1;c[d+113708>>2]=0;a[d+4172|0]=0;c[d+4168>>2]=65432;c[d+4164>>2]=55352;c[d+4160>>2]=46024;a[d+4173|0]=0;b=h|0;h=cg(535112,46)|0;l=(h|0)==0?798256:h+1|0;L44:do{if((cL(l|0,93544)|0)==0){r=32}else{if((cL(l|0,94616)|0)==0){r=32;break}do{if((cL(l|0,75176)|0)!=0){if((cL(l|0,55776)|0)==0){break}h=(a[543313]|0)!=0?543313:629148;gr(b,h,88912);o=gH(b,0)|0;if((o|0)==0){gr(b,h,88560);h=gH(b,0)|0;if((h|0)==0){break L44}else{x=h}}else{x=o}o=d+4180|0;if(h_(x,o)|0){h2(o,b)}gF(x);break L44}}while(0);o=4096;h=d+4256|0;u=535112;while(1){n=o-1|0;if((n|0)==0){r=41;break}q=a[u]|0;a[h]=q;if(q<<24>>24==0){break}else{o=n;h=h+1|0;u=u+1|0}}do{if((r|0)==41){a[h]=0;if((a[u]|0)==0){break}else{y=u}do{y=y+1|0;}while((a[y]|0)!=0)}}while(0);c[d+4252>>2]=1}}while(0);do{if((r|0)==32){y=gH(535112,0)|0;if((y|0)==0){break}x=d+4180|0;if(h_(y,x)|0){h2(x,535112)}gF(y)}}while(0);if((a[657930]|0)!=0){L74:do{if((a[608664]|0)==0){gB(j,657930,68648)}else{d=4096;y=j;x=608664;while(1){l=d-1|0;if((l|0)==0){break}u=a[x]|0;a[y]=u;if(u<<24>>24==0){break L74}else{d=l;y=y+1|0;x=x+1|0}}a[y]=0;if((a[x]|0)==0){break}else{z=x}do{z=z+1|0;}while((a[z]|0)!=0)}}while(0);if((a[637400]&1)!=0){z=c[198610]|0;x=(z|0)!=0?z:c[p>>2]|0;ec(x|0,67e3,(w=i,i=i+8|0,c[w>>2]=j,w)|0)|0;i=w;x=c[198610]|0;z=(x|0)!=0?x:c[p>>2]|0;aY(z|0)|0}z=c[153190]|0;x=XY(16)|0;do{if((x|0)==0){A=0}else{if((c[x-4>>2]&3|0)!=0){X2(x|0,0,16)}y=x;do{if((z|0)==0){B=0}else{d=z*12|0;if(z>>>0<=65535){B=d;break}B=((d>>>0)/(z>>>0)|0|0)==12?d:-1}}while(0);d=XY(B)|0;if((d|0)==0){c[x>>2]=0;it(y);A=0;break}if((c[d-4>>2]&3|0)==0){l=x;c[l>>2]=d;C=l}else{X2(d|0,0,B|0);l=x;c[l>>2]=d;C=l}l=x+8|0;c[l>>2]=z;d=f|0;u=c5(j|0,78048)|0;if((u|0)!=0){h=x+4|0;c[h>>2]=0;L104:do{if((c[l>>2]|0)!=0){o=f+4096|0;n=f+8192|0;do{a[d]=0;if((bX(d|0,4096,u|0)|0)==0){break L104}q=cg(d|0,10)|0;if((q|0)!=0){a[q]=0}a[o]=0;if((bX(o|0,4096,u|0)|0)==0){break L104}q=cg(o|0,10)|0;if((q|0)!=0){a[q]=0}a[n]=0;if((bX(n|0,4096,u|0)|0)==0){break L104}q=cg(n|0,10)|0;if((q|0)!=0){a[q]=0}q=c[h>>2]|0;t=c[C>>2]|0;if((a[o]|0)==0){break L104}if((a[n]|0)==0){break L104}if((a[d]|0)!=0){c[t+(q*12|0)>>2]=dq(d|0)|0}c[t+(q*12|0)+4>>2]=dq(o|0)|0;c[t+(q*12|0)+8>>2]=dq(n|0)|0;q=(c[h>>2]|0)+1|0;c[h>>2]=q;}while(q>>>0<(c[l>>2]|0)>>>0)}}while(0);aQ(u|0)|0}c[x+12>>2]=dq(j|0)|0;A=y}}while(0);c[(c[58922]|0)+113712>>2]=A}v=+a8()*1.0e3;A=+Q(v)>=1.0?v>0.0?(ag(+P(v/4294967296.0),4294967295.0)|0)>>>0:~~+aa((v- +(~~v>>>0))/4294967296.0)>>>0:0;x=(c[58922]|0)+113720|0;c[x>>2]=~~v>>>0;c[x+4>>2]=A;A=794432;x=c[A+4>>2]|0;C=794432;c[C>>2]=c[A>>2]|1;c[C+4>>2]=x;do{if((a[795517]&1)==0){L131:do{if((a[637436]&1)==0){x=4096;C=j;A=674314;while(1){f=x-1|0;if((f|0)==0){break}z=a[A]|0;a[C]=z;if(z<<24>>24==0){break L131}else{x=f;C=C+1|0;A=A+1|0}}a[C]=0;if((a[A]|0)==0){break}else{D=A}do{D=D+1|0;}while((a[D]|0)!=0)}else{bN(j|0,4096,91928,(w=i,i=i+8|0,c[w>>2]=670218,w)|0)|0;i=w}}while(0);L140:do{if((a[j]|0)!=0){y=4096;u=b;A=j;while(1){C=y-1|0;if((C|0)==0){r=99;break}x=a[A]|0;a[u]=x;if(x<<24>>24==0){break}else{y=C;u=u+1|0;A=A+1|0}}do{if((r|0)==99){a[u]=0;if((a[A]|0)==0){break}else{E=A}do{E=E+1|0;}while((a[E]|0)!=0)}}while(0);if((eA(b|0,j|0)|0)==0){F=4096;G=j;H=b}else{break}while(1){A=F-1|0;if((A|0)==0){break}u=a[H]|0;a[G]=u;if(u<<24>>24==0){break L140}else{F=A;G=G+1|0;H=H+1|0}}a[G]=0;if((a[H]|0)==0){break}else{I=H}do{I=I+1|0;}while((a[I]|0)!=0)}}while(0);A=c[(c[58922]|0)+113712>>2]|0;if((A|0)==0){break}is(A,(a[j]|0)!=0?j:0,c[182922]|0)}}while(0);eF(4488,((a[535088]&1)!=0?0:2147483647)|0,1);k=0;i=e;return k|0}function fT(){var b=0,e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0.0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0;b=i;i=i+8664|0;e=b|0;f=b+8|0;j=b+136|0;k=b+264|0;l=b+4360|0;m=b+8456|0;n=b+8464|0;o=b+8592|0;q=b+8656|0;if((a[731752]&1)!=0){a[731752]=0;r=c[58922]|0;if((a[r+4156|0]&1)!=0){XZ(c[r+4152>>2]|0)}s=c[r+40>>2]|0;t=s+8|0;u=s|0;v=c[u>>2]|0;if((c[t>>2]|0)==0){w=v}else{x=0;y=v;while(1){XZ(c[y+(x*12|0)>>2]|0);v=x+1|0;z=c[u>>2]|0;if(v>>>0<(c[t>>2]|0)>>>0){x=v;y=z}else{w=z;break}}}XZ(w);XZ(s);s=c[r+44>>2]|0;r=s+8|0;w=s|0;y=c[w>>2]|0;if((c[r>>2]|0)==0){A=y}else{x=0;t=y;while(1){XZ(c[t+(x*12|0)>>2]|0);y=x+1|0;u=c[w>>2]|0;if(y>>>0<(c[r>>2]|0)>>>0){x=y;t=u}else{A=u;break}}}XZ(A);XZ(s);it(c[(c[58922]|0)+113712>>2]|0);XZ(c[58922]|0);L173:do{if(!((a[794446]&1)==0|(a[657930]|0)==0)){s=o|0;A=gH(657930,0)|0;do{if((A|0)==0){t=XY(20)|0;if((t|0)==0){break L173}if((c[t-4>>2]&3|0)==0){B=t;break}else{X2(t|0,0,20);B=t;break}}else{B=A}}while(0);if((a[637400]&1)!=0){A=c[198610]|0;t=(A|0)!=0?A:c[p>>2]|0;ec(t|0,97496,(C=i,i=i+8|0,c[C>>2]=657930,C)|0)|0;i=C;t=c[198610]|0;A=(t|0)!=0?t:c[p>>2]|0;aY(A|0)|0}gK(B,32760,612764);gK(B,25864,616860);gK(B,28856,(a[633244]&1)!=0?98168:44720);A=c[158313]|0;t=n|0;bN(t|0,128,53432,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;gK(B,28184,t);gK(B,55760,535112);gK(B,54704,(a[539208]&1)!=0?98168:44720);D=+g[133775];bN(t|0,128,29648,(C=i,i=i+8|0,h[C>>3]=D,C)|0)|0;i=C;gK(B,58744,t);gK(B,60640,(a[535105]&1)!=0?98168:44720);gK(B,62848,(a[535096]&1)!=0?98168:44720);D=+g[135827];bN(t|0,128,29648,(C=i,i=i+8|0,h[C>>3]=D,C)|0)|0;i=C;gK(B,56784,t);gK(B,69424,(a[535088]&1)!=0?98168:44720);gK(B,68096,(a[535089]&1)!=0?98168:44720);A=c[133773]|0;bN(t|0,128,53432,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;gK(B,66304,t);A=c[133777]|0;bN(t|0,128,53432,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;gK(B,58080,t);gK(B,37856,551588);gK(B,36832,(a[559785]&1)!=0?98168:44720);D=+g[139947];bN(t|0,128,29648,(C=i,i=i+8|0,h[C>>3]=D,C)|0)|0;i=C;gK(B,36432,t);if((a[629148]|0)==0){gK(B,98400,41208)}else{gK(B,98400,629148)}if((a[707082]|0)==0){gK(B,101032,41208)}else{gK(B,101032,707082)}if((a[711178]|0)==0){gK(B,99496,41208)}else{gK(B,99496,711178)}if((a[543313]|0)==0){gK(B,41528,41208)}else{gK(B,41528,543313)}if((a[633281]|0)==0){gK(B,30808,41208)}else{gK(B,30808,633281)}if((a[715274]|0)==0){gK(B,30304,41208)}else{gK(B,30304,715274)}gK(B,29928,596368);D=+g[150116];bN(t|0,128,29648,(C=i,i=i+8|0,h[C>>3]=D,C)|0)|0;i=C;gK(B,29464,t);D=+g[150117];bN(t|0,128,29648,(C=i,i=i+8|0,h[C>>3]=D,C)|0)|0;i=C;gK(B,29160,t);gK(B,97072,(c[198603]|0)!=0?98168:44720);A=794432;if((c[A>>2]&16384|0)==0&(c[A+4>>2]&0|0)==0){gK(B,96688,44720)}else{gK(B,96688,98168)}A=794432;if((c[A>>2]&128|0)==0&(c[A+4>>2]&0|0)==0){gK(B,96208,44720)}else{gK(B,96208,98168)}A=794432;if((c[A>>2]&65536|0)==0&(c[A+4>>2]&0|0)==0){gK(B,95520,44720)}else{gK(B,95520,98168)}A=794432;if((c[A>>2]&32768|0)==0&(c[A+4>>2]&0|0)==0){gK(B,95056,44720)}else{gK(B,95056,98168)}A=d[794416]|0;bN(t|0,128,53432,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;gK(B,94544,t);A=d[794417]|0;bN(t|0,128,53432,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;gK(B,94232,t);A=c[198590]|0;bN(t|0,128,53432,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;gK(B,93864,t);A=c[198598]|0;bN(t|0,128,53432,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;gK(B,45472,t);A=c[198599]|0;bN(t|0,128,53432,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;gK(B,44888,t);A=c[198596]|0;bN(t|0,128,53432,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;gK(B,47744,t);A=c[198597]|0;bN(t|0,128,53432,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;gK(B,46592,t);D=+g[137877];bN(t|0,128,29648,(C=i,i=i+8|0,h[C>>3]=D,C)|0)|0;i=C;gK(B,52064,t);gK(B,19912,(a[794446]&1)!=0?98168:44720);A=c[198605]|0;bN(t|0,128,53432,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;gK(B,93456,t);A=c[182916]|0;bN(t|0,128,53432,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;gK(B,93048,t);A=a[736529]&1;bN(t|0,128,53432,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;gK(B,30112,t);A=c[198602]|0;bN(t|0,128,53432,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;gK(B,92368,t);A=794432;if((c[A>>2]&524288|0)==0&(c[A+4>>2]&0|0)==0){gK(B,91888,44720);E=0}else{gK(B,91888,98168);E=0}while(1){A=E+1|0;bN(s|0,64,91456,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;bN(t|0,128,53432,(C=i,i=i+8|0,c[C>>2]=c[596324+(E<<2)>>2],C)|0)|0;i=C;gK(B,s,t);bN(s|0,64,90920,(C=i,i=i+8|0,c[C>>2]=A,C)|0)|0;i=C;bN(t|0,128,53432,(C=i,i=i+8|0,c[C>>2]=c[595780+(E<<2)>>2],C)|0)|0;i=C;gK(B,s,t);if(A>>>0<8){E=A}else{break}}gL(B,657930)|0;gF(B)}}while(0);if((a[794444]&1)!=0){gc()}B=c[196481]|0;if((B|0)!=0){E=B+4|0;n=c[E>>2]|0;o=B|0;if(n>>>0>1){t=1;s=n;while(1){n=c[(c[o>>2]|0)+(t<<2)>>2]|0;if((n|0)==0){G=s}else{XZ(c[n+8>>2]|0);XZ(c[(c[o>>2]|0)+(t<<2)>>2]|0);c[(c[o>>2]|0)+(t<<2)>>2]=0;G=c[E>>2]|0}n=t+1|0;if(n>>>0<G>>>0){t=n;s=G}else{break}}}c[E>>2]=1;E=B+12|0;XZ(c[E>>2]|0);c[E>>2]=0;XZ(c[o>>2]|0);XZ(B);c[196481]=0}X2(535e3,0,102384);B=c[198610]|0;if((B|0)==0){X2(637400,0,158120);a[637402]=1;a[637401]=1;c[160384]=0;c[159351]=1;c[159352]=1;c[159353]=1;c[159354]=1;c[159355]=1;c[159356]=1;c[159357]=1;c[159358]=1;cd(0)}aQ(B|0)|0;X2(637400,0,158120);a[637402]=1;a[637401]=1;c[160384]=0;c[159351]=1;c[159352]=1;c[159353]=1;c[159354]=1;c[159355]=1;c[159356]=1;c[159357]=1;c[159358]=1;cd(0)}B=794432;o=c[B>>2]|0;E=c[B+4>>2]|0;if(a[7704]|0){if(!((o&32|0)==0&(E&0|0)==0)){B=c[58922]|0;a[B+52|0]=1;G=794432;s=c[G+4>>2]|0;t=794432;c[t>>2]=c[G>>2]&-33;c[t+4>>2]=s;s=B|0;B=c[s+4>>2]|0;c[s>>2]=c[s>>2]|256;c[s+4>>2]=B}f_();if((c[199350]|0)!=0){do{if((a[797247]&1)==0){B=ft[c[(c[199306]|0)+12>>2]&63](c[199309]|0,51)|0;s=797408;if((c[s>>2]&0|B&1|0)==0&(c[s+4>>2]&524288|0)==0){H=0;break}if((a[237344]&1)!=0){H=1;break}s=c[199350]|0;B=s+28|0;t=c[B>>2]|0;G=s+20|0;c[G>>2]=t;n=c[s+12>>2]|0;A=s+16|0;c[A>>2]=n+(t*136|0);x=s+4|0;r=c[(c[x>>2]|0)+4>>2]|0;w=s|0;u=c[w>>2]|0;y=c[n+(t*136|0)+8>>2]|0;z=c[n+(t*136|0)+12>>2]|0;v=c[n+(t*136|0)+16>>2]|0;fx[r&15](u,y,z,v)|0;v=c[A>>2]|0;fg[c[(c[x>>2]|0)+12>>2]&7](c[w>>2]|0,+g[v+24>>2],+g[v+28>>2],+g[v+32>>2],+g[v+36>>2]);fc[c[(c[x>>2]|0)+16>>2]&127](c[w>>2]|0,(a[(c[A>>2]|0)+68|0]&1)!=0);a[s+9|0]=1;c[B>>2]=(((c[G>>2]|0)+1|0)>>>0)%((c[s+24>>2]|0)>>>0)|0;H=1}else{H=0}}while(0);a[237344]=H}if((a[797247]&1)==0){H=ft[c[(c[199306]|0)+12>>2]&63](c[199309]|0,30)|0;s=797408;if((c[s>>2]&1073741824|H&1|0)==0&(c[s+4>>2]&0|0)==0){I=184}else{I=185}}else{I=184}do{if((I|0)==184){if(fe[c[(c[199305]|0)+12>>2]&127](c[199308]|0)|0){J=0;K=0;L=0}else{I=185;break}do{s=c[2080+(L<<2)>>2]|0;if((fd[c[(c[199306]|0)+8>>2]&15](c[199309]|0,2144,0,1,0,s)|0)<<16>>16==0){M=0;N=0}else{H=Yg(1,0,c[2080+((L|1)<<2)>>2]|0)|0;G=F;M=G;N=H}H=797408;G=c[H>>2]|0;B=c[H+4>>2]|0;H=Yg(1,0,s|0)|0;s=F;if((G&H|0)==0&(B&s|0)==0){O=0;R=0}else{s=Yg(1,0,c[2080+((L|1)<<2)>>2]|0)|0;B=F;O=B;R=s}K=N|K|R;J=M|J|O;L=L+2|0;}while(L>>>0<16);if((a[797247]&1)==0){s=ft[c[(c[199306]|0)+12>>2]&63](c[199309]|0,55)|0;B=797408;H=(c[B>>2]&0|s&1|0)!=0|(c[B+4>>2]&8388608|0)!=0;S=H?0:0;T=H?256:0}else{S=0;T=0}H=T|K;B=S|J;s=c[58922]|0;G=s|0;A=B&~c[G+4>>2];w=s+8|0;c[w>>2]=H&~c[G>>2];c[w+4>>2]=A;do{if((K&15|0)==0&(J&0|0)==0){a[s+16|0]=0;I=200}else{A=((H>>>8|B<<24)&1^1)&255;a[s+16|0]=A;if((A&1)==0){I=200;break}if(!(a[7720]|0)){a[7720]=1;c[s+20>>2]=a[7712]|0?6:12;c[s+24>>2]=0;U=1;V=0;break}A=c[s+24>>2]|0;if(A>>>0<(c[s+20>>2]|0)>>>0){U=1;V=A;break}a[7720]=0;c[w>>2]=H;c[w+4>>2]=B;U=1;V=A}}while(0);if((I|0)==200){a[7720]=0;U=0;V=c[s+24>>2]|0}a[7712]=U;c[s+24>>2]=V+1;c[G>>2]=H;c[G+4>>2]=B;w=im(s)|0;A=c[199354]|0;do{if((A|0)!=0){x=c[A+24>>2]|0;if((x|0)==0){break}fy[x&511](c[199308]|0,(a[(c[58922]|0)+36|0]&1)!=0,0)}}while(0);fW();D=+a8()*1.0e3;A=+Q(D)>=1.0?D>0.0?(ag(+P(D/4294967296.0),4294967295.0)|0)>>>0:~~+aa((D- +(~~D>>>0))/4294967296.0)>>>0:0;s=(c[58922]|0)+113720|0;B=Yf(~~D>>>0,A,c[s>>2]|0,c[s+4>>2]|0)|0;s=Ym(B,F,1e3,0)|0;B=F;D=750.0/+g[135827];A=Yf(~~D>>>0,+Q(D)>=1.0?D>0.0?(ag(+P(D/4294967296.0),4294967295.0)|0)>>>0:~~+aa((D- +(~~D>>>0))/4294967296.0)>>>0:0,s,B)|0;B=F;s=0;if((B|0)>(s|0)|(B|0)==(s|0)&A>>>0>0>>>0){s=A;A=m;c[m>>2]=0;c[m+4>>2]=0;c[m>>2]=(s>>>0)/1e3|0;c[A+4>>2]=((s>>>0)%1e3|0)*1e6|0;df(A|0,0)|0}D=+a8()*1.0e3;A=+Q(D)>=1.0?D>0.0?(ag(+P(D/4294967296.0),4294967295.0)|0)>>>0:~~+aa((D- +(~~D>>>0))/4294967296.0)>>>0:0;s=c[58922]|0;B=s+113720|0;c[B>>2]=~~D>>>0;c[B+4>>2]=A;A=c[199354]|0;do{if((A|0)==0){W=s}else{B=c[A+24>>2]|0;if((B|0)==0){W=s;break}fy[B&511](c[199308]|0,0,0);W=c[58922]|0}}while(0);s=W+8|0;do{if((c[s>>2]&256|0)==0&(c[s+4>>2]&0|0)==0){X=0}else{if((a[794444]&1)==0){X=0;break}if((a[795517]&1)!=0){X=0;break}A=794432;B=c[A+4>>2]|0;G=794432;c[G>>2]=c[A>>2]|65;c[G+4>>2]=B;X=-1}}while(0);s=794432;B=c[s>>2]|0;G=c[s+4>>2]|0;if(!((B&64|0)==0&(G&0|0)==0)){s=794432;c[s>>2]=B&-65;c[s+4>>2]=G|0}do{if((X|0)<0){G=c[W+40>>2]|0;s=c[G+8>>2]|0;if((s|0)==0){Y=0;Z=W;_=G;$=0}else{B=c[(c[G>>2]|0)+((s-1|0)*12|0)+4>>2]|0;if((B|0)==4){break}else{Y=B;Z=W;_=G;$=s}}while(1){s=Z+48|0;G=_+8|0;if(($|0)!=0){B=$-1|0;c[G>>2]=B;XZ(c[(c[_>>2]|0)+(B*12|0)>>2]|0)}if((s|0)!=0){c[s>>2]=c[(c[_>>2]|0)+((c[G>>2]|0)*12|0)+8>>2]}G=c[58922]|0;s=c[G+40>>2]|0;B=c[s+8>>2]|0;if((B|0)==0){ab=Y}else{ab=c[(c[s>>2]|0)+((B-1|0)*12|0)+4>>2]|0}if((ab|0)==4){break}else{Y=ab;Z=G;_=s;$=B}}}}while(0);if((X|w|0)!=0){break}i=b;return}}while(0);if((I|0)==185){X=794432;$=c[X+4>>2]|0;_=794432;c[_>>2]=c[X>>2]|1;c[_+4>>2]=$}a[7704]=0;$=(a[797248]&1)!=0;_=c[199308]|0;if((a[637402]&1)!=0&(_|0)!=0){if((a[535088]&1)==0){I=229}else{if((a[731765]&1)==0){ac=$}else{I=229}}if((I|0)==229){ac=1}fc[c[(c[199305]|0)+8>>2]&127](_,ac)}ac=c[199307]|0;if((a[637401]&1)!=0&(ac|0)!=0){fc[c[(c[199304]|0)+16>>2]&127](ac,(a[555688]&1)==0|$);ad=c[199307]|0}else{ad=ac}c[184126]=$?c[184127]|0:c[184128]|0;do{if((ad|0)!=0){if(fe[c[(c[199304]|0)+12>>2]&127](ad)|0){break}$=c[198610]|0;ac=($|0)!=0?$:c[p>>2]|0;a2(23104,81,1,ac|0)|0;ac=c[198610]|0;$=(ac|0)!=0?ac:c[p>>2]|0;aY($|0)|0;a[637401]=0}}while(0);ad=794432;$=c[ad+4>>2]|0;ac=794432;c[ac>>2]=c[ad>>2]&-5;c[ac+4>>2]=$;i=b;return}if((o&2|0)==0&(E&0|0)==0){if((o&1|0)==0&(E&0|0)==0){if((o&4|0)==0&(E&0|0)==0){a[731752]=1;i=b;return}$=794432;c[$>>2]=o|32;c[$+4>>2]=E;fc[c[(c[199305]|0)+8>>2]&127](c[199308]|0,0);$=c[199307]|0;if(($|0)!=0){ac=c[(c[199304]|0)+8>>2]|0;fe[ac&127]($)|0}a[7704]=1;i=b;return}do{if((a[794147]&1)==0){I=295}else{if((a[794148]&1)!=0){I=295;break}if((a[797247]&1)==0){$=ft[c[(c[199306]|0)+12>>2]&63](c[199309]|0,30)|0;ac=797408;if(!((c[ac>>2]&1073741824|$&1|0)==0&(c[ac+4>>2]&0|0)==0)){break}}if(!(fe[c[(c[199305]|0)+12>>2]&127](c[199308]|0)|0)){break}ga();f_();ac=q;c[q>>2]=0;c[q+4>>2]=0;c[q>>2]=0;c[ac+4>>2]=1e7;df(ac|0,0)|0;i=b;return}}while(0);L367:do{if((I|0)==295){if((a[797247]&1)==0){q=ft[c[(c[199306]|0)+12>>2]&63](c[199309]|0,30)|0;ac=797408;if(!((c[ac>>2]&1073741824|q&1|0)==0&(c[ac+4>>2]&0|0)==0)){break}}if(!(fe[c[(c[199305]|0)+12>>2]&127](c[199308]|0)|0)){break}do{if((a[797247]&1)==0){ac=ft[c[(c[199306]|0)+12>>2]&63](c[199309]|0,55)|0;q=797408;if((c[q>>2]&0|ac&1|0)==0&(c[q+4>>2]&8388608|0)==0){I=301;break}ae=a[17352]|0;I=303}else{I=301}}while(0);do{if((I|0)==301){if((a[795517]&1)==0){af=0;break}w=a[17352]|0;if((w&1)==0){ae=w;I=303}else{af=0}}}while(0);do{if((I|0)==303){if((ae&1)!=0){af=1;break}w=794432;q=c[w+4>>2]|0;ac=794432;c[ac>>2]=c[w>>2]|4;c[ac+4>>2]=q;a[17352]=1;q=736472;c[q>>2]=0;c[q+4>>2]=0;break L367}}while(0);a[17352]=af;ga();q=c[196486]|0;if((q|0)!=0){ac=cb(c[q>>2]|0)|0;c[(c[q+12>>2]|0)+(c[q+20>>2]<<2)>>2]=ac}if((c[184114]|0)!=0){D=+a8()*1.0e3;ac=~~D>>>0;q=+Q(D)>=1.0?D>0.0?(ag(+P(D/4294967296.0),4294967295.0)|0)>>>0:~~+aa((D- +(~~D>>>0))/4294967296.0)>>>0:0;do{if((a[794147]&1)==0){w=(a[797248]&1)!=0;$=736472;ad=c[$>>2]|0;_=c[$+4>>2]|0;$=(ad|0)==0&(_|0)==0|w;X=736464;Z=c[X>>2]|0;ab=c[X+4>>2]|0;X=Yf(ac,q,ad,_)|0;_=$?Z:X;X=$?ab:F;if(w){ah=X;ai=_;aj=0;ak=0;break}if((a[794149]&1)==0){ah=X;ai=_;aj=q;ak=ac;break}D=(+(_>>>0)+ +(X|0)*4294967296.0)/+g[158314];ah=+Q(D)>=1.0?D>0.0?(ag(+P(D/4294967296.0),4294967295.0)|0)>>>0:~~+aa((D- +(~~D>>>0))/4294967296.0)>>>0:0;ai=~~D>>>0;aj=q;ak=ac}else{X=736464;ah=c[X+4>>2]|0;ai=c[X>>2]|0;aj=0;ak=0}}while(0);ac=736472;c[ac>>2]=ak;c[ac+4>>2]=aj;fc[c[184114]&127](ai,ah)}fz[c[59482]&8191]();do{if(+g[158315]>=0.0){D=+a8()*1.0e3;ac=+Q(D)>=1.0?D>0.0?(ag(+P(D/4294967296.0),4294967295.0)|0)>>>0:~~+aa((D- +(~~D>>>0))/4294967296.0)>>>0:0;q=731680;X=731672;_=c[X>>2]|0;w=c[X+4>>2]|0;X=Yf(c[q>>2]|0,c[q+4>>2]|0,~~D>>>0,ac)|0;ac=Ye(X,F,_,w)|0;w=F;_=0;if((w|0)>(_|0)|(w|0)==(_|0)&ac>>>0>999>>>0){_=Ym(ac,w,1e3,0)|0;w=_;_=e;c[e>>2]=0;c[e+4>>2]=0;c[e>>2]=(w>>>0)/1e3|0;c[_+4>>2]=((w>>>0)%1e3|0)*1e6|0;df(_|0,0)|0;_=731672;w=731680;ac=Ye(c[w>>2]|0,c[w+4>>2]|0,c[_>>2]|0,c[_+4>>2]|0)|0;_=731680;c[_>>2]=ac;c[_+4>>2]=F;break}else{D=+a8()*1.0e3;_=+Q(D)>=1.0?D>0.0?(ag(+P(D/4294967296.0),4294967295.0)|0)>>>0:~~+aa((D- +(~~D>>>0))/4294967296.0)>>>0:0;ac=731680;c[ac>>2]=~~D>>>0;c[ac+4>>2]=_;break}}}while(0);_=c[196486]|0;if((_|0)==0){i=b;return}ac=_+20|0;c[ac>>2]=(c[ac>>2]|0)+1&c[_+16>>2];ac=_+33|0;a[_+32|0]=a[ac]&1^1;a[ac]=0;i=b;return}}while(0);e=794432;ah=c[e+4>>2]|0;ai=794432;c[ai>>2]=c[e>>2]&-2;c[ai+4>>2]=ah;i=b;return}ah=k|0;k=l|0;L408:do{if((a[674314]|0)==0){l=c[58922]|0;if((a[l+4176|0]&1)==0){al=l}else{I=248}}else{if((o&128|0)==0&(E&0|0)==0){I=248;break}gz(ah,674314,4096);bN(k|0,4096,88416,(C=i,i=i+8|0,c[C>>2]=ah,C)|0)|0;i=C;l=c[196481]|0;ai=l+4|0;if((c[ai>>2]|0)>>>0>=(c[l+8>>2]|0)>>>0){I=248;break}e=XY(12)|0;do{if((e|0)!=0){if((c[e-4>>2]&3|0)==0){break}X2(e|0,0,12)}}while(0);c[e+4>>2]=1;c[e>>2]=1;aj=dq(k|0)|0;ak=c[ai>>2]|0;c[e+8>>2]=aj;aj=l|0;c[(c[aj>>2]|0)+(ak<<2)>>2]=e;ak=c[ai>>2]|0;c[ai>>2]=ak+1;if(ak>>>0>1){am=ak}else{I=248;break}while(1){ak=am>>>1;af=c[aj>>2]|0;ae=af+(ak<<2)|0;ac=c[ae>>2]|0;_=c[af+(am<<2)>>2]|0;if((c[_+4>>2]|0)>>>0<=(c[ac+4>>2]|0)>>>0){I=248;break L408}c[ae>>2]=_;c[(c[aj>>2]|0)+(am<<2)>>2]=ac;if(am>>>0>3){am=ak}else{I=248;break}}}}while(0);do{if((I|0)==248){am=c[58922]|0;E=c[am+4160>>2]|0;o=c[am+113712>>2]|0;if((o|0)==0){al=am;break}is(o,(a[674314]|0)!=0?674314:0,(E|0)==0?798256:E);al=c[58922]|0}}while(0);X2(al|0,0,17);a[al+53|0]=1;im(al)|0;al=c[199354]|0;do{if((al|0)!=0){I=c[al+24>>2]|0;if((I|0)==0){break}fy[I&511](c[199308]|0,(a[(c[58922]|0)+36|0]&1)!=0,0)}}while(0);if((c[199305]|0)!=0){fW()}al=c[199354]|0;do{if((al|0)!=0){I=c[al+24>>2]|0;if((I|0)==0){break}fy[I&511](c[199308]|0,0,0)}}while(0);if((a[794444]&1)!=0){gc()}al=a[637400]&1;I=(a[657930]|0)!=0;E=I?657930:0;o=(a[707082]|0)!=0;am=o?707082:0;aj=(a[711178]|0)!=0;ai=aj?711178:0;e=(a[674314]|0)!=0;l=e?674314:0;ak=(c[58922]|0)+4176|0;ac=a[ak]&1;a[ak]=0;ak=f;_=j;if((a[794444]&1)!=0){gc()}X2(ak|0,0,128);ae=f|0;c[ae>>2]=dq(43360)|0;do{if(ac<<24>>24==0){af=(a[637400]&1)!=0;if(e){if(af){w=c[198610]|0;X=(w|0)!=0?w:c[p>>2]|0;ec(X|0,42648,(C=i,i=i+8|0,c[C>>2]=l,C)|0)|0;i=C;X=c[198610]|0;w=(X|0)!=0?X:c[p>>2]|0;aY(w|0)|0}c[f+4>>2]=dq(l|0)|0;an=2;break}else{if(af){af=c[198610]|0;w=(af|0)!=0?af:c[p>>2]|0;a2(42096,40,1,w|0)|0;w=c[198610]|0;af=(w|0)!=0?w:c[p>>2]|0;aY(af|0)|0}c[f+4>>2]=dq(41424)|0;an=2;break}}else{an=1}}while(0);if(o){c[f+(an<<2)>>2]=dq(41120)|0;c[f+(an+1<<2)>>2]=dq(am|0)|0;ao=an+2|0}else{ao=an}if(aj){c[f+(ao<<2)>>2]=dq(40576)|0;c[f+(ao+1<<2)>>2]=dq(ai|0)|0;ap=ao+2|0}else{ap=ao}if(I){c[f+(ap<<2)>>2]=dq(39568)|0;c[f+(ap+1<<2)>>2]=dq(E|0)|0;aq=ap+2|0}else{aq=ap}if(al<<24>>24==0){ar=aq}else{c[f+(aq<<2)>>2]=dq(38976)|0;ar=aq+1|0}X5(_|0,ak|0,128)|0;ak=f9(ar,ae)|0;ae=0;do{XZ(c[j+(ae<<2)>>2]|0);ae=ae+1|0;}while(ae>>>0<32);if((ak|0)==0){if((a[637400]&1)!=0){ak=c[198610]|0;ae=(ak|0)!=0?ak:c[p>>2]|0;a2(81888,45,1,ae|0)|0;ae=c[198610]|0;ak=(ae|0)!=0?ae:c[p>>2]|0;aY(ak|0)|0}ak=794432;ae=c[ak+4>>2]|0|0;j=794432;c[j>>2]=c[ak>>2]&-4|1;c[j+4>>2]=ae;i=b;return}gz(ah,674314,4096);bN(k|0,4096,78424,(C=i,i=i+8|0,c[C>>2]=ah,C)|0)|0;i=C;C=c[196481]|0;ah=C+4|0;L475:do{if((c[ah>>2]|0)>>>0<(c[C+8>>2]|0)>>>0){ae=XY(12)|0;do{if((ae|0)!=0){if((c[ae-4>>2]&3|0)==0){break}X2(ae|0,0,12)}}while(0);c[ae+4>>2]=1;c[ae>>2]=90;j=dq(k|0)|0;ak=c[ah>>2]|0;c[ae+8>>2]=j;j=C|0;c[(c[j>>2]|0)+(ak<<2)>>2]=ae;ak=c[ah>>2]|0;c[ah>>2]=ak+1;if(ak>>>0>1){as=ak}else{break}while(1){ak=as>>>1;ar=c[j>>2]|0;_=ar+(ak<<2)|0;aq=c[_>>2]|0;f=c[ar+(as<<2)>>2]|0;if((c[f+4>>2]|0)>>>0<=(c[aq+4>>2]|0)>>>0){break L475}c[_>>2]=f;c[(c[j>>2]|0)+(as<<2)>>2]=aq;if(as>>>0>3){as=ak}else{break}}}}while(0);a[(c[58922]|0)+53|0]=1;as=c[198610]|0;a2(75200,52,1,((as|0)!=0?as:c[p>>2]|0)|0)|0;as=c[198610]|0;aY(((as|0)!=0?as:c[p>>2]|0)|0)|0;i=b;return}function fU(a,d){a=a|0;d=d|0;var e=0,f=0,g=0,h=0;e=d<<1;if((e|0)==0){return d|0}else{f=0}do{g=b[a+(f<<1)>>1]|0;h=(c[184136]|0)-1|0;c[184136]=h;b[(c[184135]|0)+(h<<1)>>1]=g;f=f+1|0;}while(f>>>0<e>>>0);return d|0}function fV(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0;b=i;i=i+24|0;d=b|0;if((a[625052]|0)==0){i=b;return}do{if((a[551539]&1)!=0|(c[184103]|0)!=0){e=c[199305]|0;if((c[e+48>>2]|0)==0){f=358;break}g=e+44|0;if((c[g>>2]|0)==0){f=358;break}X2(d|0,0,24);fc[c[g>>2]&127](c[199308]|0,d);g=d+8|0;e=c[g>>2]|0;if((e|0)==0){f=363;break}h=d+12|0;j=c[h>>2]|0;if((j|0)==0){f=363;break}k=XY(ab(e*3|0,j)|0)|0;if((k|0)==0){f=363;break}if(ft[c[(c[199305]|0)+48>>2]&63](c[199308]|0,k)|0){j=c[g>>2]|0;g=hw(k,j,c[h>>2]|0,j*3|0,1)|0;XZ(k);if(g){f=361;break}else{f=363;break}}else{XZ(k);f=363;break}}else{f=358}}while(0);do{if((f|0)==358){d=c[198547]|0;k=d;if((k|0)==(-1|0)|(k|0)==0){k=c[198610]|0;g=(k|0)!=0?k:c[p>>2]|0;a2(101320,103,1,g|0)|0;g=c[198610]|0;k=(g|0)!=0?g:c[p>>2]|0;aY(k|0)|0;f=363;break}else{k=c[198548]|0;g=c[198549]|0;j=c[198550]|0;if(hw(d+(ab(g-1|0,j)|0)|0,k,g,-j|0,0)|0){f=361;break}else{f=363;break}}}}while(0);do{if((f|0)==361){if((a[637400]&1)==0){l=69e3;break}j=c[198610]|0;g=(j|0)!=0?j:c[p>>2]|0;a2(92592,30,1,g|0)|0;g=c[198610]|0;j=(g|0)!=0?g:c[p>>2]|0;aY(j|0)|0;l=69e3}else if((f|0)==363){j=c[198610]|0;a2(57272,50,1,((j|0)!=0?j:c[p>>2]|0)|0)|0;j=c[198610]|0;aY(((j|0)!=0?j:c[p>>2]|0)|0)|0;l=48432}}while(0);j=c[196481]|0;g=j+4|0;k=c[g>>2]|0;if(k>>>0>1){d=j|0;h=1;e=k;while(1){k=c[(c[d>>2]|0)+(h<<2)>>2]|0;if((k|0)==0){m=e}else{XZ(c[k+8>>2]|0);XZ(c[(c[d>>2]|0)+(h<<2)>>2]|0);c[(c[d>>2]|0)+(h<<2)>>2]=0;m=c[g>>2]|0}k=h+1|0;if(k>>>0<m>>>0){h=k;e=m}else{break}}}c[g>>2]=1;g=j+12|0;XZ(c[g>>2]|0);c[g>>2]=0;g=c[196481]|0;j=g+4|0;m=(c[j>>2]|0)>>>0<(c[g+8>>2]|0)>>>0;if((a[794147]&1)!=0){L526:do{if(m){e=XY(12)|0;do{if((e|0)!=0){if((c[e-4>>2]&3|0)==0){break}X2(e|0,0,12)}}while(0);c[e+4>>2]=1;c[e>>2]=1;h=dq(l|0)|0;d=c[j>>2]|0;c[e+8>>2]=h;h=g|0;c[(c[h>>2]|0)+(d<<2)>>2]=e;d=c[j>>2]|0;c[j>>2]=d+1;if(d>>>0>1){n=d}else{break}while(1){d=n>>>1;k=c[h>>2]|0;o=k+(d<<2)|0;q=c[o>>2]|0;r=c[k+(n<<2)>>2]|0;if((c[r+4>>2]|0)>>>0<=(c[q+4>>2]|0)>>>0){break L526}c[o>>2]=r;c[(c[h>>2]|0)+(n<<2)>>2]=q;if(n>>>0>3){n=d}else{break}}}}while(0);fW();i=b;return}if(!m){i=b;return}m=XY(12)|0;do{if((m|0)!=0){if((c[m-4>>2]&3|0)==0){break}X2(m|0,0,12)}}while(0);c[m+4>>2]=1;c[m>>2]=180;n=dq(l|0)|0;l=c[j>>2]|0;c[m+8>>2]=n;n=g|0;c[(c[n>>2]|0)+(l<<2)>>2]=m;m=c[j>>2]|0;c[j>>2]=m+1;if(m>>>0>1){s=m}else{i=b;return}while(1){m=s>>>1;j=c[n>>2]|0;l=j+(m<<2)|0;g=c[l>>2]|0;h=c[j+(s<<2)>>2]|0;if((c[h+4>>2]|0)>>>0<=(c[g+4>>2]|0)>>>0){f=387;break}c[l>>2]=h;c[(c[n>>2]|0)+(s<<2)>>2]=g;if(s>>>0>3){s=m}else{f=388;break}}if((f|0)==387){i=b;return}else if((f|0)==388){i=b;return}}function fW(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0;b=c[198547]|0;d=(b|0)==-1?0:b;b=c[198548]|0;e=c[198549]|0;f=c[198550]|0;if((a[637402]&1)==0){return}c[198547]=d;c[198548]=b;c[198549]=e;c[198550]=f;do{if((c[182940]|0)==0){g=d;if((g|0)==(-1|0)|(g|0)==0){h=d;i=f;break}c[199316]=b;c[199317]=e;c[199319]=b;c[199320]=e;c[199318]=f;c[199321]=b<<1;hV(797264,c[199348]|0,d);h=c[199348]|0;i=c[199321]|0}else{h=d;i=f}}while(0);f=hc(c[196481]|0)|0;c[199355]=f;if(fd[c[(c[199305]|0)+4>>2]&15](c[199308]|0,h,b,e,i,f)|0){return}a[637402]=0;return}function fX(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0;if((a[637402]&1)==0){return}c[198547]=b;c[198548]=d;c[198549]=e;c[198550]=f;do{if((c[182940]|0)==0){g=b;if((g|0)==(-1|0)|(g|0)==0){h=b;i=f;break}c[199316]=d;c[199317]=e;c[199319]=d;c[199320]=e;c[199318]=f;c[199321]=d<<1;hV(797264,c[199348]|0,b);h=c[199348]|0;i=c[199321]|0}else{h=b;i=f}}while(0);f=hc(c[196481]|0)|0;c[199355]=f;if(fd[c[(c[199305]|0)+4>>2]&15](c[199308]|0,h,d,e,i,f)|0){return}a[637402]=0;return}function fY(b,c){b=b|0;c=c|0;var d=0,e=0;d=c>>>0>1024?1024:c;if(fZ(b,d<<1)|0){e=a[637401]&1}else{e=0}a[637401]=e;return d|0}function fZ(d,e){d=d|0;e=e|0;var f=0,j=0,k=0,l=0,m=0.0,n=0,o=0,q=0.0,r=0,s=0;f=i;i=i+24|0;j=f|0;if((a[794147]&1)!=0){k=1;i=f;return k|0}if((a[736529]&1)!=0){k=1;i=f;return k|0}if((a[637401]&1)==0){k=0;i=f;return k|0}X2(j|0,0,24);l=c[184124]|0;m=+g[184146]*30517578125.0e-15;if((e|0)==0){n=l}else{o=0;do{g[l+(o<<2)>>2]=m*+(b[d+(o<<1)>>1]|0);o=o+1|0;}while(o>>>0<e>>>0);n=c[184124]|0}c[j>>2]=n;c[j+8>>2]=e>>>1;c[j+4>>2]=c[184133];if((a[736564]&1)==0){q=+h[92065]}else{e=fe[c[(c[199304]|0)+32>>2]&127](c[199307]|0)|0;n=769360;o=c[n>>2]|0;d=Ye(o,c[n+4>>2]|0,1,0)|0;n=769360;c[n>>2]=d;c[n+4>>2]=F;c[736592+((o&8191)<<2)>>2]=e;o=(c[184144]|0)>>>1;m=+h[92071]*(+(e-o|0)/+(o|0)*+g[139947]+1.0);h[92065]=m;q=m}o=j+16|0;h[o>>3]=q;if((a[794149]&1)!=0){h[o>>3]=q*+g[158314]}fc[c[(c[184123]|0)+4>>2]&127](c[184122]|0,j);o=c[184133]|0;e=c[j+12>>2]|0;if((a[736528]&1)!=0){if((fi[c[(c[199304]|0)+4>>2]&63](c[199307]|0,o,e<<3)|0)>=0){k=1;i=f;return k|0}j=c[198610]|0;n=(j|0)!=0?j:c[p>>2]|0;a2(59576,81,1,n|0)|0;n=c[198610]|0;j=(n|0)!=0?n:c[p>>2]|0;aY(j|0)|0;k=0;i=f;return k|0}j=c[184134]|0;n=e<<1;if((n|0)==0){r=j}else{d=0;do{l=~~(+g[o+(d<<2)>>2]*32768.0);if((l|0)>32767){s=32767}else{s=(l|0)<-32768?-32768:l&65535}b[j+(d<<1)>>1]=s;d=d+1|0;}while(d>>>0<n>>>0);r=c[184134]|0}if((fi[c[(c[199304]|0)+4>>2]&63](c[199307]|0,r,e<<2)|0)>=0){k=1;i=f;return k|0}e=c[198610]|0;a2(59576,81,1,((e|0)!=0?e:c[p>>2]|0)|0)|0;e=c[198610]|0;aY(((e|0)!=0?e:c[p>>2]|0)|0)|0;k=0;i=f;return k|0}function f_(){var b=0,d=0,e=0,f=0,h=0,i=0,j=0,k=0,l=0.0,m=0.0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0.0,A=0.0,B=0,C=0,D=0,E=0,F=0,G=0;fb[c[(c[199306]|0)+4>>2]&127](c[199309]|0);b=c[199350]|0;if((b|0)==0){return}d=797408;c[d>>2]=0;c[d+4>>2]=0;d=(a[(c[b+16>>2]|0)+68|0]&1)!=0?65542:6;if((fd[c[(c[199306]|0)+8>>2]&15](c[199309]|0,0,0,d,0,2)|0)<<16>>16==0){a[(c[199350]|0)+9|0]=0;return}else{e=0}do{b=fd[c[(c[199306]|0)+8>>2]&15](c[199309]|0,0,0,d,e,0)|0;f=fd[c[(c[199306]|0)+8>>2]&15](c[199309]|0,0,0,d,e,1)|0;h=c[199350]|0;L631:do{if((a[h+8|0]&1)==0){a[h+9|0]=0;i=0;j=0}else{k=c[h+16>>2]|0;l=(+((b<<16>>16)+32767|0)/65535.0- +g[k+24>>2])/+g[k+32>>2];m=(+((f<<16>>16)+32767|0)/65535.0- +g[k+28>>2])/+g[k+36>>2];n=k+4|0;o=c[n>>2]|0;do{if((o|0)==0){p=h+9|0}else{q=h+28|0;r=k|0;s=0;t=0;u=0;v=o;while(1){w=c[r>>2]|0;x=w+(u*104|0)|0;y=c[w+(u*104|0)+8>>2]|0;do{if((y|0)==0){z=(l- +g[x>>2])/+g[w+(u*104|0)+12>>2];A=(m- +g[w+(u*104|0)+4>>2])/+g[w+(u*104|0)+16>>2];if(z*z+A*A>1.0){B=s;C=t;D=v}else{E=455}}else if((y|0)==1){A=+Q(+(l- +g[x>>2]));if(A>+g[w+(u*104|0)+12>>2]){B=s;C=t;D=v;break}A=+Q(+(m- +g[w+(u*104|0)+4>>2]));if(A>+g[w+(u*104|0)+16>>2]){B=s;C=t;D=v}else{E=455}}else{B=s;C=t;D=v}}while(0);do{if((E|0)==455){E=0;x=w+(u*104|0)+24|0;y=c[x>>2]|0;F=c[x+4>>2]|0;x=y|t;G=F|s;if((y&0|0)==0&(F&524288|0)==0){B=G;C=x;D=v;break}c[q>>2]=c[w+(u*104|0)+32>>2];B=G;C=x;D=c[n>>2]|0}}while(0);w=u+1|0;if(w>>>0<D>>>0){s=B;t=C;u=w;v=D}else{break}}v=h+9|0;if((C|0)==0&(B|0)==0){p=v;break}u=(a[v]&1)==0;i=u?B:0;j=u?C:0;break L631}}while(0);a[p]=0;i=0;j=0}}while(0);h=797408;f=c[h+4>>2]|i;b=797408;c[b>>2]=c[h>>2]|j;c[b+4>>2]=f;e=e+1|0;}while((fd[c[(c[199306]|0)+8>>2]&15](c[199309]|0,0,0,d,e,2)|0)<<16>>16!=0);return}function f$(){var a=0,b=0,d=0;a=i;if((c[196481]|0)!=0){i=a;return}b=XY(16)|0;do{if((b|0)!=0){if((c[b-4>>2]&3|0)!=0){X2(b|0,0,16)}c[b+8>>2]=9;d=XY(36)|0;if((d|0)==0){c[b>>2]=0;XZ(b);break}if((c[d-4>>2]&3|0)!=0){X2(d|0,0,36)}c[b>>2]=d;c[b+4>>2]=1;c[196481]=b;i=a;return}}while(0);c[196481]=0;a=c[198610]|0;ec(((a|0)!=0?a:c[p>>2]|0)|0,63392,(a=i,i=i+16|0,c[a>>2]=36312,c[a+8>>2]=1398,a)|0)|0;i=a;a=c[198610]|0;aY(((a|0)!=0?a:c[p>>2]|0)|0)|0;cd(2)}function f0(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;b=i;if((a[633244]&1)==0|(c[196482]|0)!=0){i=b;return}if((c[184095]|0)!=0){d=c[198610]|0;e=(d|0)!=0?d:c[p>>2]|0;a2(31632,76,1,e|0)|0;e=c[198610]|0;d=(e|0)!=0?e:c[p>>2]|0;aY(d|0)|0;i=b;return}d=fw[c[59478]&31]()|0;c[196484]=d;if((d|0)==0){e=c[198610]|0;f=(e|0)!=0?e:c[p>>2]|0;a2(27712,85,1,f|0)|0;f=c[198610]|0;e=(f|0)!=0?f:c[p>>2]|0;aY(e|0)|0;i=b;return}e=d+3|0;f=e&-4;g=XY(f)|0;if((g|0)==0){c[196483]=0;h=c[198610]|0;j=(h|0)!=0?h:c[p>>2]|0;a2(23496,66,1,j|0)|0;j=c[198610]|0;h=(j|0)!=0?j:c[p>>2]|0;aY(h|0)|0;i=b;return}if((c[g-4>>2]&3|0)!=0){X2(g|0,0,f|0)}c[196483]=g;if(!(ft[c[59480]&63](g,d)|0)){d=c[198610]|0;g=(d|0)!=0?d:c[p>>2]|0;a2(101240,73,1,g|0)|0;g=c[198610]|0;d=(g|0)!=0?g:c[p>>2]|0;aY(d|0)|0;XZ(c[196483]|0);c[196483]=0;i=b;return}if((a[637400]&1)!=0){d=c[198610]|0;g=(d|0)!=0?d:c[p>>2]|0;d=((c[158312]|0)>>>0)/1e6|0;ec(g|0,96944,(k=i,i=i+8|0,c[k>>2]=d,k)|0)|0;i=k;d=c[198610]|0;g=(d|0)!=0?d:c[p>>2]|0;aY(g|0)|0}g=c[158312]|0;d=c[196483]|0;L695:do{if(f<<2>>>0<g>>>0){h=XY(32)|0;if((h|0)==0){l=509;break}if((c[h-4>>2]&3|0)!=0){X2(h|0,0,32)}j=h;c[h+16>>2]=1;m=e>>>2;c[h+24>>2]=m;n=g-1|0;o=n>>>1|n;n=o>>>2|o;o=n>>>4|n;n=o>>>8|o;o=(n>>>16|n)+1|0;n=o>>>1;q=(o-g|0)>>>0<(g-n|0)>>>0?o:n;n=q>>>3;c[h+4>>2]=n;c[h+8>>2]=n-1;if((a[637400]&1)!=0){o=c[198610]|0;r=(o|0)!=0?o:c[p>>2]|0;o=q>>>23<<3;ec(r|0,58576,(k=i,i=i+8|0,c[k>>2]=o,k)|0)|0;i=k;o=c[198610]|0;r=(o|0)!=0?o:c[p>>2]|0;aY(r|0)|0}r=n<<3;n=XY(r)|0;do{if((n|0)==0){c[h>>2]=0;s=h+12|0}else{if((c[n-4>>2]&3|0)==0){c[h>>2]=n}else{X2(n|0,0,r|0);c[h>>2]=n}o=m<<2;q=XY(o)|0;if((q|0)==0){t=h+12|0;c[t>>2]=0;s=t;break}if((c[q-4>>2]&3|0)==0){c[h+12>>2]=q;X5(q|0,d|0,f)|0;c[196482]=j;if((h|0)==0){break L695}i=b;return}else{X2(q|0,0,o|0);c[h+12>>2]=q;X5(q|0,d|0,f)|0;c[196482]=j;i=b;return}}}while(0);XZ(n);XZ(c[s>>2]|0);XZ(h);l=509}else{l=509}}while(0);if((l|0)==509){c[196482]=0}l=c[198610]|0;a2(91256,78,1,((l|0)!=0?l:c[p>>2]|0)|0)|0;l=c[198610]|0;aY(((l|0)!=0?l:c[p>>2]|0)|0)|0;i=b;return}function f1(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;a=i;i=i+4608|0;b=c[182916]|0;d=a|0;if((b|0)==0){bN(d|0,4096,60088,(e=i,i=i+8|0,c[e>>2]=698890,e)|0)|0;i=e}else{bN(d|0,4096,89008,(e=i,i=i+16|0,c[e>>2]=698890,c[e+8>>2]=b,e)|0)|0;i=e}b=a+4096|0;if(gj(d)|0){f=c[182916]|0;bN(b|0,512,82416,(e=i,i=i+8|0,c[e>>2]=f,e)|0)|0;i=e}else{bN(b|0,512,79040,(e=i,i=i+8|0,c[e>>2]=d,e)|0)|0;i=e}e=c[196481]|0;d=e+4|0;f=c[d>>2]|0;if(f>>>0>1){g=e|0;h=1;j=f;while(1){f=c[(c[g>>2]|0)+(h<<2)>>2]|0;if((f|0)==0){k=j}else{XZ(c[f+8>>2]|0);XZ(c[(c[g>>2]|0)+(h<<2)>>2]|0);c[(c[g>>2]|0)+(h<<2)>>2]=0;k=c[d>>2]|0}f=h+1|0;if(f>>>0<k>>>0){h=f;j=k}else{break}}}c[d>>2]=1;d=e+12|0;XZ(c[d>>2]|0);c[d>>2]=0;d=c[196481]|0;e=d+4|0;if((c[e>>2]|0)>>>0>=(c[d+8>>2]|0)>>>0){i=a;return}k=XY(12)|0;do{if((k|0)!=0){if((c[k-4>>2]&3|0)==0){break}X2(k|0,0,12)}}while(0);c[k+4>>2]=2;c[k>>2]=180;j=dq(b|0)|0;b=c[e>>2]|0;c[k+8>>2]=j;j=d|0;c[(c[j>>2]|0)+(b<<2)>>2]=k;k=c[e>>2]|0;c[e>>2]=k+1;if(k>>>0>1){l=k}else{i=a;return}while(1){k=l>>>1;e=c[j>>2]|0;b=e+(k<<2)|0;d=c[b>>2]|0;h=c[e+(l<<2)>>2]|0;if((c[h+4>>2]|0)>>>0<=(c[d+4>>2]|0)>>>0){m=540;break}c[b>>2]=h;c[(c[j>>2]|0)+(l<<2)>>2]=d;if(l>>>0>3){l=k}else{m=543;break}}if((m|0)==540){i=a;return}else if((m|0)==543){i=a;return}}function f2(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;b=i;i=i+4608|0;d=c[182916]|0;if((a[633273]&1)==0){e=d}else{f=d+1|0;c[182916]=f;e=f}f=b|0;if((e|0)==0){bN(f|0,4096,60088,(g=i,i=i+8|0,c[g>>2]=698890,g)|0)|0;i=g}else{bN(f|0,4096,89008,(g=i,i=i+16|0,c[g>>2]=698890,c[g+8>>2]=e,g)|0)|0;i=g}e=b+4096|0;if(gh(f)|0){d=c[182916]|0;bN(e|0,512,75776,(g=i,i=i+8|0,c[g>>2]=d,g)|0)|0;i=g}else{bN(e|0,512,72920,(g=i,i=i+8|0,c[g>>2]=f,g)|0)|0;i=g}g=c[196481]|0;f=g+4|0;d=c[f>>2]|0;if(d>>>0>1){h=g|0;j=1;k=d;while(1){d=c[(c[h>>2]|0)+(j<<2)>>2]|0;if((d|0)==0){l=k}else{XZ(c[d+8>>2]|0);XZ(c[(c[h>>2]|0)+(j<<2)>>2]|0);c[(c[h>>2]|0)+(j<<2)>>2]=0;l=c[f>>2]|0}d=j+1|0;if(d>>>0<l>>>0){j=d;k=l}else{break}}}c[f>>2]=1;f=g+12|0;XZ(c[f>>2]|0);c[f>>2]=0;f=c[196481]|0;g=f+4|0;if((c[g>>2]|0)>>>0>=(c[f+8>>2]|0)>>>0){i=b;return}l=XY(12)|0;do{if((l|0)!=0){if((c[l-4>>2]&3|0)==0){break}X2(l|0,0,12)}}while(0);c[l+4>>2]=2;c[l>>2]=180;k=dq(e|0)|0;e=c[g>>2]|0;c[l+8>>2]=k;k=f|0;c[(c[k>>2]|0)+(e<<2)>>2]=l;l=c[g>>2]|0;c[g>>2]=l+1;if(l>>>0>1){m=l}else{i=b;return}while(1){l=m>>>1;g=c[k>>2]|0;e=g+(l<<2)|0;f=c[e>>2]|0;j=c[g+(m<<2)>>2]|0;if((c[j+4>>2]|0)>>>0<=(c[f+4>>2]|0)>>>0){n=567;break}c[e>>2]=j;c[(c[k>>2]|0)+(m<<2)>>2]=f;if(m>>>0>3){m=l}else{n=565;break}}if((n|0)==565){i=b;return}else if((n|0)==567){i=b;return}}function f3(){var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;if((a[637400]&1)!=0){b=c[198610]|0;d=(b|0)!=0?b:c[p>>2]|0;a2(67632,27,1,d|0)|0;d=c[198610]|0;b=(d|0)!=0?d:c[p>>2]|0;aY(b|0)|0}b=c[196481]|0;d=b+4|0;e=c[d>>2]|0;if(e>>>0>1){f=b|0;g=1;h=e;while(1){e=c[(c[f>>2]|0)+(g<<2)>>2]|0;if((e|0)==0){i=h}else{XZ(c[e+8>>2]|0);XZ(c[(c[f>>2]|0)+(g<<2)>>2]|0);c[(c[f>>2]|0)+(g<<2)>>2]=0;i=c[d>>2]|0}e=g+1|0;if(e>>>0<i>>>0){g=e;h=i}else{break}}}c[d>>2]=1;d=b+12|0;XZ(c[d>>2]|0);c[d>>2]=0;d=c[196481]|0;b=d+4|0;if((c[b>>2]|0)>>>0>=(c[d+8>>2]|0)>>>0){j=c[59484]|0;fz[j&8191]();f4();return}i=XY(12)|0;do{if((i|0)!=0){if((c[i-4>>2]&3|0)==0){break}X2(i|0,0,12)}}while(0);c[i+4>>2]=1;c[i>>2]=120;h=dq(65320)|0;g=c[b>>2]|0;c[i+8>>2]=h;h=d|0;c[(c[h>>2]|0)+(g<<2)>>2]=i;i=c[b>>2]|0;c[b>>2]=i+1;if(i>>>0>1){k=i}else{j=c[59484]|0;fz[j&8191]();f4();return}while(1){i=k>>>1;b=c[h>>2]|0;g=b+(i<<2)|0;d=c[g>>2]|0;f=c[b+(k<<2)>>2]|0;if((c[f+4>>2]|0)>>>0<=(c[d+4>>2]|0)>>>0){l=586;break}c[g>>2]=f;c[(c[h>>2]|0)+(k<<2)>>2]=d;if(k>>>0>3){k=i}else{l=587;break}}if((l|0)==586){j=c[59484]|0;fz[j&8191]();f4();return}else if((l|0)==587){j=c[59484]|0;fz[j&8191]();f4();return}}function f4(){var b=0,d=0,e=0,f=0,g=0;b=i;d=0;do{e=c[637404+(d<<2)>>2]|0;L821:do{if((e|0)!=1){fc[c[59472]&127](d,e);switch(e|0){case 5:{if((a[637400]&1)==0){break L821}f=c[198610]|0;ec(((f|0)!=0?f:c[p>>2]|0)|0,60352,(g=i,i=i+8|0,c[g>>2]=d+1,g)|0)|0;i=g;f=c[198610]|0;aY(((f|0)!=0?f:c[p>>2]|0)|0)|0;break L821;break};case 2:{if((a[637400]&1)==0){break L821}f=c[198610]|0;ec(((f|0)!=0?f:c[p>>2]|0)|0,60280,(g=i,i=i+8|0,c[g>>2]=d+1,g)|0)|0;i=g;f=c[198610]|0;aY(((f|0)!=0?f:c[p>>2]|0)|0)|0;break L821;break};case 0:{if((a[637400]&1)==0){break L821}f=c[198610]|0;ec(((f|0)!=0?f:c[p>>2]|0)|0,60448,(g=i,i=i+8|0,c[g>>2]=d+1,g)|0)|0;i=g;f=c[198610]|0;aY(((f|0)!=0?f:c[p>>2]|0)|0)|0;break L821;break};case 516:{if((a[637400]&1)==0){break L821}f=c[198610]|0;ec(((f|0)!=0?f:c[p>>2]|0)|0,60208,(g=i,i=i+8|0,c[g>>2]=d+1,g)|0)|0;i=g;f=c[198610]|0;aY(((f|0)!=0?f:c[p>>2]|0)|0)|0;break L821;break};case 772:{if((a[637400]&1)==0){break L821}f=c[198610]|0;ec(((f|0)!=0?f:c[p>>2]|0)|0,60136,(g=i,i=i+8|0,c[g>>2]=d+1,g)|0)|0;i=g;f=c[198610]|0;aY(((f|0)!=0?f:c[p>>2]|0)|0)|0;break L821;break};case 260:{if((a[637400]&1)==0){break L821}f=c[198610]|0;ec(((f|0)!=0?f:c[p>>2]|0)|0,59792,(g=i,i=i+8|0,c[g>>2]=d+1,g)|0)|0;i=g;f=c[198610]|0;aY(((f|0)!=0?f:c[p>>2]|0)|0)|0;break L821;break};case 257:{if((a[637400]&1)==0){break L821}f=c[198610]|0;ec(((f|0)!=0?f:c[p>>2]|0)|0,59944,(g=i,i=i+8|0,c[g>>2]=d+1,g)|0)|0;i=g;f=c[198610]|0;aY(((f|0)!=0?f:c[p>>2]|0)|0)|0;break L821;break};default:{break L821}}}}while(0);d=d+1|0;}while(d>>>0<8);i=b;return}function f5(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;e=i;i=i+256|0;if((c[184100]|0)==0){i=e;return}f=e|0;a[f]=0;if(fe[c[184096]&127](b)|0){g=b?61312:60256;bN(f|0,256,62296,(h=i,i=i+8|0,c[h>>2]=g,h)|0)|0;i=h;j=0}else{g=b?58640:57872;bN(f|0,256,59256,(h=i,i=i+8|0,c[h>>2]=g,h)|0)|0;i=h;j=1}if((a[f]|0)==0){i=e;return}do{if(j){g=c[198610]|0;b=(g|0)!=0?g:c[p>>2]|0;ec(b|0,57240,(h=i,i=i+8|0,c[h>>2]=f,h)|0)|0;i=h;b=c[198610]|0;g=(b|0)!=0?b:c[p>>2]|0;aY(g|0)|0}else{if((a[637400]&1)==0){break}g=c[198610]|0;b=(g|0)!=0?g:c[p>>2]|0;ec(b|0,93640,(h=i,i=i+8|0,c[h>>2]=f,h)|0)|0;i=h;b=c[198610]|0;g=(b|0)!=0?b:c[p>>2]|0;aY(g|0)|0}}while(0);if(!d){i=e;return}d=c[196481]|0;h=d+4|0;j=c[h>>2]|0;if(j>>>0>1){g=d|0;b=1;k=j;while(1){j=c[(c[g>>2]|0)+(b<<2)>>2]|0;if((j|0)==0){l=k}else{XZ(c[j+8>>2]|0);XZ(c[(c[g>>2]|0)+(b<<2)>>2]|0);c[(c[g>>2]|0)+(b<<2)>>2]=0;l=c[h>>2]|0}j=b+1|0;if(j>>>0<l>>>0){b=j;k=l}else{break}}}c[h>>2]=1;h=d+12|0;XZ(c[h>>2]|0);c[h>>2]=0;h=c[196481]|0;d=h+4|0;if((c[d>>2]|0)>>>0>=(c[h+8>>2]|0)>>>0){i=e;return}l=XY(12)|0;do{if((l|0)!=0){if((c[l-4>>2]&3|0)==0){break}X2(l|0,0,12)}}while(0);c[l+4>>2]=1;c[l>>2]=180;k=dq(f|0)|0;f=c[d>>2]|0;c[l+8>>2]=k;k=h|0;c[(c[k>>2]|0)+(f<<2)>>2]=l;l=c[d>>2]|0;c[d>>2]=l+1;if(l>>>0>1){m=l}else{i=e;return}while(1){l=m>>>1;d=c[k>>2]|0;f=d+(l<<2)|0;h=c[f>>2]|0;b=c[d+(m<<2)>>2]|0;if((c[b+4>>2]|0)>>>0<=(c[h+4>>2]|0)>>>0){n=636;break}c[f>>2]=b;c[(c[k>>2]|0)+(m<<2)>>2]=h;if(m>>>0>3){m=l}else{n=632;break}}if((n|0)==632){i=e;return}else if((n|0)==636){i=e;return}}function f6(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0;d=i;i=i+256|0;e=c[184100]|0;if((e|0)==0){i=d;return}f=d|0;a[f]=0;g=fw[e&31]()|0;e=g>>>0>b>>>0;do{if(fe[c[184099]&127](b)|0){if(e){h=b+1|0;bN(f|0,256,56616,(j=i,i=i+16|0,c[j>>2]=h,c[j+8>>2]=g,j)|0)|0;i=j;k=0;break}else{bN(f|0,256,55304,(j=i,i=i+1|0,i=i+7>>3<<3,c[j>>2]=0,j)|0)|0;i=j;k=0;break}}else{if(e){h=b+1|0;bN(f|0,256,54440,(j=i,i=i+16|0,c[j>>2]=h,c[j+8>>2]=g,j)|0)|0;i=j;k=1;break}else{bN(f|0,256,53568,(j=i,i=i+1|0,i=i+7>>3<<3,c[j>>2]=0,j)|0)|0;i=j;k=1;break}}}while(0);if((a[f]|0)==0){i=d;return}do{if(k){g=c[198610]|0;b=(g|0)!=0?g:c[p>>2]|0;ec(b|0,57240,(j=i,i=i+8|0,c[j>>2]=f,j)|0)|0;i=j;b=c[198610]|0;g=(b|0)!=0?b:c[p>>2]|0;aY(g|0)|0}else{if((a[637400]&1)==0){break}g=c[198610]|0;b=(g|0)!=0?g:c[p>>2]|0;ec(b|0,93640,(j=i,i=i+8|0,c[j>>2]=f,j)|0)|0;i=j;b=c[198610]|0;g=(b|0)!=0?b:c[p>>2]|0;aY(g|0)|0}}while(0);j=c[196481]|0;k=j+4|0;g=c[k>>2]|0;if(g>>>0>1){b=j|0;e=1;h=g;while(1){g=c[(c[b>>2]|0)+(e<<2)>>2]|0;if((g|0)==0){l=h}else{XZ(c[g+8>>2]|0);XZ(c[(c[b>>2]|0)+(e<<2)>>2]|0);c[(c[b>>2]|0)+(e<<2)>>2]=0;l=c[k>>2]|0}g=e+1|0;if(g>>>0<l>>>0){e=g;h=l}else{break}}}c[k>>2]=1;k=j+12|0;XZ(c[k>>2]|0);c[k>>2]=0;k=c[196481]|0;j=k+4|0;if((c[j>>2]|0)>>>0>=(c[k+8>>2]|0)>>>0){i=d;return}l=XY(12)|0;do{if((l|0)!=0){if((c[l-4>>2]&3|0)==0){break}X2(l|0,0,12)}}while(0);c[l+4>>2]=1;c[l>>2]=180;h=dq(f|0)|0;f=c[j>>2]|0;c[l+8>>2]=h;h=k|0;c[(c[h>>2]|0)+(f<<2)>>2]=l;l=c[j>>2]|0;c[j>>2]=l+1;if(l>>>0>1){m=l}else{i=d;return}while(1){l=m>>>1;j=c[h>>2]|0;f=j+(l<<2)|0;k=c[f>>2]|0;e=c[j+(m<<2)>>2]|0;if((c[e+4>>2]|0)>>>0<=(c[k+4>>2]|0)>>>0){n=668;break}c[f>>2]=e;c[(c[h>>2]|0)+(m<<2)>>2]=k;if(m>>>0>3){m=l}else{n=663;break}}if((n|0)==668){i=d;return}else if((n|0)==663){i=d;return}}function f7(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0;d=i;i=i+216|0;e=d|0;f=d+72|0;g=d+144|0;h=4096;j=674314;k=b;while(1){l=h-1|0;if((l|0)==0){m=672;break}n=a[k]|0;a[j]=n;if(n<<24>>24==0){o=4096;q=670218;r=b;break}else{h=l;j=j+1|0;k=k+1|0}}do{if((m|0)==672){a[j]=0;if((a[k]|0)==0){o=4096;q=670218;r=b;break}else{s=k}while(1){h=s+1|0;if((a[h]|0)==0){o=4096;q=670218;r=b;break}else{s=h}}}}while(0);while(1){s=o-1|0;if((s|0)==0){m=676;break}k=a[r]|0;a[q]=k;if(k<<24>>24==0){break}else{o=s;q=q+1|0;r=r+1|0}}do{if((m|0)==676){a[q]=0;if((a[r]|0)==0){break}else{t=r}do{t=t+1|0;}while((a[t]|0)!=0)}}while(0);t=cg(670218,46)|0;if((t|0)!=0){a[t]=0}if((a[657928]&1)==0){gt(678410,670218,100880)}if((a[657929]&1)==0){gt(698890,670218,99104)}do{if((eB(678410,g|0)|0)>=0){if((c[g+8>>2]&61440|0)!=16384){break}gu(678410,100880);if((a[637400]&1)==0){break}t=c[198610]|0;r=(t|0)!=0?t:c[p>>2]|0;ec(r|0,61e3,(u=i,i=i+8|0,c[u>>2]=678410,u)|0)|0;i=u;r=c[198610]|0;t=(r|0)!=0?r:c[p>>2]|0;aY(t|0)|0}}while(0);do{if((eB(698890,f|0)|0)>=0){if((c[f+8>>2]&61440|0)!=16384){break}gu(698890,99104);if((a[637400]&1)==0){break}g=c[198610]|0;t=(g|0)!=0?g:c[p>>2]|0;ec(t|0,60864,(u=i,i=i+8|0,c[u>>2]=698890,u)|0)|0;i=u;t=c[198610]|0;g=(t|0)!=0?t:c[p>>2]|0;aY(g|0)|0}}while(0);if((a[629148]|0)==0){gA(629148,b)}if((a[657930]|0)==0){i=d;return}if((eB(657930,e|0)|0)<0){i=d;return}if((c[e+8>>2]&61440|0)!=16384){i=d;return}gu(657930,60704);if((a[637400]&1)!=0){e=c[198610]|0;b=(e|0)!=0?e:c[p>>2]|0;ec(b|0,60592,(u=i,i=i+8|0,c[u>>2]=657930,u)|0)|0;i=u;u=c[198610]|0;b=(u|0)!=0?u:c[p>>2]|0;aY(b|0)|0}b=c5(657930,23072)|0;if((b|0)!=0){aQ(b|0)|0;i=d;return}a[657930]=0;if((a[637400]&1)==0){i=d;return}b=c[198610]|0;a2(60512,59,1,((b|0)!=0?b:c[p>>2]|0)|0)|0;b=c[198610]|0;aY(((b|0)!=0?b:c[p>>2]|0)|0)|0;i=d;return}function f8(){var b=0,d=0,e=0;b=c[160384]|0;do{if((b|0)==1){if((a[657928]&1)==0){gs(678410,641544,100880)}if((a[657929]&1)==0){gs(698890,641544,99104)}gs(682506,678410,44304)}else if((b|0)==4){if(!((a[657928]&1)==0|(a[649736]|0)==0|(a[653832]|0)==0)){d=c[198610]|0;e=(d|0)!=0?d:c[p>>2]|0;a2(61488,109,1,e|0)|0;e=c[198610]|0;d=(e|0)!=0?e:c[p>>2]|0;aY(d|0)|0}gs(690698,649736,100880);gs(694794,653832,100880);if((a[657929]&1)!=0){break}gs(698890,(a[649736]|0)!=0?649736:653832,99104)}else if((b|0)==2|(b|0)==3){if((a[657928]&1)==0){gs(678410,645640,100880)}gs(686602,678410,61664);if((a[657929]&1)!=0){break}gs(698890,645640,99104)}else{gs(682506,678410,44304)}}while(0);gs(785948,678410,798256);if((a[670218]|0)==0){return}if((a[719374]|0)==0){gt(719374,670218,61424)}if((a[723470]|0)==0){gt(723470,670218,61360)}if((a[727566]|0)==0){gt(727566,670218,61304)}if((a[702986]|0)==0){gt(702986,670218,61256)}if((a[625052]|0)!=0){return}gA(625052,670218);return}function f9(d,e){d=d|0;e=e|0;var f=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,ab=0,ac=0,ad=0,ae=0,af=0,ah=0,ai=0,aj=0,am=0,ao=0,ap=0,aq=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aB=0,aD=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0,cf=0,cg=0,ch=0,ci=0,cj=0,ck=0,cl=0,cm=0,cn=0,co=0,cp=0,cq=0,cr=0,cs=0,ct=0,cu=0,cv=0,cw=0,cx=0,cy=0,cz=0,cA=0,cB=0,cC=0,cD=0,cE=0,cF=0,cG=0,cH=0,cI=0,cJ=0,cK=0,cL=0,cM=0,cN=0,cO=0,cP=0,cQ=0,cR=0,cS=0,cT=0,cU=0,cV=0,cW=0,cX=0,cY=0,cZ=0,c_=0,c$=0,c0=0,c1=0,c2=0,c3=0,c4=0,c5=0,c6=0,c7=0,c8=0,c9=0,da=0,db=0,dc=0,dd=0,de=0,df=0,dg=0,dh=0,di=0,dj=0,dk=0,dl=0,dm=0,dn=0,dp=0,dq=0,dr=0,ds=0,dt=0,du=0,dv=0,dw=0,dx=0,dy=0,dz=0,dA=0,dB=0,dC=0,dD=0,dE=0,dF=0,dG=0,dH=0,dI=0,dJ=0,dK=0,dL=0,dM=0,dN=0,dO=0,dP=0,dQ=0,dR=0,dS=0,dT=0,dU=0.0,dV=0.0,dW=0,dX=0,dY=0,dZ=0,d_=0,d$=0,d0=0,d1=0,d2=0,d3=0,d4=0,d5=0,d6=0,d7=0,d8=0,d9=0,ea=0,eb=0,ec=0,ed=0,ee=0,ef=0,eg=0,eh=0,ei=0,ej=0,ek=0,el=0,em=0,en=0,eo=0,ep=0,eq=0,er=0,es=0,et=0,eu=0,ev=0,ew=0,ex=0,ey=0,ez=0,eA=0,eB=0,eC=0,eD=0,eE=0,eF=0,eG=0,eH=0,eI=0,eJ=0,eK=0,eL=0,eM=0,eN=0,eO=0,eP=0,eQ=0,eR=0,eS=0,eT=0,eU=0,eV=0,eW=0,eX=0,eY=0,eZ=0,e_=0,e$=0,e0=0,e1=0,e2=0,e3=0,e4=0,e5=0,e6=0,e7=0,e8=0,e9=0,fa=0,fb=0,fc=0,fd=0,fe=0,ff=0,fg=0,fh=0,fi=0,fj=0,fk=0,fl=0,fm=0;f=i;i=i+13008|0;j=1;k=0;l=i;i=i+168|0;c[l>>2]=0;while(1)switch(j|0){case 1:m=f|0;n=f+8|0;o=f+16|0;q=f+24|0;r=f+32|0;u=f+40|0;v=f+48|0;w=f+56|0;x=f+64|0;y=f+72|0;z=f+144|0;A=f+216|0;B=f+4312|0;C=f+8408|0;D=f+12504|0;E=f+12512|0;a[637402]=1;a[637401]=1;c[160384]=0;c[159351]=1;c[159352]=1;c[159353]=1;c[159354]=1;c[159355]=1;c[159356]=1;c[159357]=1;c[159358]=1;F=X3(795472,j,l)|0;j=510;break;case 510:if((F|0)>0){j=2;break}else{j=3;break};case 2:G=c[198610]|0;ar(46,((G|0)!=0?G:c[p>>2]|0)|0,49224,(H=i,i=i+8|0,c[H>>2]=794447,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;G=c[198610]|0;an(102,((G|0)!=0?G:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;I=F;j=509;break;case 3:a[794445]=1;a[795516]=0;a[795517]=0;a[657928]=0;a[657929]=0;if((d|0)<2){j=4;break}else{j=5;break};case 4:a[795517]=1;j=182;break;case 5:c[1734]=0;c[D>>2]=0;c[E>>2]=94448;c[E+4>>2]=0;c[E+8>>2]=D;c[E+12>>2]=77;c[E+16>>2]=94152;c[E+20>>2]=0;c[E+24>>2]=0;c[E+28>>2]=104;c[E+32>>2]=93736;c[E+36>>2]=1;c[E+40>>2]=0;c[E+44>>2]=115;c[E+48>>2]=93320;c[E+52>>2]=0;c[E+56>>2]=0;c[E+60>>2]=102;c[E+64>>2]=92904;c[E+68>>2]=0;c[E+72>>2]=0;c[E+76>>2]=118;c[E+80>>2]=92584;c[E+84>>2]=1;c[E+88>>2]=0;c[E+92>>2]=103;c[E+96>>2]=92288;c[E+100>>2]=1;c[E+104>>2]=0;c[E+108>>2]=99;c[E+112>>2]=91696;c[E+116>>2]=1;c[E+120>>2]=D;c[E+124>>2]=67;c[E+128>>2]=90984;c[E+132>>2]=1;c[E+136>>2]=0;c[E+140>>2]=109;c[E+144>>2]=90776;c[E+148>>2]=1;c[E+152>>2]=0;c[E+156>>2]=78;c[E+160>>2]=90472;c[E+164>>2]=0;c[E+168>>2]=0;c[E+172>>2]=112;c[E+176>>2]=90224;c[E+180>>2]=0;c[E+184>>2]=0;c[E+188>>2]=106;c[E+192>>2]=89872;c[E+196>>2]=0;c[E+200>>2]=0;c[E+204>>2]=74;c[E+208>>2]=89600;c[E+212>>2]=1;c[E+216>>2]=0;c[E+220>>2]=65;c[E+224>>2]=89288;c[E+228>>2]=1;c[E+232>>2]=0;c[E+236>>2]=83;c[E+240>>2]=89e3;c[E+244>>2]=1;c[E+248>>2]=0;c[E+252>>2]=98;c[E+256>>2]=88744;c[E+260>>2]=1;c[E+264>>2]=0;c[E+268>>2]=66;c[E+272>>2]=88192;c[E+276>>2]=0;c[E+280>>2]=0;c[E+284>>2]=52;c[E+288>>2]=87896;c[E+292>>2]=1;c[E+296>>2]=0;c[E+300>>2]=89;c[E+304>>2]=87616;c[E+308>>2]=1;c[E+312>>2]=0;c[E+316>>2]=90;c[E+320>>2]=87328;c[E+324>>2]=1;c[E+328>>2]=0;c[E+332>>2]=80;c[E+336>>2]=87072;c[E+340>>2]=1;c[E+344>>2]=0;c[E+348>>2]=82;c[E+352>>2]=86744;c[E+356>>2]=1;c[E+360>>2]=0;c[E+364>>2]=77;c[E+368>>2]=86464;c[E+372>>2]=1;c[E+376>>2]=0;c[E+380>>2]=85;c[E+384>>2]=86184;c[E+388>>2]=1;c[E+392>>2]=D;c[E+396>>2]=66;c[E+400>>2]=85928;c[E+404>>2]=1;c[E+408>>2]=D;c[E+412>>2]=73;c[E+416>>2]=85600;c[E+420>>2]=0;c[E+424>>2]=D;c[E+428>>2]=110;c[E+432>>2]=85056;c[E+436>>2]=1;c[E+440>>2]=0;c[E+444>>2]=88;c[E+448>>2]=84712;c[E+452>>2]=0;c[E+456>>2]=0;c[E+460>>2]=68;c[E+464>>2]=84344;c[E+468>>2]=0;c[E+472>>2]=D;c[E+476>>2]=102;X2(E+480|0,0,16);J=e+(d<<2)|0;K=0;j=6;break;case 6:c[D>>2]=0;if((K|0)==0){j=7;break}else{L=K;j=8;break};case 7:c[1734]=1;L=1;j=8;break;case 8:if((d|0)==1){M=L;j=162;break}else{j=9;break};case 9:N=e+(L<<2)|0;O=c[N>>2]|0;if((O|0)==0){R=-1;S=-1;j=17;break}else{T=0;U=O;j=10;break};case 10:if((a[U]|0)==45){j=11;break}else{j=12;break};case 11:if((a[U+1|0]|0)==45){j=12;break}else{V=T;j=13;break};case 12:G=T+1|0;W=c[e+(G+L<<2)>>2]|0;if((W|0)==0){V=-1;j=13;break}else{T=G;U=W;j=10;break};case 13:X=0;Y=O;j=14;break;case 14:if((a[Y]|0)==45){j=15;break}else{j=16;break};case 15:if((a[Y+1|0]|0)==45){R=X;S=V;j=17;break}else{j=16;break};case 16:W=X+1|0;G=c[e+(W+L<<2)>>2]|0;if((G|0)==0){R=-1;S=V;j=17;break}else{X=W;Y=G;j=14;break};case 17:Z=(S|0)==-1;_=(R|0)==-1;if(Z&_){M=L;j=162;break}else{j=18;break};case 18:if((S|0)>0){j=19;break}else{j=21;break};case 19:if((S|0)<(R|0)|_){j=20;break}else{j=21;break};case 20:aH(82,N|0,e+(S+L<<2)|0,J|0);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;j=28;break;case 21:if((R|0)>0){j=22;break}else{j=25;break};case 22:if((R|0)<(S|0)|Z){j=23;break}else{j=25;break};case 23:aH(82,N|0,e+(R+L<<2)|0,J|0);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((S|0)==0){j=28;break}else{j=24;break};case 24:$=c[1734]|0;j=40;break;case 25:ab=(S|0)==0;ac=(R|0)==0;if(ab|ac){j=27;break}else{j=26;break};case 26:G=c[198610]|0;ar(46,((G|0)!=0?G:c[p>>2]|0)|0,63392,(H=i,i=i+16|0,c[H>>2]=96632,c[H+8>>2]=190,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;G=c[198610]|0;an(102,((G|0)!=0?G:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;ak(120,2);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;return 0;case 27:if(ab){j=28;break}else{j=39;break};case 28:ad=c[1734]|0;ae=c[e+(ad<<2)>>2]|0;af=ae+1|0;ah=a[af]|0;if(ah<<24>>24==58){j=160;break}else{j=29;break};case 29:ai=ar(24,83992,ah<<24>>24|0,41)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((ai|0)==0){j=160;break}else{j=30;break};case 30:aj=ae+2|0;G=(a[ai+1|0]|0)==58;am=G&(a[aj]|0)!=0;if(G){j=31;break}else{j=36;break};case 31:if(am){j=32;break}else{j=33;break};case 32:c[59642]=aj;ao=ad+1|0;ap=aj;j=34;break;case 33:G=c[e+(ad+1<<2)>>2]|0;c[59642]=G;ao=ad+2|0;ap=G;j=34;break;case 34:c[1734]=ao;if((ap|0)==0){j=160;break}else{j=35;break};case 35:aq=a[ai]|0;as=ao;j=49;break;case 36:if(am){j=37;break}else{j=38;break};case 37:G=an(10,aj|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;aH(192,af|0,aj|0,G+1|0);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;aq=a[ai]|0;as=ad;j=49;break;case 38:G=ad+1|0;c[1734]=G;aq=a[ai]|0;as=G;j=49;break;case 39:if(ac){$=L;j=40;break}else{j=160;break};case 40:at=0;j=41;break;case 41:au=c[E+(at<<4)>>2]|0;if((au|0)==0){j=160;break}else{j=42;break};case 42:G=aC(38,au|0,(c[e+($<<2)>>2]|0)+2|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((G|0)==0){j=44;break}else{j=43;break};case 43:at=at+1|0;j=41;break;case 44:av=$+1|0;if((c[E+(at<<4)+4>>2]|0)==0){aw=av;j=47;break}else{j=45;break};case 45:ax=c[e+(av<<2)>>2]|0;if((ax|0)==0){j=160;break}else{j=46;break};case 46:c[59642]=ax;aw=$+2|0;j=47;break;case 47:c[1734]=aw;ay=c[E+(at<<4)+8>>2]|0;az=c[E+(at<<4)+12>>2]|0;if((ay|0)==0){aq=az;as=aw;j=49;break}else{j=48;break};case 48:c[ay>>2]=az;j=139;break;case 49:switch(aq|0){case 68:{j=50;break};case 104:{j=51;break};case 52:{j=52;break};case 106:{j=53;break};case 74:{j=54;break};case 65:{j=55;break};case 115:{j=58;break};case 102:{j=64;break};case 103:{j=65;break};case 98:{j=71;break};case 66:{j=77;break};case 89:{j=83;break};case 90:{j=89;break};case 83:{j=95;break};case 118:{j=101;break};case 109:{j=102;break};case 78:{j=105;break};case 112:{j=108;break};case 99:{j=109;break};case 80:case 82:{j=114;break};case 77:{j=120;break};case 85:{j=128;break};case 88:{j=134;break};case 0:{j=139;break};case 63:{j=160;break};case-1:{M=as;j=162;break};default:{j=161;break}}break;case 50:K=c[1734]|0;j=6;break;case 51:aI(3244);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;ak(120,0);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;return 0;case 52:c[159352]=257;j=50;break;case 53:c[159352]=516;j=50;break;case 54:c[159352]=772;j=50;break;case 55:G=ar(20,c[59642]|0,0,0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;aB=G-1|0;if(aB>>>0>7){j=56;break}else{j=57;break};case 56:G=c[198610]|0;aG(4,83624,57,1,((G|0)!=0?G:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;G=c[198610]|0;an(102,((G|0)!=0?G:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;aI(3244);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;ak(32,83376);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;return 0;case 57:c[637404+(aB<<2)>>2]=5;j=50;break;case 58:aD=4096;aJ=678410;aK=c[59642]|0;j=59;break;case 59:aL=aD-1|0;if((aL|0)==0){j=61;break}else{j=60;break};case 60:G=a[aK]|0;a[aJ]=G;if(G<<24>>24==0){j=63;break}else{aD=aL;aJ=aJ+1|0;aK=aK+1|0;j=59;break};case 61:a[aJ]=0;if((a[aK]|0)==0){j=63;break}else{aM=aK;j=62;break};case 62:G=aM+1|0;if((a[G]|0)==0){j=63;break}else{aM=G;j=62;break};case 63:a[657928]=1;j=50;break;case 64:a[637403]=1;j=50;break;case 65:aN=4096;aO=641544;aP=c[59642]|0;j=66;break;case 66:aQ=aN-1|0;if((aQ|0)==0){j=68;break}else{j=67;break};case 67:G=a[aP]|0;a[aO]=G;if(G<<24>>24==0){j=70;break}else{aN=aQ;aO=aO+1|0;aP=aP+1|0;j=66;break};case 68:a[aO]=0;if((a[aP]|0)==0){j=70;break}else{aR=aP;j=69;break};case 69:G=aR+1|0;if((a[G]|0)==0){j=70;break}else{aR=G;j=69;break};case 70:c[160384]=1;j=50;break;case 71:aS=4096;aT=645640;aU=c[59642]|0;j=72;break;case 72:aV=aS-1|0;if((aV|0)==0){j=74;break}else{j=73;break};case 73:G=a[aU]|0;a[aT]=G;if(G<<24>>24==0){j=76;break}else{aS=aV;aT=aT+1|0;aU=aU+1|0;j=72;break};case 74:a[aT]=0;if((a[aU]|0)==0){j=76;break}else{aW=aU;j=75;break};case 75:G=aW+1|0;if((a[G]|0)==0){j=76;break}else{aW=G;j=75;break};case 76:c[160384]=2;j=50;break;case 77:aX=4096;aY=645640;aZ=c[59642]|0;j=78;break;case 78:a_=aX-1|0;if((a_|0)==0){j=80;break}else{j=79;break};case 79:G=a[aZ]|0;a[aY]=G;if(G<<24>>24==0){j=82;break}else{aX=a_;aY=aY+1|0;aZ=aZ+1|0;j=78;break};case 80:a[aY]=0;if((a[aZ]|0)==0){j=82;break}else{a$=aZ;j=81;break};case 81:G=a$+1|0;if((a[G]|0)==0){j=82;break}else{a$=G;j=81;break};case 82:c[160384]=3;j=50;break;case 83:a0=4096;a1=649736;a2=c[59642]|0;j=84;break;case 84:a3=a0-1|0;if((a3|0)==0){j=86;break}else{j=85;break};case 85:G=a[a2]|0;a[a1]=G;if(G<<24>>24==0){j=88;break}else{a0=a3;a1=a1+1|0;a2=a2+1|0;j=84;break};case 86:a[a1]=0;if((a[a2]|0)==0){j=88;break}else{a4=a2;j=87;break};case 87:G=a4+1|0;if((a[G]|0)==0){j=88;break}else{a4=G;j=87;break};case 88:c[160384]=4;j=50;break;case 89:a5=4096;a6=653832;a7=c[59642]|0;j=90;break;case 90:a8=a5-1|0;if((a8|0)==0){j=92;break}else{j=91;break};case 91:G=a[a7]|0;a[a6]=G;if(G<<24>>24==0){j=94;break}else{a5=a8;a6=a6+1|0;a7=a7+1|0;j=90;break};case 92:a[a6]=0;if((a[a7]|0)==0){j=94;break}else{a9=a7;j=93;break};case 93:G=a9+1|0;if((a[G]|0)==0){j=94;break}else{a9=G;j=93;break};case 94:c[160384]=4;j=50;break;case 95:ba=4096;bb=698890;bc=c[59642]|0;j=96;break;case 96:bd=ba-1|0;if((bd|0)==0){j=98;break}else{j=97;break};case 97:G=a[bc]|0;a[bb]=G;if(G<<24>>24==0){j=100;break}else{ba=bd;bb=bb+1|0;bc=bc+1|0;j=96;break};case 98:a[bb]=0;if((a[bc]|0)==0){j=100;break}else{be=bc;j=99;break};case 99:G=be+1|0;if((a[G]|0)==0){j=100;break}else{be=G;j=99;break};case 100:a[657929]=1;j=50;break;case 101:a[637400]=1;j=50;break;case 102:G=ar(20,c[59642]|0,0,0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;bf=G-1|0;if(bf>>>0>7){j=103;break}else{j=104;break};case 103:G=c[198610]|0;aG(4,83016,52,1,((G|0)!=0?G:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;G=c[198610]|0;an(102,((G|0)!=0?G:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;aI(3244);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;ak(32,83376);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;return 0;case 104:c[637404+(bf<<2)>>2]=2;j=50;break;case 105:G=ar(20,c[59642]|0,0,0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;bg=G-1|0;if(bg>>>0>7){j=106;break}else{j=107;break};case 106:G=c[198610]|0;aG(4,82688,58,1,((G|0)!=0?G:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;G=c[198610]|0;an(102,((G|0)!=0?G:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;aI(3244);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;ak(32,83376);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;return 0;case 107:c[637404+(bg<<2)>>2]=0;j=50;break;case 108:c[159352]=260;j=50;break;case 109:bh=4096;bi=657930;bj=c[59642]|0;j=110;break;case 110:bk=bh-1|0;if((bk|0)==0){j=112;break}else{j=111;break};case 111:G=a[bj]|0;a[bi]=G;if(G<<24>>24==0){j=50;break}else{bh=bk;bi=bi+1|0;bj=bj+1|0;j=110;break};case 112:a[bi]=0;if((a[bj]|0)==0){j=50;break}else{bl=bj;j=113;break};case 113:G=bl+1|0;if((a[G]|0)==0){j=50;break}else{bl=G;j=113;break};case 114:bm=4096;bn=790045;bo=c[59642]|0;j=115;break;case 115:bp=bm-1|0;if((bp|0)==0){j=117;break}else{j=116;break};case 116:G=a[bo]|0;a[bn]=G;if(G<<24>>24==0){j=119;break}else{bm=bp;bn=bn+1|0;bo=bo+1|0;j=115;break};case 117:a[bn]=0;if((a[bo]|0)==0){j=119;break}else{bq=bo;j=118;break};case 118:G=bq+1|0;if((a[G]|0)==0){j=119;break}else{bq=G;j=118;break};case 119:a[794142]=(aq|0)==80|0;a[794141]=(aq|0)==82|0;j=50;break;case 120:br=c[59642]|0;G=aC(38,br|0,82400)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((G|0)==0){j=121;break}else{j=122;break};case 121:a[794144]=1;a[794145]=1;j=50;break;case 122:G=aC(38,br|0,82144)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((G|0)==0){j=123;break}else{j=124;break};case 123:a[794144]=1;j=50;break;case 124:G=aC(38,br|0,81600)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((G|0)==0){j=125;break}else{j=126;break};case 125:a[794145]=1;j=50;break;case 126:G=aC(38,br|0,81312)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((G|0)==0){j=50;break}else{j=127;break};case 127:G=c[198610]|0;aG(4,80800,54,1,((G|0)!=0?G:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;G=c[198610]|0;an(102,((G|0)!=0?G:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;aI(3244);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;ak(32,83376);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;return 0;case 128:bs=4096;bt=719374;bu=c[59642]|0;j=129;break;case 129:bv=bs-1|0;if((bv|0)==0){j=131;break}else{j=130;break};case 130:G=a[bu]|0;a[bt]=G;if(G<<24>>24==0){j=133;break}else{bs=bv;bt=bt+1|0;bu=bu+1|0;j=129;break};case 131:a[bt]=0;if((a[bu]|0)==0){j=133;break}else{bw=bu;j=132;break};case 132:G=bw+1|0;if((a[G]|0)==0){j=133;break}else{bw=G;j=132;break};case 133:a[719371]=1;j=50;break;case 134:bx=4096;by=702986;bz=c[59642]|0;j=135;break;case 135:bA=bx-1|0;if((bA|0)==0){j=137;break}else{j=136;break};case 136:G=a[bz]|0;a[by]=G;if(G<<24>>24==0){j=50;break}else{bx=bA;by=by+1|0;bz=bz+1|0;j=135;break};case 137:a[by]=0;if((a[bz]|0)==0){j=50;break}else{bB=bz;j=138;break};case 138:G=bB+1|0;if((a[G]|0)==0){j=50;break}else{bB=G;j=138;break};case 139:switch(c[D>>2]|0){case 77:{j=140;break};case 67:{j=141;break};case 66:{j=146;break};case 73:{j=152;break};case 110:{j=158;break};case 102:{j=159;break};default:{j=50;break}}break;case 140:a[795517]=1;j=50;break;case 141:bC=4096;bD=662026;bE=c[59642]|0;j=142;break;case 142:bF=bC-1|0;if((bF|0)==0){j=144;break}else{j=143;break};case 143:G=a[bE]|0;a[bD]=G;if(G<<24>>24==0){j=50;break}else{bC=bF;bD=bD+1|0;bE=bE+1|0;j=142;break};case 144:a[bD]=0;if((a[bE]|0)==0){j=50;break}else{bG=bE;j=145;break};case 145:G=bG+1|0;if((a[G]|0)==0){j=50;break}else{bG=G;j=145;break};case 146:bH=4096;bI=723470;bJ=c[59642]|0;j=147;break;case 147:bK=bH-1|0;if((bK|0)==0){j=149;break}else{j=148;break};case 148:G=a[bJ]|0;a[bI]=G;if(G<<24>>24==0){j=151;break}else{bH=bK;bI=bI+1|0;bJ=bJ+1|0;j=147;break};case 149:a[bI]=0;if((a[bJ]|0)==0){j=151;break}else{bL=bJ;j=150;break};case 150:G=bL+1|0;if((a[G]|0)==0){j=151;break}else{bL=G;j=150;break};case 151:a[719372]=1;j=50;break;case 152:bM=4096;bN=727566;bO=c[59642]|0;j=153;break;case 153:bP=bM-1|0;if((bP|0)==0){j=155;break}else{j=154;break};case 154:G=a[bO]|0;a[bN]=G;if(G<<24>>24==0){j=157;break}else{bM=bP;bN=bN+1|0;bO=bO+1|0;j=153;break};case 155:a[bN]=0;if((a[bO]|0)==0){j=157;break}else{bQ=bO;j=156;break};case 156:G=bQ+1|0;if((a[G]|0)==0){j=157;break}else{bQ=G;j=156;break};case 157:a[719373]=1;j=50;break;case 158:a[719370]=1;j=50;break;case 159:an(2,10)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;an(80,79592)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;aC(24,79328,(H=i,i=i+24|0,c[H>>2]=79032,c[H+8>>2]=78768,c[H+16>>2]=44840,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;aC(24,79328,(H=i,i=i+24|0,c[H>>2]=78168,c[H+8>>2]=77872,c[H+16>>2]=44840,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;aC(24,79328,(H=i,i=i+24|0,c[H>>2]=77512,c[H+8>>2]=77200,c[H+16>>2]=45440,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;aC(24,79328,(H=i,i=i+24|0,c[H>>2]=76920,c[H+8>>2]=76648,c[H+16>>2]=44840,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;aC(24,79328,(H=i,i=i+24|0,c[H>>2]=76384,c[H+8>>2]=76080,c[H+16>>2]=45440,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;aC(24,79328,(H=i,i=i+24|0,c[H>>2]=75768,c[H+8>>2]=75480,c[H+16>>2]=44840,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;aC(24,79328,(H=i,i=i+24|0,c[H>>2]=74960,c[H+8>>2]=74632,c[H+16>>2]=44840,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;aC(24,79328,(H=i,i=i+24|0,c[H>>2]=74320,c[H+8>>2]=74056,c[H+16>>2]=44840,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;aC(24,79328,(H=i,i=i+24|0,c[H>>2]=73840,c[H+8>>2]=74056,c[H+16>>2]=44840,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;aC(24,79328,(H=i,i=i+24|0,c[H>>2]=73624,c[H+8>>2]=74056,c[H+16>>2]=44840,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;aC(24,79328,(H=i,i=i+24|0,c[H>>2]=73352,c[H+8>>2]=74056,c[H+16>>2]=44840,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;aC(24,79328,(H=i,i=i+24|0,c[H>>2]=73128,c[H+8>>2]=74056,c[H+16>>2]=44840,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;aC(24,79328,(H=i,i=i+24|0,c[H>>2]=72904,c[H+8>>2]=74056,c[H+16>>2]=44840,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;aC(24,79328,(H=i,i=i+24|0,c[H>>2]=72624,c[H+8>>2]=74056,c[H+16>>2]=44840,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;aC(24,79328,(H=i,i=i+24|0,c[H>>2]=71880,c[H+8>>2]=74056,c[H+16>>2]=44840,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;aC(24,79328,(H=i,i=i+24|0,c[H>>2]=71520,c[H+8>>2]=71128,c[H+16>>2]=45440,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;aC(24,79328,(H=i,i=i+24|0,c[H>>2]=70856,c[H+8>>2]=74056,c[H+16>>2]=44840,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;aC(24,79328,(H=i,i=i+24|0,c[H>>2]=70616,c[H+8>>2]=70408,c[H+16>>2]=44840,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;aC(24,79328,(H=i,i=i+24|0,c[H>>2]=70344,c[H+8>>2]=70232,c[H+16>>2]=44840,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;aC(24,79328,(H=i,i=i+24|0,c[H>>2]=70136,c[H+8>>2]=70064,c[H+16>>2]=44840,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;aC(24,79328,(H=i,i=i+24|0,c[H>>2]=69776,c[H+8>>2]=69656,c[H+16>>2]=44840,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;aC(24,79328,(H=i,i=i+24|0,c[H>>2]=69480,c[H+8>>2]=69352,c[H+16>>2]=45440,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;aC(24,79328,(H=i,i=i+24|0,c[H>>2]=69296,c[H+8>>2]=69208,c[H+16>>2]=44840,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;aC(24,79328,(H=i,i=i+24|0,c[H>>2]=69168,c[H+8>>2]=69072,c[H+16>>2]=44840,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;aC(24,79328,(H=i,i=i+24|0,c[H>>2]=68984,c[H+8>>2]=68896,c[H+16>>2]=44840,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;aC(24,79328,(H=i,i=i+24|0,c[H>>2]=68472,c[H+8>>2]=68376,c[H+16>>2]=44840,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;aC(24,79328,(H=i,i=i+24|0,c[H>>2]=68216,c[H+8>>2]=68064,c[H+16>>2]=44840,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;ak(120,0);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;return 0;case 160:aI(3244);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;ak(32,83376);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;return 0;case 161:G=c[198610]|0;aG(4,80472,46,1,((G|0)!=0?G:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;G=c[198610]|0;an(102,((G|0)!=0?G:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;ak(32,83376);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;return 0;case 162:bR=(M|0)<(d|0);if((a[795517]&1)==0){j=165;break}else{j=163;break};case 163:if(bR){j=164;break}else{j=168;break};case 164:G=c[198610]|0;aG(4,80160,71,1,((G|0)!=0?G:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;G=c[198610]|0;an(102,((G|0)!=0?G:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;ak(32,83376);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;return 0;case 165:if(bR){j=166;break}else{j=167;break};case 166:ak(58,c[e+(M<<2)>>2]|0);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;j=168;break;case 167:a[795516]=1;j=168;break;case 168:if((a[657928]&1)==0){j=175;break}else{j=169;break};case 169:G=aC(28,678410,z|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((G|0)<0){j=175;break}else{j=170;break};case 170:if((c[z+8>>2]&61440|0)==16384){bS=4096;bT=707082;bU=678410;j=171;break}else{j=175;break};case 171:bV=bS-1|0;if((bV|0)==0){j=173;break}else{j=172;break};case 172:G=a[bU]|0;a[bT]=G;if(G<<24>>24==0){j=175;break}else{bS=bV;bT=bT+1|0;bU=bU+1|0;j=171;break};case 173:a[bT]=0;if((a[bU]|0)==0){j=175;break}else{bW=bU;j=174;break};case 174:G=bW+1|0;if((a[G]|0)==0){j=175;break}else{bW=G;j=174;break};case 175:if((a[657929]&1)==0){j=182;break}else{j=176;break};case 176:G=aC(28,698890,y|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((G|0)<0){j=182;break}else{j=177;break};case 177:if((c[y+8>>2]&61440|0)==16384){bX=4096;bY=711178;bZ=698890;j=178;break}else{j=182;break};case 178:b_=bX-1|0;if((b_|0)==0){j=180;break}else{j=179;break};case 179:G=a[bZ]|0;a[bY]=G;if(G<<24>>24==0){j=182;break}else{bX=b_;bY=bY+1|0;bZ=bZ+1|0;j=178;break};case 180:a[bY]=0;if((a[bZ]|0)==0){j=182;break}else{b$=bZ;j=181;break};case 181:G=b$+1|0;if((a[G]|0)==0){j=182;break}else{b$=G;j=181;break};case 182:if((a[637400]&1)==0){j=185;break}else{j=183;break};case 183:G=c[198610]|0;aG(4,48376,49,1,((G|0)!=0?G:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;G=c[198610]|0;an(102,((G|0)!=0?G:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;G=c[p>>2]|0;aG(4,96928,11,1,G|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;ar(46,G|0,96536,(H=i,i=i+16|0,c[H>>2]=95792,c[H+8>>2]=32,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;ar(46,G|0,95288,(H=i,i=i+8|0,c[H>>2]=94856,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;if((a[637400]&1)==0){j=185;break}else{j=184;break};case 184:G=c[198610]|0;aG(4,47528,50,1,((G|0)!=0?G:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;G=c[198610]|0;an(102,((G|0)!=0?G:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;j=185;break;case 185:if((a[794352]&1)==0){j=186;break}else{j=233;break};case 186:a[535e3]=103;a[535001]=108;a[535002]=0;a[551544]=114;a[551545]=119;a[551546]=101;a[551547]=98;a[551548]=97;a[551549]=117;a[551550]=100;a[551551]=105;a[551552]=111;a[551553]=0;a[559832]=114;a[559833]=119;a[559834]=101;a[559835]=98;a[559836]=105;a[559837]=110;a[559838]=112;a[559839]=117;a[559840]=116;a[559841]=0;g[133766]=3.0;g[133767]=3.0;a[535072]=a[637403]&1;a[535073]=1;c[133769]=0;c[133770]=0;c[133771]=0;a[551536]=0;a[535088]=1;a[535089]=0;c[133773]=0;a[543312]=0;a[535096]=1;a[535097]=1;a[535105]=0;a[535098]=1;g[133775]=-1.0;a[535104]=0;c[133777]=4;a[539208]=0;a[551540]=1;a[551512]=1;g[137877]=48.0;a[551513]=1;g[137879]=.05000000074505806;g[137880]=.05000000074505806;g[137881]=1.0;g[137882]=1.0;g[137883]=0.0;g[135827]=59.95000076293945;a[551537]=0;a[551538]=0;a[551539]=1;a[551576]=1;c[137895]=48e3;g[137896]=48.0e3;c[138921]=64;a[555688]=1;a[559785]=1;g[139947]=.004999999888241291;g[139948]=0.0;a[633244]=0;c[158312]=20971520;c[158313]=1;g[158314]=3.0;g[158315]=-1.0;a[633264]=0;X2(633268,0,7);a[633275]=1;a[633276]=0;b[316639]=-10181;a[633280]=0;c[153190]=100;X5(559896,3464,2240)|0;X5(562136,2464,1e3)|0;X5(564376,2464,1e3)|0;X5(566616,2464,1e3)|0;X5(568856,2464,1e3)|0;X5(571096,2464,1e3)|0;X5(573336,2464,1e3)|0;X5(575576,2464,1e3)|0;b0=0;j=187;break;case 187:G=577832+(b0*40|0)|0;c[G>>2]=65535;c[G+4>>2]=0;c[577848+(b0*40|0)>>2]=-1;G=b0+1|0;if(G>>>0<56){b0=G;j=187;break}else{b1=0;j=213;break};case 188:if((a[559896+(b2*40|0)|0]&1)==0){j=191;break}else{j=189;break};case 189:if((b2|0)==(c[559900+(b2*40|0)>>2]|0)){j=191;break}else{j=190;break};case 190:G=c[198610]|0;ar(46,((G|0)!=0?G:c[p>>2]|0)|0,63392,(H=i,i=i+16|0,c[H>>2]=44336,c[H+8>>2]=248,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;G=c[198610]|0;an(102,((G|0)!=0?G:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;ak(120,2);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;return 0;case 191:G=b2+1|0;if((G|0)<56){b2=G;j=188;break}else{b3=0;j=192;break};case 192:if((a[562136+(b3*40|0)|0]&1)==0){j=194;break}else{j=193;break};case 193:if((b3|0)==(c[562140+(b3*40|0)>>2]|0)){j=194;break}else{j=190;break};case 194:G=b3+1|0;if((G|0)<56){b3=G;j=192;break}else{b4=0;j=195;break};case 195:if((a[564376+(b4*40|0)|0]&1)==0){j=197;break}else{j=196;break};case 196:if((b4|0)==(c[564380+(b4*40|0)>>2]|0)){j=197;break}else{j=190;break};case 197:G=b4+1|0;if((G|0)<56){b4=G;j=195;break}else{b5=0;j=198;break};case 198:if((a[566616+(b5*40|0)|0]&1)==0){j=200;break}else{j=199;break};case 199:if((b5|0)==(c[566620+(b5*40|0)>>2]|0)){j=200;break}else{j=190;break};case 200:G=b5+1|0;if((G|0)<56){b5=G;j=198;break}else{b6=0;j=201;break};case 201:if((a[568856+(b6*40|0)|0]&1)==0){j=203;break}else{j=202;break};case 202:if((b6|0)==(c[568860+(b6*40|0)>>2]|0)){j=203;break}else{j=190;break};case 203:G=b6+1|0;if((G|0)<56){b6=G;j=201;break}else{b7=0;j=204;break};case 204:if((a[571096+(b7*40|0)|0]&1)==0){j=206;break}else{j=205;break};case 205:if((b7|0)==(c[571100+(b7*40|0)>>2]|0)){j=206;break}else{j=190;break};case 206:G=b7+1|0;if((G|0)<56){b7=G;j=204;break}else{b8=0;j=207;break};case 207:if((a[573336+(b8*40|0)|0]&1)==0){j=209;break}else{j=208;break};case 208:if((b8|0)==(c[573340+(b8*40|0)>>2]|0)){j=209;break}else{j=190;break};case 209:G=b8+1|0;if((G|0)<56){b8=G;j=207;break}else{b9=0;j=210;break};case 210:if((a[575576+(b9*40|0)|0]&1)==0){j=212;break}else{j=211;break};case 211:if((b9|0)==(c[575580+(b9*40|0)>>2]|0)){j=212;break}else{j=190;break};case 212:G=b9+1|0;if((G|0)<56){b9=G;j=210;break}else{j=220;break};case 213:G=580072+(b1*40|0)|0;c[G>>2]=65535;c[G+4>>2]=0;c[580088+(b1*40|0)>>2]=-1;G=b1+1|0;if(G>>>0<56){b1=G;j=213;break}else{ca=0;j=214;break};case 214:G=582312+(ca*40|0)|0;c[G>>2]=65535;c[G+4>>2]=0;c[582328+(ca*40|0)>>2]=-1;G=ca+1|0;if(G>>>0<56){ca=G;j=214;break}else{cb=0;j=215;break};case 215:G=584552+(cb*40|0)|0;c[G>>2]=65535;c[G+4>>2]=0;c[584568+(cb*40|0)>>2]=-1;G=cb+1|0;if(G>>>0<56){cb=G;j=215;break}else{cc=0;j=216;break};case 216:G=586792+(cc*40|0)|0;c[G>>2]=65535;c[G+4>>2]=0;c[586808+(cc*40|0)>>2]=-1;G=cc+1|0;if(G>>>0<56){cc=G;j=216;break}else{cd=0;j=217;break};case 217:G=589032+(cd*40|0)|0;c[G>>2]=65535;c[G+4>>2]=0;c[589048+(cd*40|0)>>2]=-1;G=cd+1|0;if(G>>>0<56){cd=G;j=217;break}else{ce=0;j=218;break};case 218:G=591272+(ce*40|0)|0;c[G>>2]=65535;c[G+4>>2]=0;c[591288+(ce*40|0)>>2]=-1;G=ce+1|0;if(G>>>0<56){ce=G;j=218;break}else{cf=0;j=219;break};case 219:G=593512+(cf*40|0)|0;c[G>>2]=65535;c[G+4>>2]=0;c[593528+(cf*40|0)>>2]=-1;G=cf+1|0;if(G>>>0<56){cf=G;j=219;break}else{b2=0;j=188;break};case 220:g[148936]=.5;a[596358]=1;c[149090]=6;c[149091]=3;g[150116]=1.0;g[150117]=1.0;a[596356]=0;a[596357]=1;c[148937]=0;c[148938]=1;c[148939]=2;c[148940]=3;c[148941]=4;c[148942]=5;c[148943]=6;c[148944]=7;a[794446]=0;X2(794384,0,16);a[794352]=1;aI(2244);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;cg=(a[637400]&1)!=0;if((a[657930]|0)==0){j=224;break}else{j=221;break};case 221:if(cg){j=222;break}else{j=223;break};case 222:G=c[198610]|0;ar(46,((G|0)!=0?G:c[p>>2]|0)|0,84848,(H=i,i=i+8|0,c[H>>2]=657930,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;G=c[198610]|0;an(102,((G|0)!=0?G:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;j=223;break;case 223:G=an(38,657930)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if(G){j=233;break}else{j=230;break};case 224:if(cg){j=225;break}else{j=226;break};case 225:G=c[198610]|0;aG(4,84496,35,1,((G|0)!=0?G:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;G=c[198610]|0;an(102,((G|0)!=0?G:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;j=226;break;case 226:ch=an(38,0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((a[657930]|0)==0){j=229;break}else{j=227;break};case 227:if((a[637400]&1)==0){j=229;break}else{j=228;break};case 228:G=c[198610]|0;ar(46,((G|0)!=0?G:c[p>>2]|0)|0,84112,(H=i,i=i+8|0,c[H>>2]=657930,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;G=c[198610]|0;an(102,((G|0)!=0?G:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if(ch){j=233;break}else{j=230;break};case 229:if(ch){j=233;break}else{j=230;break};case 230:G=c[198610]|0;ar(46,((G|0)!=0?G:c[p>>2]|0)|0,83768,(H=i,i=i+8|0,c[H>>2]=657930,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;G=c[198610]|0;an(102,((G|0)!=0?G:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((a[794445]&1)==0){j=231;break}else{j=232;break};case 231:G=c[198610]|0;ar(46,((G|0)!=0?G:c[p>>2]|0)|0,63392,(H=i,i=i+16|0,c[H>>2]=83144,c[H+8>>2]=827,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;G=c[198610]|0;an(102,((G|0)!=0?G:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;ak(120,2);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;return 0;case 232:a[794447]=112;a[794448]=97;a[794449]=114;a[794450]=115;a[794451]=101;a[794452]=95;a[794453]=99;a[794454]=111;a[794455]=110;a[794456]=102;a[794457]=105;a[794458]=103;a[794459]=95;a[794460]=102;a[794461]=105;a[794462]=108;a[794463]=101;a[794464]=40;a[794465]=41;a[794466]=0;al(90,795472,1);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;return 0;case 233:G=(a[795517]&1)!=0;W=G?98:18;c[59490]=G?2626:1664;c[59502]=G?1092:2590;c[59508]=G?16:18;c[59492]=G?38:90;c[59494]=G?64:80;c[59470]=W;c[59464]=G?62:116;c[59476]=G?72:56;c[59474]=G?48:84;c[59468]=G?20:78;c[59466]=G?60:52;c[59472]=G?92:80;c[59484]=G?2490:1118;c[59482]=G?2222:1184;c[59478]=G?10:6;c[59480]=G?12:48;c[59460]=G?46:22;c[59506]=G?430:2644;c[59504]=G?284:280;c[59488]=G?8:48;c[59486]=G?40:38;c[59462]=G?2756:2344;c[59496]=G?24:4;c[59500]=G?50:74;c[59498]=G?56:4;ak(W|0,10);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;ak(c[59492]|0,731688);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;W=c[182922]|0;if((W|0)==0){j=234;break}else{ci=W;j=235;break};case 234:c[182922]=38256;ci=38256;j=235;break;case 235:W=c[182923]|0;if((W|0)==0){j=236;break}else{cj=W;j=237;break};case 236:c[182923]=51888;cj=51888;j=237;break;case 237:aG(2,794208,64,50896,(H=i,i=i+16|0,c[H>>2]=ci,c[H+8>>2]=cj,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;W=c[182924]|0;ck=4096;cl=732280;cm=(W|0)==0?50168:W;j=238;break;case 238:cn=ck-1|0;if((cn|0)==0){j=240;break}else{j=239;break};case 239:W=a[cm]|0;a[cl]=W;if(W<<24>>24==0){j=242;break}else{ck=cn;cl=cl+1|0;cm=cm+1|0;j=238;break};case 240:a[cl]=0;if((a[cm]|0)==0){j=242;break}else{co=cm;j=241;break};case 241:W=co+1|0;if((a[W]|0)==0){j=242;break}else{co=W;j=241;break};case 242:a[731764]=a[731701]&1;cp=0;j=243;break;case 243:if(cp>>>0<2){j=244;break}else{j=245;break};case 244:cq=c[19296+(cp<<2)>>2]|0;W=aC(14,551544,c[cq+28>>2]|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((W|0)==0){j=252;break}else{cp=cp+1|0;j=243;break};case 245:W=c[198610]|0;ar(46,((W|0)!=0?W:c[p>>2]|0)|0,50368,(H=i,i=i+8|0,c[H>>2]=551544,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;W=c[198610]|0;an(102,((W|0)!=0?W:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;W=a[637400]|0;if((W&1)==0){cr=W;j=247;break}else{j=246;break};case 246:W=c[198610]|0;aG(4,49504,29,1,((W|0)!=0?W:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;W=c[198610]|0;an(102,((W|0)!=0?W:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;cr=a[637400]|0;j=247;break;case 247:if((cr&1)==0){cs=cr;j=249;break}else{j=248;break};case 248:W=c[198610]|0;ar(46,((W|0)!=0?W:c[p>>2]|0)|0,54744,(H=i,i=i+8|0,c[H>>2]=95112,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;W=c[198610]|0;an(102,((W|0)!=0?W:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;cs=a[637400]|0;j=249;break;case 249:if((cs&1)==0){j=251;break}else{j=250;break};case 250:W=c[198610]|0;ar(46,((W|0)!=0?W:c[p>>2]|0)|0,54744,(H=i,i=i+8|0,c[H>>2]=84936,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;W=c[198610]|0;an(102,((W|0)!=0?W:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;j=251;break;case 251:ak(68,48720);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;return 0;case 252:c[199304]=cq;W=aC(14,535e3,65912)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((W|0)==0){j=258;break}else{j=253;break};case 253:W=c[198610]|0;ar(46,((W|0)!=0?W:c[p>>2]|0)|0,52920,(H=i,i=i+8|0,c[H>>2]=535e3,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;W=c[198610]|0;an(102,((W|0)!=0?W:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;W=a[637400]|0;if((W&1)==0){ct=W;j=255;break}else{j=254;break};case 254:W=c[198610]|0;aG(4,52104,29,1,((W|0)!=0?W:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;W=c[198610]|0;an(102,((W|0)!=0?W:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;ct=a[637400]|0;j=255;break;case 255:if((ct&1)==0){j=257;break}else{j=256;break};case 256:W=c[198610]|0;ar(46,((W|0)!=0?W:c[p>>2]|0)|0,54744,(H=i,i=i+8|0,c[H>>2]=65912,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;W=c[198610]|0;an(102,((W|0)!=0?W:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;j=257;break;case 257:ak(68,51192);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;return 0;case 258:c[199305]=72;W=aC(14,559832,99344)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((W|0)==0){j=264;break}else{j=259;break};case 259:W=c[198610]|0;ar(46,((W|0)!=0?W:c[p>>2]|0)|0,56824,(H=i,i=i+8|0,c[H>>2]=559832,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;W=c[198610]|0;an(102,((W|0)!=0?W:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;W=a[637400]|0;if((W&1)==0){cu=W;j=261;break}else{j=260;break};case 260:W=c[198610]|0;aG(4,55928,29,1,((W|0)!=0?W:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;W=c[198610]|0;an(102,((W|0)!=0?W:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;cu=a[637400]|0;j=261;break;case 261:if((cu&1)==0){j=263;break}else{j=262;break};case 262:W=c[198610]|0;ar(46,((W|0)!=0?W:c[p>>2]|0)|0,54744,(H=i,i=i+8|0,c[H>>2]=99344,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;W=c[198610]|0;an(102,((W|0)!=0?W:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;j=263;break;case 263:ak(68,53856);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;return 0;case 264:c[199306]=7808;W=a[637400]|0;if((W&1)==0){cv=W;j=266;break}else{j=265;break};case 265:W=c[198610]|0;G=(W|0)!=0?W:c[p>>2]|0;W=aF(c[59508]|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;ar(46,G|0,98232,(H=i,i=i+8|0,c[H>>2]=W,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;W=c[198610]|0;an(102,((W|0)!=0?W:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;cv=a[637400]|0;j=266;break;case 266:if((cv&1)==0){j=268;break}else{j=267;break};case 267:W=c[198610]|0;ar(46,((W|0)!=0?W:c[p>>2]|0)|0,97752,(H=i,i=i+8|0,c[H>>2]=1,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;W=c[198610]|0;an(102,((W|0)!=0?W:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;j=268;break;case 268:W=aF(c[59508]|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((W|0)==1){j=270;break}else{j=269;break};case 269:W=c[198610]|0;aG(4,97296,117,1,((W|0)!=0?W:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;W=c[198610]|0;an(102,((W|0)!=0?W:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;j=270;break;case 270:aI(c[59490]|0);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;cw=(a[795517]&1)==0;W=a[795516]&1;a[794146]=cw?W^1:0;if(W<<24>>24==0){j=273;break}else{j=271;break};case 271:if(cw){j=272;break}else{j=369;break};case 272:W=an(16,c[160384]|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if(W){j=369;break}else{j=493;break};case 273:if(cw){j=274;break}else{j=369;break};case 274:aI(2436);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;W=an(16,c[160384]|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if(W){j=275;break}else{j=493;break};case 275:cx=A|0;cy=B|0;cz=C|0;if((a[633273]&1)==0){j=289;break}else{j=276;break};case 276:al(88,cx|0,698890);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;aH(154,cy|0,698890,4096);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;cA=ar(32,cx|0,0,0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((cA|0)==0){j=289;break}else{j=277;break};case 277:cB=cA+4|0;cC=cA|0;if((c[cB>>2]|0)==0){j=278;break}else{cD=0;cE=0;j=279;break};case 278:cF=c[cC>>2]|0;cG=0;j=287;break;case 279:cH=c[(c[cC>>2]|0)+(cD<<3)>>2]|0;aH(154,cz|0,cH|0,4096);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;W=an(10,cy|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;G=ar(2,cz|0,cy|0,W|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((G|0)==0){j=280;break}else{cI=cE;j=284;break};case 280:G=an(10,cH|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;cJ=cH+G|0;j=281;break;case 281:if(cJ>>>0>cH>>>0){j=282;break}else{j=283;break};case 282:G=cJ-1|0;if(((a[G]|0)-48|0)>>>0<10){cJ=G;j=281;break}else{j=283;break};case 283:G=ar(4,cJ|0,0,0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;cI=G>>>0>cE>>>0?G:cE;j=284;break;case 284:G=cD+1|0;cK=c[cB>>2]|0;if(G>>>0<cK>>>0){cD=G;cE=cI;j=279;break}else{j=285;break};case 285:G=c[cC>>2]|0;if((cK|0)==0){cF=G;cG=cI;j=287;break}else{cL=0;cM=G;j=286;break};case 286:ak(36,c[cM+(cL<<3)>>2]|0);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;G=cL+1|0;W=c[cC>>2]|0;if(G>>>0<(c[cB>>2]|0)>>>0){cL=G;cM=W;j=286;break}else{cF=W;cG=cI;j=287;break};case 287:ak(36,cF|0);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;ak(36,cA|0);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;c[182916]=cG;if((a[637400]&1)==0){j=289;break}else{j=288;break};case 288:W=c[198610]|0;ar(46,((W|0)!=0?W:c[p>>2]|0)|0,98608,(H=i,i=i+8|0,c[H>>2]=cG,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;W=c[198610]|0;an(102,((W|0)!=0?W:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;j=289;break;case 289:if((a[794144]&1)==0){j=290;break}else{j=323;break};case 290:switch(c[160384]|0){case 0:{j=291;break};case 1:{j=299;break};case 2:case 3:{j=307;break};case 4:{j=315;break};default:{j=325;break}}break;case 291:cN=an(c[59498]|0,0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;cO=an(c[59500]|0,0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((cN|0)==0|(cO|0)==0){j=295;break}else{j=292;break};case 292:c[x>>2]=0;cP=aC(2,678410,x|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;cQ=c[x>>2]|0;if((cP|0)<1|(cP|0)>(cN|0)){j=294;break}else{j=293;break};case 293:X5(cO|0,cQ|0,cP)|0;j=294;break;case 294:ak(36,cQ|0);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;j=295;break;case 295:cR=an(c[59498]|0,1)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;cS=an(c[59500]|0,1)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((cR|0)==0|(cS|0)==0){j=325;break}else{j=296;break};case 296:c[w>>2]=0;cT=aC(2,682506,w|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;cU=c[w>>2]|0;if((cT|0)<1|(cT|0)>(cR|0)){j=298;break}else{j=297;break};case 297:X5(cS|0,cU|0,cT)|0;j=298;break;case 298:ak(36,cU|0);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;j=325;break;case 299:cV=an(c[59498]|0,1280)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;cW=an(c[59500]|0,1280)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((cV|0)==0|(cW|0)==0){j=303;break}else{j=300;break};case 300:c[v>>2]=0;cX=aC(2,678410,v|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;cY=c[v>>2]|0;if((cX|0)<1|(cX|0)>(cV|0)){j=302;break}else{j=301;break};case 301:X5(cW|0,cY|0,cX)|0;j=302;break;case 302:ak(36,cY|0);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;j=303;break;case 303:cZ=an(c[59498]|0,1537)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;c_=an(c[59500]|0,1537)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((cZ|0)==0|(c_|0)==0){j=325;break}else{j=304;break};case 304:c[u>>2]=0;c$=aC(2,682506,u|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;c0=c[u>>2]|0;if((c$|0)<1|(c$|0)>(cZ|0)){j=306;break}else{j=305;break};case 305:X5(c_|0,c0|0,c$)|0;j=306;break;case 306:ak(36,c0|0);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;j=325;break;case 307:c1=an(c[59498]|0,256)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;c2=an(c[59500]|0,256)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((c1|0)==0|(c2|0)==0){j=311;break}else{j=308;break};case 308:c[r>>2]=0;c3=aC(2,678410,r|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;c4=c[r>>2]|0;if((c3|0)<1|(c3|0)>(c1|0)){j=310;break}else{j=309;break};case 309:X5(c2|0,c4|0,c3)|0;j=310;break;case 310:ak(36,c4|0);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;j=311;break;case 311:c5=an(c[59498]|0,512)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;c6=an(c[59500]|0,512)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((c5|0)==0|(c6|0)==0){j=325;break}else{j=312;break};case 312:c[q>>2]=0;c7=aC(2,686602,q|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;c8=c[q>>2]|0;if((c7|0)<1|(c7|0)>(c5|0)){j=314;break}else{j=313;break};case 313:X5(c6|0,c8|0,c7)|0;j=314;break;case 314:ak(36,c8|0);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;j=325;break;case 315:c9=an(c[59498]|0,768)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;da=an(c[59500]|0,768)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((c9|0)==0|(da|0)==0){j=319;break}else{j=316;break};case 316:c[o>>2]=0;db=aC(2,690698,o|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;dc=c[o>>2]|0;if((db|0)<1|(db|0)>(c9|0)){j=318;break}else{j=317;break};case 317:X5(da|0,dc|0,db)|0;j=318;break;case 318:ak(36,dc|0);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;j=319;break;case 319:dd=an(c[59498]|0,1024)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;de=an(c[59500]|0,1024)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((dd|0)==0|(de|0)==0){j=325;break}else{j=320;break};case 320:c[n>>2]=0;df=aC(2,694794,n|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;dg=c[n>>2]|0;if((df|0)<1|(df|0)>(dd|0)){j=322;break}else{j=321;break};case 321:X5(de|0,dg|0,df)|0;j=322;break;case 322:ak(36,dg|0);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;j=325;break;case 323:if((a[637400]&1)==0){j=325;break}else{j=324;break};case 324:W=c[198610]|0;aG(4,45976,31,1,((W|0)!=0?W:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;W=c[198610]|0;an(102,((W|0)!=0?W:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;j=325;break;case 325:if((a[633275]&1)==0){j=338;break}else{j=326;break};case 326:aH(52,cx|0,698890,38344);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;dh=aC(4,cx|0,23072)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((dh|0)==0){j=338;break}else{j=327;break};case 327:an(46,dh|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((a[637400]&1)==0){j=329;break}else{j=328;break};case 328:W=c[198610]|0;ar(46,((W|0)!=0?W:c[p>>2]|0)|0,99360,(H=i,i=i+8|0,c[H>>2]=cx,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;W=c[198610]|0;an(102,((W|0)!=0?W:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;j=329;break;case 329:W=an(68,cx|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;aG(2,cy|0,4096,98984,(H=i,i=i+16|0,c[H>>2]=cx,c[H+8>>2]=W?37776:37488,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;di=c[196481]|0;dj=di+4|0;if((c[dj>>2]|0)>>>0<(c[di+8>>2]|0)>>>0){j=330;break}else{j=336;break};case 330:dk=an(84,12)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((dk|0)==0){j=333;break}else{j=331;break};case 331:if((c[dk-4>>2]&3|0)==0){j=333;break}else{j=332;break};case 332:X2(dk|0,0,12);j=333;break;case 333:W=dk;c[dk+4>>2]=1;c[dk>>2]=180;G=an(92,cy|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;dl=c[dj>>2]|0;c[dk+8>>2]=G;dm=di|0;c[(c[dm>>2]|0)+(dl<<2)>>2]=W;W=c[dj>>2]|0;c[dj>>2]=W+1;if(W>>>0>1){dn=W;j=334;break}else{j=336;break};case 334:dp=dn>>>1;W=c[dm>>2]|0;dq=W+(dp<<2)|0;dr=c[dq>>2]|0;ds=c[W+(dn<<2)>>2]|0;if((c[ds+4>>2]|0)>>>0>(c[dr+4>>2]|0)>>>0){j=335;break}else{j=336;break};case 335:c[dq>>2]=ds;c[(c[dm>>2]|0)+(dn<<2)>>2]=dr;if(dn>>>0>3){dn=dp;j=334;break}else{j=336;break};case 336:if((a[637400]&1)==0){j=338;break}else{j=337;break};case 337:W=c[198610]|0;ar(46,((W|0)!=0?W:c[p>>2]|0)|0,93640,(H=i,i=i+8|0,c[H>>2]=cy,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;W=c[198610]|0;an(102,((W|0)!=0?W:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;j=338;break;case 338:if((a[794142]&1)==0){j=351;break}else{j=339;break};case 339:W=aC(44,790045,0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;c[196486]=W;if((W|0)==0){j=340;break}else{j=341;break};case 340:W=c[198610]|0;ar(46,((W|0)!=0?W:c[p>>2]|0)|0,20160,(H=i,i=i+8|0,c[H>>2]=790045,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;W=c[198610]|0;an(102,((W|0)!=0?W:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;ak(32,101224);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;return 0;case 341:a[790044]=1;dt=c[196481]|0;du=dt+4|0;if((c[du>>2]|0)>>>0<(c[dt+8>>2]|0)>>>0){j=342;break}else{j=348;break};case 342:dv=an(84,12)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((dv|0)==0){j=345;break}else{j=343;break};case 343:if((c[dv-4>>2]&3|0)==0){j=345;break}else{j=344;break};case 344:X2(dv|0,0,12);j=345;break;case 345:W=dv;c[dv+4>>2]=2;c[dv>>2]=180;dl=an(92,100920)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;G=c[du>>2]|0;c[dv+8>>2]=dl;dw=dt|0;c[(c[dw>>2]|0)+(G<<2)>>2]=W;W=c[du>>2]|0;c[du>>2]=W+1;if(W>>>0>1){dx=W;j=346;break}else{j=348;break};case 346:dy=dx>>>1;W=c[dw>>2]|0;dz=W+(dy<<2)|0;dA=c[dz>>2]|0;dB=c[W+(dx<<2)>>2]|0;if((c[dB+4>>2]|0)>>>0>(c[dA+4>>2]|0)>>>0){j=347;break}else{j=348;break};case 347:c[dz>>2]=dB;c[(c[dw>>2]|0)+(dx<<2)>>2]=dA;if(dx>>>0>3){dx=dy;j=346;break}else{j=348;break};case 348:if((a[637400]&1)==0){j=350;break}else{j=349;break};case 349:W=c[198610]|0;aG(4,100120,36,1,((W|0)!=0?W:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;W=c[198610]|0;an(102,((W|0)!=0?W:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;j=350;break;case 350:c[158313]=1;j=369;break;case 351:if((a[794141]&1)==0){j=369;break}else{j=352;break};case 352:aG(2,cx|0,4096,28072,(H=i,i=i+8|0,c[H>>2]=790045,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;W=aC(44,790045,1)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;c[196486]=W;dC=c[196481]|0;dD=dC+4|0;dE=c[dD>>2]|0;if(dE>>>0>1){j=353;break}else{j=357;break};case 353:dF=dC|0;dG=1;dH=dE;j=354;break;case 354:dI=c[(c[dF>>2]|0)+(dG<<2)>>2]|0;if((dI|0)==0){dJ=dH;j=356;break}else{j=355;break};case 355:ak(36,c[dI+8>>2]|0);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;ak(36,c[(c[dF>>2]|0)+(dG<<2)>>2]|0);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;c[(c[dF>>2]|0)+(dG<<2)>>2]=0;dJ=c[dD>>2]|0;j=356;break;case 356:W=dG+1|0;if(W>>>0<dJ>>>0){dG=W;dH=dJ;j=354;break}else{j=357;break};case 357:c[dD>>2]=1;W=dC+12|0;ak(36,c[W>>2]|0);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;c[W>>2]=0;dK=c[196481]|0;dL=dK+4|0;if((c[dL>>2]|0)>>>0<(c[dK+8>>2]|0)>>>0){j=358;break}else{j=364;break};case 358:dM=(c[196486]|0)!=0?cx:27680;dN=an(84,12)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((dN|0)==0){j=361;break}else{j=359;break};case 359:if((c[dN-4>>2]&3|0)==0){j=361;break}else{j=360;break};case 360:X2(dN|0,0,12);j=361;break;case 361:W=dN;c[dN+4>>2]=1;c[dN>>2]=180;G=an(92,dM|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;dl=c[dL>>2]|0;c[dN+8>>2]=G;dO=dK|0;c[(c[dO>>2]|0)+(dl<<2)>>2]=W;W=c[dL>>2]|0;c[dL>>2]=W+1;if(W>>>0>1){dP=W;j=362;break}else{j=364;break};case 362:dQ=dP>>>1;W=c[dO>>2]|0;dR=W+(dQ<<2)|0;dS=c[dR>>2]|0;dT=c[W+(dP<<2)>>2]|0;if((c[dT+4>>2]|0)>>>0>(c[dS+4>>2]|0)>>>0){j=363;break}else{j=364;break};case 363:c[dR>>2]=dT;c[(c[dO>>2]|0)+(dP<<2)>>2]=dS;if(dP>>>0>3){dP=dQ;j=362;break}else{j=364;break};case 364:if((c[196486]|0)==0){j=368;break}else{j=365;break};case 365:if((a[637400]&1)==0){j=367;break}else{j=366;break};case 366:W=c[198610]|0;ar(46,((W|0)!=0?W:c[p>>2]|0)|0,27336,(H=i,i=i+8|0,c[H>>2]=790045,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;W=c[198610]|0;an(102,((W|0)!=0?W:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;j=367;break;case 367:c[158313]=1;j=369;break;case 368:W=c[198610]|0;aG(4,26592,51,1,((W|0)!=0?W:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;W=c[198610]|0;an(102,((W|0)!=0?W:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;j=369;break;case 369:ak(c[59464]|0,58);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;ak(c[59476]|0,64);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;ak(c[59474]|0,18);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;ak(c[59466]|0,8);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;ak(c[59468]|0,612);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;ak(c[59494]|0,731704);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;dU=+aE(2);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;dV=dU*1.0e3;W=+Q(dV)>=1.0?dV>0.0?(ag(+P(dV/4294967296.0),4294967295.0)|0)>>>0:~~+aa((dV- +(~~dV>>>0))/4294967296.0)>>>0:0;dl=731680;c[dl>>2]=~~dV>>>0;c[dl+4>>2]=W;dV=+aA(2,+(1.0e6/(+h[91466]*+g[158315])));if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;W=+Q(dV)>=1.0?dV>0.0?(ag(+P(dV/4294967296.0),4294967295.0)|0)>>>0:~~+aa((dV- +(~~dV>>>0))/4294967296.0)>>>0:0;dl=731672;c[dl>>2]=~~dV>>>0;c[dl+4>>2]=W;aI(2804);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;aI(974);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;aI(3774);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((a[794146]&1)==0){j=370;break}else{j=371;break};case 370:a[794146]=0;j=372;break;case 371:W=a[794145]&1;a[794146]=W^1;if(W<<24>>24==0){j=374;break}else{j=372;break};case 372:if((a[637400]&1)==0){j=374;break}else{j=373;break};case 373:W=c[198610]|0;aG(4,45352,35,1,((W|0)!=0?W:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;W=c[198610]|0;an(102,((W|0)!=0?W:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;j=374;break;case 374:if((c[196486]|0)!=0|(a[616860]|0)==0){j=492;break}else{j=375;break};case 375:aI(c[59506]|0);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;dW=an(84,16)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((dW|0)==0){dX=0;j=491;break}else{j=376;break};case 376:if((c[dW-4>>2]&3|0)==0){j=378;break}else{j=377;break};case 377:X2(dW|0,0,16);j=378;break;case 378:dY=dW;dZ=dW+12|0;c[dZ>>2]=1;d_=an(84,12)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((d_|0)==0){j=382;break}else{j=379;break};case 379:if((c[d_-4>>2]&3|0)==0){j=380;break}else{j=381;break};case 380:W=dW;c[W>>2]=d_;d$=W;j=383;break;case 381:X2(d_|0,0,12);W=dW;c[W>>2]=d_;d$=W;j=383;break;case 382:c[dW>>2]=0;c[dZ>>2]=0;j=484;break;case 383:d0=an(96,616860)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((d0|0)==0){j=384;break}else{j=385;break};case 384:W=c[198610]|0;ar(46,((W|0)!=0?W:c[p>>2]|0)|0,40040,(H=i,i=i+8|0,c[H>>2]=616860,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;W=c[198610]|0;an(102,((W|0)!=0?W:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;j=484;break;case 385:d1=d0|0;W=c[d1>>2]|0;if((W|0)==0){j=386;break}else{d2=W;j=387;break};case 386:ak(26,dY|0);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;j=486;break;case 387:if((c[d2+20>>2]|0)==0){j=388;break}else{j=389;break};case 388:W=aC(38,c[d2>>2]|0,96560)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((W|0)==0){j=390;break}else{j=389;break};case 389:W=c[d2+16>>2]|0;if((W|0)==0){j=485;break}else{d2=W;j=387;break};case 390:d3=c[d2+12>>2]|0;if((d3|0)==0){j=485;break}else{j=391;break};case 391:if((a[794280]|0)==0){d4=d3;j=392;break}else{d5=d3;j=398;break};case 392:if((c[d4+20>>2]|0)==0){j=393;break}else{j=397;break};case 393:W=aC(38,c[d4>>2]|0,67264)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((W|0)==0){j=394;break}else{j=397;break};case 394:d6=d4+8|0;j=395;break;case 395:d7=c[d6>>2]|0;if((d7|0)==0){j=397;break}else{j=396;break};case 396:W=aC(38,56416,c[d7>>2]|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((W|0)==0){j=397;break}else{d6=d7+8|0;j=395;break};case 397:W=c[d4+16>>2]|0;if((W|0)==0){j=485;break}else{d4=W;j=392;break};case 398:if((c[d5+20>>2]|0)==0){j=399;break}else{j=405;break};case 399:W=aC(38,c[d5>>2]|0,67264)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((W|0)==0){j=400;break}else{j=405;break};case 400:d8=d5+8|0;j=401;break;case 401:d9=c[d8>>2]|0;if((d9|0)==0){j=405;break}else{j=402;break};case 402:W=aC(38,56416,c[d9>>2]|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((W|0)==0){j=403;break}else{d8=d9+8|0;j=401;break};case 403:ea=c[d9+4>>2]|0;if((ea|0)==0){j=405;break}else{j=404;break};case 404:W=aC(38,ea|0,794280)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((W|0)==0){j=406;break}else{j=405;break};case 405:W=c[d5+16>>2]|0;if((W|0)==0){j=485;break}else{d5=W;j=398;break};case 406:W=c[d5+12>>2]|0;eb=dW+8|0;if((W|0)==0){j=465;break}else{ec=W;j=407;break};case 407:ed=c[ec>>2]|0;W=aC(38,ed|0,85544)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((W|0)==0){j=408;break}else{j=411;break};case 408:ee=c[ec+4>>2]|0;if((ee|0)==0){j=463;break}else{j=409;break};case 409:if((a[637400]&1)==0){j=463;break}else{j=410;break};case 410:W=c[198610]|0;ar(46,((W|0)!=0?W:c[p>>2]|0)|0,82064,(H=i,i=i+8|0,c[H>>2]=ee,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;W=c[198610]|0;an(102,((W|0)!=0?W:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;j=463;break;case 411:W=aC(38,ed|0,78704)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((W|0)==0){j=412;break}else{j=463;break};case 412:ef=c[eb>>2]|0;if((ef|0)==(c[dZ>>2]|0)){j=414;break}else{j=413;break};case 413:eg=ef;eh=c[d$>>2]|0;j=416;break;case 414:c[dZ>>2]=ef<<1;W=aC(20,c[d$>>2]|0,ef*24|0|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;ei=W;c[d$>>2]=ei;if((W|0)==0){j=464;break}else{j=415;break};case 415:eg=c[eb>>2]|0;eh=ei;j=416;break;case 416:ej=eh+(eg*12|0)|0;ek=c[ec+12>>2]|0;if((ek|0)==0){j=463;break}else{j=417;break};case 417:X2(ej|0,0,12);el=ej|0;em=eh+(eg*12|0)+8|0;en=ek;eo=1;ep=0;eq=0;j=418;break;case 418:er=c[en>>2]|0;W=aC(38,er|0,75408)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((W|0)==0){j=419;break}else{j=420;break};case 419:c[el>>2]=c[en+4>>2];es=eo;et=ep;eu=eq;j=461;break;case 420:W=aC(38,er|0,72488)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((W|0)==0){j=421;break}else{es=eo;et=ep;eu=eq;j=461;break};case 421:if(eo){ev=ep;j=440;break}else{j=422;break};case 422:ew=(eq|0)!=0;if(ew){j=423;break}else{ex=2;j=424;break};case 423:W=an(10,eq|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;ex=W+2|0;j=424;break;case 424:ey=aC(20,eq|0,ex|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((ey|0)==0){j=425;break}else{j=426;break};case 425:c[em>>2]=0;j=463;break;case 426:if(ew){j=427;break}else{j=434;break};case 427:ez=an(10,ey|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;eA=ez>>>0>ex>>>0?0:ex-ez|0;if((eA|0)==0){eB=70032;j=431;break}else{j=428;break};case 428:eC=ey+ez|0;if((eA|0)==1){eD=70032;eE=eC;j=430;break}else{j=429;break};case 429:eF=ey+(ez+1)|0;a[eC]=43;if((eA|0)==2){eD=70033;eE=eF;j=430;break}else{j=490;break};case 430:a[eE]=0;eB=eD;j=431;break;case 431:if((a[eB]|0)==0){j=433;break}else{eG=eB;j=432;break};case 432:W=eG+1|0;if((a[W]|0)==0){j=433;break}else{eG=W;j=432;break};case 433:c[em>>2]=ey;ev=ey;j=440;break;case 434:if((ex|0)==1){eH=70032;eI=ey;j=436;break}else if((ex|0)==0){eJ=70032;j=437;break}else{j=435;break};case 435:eK=ey+1|0;a[ey]=43;if((ex|0)==2){eH=70033;eI=eK;j=436;break}else{j=489;break};case 436:a[eI]=0;eJ=eH;j=437;break;case 437:if((a[eJ]|0)==0){j=439;break}else{eL=eJ;j=438;break};case 438:W=eL+1|0;if((a[W]|0)==0){j=439;break}else{eL=W;j=438;break};case 439:c[em>>2]=ey;ev=ey;j=440;break;case 440:eM=c[en+4>>2]|0;if((eM|0)==0){j=463;break}else{j=441;break};case 441:eN=(ev|0)!=0;if(eN){j=442;break}else{eO=1;j=443;break};case 442:W=an(10,ev|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;eO=W+1|0;j=443;break;case 443:W=an(10,eM|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;eP=W+eO|0;eQ=aC(20,ev|0,eP|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((eQ|0)==0){j=444;break}else{j=445;break};case 444:c[em>>2]=0;j=463;break;case 445:if(eN){j=446;break}else{j=454;break};case 446:eR=an(10,eQ|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;eS=eR>>>0>eP>>>0?0:eP-eR|0;if((eS|0)==0){eT=eM;j=451;break}else{j=447;break};case 447:eU=eS;eV=eQ+eR|0;eW=eM;j=448;break;case 448:eX=eU-1|0;if((eX|0)==0){j=450;break}else{j=449;break};case 449:W=a[eW]|0;a[eV]=W;if(W<<24>>24==0){j=453;break}else{eU=eX;eV=eV+1|0;eW=eW+1|0;j=448;break};case 450:a[eV]=0;eT=eW;j=451;break;case 451:if((a[eT]|0)==0){j=453;break}else{eY=eT;j=452;break};case 452:W=eY+1|0;if((a[W]|0)==0){j=453;break}else{eY=W;j=452;break};case 453:c[em>>2]=eQ;es=0;et=eQ;eu=eQ;j=461;break;case 454:if((eP|0)==0){eZ=eM;j=458;break}else{e_=eP;e$=eQ;e0=eM;j=455;break};case 455:e1=e_-1|0;if((e1|0)==0){j=457;break}else{j=456;break};case 456:W=a[e0]|0;a[e$]=W;if(W<<24>>24==0){j=460;break}else{e_=e1;e$=e$+1|0;e0=e0+1|0;j=455;break};case 457:a[e$]=0;eZ=e0;j=458;break;case 458:if((a[eZ]|0)==0){j=460;break}else{e2=eZ;j=459;break};case 459:W=e2+1|0;if((a[W]|0)==0){j=460;break}else{e2=W;j=459;break};case 460:c[em>>2]=eQ;es=0;et=eQ;eu=eQ;j=461;break;case 461:W=c[en+16>>2]|0;if((W|0)==0){j=462;break}else{en=W;eo=es;ep=et;eq=eu;j=418;break};case 462:c[eb>>2]=(c[eb>>2]|0)+1;j=463;break;case 463:W=c[ec+16>>2]|0;if((W|0)==0){j=465;break}else{ec=W;j=407;break};case 464:W=c[198610]|0;aG(4,47352,68,1,((W|0)!=0?W:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;W=c[198610]|0;an(102,((W|0)!=0?W:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;j=485;break;case 465:if((c[eb>>2]|0)==0){j=466;break}else{j=467;break};case 466:W=c[198610]|0;ar(46,((W|0)!=0?W:c[p>>2]|0)|0,40400,(H=i,i=i+8|0,c[H>>2]=616860,H)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;i=H;W=c[198610]|0;an(102,((W|0)!=0?W:c[p>>2]|0)|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;j=485;break;case 467:if((a[620956]|0)==0){j=481;break}else{j=468;break};case 468:e3=aC(30,620956,0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((e3|0)==0){j=481;break}else{j=469;break};case 469:e4=e3+4|0;j=470;break;case 470:e5=c[e4>>2]|0;if((e5|0)==0){j=472;break}else{j=471;break};case 471:W=aC(38,794280,c[e5+4>>2]|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((W|0)==0){j=473;break}else{e4=e5+12|0;j=470;break};case 472:ak(70,e3|0);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;j=481;break;case 473:e6=an(92,c[e5+8>>2]|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;W=ar(10,e6|0,53448,m|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((W|0)==0){j=477;break}else{e7=W;j=474;break};case 474:e8=ar(4,e7|0,0,0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if(e8>>>0<(c[eb>>2]|0)>>>0){j=475;break}else{j=476;break};case 475:a[(c[d$>>2]|0)+(e8*12|0)+4|0]=1;j=476;break;case 476:W=ar(10,0,53448,m|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((W|0)==0){j=477;break}else{e7=W;j=474;break};case 477:ak(36,e6|0);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;ak(70,e3|0);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;aI(c[59506]|0);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;W=c[eb>>2]|0;if((W|0)==0){j=481;break}else{e9=0;fa=0;fb=W;j=478;break};case 478:fc=c[d$>>2]|0;if((a[fc+(fa*12|0)+4|0]&1)==0){fd=e9;fe=fb;j=480;break}else{j=479;break};case 479:W=e9+1|0;aH(c[59504]|0,e9|0,1,c[fc+(fa*12|0)+8>>2]|0);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;fd=W;fe=c[eb>>2]|0;j=480;break;case 480:W=fa+1|0;if(W>>>0<fe>>>0){e9=fd;fa=W;fb=fe;j=478;break}else{j=481;break};case 481:ff=c[d1>>2]|0;if((ff|0)==0){j=483;break}else{j=482;break};case 482:ak(28,ff|0);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;j=483;break;case 483:ak(36,d0|0);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;dX=dY;j=491;break;case 484:ak(26,dY|0);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;dX=0;j=491;break;case 485:ak(26,dY|0);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;j=486;break;case 486:fg=c[d1>>2]|0;if((fg|0)==0){j=488;break}else{j=487;break};case 487:ak(28,fg|0);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;j=488;break;case 488:ak(36,d0|0);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;dX=0;j=491;break;case 489:a[eK]=0;j=439;break;case 490:a[eF]=0;j=433;break;case 491:c[198587]=dX;j=492;break;case 492:a[794445]=0;a[794444]=1;I=0;j=509;break;case 493:aI(2722);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;fh=c[184111]|0;if((fh|0)==0){j=496;break}else{j=494;break};case 494:if((a[797241]&1)==0){j=495;break}else{j=496;break};case 495:aI(fh|0);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;j=496;break;case 496:aI(4074);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;if((a[797243]&1)==0){j=498;break}else{j=497;break};case 497:c[199308]=0;j=498;break;case 498:if((a[797244]&1)==0){j=500;break}else{j=499;break};case 499:c[199307]=0;j=500;break;case 500:if((a[797245]&1)==0){j=502;break}else{j=501;break};case 501:c[199309]=0;j=502;break;case 502:a[797243]=0;a[797244]=0;a[797245]=0;aI(c[59462]|0);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;aI(c[59502]|0);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;fi=c[184120]|0;if((fi|0)==0){j=508;break}else{j=503;break};case 503:fj=fi+4104|0;if((c[fj>>2]|0)==0){j=504;break}else{j=505;break};case 504:fk=fi|0;j=507;break;case 505:fl=fi|0;fm=0;j=506;break;case 506:W=c[fi+4100>>2]|0;aH(116,c[fl>>2]|0,c[W+(fm<<4)+4>>2]|0,c[(c[c[W+(fm<<4)+8>>2]>>2]|0)+(c[W+(fm<<4)+12>>2]<<3)>>2]|0);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;W=fm+1|0;if(W>>>0<(c[fj>>2]|0)>>>0){fm=W;j=506;break}else{fk=fl;j=507;break};case 507:aC(36,c[fk>>2]|0,fi+4|0)|0;if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;ak(24,c[184120]|0);if((s|0)!=0&(t|0)!=0){k=X4(c[s>>2]|0,l)|0;if((k|0)>0){j=-1;break}else return 0}s=t=0;j=508;break;case 508:X2(731688,0,4800);a[794444]=0;I=1;j=509;break;case 509:i=f;return I|0;case-1:if((k|0)==1){F=t;j=510}s=t=0;break}return 0}function ga(){var d=0,e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0.0,K=0.0,L=0.0,M=0,N=0,O=0,P=0,Q=0,R=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0;d=i;i=i+9216|0;e=d|0;f=d+256|0;j=d+768|0;k=d+4864|0;l=d+8960|0;a[797247]=0;m=561832;if((c[140457]|0)==0&((c[m>>2]|0)==65535&(c[m+4>>2]|0)==0)&(c[140462]|0)==-1){n=742}else{m=ft[c[(c[199306]|0)+12>>2]&63](c[199309]|0,48)|0;o=797408;q=(c[o>>2]&0|m&1|0)==0&(c[o+4>>2]&65536|0)==0;a[797247]=q&1;if(q){r=0}else{n=742}}do{if((n|0)==742){q=ft[c[(c[199306]|0)+12>>2]&63](c[199309]|0,43)|0;o=797408;if((c[o>>2]&0|q&1|0)==0&(c[o+4>>2]&2048|0)==0){r=0;break}if((a[797808]&1)!=0){r=1;break}fV();r=1}}while(0);a[797808]=r;r=a[637401]|0;if((r&1)==0){s=r}else{do{if((a[797247]&1)==0){r=ft[c[(c[199306]|0)+12>>2]&63](c[199309]|0,45)|0;o=797408;if((c[o>>2]&0|r&1|0)==0&(c[o+4>>2]&8192|0)==0){t=0;break}if((a[797872]&1)!=0){t=1;break}o=a[736529]&1;a[736529]=o^1;r=o<<24>>24==0?21096:20800;o=c[196481]|0;q=o+4|0;m=c[q>>2]|0;if(m>>>0>1){u=o|0;v=1;w=m;while(1){m=c[(c[u>>2]|0)+(v<<2)>>2]|0;if((m|0)==0){x=w}else{XZ(c[m+8>>2]|0);XZ(c[(c[u>>2]|0)+(v<<2)>>2]|0);c[(c[u>>2]|0)+(v<<2)>>2]=0;x=c[q>>2]|0}m=v+1|0;if(m>>>0<x>>>0){v=m;w=x}else{break}}}c[q>>2]=1;w=o+12|0;XZ(c[w>>2]|0);c[w>>2]=0;w=c[196481]|0;v=w+4|0;L1047:do{if((c[v>>2]|0)>>>0<(c[w+8>>2]|0)>>>0){u=XY(12)|0;do{if((u|0)!=0){if((c[u-4>>2]&3|0)==0){break}X2(u|0,0,12)}}while(0);c[u+4>>2]=1;c[u>>2]=180;m=dq(r|0)|0;y=c[v>>2]|0;c[u+8>>2]=m;m=w|0;c[(c[m>>2]|0)+(y<<2)>>2]=u;y=c[v>>2]|0;c[v>>2]=y+1;if(y>>>0>1){z=y}else{break}while(1){y=z>>>1;A=c[m>>2]|0;B=A+(y<<2)|0;C=c[B>>2]|0;D=c[A+(z<<2)>>2]|0;if((c[D+4>>2]|0)>>>0<=(c[C+4>>2]|0)>>>0){break L1047}c[B>>2]=D;c[(c[m>>2]|0)+(z<<2)>>2]=C;if(z>>>0>3){z=y}else{break}}}}while(0);v=c[199307]|0;do{if((v|0)!=0){w=c[199304]|0;if((a[736529]&1)!=0){o=c[w+8>>2]|0;fe[o&127](v)|0;break}if(fe[c[w+12>>2]&127](v)|0){break}w=c[198610]|0;o=(w|0)!=0?w:c[p>>2]|0;a2(20488,45,1,o|0)|0;o=c[198610]|0;w=(o|0)!=0?o:c[p>>2]|0;aY(w|0)|0;a[637401]=0}}while(0);if((a[637400]&1)==0){t=1;break}v=c[198610]|0;w=(v|0)!=0?v:c[p>>2]|0;ec(w|0,93640,(E=i,i=i+8|0,c[E>>2]=r,E)|0)|0;i=E;w=c[198610]|0;v=(w|0)!=0?w:c[p>>2]|0;aY(v|0)|0;t=1}else{t=0}}while(0);a[797872]=t;s=a[637401]|0}t=l|0;do{if((s&1)!=0){l=a[797247]|0;if((l&1)==0){z=ft[c[(c[199306]|0)+12>>2]&63](c[199309]|0,49)|0;x=797408;G=(c[x>>2]&0|z&1|0)!=0|(c[x+4>>2]&131072|0)!=0;H=a[797247]|0}else{G=0;H=l}if((H&1)==0){l=ft[c[(c[199306]|0)+12>>2]&63](c[199309]|0,50)|0;x=797408;I=(c[x>>2]&0|l&1|0)!=0|(c[x+4>>2]&262144|0)!=0}else{I=0}if(!(G|I)){break}J=G?.5:0.0;if(I){K=J+-.5}else{K=J}J=K+ +g[184145];g[184145]=J;do{if(J>12.0){g[184145]=12.0;L=12.0}else{if(J>=-80.0){L=J;break}g[184145]=-80.0;L=-80.0}}while(0);J=L;bN(t|0,256,21408,(E=i,i=i+8|0,h[E>>3]=J,E)|0)|0;i=E;r=c[196481]|0;x=r+4|0;l=c[x>>2]|0;if(l>>>0>1){z=r|0;v=1;w=l;while(1){l=c[(c[z>>2]|0)+(v<<2)>>2]|0;if((l|0)==0){M=w}else{XZ(c[l+8>>2]|0);XZ(c[(c[z>>2]|0)+(v<<2)>>2]|0);c[(c[z>>2]|0)+(v<<2)>>2]=0;M=c[x>>2]|0}l=v+1|0;if(l>>>0<M>>>0){v=l;w=M}else{break}}}c[x>>2]=1;w=r+12|0;XZ(c[w>>2]|0);c[w>>2]=0;w=c[196481]|0;v=w+4|0;L1092:do{if((c[v>>2]|0)>>>0<(c[w+8>>2]|0)>>>0){z=XY(12)|0;do{if((z|0)!=0){if((c[z-4>>2]&3|0)==0){break}X2(z|0,0,12)}}while(0);c[z+4>>2]=1;c[z>>2]=180;l=dq(t|0)|0;o=c[v>>2]|0;c[z+8>>2]=l;l=w|0;c[(c[l>>2]|0)+(o<<2)>>2]=z;o=c[v>>2]|0;c[v>>2]=o+1;if(o>>>0>1){N=o}else{break}while(1){o=N>>>1;q=c[l>>2]|0;m=q+(o<<2)|0;u=c[m>>2]|0;y=c[q+(N<<2)>>2]|0;if((c[y+4>>2]|0)>>>0<=(c[u+4>>2]|0)>>>0){break L1092}c[m>>2]=y;c[(c[l>>2]|0)+(N<<2)>>2]=u;if(N>>>0>3){N=o}else{break}}}}while(0);if((a[637400]&1)!=0){v=c[198610]|0;w=(v|0)!=0?v:c[p>>2]|0;ec(w|0,93640,(E=i,i=i+8|0,c[E>>2]=t,E)|0)|0;i=E;w=c[198610]|0;v=(w|0)!=0?w:c[p>>2]|0;aY(v|0)|0}g[184146]=+S(10.0,+(+g[184145]/20.0))}}while(0);c[198544]=(c[198544]|0)+1;a[794150]=(fd[c[(c[199306]|0)+8>>2]&15](c[199309]|0,17304,0,1,0,16)|0)<<16>>16!=0|0;a[794151]=(fd[c[(c[199306]|0)+8>>2]&15](c[199309]|0,17304,1,1,0,16)|0)<<16>>16!=0|0;a[794152]=(fd[c[(c[199306]|0)+8>>2]&15](c[199309]|0,17304,2,1,0,16)|0)<<16>>16!=0|0;a[794153]=(fd[c[(c[199306]|0)+8>>2]&15](c[199309]|0,17304,3,1,0,16)|0)<<16>>16!=0|0;a[794154]=(fd[c[(c[199306]|0)+8>>2]&15](c[199309]|0,17304,4,1,0,16)|0)<<16>>16!=0|0;a[794155]=(fd[c[(c[199306]|0)+8>>2]&15](c[199309]|0,17304,5,1,0,16)|0)<<16>>16!=0|0;a[794156]=(fd[c[(c[199306]|0)+8>>2]&15](c[199309]|0,17304,6,1,0,16)|0)<<16>>16!=0|0;a[794157]=(fd[c[(c[199306]|0)+8>>2]&15](c[199309]|0,17304,7,1,0,16)|0)<<16>>16!=0|0;do{if((a[797247]&1)==0){t=ft[c[(c[199306]|0)+12>>2]&63](c[199309]|0,54)|0;N=797408;if((c[N>>2]&0|t&1|0)==0&(c[N+4>>2]&4194304|0)==0){O=0;break}N=c[(c[199306]|0)+28>>2]|0;if((N|0)==0){O=0;break}if((a[797888]&1)!=0){O=1;break}t=a[797896]&1;M=t^1;a[797896]=M;if((a[637400]&1)==0){P=N;Q=M}else{M=c[198610]|0;N=(M|0)!=0?M:c[p>>2]|0;M=t<<24>>24==0?45440:44840;ec(N|0,22472,(E=i,i=i+8|0,c[E>>2]=M,E)|0)|0;i=E;M=c[198610]|0;N=(M|0)!=0?M:c[p>>2]|0;aY(N|0)|0;P=c[(c[199306]|0)+28>>2]|0;Q=a[797896]|0}fc[P&127](c[199309]|0,(Q&1)!=0);N=c[199354]|0;if((N|0)==0){O=1;break}M=c[N+32>>2]|0;if((M|0)==0){O=1;break}fc[M&127](c[199308]|0,(a[797896]&1)==0);O=1}else{O=0}}while(0);a[797888]=O;if((c[199350]|0)!=0){do{if((a[797247]&1)==0){O=ft[c[(c[199306]|0)+12>>2]&63](c[199309]|0,51)|0;Q=797408;if((c[Q>>2]&0|O&1|0)==0&(c[Q+4>>2]&524288|0)==0){R=0;break}if((a[237344]&1)!=0){R=1;break}Q=c[199350]|0;O=Q+28|0;P=c[O>>2]|0;M=Q+20|0;c[M>>2]=P;N=c[Q+12>>2]|0;t=Q+16|0;c[t>>2]=N+(P*136|0);I=Q+4|0;G=c[(c[I>>2]|0)+4>>2]|0;H=Q|0;s=c[H>>2]|0;v=c[N+(P*136|0)+8>>2]|0;w=c[N+(P*136|0)+12>>2]|0;r=c[N+(P*136|0)+16>>2]|0;fx[G&15](s,v,w,r)|0;r=c[t>>2]|0;fg[c[(c[I>>2]|0)+12>>2]&7](c[H>>2]|0,+g[r+24>>2],+g[r+28>>2],+g[r+32>>2],+g[r+36>>2]);fc[c[(c[I>>2]|0)+16>>2]&127](c[H>>2]|0,(a[(c[t>>2]|0)+68|0]&1)!=0);a[Q+9|0]=1;c[O>>2]=(((c[M>>2]|0)+1|0)>>>0)%((c[Q+24>>2]|0)>>>0)|0;R=1}else{R=0}}while(0);a[237344]=R}if((a[797247]&1)==0){R=ft[c[(c[199306]|0)+12>>2]&63](c[199309]|0,35)|0;Q=797408;T=((c[Q>>2]&0|R&1|0)!=0|(c[Q+4>>2]&8|0)!=0)&1}else{T=0}do{if((a[794147]&1)==0){if((a[797247]&1)!=0){U=0;break}Q=ft[c[(c[199306]|0)+12>>2]&63](c[199309]|0,36)|0;R=797408;U=((c[R>>2]&0|Q&1|0)!=0|(c[R+4>>2]&16|0)!=0)&1}else{U=0}}while(0);R=U|T;if((a[633264]&1)==0){V=1}else{V=fe[c[(c[199305]|0)+16>>2]&127](c[199308]|0)|0}do{if(R<<24>>24==0|V^1){n=831}else{if((a[797848]&1)!=0){n=831;break}T=a[794147]&1;a[794147]=T^1;U=(a[637400]&1)!=0;if(T<<24>>24==0){if(U){T=c[198610]|0;Q=(T|0)!=0?T:c[p>>2]|0;a2(23888,19,1,Q|0)|0;Q=c[198610]|0;T=(Q|0)!=0?Q:c[p>>2]|0;aY(T|0)|0}T=c[199307]|0;if((T|0)==0){break}Q=c[(c[199304]|0)+8>>2]|0;fe[Q&127](T)|0;break}if(U){U=c[198610]|0;T=(U|0)!=0?U:c[p>>2]|0;a2(23472,21,1,T|0)|0;T=c[198610]|0;U=(T|0)!=0?T:c[p>>2]|0;aY(U|0)|0}U=c[199307]|0;if((U|0)==0){break}if((a[736529]&1)!=0){break}if(fe[c[(c[199304]|0)+12>>2]&127](U)|0){break}U=c[198610]|0;T=(U|0)!=0?U:c[p>>2]|0;a2(23104,81,1,T|0)|0;T=c[198610]|0;U=(T|0)!=0?T:c[p>>2]|0;aY(U|0)|0;a[637401]=0}}while(0);do{if((n|0)==831){U=(a[17344]&1)==0;if(!V){if(U){break}if((a[637400]&1)!=0){T=c[198610]|0;Q=(T|0)!=0?T:c[p>>2]|0;a2(23888,19,1,Q|0)|0;Q=c[198610]|0;T=(Q|0)!=0?Q:c[p>>2]|0;aY(T|0)|0}a[794147]=1;T=c[199307]|0;if((T|0)==0){break}Q=c[(c[199304]|0)+8>>2]|0;fe[Q&127](T)|0;break}if(!U){break}if((a[637400]&1)!=0){U=c[198610]|0;T=(U|0)!=0?U:c[p>>2]|0;a2(23472,21,1,T|0)|0;T=c[198610]|0;U=(T|0)!=0?T:c[p>>2]|0;aY(U|0)|0}a[794147]=0;U=c[199307]|0;if((U|0)==0){break}if((a[736529]&1)!=0){break}if(fe[c[(c[199304]|0)+12>>2]&127](U)|0){break}U=c[198610]|0;T=(U|0)!=0?U:c[p>>2]|0;a2(23104,81,1,T|0)|0;T=c[198610]|0;U=(T|0)!=0?T:c[p>>2]|0;aY(U|0)|0;a[637401]=0}}while(0);a[17344]=V&1;a[797848]=R;do{if((a[797247]&1)==0){R=ft[c[(c[199306]|0)+12>>2]&63](c[199309]|0,36)|0;V=797408;if((c[V>>2]&0|R&1|0)==0&(c[V+4>>2]&16|0)==0){W=0;X=0;break}W=a[797856]&1^1;X=1}else{W=0;X=0}}while(0);a[794148]=W;a[797856]=X;do{if((a[797247]&1)==0){X=ft[c[(c[199306]|0)+12>>2]&63](c[199309]|0,33)|0;W=797408;if((c[W>>2]&0|X&1|0)==0&(c[W+4>>2]&2|0)==0){Y=0;Z=0;break}Y=a[797864]&1^1;Z=1}else{Y=0;Z=0}}while(0);a[794148]=(a[794148]&1|Y|0)!=0|0;a[797864]=Z;do{if((a[797247]&1)==0){Z=ft[c[(c[199306]|0)+12>>2]&63](c[199309]|0,29)|0;Y=797408;if((c[Y>>2]&536870912|Z&1|0)==0&(c[Y+4>>2]&0|0)==0){_=0;n=864;break}if((a[797904]&1)!=0){_=1;n=864;break}a[535072]=a[535072]&1^1;a[797241]=a[736440]&1;a[797242]=0;gD();Y=c[184111]|0;do{if((Y|0)!=0){if((a[797241]&1)!=0){break}fz[Y&8191]()}}while(0);gE();if((a[797243]&1)!=0){c[199308]=0}if((a[797244]&1)!=0){c[199307]=0}if((a[797245]&1)!=0){c[199309]=0}a[797243]=0;a[797244]=0;a[797245]=0;gC();a[797241]=0;Y=c[199306]|0;if((Y|0)!=0){fb[c[Y+4>>2]&127](c[199309]|0)}a[797904]=1;if((a[794147]&1)==0){break}fW()}else{_=0;n=864}}while(0);if((n|0)==864){a[797904]=_}do{if((a[794147]&1)!=0){if((a[794148]&1)!=0){break}i=d;return}}while(0);_=a[797247]|0;if((_&1)==0){Y=ft[c[(c[199306]|0)+12>>2]&63](c[199309]|0,25)|0;Z=797408;$=(c[Z>>2]&33554432|Y&1|0)!=0|(c[Z+4>>2]&0|0)!=0;aa=a[797247]|0}else{$=0;aa=_}if((aa&1)==0){aa=ft[c[(c[199306]|0)+12>>2]&63](c[199309]|0,26)|0;_=797408;ab=(c[_>>2]&67108864|aa&1|0)!=0|(c[_+4>>2]&0|0)!=0}else{ab=0}do{if($){if((a[797920]&1)!=0){n=883;break}_=a[797248]&1;a[797248]=_^1;aa=_<<24>>24==0;Z=c[199308]|0;if((a[637402]&1)!=0&(Z|0)!=0){if((a[535088]&1)==0){n=878}else{if((a[731765]&1)==0){ac=aa}else{n=878}}if((n|0)==878){ac=1}fc[c[(c[199305]|0)+8>>2]&127](Z,ac)}Z=c[199307]|0;if((a[637401]&1)!=0&(Z|0)!=0){fc[c[(c[199304]|0)+16>>2]&127](Z,(_&a[555688])<<24>>24==0)}c[184126]=aa?c[184127]|0:c[184128]|0}else{n=883}}while(0);do{if((n|0)==883){if((a[797912]&1|0)==(ab&1|0)){break}a[797248]=ab&1;ac=c[199308]|0;if((a[637402]&1)!=0&(ac|0)!=0){if((a[535088]&1)==0){n=887}else{if((a[731765]&1)==0){ad=ab}else{n=887}}if((n|0)==887){ad=1}fc[c[(c[199305]|0)+8>>2]&127](ac,ad)}ac=c[199307]|0;if((a[637401]&1)!=0&(ac|0)!=0){fc[c[(c[199304]|0)+16>>2]&127](ac,(a[555688]&1)==0|ab)}c[184126]=ab?c[184127]|0:c[184128]|0}}while(0);a[797920]=$&1;a[797912]=ab&1;do{if((a[797247]&1)==0){ab=ft[c[(c[199306]|0)+12>>2]&63](c[199309]|0,31)|0;$=797408;if((c[$>>2]&-2147483648|ab&1|0)==0&(c[$+4>>2]&0|0)==0){ae=0;break}if((a[797776]&1)!=0){ae=1;break}$=e|0;ab=(c[182916]|0)+1|0;c[182916]=ab;ad=c[196481]|0;if((ad|0)==0){af=ab}else{ab=ad+4|0;ac=c[ab>>2]|0;if(ac>>>0>1){aa=ad|0;_=1;Z=ac;while(1){ac=c[(c[aa>>2]|0)+(_<<2)>>2]|0;if((ac|0)==0){ag=Z}else{XZ(c[ac+8>>2]|0);XZ(c[(c[aa>>2]|0)+(_<<2)>>2]|0);c[(c[aa>>2]|0)+(_<<2)>>2]=0;ag=c[ab>>2]|0}ac=_+1|0;if(ac>>>0<ag>>>0){_=ac;Z=ag}else{break}}}c[ab>>2]=1;Z=ad+12|0;XZ(c[Z>>2]|0);c[Z>>2]=0;af=c[182916]|0}bN($|0,256,70144,(E=i,i=i+8|0,c[E>>2]=af,E)|0)|0;i=E;Z=c[196481]|0;L1255:do{if((Z|0)!=0){_=Z+4|0;if((c[_>>2]|0)>>>0>=(c[Z+8>>2]|0)>>>0){break}aa=XY(12)|0;do{if((aa|0)!=0){if((c[aa-4>>2]&3|0)==0){break}X2(aa|0,0,12)}}while(0);c[aa+4>>2]=1;c[aa>>2]=180;ac=dq($|0)|0;Y=c[_>>2]|0;c[aa+8>>2]=ac;ac=Z|0;c[(c[ac>>2]|0)+(Y<<2)>>2]=aa;Y=c[_>>2]|0;c[_>>2]=Y+1;if(Y>>>0>1){ah=Y}else{break}while(1){Y=ah>>>1;W=c[ac>>2]|0;X=W+(Y<<2)|0;V=c[X>>2]|0;R=c[W+(ah<<2)>>2]|0;if((c[R+4>>2]|0)>>>0<=(c[V+4>>2]|0)>>>0){break L1255}c[X>>2]=R;c[(c[ac>>2]|0)+(ah<<2)>>2]=V;if(ah>>>0>3){ah=Y}else{break}}}}while(0);if((a[637400]&1)==0){ae=1;break}Z=c[198610]|0;ad=(Z|0)!=0?Z:c[p>>2]|0;ec(ad|0,93640,(E=i,i=i+8|0,c[E>>2]=$,E)|0)|0;i=E;ad=c[198610]|0;Z=(ad|0)!=0?ad:c[p>>2]|0;aY(Z|0)|0;ae=1}else{ae=0}}while(0);a[797776]=ae;do{if((a[797247]&1)==0){ae=ft[c[(c[199306]|0)+12>>2]&63](c[199309]|0,32)|0;ah=797408;if((c[ah>>2]&0|ae&1|0)==0&(c[ah+4>>2]&1|0)==0){ai=0;break}if((a[797784]&1)!=0){ai=1;break}ah=e|0;ae=c[182916]|0;if((ae|0)==0){aj=0}else{af=ae-1|0;c[182916]=af;aj=af}af=c[196481]|0;if((af|0)==0){ak=aj}else{ae=af+4|0;ag=c[ae>>2]|0;if(ag>>>0>1){Z=af|0;ad=1;ab=ag;while(1){ag=c[(c[Z>>2]|0)+(ad<<2)>>2]|0;if((ag|0)==0){al=ab}else{XZ(c[ag+8>>2]|0);XZ(c[(c[Z>>2]|0)+(ad<<2)>>2]|0);c[(c[Z>>2]|0)+(ad<<2)>>2]=0;al=c[ae>>2]|0}ag=ad+1|0;if(ag>>>0<al>>>0){ad=ag;ab=al}else{break}}}c[ae>>2]=1;ab=af+12|0;XZ(c[ab>>2]|0);c[ab>>2]=0;ak=c[182916]|0}bN(ah|0,256,70144,(E=i,i=i+8|0,c[E>>2]=ak,E)|0)|0;i=E;ab=c[196481]|0;L1286:do{if((ab|0)!=0){ad=ab+4|0;if((c[ad>>2]|0)>>>0>=(c[ab+8>>2]|0)>>>0){break}Z=XY(12)|0;do{if((Z|0)!=0){if((c[Z-4>>2]&3|0)==0){break}X2(Z|0,0,12)}}while(0);c[Z+4>>2]=1;c[Z>>2]=180;$=dq(ah|0)|0;ag=c[ad>>2]|0;c[Z+8>>2]=$;$=ab|0;c[(c[$>>2]|0)+(ag<<2)>>2]=Z;ag=c[ad>>2]|0;c[ad>>2]=ag+1;if(ag>>>0>1){am=ag}else{break}while(1){ag=am>>>1;ac=c[$>>2]|0;_=ac+(ag<<2)|0;aa=c[_>>2]|0;Y=c[ac+(am<<2)>>2]|0;if((c[Y+4>>2]|0)>>>0<=(c[aa+4>>2]|0)>>>0){break L1286}c[_>>2]=Y;c[(c[$>>2]|0)+(am<<2)>>2]=aa;if(am>>>0>3){am=ag}else{break}}}}while(0);if((a[637400]&1)==0){ai=1;break}ab=c[198610]|0;af=(ab|0)!=0?ab:c[p>>2]|0;ec(af|0,93640,(E=i,i=i+8|0,c[E>>2]=ah,E)|0)|0;i=E;af=c[198610]|0;ab=(af|0)!=0?af:c[p>>2]|0;aY(ab|0)|0;ai=1}else{ai=0}}while(0);a[797784]=ai;ai=(c[196486]|0)==0;do{if((a[797247]&1)==0){am=ft[c[(c[199306]|0)+12>>2]&63](c[199309]|0,28)|0;ak=797408;if((c[ak>>2]&268435456|am&1|0)==0&(c[ak+4>>2]&0|0)==0){an=0;break}if((a[797816]&1)!=0){an=1;break}f2();an=1}else{an=0}}while(0);a[797816]=an&1;if(ai){do{if((a[797247]&1)==0){ai=ft[c[(c[199306]|0)+12>>2]&63](c[199309]|0,27)|0;ak=797408;am=(c[ak>>2]&134217728|ai&1|0)!=0|(c[ak+4>>2]&0|0)!=0;if(an|am^1){ao=am;break}if((a[797824]&1)!=0){ao=am;break}f1();ao=am}else{ao=0}}while(0);a[797824]=ao&1}if((a[785940]&1)!=0){ao=c[184136]|0;if(fZ((c[184135]|0)+(ao<<1)|0,(c[184137]|0)-ao|0)|0){ap=a[637401]&1}else{ap=0}a[637401]=ap}a[785940]=0;do{if(a[17336]|0){if((c[196482]|0)==0){break}L1322:do{if((a[797247]&1)==0){ap=ft[c[(c[199306]|0)+12>>2]&63](c[199309]|0,33)|0;ao=797408;if((c[ao>>2]&0|ap&1|0)==0&(c[ao+4>>2]&2|0)==0){n=995;break}ao=c[196481]|0;ap=ao+4|0;an=c[ap>>2]|0;if(an>>>0>1){am=ao|0;ak=1;ai=an;while(1){an=c[(c[am>>2]|0)+(ak<<2)>>2]|0;if((an|0)==0){aq=ai}else{XZ(c[an+8>>2]|0);XZ(c[(c[am>>2]|0)+(ak<<2)>>2]|0);c[(c[am>>2]|0)+(ak<<2)>>2]=0;aq=c[ap>>2]|0}an=ak+1|0;if(an>>>0<aq>>>0){ak=an;ai=aq}else{break}}}c[ap>>2]=1;ai=ao+12|0;XZ(c[ai>>2]|0);c[ai>>2]=0;ai=c[196482]|0;ak=ai+12|0;am=c[ak>>2]|0;an=am;al=ai+28|0;do{if((a[al]&1)==0){aj=ai+16|0;e=ai+8|0;ab=c[e>>2]|0;af=(c[aj>>2]|0)-1&ab;c[aj>>2]=af;ae=ai+20|0;$=c[ae>>2]|0;if((af|0)==($|0)){c[aj>>2]=af+1&ab;ad=c[196481]|0;Z=ad+4|0;if((c[Z>>2]|0)>>>0>=(c[ad+8>>2]|0)>>>0){break L1322}ag=XY(12)|0;do{if((ag|0)!=0){if((c[ag-4>>2]&3|0)==0){break}X2(ag|0,0,12)}}while(0);c[ag+4>>2]=0;c[ag>>2]=30;aa=dq(24360)|0;Y=c[Z>>2]|0;c[ag+8>>2]=aa;aa=ad|0;c[(c[aa>>2]|0)+(Y<<2)>>2]=ag;Y=c[Z>>2]|0;c[Z>>2]=Y+1;if(Y>>>0>1){ar=Y}else{break L1322}while(1){Y=ar>>>1;_=c[aa>>2]|0;ac=_+(Y<<2)|0;V=c[ac>>2]|0;R=c[_+(ar<<2)>>2]|0;if((c[R+4>>2]|0)>>>0<=(c[V+4>>2]|0)>>>0){break L1322}c[ac>>2]=R;c[(c[aa>>2]|0)+(ar<<2)>>2]=V;if(ar>>>0>3){ar=Y}else{break L1322}}}else{aa=ai|0;Z=(c[aa>>2]|0)+(af<<3)|0;ag=c[Z>>2]|0;ad=c[Z+4>>2]|0;if((ag|0)==0&(ad|0)==0){as=af;at=$;au=ab}else{Z=ad;ad=ag;ag=am;while(1){Y=ag+(Z<<2)|0;c[Y>>2]=c[Y>>2]^ad;av=c[e>>2]|0;aw=(c[aj>>2]|0)-1&av;c[aj>>2]=aw;Y=(c[aa>>2]|0)+(aw<<3)|0;V=c[Y>>2]|0;R=c[Y+4>>2]|0;if((V|0)==0&(R|0)==0){break}Z=R;ad=V;ag=c[ak>>2]|0}as=aw;at=c[ae>>2]|0;au=av}if((as|0)!=(at|0)){break}c[aj>>2]=at+1&au;break}}else{a[al]=0}}while(0);a[785940]=1;al=c[184137]|0;c[184136]=al;L1356:do{if((c[184125]|0)!=0){ak=0;am=al;while(1){ai=b[(c[184134]|0)+((ak|1)<<1)>>1]|0;ao=am-1|0;c[184136]=ao;b[(c[184135]|0)+(ao<<1)>>1]=ai;ai=b[(c[184134]|0)+(ak<<1)>>1]|0;ao=(c[184136]|0)-1|0;c[184136]=ao;b[(c[184135]|0)+(ao<<1)>>1]=ai;ai=ak+2|0;if(ai>>>0>=(c[184125]|0)>>>0){break L1356}ak=ai;am=c[184136]|0}}}while(0);c[184125]=0;al=c[196481]|0;am=al+4|0;L1361:do{if((c[am>>2]|0)>>>0<(c[al+8>>2]|0)>>>0){ak=(a[794147]&1)!=0?1:30;aj=XY(12)|0;do{if((aj|0)!=0){if((c[aj-4>>2]&3|0)==0){break}X2(aj|0,0,12)}}while(0);c[aj+4>>2]=0;c[aj>>2]=ak;ae=dq(24632)|0;ai=c[am>>2]|0;c[aj+8>>2]=ae;ae=al|0;c[(c[ae>>2]|0)+(ai<<2)>>2]=aj;ai=c[am>>2]|0;c[am>>2]=ai+1;if(ai>>>0>1){ax=ai}else{break}while(1){ai=ax>>>1;ao=c[ae>>2]|0;ap=ao+(ai<<2)|0;ag=c[ap>>2]|0;ad=c[ao+(ax<<2)>>2]|0;if((c[ad+4>>2]|0)>>>0<=(c[ag+4>>2]|0)>>>0){break L1361}c[ap>>2]=ad;c[(c[ae>>2]|0)+(ax<<2)>>2]=ag;if(ax>>>0>3){ax=ai}else{break}}}}while(0);am=c[59460]|0;al=c[196484]|0;ft[am&63](an,al)|0;al=c[196486]|0;if((al|0)==0){break}a[al+33|0]=1;am=al+20|0;ae=c[am>>2]|0;aj=c[al+12>>2]|0;do{if(ae>>>0<2){ak=c[aj>>2]|0;ai=al+28|0;if((ak|0)!=(c[ai>>2]|0)){ay=ai;n=983;break}c[am>>2]=0;ag=c[al>>2]|0;eo(ag|0,ak|0,0)|0;az=ai}else{ay=al+28|0;n=983}}while(0);if((n|0)==983){an=ae-((a[al+32|0]&1)!=0?1:2)&c[al+16>>2];c[am>>2]=an;ai=c[al>>2]|0;ak=c[aj+(an<<2)>>2]|0;eo(ai|0,ak|0,0)|0;az=ay}ak=al|0;ai=cb(c[ak>>2]|0)|0;an=c[az>>2]|0;if((ai|0)>(an|0)){break}ai=c[ak>>2]|0;if((a[al+24|0]&1)==0){eo(ai|0,16,0)|0;ag=c[59480]|0;ad=al+4|0;ap=c[ad>>2]|0;ao=al+8|0;Z=c[ao>>2]|0;ft[ag&63](ap,Z)|0;Z=c[ad>>2]|0;ad=c[ao>>2]|0;ao=c[ak>>2]|0;a2(Z|0,1,ad|0,ao|0)|0;break}else{eo(ai|0,an|0,0)|0;break}}else{n=995}}while(0);do{if((n|0)==995){ah=c[158313]|0;an=(((c[199458]|0)+1|0)>>>0)%(((ah|0)!=0?ah:1)>>>0)|0;c[199458]=an;if(!((an|0)==0|(c[196486]|0)!=0)){break}an=c[59480]|0;ah=c[196483]|0;ai=c[196484]|0;ft[an&63](ah,ai)|0;ai=c[196482]|0;ah=c[196483]|0;an=ai+12|0;ao=c[an>>2]|0;ad=ah;Z=ai+16|0;ak=c[Z>>2]|0;c[Z>>2]=ak+1;ap=ai|0;ag=(c[ap>>2]|0)+(ak<<3)|0;c[ag>>2]=0;c[ag+4>>2]=0;ag=ai+8|0;ak=c[ag>>2]|0;aa=c[Z>>2]&ak;c[Z>>2]=aa;e=ai+20|0;ab=(aa|0)==(c[e>>2]|0);$=ai+24|0;af=c[$>>2]|0;if((af|0)==0){aA=ab;aB=aa;aC=ak;aD=0}else{V=0;R=0;Y=ab;ab=aa;aa=ak;ak=af;while(1){af=R;ac=c[ao+(af<<2)>>2]|0;_=c[ad+(af<<2)>>2]|0;if((ac|0)==(_|0)){aE=Y;aF=ab;aG=aa;aH=ak}else{af=(c[ap>>2]|0)+(ab<<3)|0;c[af>>2]=_^ac;c[af+4>>2]=R;af=c[ag>>2]|0;ac=(c[Z>>2]|0)+1&af;c[Z>>2]=ac;aE=(ac|0)==(c[e>>2]|0)|Y;aF=ac;aG=af;aH=c[$>>2]|0}af=Ye(R,V,1,0)|0;ac=F;_=0;if(ac>>>0<_>>>0|ac>>>0==_>>>0&af>>>0<aH>>>0){V=ac;R=af;Y=aE;ab=aF;aa=aG;ak=aH}else{aA=aE;aB=aF;aC=aG;aD=aH;break}}}do{if(aA){ak=aB+1&aC;c[e>>2]=ak;aa=c[ap>>2]|0;ab=aa+(ak<<3)|0;if((c[ab>>2]|0)==0&(c[ab+4>>2]|0)==0){break}else{aI=ak}do{aI=aI+1&aC;c[e>>2]=aI;ak=aa+(aI<<3)|0;}while(!((c[ak>>2]|0)==0&(c[ak+4>>2]|0)==0))}}while(0);e=c[an>>2]|0;ap=aD<<2;X5(e|0,ah|0,ap)|0;a[ai+28|0]=1}}while(0);fb[c[59476]&127]((a[785940]&1)!=0?20:64);fb[c[59474]&127]((a[785940]&1)!=0?34:18)}else{a[17336]=1}}while(0);L1400:do{if((a[797247]&1)==0){aD=ft[c[(c[199306]|0)+12>>2]&63](c[199309]|0,47)|0;aI=797408;aC=(c[aI>>2]&0|aD&1|0)!=0|(c[aI+4>>2]&32768|0)!=0;a[794149]=aC&1;if(!aC){break}aC=c[196481]|0;aI=aC+4|0;aD=c[aI>>2]|0;if(aD>>>0>1){aB=aC|0;aA=1;aH=aD;while(1){aD=c[(c[aB>>2]|0)+(aA<<2)>>2]|0;if((aD|0)==0){aJ=aH}else{XZ(c[aD+8>>2]|0);XZ(c[(c[aB>>2]|0)+(aA<<2)>>2]|0);c[(c[aB>>2]|0)+(aA<<2)>>2]=0;aJ=c[aI>>2]|0}aD=aA+1|0;if(aD>>>0<aJ>>>0){aA=aD;aH=aJ}else{break}}}c[aI>>2]=1;aH=aC+12|0;XZ(c[aH>>2]|0);c[aH>>2]=0;aH=c[196481]|0;aA=aH+4|0;if((c[aA>>2]|0)>>>0>=(c[aH+8>>2]|0)>>>0){break}aB=(a[785940]&1)!=0?25304:24960;aD=XY(12)|0;do{if((aD|0)!=0){if((c[aD-4>>2]&3|0)==0){break}X2(aD|0,0,12)}}while(0);c[aD+4>>2]=0;c[aD>>2]=30;aC=dq(aB|0)|0;aI=c[aA>>2]|0;c[aD+8>>2]=aC;aC=aH|0;c[(c[aC>>2]|0)+(aI<<2)>>2]=aD;aI=c[aA>>2]|0;c[aA>>2]=aI+1;if(aI>>>0>1){aK=aI}else{break}while(1){aI=aK>>>1;aG=c[aC>>2]|0;aF=aG+(aI<<2)|0;aE=c[aF>>2]|0;az=c[aG+(aK<<2)>>2]|0;if((c[az+4>>2]|0)>>>0<=(c[aE+4>>2]|0)>>>0){break L1400}c[aF>>2]=az;c[(c[aC>>2]|0)+(aK<<2)>>2]=aE;if(aK>>>0>3){aK=aI}else{break}}}else{a[794149]=0}}while(0);do{if((a[797247]&1)==0){aK=ft[c[(c[199306]|0)+12>>2]&63](c[199309]|0,34)|0;aJ=797408;if((c[aJ>>2]&0|aK&1|0)==0&(c[aJ+4>>2]&4|0)==0){aL=0;aM=0;break}aL=(a[797880]&1)==0;aM=1}else{aL=0;aM=0}}while(0);do{if((a[790044]&1)==0){if(!aL){break}aJ=j|0;aK=k|0;if((c[196486]|0)==0){c[158313]=1;aC=c[182916]|0;if((aC|0)==0){bN(aJ|0,4096,28448,(E=i,i=i+8|0,c[E>>2]=785948,E)|0)|0;i=E}else{bN(aJ|0,4096,28728,(E=i,i=i+16|0,c[E>>2]=785948,c[E+8>>2]=aC,E)|0)|0;i=E}bN(aK|0,4096,28072,(E=i,i=i+8|0,c[E>>2]=aJ,E)|0)|0;i=E;c[196486]=hd(aJ,1)|0;aC=c[196481]|0;aA=aC+4|0;aD=c[aA>>2]|0;if(aD>>>0>1){aH=aC|0;aB=1;aI=aD;while(1){aD=c[(c[aH>>2]|0)+(aB<<2)>>2]|0;if((aD|0)==0){aN=aI}else{XZ(c[aD+8>>2]|0);XZ(c[(c[aH>>2]|0)+(aB<<2)>>2]|0);c[(c[aH>>2]|0)+(aB<<2)>>2]=0;aN=c[aA>>2]|0}aD=aB+1|0;if(aD>>>0<aN>>>0){aB=aD;aI=aN}else{break}}}c[aA>>2]=1;aI=aC+12|0;XZ(c[aI>>2]|0);c[aI>>2]=0;aI=c[196481]|0;aB=aI+4|0;L1491:do{if((c[aB>>2]|0)>>>0<(c[aI+8>>2]|0)>>>0){aH=(c[196486]|0)!=0?aK:27680;aD=XY(12)|0;do{if((aD|0)!=0){if((c[aD-4>>2]&3|0)==0){break}X2(aD|0,0,12)}}while(0);c[aD+4>>2]=1;c[aD>>2]=180;ai=dq(aH|0)|0;ah=c[aB>>2]|0;c[aD+8>>2]=ai;ai=aI|0;c[(c[ai>>2]|0)+(ah<<2)>>2]=aD;ah=c[aB>>2]|0;c[aB>>2]=ah+1;if(ah>>>0>1){aO=ah}else{break}while(1){ah=aO>>>1;an=c[ai>>2]|0;aE=an+(ah<<2)|0;az=c[aE>>2]|0;aF=c[an+(aO<<2)>>2]|0;if((c[aF+4>>2]|0)>>>0<=(c[az+4>>2]|0)>>>0){break L1491}c[aE>>2]=aF;c[(c[ai>>2]|0)+(aO<<2)>>2]=az;if(aO>>>0>3){aO=ah}else{break}}}}while(0);if((c[196486]|0)==0){aB=c[198610]|0;aI=(aB|0)!=0?aB:c[p>>2]|0;a2(26592,51,1,aI|0)|0;aI=c[198610]|0;aB=(aI|0)!=0?aI:c[p>>2]|0;aY(aB|0)|0;break}if((a[637400]&1)==0){break}aB=c[198610]|0;aI=(aB|0)!=0?aB:c[p>>2]|0;ec(aI|0,27336,(E=i,i=i+8|0,c[E>>2]=aJ,E)|0)|0;i=E;aI=c[198610]|0;aB=(aI|0)!=0?aI:c[p>>2]|0;aY(aB|0)|0;break}else{aB=c[196481]|0;aI=aB+4|0;aK=c[aI>>2]|0;if(aK>>>0>1){aC=aB|0;aA=1;ai=aK;while(1){aK=c[(c[aC>>2]|0)+(aA<<2)>>2]|0;if((aK|0)==0){aP=ai}else{XZ(c[aK+8>>2]|0);XZ(c[(c[aC>>2]|0)+(aA<<2)>>2]|0);c[(c[aC>>2]|0)+(aA<<2)>>2]=0;aP=c[aI>>2]|0}aK=aA+1|0;if(aK>>>0<aP>>>0){aA=aK;ai=aP}else{break}}}c[aI>>2]=1;ai=aB+12|0;XZ(c[ai>>2]|0);c[ai>>2]=0;ai=c[196481]|0;aA=ai+4|0;L1459:do{if((c[aA>>2]|0)>>>0<(c[ai+8>>2]|0)>>>0){aC=XY(12)|0;do{if((aC|0)!=0){if((c[aC-4>>2]&3|0)==0){break}X2(aC|0,0,12)}}while(0);c[aC+4>>2]=2;c[aC>>2]=180;aJ=dq(29360)|0;aK=c[aA>>2]|0;c[aC+8>>2]=aJ;aJ=ai|0;c[(c[aJ>>2]|0)+(aK<<2)>>2]=aC;aK=c[aA>>2]|0;c[aA>>2]=aK+1;if(aK>>>0>1){aR=aK}else{break}while(1){aK=aR>>>1;aD=c[aJ>>2]|0;aH=aD+(aK<<2)|0;ah=c[aH>>2]|0;az=c[aD+(aR<<2)>>2]|0;if((c[az+4>>2]|0)>>>0<=(c[ah+4>>2]|0)>>>0){break L1459}c[aH>>2]=az;c[(c[aJ>>2]|0)+(aR<<2)>>2]=ah;if(aR>>>0>3){aR=aK}else{break}}}}while(0);if((a[637400]&1)!=0){aA=c[198610]|0;ai=(aA|0)!=0?aA:c[p>>2]|0;a2(29056,34,1,ai|0)|0;ai=c[198610]|0;aA=(ai|0)!=0?ai:c[p>>2]|0;aY(aA|0)|0}aA=c[196486]|0;if((aA|0)!=0){ai=c[aA>>2]|0;if((ai|0)!=0){aQ(ai|0)|0}XZ(c[aA+4>>2]|0);XZ(c[aA+12>>2]|0);XZ(aA)}c[196486]=0;break}}else{if(!((a[794143]&1)!=0|aL)){break}aA=c[196481]|0;ai=aA+4|0;L1428:do{if((c[ai>>2]|0)>>>0<(c[aA+8>>2]|0)>>>0){aB=XY(12)|0;do{if((aB|0)!=0){if((c[aB-4>>2]&3|0)==0){break}X2(aB|0,0,12)}}while(0);c[aB+4>>2]=1;c[aB>>2]=180;aI=dq(26168)|0;aJ=c[ai>>2]|0;c[aB+8>>2]=aI;aI=aA|0;c[(c[aI>>2]|0)+(aJ<<2)>>2]=aB;aJ=c[ai>>2]|0;c[ai>>2]=aJ+1;if(aJ>>>0>1){aS=aJ}else{break}while(1){aJ=aS>>>1;aC=c[aI>>2]|0;aK=aC+(aJ<<2)|0;ah=c[aK>>2]|0;az=c[aC+(aS<<2)>>2]|0;if((c[az+4>>2]|0)>>>0<=(c[ah+4>>2]|0)>>>0){break L1428}c[aK>>2]=az;c[(c[aI>>2]|0)+(aS<<2)>>2]=ah;if(aS>>>0>3){aS=aJ}else{break}}}}while(0);if((a[637400]&1)!=0){ai=c[198610]|0;aA=(ai|0)!=0?ai:c[p>>2]|0;a2(25656,33,1,aA|0)|0;aA=c[198610]|0;ai=(aA|0)!=0?aA:c[p>>2]|0;aY(ai|0)|0}ai=c[196486]|0;if((ai|0)!=0){aA=c[ai>>2]|0;if((aA|0)!=0){aQ(aA|0)|0}XZ(c[ai+4>>2]|0);XZ(c[ai+12>>2]|0);XZ(ai)}c[196486]=0;a[794143]=0;a[790044]=0}}while(0);a[797880]=aM;aM=f|0;L1506:do{if((c[198568]|0)!=0){if((c[(c[199305]|0)+20>>2]|0)==0){break}f=a[797247]|0;if((f&1)==0){aS=ft[c[(c[199306]|0)+12>>2]&63](c[199309]|0,38)|0;aL=797408;aT=(c[aL>>2]&0|aS&1|0)!=0|(c[aL+4>>2]&64|0)!=0;aU=a[797247]|0}else{aT=0;aU=f}if((aU&1)==0){f=ft[c[(c[199306]|0)+12>>2]&63](c[199309]|0,39)|0;aL=797408;aV=(c[aL>>2]&0|f&1|0)!=0|(c[aL+4>>2]&128|0)!=0}else{aV=0}do{if(aT){if((a[797800]&1)!=0){n=1088;break}aL=c[198568]|0;f=(((c[198569]|0)+1|0)>>>0)%((c[aL+4>>2]|0)>>>0)|0;c[198569]=f;aW=f;aX=aL;n=1093}else{n=1088}}while(0);do{if((n|0)==1088){if(!aV){break}if((a[797792]&1)!=0){break}aL=c[198569]|0;if((aL|0)==0){f=c[198568]|0;aS=(c[f+4>>2]|0)-1|0;c[198569]=aS;aW=aS;aX=f;n=1093;break}else{f=aL-1|0;c[198569]=f;aW=f;aX=c[198568]|0;n=1093;break}}}while(0);do{if((n|0)==1093){f=c[(c[aX>>2]|0)+(aW<<3)>>2]|0;aL=cg(f|0,46)|0;if((aL|0)==0){break L1506}do{if((cL(aL|0,32024)|0)==0){aZ=2}else{if((cL(aL|0,31624)|0)==0){aZ=0;break}if((cL(aL|0,31200)|0)==0){aZ=0}else{break L1506}}}while(0);aL=c[196481]|0;aS=aL+4|0;aR=c[aS>>2]|0;if(aR>>>0>1){aP=aL|0;aO=1;aN=aR;while(1){aR=c[(c[aP>>2]|0)+(aO<<2)>>2]|0;if((aR|0)==0){a_=aN}else{XZ(c[aR+8>>2]|0);XZ(c[(c[aP>>2]|0)+(aO<<2)>>2]|0);c[(c[aP>>2]|0)+(aO<<2)>>2]=0;a_=c[aS>>2]|0}aR=aO+1|0;if(aR>>>0<a_>>>0){aO=aR;aN=a_}else{break}}}c[aS>>2]=1;aN=aL+12|0;XZ(c[aN>>2]|0);c[aN>>2]=0;aN=c[198569]|0;bN(aM|0,512,30552,(E=i,i=i+16|0,c[E>>2]=aN,c[E+8>>2]=f,E)|0)|0;i=E;aN=c[196481]|0;aO=aN+4|0;L1540:do{if((c[aO>>2]|0)>>>0<(c[aN+8>>2]|0)>>>0){aP=XY(12)|0;do{if((aP|0)!=0){if((c[aP-4>>2]&3|0)==0){break}X2(aP|0,0,12)}}while(0);c[aP+4>>2]=1;c[aP>>2]=120;aR=dq(aM|0)|0;k=c[aO>>2]|0;c[aP+8>>2]=aR;aR=aN|0;c[(c[aR>>2]|0)+(k<<2)>>2]=aP;k=c[aO>>2]|0;c[aO>>2]=k+1;if(k>>>0>1){a$=k}else{break}while(1){k=a$>>>1;j=c[aR>>2]|0;ai=j+(k<<2)|0;aA=c[ai>>2]|0;aI=c[j+(a$<<2)>>2]|0;if((c[aI+4>>2]|0)>>>0<=(c[aA+4>>2]|0)>>>0){break L1540}c[ai>>2]=aI;c[(c[aR>>2]|0)+(a$<<2)>>2]=aA;if(a$>>>0>3){a$=k}else{break}}}}while(0);if((a[637400]&1)!=0){aO=c[198610]|0;aN=(aO|0)!=0?aO:c[p>>2]|0;ec(aN|0,30160,(E=i,i=i+8|0,c[E>>2]=f,E)|0)|0;i=E;aN=c[198610]|0;aO=(aN|0)!=0?aN:c[p>>2]|0;aY(aO|0)|0}if(fi[c[(c[199305]|0)+20>>2]&63](c[199308]|0,aZ,f)|0){break}aO=c[198610]|0;aN=(aO|0)!=0?aO:c[p>>2]|0;a2(29800,44,1,aN|0)|0;aN=c[198610]|0;aO=(aN|0)!=0?aN:c[p>>2]|0;aY(aO|0)|0}}while(0);a[797800]=aT&1;a[797792]=aV&1}}while(0);if((c[198587]|0)!=0){aV=a[797247]|0;if((aV&1)==0){aT=ft[c[(c[199306]|0)+12>>2]&63](c[199309]|0,40)|0;aZ=797408;a0=(c[aZ>>2]&0|aT&1|0)!=0|(c[aZ+4>>2]&256|0)!=0;a1=a[797247]|0}else{a0=0;a1=aV}if((a1&1)==0){aV=ft[c[(c[199306]|0)+12>>2]&63](c[199309]|0,41)|0;aZ=797408;a3=(c[aZ>>2]&0|aV&1|0)!=0|(c[aZ+4>>2]&512|0)!=0;a4=a[797247]|0}else{a3=0;a4=a1}if((a4&1)==0){a4=ft[c[(c[199306]|0)+12>>2]&63](c[199309]|0,42)|0;a1=797408;a5=(c[a1>>2]&0|a4&1|0)!=0|(c[a1+4>>2]&1024|0)!=0}else{a5=0}do{if(a0){if((a[797960]&1)!=0){n=1124;break}a1=c[198587]|0;a4=a1+4|0;c[a4>>2]=(((c[a4>>2]|0)+1|0)>>>0)%((c[a1+8>>2]|0)>>>0)|0;hy(a1)}else{n=1124}}while(0);L1570:do{if((n|0)==1124){do{if(a3){if((a[797952]&1)!=0){break}a1=c[198587]|0;a4=a1+4|0;aZ=c[a4>>2]|0;if((aZ|0)==0){a6=c[a1+8>>2]|0}else{a6=aZ}c[a4>>2]=a6-1;hy(a1);break L1570}}while(0);if(!a5){break}if((a[797944]&1)!=0){break}a1=c[198587]|0;a4=a1|0;aZ=(c[a4>>2]|0)+((c[a1+4>>2]|0)*12|0)+4|0;a[aZ]=a[aZ]&1^1;fz[c[59506]&8191]();aZ=a1+8|0;aV=c[aZ>>2]|0;if((aV|0)!=0){aT=0;E=0;a$=aV;while(1){aV=c[a4>>2]|0;if((a[aV+(E*12|0)+4|0]&1)==0){a7=aT;a8=a$}else{fy[c[59504]&511](aT,1,c[aV+(E*12|0)+8>>2]|0);a7=aT+1|0;a8=c[aZ>>2]|0}aV=E+1|0;if(aV>>>0<a8>>>0){aT=a7;E=aV;a$=a8}else{break}}}hy(a1)}}while(0);a[797952]=a3&1;a[797960]=a0&1;a[797944]=a5&1}if((c[184100]|0)!=0){a5=a[797247]|0;if((a5&1)==0){a0=ft[c[(c[199306]|0)+12>>2]&63](c[199309]|0,52)|0;a3=797408;a9=(c[a3>>2]&0|a0&1|0)!=0|(c[a3+4>>2]&1048576|0)!=0;ba=a[797247]|0}else{a9=0;ba=a5}if((ba&1)==0){ba=ft[c[(c[199306]|0)+12>>2]&63](c[199309]|0,53)|0;a5=797408;bb=(c[a5>>2]&0|ba&1|0)!=0|(c[a5+4>>2]&2097152|0)!=0}else{bb=0}do{if(a9){if((a[797936]&1)!=0){n=1145;break}f5((fw[c[184097]&31]()|0)^1,1)}else{n=1145}}while(0);do{if((n|0)==1145){if(!bb){break}if((a[797928]&1)!=0){break}a5=fw[c[184100]&31]()|0;ba=fw[c[184098]&31]()|0;if((a5|0)==(-1|0)|(a5|0)==0){a3=c[198610]|0;a0=(a3|0)!=0?a3:c[p>>2]|0;a2(32608,59,1,a0|0)|0;a0=c[198610]|0;a3=(a0|0)!=0?a0:c[p>>2]|0;aY(a3|0)|0;break}if(ba>>>0<a5>>>0){bc=((ba+1|0)>>>0)%((a5+1|0)>>>0)|0}else{bc=0}f6(bc)}}while(0);a[797936]=a9&1;a[797928]=bb&1}do{if((a[797247]&1)==0){bb=ft[c[(c[199306]|0)+12>>2]&63](c[199309]|0,37)|0;a9=797408;if((c[a9>>2]&0|bb&1|0)==0&(c[a9+4>>2]&32|0)==0){bd=0;break}if((a[797840]&1)!=0){bd=1;break}f3();bd=1}else{bd=0}}while(0);a[797840]=bd;i=d;return}function gb(a,d){a=a|0;d=d|0;var e=0;e=(c[184136]|0)-1|0;c[184136]=e;b[(c[184135]|0)+(e<<1)>>1]=d;d=(c[184136]|0)-1|0;c[184136]=d;b[(c[184135]|0)+(d<<1)>>1]=a;return}function gc(){var b=0,d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0;b=i;i=i+4096|0;d=b|0;L1621:do{if((a[794146]&1)!=0){switch(c[160384]|0){case 1:{e=a[637400]|0;if((e&1)==0){f=e}else{e=c[198610]|0;g=(e|0)!=0?e:c[p>>2]|0;a2(35856,32,1,g|0)|0;g=c[198610]|0;e=(g|0)!=0?g:c[p>>2]|0;aY(e|0)|0;f=a[637400]|0}if((f&1)==0){h=f}else{e=c[198610]|0;g=(e|0)!=0?e:c[p>>2]|0;ec(g|0,36656,(j=i,i=i+8|0,c[j>>2]=678410,j)|0)|0;i=j;g=c[198610]|0;e=(g|0)!=0?g:c[p>>2]|0;aY(e|0)|0;h=a[637400]|0}if((h&1)!=0){e=c[198610]|0;g=(e|0)!=0?e:c[p>>2]|0;ec(g|0,36288,(j=i,i=i+8|0,c[j>>2]=682506,j)|0)|0;i=j;g=c[198610]|0;e=(g|0)!=0?g:c[p>>2]|0;aY(e|0)|0}gk(678410,1280);gk(682506,1537);break L1621;break};case 0:{e=a[637400]|0;if((e&1)==0){k=e}else{e=c[198610]|0;g=(e|0)!=0?e:c[p>>2]|0;a2(37104,32,1,g|0)|0;g=c[198610]|0;e=(g|0)!=0?g:c[p>>2]|0;aY(e|0)|0;k=a[637400]|0}if((k&1)==0){l=k}else{e=c[198610]|0;g=(e|0)!=0?e:c[p>>2]|0;ec(g|0,36656,(j=i,i=i+8|0,c[j>>2]=678410,j)|0)|0;i=j;g=c[198610]|0;e=(g|0)!=0?g:c[p>>2]|0;aY(e|0)|0;l=a[637400]|0}if((l&1)!=0){e=c[198610]|0;g=(e|0)!=0?e:c[p>>2]|0;ec(g|0,36288,(j=i,i=i+8|0,c[j>>2]=682506,j)|0)|0;i=j;g=c[198610]|0;e=(g|0)!=0?g:c[p>>2]|0;aY(e|0)|0}gk(678410,0);gk(682506,1);break L1621;break};case 2:case 3:{e=a[637400]|0;if((e&1)==0){m=e}else{e=c[198610]|0;g=(e|0)!=0?e:c[p>>2]|0;a2(35128,30,1,g|0)|0;g=c[198610]|0;e=(g|0)!=0?g:c[p>>2]|0;aY(e|0)|0;m=a[637400]|0}if((m&1)==0){n=m}else{e=c[198610]|0;g=(e|0)!=0?e:c[p>>2]|0;ec(g|0,34696,(j=i,i=i+8|0,c[j>>2]=678410,j)|0)|0;i=j;g=c[198610]|0;e=(g|0)!=0?g:c[p>>2]|0;aY(e|0)|0;n=a[637400]|0}if((n&1)!=0){e=c[198610]|0;g=(e|0)!=0?e:c[p>>2]|0;ec(g|0,34264,(j=i,i=i+8|0,c[j>>2]=686602,j)|0)|0;i=j;g=c[198610]|0;e=(g|0)!=0?g:c[p>>2]|0;aY(e|0)|0}gk(678410,256);gk(686602,512);break L1621;break};case 4:{e=a[637400]|0;if((e&1)==0){o=e}else{e=c[198610]|0;g=(e|0)!=0?e:c[p>>2]|0;a2(33784,40,1,g|0)|0;g=c[198610]|0;e=(g|0)!=0?g:c[p>>2]|0;aY(e|0)|0;o=a[637400]|0}if((o&1)==0){q=o}else{e=c[198610]|0;g=(e|0)!=0?e:c[p>>2]|0;ec(g|0,33456,(j=i,i=i+8|0,c[j>>2]=690698,j)|0)|0;i=j;g=c[198610]|0;e=(g|0)!=0?g:c[p>>2]|0;aY(e|0)|0;q=a[637400]|0}if((q&1)!=0){e=c[198610]|0;g=(e|0)!=0?e:c[p>>2]|0;ec(g|0,32984,(j=i,i=i+8|0,c[j>>2]=694794,j)|0)|0;i=j;g=c[198610]|0;e=(g|0)!=0?g:c[p>>2]|0;aY(e|0)|0}gk(690698,768);gk(694794,1024);break L1621;break};default:{break L1621}}}}while(0);q=c[196482]|0;if((q|0)!=0){XZ(c[q>>2]|0);XZ(c[q+12>>2]|0);XZ(q)}c[196482]=0;XZ(c[196483]|0);c[196483]=0;q=c[198587]|0;if((q|0)!=0){hx(q)}q=c[196486]|0;if((q|0)!=0){o=c[q>>2]|0;if((o|0)!=0){aQ(o|0)|0}XZ(c[q+4>>2]|0);XZ(c[q+12>>2]|0);XZ(q)}do{if((a[795517]&1)==0){if((a[795516]&1)!=0){break}q=d|0;if((a[633274]&1)==0){break}gt(q,698890,38344);o=gh(q)|0;if((a[637400]&1)==0){break}n=c[198610]|0;m=(n|0)!=0?n:c[p>>2]|0;n=o?37776:37488;ec(m|0,38016,(j=i,i=i+16|0,c[j>>2]=q,c[j+8>>2]=n,j)|0)|0;i=j;n=c[198610]|0;q=(n|0)!=0?n:c[p>>2]|0;aY(q|0)|0}}while(0);gD();d=c[184111]|0;do{if((d|0)!=0){if((a[797241]&1)!=0){break}fz[d&8191]()}}while(0);gE();if((a[797243]&1)!=0){c[199308]=0}if((a[797244]&1)!=0){c[199307]=0}if((a[797245]&1)!=0){c[199309]=0}a[797243]=0;a[797244]=0;a[797245]=0;fz[c[59462]&8191]();fz[c[59502]&8191]();d=c[184120]|0;if((d|0)!=0){q=d+4104|0;if((c[q>>2]|0)==0){r=d|0}else{n=d+4100|0;m=d|0;o=0;while(1){l=c[n>>2]|0;gK(c[m>>2]|0,c[l+(o<<4)+4>>2]|0,c[(c[c[l+(o<<4)+8>>2]>>2]|0)+(c[l+(o<<4)+12>>2]<<3)>>2]|0);l=o+1|0;if(l>>>0<(c[q>>2]|0)>>>0){o=l}else{r=m;break}}}m=c[r>>2]|0;r=d+4|0;gL(m,r)|0;hn(c[184120]|0)}X2(731688,0,4800);if((a[637436]&1)==0){a[794444]=0;i=b;return}if((a[637400]&1)!=0){r=c[198610]|0;m=(r|0)!=0?r:c[p>>2]|0;ec(m|0,44776,(j=i,i=i+8|0,c[j>>2]=637437,j)|0)|0;i=j;m=c[198610]|0;r=(m|0)!=0?m:c[p>>2]|0;aY(r|0)|0}if((bz(637437)|0)<0){r=c[198610]|0;m=(r|0)!=0?r:c[p>>2]|0;ec(m|0,44104,(j=i,i=i+8|0,c[j>>2]=637437,j)|0)|0;i=j;j=c[198610]|0;m=(j|0)!=0?j:c[p>>2]|0;aY(m|0)|0}a[637436]=0;a[794444]=0;i=b;return}function gd(d,e){d=d|0;e=e|0;var f=0,g=0;f=c[184125]|0;c[184125]=f+1;b[(c[184134]|0)+(f<<1)>>1]=d;d=c[184125]|0;c[184125]=d+1;b[(c[184134]|0)+(d<<1)>>1]=e;e=c[184125]|0;if(e>>>0<(c[184126]|0)>>>0){return}if(fZ(c[184134]|0,e)|0){g=a[637401]&1}else{g=0}a[637401]=g;c[184125]=0;return}function ge(d,f,g,h){d=d|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;j=i;i=i+16|0;k=j|0;l=j+8|0;m=f&255;f=c[196486]|0;do{if((f|0)!=0){if((a[790044]&1)==0){break}if((d6(l|0,2,1,c[f>>2]|0)|0)!=1){a[794143]=1;break}n=b[l>>1]|0;i=j;return n|0}}while(0);if(h>>>0<25|(m|0)==3){o=fd[c[(c[199306]|0)+8>>2]&15](c[199309]|0,7776,d,m,g,h)|0}else{o=0}g=(m|0)==1;if(g&(d|0)==0){m=797408;l=c[m>>2]|0;f=c[m+4>>2]|0;m=Yg(1,0,h|0)|0;p=F;q=((l&m|0)!=0|(f&p|0)!=0)&1|o}else{q=o}do{if(g){if((h-4|0)>>>0<=3){r=q;break}o=q<<16>>16!=0;do{if(o){if((a[794150+d|0]&1)==0){s=b[794158+(d<<1)>>1]|0;t=1<<h;break}else{p=1<<h;f=794158+(d<<1)|0;m=(e[f>>1]|0|p)&65535;b[f>>1]=m;s=m;t=p;break}}else{p=1<<h;m=794158+(d<<1)|0;f=(e[m>>1]|0)&(p^65535)&65535;b[m>>1]=f;s=f;t=p}}while(0);if((s&65535&t|0)==0){u=o}else{u=(((c[198544]|0)>>>0)%((c[149090]|0)>>>0)|0)>>>0<(c[149091]|0)>>>0&o}r=u&1}else{r=q}}while(0);q=c[196486]|0;if((q|0)==0){n=r;i=j;return n|0}if((a[790044]&1)!=0){n=r;i=j;return n|0}b[k>>1]=r;a2(k|0,2,1,c[q>>2]|0)|0;n=r;i=j;return n|0}function gf(){var a=0,b=0,d=0;a=i;dd(67960|0)|0;dd(67872|0)|0;b=c[o>>2]|0;a2(96928|0,11,1,b|0)|0;ec(b|0,96536|0,(d=i,i=i+16|0,c[d>>2]=95792,c[d+8>>2]=32,d)|0)|0;i=d;ec(b|0,95288|0,(d=i,i=i+8|0,c[d>>2]=94856,d)|0)|0;i=d;dd(67960|0)|0;dd(67776|0)|0;dd(67688|0)|0;dd(67544|0)|0;dd(67280|0)|0;dd(66816|0)|0;dd(66648|0)|0;dd(66464|0)|0;dd(66168|0)|0;dd(65960|0)|0;dd(65800|0)|0;dd(65576|0)|0;dd(65352|0)|0;dd(65256|0)|0;dd(65128|0)|0;dd(64800|0)|0;dd(64648|0)|0;c2(64408|0,(d=i,i=i+8|0,c[d>>2]=8,d)|0)|0;i=d;c2(64280|0,(d=i,i=i+8|0,c[d>>2]=8,d)|0)|0;i=d;c2(64176|0,(d=i,i=i+8|0,c[d>>2]=8,d)|0)|0;i=d;dd(64016|0)|0;dd(63888|0)|0;dd(63728|0)|0;dd(63608|0)|0;dd(63536|0)|0;dd(63216|0)|0;dd(63040|0)|0;dd(62896|0)|0;dd(62760|0)|0;dd(62696|0)|0;dd(62584|0)|0;dd(62464|0)|0;dd(62352|0)|0;dd(62240|0)|0;dd(62168|0)|0;dd(61816|0)|0;i=a;return}function gg(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0;e=c5(b|0,23072|0)|0;do{if((e|0)!=0){eo(e|0,0,2)|0;b=cb(e|0)|0;ew(e|0);f=XY(b+1|0)|0;if((f|0)==0){g=c[198610]|0;h=(g|0)!=0?g:c[p>>2]|0;a2(64088|0,47,1,h|0)|0;h=c[198610]|0;g=(h|0)!=0?h:c[p>>2]|0;aY(g|0)|0;aQ(e|0)|0;break}g=d6(f|0,1,b|0,e|0)|0;if((g|0)<(b|0)){h=c[198610]|0;i=(h|0)!=0?h:c[p>>2]|0;a2(54608|0,44,1,i|0)|0;i=c[198610]|0;h=(i|0)!=0?i:c[p>>2]|0;aY(h|0)|0}c[d>>2]=f;a[f+b|0]=0;aQ(e|0)|0;j=g;return j|0}}while(0);c[d>>2]=0;j=-1;return j|0}function gh(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;d=i;if((a[637400]&1)!=0){e=c[198610]|0;f=(e|0)!=0?e:c[p>>2]|0;ec(f|0,39040,(g=i,i=i+8|0,c[g>>2]=b,g)|0)|0;i=g;f=c[198610]|0;e=(f|0)!=0?f:c[p>>2]|0;aY(e|0)|0}e=fw[c[59478]&31]()|0;if((e|0)==0){h=0;i=d;return h|0}f=XY(e)|0;if((f|0)==0){j=c[198610]|0;k=(j|0)!=0?j:c[p>>2]|0;a2(34760,70,1,k|0)|0;k=c[198610]|0;j=(k|0)!=0?k:c[p>>2]|0;aY(j|0)|0;h=0;i=d;return h|0}if((a[637400]&1)!=0){j=c[198610]|0;k=(j|0)!=0?j:c[p>>2]|0;ec(k|0,30240,(g=i,i=i+8|0,c[g>>2]=e,g)|0)|0;i=g;k=c[198610]|0;j=(k|0)!=0?k:c[p>>2]|0;aY(j|0)|0}do{if(ft[c[59480]&63](f,e)|0){j=c5(b|0,85512)|0;if((j|0)==0){l=1284;break}k=(a2(f|0,1,e|0,j|0)|0)==(e|0);aQ(j|0)|0;if(k){m=1}else{l=1284}}else{l=1284}}while(0);if((l|0)==1284){l=c[198610]|0;e=(l|0)!=0?l:c[p>>2]|0;ec(e|0,26240,(g=i,i=i+8|0,c[g>>2]=b,g)|0)|0;i=g;g=c[198610]|0;b=(g|0)!=0?g:c[p>>2]|0;aY(b|0)|0;m=0}XZ(f);h=m;i=d;return h|0}function gi(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;if((a[794445]&1)==0){d=c[198610]|0;e=(d|0)!=0?d:c[p>>2]|0;ec(e|0,63392,(e=i,i=i+16|0,c[e>>2]=83144,c[e+8>>2]=827,e)|0)|0;i=e;e=c[198610]|0;d=(e|0)!=0?e:c[p>>2]|0;aY(d|0)|0;cd(2)}else{f=1024;g=794447;h=b}while(1){b=f-1|0;if((b|0)==0){break}d=a[h]|0;a[g]=d;if(d<<24>>24==0){j=1298;break}else{f=b;g=g+1|0;h=h+1|0}}if((j|0)==1298){eC(795472,1)}a[g]=0;if((a[h]|0)==0){eC(795472,1)}else{k=h}do{k=k+1|0;}while((a[k]|0)!=0);eC(795472,1)}function gj(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;d=i;i=i+16|0;e=d|0;f=d+8|0;if((a[637400]&1)!=0){g=c[198610]|0;h=(g|0)!=0?g:c[p>>2]|0;ec(h|0,22168,(j=i,i=i+8|0,c[j>>2]=b,j)|0)|0;i=j;h=c[198610]|0;g=(h|0)!=0?h:c[p>>2]|0;aY(g|0)|0}c[e>>2]=0;g=gg(b,e)|0;if((g|0)<0){h=c[198610]|0;k=(h|0)!=0?h:c[p>>2]|0;ec(k|0,99760,(j=i,i=i+8|0,c[j>>2]=b,j)|0)|0;i=j;b=c[198610]|0;k=(b|0)!=0?b:c[p>>2]|0;aY(k|0)|0;l=0;i=d;return l|0}if((a[637400]&1)!=0){k=c[198610]|0;b=(k|0)!=0?k:c[p>>2]|0;ec(b|0,95360,(j=i,i=i+8|0,c[j>>2]=g,j)|0)|0;i=j;j=c[198610]|0;b=(j|0)!=0?j:c[p>>2]|0;aY(b|0)|0}c[f>>2]=0;L1818:do{if((a[633272]&1)==0){m=1317}else{if((a[637400]&1)!=0){b=c[198610]|0;j=(b|0)!=0?b:c[p>>2]|0;a2(91376,36,1,j|0)|0;j=c[198610]|0;b=(j|0)!=0?j:c[p>>2]|0;aY(b|0)|0}switch(c[160384]|0){case 1:{n=1280;o=1537;break};case 0:{n=0;o=1;break};case 4:{n=768;o=1024;break};case 2:case 3:{n=256;o=512;break};default:{m=1317;break L1818}}b=fe[c[59498]&127](n)|0;j=fe[c[59498]&127](o)|0;if((b|0)==0){q=0;r=0}else{q=XY(b)|0;r=b}if((j|0)==0){s=0;t=0}else{b=XY(j)|0;c[f>>2]=b;s=b;t=j}do{if((q|0)!=0){j=fe[c[59500]&127](n)|0;if((j|0)==0){break}X5(q|0,j|0,r)|0}}while(0);j=f;if((s|0)==0){u=0;v=t;w=n;x=o;y=r;z=q;A=j;break}b=fe[c[59500]&127](o)|0;if((b|0)==0){u=s;v=t;w=n;x=o;y=r;z=q;A=j;break}X5(s|0,b|0,t)|0;u=s;v=t;w=n;x=o;y=r;z=q;A=j}}while(0);if((m|0)==1317){u=0;v=0;w=-1;x=-1;y=0;z=0;A=f}f=c[e>>2]|0;e=ft[c[59460]&63](f,g)|0;do{if(e){do{if((z|0)!=0){g=fe[c[59500]&127](w)|0;if((g|0)==0){break}X5(g|0,z|0,y)|0}}while(0);if((u|0)==0){break}g=fe[c[59500]&127](x)|0;if((g|0)==0){break}X5(g|0,u|0,v)|0}}while(0);if((z|0)==0){B=u}else{XZ(z);B=c[A>>2]|0}if((B|0)!=0){XZ(B)}XZ(f);l=e;i=d;return l|0}function gk(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;e=i;i=i+8200|0;f=e|0;g=e+4096|0;h=e+8192|0;j=fe[c[59498]&127](d)|0;k=fe[c[59500]&127](d)|0;if((k|0)==0|(j|0)==0){i=e;return}l=c5(b|0,85512)|0;do{if((l|0)!=0){m=(a2(k|0,1,j|0,l|0)|0)==(j|0);aQ(l|0)|0;if(!m){break}if((a[637400]&1)==0){i=e;return}m=c[198610]|0;n=(m|0)!=0?m:c[p>>2]|0;ec(n|0,81352,(o=i,i=i+8|0,c[o>>2]=b,o)|0)|0;i=o;n=c[198610]|0;m=(n|0)!=0?n:c[p>>2]|0;aY(m|0)|0;i=e;return}}while(0);b=c[198610]|0;a2(87944,42,1,((b|0)!=0?b:c[p>>2]|0)|0)|0;b=c[198610]|0;aY(((b|0)!=0?b:c[p>>2]|0)|0)|0;b=c[198610]|0;a2(84760,46,1,((b|0)!=0?b:c[p>>2]|0)|0)|0;b=c[198610]|0;aY(((b|0)!=0?b:c[p>>2]|0)|0)|0;b=f|0;l=g|0;g=dE(87160)|0;do{if((g|0)!=0){bN(b|0,4096,49560,(o=i,i=i+8|0,c[o>>2]=g,o)|0)|0;i=o;eG(h|0)|0;m=bd(h|0)|0;cT(l|0,4096,48760,m|0)|0;m=X1(b|0)|0;n=m>>>0>4096?0:4096-m|0;L1873:do{if((n|0)==0){q=l;r=1348}else{s=n;t=f+m|0;u=l;while(1){v=s-1|0;if((v|0)==0){break}w=a[u]|0;a[t]=w;if(w<<24>>24==0){break L1873}else{s=v;t=t+1|0;u=u+1|0}}a[t]=0;q=u;r=1348}}while(0);do{if((r|0)==1348){if((a[q]|0)==0){break}else{x=q}do{x=x+1|0;}while((a[x]|0)!=0)}}while(0);switch(d|0){case 1:case 1537:{y=44304;break};case 512:{y=44360;break};case 768:{y=43528;break};case 1024:{y=42840;break};case 0:case 1280:case 256:{y=100880;break};default:{y=798256}}u=X1(b|0)|0;t=u>>>0>4096?0:4096-u|0;L1891:do{if((t|0)==0){z=y;r=1361}else{m=t;n=f+u|0;s=y;while(1){v=m-1|0;if((v|0)==0){break}w=a[s]|0;a[n]=w;if(w<<24>>24==0){break L1891}else{m=v;n=n+1|0;s=s+1|0}}a[n]=0;z=s;r=1361}}while(0);do{if((r|0)==1361){if((a[z]|0)==0){break}else{A=z}do{A=A+1|0;}while((a[A]|0)!=0)}}while(0);s=c5(b|0,85512)|0;if((s|0)==0){break}n=(a2(k|0,1,j|0,s|0)|0)==(j|0);aQ(s|0)|0;if(!n){break}n=c[198610]|0;s=(n|0)!=0?n:c[p>>2]|0;ec(s|0,47800,(o=i,i=i+8|0,c[o>>2]=b,o)|0)|0;i=o;s=c[198610]|0;n=(s|0)!=0?s:c[p>>2]|0;aY(n|0)|0;i=e;return}}while(0);o=c[198610]|0;a2(46720,57,1,((o|0)!=0?o:c[p>>2]|0)|0)|0;o=c[198610]|0;aY(((o|0)!=0?o:c[p>>2]|0)|0)|0;i=e;return}function gl(b){b=b|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0;e=i;i=i+8280|0;f=e|0;g=e+48|0;h=e+56|0;j=e+4152|0;k=e+8248|0;l=e+8264|0;m=e+8272|0;L1908:do{if((a[674314]|0)!=0){if((a[731764]&1)!=0){break}n=cg(674314,46)|0;o=(n|0)==0?798256:n+1|0;if((o|0)==0){break}if((X8(o|0,77920)|0)!=0){break}a[637436]=1;o=h|0;n=j|0;q=gp(732280,93176)|0;do{if((q|0)!=0){c[g>>2]=0;r=gg(674314,g)|0;if((r|0)<22){s=c[198610]|0;t=(s|0)!=0?s:c[p>>2]|0;ec(t|0,65496,(u=i,i=i+8|0,c[u>>2]=107,u)|0)|0;i=u;t=c[198610]|0;s=(t|0)!=0?t:c[p>>2]|0;aY(s|0)|0;XZ(c[g>>2]|0);v=0}else{s=r-22|0;L1917:do{if((s|0)>22){t=c[g>>2]|0;w=t+r|0;x=t+22|0;y=t+s|0;while(1){if((d[y+1|0]<<8|d[y]|d[y+2|0]<<16|d[y+3|0]<<24|0)==101010256){if((y+((d[y+21|0]<<8|d[y+20|0])+22)|0)==(w|0)){break}}z=y-1|0;if(z>>>0>x>>>0){y=z}else{A=1385;break L1917}}x=d[y+17|0]<<8|d[y+16|0]|d[y+18|0]<<16|d[y+19|0]<<24;w=t+x|0;L1925:do{if((d[t+(x+1)|0]<<8|d[w]|d[t+(x+2)|0]<<16|d[t+(x+3)|0]<<24|0)==33639248){z=q|0;B=q+4|0;C=w;L1927:while(1){D=a[C+10|0]|0;E=a[C+11|0]|0;F=a[C+16|0]|0;G=a[C+17|0]|0;H=a[C+18|0]|0;I=a[C+19|0]|0;J=d[C+21|0]<<8|d[C+20|0]|d[C+22|0]<<16|d[C+23|0]<<24;K=d[C+25|0]<<8|d[C+24|0]|d[C+26|0]<<16|d[C+27|0]<<24;L=d[C+29|0]<<8|d[C+28|0];M=d[C+33|0]<<8|d[C+32|0];N=d[C+31|0]<<8|d[C+30|0];X2(o|0,0,4096);if(L>>>0>4095){A=1391;break}O=C+46|0;X5(o|0,O|0,L)|0;O=d[C+43|0]<<8|d[C+42|0]|d[C+44|0]<<16|d[C+45|0]<<24;P=O+30+(d[t+(O+27)|0]<<8|d[t+(O+26)|0])+(d[t+(O+29)|0]<<8|d[t+(O+28)|0])|0;if((a[637400]&1)!=0){O=c[198610]|0;Q=(O|0)!=0?O:c[p>>2]|0;ec(Q|0,55360,(u=i,i=i+24|0,c[u>>2]=P,c[u+8>>2]=J,c[u+16>>2]=K,u)|0)|0;i=u;Q=c[198610]|0;O=(Q|0)!=0?Q:c[p>>2]|0;aY(O|0)|0}O=cg(o|0,46)|0;Q=(O|0)==0?798256:O+1|0;L1933:do{if((Q|0)!=0){O=c[B>>2]|0;R=0;while(1){if(R>>>0>=O>>>0){break L1933}if((X8(c[(c[z>>2]|0)+(R<<3)>>2]|0,Q|0)|0)==0){break L1927}else{R=R+1|0}}}}while(0);Q=L+46+N+M|0;R=C+Q|0;if((d[C+(Q+1)|0]<<8|d[R]|d[C+(Q+2)|0]<<16|d[C+(Q+3)|0]<<24|0)==33639248){C=R}else{break L1925}}if((A|0)==1391){C=c[198610]|0;z=(C|0)!=0?C:c[p>>2]|0;ec(z|0,65496,(u=i,i=i+8|0,c[u>>2]=141,u)|0)|0;i=u;z=c[198610]|0;C=(z|0)!=0?z:c[p>>2]|0;aY(C|0)|0;S=0;break L1917}C=(G&255)<<8|F&255|(H&255)<<16|(I&255)<<24;z=(E&255)<<8|D&255;B=t+P|0;R=cg(o|0,47)|0;gB(n,674314,(R|0)==0?o:R+1|0);if((z|0)==8){R=XY(K)|0;if((R|0)!=0){X2(f|0,0,48);Q=XY(43784)|0;do{if((Q|0)==0){O=c[198610]|0;T=(O|0)!=0?O:c[p>>2]|0;ec(T|0,65496,(u=i,i=i+8|0,c[u>>2]=61,u)|0)|0;i=u;T=c[198610]|0;O=(T|0)!=0?T:c[p>>2]|0;aY(O|0)|0}else{O=f+28|0;c[O>>2]=Q;c[Q>>2]=0;c[Q+10992>>2]=0;c[Q+10996>>2]=0;c[Q+43780>>2]=1;c[Q+11e3>>2]=1;c[Q+11004>>2]=0;c[Q+11008>>2]=-15;c[f>>2]=B;c[f+4>>2]=J;c[f+12>>2]=R;c[f+16>>2]=K;T=(jA(f)|0)==1;U=c[O>>2]|0;if((U|0)!=0){XZ(U);c[O>>2]=0}if(!T){T=c[198610]|0;O=(T|0)!=0?T:c[p>>2]|0;ec(O|0,65496,(u=i,i=i+8|0,c[u>>2]=71,u)|0)|0;i=u;O=c[198610]|0;T=(O|0)!=0?O:c[p>>2]|0;aY(T|0)|0;break}if((K|0)==0){V=0}else{T=K;O=R;U=-1;while(1){W=T-1|0;X=d[O]|0;Y=c[15880+(((X^U)&15)<<2)>>2]^U>>>4;Z=Y>>>4^c[15880+((Y&15^X>>>4)<<2)>>2];if((W|0)==0){break}else{T=W;O=O+1|0;U=Z}}V=~Z}if((V|0)!=(C|0)){U=c[198610]|0;O=(U|0)!=0?U:c[p>>2]|0;ec(O|0,39640,(u=i,i=i+16|0,c[u>>2]=V,c[u+8>>2]=C,u)|0)|0;i=u;O=c[198610]|0;U=(O|0)!=0?O:c[p>>2]|0;aY(U|0)|0}U=c5(n|0,85512)|0;do{if((U|0)!=0){O=(a2(R|0,1,K|0,U|0)|0)==(K|0);aQ(U|0)|0;if(!O){break}XZ(R);O=4096;T=674314;M=n;while(1){N=O-1|0;if((N|0)==0){break}L=a[M]|0;a[T]=L;if(L<<24>>24==0){S=1;break L1917}else{O=N;T=T+1|0;M=M+1|0}}a[T]=0;if((a[M]|0)==0){S=1;break L1917}else{_=M}while(1){O=_+1|0;if((a[O]|0)==0){S=1;break L1917}else{_=O}}}}while(0);U=c[198610]|0;M=(U|0)!=0?U:c[p>>2]|0;ec(M|0,65496,(u=i,i=i+8|0,c[u>>2]=81,u)|0)|0;i=u;M=c[198610]|0;U=(M|0)!=0?M:c[p>>2]|0;aY(U|0)|0}}while(0);XZ(R)}C=c[198610]|0;Q=(C|0)!=0?C:c[p>>2]|0;ec(Q|0,65496,(u=i,i=i+8|0,c[u>>2]=175,u)|0)|0;i=u;Q=c[198610]|0;C=(Q|0)!=0?Q:c[p>>2]|0;aY(C|0)|0;S=0;break L1917}else if((z|0)==0){C=c5(n|0,85512)|0;if((C|0)!=0){Q=(a2(B|0,1,K|0,C|0)|0)==(K|0);aQ(C|0)|0;if(Q){S=1;break L1917}}Q=c[198610]|0;ec(((Q|0)!=0?Q:c[p>>2]|0)|0,65496,(u=i,i=i+8|0,c[u>>2]=165,u)|0)|0;i=u;Q=c[198610]|0;aY(((Q|0)!=0?Q:c[p>>2]|0)|0)|0;S=0;break L1917}else{Q=c[198610]|0;ec(((Q|0)!=0?Q:c[p>>2]|0)|0,65496,(u=i,i=i+8|0,c[u>>2]=178,u)|0)|0;i=u;Q=c[198610]|0;aY(((Q|0)!=0?Q:c[p>>2]|0)|0)|0;S=0;break L1917}}}while(0);t=c[198610]|0;a2(46056,101,1,((t|0)!=0?t:c[p>>2]|0)|0)|0;t=c[198610]|0;aY(((t|0)!=0?t:c[p>>2]|0)|0)|0;t=c[198610]|0;ec(((t|0)!=0?t:c[p>>2]|0)|0,65496,(u=i,i=i+8|0,c[u>>2]=186,u)|0)|0;i=u;t=c[198610]|0;aY(((t|0)!=0?t:c[p>>2]|0)|0)|0;S=0}else{A=1385}}while(0);if((A|0)==1385){s=c[198610]|0;r=(s|0)!=0?s:c[p>>2]|0;ec(r|0,65496,(u=i,i=i+8|0,c[u>>2]=113,u)|0)|0;i=u;r=c[198610]|0;s=(r|0)!=0?r:c[p>>2]|0;aY(s|0)|0;S=0}XZ(c[g>>2]|0);v=S}s=q+4|0;r=q|0;t=c[r>>2]|0;if((c[s>>2]|0)==0){$=t}else{w=0;x=t;while(1){XZ(c[x+(w<<3)>>2]|0);t=w+1|0;y=c[r>>2]|0;if(t>>>0<(c[s>>2]|0)>>>0){w=t;x=y}else{$=y;break}}}XZ($);XZ(q);if(v){aa=4096;ab=637437;ac=674314}else{break}while(1){x=aa-1|0;if((x|0)==0){break}w=a[ac]|0;a[ab]=w;if(w<<24>>24==0){break L1908}else{aa=x;ab=ab+1|0;ac=ac+1|0}}a[ab]=0;if((a[ac]|0)==0){break L1908}else{ad=ac}while(1){ad=ad+1|0;if((a[ad]|0)==0){break L1908}}}}while(0);q=c[198610]|0;n=(q|0)!=0?q:c[p>>2]|0;ec(n|0,74664,(u=i,i=i+8|0,c[u>>2]=674314,u)|0)|0;i=u;n=c[198610]|0;q=(n|0)!=0?n:c[p>>2]|0;aY(q|0)|0;a[637436]=0;ae=0;i=e;return ae|0}}while(0);L1999:do{switch(b|0){case 2:{u=m|0;c[u>>2]=(a[674314]|0)!=0?674314:0;c[m+4>>2]=645640;if(gm(257,u,2)|0){break L1999}else{ae=0}i=e;return ae|0};case 3:{u=m|0;c[u>>2]=(a[674314]|0)!=0?674314:0;c[m+4>>2]=645640;if(gm(258,u,2)|0){break L1999}else{ae=0}i=e;return ae|0};case 1:{u=m|0;c[u>>2]=(a[674314]|0)!=0?674314:0;c[m+4>>2]=641544;if(gm(260,u,2)|0){break L1999}else{ae=0}i=e;return ae|0};case 0:{if((a[795516]&1)==0){c[l>>2]=674314;if(gm(0,l,1)|0){break L1999}else{ae=0}i=e;return ae|0}if((a[731766]&1)==0){u=c[198610]|0;ad=(u|0)!=0?u:c[p>>2]|0;a2(51224,78,1,ad|0)|0;ad=c[198610]|0;u=(ad|0)!=0?ad:c[p>>2]|0;aY(u|0)|0;ae=0;i=e;return ae|0}else{if(fe[c[59488]&127](0)|0){break L1999}else{ae=0}i=e;return ae|0}break};case 4:{u=k|0;c[u>>2]=(a[674314]|0)!=0?674314:0;c[k+4>>2]=(a[649736]|0)!=0?649736:0;c[k+8>>2]=(a[653832]|0)!=0?653832:0;if(gm(259,u,3)|0){break L1999}else{ae=0}i=e;return ae|0};default:{u=c[198610]|0;a2(71552,39,1,((u|0)!=0?u:c[p>>2]|0)|0)|0;u=c[198610]|0;aY(((u|0)!=0?u:c[p>>2]|0)|0)|0;ae=0;i=e;return ae|0}}}while(0);ae=1;i=e;return ae|0}function gm(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;g=i;i=i+520|0;h=g|0;j=g+368|0;k=g+400|0;l=g+408|0;m=g+416|0;n=g+424|0;o=g+440|0;q=g+456|0;if((f|0)==0|f>>>0>4){r=0;i=g;return r|0}X2(n|0,0,16);X2(o|0,0,16);X2(q|0,0,64);do{if((a[702986]|0)==0){s=0}else{t=c5(702986,78048)|0;if((t|0)==0){s=0;break}eo(t|0,0,2)|0;u=(cb(t|0)|0)+2|0;ew(t|0);v=(u|0)==0?0:u;w=XY(v)|0;if((w|0)==0){aQ(t|0)|0;s=0;break}if((c[w-4>>2]&3|0)!=0){X2(w|0,0,v|0)}v=w;x=w;while(1){if((eh(t|0)|0)!=0){y=x;break}bX(x|0,u-x+v|0,t|0)|0;z=x+(X1(x|0)|0)|0;if((z|0)==0){y=0;break}else{x=z}}x=b1(y|0,-1|0)|0;if((x|0)!=0){a[x]=0}aQ(t|0)|0;if((a[637400]&1)==0){s=w;break}x=c[198610]|0;ec(((x|0)!=0?x:c[p>>2]|0)|0,52144,(A=i,i=i+8|0,c[A>>2]=702986,A)|0)|0;i=A;x=c[198610]|0;aY(((x|0)!=0?x:c[p>>2]|0)|0)|0;s=w}}while(0);y=(a[637400]&1)!=0;do{if((a[731700]&1)==0){if(y){x=c[198610]|0;v=(x|0)!=0?x:c[p>>2]|0;x=c[e>>2]|0;ec(v|0,69680,(A=i,i=i+8|0,c[A>>2]=x,A)|0)|0;i=A;x=c[198610]|0;v=(x|0)!=0?x:c[p>>2]|0;aY(v|0)|0}v=c[e>>2]|0;x=n|0;c[m>>2]=0;u=gg(v,m)|0;if((u|0)<1){B=u;C=0}else{L2051:do{if((a[719370]&1)==0){v=c[m>>2]|0;c[k>>2]=0;z=a[719371]|0;D=a[719372]|0;E=a[719373]|0;if(((D&1)+(z&1)+(E&1)|0)>1){F=c[198610]|0;G=(F|0)!=0?F:c[p>>2]|0;a2(59840,77,1,G|0)|0;G=c[198610]|0;F=(G|0)!=0?G:c[p>>2]|0;aY(F|0)|0;H=u;I=v;break}F=(E|z)&1;G=((D|z)&1)!=0;if(((E|D)&1)!=0|(a[719374]|0)==0){J=1483}else{D=gg(719374,k)|0;if((D|0)>-1){K=58904;L=719374;M=6;N=D}else{J=1483}}do{if((J|0)==1483){if(!(F<<24>>24!=0|(a[723470]|0)==0)){D=gg(723470,k)|0;if((D|0)>-1){K=58280;L=723470;M=10;N=D;break}}if(!(G|(a[727566]|0)==0)){D=gg(727566,k)|0;if((D|0)>-1){K=57600;L=727566;M=8;N=D;break}}if((a[637400]&1)==0){H=u;I=v;break L2051}D=c[198610]|0;E=(D|0)!=0?D:c[p>>2]|0;a2(56904,43,1,E|0)|0;E=c[198610]|0;D=(E|0)!=0?E:c[p>>2]|0;aY(D|0)|0;H=u;I=v;break L2051}}while(0);if((a[637400]&1)!=0){G=c[198610]|0;F=(G|0)!=0?G:c[p>>2]|0;ec(F|0,55976,(A=i,i=i+16|0,c[A>>2]=K,c[A+8>>2]=L,A)|0)|0;i=A;F=c[198610]|0;G=(F|0)!=0?F:c[p>>2]|0;aY(G|0)|0}G=u<<2;c[l>>2]=G;F=XY(G)|0;if((F|0)==0){G=c[198610]|0;D=(G|0)!=0?G:c[p>>2]|0;a2(54768,67,1,D|0)|0;D=c[198610]|0;G=(D|0)!=0?D:c[p>>2]|0;aY(G|0)|0;c[m>>2]=v;XZ(c[k>>2]|0);H=u;I=v;break}G=c[k>>2]|0;D=fd[M&15](G,N,v,u,F,l)|0;if((D|0)==1){if((a[637400]&1)!=0){E=c[198610]|0;z=(E|0)!=0?E:c[p>>2]|0;ec(z|0,53904,(A=i,i=i+8|0,c[A>>2]=K,A)|0)|0;i=A;z=c[198610]|0;E=(z|0)!=0?z:c[p>>2]|0;aY(E|0)|0}XZ(v);c[m>>2]=F;O=c[l>>2]|0;P=F}else{F=c[198610]|0;E=(F|0)!=0?F:c[p>>2]|0;ec(E|0,53008,(A=i,i=i+16|0,c[A>>2]=K,c[A+8>>2]=D,A)|0)|0;i=A;D=c[198610]|0;E=(D|0)!=0?D:c[p>>2]|0;aY(E|0)|0;O=u;P=v}XZ(G);H=O;I=P}else{H=u;I=c[m>>2]|0}}while(0);u=(H|0)==0;if((I|0)==0|u){Q=0}else{w=H;t=I;G=-1;while(1){E=w-1|0;D=d[t]|0;F=c[15880+(((D^G)&15)<<2)>>2]^G>>>4;R=F>>>4^c[15880+((F&15^D>>>4)<<2)>>2];if((E|0)==0){break}else{w=E;t=t+1|0;G=R}}Q=~R}c[160385]=Q;G=h;X2(G|0,0,360);t=h+324|0;X5(t|0,101680,32)|0;t=h+360|0;c[t>>2]=H;c[t+4>>2]=0;w=h+64|0;if(u){S=0}else{E=H;D=I;F=0;while(1){z=64-F|0;T=E>>>0<z>>>0?E:z;z=G+F|0;X5(z|0,D|0,T)|0;z=T+(c[w>>2]|0)|0;c[w>>2]=z;if((z|0)==64){gN(h);U=c[w>>2]|0}else{U=z}if((E|0)==(T|0)){S=U;break}else{E=E-T|0;D=D+T|0;F=U}}}c[w>>2]=S+1;a[h+S|0]=-128;F=c[w>>2]|0;if(F>>>0>56){X2(G+F|0,0,64-F|0);gN(h);V=c[w>>2]|0}else{V=F}X2(G+V|0,0,56-V|0);F=c[t>>2]|0;c[h+56>>2]=dX(F>>>29|c[t+4>>2]<<3|0)|0;c[h+60>>2]=dX(F<<3|0>>>29|0)|0;gN(h);c[j>>2]=dX(c[h+324>>2]|0)|0;c[j+4>>2]=dX(c[h+328>>2]|0)|0;c[j+8>>2]=dX(c[h+332>>2]|0)|0;c[j+12>>2]=dX(c[h+336>>2]|0)|0;c[j+16>>2]=dX(c[h+340>>2]|0)|0;c[j+20>>2]=dX(c[h+344>>2]|0)|0;c[j+24>>2]=dX(c[h+348>>2]|0)|0;c[j+28>>2]=dX(c[h+352>>2]|0)|0;F=j;D=0;do{bN(794280+(D<<1)|0,3,34240,(A=i,i=i+8|0,c[A>>2]=d[F+D|0]|0,A)|0)|0;i=A;D=D+1|0;}while(D>>>0<32);if((a[637400]&1)!=0){D=c[198610]|0;F=(D|0)!=0?D:c[p>>2]|0;D=c[160385]|0;ec(F|0,60912,(A=i,i=i+16|0,c[A>>2]=D,c[A+8>>2]=794280,A)|0)|0;i=A;D=c[198610]|0;F=(D|0)!=0?D:c[p>>2]|0;aY(F|0)|0}c[x>>2]=I;B=H;C=I}c[o>>2]=B;if((B|0)==-1){F=c[198610]|0;D=(F|0)!=0?F:c[p>>2]|0;a2(68400,46,1,D|0)|0;D=c[198610]|0;F=(D|0)!=0?D:c[p>>2]|0;aY(F|0)|0;W=0;break}if((a[637400]&1)==0){X=C;Y=B;J=1519;break}F=c[198610]|0;D=(F|0)!=0?F:c[p>>2]|0;ec(D|0,66688,(A=i,i=i+8|0,c[A>>2]=B,A)|0)|0;i=A;D=c[198610]|0;F=(D|0)!=0?D:c[p>>2]|0;aY(F|0)|0;X=C;Y=B;J=1519}else{if(!y){X=0;Y=0;J=1519;break}F=c[198610]|0;D=(F|0)!=0?F:c[p>>2]|0;a2(64696,72,1,D|0)|0;D=c[198610]|0;F=(D|0)!=0?D:c[p>>2]|0;aY(F|0)|0;X=0;Y=0;J=1519}}while(0);L2111:do{if((J|0)==1519){y=q|0;c[q>>2]=c[e>>2];c[q+4>>2]=X;c[q+8>>2]=Y;c[q+12>>2]=s;L2113:do{if(f>>>0>1){B=1;L2114:while(1){Z=e+(B<<2)|0;C=c[Z>>2]|0;do{if((C|0)==0){_=0}else{if((a[731700]&1)!=0){_=C;break}I=gg(C,n+(B<<2)|0)|0;c[o+(B<<2)>>2]=I;if((I|0)==-1){break L2114}_=c[Z>>2]|0}}while(0);c[q+(B<<4)>>2]=_;c[q+(B<<4)+4>>2]=c[n+(B<<2)>>2];c[q+(B<<4)+8>>2]=c[o+(B<<2)>>2];B=B+1|0;if(B>>>0>=f>>>0){break L2113}}B=c[198610]|0;ec(((B|0)!=0?B:c[p>>2]|0)|0,63128,(A=i,i=i+8|0,c[A>>2]=c[Z>>2],A)|0)|0;i=A;B=c[198610]|0;aY(((B|0)!=0?B:c[p>>2]|0)|0)|0;W=0;break L2111}}while(0);if((b|0)==0){if(fe[c[59488]&127](y)|0){W=1;break}}else{if(fi[c[59486]&63](b,y,f)|0){W=1;break}}x=c[198610]|0;B=(x|0)!=0?x:c[p>>2]|0;a2(61736,42,1,B|0)|0;B=c[198610]|0;x=(B|0)!=0?B:c[p>>2]|0;aY(x|0)|0;W=0}}while(0);XZ(c[n>>2]|0);XZ(c[n+4>>2]|0);XZ(c[n+8>>2]|0);XZ(c[n+12>>2]|0);XZ(s);r=W;i=g;return r|0}function gn(b,d){b=b|0;d=d|0;var e=0,f=0,g=0;e=a[b+4|0]&1;f=a[d+4|0]&1;if(e<<24>>24==f<<24>>24){g=X8(c[b>>2]|0,c[d>>2]|0)|0;return g|0}else{g=(f&255)-(e&255)|0;return g|0}return 0}function go(a,b){a=a|0;b=b|0;return X8(c[a>>2]|0,c[b>>2]|0)|0}function gp(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;d=i;i=i+8|0;e=d|0;f=XY(12)|0;do{if((f|0)==0){g=0}else{do{if((c[f-4>>2]&3|0)==0){h=f+4|0;j=c[h>>2]|0;if(j>>>0<32){k=h;l=j;m=f;break}j=c[198610]|0;h=(j|0)!=0?j:c[p>>2]|0;ec(h|0,63392,(n=i,i=i+16|0,c[n>>2]=25928,c[n+8>>2]=69,n)|0)|0;i=n;h=c[198610]|0;j=(h|0)!=0?h:c[p>>2]|0;aY(j|0)|0;cd(2);return 0}else{X2(f|0,0,12);k=f+4|0;l=0;m=f}}while(0);j=f;h=c[j>>2]|0;o=h;q=X_(o,256)|0;if((q|0)==0){if((l|0)!=0){r=0;do{XZ(c[h+(r<<3)>>2]|0);r=r+1|0;}while(r>>>0<l>>>0)}XZ(o);XZ(f);g=0;break}r=q;c[j>>2]=r;h=f+8|0;c[h>>2]=32;s=dq(a|0)|0;L2151:do{if((s|0)==0){t=0;u=l;v=r}else{w=d8(s|0,b|0,e|0)|0;L2153:do{if((w|0)!=0){x=w;y=r;z=l;A=32;while(1){if(z>>>0<A>>>0){B=y;C=A}else{D=A<<1;if(z>>>0>=D>>>0){break}E=X_(y,A<<4)|0;if((E|0)==0){t=s;u=z;v=y;break L2151}F=E;c[j>>2]=F;c[h>>2]=D;B=F;C=D}D=dq(x|0)|0;if((D|0)==0){t=s;u=z;v=B;break L2151}c[B+(z<<3)>>2]=D;D=c[k>>2]|0;F=c[j>>2]|0;c[F+(D<<3)+4>>2]=0;E=D+1|0;c[k>>2]=E;D=d8(0,b|0,e|0)|0;if((D|0)==0){break L2153}else{x=D;y=F;z=E;A=C}}A=c[198610]|0;ec(((A|0)!=0?A:c[p>>2]|0)|0,63392,(n=i,i=i+16|0,c[n>>2]=25928,c[n+8>>2]=69,n)|0)|0;i=n;A=c[198610]|0;aY(((A|0)!=0?A:c[p>>2]|0)|0)|0;cd(2);return 0}}while(0);XZ(s);G=m;i=d;return G|0}}while(0);if((u|0)!=0){s=0;do{XZ(c[v+(s<<3)>>2]|0);s=s+1|0;}while(s>>>0<u>>>0)}XZ(v);XZ(f);g=t}}while(0);XZ(g);G=0;i=d;return G|0}function gq(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;f=i;i=i+8264|0;g=f|0;h=f+4096|0;j=f+4168|0;k=XY(12)|0;if((k|0)==0){l=0;i=f;return l|0}do{if((c[k-4>>2]&3|0)==0){m=k+4|0;n=c[m>>2]|0;if(n>>>0<32){o=m;q=n;r=k;break}n=c[198610]|0;m=(n|0)!=0?n:c[p>>2]|0;ec(m|0,63392,(s=i,i=i+16|0,c[s>>2]=25928,c[s+8>>2]=69,s)|0)|0;i=s;m=c[198610]|0;n=(m|0)!=0?m:c[p>>2]|0;aY(n|0)|0;cd(2);return 0}else{X2(k|0,0,12);o=k+4|0;q=0;r=k}}while(0);n=k;m=c[n>>2]|0;t=m;u=X_(t,256)|0;if((u|0)==0){if((q|0)!=0){v=0;do{XZ(c[m+(v<<3)>>2]|0);v=v+1|0;}while(v>>>0<q>>>0)}XZ(t);XZ(k);l=0;i=f;return l|0}t=u;c[n>>2]=t;u=k+8|0;c[u>>2]=32;if((d|0)==0){w=0}else{w=gp(d,93176)|0}d=bC(b|0)|0;L2192:do{if((d|0)==0){v=c[198610]|0;m=(v|0)!=0?v:c[p>>2]|0;ec(m|0,38560,(s=i,i=i+8|0,c[s>>2]=b,s)|0)|0;i=s;m=c[198610]|0;v=(m|0)!=0?m:c[p>>2]|0;aY(v|0)|0;x=q;y=t}else{v=bS(d|0)|0;L2194:do{if((v|0)!=0){m=j|0;z=(w|0)==0;A=g|0;B=w|0;C=w+4|0;D=h+8|0;E=v;F=t;G=q;H=32;L2196:while(1){I=E+4|0;J=cg(I|0,46)|0;K=(J|0)==0?798256:J+1|0;gr(m,b,I);J=a[E+1036|0]|0;do{if((J<<24>>24|0)==0|(J<<24>>24|0)==10){if((eB(m|0,h|0)|0)<0){L=0;M=1585;break}N=(c[D>>2]&61440|0)==16384;M=1584}else if((J<<24>>24|0)==4){N=1;M=1584}else{L=0;M=1585}}while(0);if((M|0)==1584){M=0;if(e|N^1){L=N;M=1585}else{O=F;P=G;Q=H}}L2203:do{if((M|0)==1585){M=0;if((cL(I|0,53952)|0)==0){O=F;P=G;Q=H;break}if((cL(I|0,44936)|0)==0){O=F;P=G;Q=H;break}L2207:do{if(!(L|z)){bN(A|0,4096,45336,(s=i,i=i+16|0,c[s>>2]=53952,c[s+8>>2]=K,s)|0)|0;i=s;J=c[C>>2]|0;R=0;while(1){if(R>>>0>=J>>>0){O=F;P=G;Q=H;break L2203}S=c[(c[B>>2]|0)+(R<<3)>>2]|0;if((X8(S|0,K|0)|0)==0){break L2207}if((X8(S|0,A|0)|0)==0){break}else{R=R+1|0}}}}while(0);R=L&1;if(G>>>0<H>>>0){T=F;U=H}else{J=H<<1;if(G>>>0>=J>>>0){M=1595;break L2196}S=X_(F,H<<4)|0;if((S|0)==0){V=F;M=1604;break L2196}W=S;c[n>>2]=W;c[u>>2]=J;T=W;U=J}J=dq(m|0)|0;if((J|0)==0){V=T;M=1604;break L2196}c[T+(G<<3)>>2]=J;J=c[o>>2]|0;W=c[n>>2]|0;c[W+(J<<3)+4>>2]=R;R=J+1|0;c[o>>2]=R;O=W;P=R;Q=U}}while(0);K=bS(d|0)|0;if((K|0)==0){break L2194}else{E=K;F=O;G=P;H=Q}}if((M|0)==1595){H=c[198610]|0;F=(H|0)!=0?H:c[p>>2]|0;ec(F|0,63392,(s=i,i=i+16|0,c[s>>2]=25928,c[s+8>>2]=69,s)|0)|0;i=s;F=c[198610]|0;H=(F|0)!=0?F:c[p>>2]|0;aY(H|0)|0;cd(2);return 0}else if((M|0)==1604){H=c[198610]|0;ec(((H|0)!=0?H:c[p>>2]|0)|0,38560,(s=i,i=i+8|0,c[s>>2]=b,s)|0)|0;i=s;H=c[198610]|0;aY(((H|0)!=0?H:c[p>>2]|0)|0)|0;eI(d|0)|0;x=G;y=V;break L2192}}}while(0);eI(d|0)|0;if((w|0)==0){l=r;i=f;return l|0}v=w+4|0;H=w|0;F=c[H>>2]|0;if((c[v>>2]|0)==0){X=F}else{E=0;m=F;while(1){XZ(c[m+(E<<3)>>2]|0);F=E+1|0;A=c[H>>2]|0;if(F>>>0<(c[v>>2]|0)>>>0){E=F;m=A}else{X=A;break}}}XZ(X);XZ(w);l=r;i=f;return l|0}}while(0);if((x|0)!=0){r=0;do{XZ(c[y+(r<<3)>>2]|0);r=r+1|0;}while(r>>>0<x>>>0)}XZ(y);XZ(k);if((w|0)==0){l=0;i=f;return l|0}k=w+4|0;y=w|0;x=c[y>>2]|0;if((c[k>>2]|0)==0){Y=x}else{r=0;X=x;while(1){XZ(c[X+(r<<3)>>2]|0);x=r+1|0;d=c[y>>2]|0;if(x>>>0<(c[k>>2]|0)>>>0){r=x;X=d}else{Y=d;break}}}XZ(Y);XZ(w);l=0;i=f;return l|0}function gr(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=i;g=4096;h=0;j=b;k=d;while(1){d=g-1|0;if((d|0)==0){l=1622;break}m=a[k]|0;a[j]=m;if(m<<24>>24==0){n=h;break}else{g=d;h=h+1|0;j=j+1|0;k=k+1|0}}do{if((l|0)==1622){a[j]=0;if((a[k]|0)==0){n=h;break}else{o=k;q=h}while(1){g=o+1|0;d=q+1|0;if((a[g]|0)==0){n=d;break}else{o=g;q=d}}}}while(0);if(n>>>0>=4096){n=c[198610]|0;q=(n|0)!=0?n:c[p>>2]|0;ec(q|0,63392,(r=i,i=i+16|0,c[r>>2]=25928,c[r+8>>2]=573,r)|0)|0;i=r;q=c[198610]|0;n=(q|0)!=0?q:c[p>>2]|0;aY(n|0)|0;cd(2)}if((a[b]|0)!=0){gy(b)}n=X1(b|0)|0;q=n>>>0>4096?0:4096-n|0;L2262:do{if((q|0)==0){s=0;t=e;l=1633}else{o=q;h=0;k=b+n|0;j=e;while(1){d=o-1|0;if((d|0)==0){break}g=a[j]|0;a[k]=g;if(g<<24>>24==0){u=h;break L2262}else{o=d;h=h+1|0;k=k+1|0;j=j+1|0}}a[k]=0;s=h;t=j;l=1633}}while(0);do{if((l|0)==1633){if((a[t]|0)==0){u=s;break}else{v=t;w=s}while(1){e=v+1|0;b=w+1|0;if((a[e]|0)==0){u=b;break}else{v=e;w=b}}}}while(0);if((u+n|0)>>>0<4096){i=f;return}else{f=c[198610]|0;n=(f|0)!=0?f:c[p>>2]|0;ec(n|0,63392,(r=i,i=i+16|0,c[r>>2]=25928,c[r+8>>2]=578,r)|0)|0;i=r;r=c[198610]|0;n=(r|0)!=0?r:c[p>>2]|0;aY(n|0)|0;cd(2)}}function gs(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;f=i;i=i+4096|0;g=f|0;h=4096;j=0;k=g;l=d;while(1){d=h-1|0;if((d|0)==0){m=1641;break}n=a[l]|0;a[k]=n;if(n<<24>>24==0){o=j;break}else{h=d;j=j+1|0;k=k+1|0;l=l+1|0}}do{if((m|0)==1641){a[k]=0;if((a[l]|0)==0){o=j;break}else{q=l;r=j}while(1){h=q+1|0;d=r+1|0;if((a[h]|0)==0){o=d;break}else{q=h;r=d}}}}while(0);if(o>>>0>=4096){o=c[198610]|0;r=(o|0)!=0?o:c[p>>2]|0;ec(r|0,63392,(s=i,i=i+16|0,c[s>>2]=25928,c[s+8>>2]=409,s)|0)|0;i=s;r=c[198610]|0;o=(r|0)!=0?r:c[p>>2]|0;aY(o|0)|0;cd(2)}o=cg(g|0,46)|0;if((o|0)==0){t=4096;u=0;v=b;w=g}else{a[o]=0;t=4096;u=0;v=b;w=g}while(1){g=t-1|0;if((g|0)==0){m=1649;break}o=a[w]|0;a[v]=o;if(o<<24>>24==0){x=u;break}else{t=g;u=u+1|0;v=v+1|0;w=w+1|0}}do{if((m|0)==1649){a[v]=0;if((a[w]|0)==0){x=u;break}else{y=w;z=u}while(1){t=y+1|0;g=z+1|0;if((a[t]|0)==0){x=g;break}else{y=t;z=g}}}}while(0);if(x>>>0>=4096){x=c[198610]|0;z=(x|0)!=0?x:c[p>>2]|0;ec(z|0,63392,(s=i,i=i+16|0,c[s>>2]=25928,c[s+8>>2]=414,s)|0)|0;i=s;z=c[198610]|0;x=(z|0)!=0?z:c[p>>2]|0;aY(x|0)|0;cd(2)}x=X1(b|0)|0;z=x>>>0>4096?0:4096-x|0;L2301:do{if((z|0)==0){A=0;B=e;m=1658}else{y=z;u=0;w=b+x|0;v=e;while(1){g=y-1|0;if((g|0)==0){break}t=a[v]|0;a[w]=t;if(t<<24>>24==0){C=u;break L2301}else{y=g;u=u+1|0;w=w+1|0;v=v+1|0}}a[w]=0;A=u;B=v;m=1658}}while(0);do{if((m|0)==1658){if((a[B]|0)==0){C=A;break}else{D=B;E=A}while(1){e=D+1|0;b=E+1|0;if((a[e]|0)==0){C=b;break}else{D=e;E=b}}}}while(0);if((C+x|0)>>>0<4096){i=f;return}else{f=c[198610]|0;x=(f|0)!=0?f:c[p>>2]|0;ec(x|0,63392,(s=i,i=i+16|0,c[s>>2]=25928,c[s+8>>2]=415,s)|0)|0;i=s;s=c[198610]|0;x=(s|0)!=0?s:c[p>>2]|0;aY(x|0)|0;cd(2)}}function gt(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;f=i;g=4096;h=0;j=b;k=d;while(1){d=g-1|0;if((d|0)==0){l=1666;break}m=a[k]|0;a[j]=m;if(m<<24>>24==0){n=h;break}else{g=d;h=h+1|0;j=j+1|0;k=k+1|0}}do{if((l|0)==1666){a[j]=0;if((a[k]|0)==0){n=h;break}else{o=k;q=h}while(1){g=o+1|0;d=q+1|0;if((a[g]|0)==0){n=d;break}else{o=g;q=d}}}}while(0);if(n>>>0>=4096){n=c[198610]|0;q=(n|0)!=0?n:c[p>>2]|0;ec(q|0,63392,(r=i,i=i+16|0,c[r>>2]=25928,c[r+8>>2]=420,r)|0)|0;i=r;q=c[198610]|0;n=(q|0)!=0?q:c[p>>2]|0;aY(n|0)|0;cd(2)}n=X1(b|0)|0;q=n>>>0>4096?0:4096-n|0;L2327:do{if((q|0)==0){s=0;t=e;l=1675}else{o=q;h=0;k=b+n|0;j=e;while(1){d=o-1|0;if((d|0)==0){break}g=a[j]|0;a[k]=g;if(g<<24>>24==0){u=h;break L2327}else{o=d;h=h+1|0;k=k+1|0;j=j+1|0}}a[k]=0;s=h;t=j;l=1675}}while(0);do{if((l|0)==1675){if((a[t]|0)==0){u=s;break}else{v=t;w=s}while(1){e=v+1|0;b=w+1|0;if((a[e]|0)==0){u=b;break}else{v=e;w=b}}}}while(0);if((u+n|0)>>>0<4096){i=f;return}else{f=c[198610]|0;n=(f|0)!=0?f:c[p>>2]|0;ec(n|0,63392,(r=i,i=i+16|0,c[r>>2]=25928,c[r+8>>2]=421,r)|0)|0;i=r;r=c[198610]|0;n=(r|0)!=0?r:c[p>>2]|0;aY(n|0)|0;cd(2)}}function gu(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;e=i;gy(b);f=cg(670218,47)|0;g=(f|0)==0?670218:f+1|0;f=X1(b|0)|0;h=f>>>0>4096?0:4096-f|0;L2342:do{if((h|0)==0){j=0;k=g;l=1685}else{m=h;n=0;o=b+f|0;q=g;while(1){r=m-1|0;if((r|0)==0){break}s=a[q]|0;a[o]=s;if(s<<24>>24==0){t=n;break L2342}else{m=r;n=n+1|0;o=o+1|0;q=q+1|0}}a[o]=0;j=n;k=q;l=1685}}while(0);do{if((l|0)==1685){if((a[k]|0)==0){t=j;break}else{u=k;v=j}while(1){g=u+1|0;h=v+1|0;if((a[g]|0)==0){t=h;break}else{u=g;v=h}}}}while(0);if((t+f|0)>>>0>=4096){f=c[198610]|0;t=(f|0)!=0?f:c[p>>2]|0;ec(t|0,63392,(w=i,i=i+16|0,c[w>>2]=25928,c[w+8>>2]=457,w)|0)|0;i=w;t=c[198610]|0;f=(t|0)!=0?t:c[p>>2]|0;aY(f|0)|0;cd(2)}f=X1(b|0)|0;t=f>>>0>4096?0:4096-f|0;L2356:do{if((t|0)==0){x=0;y=d;l=1694}else{v=t;u=0;j=b+f|0;k=d;while(1){q=v-1|0;if((q|0)==0){break}n=a[k]|0;a[j]=n;if(n<<24>>24==0){z=u;break L2356}else{v=q;u=u+1|0;j=j+1|0;k=k+1|0}}a[j]=0;x=u;y=k;l=1694}}while(0);do{if((l|0)==1694){if((a[y]|0)==0){z=x;break}else{A=y;B=x}while(1){d=A+1|0;b=B+1|0;if((a[d]|0)==0){z=b;break}else{A=d;B=b}}}}while(0);if((z+f|0)>>>0<4096){i=e;return}else{e=c[198610]|0;f=(e|0)!=0?e:c[p>>2]|0;ec(f|0,63392,(w=i,i=i+16|0,c[w>>2]=25928,c[w+8>>2]=458,w)|0)|0;i=w;w=c[198610]|0;f=(w|0)!=0?w:c[p>>2]|0;aY(f|0)|0;cd(2)}}function gv(){var b=0,d=0.0,e=0.0,f=0.0,j=0.0,k=0.0,l=0.0,m=0,n=0,o=0,q=0.0;b=i;a[731765]=0;d=+h[91466];if(d<=0.0){i=b;return}e=+h[91467];if(e<=0.0){i=b;return}f=+g[135827];j=f;if(+Q(+(1.0-d/j))>.05000000074505806){if((a[637400]&1)==0){k=d;l=f}else{m=c[198610]|0;n=(m|0)!=0?m:c[p>>2]|0;f=d;ec(n|0,58784,(o=i,i=i+16|0,h[o>>3]=j,h[o+8>>3]=f,o)|0)|0;i=o;n=c[198610]|0;m=(n|0)!=0?n:c[p>>2]|0;aY(m|0)|0;k=+h[91466];l=+g[135827]}do{if(k>l){a[731765]=1;if((a[637400]&1)==0){break}m=c[198610]|0;n=(m|0)!=0?m:c[p>>2]|0;a2(58144,57,1,n|0)|0;n=c[198610]|0;m=(n|0)!=0?n:c[p>>2]|0;aY(m|0)|0}}while(0);q=+h[91467]}else{q=e*(j/d)}d=q;g[137896]=d;if((a[637400]&1)!=0){m=c[198610]|0;n=(m|0)!=0?m:c[p>>2]|0;q=d;ec(n|0,57528,(o=i,i=i+8|0,h[o>>3]=q,o)|0)|0;i=o;o=c[198610]|0;n=(o|0)!=0?o:c[p>>2]|0;aY(n|0)|0}n=c[199308]|0;if((n|0)==0){i=b;return}if((a[731765]&1)!=0){fc[c[(c[199305]|0)+8>>2]&127](n,1);i=b;return}o=(a[797248]&1)!=0;if((a[637402]&1)!=0){fc[c[(c[199305]|0)+8>>2]&127](n,(a[535088]&1)==0|o)}n=c[199307]|0;if((a[637401]&1)!=0&(n|0)!=0){fc[c[(c[199304]|0)+16>>2]&127](n,(a[555688]&1)==0|o)}c[184126]=o?c[184127]|0:c[184128]|0;i=b;return}function gw(){var a=0,b=0,d=0;a=c[199354]|0;if((a|0)==0){b=0;return b|0}d=c[a+4>>2]|0;if((d|0)==0){b=0;return b|0}b=fe[d&127](c[199308]|0)|0;return b|0}function gx(a){a=a|0;var b=0,d=0,e=0;b=c[199354]|0;if((b|0)==0){d=0;return d|0}e=c[b+8>>2]|0;if((e|0)==0){d=0;return d|0}d=ft[e&63](c[199308]|0,a)|0;return d|0}function gy(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;d=i;i=i+8|0;e=d|0;f=cg(b|0,47)|0;g=X1(b|0)|0;if((f|0)==0){h=g>>>0>4096?0:4096-g|0;L2424:do{if((h|0)==0){j=0;k=36576;l=1754}else{m=b+g|0;do{if((h|0)==1){n=36576;o=m;q=0}else{r=b+(g+1)|0;a[m]=47;if((h|0)==2){n=36577;o=r;q=1;break}a[r]=0;s=1;break L2424}}while(0);a[o]=0;j=q;k=n;l=1754}}while(0);do{if((l|0)==1754){if((a[k]|0)==0){s=j;break}else{t=k;u=j}while(1){n=t+1|0;q=u+1|0;if((a[n]|0)==0){s=q;break}else{t=n;u=q}}}}while(0);if((s+g|0)>>>0<4096){i=d;return}else{s=c[198610]|0;u=(s|0)!=0?s:c[p>>2]|0;ec(u|0,63392,(v=i,i=i+16|0,c[v>>2]=25928,c[v+8>>2]=450,v)|0)|0;i=v;u=c[198610]|0;s=(u|0)!=0?u:c[p>>2]|0;aY(s|0)|0;cd(2)}}if((f|0)==(b+(g-1)|0)){i=d;return}g=e|0;s=a[f]|0;a[g]=s;a[e+1|0]=0;e=X1(b|0)|0;f=e>>>0>4096?0:4096-e|0;L2442:do{if((f|0)==0){w=0;x=g;y=s;l=1746}else{u=f;t=0;j=b+e|0;k=g;while(1){q=u-1|0;if((q|0)==0){break}n=a[k]|0;a[j]=n;if(n<<24>>24==0){z=t;break L2442}else{u=q;t=t+1|0;j=j+1|0;k=k+1|0}}a[j]=0;w=t;x=k;y=a[k]|0;l=1746}}while(0);do{if((l|0)==1746){if(y<<24>>24==0){z=w;break}else{A=x;B=w}while(1){g=A+1|0;b=B+1|0;if((a[g]|0)==0){z=b;break}else{A=g;B=b}}}}while(0);if((z+e|0)>>>0<4096){i=d;return}else{d=c[198610]|0;e=(d|0)!=0?d:c[p>>2]|0;ec(e|0,63392,(v=i,i=i+16|0,c[v>>2]=25928,c[v+8>>2]=447,v)|0)|0;i=v;v=c[198610]|0;e=(v|0)!=0?v:c[p>>2]|0;aY(e|0)|0;cd(2)}}function gz(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;f=i;g=cg(d|0,47)|0;h=(g|0)==0?d:g+1|0;L2457:do{if((e|0)==0){j=0;k=h;l=1767}else{g=e;d=0;m=b;n=h;while(1){o=g-1|0;if((o|0)==0){break}q=a[n]|0;a[m]=q;if(q<<24>>24==0){r=d;break L2457}else{g=o;d=d+1|0;m=m+1|0;n=n+1|0}}a[m]=0;j=d;k=n;l=1767}}while(0);do{if((l|0)==1767){if((a[k]|0)==0){r=j;break}else{s=k;t=j}while(1){h=s+1|0;b=t+1|0;if((a[h]|0)==0){r=b;break}else{s=h;t=b}}}}while(0);if(r>>>0<e>>>0){i=f;return}else{f=c[198610]|0;e=(f|0)!=0?f:c[p>>2]|0;ec(e|0,63392,(e=i,i=i+16|0,c[e>>2]=25928,c[e+8>>2]=470,e)|0)|0;i=e;e=c[198610]|0;f=(e|0)!=0?e:c[p>>2]|0;aY(f|0)|0;cd(2)}}function gA(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;e=i;f=4096;g=0;h=b;j=d;while(1){d=f-1|0;if((d|0)==0){k=1775;break}l=a[j]|0;a[h]=l;if(l<<24>>24==0){m=g;break}else{f=d;g=g+1|0;h=h+1|0;j=j+1|0}}do{if((k|0)==1775){a[h]=0;if((a[j]|0)==0){m=g;break}else{n=j;o=g}while(1){f=n+1|0;d=o+1|0;if((a[f]|0)==0){m=d;break}else{n=f;o=d}}}}while(0);if(m>>>0>=4096){m=c[198610]|0;o=(m|0)!=0?m:c[p>>2]|0;ec(o|0,63392,(q=i,i=i+16|0,c[q>>2]=25928,c[q+8>>2]=475,q)|0)|0;i=q;o=c[198610]|0;m=(o|0)!=0?o:c[p>>2]|0;aY(m|0)|0;cd(2)}if((X1(b|0)|0)>>>0<2){i=e;return}m=cg(b|0,47)|0;if((m|0)==0){bN(b|0,3,99560,(q=i,i=i+8|0,c[q>>2]=36576,q)|0)|0;i=q;i=e;return}else{a[m+1|0]=0;i=e;return}}function gB(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;f=i;if((a[e]|0)==47){g=4096;h=0;j=b;k=e;while(1){l=g-1|0;if((l|0)==0){m=1790;break}n=a[k]|0;a[j]=n;if(n<<24>>24==0){o=h;break}else{g=l;h=h+1|0;j=j+1|0;k=k+1|0}}do{if((m|0)==1790){a[j]=0;if((a[k]|0)==0){o=h;break}else{q=k;r=h}while(1){g=q+1|0;l=r+1|0;if((a[g]|0)==0){o=l;break}else{q=g;r=l}}}}while(0);if(o>>>0<4096){i=f;return}else{o=c[198610]|0;r=(o|0)!=0?o:c[p>>2]|0;ec(r|0,63392,(s=i,i=i+16|0,c[s>>2]=25928,c[s+8>>2]=562,s)|0)|0;i=s;r=c[198610]|0;o=(r|0)!=0?r:c[p>>2]|0;aY(o|0)|0;cd(2)}}else{t=4096;u=0;v=b;w=d}while(1){d=t-1|0;if((d|0)==0){m=1796;break}o=a[w]|0;a[v]=o;if(o<<24>>24==0){x=u;break}else{t=d;u=u+1|0;v=v+1|0;w=w+1|0}}do{if((m|0)==1796){a[v]=0;if((a[w]|0)==0){x=u;break}else{y=w;z=u}while(1){t=y+1|0;d=z+1|0;if((a[t]|0)==0){x=d;break}else{y=t;z=d}}}}while(0);if(x>>>0>=4096){x=c[198610]|0;z=(x|0)!=0?x:c[p>>2]|0;ec(z|0,63392,(s=i,i=i+16|0,c[s>>2]=25928,c[s+8>>2]=565,s)|0)|0;i=s;z=c[198610]|0;x=(z|0)!=0?z:c[p>>2]|0;aY(x|0)|0;cd(2)}do{if((X1(b|0)|0)>>>0>=2){x=cg(b|0,47)|0;if((x|0)==0){bN(b|0,3,99560,(s=i,i=i+8|0,c[s>>2]=36576,s)|0)|0;i=s;break}else{a[x+1|0]=0;break}}}while(0);x=X1(b|0)|0;z=x>>>0>4096?0:4096-x|0;L2520:do{if((z|0)==0){A=0;B=e;m=1809}else{y=z;u=0;w=b+x|0;v=e;while(1){d=y-1|0;if((d|0)==0){break}t=a[v]|0;a[w]=t;if(t<<24>>24==0){C=u;break L2520}else{y=d;u=u+1|0;w=w+1|0;v=v+1|0}}a[w]=0;A=u;B=v;m=1809}}while(0);do{if((m|0)==1809){if((a[B]|0)==0){C=A;break}else{D=B;E=A}while(1){e=D+1|0;b=E+1|0;if((a[e]|0)==0){C=b;break}else{D=e;E=b}}}}while(0);if((C+x|0)>>>0<4096){i=f;return}else{f=c[198610]|0;x=(f|0)!=0?f:c[p>>2]|0;ec(x|0,63392,(s=i,i=i+16|0,c[s>>2]=25928,c[s+8>>2]=567,s)|0)|0;i=s;s=c[198610]|0;x=(s|0)!=0?s:c[p>>2]|0;aY(x|0)|0;cd(2)}}function gC(){var b=0,d=0,e=0,f=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0.0,r=0.0,s=0,t=0.0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0;b=i;i=i+24|0;d=b|0;a[797243]=(c[199308]|0)==0|0;a[797244]=(c[199307]|0)==0|0;a[797245]=(c[199309]|0)==0|0;gv();c[198551]=0;e=d;L2535:do{if((a[543313]|0)!=0){f=gq(543313,62984,0)|0;c[198568]=f;do{if((f|0)!=0){j=f+4|0;if((c[j>>2]|0)==0){XZ(c[f>>2]|0);XZ(f);break}c[198569]=0;dh(c[f>>2]|0,c[j>>2]|0,8,26);j=c[198568]|0;if((c[j+4>>2]|0)==0){break L2535}else{k=0;l=j}while(1){if((a[637400]&1)==0){m=l}else{j=c[198610]|0;n=(j|0)!=0?j:c[p>>2]|0;j=c[(c[l>>2]|0)+(k<<3)>>2]|0;ec(n|0,61672,(o=i,i=i+8|0,c[o>>2]=j,o)|0)|0;i=o;j=c[198610]|0;n=(j|0)!=0?j:c[p>>2]|0;aY(n|0)|0;m=c[198568]|0}n=k+1|0;if(n>>>0<(c[m+4>>2]|0)>>>0){k=n;l=m}else{break L2535}}}}while(0);c[198568]=0;c[198569]=0}}while(0);m=c[182928]|0;l=c[182929]|0;k=(m>>>0>l>>>0?m:l)-1|0;l=k>>>1|k;k=l>>>2|l;l=k>>>4|k;k=l>>>8|l;l=((k>>>16|k)+1|0)>>>8;k=(a[785760]&1)==0?l>>>0>1?l:1:c[196445]|0;q=+g[133775];g[182936]=q;do{if(q<0.0){r=+g[182930];if(r>0.0){if((a[535104]&1)==0){s=1828}else{t=r}}else{s=1828}if((s|0)==1828){t=+((c[182926]|0)>>>0>>>0)/+((c[182927]|0)>>>0>>>0)}g[182936]=t;if((a[637400]&1)==0){break}l=c[198610]|0;m=(l|0)!=0?l:c[p>>2]|0;r=t;ec(m|0,21792,(o=i,i=i+8|0,h[o>>3]=r,o)|0)|0;i=o;m=c[198610]|0;l=(m|0)!=0?m:c[p>>2]|0;aY(l|0)|0}}while(0);do{if((a[535072]&1)==0){if((a[535097]&1)==0){s=~~+bH(+(+((c[182926]|0)>>>0>>>0)*+g[133766]));u=s;v=~~+bH(+(+((c[182927]|0)>>>0>>>0)*+g[133767]));break}else{t=+((c[182927]|0)>>>0>>>0);q=+(~~+bH(+(t*+g[182936]))>>>0>>>0);s=~~+bH(+(+g[133766]*q));u=s;v=~~+bH(+(t*+g[133767]));break}}else{u=c[133770]|0;v=c[133771]|0}}while(0);s=(a[637400]&1)==0;do{if((u|0)==0|(v|0)==0){if(s){break}l=c[198610]|0;m=(l|0)!=0?l:c[p>>2]|0;a2(94920,30,1,m|0)|0;m=c[198610]|0;l=(m|0)!=0?m:c[p>>2]|0;aY(l|0)|0}else{if(s){break}l=c[198610]|0;m=(l|0)!=0?l:c[p>>2]|0;ec(m|0,99432,(o=i,i=i+16|0,c[o>>2]=u,c[o+8>>2]=v,o)|0)|0;i=o;m=c[198610]|0;l=(m|0)!=0?m:c[p>>2]|0;aY(l|0)|0}}while(0);c[199315]=0;c[199313]=0;c[199314]=0;s=k<<8;XZ(c[199332]|0);XZ(c[199335]|0);XZ(c[199336]|0);XZ(c[199339]|0);XZ(c[199342]|0);XZ(c[199340]|0);XZ(c[199346]|0);X2(797264,0,128);XZ(c[199348]|0);c[199348]=0;if((c[182940]|0)==0){l=c[198610]|0;m=(l|0)!=0?l:c[p>>2]|0;a2(64488,120,1,m|0)|0;m=c[198610]|0;l=(m|0)!=0?m:c[p>>2]|0;aY(l|0)|0;c[199324]=1;c[199322]=2;c[199323]=3;if(!(hJ(797264)|0)){l=c[198610]|0;m=(l|0)!=0?l:c[p>>2]|0;a2(90832,53,1,m|0)|0;m=c[198610]|0;l=(m|0)!=0?m:c[p>>2]|0;aY(l|0)|0;gG(87672)}l=ab(s,s)|0;s=l<<1;if(l>>>0>65535){w=(l&2147418112|0)==(l|0)?s:-1}else{w=s}s=XY(w)|0;do{if((s|0)!=0){if((c[s-4>>2]&3|0)==0){break}X2(s|0,0,w|0)}}while(0);c[199348]=s}c[e>>2]=c[2394];c[e+4>>2]=c[2395];c[e+8>>2]=c[2396];c[e+12>>2]=c[2397];c[e+16>>2]=c[2398];c[d>>2]=u;c[d+4>>2]=v;a[d+8|0]=a[535072]&1;if((a[535088]&1)==0){x=0}else{x=a[731765]&1^1}a[d+9|0]=x;a[d+10|0]=a[535097]&1;a[d+11|0]=a[535096]&1;c[d+12>>2]=k;if((a[785760]&1)==0){y=(c[182940]|0)==1|0}else{y=1}a[d+16|0]=y;y=c[199306]|0;k=fi[c[c[199305]>>2]&63](d,797224,797236)|0;c[199308]=k;if((k|0)==0){d=c[198610]|0;x=(d|0)!=0?d:c[p>>2]|0;a2(84400,62,1,x|0)|0;x=c[198610]|0;d=(x|0)!=0?x:c[p>>2]|0;aY(d|0)|0;gG(87672)}c[199354]=0;d=c[199305]|0;x=c[d+56>>2]|0;if((x|0)==0){z=d}else{fc[x&127](k,797416);z=c[199305]|0}k=c[z+40>>2]|0;z=c[182937]|0;if((k|0)!=0&(z|0)!=0){fc[k&127](c[199308]|0,z)}z=c[199354]|0;do{if((z|0)!=0){k=c[z+12>>2]|0;x=c[133777]|0;if(!((k|0)!=0&(x|0)!=4)){break}fc[k&127](c[199308]|0,x)}}while(0);do{if((c[199306]|0)==0){if((a[637400]&1)!=0){z=c[198610]|0;x=(z|0)!=0?z:c[p>>2]|0;a2(80920,101,1,x|0)|0;x=c[198610]|0;z=(x|0)!=0?x:c[p>>2]|0;aY(z|0)|0}c[199306]=y;if((y|0)==0){z=c[198610]|0;x=(z|0)!=0?z:c[p>>2]|0;a2(74376,59,1,x|0)|0;x=c[198610]|0;z=(x|0)!=0?x:c[p>>2]|0;aY(z|0)|0;gG(87672)}z=fw[c[y>>2]&31]()|0;c[199309]=z;if((z|0)!=0){break}z=c[198610]|0;x=(z|0)!=0?z:c[p>>2]|0;a2(77600,59,1,x|0)|0;x=c[198610]|0;z=(x|0)!=0?x:c[p>>2]|0;aY(z|0)|0;gG(87672)}}while(0);y=c[199350]|0;if((y|0)!=0){z=y+24|0;x=y+12|0;k=c[x>>2]|0;if((c[z>>2]|0)==0){A=k}else{d=0;v=k;while(1){XZ(c[v+(d*136|0)>>2]|0);XZ(c[v+(d*136|0)+8>>2]|0);k=d+1|0;u=c[x>>2]|0;if(k>>>0<(c[z>>2]|0)>>>0){d=k;v=u}else{A=u;break}}}XZ(A);A=c[y+4>>2]|0;if((A|0)!=0){fc[c[A>>2]&127](c[y>>2]|0,0)}XZ(y);c[199350]=0}do{if((a[596368]|0)!=0){y=hI()|0;c[199350]=y;if((y|0)!=0){break}y=c[198610]|0;A=(y|0)!=0?y:c[p>>2]|0;a2(66256,45,1,A|0)|0;A=c[198610]|0;y=(A|0)!=0?A:c[p>>2]|0;aY(y|0)|0}}while(0);y=785752;c[y>>2]=0;c[y+4>>2]=0;y=c[184104]|0;if((a[797242]&1)==0&(y|0)!=0){fz[y&8191]()}a[797242]=0;do{if((c[199307]|0)==0){y=~~(+g[158314]*65536.0);A=XY(y<<1)|0;c[184134]=A;if((A|0)==0){A=c[198610]|0;v=(A|0)!=0?A:c[p>>2]|0;ec(v|0,63392,(o=i,i=i+16|0,c[o>>2]=44856,c[o+8>>2]=497,o)|0)|0;i=o;v=c[198610]|0;A=(v|0)!=0?v:c[p>>2]|0;aY(A|0)|0;cd(2)}c[184128]=512;c[184127]=2048;c[184126]=512;A=XY(8192)|0;c[184135]=A;if((A|0)==0){A=c[198610]|0;v=(A|0)!=0?A:c[p>>2]|0;ec(v|0,63392,(o=i,i=i+16|0,c[o>>2]=44856,c[o+8>>2]=504,o)|0)|0;i=o;v=c[198610]|0;A=(v|0)!=0?v:c[p>>2]|0;aY(A|0)|0;cd(2)}c[184137]=4096;if((a[551576]&1)==0){a[637401]=0;break}A=fi[c[c[199304]>>2]&63]((a[551588]|0)!=0?551588:0,c[137895]|0,c[138921]|0)|0;c[199307]=A;do{if((A|0)==0){v=c[198610]|0;d=(v|0)!=0?v:c[p>>2]|0;a2(38400,85,1,d|0)|0;d=c[198610]|0;v=(d|0)!=0?d:c[p>>2]|0;aY(v|0)|0;a[637401]=0}else{if((a[637401]&1)==0){break}v=c[(c[199304]|0)+24>>2]|0;if((v|0)==0){break}if(!(fe[v&127](A)|0)){break}a[736528]=1}}while(0);do{if((a[555688]&1)==0){if((a[637401]&1)==0){break}fc[c[(c[199304]|0)+16>>2]&127](c[199307]|0,1);c[184126]=c[184127]}}while(0);t=+((c[137895]|0)>>>0>>>0)/+g[137896];h[92065]=t;h[92071]=t;A=a[559796]|0;v=c[184122]|0;do{if((v|0)!=0){d=c[184123]|0;if((d|0)==0){break}fb[c[d+8>>2]&127](v)}}while(0);c[184123]=1760;v=ii(t)|0;c[184122]=v;if((v|0)==0){c[184123]=0;v=c[198610]|0;d=(v|0)!=0?v:c[p>>2]|0;v=A<<24>>24!=0?559796:29896;ec(d|0,34344,(o=i,i=i+8|0,c[o>>2]=v,o)|0)|0;i=o;v=c[198610]|0;d=(v|0)!=0?v:c[p>>2]|0;aY(d|0)|0;a[637401]=0}d=XY(16384)|0;c[184124]=d;if((d|0)==0){d=c[198610]|0;v=(d|0)!=0?d:c[p>>2]|0;ec(v|0,63392,(o=i,i=i+16|0,c[o>>2]=44856,c[o+8>>2]=561,o)|0)|0;i=o;v=c[198610]|0;d=(v|0)!=0?v:c[p>>2]|0;aY(d|0)|0;cd(2)}c[184125]=0;if(+((c[137895]|0)>>>0>>>0)>=+g[137896]*16.0){d=c[198610]|0;v=(d|0)!=0?d:c[p>>2]|0;ec(v|0,63392,(o=i,i=i+16|0,c[o>>2]=44856,c[o+8>>2]=565,o)|0)|0;i=o;v=c[198610]|0;d=(v|0)!=0?v:c[p>>2]|0;aY(d|0)|0;cd(2)}d=XY(y<<2)|0;c[184133]=d;if((d|0)==0){d=c[198610]|0;v=(d|0)!=0?d:c[p>>2]|0;ec(v|0,63392,(o=i,i=i+16|0,c[o>>2]=44856,c[o+8>>2]=566,o)|0)|0;i=o;v=c[198610]|0;d=(v|0)!=0?v:c[p>>2]|0;aY(d|0)|0;cd(2)}a[736564]=0;L2668:do{if((c[184095]|0)==0){if((a[637401]&1)==0){break}if((a[559785]&1)==0){break}d=c[199304]|0;v=c[d+36>>2]|0;do{if((v|0)!=0){if((c[d+32>>2]|0)==0){break}c[184144]=fe[v&127](c[199307]|0)|0;a[736564]=1;break L2668}}while(0);v=c[198610]|0;d=(v|0)!=0?v:c[p>>2]|0;a2(25728,97,1,d|0)|0;d=c[198610]|0;v=(d|0)!=0?d:c[p>>2]|0;aY(v|0)|0}}while(0);t=+g[139948];g[184145]=t;g[184146]=+S(10.0,+(t/20.0));y=769360;c[y>>2]=0;c[y+4>>2]=0;if((a[637401]&1)==0){break}if(!((a[736529]&1)==0&(c[184095]|0)!=0)){break}y=c[(c[199304]|0)+12>>2]|0;A=c[199307]|0;fe[y&127](A)|0}}while(0);if((a[797248]&1)==0){B=736472;C=0;D=0;E=B|0;c[E>>2]=C;F=B+4|0;c[F>>2]=D;i=b;return}o=c[199308]|0;if((a[637402]&1)!=0&(o|0)!=0){fc[c[(c[199305]|0)+8>>2]&127](o,1)}o=c[199307]|0;if((a[637401]&1)!=0&(o|0)!=0){fc[c[(c[199304]|0)+16>>2]&127](o,1)}c[184126]=c[184127];B=736472;C=0;D=0;E=B|0;c[E>>2]=C;F=B+4|0;c[F>>2]=D;i=b;return}function gD(){var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0.0,n=0.0,o=0.0,q=0,r=0,s=0,t=0,u=0.0,v=0;b=i;d=c[199307]|0;e=c[199304]|0;if((d|0)!=0&(e|0)!=0){fb[c[e+20>>2]&127](d)}XZ(c[184134]|0);c[184134]=0;c[184125]=0;XZ(c[184135]|0);c[184135]=0;if((a[551576]&1)==0){a[637401]=0;i=b;return}d=c[184123]|0;e=c[184122]|0;if((d|0)!=0&(e|0)!=0){fb[c[d+8>>2]&127](e)}c[184123]=0;c[184122]=0;XZ(c[184124]|0);c[184124]=0;XZ(c[184133]|0);c[184133]=0;e=769360;d=c[e>>2]|0;f=c[e+4>>2]|0;e=0;g=f>>>0<e>>>0|f>>>0==e>>>0&d>>>0<8192>>>0?d:8192;if(g>>>0<3){i=b;return}else{j=1;k=0;l=0}do{l=Ye(c[736592+(j<<2)>>2]|0,0,l,k)|0;k=F;j=j+1|0;}while(j>>>0<g>>>0);j=g-1|0;d=Yp(l,k,j,0)|0;k=d;d=1;l=0;e=0;do{f=k-(c[736592+(d<<2)>>2]|0)|0;e=Ye(ab(f,f)|0,0,e,l)|0;l=F;d=d+1|0;}while(d>>>0<g>>>0);m=+R(+((+(e>>>0)+ +(l>>>0)*4294967296.0)/+((g-2|0)>>>0>>>0)));l=c[184144]|0;n=+(l>>>0>>>0);o=+(k|0)/n;k=(l*3|0)>>>2;e=l>>>2;l=0;d=0;f=1;while(1){q=c[736592+(f<<2)>>2]|0;if(q>>>0<k>>>0){r=(q>>>0<=e>>>0)+d|0;s=l}else{r=d;s=l+1|0}q=f+1|0;if(q>>>0<g>>>0){l=s;d=r;f=q}else{break}}f=a[637400]|0;if((f&1)==0){t=f}else{f=c[198610]|0;d=(f|0)!=0?f:c[p>>2]|0;u=(1.0-o)*100.0;o=+(~~m>>>0>>>0)/n*100.0;ec(d|0,60712,(v=i,i=i+16|0,h[v>>3]=u,h[v+8>>3]=o,v)|0)|0;i=v;d=c[198610]|0;f=(d|0)!=0?d:c[p>>2]|0;aY(f|0)|0;t=a[637400]|0}if((t&1)==0){i=b;return}t=c[198610]|0;o=+(j>>>0>>>0);ec(((t|0)!=0?t:c[p>>2]|0)|0,59664,(v=i,i=i+16|0,h[v>>3]=+(s>>>0>>>0)*100.0/o,h[v+8>>3]=+(r>>>0>>>0)*100.0/o,v)|0)|0;i=v;v=c[198610]|0;aY(((v|0)!=0?v:c[p>>2]|0)|0)|0;i=b;return}function gE(){var b=0,d=0,e=0,f=0,g=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0.0,v=0.0;b=i;d=c[199350]|0;if((d|0)!=0){e=d+24|0;f=d+12|0;g=c[f>>2]|0;if((c[e>>2]|0)==0){j=g}else{k=0;l=g;while(1){XZ(c[l+(k*136|0)>>2]|0);XZ(c[l+(k*136|0)+8>>2]|0);g=k+1|0;m=c[f>>2]|0;if(g>>>0<(c[e>>2]|0)>>>0){k=g;l=m}else{j=m;break}}}XZ(j);j=c[d+4>>2]|0;if((j|0)!=0){fc[c[j>>2]&127](c[d>>2]|0,0)}XZ(d);c[199350]=0;d=797408;c[d>>2]=0;c[d+4>>2]=0}d=c[199309]|0;j=c[199308]|0;l=c[199306]|0;if((d|0)!=(j|0)&(l|0)!=0){fb[c[l+16>>2]&127](d);n=c[199308]|0}else{n=j}j=c[199305]|0;if((n|0)!=0&(j|0)!=0){fb[c[j+24>>2]&127](n)}XZ(c[199332]|0);XZ(c[199335]|0);XZ(c[199336]|0);XZ(c[199339]|0);XZ(c[199342]|0);XZ(c[199340]|0);XZ(c[199346]|0);X2(797264,0,128);XZ(c[199348]|0);c[199348]=0;n=c[198568]|0;if((n|0)!=0){j=n+4|0;d=n|0;l=c[d>>2]|0;if((c[j>>2]|0)==0){o=l}else{k=0;e=l;while(1){XZ(c[e+(k<<3)>>2]|0);l=k+1|0;f=c[d>>2]|0;if(l>>>0<(c[j>>2]|0)>>>0){k=l;e=f}else{o=f;break}}}XZ(o);XZ(n)}c[198568]=0;c[198569]=0;if((a[543312]&1)!=0){if((a[637400]&1)==0){i=b;return}n=c[198610]|0;o=(n|0)!=0?n:c[p>>2]|0;a2(71184,66,1,o|0)|0;o=c[198610]|0;n=(o|0)!=0?o:c[p>>2]|0;aY(n|0)|0;i=b;return}n=785752;o=c[n+4>>2]|0;e=0;if(o>>>0<e>>>0|o>>>0==e>>>0&(c[n>>2]|0)>>>0<4096>>>0){if((a[637400]&1)==0){i=b;return}n=c[198610]|0;e=(n|0)!=0?n:c[p>>2]|0;ec(e|0,69488,(q=i,i=i+8|0,c[q>>2]=4096,q)|0)|0;i=q;e=c[198610]|0;n=(e|0)!=0?e:c[p>>2]|0;aY(n|0)|0;i=b;return}else{r=0;s=0;t=0}do{n=769368+(r<<3)|0;t=Ye(c[n>>2]|0,c[n+4>>2]|0,t,s)|0;s=F;r=r+1|0;}while(r>>>0<2048);r=Ym(t,s,2048,0)|0;s=F;t=0;n=0;e=0;do{o=769368+(e<<3)|0;k=Yf(c[o>>2]|0,c[o+4>>2]|0,r,s)|0;o=F;j=Yo(k,o,k,o)|0;n=Ye(j,F,n,t)|0;t=F;e=e+1|0;}while(e>>>0<2048);u=+(r>>>0)+ +(s|0)*4294967296.0;if((a[637400]&1)==0){i=b;return}v=+R(+((+(n>>>0)+ +(t|0)*4294967296.0)/2047.0))/u;t=c[198610]|0;ec(((t|0)!=0?t:c[p>>2]|0)|0,68224,(q=i,i=i+24|0,h[q>>3]=1.0e6/u,h[q+8>>3]=v*100.0,c[q+16>>2]=2048,q)|0)|0;i=q;q=c[198610]|0;aY(((q|0)!=0?q:c[p>>2]|0)|0)|0;i=b;return}function gF(a){a=a|0;var b=0,d=0;if((a|0)==0){return}b=c[a+4>>2]|0;if((b|0)!=0){d=b;while(1){XZ(c[d+4>>2]|0);XZ(c[d+8>>2]|0);b=c[d+12>>2]|0;XZ(d|0);if((b|0)==0){break}else{d=b}}}d=c[a+16>>2]|0;if((d|0)!=0){b=d;while(1){XZ(c[b>>2]|0);d=c[b+4>>2]|0;XZ(b);if((d|0)==0){break}else{b=d}}}XZ(c[a>>2]|0);XZ(a);return}function gG(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0;if((a[794445]&1)==0){d=c[198610]|0;e=(d|0)!=0?d:c[p>>2]|0;ec(e|0,63392,(e=i,i=i+16|0,c[e>>2]=83144,c[e+8>>2]=827,e)|0)|0;i=e;e=c[198610]|0;d=(e|0)!=0?e:c[p>>2]|0;aY(d|0)|0;cd(2)}else{f=1024;g=794447;h=b}while(1){b=f-1|0;if((b|0)==0){break}d=a[h]|0;a[g]=d;if(d<<24>>24==0){j=2001;break}else{f=b;g=g+1|0;h=h+1|0}}if((j|0)==2001){eC(795472,1)}a[g]=0;if((a[h]|0)==0){eC(795472,1)}else{k=h}do{k=k+1|0;}while((a[k]|0)!=0);eC(795472,1)}function gH(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;e=i;i=i+4112|0;f=e|0;g=e+8|0;h=e+4104|0;j=XY(20)|0;if((j|0)==0){k=0;i=e;return k|0}if((c[j-4>>2]&3|0)!=0){X2(j|0,0,20)}l=j;if((b|0)==0){k=l;i=e;return k|0}m=dq(b|0)|0;n=j;c[n>>2]=m;if((m|0)==0){XZ(j);k=0;i=e;return k|0}o=j+12|0;c[o>>2]=d;d=c5(b|0,78048)|0;if((d|0)==0){XZ(m);XZ(j);k=0;i=e;return k|0}if((eh(d|0)|0)==0){m=j+8|0;b=g|0;q=j+16|0;r=j+4|0;do{j=XY(16)|0;do{if((j|0)!=0){if((c[j-4>>2]&3|0)==0){break}X2(j|0,0,16)}}while(0);s=j;t=XY(9)|0;u=bP(d|0)|0;v=0;w=8;y=t;while(1){if((u|0)==(-1|0)|(u|0)==10){break}if((v|0)==(w|0)){t=w<<1;z=t;A=X_(y,t|1)|0}else{z=w;A=y}a[A+v|0]=u&255;u=bP(d|0)|0;v=v+1|0;w=z;y=A}a[y+v|0]=0;if((y|0)!=0){w=b1(y|0,35)|0;if((w|0)!=0){a[w]=0}u=c[o>>2]|0;do{if((w|0)==(y|0)){if(u>>>0>=16){B=2071;break}if((bJ(y+1|0,69440,8)|0)!=0){C=y;B=2072;break}t=y+9|0;while(1){D=t+1|0;if((bc(a[t]|0)|0)==0){break}else{t=D}}E=a[t]|0;if((E<<24>>24|0)==0){break}else if((E<<24>>24|0)==34){E=d8(D|0,66328,f|0)|0;if((E|0)==0){break}F=dq(E|0)|0}else{E=d8(t|0,64368,f|0)|0;if((E|0)==0){break}F=dq(E|0)|0}if((F|0)==0){break}E=c[q>>2]|0;G=XY(8)|0;do{if((G|0)!=0){if((c[G-4>>2]&3|0)==0){break}H=G;I=H|0;x=0;a[I]=x&255;x=x>>8;a[I+1|0]=x&255;x=x>>8;a[I+2|0]=x&255;x=x>>8;a[I+3|0]=x&255;I=H+4|0;x=0;a[I]=x&255;x=x>>8;a[I+1|0]=x&255;x=x>>8;a[I+2|0]=x&255;x=x>>8;a[I+3|0]=x&255}}while(0);t=G;c[G>>2]=dq(F|0)|0;if((E|0)==0){c[q>>2]=t}else{I=E;do{J=I+4|0;I=c[J>>2]|0;}while((I|0)!=0);c[J>>2]=t}L2859:do{if((a[F]|0)==126){I=dE(87160)|0;E=4096;G=b;H=(I|0)!=0?I:798256;while(1){I=E-1|0;if((I|0)==0){B=2045;break}K=a[H]|0;a[G]=K;if(K<<24>>24==0){break}else{E=I;G=G+1|0;H=H+1|0}}do{if((B|0)==2045){B=0;a[G]=0;if((a[H]|0)==0){break}else{L=H}do{L=L+1|0;}while((a[L]|0)!=0)}}while(0);H=F+1|0;G=X1(b|0)|0;E=G>>>0>4096?0:4096-G|0;if((E|0)==0){M=H}else{I=E;E=g+G|0;G=H;while(1){H=I-1|0;if((H|0)==0){break}K=a[G]|0;a[E]=K;if(K<<24>>24==0){break L2859}else{I=H;E=E+1|0;G=G+1|0}}a[E]=0;M=G}if((a[M]|0)==0){break}else{N=M}do{N=N+1|0;}while((a[N]|0)!=0)}else{gB(b,c[n>>2]|0,F)}}while(0);t=gH(b,u+1|0)|0;if((t|0)==0){XZ(F);break}G=c[r>>2]|0;if((G|0)==0){E=t+4|0;I=c[E>>2]|0;if((I|0)==0){O=0}else{H=I;do{a[H|0]=1;H=c[H+12>>2]|0;}while((H|0)!=0);O=c[E>>2]|0}c[r>>2]=O;P=O}else{H=G;do{Q=H+12|0;H=c[Q>>2]|0;}while((H|0)!=0);H=t+4|0;E=c[H>>2]|0;if((E|0)==0){R=0}else{I=E;do{a[I|0]=1;I=c[I+12>>2]|0;}while((I|0)!=0);R=c[H>>2]|0}c[Q>>2]=R;P=G}c[t+4>>2]=0;if((P|0)==0){S=0}else{I=P;while(1){E=c[I+12>>2]|0;if((E|0)==0){S=I;break}else{I=E}}}c[m>>2]=S;gF(t);XZ(F)}else{if(u>>>0>15){B=2071}else{C=y;B=2072}}}while(0);if((B|0)==2071){B=0;u=c[p>>2]|0;a2(68112,58,1,u|0)|0;C=y;B=2072}L2906:do{if((B|0)==2072){while(1){B=0;if((bc(a[C]|0)|0)==0){break}else{C=C+1|0;B=2072}}t=XY(9)|0;if((eJ(a[C]|0)|0)==0){T=C;U=t;V=0}else{u=C;w=t;t=8;v=0;while(1){if((v|0)==(t|0)){I=v<<1;W=I;X=X_(w,I|1)|0}else{W=t;X=w}I=u+1|0;G=v+1|0;a[X+v|0]=a[u]|0;if((eJ(a[I]|0)|0)==0){T=I;U=X;V=G;break}else{u=I;w=X;t=W;v=G}}}a[U+V|0]=0;v=j+4|0;c[v>>2]=U;t=T;while(1){Y=t+1|0;if((bc(a[t]|0)|0)==0){break}else{t=Y}}do{if((a[t]|0)==61){w=Y;while(1){Z=w+1|0;if((bc(a[w]|0)|0)==0){break}else{w=Z}}u=a[w]|0;if((u<<24>>24|0)==34){G=d8(Z|0,66328,h|0)|0;if((G|0)==0){B=2086;break}_=dq(G|0)|0}else if((u<<24>>24|0)==0){B=2086;break}else{u=d8(w|0,64368,h|0)|0;if((u|0)==0){B=2086;break}_=dq(u|0)|0}c[j+8>>2]=_;if((_|0)==0){break}if((c[r>>2]|0)==0){c[r>>2]=s;c[m>>2]=s;break L2906}else{c[(c[m>>2]|0)+12>>2]=s;c[m>>2]=s;break L2906}}else{B=2086}}while(0);if((B|0)==2086){B=0;c[j+8>>2]=0}c[v>>2]=0;XZ(U)}}while(0);XZ(y)}if((s|0)!=(c[m>>2]|0)){XZ(j)}}while((eh(d|0)|0)==0)}aQ(d|0)|0;k=l;i=e;return k|0}function gI(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;f=i;i=i+8192|0;g=f|0;h=f+4096|0;j=b+4|0;while(1){k=c[j>>2]|0;if((k|0)==0){l=0;m=2144;break}if((cL(d|0,c[k+4>>2]|0)|0)==0){break}else{j=k+12|0}}if((m|0)==2144){i=f;return l|0}j=c[k+8>>2]|0;k=a[j]|0;do{if((k<<24>>24|0)==58){if((a[j+1|0]|0)!=47){n=e;o=j;q=4096;m=2133;break}d=h|0;b=g|0;a[d]=0;r=bZ()|0;s=0;while(1){if(s>>>0>=3){m=2119;break}t=c[15088+(s<<2)>>2]|0;bN(b|0,4096,84576,(u=i,i=i+16|0,c[u>>2]=r,c[u+8>>2]=t,u)|0)|0;i=u;v=eK(b|0,d|0,4095)|0;if((v|0)>-1){m=2118;break}else{s=s+1|0}}if((m|0)==2118){a[h+v|0]=0}else if((m|0)==2119){s=c[198610]|0;a2(81112,78,1,((s|0)!=0?s:c[p>>2]|0)|0)|0;s=c[198610]|0;aY(((s|0)!=0?s:c[p>>2]|0)|0)|0}if((a[637400]&1)!=0){s=c[198610]|0;b=(s|0)!=0?s:c[p>>2]|0;ec(b|0,85408,(u=i,i=i+8|0,c[u>>2]=d,u)|0)|0;i=u;b=c[198610]|0;s=(b|0)!=0?b:c[p>>2]|0;aY(s|0)|0}do{if((X1(d|0)|0)>>>0<2){w=4096;x=0;y=e;z=d}else{s=cg(d|0,47)|0;if((s|0)==0){bN(d|0,3,99560,(u=i,i=i+8|0,c[u>>2]=36576,u)|0)|0;i=u;w=4096;x=0;y=e;z=d;break}else{a[s+1|0]=0;w=4096;x=0;y=e;z=d;break}}}while(0);while(1){d=w-1|0;if((d|0)==0){m=2128;break}s=a[z]|0;a[y]=s;if(s<<24>>24==0){A=x;break}else{w=d;x=x+1|0;y=y+1|0;z=z+1|0}}do{if((m|0)==2128){a[y]=0;if((a[z]|0)==0){A=x;break}else{B=z;C=x}while(1){d=B+1|0;s=C+1|0;if((a[d]|0)==0){A=s;break}else{B=d;C=s}}}}while(0);if(A>>>0<4096){D=A;E=j+2|0;m=2132;break}else{l=0;i=f;return l|0}}else if((k<<24>>24|0)==126){s=dE(87160)|0;if((s|0)==0){n=e;o=j;q=4096;m=2133;break}else{F=4096;G=0;H=e;I=s}while(1){s=F-1|0;if((s|0)==0){m=2110;break}d=a[I]|0;a[H]=d;if(d<<24>>24==0){J=G;break}else{F=s;G=G+1|0;H=H+1|0;I=I+1|0}}do{if((m|0)==2110){a[H]=0;if((a[I]|0)==0){J=G;break}else{K=I;L=G}while(1){s=K+1|0;d=L+1|0;if((a[s]|0)==0){J=d;break}else{K=s;L=d}}}}while(0);if(J>>>0<4096){D=J;E=j+1|0;m=2132;break}else{l=0;i=f;return l|0}}else{n=e;o=j;q=4096;m=2133}}while(0);if((m|0)==2132){if((D|0)==4096){M=0;N=E;O=0;m=2137}else{n=e+D|0;o=E;q=4096-D|0;m=2133}}L2994:do{if((m|0)==2133){D=q;E=0;e=n;j=o;while(1){J=D-1|0;if((J|0)==0){break}L=a[j]|0;a[e]=L;if(L<<24>>24==0){P=E;Q=q;break L2994}else{D=J;E=E+1|0;e=e+1|0;j=j+1|0}}a[e]=0;M=E;N=j;O=q;m=2137}}while(0);do{if((m|0)==2137){if((a[N]|0)==0){P=M;Q=O;break}else{R=N;S=M}while(1){q=R+1|0;o=S+1|0;if((a[q]|0)==0){P=o;Q=O;break}else{R=q;S=o}}}}while(0);l=P>>>0<Q>>>0;i=f;return l|0}function gJ(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=b+4|0;while(1){g=c[f>>2]|0;if((g|0)==0){h=0;i=2160;break}if((cL(d|0,c[g+4>>2]|0)|0)==0){break}else{f=g+12|0}}if((i|0)==2160){return h|0}i=c[g+8>>2]|0;if((X8(i|0,98168)|0)==0){a[e]=1;h=1;return h|0}if((X8(i|0,53440)|0)==0){a[e]=1;h=1;return h|0}if((X8(i|0,44720)|0)==0){a[e]=0;h=1;return h|0}if((X8(i|0,38248)|0)!=0){h=0;return h|0}a[e]=0;h=1;return h|0}function gK(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0;f=b+4|0;b=c[f>>2]|0;L3030:do{if((b|0)==0){g=0}else{h=b;while(1){if((a[h|0]&1)==0){if((cL(d|0,c[h+4>>2]|0)|0)==0){break}}i=c[h+12>>2]|0;if((i|0)==0){g=h;break L3030}else{h=i}}i=h+8|0;XZ(c[i>>2]|0);c[i>>2]=dq(e|0)|0;return}}while(0);b=XY(16)|0;do{if((b|0)!=0){if((c[b-4>>2]&3|0)==0){break}X2(b|0,0,16)}}while(0);i=b;c[b+4>>2]=dq(d|0)|0;c[b+8>>2]=dq(e|0)|0;if((g|0)==0){c[f>>2]=i;return}else{c[g+12>>2]=i;return}}function gL(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0;e=i;f=(d|0)!=0;do{if(f){g=c5(d|0,94016)|0;if((g|0)==0){h=0}else{j=g;break}i=e;return h|0}else{j=c[o>>2]|0}}while(0);d=c[b+16>>2]|0;if((d|0)!=0){g=d;do{ec(j|0,87504,(k=i,i=i+8|0,c[k>>2]=c[g>>2],k)|0)|0;i=k;g=c[g+4>>2]|0;}while((g|0)!=0)}g=c[b+4>>2]|0;if((g|0)!=0){b=g;do{if((a[b|0]&1)==0){g=c[b+4>>2]|0;d=c[b+8>>2]|0;ec(j|0,84224,(k=i,i=i+16|0,c[k>>2]=g,c[k+8>>2]=d,k)|0)|0;i=k}b=c[b+12>>2]|0;}while((b|0)!=0)}if(!f){h=1;i=e;return h|0}aQ(j|0)|0;h=1;i=e;return h|0}function gM(d){d=d|0;var e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aW=0,aX=0,aZ=0,a_=0,a0=0,a1=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0.0,bC=0.0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0;e=i;i=i+12840|0;f=e|0;h=e+72|0;j=e+144|0;k=e+4312|0;l=e+4320|0;m=e+8416|0;n=e+12512|0;o=e+12520|0;q=e+12528|0;r=e+12536|0;s=e+12544|0;t=e+12552|0;u=e+12560|0;v=e+12568|0;w=e+12576|0;x=e+12584|0;y=e+12592|0;z=e+12600|0;A=e+12608|0;B=e+12616|0;C=e+12624|0;D=e+12632|0;E=e+12640|0;F=e+12648|0;G=e+12656|0;H=e+12664|0;I=e+12728|0;J=e+12736|0;K=e+12744|0;L=e+12752|0;M=e+12760|0;N=e+12768|0;O=e+12776|0;P=e+12784|0;Q=e+12792|0;R=e+12800|0;S=e+12808|0;T=e+12816|0;U=e+12824|0;V=e+12832|0;do{if((d|0)==0){W=e+216|0;X=dE(87416)|0;Y=dE(87160)|0;do{if((X|0)==0){if((Y|0)==0){Z=2206;break}bN(W|0,4096,86552,(_=i,i=i+8|0,c[_>>2]=Y,_)|0)|0;i=_;Z=2199}else{bN(W|0,4096,86880,(_=i,i=i+8|0,c[_>>2]=X,_)|0)|0;i=_;Z=2199}}while(0);if((Z|0)==2199){if((a[637400]&1)!=0){X=c[198610]|0;$=(X|0)!=0?X:c[p>>2]|0;ec($|0,86272,(_=i,i=i+8|0,c[_>>2]=W,_)|0)|0;i=_;$=c[198610]|0;X=($|0)!=0?$:c[p>>2]|0;aY(X|0)|0}X=gH(W,0)|0;if((X|0)!=0|(Y|0)==0){aa=X}else{bN(W|0,4096,86008,(_=i,i=i+8|0,c[_>>2]=Y,_)|0)|0;i=_;if((a[637400]&1)!=0){X=c[198610]|0;$=(X|0)!=0?X:c[p>>2]|0;ec($|0,86272,(_=i,i=i+8|0,c[_>>2]=W,_)|0)|0;i=_;$=c[198610]|0;X=($|0)!=0?$:c[p>>2]|0;aY(X|0)|0}aa=gH(W,0)|0}if((aa|0)==0){Z=2206}else{ab=aa}}do{if((Z|0)==2206){gr(W,85696,85248);if((a[637400]&1)!=0){X=c[198610]|0;$=(X|0)!=0?X:c[p>>2]|0;ec($|0,86272,(_=i,i=i+8|0,c[_>>2]=W,_)|0)|0;i=_;$=c[198610]|0;X=($|0)!=0?$:c[p>>2]|0;aY(X|0)|0}X=gH(W,0)|0;if((X|0)==0){ac=1}else{ab=X;break}i=e;return ac|0}}while(0);Y=4096;X=657930;$=W;while(1){ad=Y-1|0;if((ad|0)==0){Z=2212;break}ae=a[$]|0;a[X]=ae;if(ae<<24>>24==0){break}else{Y=ad;X=X+1|0;$=$+1|0}}do{if((Z|0)==2212){a[X]=0;if((a[$]|0)==0){break}else{af=$}do{af=af+1|0;}while((a[af]|0)!=0)}}while(0);if((ab|0)==0){ac=1}else{ag=ab;break}i=e;return ac|0}else{$=gH(d,0)|0;if(($|0)==0){ac=0}else{ag=$;break}i=e;return ac|0}}while(0);d=l|0;l=4096;ab=d;af=662026;while(1){aa=l-1|0;if((aa|0)==0){Z=2218;break}$=a[af]|0;a[ab]=$;if($<<24>>24==0){break}else{l=aa;ab=ab+1|0;af=af+1|0}}do{if((Z|0)==2218){a[ab]=0;if((a[af]|0)==0){break}else{ah=af}do{ah=ah+1|0;}while((a[ah]|0)!=0)}}while(0);ah=d8(d|0,38176,k|0)|0;d=(a[637400]&1)!=0;if((ah|0)==0){ai=d}else{af=ag+4|0;ab=ah;ah=d;while(1){if(ah){d=c[198610]|0;l=(d|0)!=0?d:c[p>>2]|0;ec(l|0,34008,(_=i,i=i+8|0,c[_>>2]=ab,_)|0)|0;i=_;l=c[198610]|0;d=(l|0)!=0?l:c[p>>2]|0;aY(d|0)|0}d=gH(ab,0)|0;if((d|0)==0){l=c[198610]|0;aa=(l|0)!=0?l:c[p>>2]|0;ec(aa|0,29504,(_=i,i=i+8|0,c[_>>2]=ab,_)|0)|0;i=_;aa=c[198610]|0;l=(aa|0)!=0?aa:c[p>>2]|0;aY(l|0)|0}else{l=c[d+8>>2]|0;if((l|0)!=0){c[l+12>>2]=c[af>>2];l=d+4|0;c[af>>2]=c[l>>2];c[l>>2]=0}gF(d)}d=d8(0,53448,k|0)|0;l=(a[637400]&1)!=0;if((d|0)==0){ai=l;break}else{ab=d;ah=l}}}do{if(ai){ah=c[198610]|0;ab=(ah|0)!=0?ah:c[p>>2]|0;a2(21560,15,1,ab|0)|0;ab=c[198610]|0;ah=(ab|0)!=0?ab:c[p>>2]|0;aY(ah|0)|0;ah=c[p>>2]|0;ab=c[ag+16>>2]|0;if((ab|0)!=0){k=ab;do{ec(ah|0,87504,(_=i,i=i+8|0,c[_>>2]=c[k>>2],_)|0)|0;i=_;k=c[k+4>>2]|0;}while((k|0)!=0)}k=ag+4|0;ab=c[k>>2]|0;if((ab|0)!=0){af=ab;do{ab=c[af+8>>2]|0;l=(a[af|0]&1)!=0?77384:798256;ec(ah|0,80704,(_=i,i=i+24|0,c[_>>2]=c[af+4>>2],c[_+8>>2]=ab,c[_+16>>2]=l,_)|0)|0;i=_;af=c[af+12>>2]|0;}while((af|0)!=0)}if((a[637400]&1)==0){aj=k;break}af=c[198610]|0;ah=(af|0)!=0?af:c[p>>2]|0;a2(99144,19,1,ah|0)|0;ah=c[198610]|0;af=(ah|0)!=0?ah:c[p>>2]|0;aY(af|0)|0;aj=k}else{aj=ag+4|0}}while(0);ai=aj;while(1){ak=c[ai>>2]|0;if((ak|0)==0){al=aj;break}if((cL(94584,c[ak+4>>2]|0)|0)==0){Z=2242;break}ai=ak+12|0}if((Z|0)==2242){g[133766]=+X0(c[ak+8>>2]|0);al=aj}while(1){am=c[al>>2]|0;if((am|0)==0){an=aj;break}if((cL(90552,c[am+4>>2]|0)|0)==0){Z=2246;break}al=am+12|0}if((Z|0)==2246){g[133767]=+X0(c[am+8>>2]|0);an=aj}while(1){ao=c[an>>2]|0;if((ao|0)==0){ap=aj;break}if((cL(87432,c[ao+4>>2]|0)|0)==0){Z=2250;break}an=ao+12|0}do{if((Z|0)==2250){c[(dS()|0)>>2]=0;an=a$(c[ao+8>>2]|0,0,0)|0;if((c[(dS()|0)>>2]|0)!=0){ap=aj;break}c[133770]=an;ap=aj}}while(0);while(1){aq=c[ap>>2]|0;if((aq|0)==0){break}if((cL(84152,c[aq+4>>2]|0)|0)==0){Z=2255;break}ap=aq+12|0}do{if((Z|0)==2255){c[(dS()|0)>>2]=0;ap=a$(c[aq+8>>2]|0,0,0)|0;if((c[(dS()|0)>>2]|0)!=0){break}c[133771]=ap}}while(0);do{if((a[637403]&1)==0){a[n]=0;if(!(gJ(ag,80632,n)|0)){break}a[535072]=a[n]&1}}while(0);a[o]=0;if(gJ(ag,77296,o)|0){a[535073]=a[o]&1;ar=aj}else{ar=aj}while(1){as=c[ar>>2]|0;if((as|0)==0){break}if((cL(74176,c[as+4>>2]|0)|0)==0){Z=2264;break}else{ar=as+12|0}}do{if((Z|0)==2264){c[(dS()|0)>>2]=0;ar=a$(c[as+8>>2]|0,0,0)|0;if((c[(dS()|0)>>2]|0)!=0){break}c[133769]=ar}}while(0);a[q]=0;if(gJ(ag,70968,q)|0){a[551536]=a[q]&1}a[r]=0;if(gJ(ag,69424,r)|0){a[535088]=a[r]&1}a[s]=0;if(gJ(ag,68096,s)|0){a[535089]=a[s]&1;at=aj}else{at=aj}while(1){au=c[at>>2]|0;if((au|0)==0){Z=2276;break}if((cL(66304,c[au+4>>2]|0)|0)==0){Z=2274;break}else{at=au+12|0}}do{if((Z|0)==2274){c[(dS()|0)>>2]=0;at=a$(c[au+8>>2]|0,0,0)|0;if((c[(dS()|0)>>2]|0)!=0){Z=2276;break}c[133773]=at;av=at}}while(0);if((Z|0)==2276){av=c[133773]|0}if(av>>>0>3){c[133773]=3}a[t]=0;if(gJ(ag,64352,t)|0){a[543312]=a[t]&1}a[u]=0;if(gJ(ag,62848,u)|0){a[535096]=a[u]&1}a[v]=0;if(gJ(ag,61624,v)|0){a[535097]=a[v]&1}a[w]=0;if(gJ(ag,60640,w)|0){a[535105]=a[w]&1}a[x]=0;if(gJ(ag,59520,x)|0){a[535098]=a[x]&1;aw=aj}else{aw=aj}while(1){ax=c[aw>>2]|0;if((ax|0)==0){ay=aj;break}if((cL(58744,c[ax+4>>2]|0)|0)==0){Z=2291;break}else{aw=ax+12|0}}if((Z|0)==2291){g[133775]=+X0(c[ax+8>>2]|0);ay=aj}while(1){az=c[ay>>2]|0;if((az|0)==0){break}if((cL(58080,c[az+4>>2]|0)|0)==0){Z=2294;break}else{ay=az+12|0}}do{if((Z|0)==2294){c[(dS()|0)>>2]=0;ay=a$(c[az+8>>2]|0,0,0)|0;if((c[(dS()|0)>>2]|0)!=0){break}c[133777]=ay}}while(0);a[y]=0;if(gJ(ag,57480,y)|0){a[535104]=a[y]&1;aA=aj}else{aA=aj}while(1){aB=c[aA>>2]|0;if((aB|0)==0){break}if((cL(56784,c[aB+4>>2]|0)|0)==0){Z=2300;break}else{aA=aB+12|0}}if((Z|0)==2300){g[135827]=+X0(c[aB+8>>2]|0)}gI(ag,55760,535112)|0;a[z]=0;if(gJ(ag,54704,z)|0){a[539208]=a[z]&1}a[A]=0;if(gJ(ag,53808,A)|0){a[551540]=a[A]&1}gI(ag,52880,547409)|0;A=aj;while(1){aC=c[A>>2]|0;if((aC|0)==0){break}if((cL(52064,c[aC+4>>2]|0)|0)==0){Z=2308;break}else{A=aC+12|0}}if((Z|0)==2308){g[137877]=+X0(c[aC+8>>2]|0)}a[B]=0;if(gJ(ag,51152,B)|0){a[551512]=a[B]&1}a[C]=0;if(gJ(ag,50328,C)|0){a[551513]=a[C]&1;aD=aj}else{aD=aj}while(1){aE=c[aD>>2]|0;if((aE|0)==0){aF=aj;break}if((cL(49472,c[aE+4>>2]|0)|0)==0){Z=2315;break}else{aD=aE+12|0}}if((Z|0)==2315){g[137879]=+X0(c[aE+8>>2]|0);aF=aj}while(1){aG=c[aF>>2]|0;if((aG|0)==0){aH=aj;break}if((cL(48688,c[aG+4>>2]|0)|0)==0){Z=2318;break}else{aF=aG+12|0}}if((Z|0)==2318){g[137880]=+X0(c[aG+8>>2]|0);aH=aj}while(1){aI=c[aH>>2]|0;if((aI|0)==0){aJ=aj;break}if((cL(47744,c[aI+4>>2]|0)|0)==0){Z=2321;break}else{aH=aI+12|0}}do{if((Z|0)==2321){c[(dS()|0)>>2]=0;aH=a$(c[aI+8>>2]|0,0,0)|0;if((c[(dS()|0)>>2]|0)!=0){aJ=aj;break}c[198596]=aH;aJ=aj}}while(0);while(1){aK=c[aJ>>2]|0;if((aK|0)==0){aL=aj;break}if((cL(46592,c[aK+4>>2]|0)|0)==0){Z=2325;break}else{aJ=aK+12|0}}do{if((Z|0)==2325){c[(dS()|0)>>2]=0;aJ=a$(c[aK+8>>2]|0,0,0)|0;if((c[(dS()|0)>>2]|0)!=0){aL=aj;break}c[198597]=aJ;aL=aj}}while(0);while(1){aM=c[aL>>2]|0;if((aM|0)==0){aN=aj;break}if((cL(45472,c[aM+4>>2]|0)|0)==0){Z=2329;break}else{aL=aM+12|0}}do{if((Z|0)==2329){c[(dS()|0)>>2]=0;aL=a$(c[aM+8>>2]|0,0,0)|0;if((c[(dS()|0)>>2]|0)!=0){aN=aj;break}c[198598]=aL;aN=aj}}while(0);while(1){aO=c[aN>>2]|0;if((aO|0)==0){aP=aj;break}if((cL(44888,c[aO+4>>2]|0)|0)==0){Z=2333;break}else{aN=aO+12|0}}do{if((Z|0)==2333){c[(dS()|0)>>2]=0;aN=a$(c[aO+8>>2]|0,0,0)|0;if((c[(dS()|0)>>2]|0)!=0){aP=aj;break}c[198599]=aN;aP=aj}}while(0);while(1){aQ=c[aP>>2]|0;if((aQ|0)==0){break}if((cL(44312,c[aQ+4>>2]|0)|0)==0){Z=2337;break}else{aP=aQ+12|0}}do{if((Z|0)==2337){c[(dS()|0)>>2]=0;aP=aV(c[aQ+8>>2]|0,0,16)|0;if((c[(dS()|0)>>2]|0)!=0){break}g[137881]=+((aP>>>16&255)>>>0>>>0)/255.0;g[137882]=+((aP>>>8&255)>>>0>>>0)/255.0;g[137883]=+((aP&255)>>>0>>>0)/255.0}}while(0);a[D]=0;if(gJ(ag,43480,D)|0){a[551537]=a[D]&1}a[E]=0;if(gJ(ag,42800,E)|0){a[551538]=a[E]&1}a[F]=0;if(gJ(ag,42200,F)|0){a[551539]=a[F]&1}gI(ag,41528,543313)|0;if((cL(543313,41208)|0)==0){a[543313]=0;aR=aj}else{aR=aj}while(1){aS=c[aR>>2]|0;if((aS|0)==0){break}if((cL(40688,c[aS+4>>2]|0)|0)==0){Z=2349;break}else{aR=aS+12|0}}if((Z|0)==2349){g[148936]=+X0(c[aS+8>>2]|0)}a[G]=0;if(gJ(ag,39928,G)|0){a[596358]=a[G]&1}G=H|0;bN(G|0,64,39128,(_=i,i=i+8|0,c[_>>2]=1,_)|0)|0;i=_;H=aj;while(1){aT=c[H>>2]|0;if((aT|0)==0){break}if((cL(G|0,c[aT+4>>2]|0)|0)==0){Z=2355;break}else{H=aT+12|0}}do{if((Z|0)==2355){c[(dS()|0)>>2]=0;H=a$(c[aT+8>>2]|0,0,0)|0;if((c[(dS()|0)>>2]|0)!=0){break}c[148937]=H}}while(0);bN(G|0,64,39128,(_=i,i=i+8|0,c[_>>2]=2,_)|0)|0;i=_;aT=aj;while(1){aU=c[aT>>2]|0;if((aU|0)==0){break}if((cL(G|0,c[aU+4>>2]|0)|0)==0){Z=2360;break}else{aT=aU+12|0}}do{if((Z|0)==2360){c[(dS()|0)>>2]=0;aT=a$(c[aU+8>>2]|0,0,0)|0;if((c[(dS()|0)>>2]|0)!=0){break}c[148938]=aT}}while(0);bN(G|0,64,39128,(_=i,i=i+8|0,c[_>>2]=3,_)|0)|0;i=_;aU=aj;while(1){aW=c[aU>>2]|0;if((aW|0)==0){break}if((cL(G|0,c[aW+4>>2]|0)|0)==0){Z=2561;break}else{aU=aW+12|0}}do{if((Z|0)==2561){c[(dS()|0)>>2]=0;aU=a$(c[aW+8>>2]|0,0,0)|0;if((c[(dS()|0)>>2]|0)!=0){break}c[148939]=aU}}while(0);bN(G|0,64,39128,(_=i,i=i+8|0,c[_>>2]=4,_)|0)|0;i=_;aW=aj;while(1){aX=c[aW>>2]|0;if((aX|0)==0){break}if((cL(G|0,c[aX+4>>2]|0)|0)==0){Z=2566;break}else{aW=aX+12|0}}do{if((Z|0)==2566){c[(dS()|0)>>2]=0;aW=a$(c[aX+8>>2]|0,0,0)|0;if((c[(dS()|0)>>2]|0)!=0){break}c[148940]=aW}}while(0);bN(G|0,64,39128,(_=i,i=i+8|0,c[_>>2]=5,_)|0)|0;i=_;aX=aj;while(1){aZ=c[aX>>2]|0;if((aZ|0)==0){break}if((cL(G|0,c[aZ+4>>2]|0)|0)==0){Z=2571;break}else{aX=aZ+12|0}}do{if((Z|0)==2571){c[(dS()|0)>>2]=0;aX=a$(c[aZ+8>>2]|0,0,0)|0;if((c[(dS()|0)>>2]|0)!=0){break}c[148941]=aX}}while(0);bN(G|0,64,39128,(_=i,i=i+8|0,c[_>>2]=6,_)|0)|0;i=_;aZ=aj;while(1){a_=c[aZ>>2]|0;if((a_|0)==0){break}if((cL(G|0,c[a_+4>>2]|0)|0)==0){Z=2576;break}else{aZ=a_+12|0}}do{if((Z|0)==2576){c[(dS()|0)>>2]=0;aZ=a$(c[a_+8>>2]|0,0,0)|0;if((c[(dS()|0)>>2]|0)!=0){break}c[148942]=aZ}}while(0);bN(G|0,64,39128,(_=i,i=i+8|0,c[_>>2]=7,_)|0)|0;i=_;a_=aj;while(1){a0=c[a_>>2]|0;if((a0|0)==0){break}if((cL(G|0,c[a0+4>>2]|0)|0)==0){Z=2581;break}else{a_=a0+12|0}}do{if((Z|0)==2581){c[(dS()|0)>>2]=0;a_=a$(c[a0+8>>2]|0,0,0)|0;if((c[(dS()|0)>>2]|0)!=0){break}c[148943]=a_}}while(0);bN(G|0,64,39128,(_=i,i=i+8|0,c[_>>2]=8,_)|0)|0;i=_;a0=aj;while(1){a1=c[a0>>2]|0;if((a1|0)==0){break}if((cL(G|0,c[a1+4>>2]|0)|0)==0){Z=2586;break}else{a0=a1+12|0}}do{if((Z|0)==2586){c[(dS()|0)>>2]=0;a0=a$(c[a1+8>>2]|0,0,0)|0;if((c[(dS()|0)>>2]|0)!=0){break}c[148944]=a0}}while(0);a[I]=0;if(gJ(ag,38512,I)|0){a[551576]=a[I]&1;a3=aj}else{a3=aj}while(1){a4=c[a3>>2]|0;if((a4|0)==0){a5=aj;break}if((cL(38160,c[a4+4>>2]|0)|0)==0){Z=2364;break}else{a3=a4+12|0}}do{if((Z|0)==2364){c[(dS()|0)>>2]=0;a3=a$(c[a4+8>>2]|0,0,0)|0;if((c[(dS()|0)>>2]|0)!=0){a5=aj;break}c[137895]=a3;a5=aj}}while(0);while(1){a6=c[a5>>2]|0;if((a6|0)==0){a7=aj;break}if((cL(37856,c[a6+4>>2]|0)|0)==0){Z=2368;break}else{a5=a6+12|0}}L3381:do{if((Z|0)==2368){a5=4096;a4=551588;a3=c[a6+8>>2]|0;while(1){I=a5-1|0;if((I|0)==0){break}a1=a[a3]|0;a[a4]=a1;if(a1<<24>>24==0){a7=aj;break L3381}else{a5=I;a4=a4+1|0;a3=a3+1|0}}a[a4]=0;if((a[a3]|0)==0){a7=aj;break}else{a8=a3}while(1){a5=a8+1|0;if((a[a5]|0)==0){a7=aj;break}else{a8=a5}}}}while(0);while(1){a9=c[a7>>2]|0;if((a9|0)==0){break}if((cL(37616,c[a9+4>>2]|0)|0)==0){Z=2375;break}else{a7=a9+12|0}}do{if((Z|0)==2375){c[(dS()|0)>>2]=0;a7=a$(c[a9+8>>2]|0,0,0)|0;if((c[(dS()|0)>>2]|0)!=0){break}c[138921]=a7}}while(0);a[J]=0;if(gJ(ag,37256,J)|0){a[555688]=a[J]&1}a[K]=0;if(gJ(ag,36832,K)|0){a[559785]=a[K]&1;ba=aj}else{ba=aj}while(1){bb=c[ba>>2]|0;if((bb|0)==0){bc=aj;break}if((cL(36432,c[bb+4>>2]|0)|0)==0){Z=2383;break}else{ba=bb+12|0}}if((Z|0)==2383){g[139947]=+X0(c[bb+8>>2]|0);bc=aj}while(1){bd=c[bc>>2]|0;if((bd|0)==0){be=aj;break}if((cL(36032,c[bd+4>>2]|0)|0)==0){Z=2386;break}else{bc=bd+12|0}}if((Z|0)==2386){g[139948]=+X0(c[bd+8>>2]|0);be=aj}while(1){bf=c[be>>2]|0;if((bf|0)==0){bg=aj;break}if((cL(35456,c[bf+4>>2]|0)|0)==0){Z=2389;break}else{be=bf+12|0}}L3414:do{if((Z|0)==2389){be=32;bd=535e3;bc=c[bf+8>>2]|0;while(1){bb=be-1|0;if((bb|0)==0){break}ba=a[bc]|0;a[bd]=ba;if(ba<<24>>24==0){bg=aj;break L3414}else{be=bb;bd=bd+1|0;bc=bc+1|0}}a[bd]=0;if((a[bc]|0)==0){bg=aj;break}else{bh=bc}while(1){be=bh+1|0;if((a[be]|0)==0){bg=aj;break}else{bh=be}}}}while(0);while(1){bi=c[bg>>2]|0;if((bi|0)==0){bj=aj;break}if((cL(34872,c[bi+4>>2]|0)|0)==0){Z=2396;break}else{bg=bi+12|0}}L3425:do{if((Z|0)==2396){bg=32;bh=535032;bf=c[bi+8>>2]|0;while(1){bc=bg-1|0;if((bc|0)==0){break}bd=a[bf]|0;a[bh]=bd;if(bd<<24>>24==0){bj=aj;break L3425}else{bg=bc;bh=bh+1|0;bf=bf+1|0}}a[bh]=0;if((a[bf]|0)==0){bj=aj;break}else{bk=bf}while(1){bg=bk+1|0;if((a[bg]|0)==0){bj=aj;break}else{bk=bg}}}}while(0);while(1){bl=c[bj>>2]|0;if((bl|0)==0){break}if((cL(34440,c[bl+4>>2]|0)|0)==0){Z=2403;break}else{bj=bl+12|0}}L3436:do{if((Z|0)==2403){bj=32;bk=551544;bi=c[bl+8>>2]|0;while(1){bf=bj-1|0;if((bf|0)==0){break}bh=a[bi]|0;a[bk]=bh;if(bh<<24>>24==0){break L3436}else{bj=bf;bk=bk+1|0;bi=bi+1|0}}a[bk]=0;if((a[bi]|0)==0){break}else{bm=bi}do{bm=bm+1|0;}while((a[bm]|0)!=0)}}while(0);gI(ag,33960,555689)|0;bm=aj;while(1){bn=c[bm>>2]|0;if((bn|0)==0){bo=aj;break}if((cL(71840,c[bn+4>>2]|0)|0)==0){Z=2411;break}else{bm=bn+12|0}}L3448:do{if((Z|0)==2411){bm=32;bl=559832;bi=c[bn+8>>2]|0;while(1){bk=bm-1|0;if((bk|0)==0){break}bj=a[bi]|0;a[bl]=bj;if(bj<<24>>24==0){bo=aj;break L3448}else{bm=bk;bl=bl+1|0;bi=bi+1|0}}a[bl]=0;if((a[bi]|0)==0){bo=aj;break}else{bp=bi}while(1){bm=bp+1|0;if((a[bm]|0)==0){bo=aj;break}else{bp=bm}}}}while(0);while(1){bq=c[bo>>2]|0;if((bq|0)==0){break}if((cL(33176,c[bq+4>>2]|0)|0)==0){Z=2418;break}else{bo=bq+12|0}}L3459:do{if((Z|0)==2418){bo=32;bp=559864;bn=c[bq+8>>2]|0;while(1){bi=bo-1|0;if((bi|0)==0){break}bl=a[bn]|0;a[bp]=bl;if(bl<<24>>24==0){break L3459}else{bo=bi;bp=bp+1|0;bn=bn+1|0}}a[bp]=0;if((a[bn]|0)==0){break}else{br=bn}do{br=br+1|0;}while((a[br]|0)!=0)}}while(0);if((a[612764]|0)==0){gI(ag,32760,612764)|0}gI(ag,32120,604568)|0;gI(ag,31776,625052)|0;do{if((a[625052]|0)!=0){if((eB(625052,j|0)|0)>=0){if((c[j+8>>2]&61440|0)==16384){break}}br=c[198610]|0;bq=(br|0)!=0?br:c[p>>2]|0;a2(31296,84,1,bq|0)|0;bq=c[198610]|0;br=(bq|0)!=0?bq:c[p>>2]|0;aY(br|0)|0;a[625052]=0}}while(0);gI(ag,30808,633281)|0;if((cL(633281,41208)|0)==0){a[633281]=0}gI(ag,30304,715274)|0;if((cL(715274,41208)|0)==0){a[715274]=0}gI(ag,29928,596368)|0;j=aj;while(1){bs=c[j>>2]|0;if((bs|0)==0){bt=aj;break}if((cL(29464,c[bs+4>>2]|0)|0)==0){Z=2436;break}else{j=bs+12|0}}if((Z|0)==2436){g[150116]=+X0(c[bs+8>>2]|0);bt=aj}while(1){bu=c[bt>>2]|0;if((bu|0)==0){break}if((cL(29160,c[bu+4>>2]|0)|0)==0){Z=2439;break}else{bt=bu+12|0}}if((Z|0)==2439){g[150117]=+X0(c[bu+8>>2]|0)}a[L]=0;if(gJ(ag,28856,L)|0){a[633244]=a[L]&1;bv=aj}else{bv=aj}while(1){bw=c[bv>>2]|0;if((bw|0)==0){bx=aj;break}if((cL(28520,c[bw+4>>2]|0)|0)==0){Z=2444;break}else{bv=bw+12|0}}do{if((Z|0)==2444){c[(dS()|0)>>2]=0;bv=a$(c[bw+8>>2]|0,0,0)|0;if((c[(dS()|0)>>2]|0)!=0){bx=aj;break}c[158312]=bv*1e6|0;bx=aj}}while(0);while(1){by=c[bx>>2]|0;if((by|0)==0){bz=aj;break}if((cL(28184,c[by+4>>2]|0)|0)==0){Z=2448;break}else{bx=by+12|0}}do{if((Z|0)==2448){c[(dS()|0)>>2]=0;bx=a$(c[by+8>>2]|0,0,0)|0;if((c[(dS()|0)>>2]|0)!=0){bz=aj;break}c[158313]=bx;bz=aj}}while(0);while(1){bA=c[bz>>2]|0;if((bA|0)==0){Z=2453;break}if((cL(27864,c[bA+4>>2]|0)|0)==0){Z=2452;break}else{bz=bA+12|0}}if((Z|0)==2452){bB=+X0(c[bA+8>>2]|0);g[158314]=bB;bC=bB}else if((Z|0)==2453){bC=+g[158314]}if(bC<1.0){g[158314]=1.0;bD=aj}else{bD=aj}while(1){bE=c[bD>>2]|0;if((bE|0)==0){break}if((cL(27464,c[bE+4>>2]|0)|0)==0){Z=2458;break}else{bD=bE+12|0}}if((Z|0)==2458){g[158315]=+X0(c[bE+8>>2]|0)}a[M]=0;if(gJ(ag,26992,M)|0){a[633264]=a[M]&1;bF=aj}else{bF=aj}while(1){bG=c[bF>>2]|0;if((bG|0)==0){break}if((cL(26336,c[bG+4>>2]|0)|0)==0){Z=2463;break}else{bF=bG+12|0}}do{if((Z|0)==2463){c[(dS()|0)>>2]=0;bF=a$(c[bG+8>>2]|0,0,0)|0;if((c[(dS()|0)>>2]|0)!=0){break}c[158317]=bF}}while(0);gI(ag,25864,616860)|0;gI(ag,25408,620956)|0;a[N]=0;if(gJ(ag,25048,N)|0){a[633272]=a[N]&1}a[O]=0;if(gJ(ag,24776,O)|0){a[633273]=a[O]&1}a[P]=0;if(gJ(ag,24456,P)|0){a[633274]=a[P]&1}a[Q]=0;if(gJ(ag,23992,Q)|0){a[633275]=a[Q]&1}a[R]=0;if(gJ(ag,23640,R)|0){a[633276]=a[R]&1;bH=aj}else{bH=aj}while(1){bI=c[bH>>2]|0;if((bI|0)==0){break}if((cL(23280,c[bI+4>>2]|0)|0)==0){Z=2477;break}else{bH=bI+12|0}}do{if((Z|0)==2477){c[(dS()|0)>>2]=0;bH=a$(c[bI+8>>2]|0,0,0)|0;if((c[(dS()|0)>>2]|0)!=0){break}b[316639]=bH&65535}}while(0);a[S]=0;if(gJ(ag,22848,S)|0){a[633280]=a[S]&1}gI(ag,22240,608664)|0;S=aj;while(1){bJ=c[S>>2]|0;if((bJ|0)==0){bK=aj;break}if((cL(21872,c[bJ+4>>2]|0)|0)==0){Z=2484;break}else{S=bJ+12|0}}do{if((Z|0)==2484){c[(dS()|0)>>2]=0;S=a$(c[bJ+8>>2]|0,0,0)|0;if((c[(dS()|0)>>2]|0)!=0){bK=aj;break}c[153190]=S;bK=aj}}while(0);while(1){bL=c[bK>>2]|0;if((bL|0)==0){bM=aj;break}if((cL(21520,c[bL+4>>2]|0)|0)==0){Z=2488;break}else{bK=bL+12|0}}do{if((Z|0)==2488){c[(dS()|0)>>2]=0;bK=a$(c[bL+8>>2]|0,0,0)|0;if((c[(dS()|0)>>2]|0)!=0){bM=aj;break}c[149090]=bK;bM=aj}}while(0);while(1){bO=c[bM>>2]|0;if((bO|0)==0){break}if((cL(21176,c[bO+4>>2]|0)|0)==0){Z=2492;break}else{bM=bO+12|0}}do{if((Z|0)==2492){c[(dS()|0)>>2]=0;bM=a$(c[bO+8>>2]|0,0,0)|0;if((c[(dS()|0)>>2]|0)!=0){break}c[149091]=bM}}while(0);a[T]=0;if(gJ(ag,20936,T)|0){a[596356]=a[T]&1}a[U]=0;if(gJ(ag,20608,U)|0){a[596357]=a[U]&1}gI(ag,20304,600472)|0;a[V]=0;if(gJ(ag,19912,V)|0){a[794446]=a[V]&1}L3584:do{if((a[657928]&1)==0){V=m|0;if(!(gI(ag,101032,V)|0)){break}if((cL(V|0,41208)|0)==0){a[707082]=0;break}do{if((eB(V|0,h|0)|0)>=0){if((c[h+8>>2]&61440|0)==16384){bP=4096;bQ=707082;bR=V}else{break}while(1){U=bP-1|0;if((U|0)==0){Z=2508;break}T=a[bR]|0;a[bQ]=T;if(T<<24>>24==0){bS=4096;bT=678410;bU=V;break}else{bP=U;bQ=bQ+1|0;bR=bR+1|0}}do{if((Z|0)==2508){a[bQ]=0;if((a[bR]|0)==0){bS=4096;bT=678410;bU=V;break}else{bV=bR}while(1){U=bV+1|0;if((a[U]|0)==0){bS=4096;bT=678410;bU=V;break}else{bV=U}}}}while(0);while(1){U=bS-1|0;if((U|0)==0){Z=2512;break}T=a[bU]|0;a[bT]=T;if(T<<24>>24==0){break}else{bS=U;bT=bT+1|0;bU=bU+1|0}}do{if((Z|0)==2512){a[bT]=0;if((a[bU]|0)==0){break}else{bW=bU}do{bW=bW+1|0;}while((a[bW]|0)!=0)}}while(0);gu(678410,100880);break L3584}}while(0);V=c[198610]|0;U=(V|0)!=0?V:c[p>>2]|0;a2(99856,72,1,U|0)|0;U=c[198610]|0;V=(U|0)!=0?U:c[p>>2]|0;aY(V|0)|0}}while(0);L3609:do{if((a[657929]&1)==0){bW=m|0;if(!(gI(ag,99496,bW)|0)){break}if((cL(bW|0,41208)|0)==0){a[711178]=0;break}do{if((eB(bW|0,f|0)|0)>=0){if((c[f+8>>2]&61440|0)==16384){bX=4096;bY=711178;bZ=bW}else{break}while(1){bU=bX-1|0;if((bU|0)==0){Z=2524;break}bT=a[bZ]|0;a[bY]=bT;if(bT<<24>>24==0){b_=4096;b$=698890;b0=bW;break}else{bX=bU;bY=bY+1|0;bZ=bZ+1|0}}do{if((Z|0)==2524){a[bY]=0;if((a[bZ]|0)==0){b_=4096;b$=698890;b0=bW;break}else{b1=bZ}while(1){bU=b1+1|0;if((a[bU]|0)==0){b_=4096;b$=698890;b0=bW;break}else{b1=bU}}}}while(0);while(1){bU=b_-1|0;if((bU|0)==0){Z=2528;break}bT=a[b0]|0;a[b$]=bT;if(bT<<24>>24==0){break}else{b_=bU;b$=b$+1|0;b0=b0+1|0}}do{if((Z|0)==2528){a[b$]=0;if((a[b0]|0)==0){break}else{b2=b0}do{b2=b2+1|0;}while((a[b2]|0)!=0)}}while(0);gu(698890,99104);break L3609}}while(0);bW=c[198610]|0;bU=(bW|0)!=0?bW:c[p>>2]|0;a2(98720,73,1,bU|0)|0;bU=c[198610]|0;bW=(bU|0)!=0?bU:c[p>>2]|0;aY(bW|0)|0}}while(0);if(!(gI(ag,98400,629148)|0)){b2=c[198610]|0;b0=(b2|0)!=0?b2:c[p>>2]|0;ec(b0|0,97944,(_=i,i=i+8|0,c[_>>2]=629148,_)|0)|0;i=_;_=c[198610]|0;b0=(_|0)!=0?_:c[p>>2]|0;aY(b0|0)|0}if((cL(629148,41208)|0)==0){a[629148]=0;b3=0}else{b3=0}do{b0=19184+(b3<<2)|0;L3641:do{if((b3|0)==0){_=0;b2=8384;while(1){b$=559896+(_*40|0)|0;do{if((a[b$|0]&1)==0){Z=2543}else{b_=c[8392+(_*20|0)>>2]|0;if((_|0)==56){b4=57;break}b1=(_-25|0)>>>0<31?73576:70576;he(ag,b1,b_,b$);bZ=a[b2]|0;if((bZ&1)==0){b5=bZ}else{hf(ag,b1,b_,b$);b5=a[b2]|0}if((b5&1)==0){Z=2543;break}hg(ag,b1,b_,b$);Z=2543}}while(0);if((Z|0)==2543){Z=0;b$=_+1|0;if((b$|0)==56){break L3641}else{b4=b$}}_=b4;b2=8384+(b4*20|0)|0}}else{b2=0;_=8384;while(1){b$=559896+(b3*2240|0)+(b2*40|0)|0;do{if((a[b$|0]&1)==0){Z=2552}else{b_=c[8392+(b2*20|0)>>2]|0;if((b2|0)==56){b6=57;break}if((b2-25|0)>>>0<31){Z=2552;break}b1=c[b0>>2]|0;he(ag,b1,b_,b$);bZ=a[_]|0;if((bZ&1)==0){b7=bZ}else{hf(ag,b1,b_,b$);b7=a[_]|0}if((b7&1)==0){Z=2552;break}hg(ag,b1,b_,b$);Z=2552}}while(0);if((Z|0)==2552){Z=0;b$=b2+1|0;if((b$|0)==56){break L3641}else{b6=b$}}b2=b6;_=8384+(b6*20|0)|0}}}while(0);b3=b3+1|0;}while(b3>>>0<8);gF(ag);ac=1;i=e;return ac|0}function gN(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;b=dX(c[a>>2]|0)|0;c[a+68>>2]=b;c[a+72>>2]=dX(c[a+4>>2]|0)|0;c[a+76>>2]=dX(c[a+8>>2]|0)|0;c[a+80>>2]=dX(c[a+12>>2]|0)|0;c[a+84>>2]=dX(c[a+16>>2]|0)|0;c[a+88>>2]=dX(c[a+20>>2]|0)|0;c[a+92>>2]=dX(c[a+24>>2]|0)|0;c[a+96>>2]=dX(c[a+28>>2]|0)|0;c[a+100>>2]=dX(c[a+32>>2]|0)|0;c[a+104>>2]=dX(c[a+36>>2]|0)|0;c[a+108>>2]=dX(c[a+40>>2]|0)|0;c[a+112>>2]=dX(c[a+44>>2]|0)|0;c[a+116>>2]=dX(c[a+48>>2]|0)|0;c[a+120>>2]=dX(c[a+52>>2]|0)|0;c[a+124>>2]=dX(c[a+56>>2]|0)|0;c[a+128>>2]=dX(c[a+60>>2]|0)|0;d=16;e=b;while(1){b=c[a+68+(d-15<<2)>>2]|0;f=c[a+68+(d-2<<2)>>2]|0;c[a+68+(d<<2)>>2]=(c[a+68+(d-7<<2)>>2]|0)+e+((b>>>18|b<<14)^b>>>3^(b>>>7|b<<25))+((f>>>19|f<<13)^f>>>10^(f>>>17|f<<15));f=d+1|0;if(f>>>0<64){d=f;e=b}else{break}}e=a+324|0;d=c[e>>2]|0;b=a+328|0;f=c[b>>2]|0;g=a+332|0;h=c[g>>2]|0;i=a+336|0;j=c[i>>2]|0;k=a+340|0;l=c[k>>2]|0;m=a+344|0;n=c[m>>2]|0;o=a+348|0;p=c[o>>2]|0;q=a+352|0;r=c[q>>2]|0;s=f;t=h;u=j;v=l;w=n;x=p;y=r;z=d;A=0;while(1){B=(x&~v^v&w)+y+((v>>>6|v<<26)^(v>>>11|v<<21)^(v>>>25|v<<7))+(c[101424+(A<<2)>>2]|0)+(c[a+68+(A<<2)>>2]|0)|0;C=B+u|0;D=((s^t)&z^s&t)+((z>>>2|z<<30)^(z>>>13|z<<19)^(z>>>22|z<<10))+B|0;B=A+1|0;if(B>>>0<64){u=t;t=s;s=z;y=x;x=w;w=v;v=C;z=D;A=B}else{break}}c[e>>2]=D+d;c[b>>2]=z+f;c[g>>2]=s+h;c[i>>2]=t+j;c[k>>2]=C+l;c[m>>2]=v+n;c[o>>2]=w+p;c[q>>2]=x+r;c[a+64>>2]=0;return}function gO(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;e=i;i=i+4096|0;f=e|0;if((b|0)==14|(b|0)==65550){if((a[637400]&1)!=0){g=c[198610]|0;h=(g|0)!=0?g:c[p>>2]|0;a2(51032,34,1,h|0)|0;h=c[198610]|0;g=(h|0)!=0?h:c[p>>2]|0;aY(g|0)|0}g=c[d>>2]|0;do{if((g|0)==0){if((a[637400]&1)==0){break}h=c[198610]|0;j=(h|0)!=0?h:c[p>>2]|0;a2(50216,37,1,j|0)|0;j=c[198610]|0;h=(j|0)!=0?j:c[p>>2]|0;aY(h|0)|0}else if((g|0)==2){if((a[637400]&1)!=0){h=c[198610]|0;j=(h|0)!=0?h:c[p>>2]|0;a2(49360,41,1,j|0)|0;j=c[198610]|0;h=(j|0)!=0?j:c[p>>2]|0;aY(h|0)|0}c[199305]=72}else if((g|0)==1|(g|0)==3){h=c[198610]|0;a2(48520,116,1,((h|0)!=0?h:c[p>>2]|0)|0)|0;h=c[198610]|0;aY(((h|0)!=0?h:c[p>>2]|0)|0)|0;k=0;i=e;return k|0}else{if((a[637400]&1)==0){k=0;i=e;return k|0}h=c[198610]|0;a2(47640,39,1,((h|0)!=0?h:c[p>>2]|0)|0)|0;h=c[198610]|0;aY(((h|0)!=0?h:c[p>>2]|0)|0)|0;k=0;i=e;return k|0}}while(0);c[d+8>>2]=14;c[d+12>>2]=24;if((b&65536|0)==0){X5(736412,d|0,40)|0;k=1;i=e;return k|0}else{c[184103]=c[d>>2];c[736416>>2]=c[d+4>>2];c[736420>>2]=c[d+8>>2];c[736424>>2]=c[d+12>>2];a[736428|0]=a[d+16|0]|0;k=1;i=e;return k|0}}else if((b|0)==18){g=a[d]|0;if((a[637400]&1)==0){l=g&1}else{h=c[198610]|0;j=(h|0)!=0?h:c[p>>2]|0;h=g&1;g=h<<24>>24!=0?45440:44840;ec(j|0,46208,(m=i,i=i+8|0,c[m>>2]=g,m)|0)|0;i=m;g=c[198610]|0;j=(g|0)!=0?g:c[p>>2]|0;aY(j|0)|0;l=h}a[731766]=l;k=1;i=e;return k|0}else if((b|0)==19){c[d>>2]=0;k=1;i=e;return k|0}else if((b|0)==21){if((a[637400]&1)!=0){l=c[198610]|0;h=(l|0)!=0?l:c[p>>2]|0;a2(44232,44,1,h|0)|0;h=c[198610]|0;l=(h|0)!=0?h:c[p>>2]|0;aY(l|0)|0}c[184114]=c[d>>2];c[736460>>2]=c[d+4>>2];c[736464>>2]=c[d+8>>2];c[736468>>2]=c[d+12>>2];k=1;i=e;return k|0}else if((b|0)==12){if((a[637400]&1)!=0){l=c[198610]|0;h=(l|0)!=0?l:c[p>>2]|0;a2(52768,42,1,h|0)|0;h=c[198610]|0;l=(h|0)!=0?h:c[p>>2]|0;aY(l|0)|0}c[184094]=c[d>>2];k=1;i=e;return k|0}else if((b|0)==13){if((a[637400]&1)!=0){l=c[198610]|0;h=(l|0)!=0?l:c[p>>2]|0;a2(51936,47,1,h|0)|0;h=c[198610]|0;l=(h|0)!=0?h:c[p>>2]|0;aY(l|0)|0}c[184096]=c[d>>2];c[736388>>2]=c[d+4>>2];c[736392>>2]=c[d+8>>2];c[736396>>2]=c[d+12>>2];c[736400>>2]=c[d+16>>2];c[736404>>2]=c[d+20>>2];c[736408>>2]=c[d+24>>2];k=1;i=e;return k|0}else if((b|0)==9){c[d>>2]=(a[629148]|0)!=0?629148:0;if((a[637400]&1)==0){k=1;i=e;return k|0}l=c[198610]|0;ec(((l|0)!=0?l:c[p>>2]|0)|0,89888,(m=i,i=i+8|0,c[m>>2]=629148,m)|0)|0;i=m;l=c[198610]|0;aY(((l|0)!=0?l:c[p>>2]|0)|0)|0;k=1;i=e;return k|0}else if((b|0)==17){l=c[184120]|0;if((l|0)==0){n=0}else{n=a[l+4108|0]&1}a[d]=n;k=1;i=e;return k|0}else if((b|0)==11){X2(731768,0,512);n=c[d+16>>2]|0;if((n|0)!=0){l=d;h=n;while(1){n=c[l>>2]|0;do{if(n>>>0<=7){if((c[l+4>>2]|0)!=1){break}j=c[l+12>>2]|0;if(j>>>0>15){break}c[731768+(n<<6)+(j<<2)>>2]=h}}while(0);n=c[l+36>>2]|0;if((n|0)==0){break}else{l=l+20|0;h=n}}}if((a[637400]&1)==0){o=0}else{h=c[198610]|0;l=(h|0)!=0?h:c[p>>2]|0;a2(54544,42,1,l|0)|0;l=c[198610]|0;h=(l|0)!=0?l:c[p>>2]|0;aY(h|0)|0;o=0}while(1){h=o+1|0;l=0;do{n=c[731768+(o<<6)+(l<<2)>>2]|0;do{if((n|0)!=0){if((a[637400]&1)==0){break}j=c[198610]|0;g=(j|0)!=0?j:c[p>>2]|0;j=c[15424+(l<<2)>>2]|0;ec(g|0,53656,(m=i,i=i+24|0,c[m>>2]=h,c[m+8>>2]=j,c[m+16>>2]=n,m)|0)|0;i=m;j=c[198610]|0;g=(j|0)!=0?j:c[p>>2]|0;aY(g|0)|0}}while(0);l=l+1|0;}while(l>>>0<16);if(h>>>0<8){o=h}else{k=1;break}}i=e;return k|0}else if((b|0)==1){o=c[d>>2]|0;if((a[637400]&1)!=0){l=c[198610]|0;n=(l|0)!=0?l:c[p>>2]|0;ec(n|0,20816,(m=i,i=i+8|0,c[m>>2]=o,m)|0)|0;i=m;n=c[198610]|0;l=(n|0)!=0?n:c[p>>2]|0;aY(l|0)|0}if((a[551540]&1)==0){k=1;i=e;return k|0}c[182937]=o;l=c[199305]|0;if((l|0)==0){k=0;i=e;return k|0}n=c[l+40>>2]|0;if((n|0)==0){k=0;i=e;return k|0}l=c[199308]|0;if((l|0)==0){k=1;i=e;return k|0}fc[n&127](l,o);k=1;i=e;return k|0}else if((b|0)==6){if((a[637400]&1)!=0){o=c[198610]|0;l=(o|0)!=0?o:c[p>>2]|0;o=c[d>>2]|0;ec(l|0,24648,(m=i,i=i+8|0,c[m>>2]=o,m)|0)|0;i=m;o=c[198610]|0;l=(o|0)!=0?o:c[p>>2]|0;aY(l|0)|0}l=c[196481]|0;if((l|0)==0){k=1;i=e;return k|0}o=l+4|0;n=c[o>>2]|0;if(n>>>0>1){g=l|0;j=1;q=n;while(1){n=c[(c[g>>2]|0)+(j<<2)>>2]|0;if((n|0)==0){r=q}else{XZ(c[n+8>>2]|0);XZ(c[(c[g>>2]|0)+(j<<2)>>2]|0);c[(c[g>>2]|0)+(j<<2)>>2]=0;r=c[o>>2]|0}n=j+1|0;if(n>>>0<r>>>0){j=n;q=r}else{break}}}c[o>>2]=1;o=l+12|0;XZ(c[o>>2]|0);c[o>>2]=0;o=c[196481]|0;l=c[d>>2]|0;r=o+4|0;q=c[r>>2]|0;if(q>>>0>=(c[o+8>>2]|0)>>>0){k=1;i=e;return k|0}j=c[d+4>>2]|0;g=XY(12)|0;do{if((g|0)!=0){if((c[g-4>>2]&3|0)==0){break}X2(g|0,0,12)}}while(0);c[g+4>>2]=1;c[g>>2]=j;if((l|0)==0){s=0;t=q}else{q=dq(l|0)|0;s=q;t=c[r>>2]|0}c[g+8>>2]=s;s=o|0;c[(c[s>>2]|0)+(t<<2)>>2]=g;g=c[r>>2]|0;c[r>>2]=g+1;if(g>>>0>1){u=g}else{k=1;i=e;return k|0}while(1){g=u>>>1;r=c[s>>2]|0;t=r+(g<<2)|0;o=c[t>>2]|0;q=c[r+(u<<2)>>2]|0;if((c[q+4>>2]|0)>>>0<=(c[o+4>>2]|0)>>>0){k=1;v=2790;break}c[t>>2]=q;c[(c[s>>2]|0)+(u<<2)>>2]=o;if(u>>>0>3){u=g}else{k=1;v=2791;break}}if((v|0)==2790){i=e;return k|0}else if((v|0)==2791){i=e;return k|0}}else if((b|0)==3){a[d]=1;if((a[637400]&1)==0){k=1;i=e;return k|0}u=c[198610]|0;a2(59304,38,1,((u|0)!=0?u:c[p>>2]|0)|0)|0;u=c[198610]|0;aY(((u|0)!=0?u:c[p>>2]|0)|0)|0;k=1;i=e;return k|0}else if((b|0)==10){u=c[d>>2]|0;do{if((u|0)==2){if((a[637400]&1)==0){break}s=c[198610]|0;g=(s|0)!=0?s:c[p>>2]|0;a2(83312,45,1,g|0)|0;g=c[198610]|0;s=(g|0)!=0?g:c[p>>2]|0;aY(s|0)|0}else if((u|0)==1){if((a[637400]&1)==0){break}s=c[198610]|0;a2(79840,47,1,((s|0)!=0?s:c[p>>2]|0)|0)|0;s=c[198610]|0;aY(((s|0)!=0?s:c[p>>2]|0)|0)|0}else if((u|0)==0){if((a[637400]&1)==0){break}s=c[198610]|0;a2(86760,47,1,((s|0)!=0?s:c[p>>2]|0)|0)|0;s=c[198610]|0;aY(((s|0)!=0?s:c[p>>2]|0)|0)|0}else{k=0;i=e;return k|0}}while(0);c[182940]=u;k=1;i=e;return k|0}else if((b|0)==2){a[d]=a[535098]&1^1;if((a[637400]&1)==0){k=1;i=e;return k|0}u=c[198610]|0;ec(((u|0)!=0?u:c[p>>2]|0)|0,76152,(m=i,i=i+8|0,c[m>>2]=(a[535098]&1^1)&255,m)|0)|0;i=m;u=c[198610]|0;aY(((u|0)!=0?u:c[p>>2]|0)|0)|0;k=1;i=e;return k|0}else if((b|0)==7){if((a[637400]&1)!=0){u=c[198610]|0;s=(u|0)!=0?u:c[p>>2]|0;a2(98272,29,1,s|0)|0;s=c[198610]|0;u=(s|0)!=0?s:c[p>>2]|0;aY(u|0)|0}a[731752]=1;k=1;i=e;return k|0}else if((b|0)==8){u=c[d>>2]|0;c[182939]=u;if((a[637400]&1)==0){k=1;i=e;return k|0}s=c[198610]|0;ec(((s|0)!=0?s:c[p>>2]|0)|0,93744,(m=i,i=i+8|0,c[m>>2]=u,m)|0)|0;i=m;u=c[198610]|0;aY(((u|0)!=0?u:c[p>>2]|0)|0)|0;k=1;i=e;return k|0}else if((b|0)==16){if((a[637400]&1)!=0){u=c[198610]|0;s=(u|0)!=0?u:c[p>>2]|0;a2(33008,34,1,s|0)|0;s=c[198610]|0;u=(s|0)!=0?s:c[p>>2]|0;aY(u|0)|0}u=c[184120]|0;if((u|0)!=0){s=u+4104|0;if((c[s>>2]|0)==0){w=u|0}else{g=u+4100|0;o=u|0;q=0;while(1){t=c[g>>2]|0;gK(c[o>>2]|0,c[t+(q<<4)+4>>2]|0,c[(c[c[t+(q<<4)+8>>2]>>2]|0)+(c[t+(q<<4)+12>>2]<<3)>>2]|0);t=q+1|0;if(t>>>0<(c[s>>2]|0)>>>0){q=t}else{w=o;break}}}o=c[w>>2]|0;w=u+4|0;gL(o,w)|0;hn(c[184120]|0)}w=d;if((a[604568]|0)!=0|(a[657930]|0)==0){x=604568}else{o=f|0;gB(o,657930,28744);x=o}o=XY(4112)|0;L3861:do{if((o|0)==0){y=0}else{if((c[o-4>>2]&3|0)!=0){X2(o|0,0,4112)}f=o;if((a[x]|0)==0){z=c[o>>2]|0}else{u=gH(x,0)|0;c[o>>2]=u;z=u}u=o;if((z|0)==0){q=XY(20)|0;do{if((q|0)!=0){if((c[q-4>>2]&3|0)==0){break}X2(q|0,0,20)}}while(0);c[u>>2]=q}h=4096;s=o+4|0;g=x;while(1){t=h-1|0;if((t|0)==0){v=2641;break}r=a[g]|0;a[s]=r;if(r<<24>>24==0){break}else{h=t;s=s+1|0;g=g+1|0}}do{if((v|0)==2641){a[s]=0;if((a[g]|0)==0){break}else{A=g}do{A=A+1|0;}while((a[A]|0)!=0)}}while(0);do{if((c[u>>2]|0)!=0){g=d;s=c[g>>2]|0;h=(s|0)==0;do{if(h){B=0;C=0}else{q=0;t=w;while(1){if((c[t+4>>2]|0)==0){D=q;break}r=q+1|0;l=t+8|0;if((c[l>>2]|0)==0){D=r;break}else{q=r;t=l}}if((D|0)==0){B=0;C=0;break}t=D<<4;if(D>>>0<=65535){B=t;C=D;break}B=((t>>>0)/(D>>>0)|0|0)==16?t:-1;C=D}}while(0);t=XY(B)|0;if((t|0)==0){c[o+4100>>2]=0;break}if((c[t-4>>2]&3|0)==0){q=o+4100|0;c[q>>2]=t;E=q}else{X2(t|0,0,B|0);q=o+4100|0;c[q>>2]=t;E=q}c[o+4104>>2]=C;if(h){y=f;break L3861}else{F=0;G=g;H=s}while(1){q=G+4|0;if((c[q>>2]|0)==0){y=f;break L3861}t=c[E>>2]|0;l=t+(F<<4)+4|0;c[l>>2]=dq(H|0)|0;I=dq(c[q>>2]|0)|0;q=bu(I|0,99200)|0;if((q|0)==0){v=2658;break}a[q]=0;r=t+(F<<4)|0;c[r>>2]=dq(I|0)|0;j=gp(q+2|0,93176)|0;q=t+(F<<4)+8|0;c[q>>2]=j;if((j|0)==0){v=2660;break}j=c[l>>2]|0;n=(c[u>>2]|0)+4|0;while(1){J=c[n>>2]|0;if((J|0)==0){break}if((cL(j|0,c[J+4>>2]|0)|0)==0){v=2664;break}else{n=J+12|0}}if((v|0)==2664){v=0;n=dq(c[J+8>>2]|0)|0;j=c[q>>2]|0;K=c[j+4>>2]|0;L=j|0;j=0;while(1){if(j>>>0>=K>>>0){break}if((cL(c[(c[L>>2]|0)+(j<<3)>>2]|0,n|0)|0)==0){v=2667;break}else{j=j+1|0}}if((v|0)==2667){v=0;c[t+(F<<4)+12>>2]=j}XZ(n)}XZ(I);L=a[637400]|0;if((L&1)==0){M=L}else{L=c[198610]|0;K=(L|0)!=0?L:c[p>>2]|0;a2(67464,24,1,K|0)|0;K=c[198610]|0;L=(K|0)!=0?K:c[p>>2]|0;aY(L|0)|0;M=a[637400]|0}if((M&1)==0){N=M}else{L=c[198610]|0;K=(L|0)!=0?L:c[p>>2]|0;L=c[r>>2]|0;ec(K|0,56504,(m=i,i=i+8|0,c[m>>2]=L,m)|0)|0;i=m;L=c[198610]|0;K=(L|0)!=0?L:c[p>>2]|0;aY(K|0)|0;N=a[637400]|0}if((N&1)==0){O=N}else{K=c[198610]|0;L=(K|0)!=0?K:c[p>>2]|0;K=c[l>>2]|0;ec(L|0,47448,(m=i,i=i+8|0,c[m>>2]=K,m)|0)|0;i=m;K=c[198610]|0;L=(K|0)!=0?K:c[p>>2]|0;aY(L|0)|0;O=a[637400]|0}if((O&1)==0){P=O}else{L=c[198610]|0;K=(L|0)!=0?L:c[p>>2]|0;L=c[E>>2]|0;Q=c[(c[c[L+(F<<4)+8>>2]>>2]|0)+(c[L+(F<<4)+12>>2]<<3)>>2]|0;ec(K|0,40496,(m=i,i=i+8|0,c[m>>2]=Q,m)|0)|0;i=m;Q=c[198610]|0;K=(Q|0)!=0?Q:c[p>>2]|0;aY(K|0)|0;P=a[637400]|0}if((P&1)!=0){K=c[198610]|0;Q=(K|0)!=0?K:c[p>>2]|0;a2(35800,29,1,Q|0)|0;Q=c[198610]|0;K=(Q|0)!=0?Q:c[p>>2]|0;aY(K|0)|0}K=c[q>>2]|0;if((c[K+4>>2]|0)!=0){Q=0;L=K;while(1){if((a[637400]&1)==0){R=L}else{K=c[198610]|0;S=(K|0)!=0?K:c[p>>2]|0;K=c[(c[L>>2]|0)+(Q<<3)>>2]|0;ec(S|0,31160,(m=i,i=i+8|0,c[m>>2]=K,m)|0)|0;i=m;K=c[198610]|0;S=(K|0)!=0?K:c[p>>2]|0;aY(S|0)|0;R=c[q>>2]|0}S=Q+1|0;if(S>>>0<(c[R+4>>2]|0)>>>0){Q=S;L=R}else{break}}}L=G+8|0;Q=c[L>>2]|0;if((Q|0)==0){y=f;break L3861}else{F=F+1|0;G=L;H=Q}}if((v|0)==2660){XZ(I);break}else if((v|0)==2658){XZ(I);break}}}while(0);hn(f);y=0}}while(0);c[184120]=y;k=1;i=e;return k|0}else if((b|0)==15){if((a[637400]&1)!=0){y=c[198610]|0;I=(y|0)!=0?y:c[p>>2]|0;y=c[d>>2]|0;ec(I|0,50952,(m=i,i=i+8|0,c[m>>2]=y,m)|0)|0;i=m;y=c[198610]|0;I=(y|0)!=0?y:c[p>>2]|0;aY(I|0)|0}I=c[184120]|0;do{if((I|0)==0){c[d+4>>2]=0;T=0}else{a[I+4108|0]=0;y=c[I+4104>>2]|0;H=I+4100|0;G=d;F=0;while(1){if(F>>>0>=y>>>0){v=2610;break}U=c[H>>2]|0;if((cL(c[U+(F<<4)+4>>2]|0,c[G>>2]|0)|0)==0){v=2609;break}else{F=F+1|0}}if((v|0)==2609){G=c[(c[c[U+(F<<4)+8>>2]>>2]|0)+(c[U+(F<<4)+12>>2]<<3)>>2]|0;c[d+4>>2]=G;T=G;break}else if((v|0)==2610){c[d+4>>2]=0;T=0;break}}}while(0);if((a[637400]&1)==0){k=1;i=e;return k|0}d=c[198610]|0;ec(((d|0)!=0?d:c[p>>2]|0)|0,42680,(m=i,i=i+8|0,c[m>>2]=(T|0)==0?30848:T,m)|0)|0;i=m;T=c[198610]|0;aY(((T|0)!=0?T:c[p>>2]|0)|0)|0;k=1;i=e;return k|0}else{if((a[637400]&1)==0){k=0;i=e;return k|0}T=c[198610]|0;ec(((T|0)!=0?T:c[p>>2]|0)|0,43408,(m=i,i=i+8|0,c[m>>2]=b,m)|0)|0;i=m;m=c[198610]|0;aY(((m|0)!=0?m:c[p>>2]|0)|0)|0;k=0;i=e;return k|0}return 0}function gP(){return 1}function gQ(a,b){a=a|0;b=b|0;return}function gR(a){a=a|0;c[198908]=a;return}function gS(a){a=a|0;c[198910]=a;return}function gT(a){a=a|0;c[198904]=a;return}function gU(a){a=a|0;c[198902]=a;return}function gV(a){a=a|0;c[198900]=a;return}function gW(){return}function gX(a){a=a|0;return 0}function gY(){return}function gZ(){return 0}function g_(a,b,c){a=a|0;b=b|0;c=c|0;return 0}function g$(){return 0}function g0(a,b){a=a|0;b=b|0;return 0}function g1(a,b){a=a|0;b=b|0;return 0}function g2(a){a=a|0;return 0}function g3(a){a=a|0;return 0}function g4(){return}function g5(a,b,c){a=a|0;b=b|0;c=c|0;return}function g6(a){a=a|0;h[a+24>>3]=60.0;h[a+32>>3]=3.0e4;c[a>>2]=320;c[a+4>>2]=240;c[a+8>>2]=320;c[a+12>>2]=240;g[a+16>>2]=1.3333333730697632;return}function g7(){var a=0;a=XY(153600)|0;do{if((a|0)!=0){if((c[a-4>>2]&3|0)==0){break}X2(a|0,0,153600)}}while(0);c[198892]=a;return}function g8(){XZ(c[198892]|0);c[198892]=0;return}function g9(b){b=b|0;X2(b|0,0,16);c[b>>2]=68640;c[b+4>>2]=798256;a[b+12|0]=0;c[b+8>>2]=798256;return}function ha(a){a=a|0;var b=0,d=0;b=i;i=i+8|0;d=b|0;c[198906]=a;c[d>>2]=2;ft[a&63](10,d)|0;i=b;return}function hb(){var a=0,d=0;fz[c[198904]&8191]();a=c[198892]|0;d=0;do{b[a+(d<<1)>>1]=128;d=d+1|0;}while(d>>>0<76800);fA[c[198900]&127](a,320,240,640);return}function hc(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0;b=a+4|0;if((c[b>>2]|0)==1){d=0;return d|0}e=a|0;f=c[(c[e>>2]|0)+4>>2]|0;g=f|0;h=(c[g>>2]|0)-1|0;c[g>>2]=h;if((h|0)!=0){d=c[f+8>>2]|0;return d|0}h=a+12|0;XZ(c[h>>2]|0);a=f+8|0;c[h>>2]=c[a>>2];c[a>>2]=0;a=c[e>>2]|0;f=a+4|0;g=c[f>>2]|0;i=(c[b>>2]|0)-1|0;c[b>>2]=i;c[f>>2]=c[a+(i<<2)>>2];XZ(g);g=1;while(1){i=g<<1;a=c[b>>2]|0;if(i>>>0>a>>>0){j=0}else{f=c[e>>2]|0;j=(c[f+(g<<2)>>2]|0)>>>0<(c[f+(i<<2)>>2]|0)>>>0}f=i|1;if(f>>>0>a>>>0){k=0}else{a=c[e>>2]|0;k=(c[a+(g<<2)>>2]|0)>>>0<(c[a+(f<<2)>>2]|0)>>>0}if(!(j|k)){break}do{if(k|j^1){if(!(j|k^1)){l=f;break}a=c[e>>2]|0;l=(c[a+(i<<2)>>2]|0)>>>0<(c[a+(f<<2)>>2]|0)>>>0?f:i}else{l=i}}while(0);i=c[e>>2]|0;f=i+(g<<2)|0;a=c[f>>2]|0;c[f>>2]=c[i+(l<<2)>>2];c[(c[e>>2]|0)+(l<<2)>>2]=a;g=l}d=c[h>>2]|0;return d|0}function hd(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;e=i;i=i+16|0;f=e|0;g=f|0;h=f;j=XY(36)|0;if((j|0)==0){k=0;i=e;return k|0}if((c[j-4>>2]&3|0)!=0){X2(j|0,0,36)}l=j;m=f;L4027:do{if((d|0)==0){a[j+24|0]=1;n=c5(b|0,23072)|0;c[j>>2]=n;if((n|0)==0){o=c[198610]|0;q=(o|0)!=0?o:c[p>>2]|0;ec(q|0,50032,(r=i,i=i+8|0,c[r>>2]=b,r)|0)|0;i=r;q=c[198610]|0;o=(q|0)!=0?q:c[p>>2]|0;aY(o|0)|0;break}X2(m|0,0,16);if((d6(m|0,4,4,n|0)|0)!=4){o=c[198610]|0;q=(o|0)!=0?o:c[p>>2]|0;a2(41984,49,1,q|0)|0;q=c[198610]|0;o=(q|0)!=0?q:c[p>>2]|0;aY(o|0)|0;s=n;t=2888;break}o=c[f>>2]|0;if(!((o|0)==1112757809|(o|0)==827740994)){o=c[198610]|0;q=(o|0)!=0?o:c[p>>2]|0;a2(36976,58,1,q|0)|0;q=c[198610]|0;o=(q|0)!=0?q:c[p>>2]|0;aY(o|0)|0;u=n;t=2887;break}if((c[f+8>>2]|0)!=(c[160385]|0)){o=c[198610]|0;q=(o|0)!=0?o:c[p>>2]|0;a2(32344,151,1,q|0)|0;q=c[198610]|0;o=(q|0)!=0?q:c[p>>2]|0;aY(o|0)|0}o=c[h+12>>2]|0;do{if((o|0)!=0){q=XY(o)|0;c[j+4>>2]=q;c[j+8>>2]=o;if((q|0)==0){u=n;t=2887;break L4027}if((d6(q|0,1,o|0,n|0)|0)!=(o|0)){v=c[198610]|0;w=(v|0)!=0?v:c[p>>2]|0;a2(28304,53,1,w|0)|0;w=c[198610]|0;v=(w|0)!=0?w:c[p>>2]|0;aY(v|0)|0;u=n;t=2887;break L4027}if((fw[c[59478]&31]()|0)==(o|0)){v=c[59460]|0;ft[v&63](q,o)|0;break}else{q=c[198610]|0;v=(q|0)!=0?q:c[p>>2]|0;a2(24144,102,1,v|0)|0;v=c[198610]|0;q=(v|0)!=0?v:c[p>>2]|0;aY(q|0)|0;break}}}while(0);q=o+16|0;c[j+28>>2]=q;x=n;y=q;t=2882}else{q=c5(b|0,85512)|0;c[j>>2]=q;if((q|0)==0){v=c[198610]|0;w=(v|0)!=0?v:c[p>>2]|0;ec(w|0,72560,(r=i,i=i+8|0,c[r>>2]=b,r)|0)|0;i=r;w=c[198610]|0;v=(w|0)!=0?w:c[p>>2]|0;aY(v|0)|0;break}c[g>>2]=0;c[g+4>>2]=0;c[f>>2]=827740994;c[f+8>>2]=c[160385];v=fw[c[59478]&31]()|0;c[h+12>>2]=v;a2(m|0,4,4,q|0)|0;w=v+16|0;c[j+28>>2]=w;c[j+8>>2]=v;if((v|0)==0){x=q;y=w;t=2882;break}z=XY(v)|0;c[j+4>>2]=z;if((z|0)==0){u=q;t=2887;break}A=c[59480]|0;ft[A&63](z,v)|0;a2(z|0,1,v|0,q|0)|0;x=q;y=w;t=2882}}while(0);do{if((t|0)==2882){m=XY(4194304)|0;if((m|0)==0){c[j+12>>2]=0;u=x;t=2887;break}if((c[m-4>>2]&3|0)!=0){X2(m|0,0,4194304)}h=m;c[j+12>>2]=h;c[h>>2]=y;c[j+16>>2]=1048575;k=l;i=e;return k|0}}while(0);if((t|0)==2887){if((u|0)!=0){s=u;t=2888}}if((t|0)==2888){aQ(s|0)|0}XZ(c[j+4>>2]|0);XZ(c[j+12>>2]|0);XZ(j);k=0;i=e;return k|0}function he(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=i;i=i+128|0;h=g+64|0;bN(h|0,64,73800,(j=i,i=i+16|0,c[j>>2]=d,c[j+8>>2]=e,j)|0)|0;i=j;j=g|0;e=b+4|0;while(1){k=c[e>>2]|0;if((k|0)==0){l=2912;break}if((cL(h|0,c[k+4>>2]|0)|0)==0){break}else{e=k+12|0}}if((l|0)==2912){i=g;return}e=64;h=0;b=j;d=c[k+8>>2]|0;while(1){k=e-1|0;if((k|0)==0){l=2900;break}m=a[d]|0;a[b]=m;if(m<<24>>24==0){n=h;break}else{e=k;h=h+1|0;b=b+1|0;d=d+1|0}}do{if((l|0)==2900){a[b]=0;if((a[d]|0)==0){n=h;break}else{o=d;p=h}while(1){e=o+1|0;k=p+1|0;if((a[e]|0)==0){n=k;break}else{o=e;p=k}}}}while(0);if(n>>>0>=64){i=g;return}do{if((X1(j|0)|0)==1){n=a[j]|0;if((dk(n|0)|0)==0){q=0;l=2906;break}r=X6(n|0)|0}else{q=0;l=2906}}while(0);L4093:do{if((l|0)==2906){while(1){l=0;if((q|0)==67){r=0;break L4093}if((X8(c[7840+(q<<3)>>2]|0,j|0)|0)==0){break}else{q=q+1|0;l=2906}}r=c[7844+(q<<3)>>2]|0}}while(0);c[f+12>>2]=r;i=g;return}function hf(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0;g=i;i=i+136|0;h=g|0;j=g+8|0;k=g+72|0;bN(k|0,64,73304,(l=i,i=i+16|0,c[l>>2]=d,c[l+8>>2]=e,l)|0)|0;i=l;l=j|0;e=b+4|0;while(1){m=c[e>>2]|0;if((m|0)==0){n=2938;break}if((cL(k|0,c[m+4>>2]|0)|0)==0){break}else{e=m+12|0}}if((n|0)==2938){i=g;return}e=64;k=0;b=l;d=c[m+8>>2]|0;while(1){m=e-1|0;if((m|0)==0){n=2920;break}o=a[d]|0;a[b]=o;if(o<<24>>24==0){q=k;break}else{e=m;k=k+1|0;b=b+1|0;d=d+1|0}}do{if((n|0)==2920){a[b]=0;if((a[d]|0)==0){q=k;break}else{r=d;s=k}while(1){e=r+1|0;m=s+1|0;if((a[e]|0)==0){q=m;break}else{r=e;s=m}}}}while(0);if(q>>>0>=64){i=g;return}if((cL(l|0,74016)|0)==0){q=f+16|0;c[q>>2]=65535;c[q+4>>2]=0;i=g;return}if((a[l]|0)!=104){q=aW(l|0,0,0)|0;l=f+16|0;c[l>>2]=q;c[l+4>>2]=F;i=g;return}l=j+1|0;if(((a[l]|0)-48|0)>>>0>=10){i=g;return}c[h>>2]=0;j=aV(l|0,h|0,0)|0;l=c[h>>2]|0;if((l|0)==0){h=c[198610]|0;q=(h|0)!=0?h:c[p>>2]|0;a2(70768,49,1,q|0)|0;q=c[198610]|0;h=(q|0)!=0?q:c[p>>2]|0;aY(h|0)|0;i=g;return}do{if((X8(l|0,55248)|0)==0){t=-32768}else{if((X8(l|0,54368)|0)==0){t=16384;break}if((X8(l|0,53480)|0)==0){t=8192;break}h=(X8(l|0,52624)|0)==0;if(h){t=h?4096:0;break}i=g;return}}while(0);l=f+16|0;c[l>>2]=t&65535|j&4095;c[l+4>>2]=0;i=g;return}function hg(b,d,e,f){b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;g=i;i=i+128|0;h=g|0;j=g+64|0;bN(j|0,64,73096,(k=i,i=i+16|0,c[k>>2]=d,c[k+8>>2]=e,k)|0)|0;i=k;k=h|0;e=b+4|0;while(1){l=c[e>>2]|0;if((l|0)==0){m=2964;break}if((cL(j|0,c[l+4>>2]|0)|0)==0){break}else{e=l+12|0}}if((m|0)==2964){i=g;return}e=64;j=0;b=k;d=c[l+8>>2]|0;while(1){l=e-1|0;if((l|0)==0){m=2950;break}n=a[d]|0;a[b]=n;if(n<<24>>24==0){o=j;break}else{e=l;j=j+1|0;b=b+1|0;d=d+1|0}}do{if((m|0)==2950){a[b]=0;if((a[d]|0)==0){o=j;break}else{p=d;q=j}while(1){e=p+1|0;l=q+1|0;if((a[e]|0)==0){o=l;break}else{p=e;q=l}}}}while(0);if(o>>>0>=64){i=g;return}if((cL(k|0,74016)|0)==0){c[f+32>>2]=-1;i=g;return}if((X1(k|0)|0)>>>0<=1){i=g;return}o=a[k]|0;if(!((o<<24>>24|0)==43|(o<<24>>24|0)==45)){i=g;return}o=a$(h+1|0,0,0)|0;if((a[k]|0)==43){c[f+32>>2]=o|-65536;i=g;return}else{c[f+32>>2]=o<<16|65535;i=g;return}}function hh(){var a=0,b=0,d=0,e=0,f=0;a=XY(48)|0;if((a|0)==0){b=0;return b|0}if((c[a-4>>2]&3|0)!=0){X2(a|0,0,48)}d=bm()|0;c[a+44>>2]=d;if((d|0)==0){XZ(a);b=0;return b|0}X2(236048,0,1292);d=6024;e=276;while(1){c[236048+(e<<2)>>2]=c[d>>2];f=c[d+12>>2]|0;if((f|0)==0){b=a;break}else{d=d+8|0;e=f}}return b|0}function hi(a){a=a|0;var b=0;b=ci(c[a+44>>2]|0)|0;X5(a|0,b|0,44)|0;return}function hj(a,b){a=a|0;b=b|0;return}function hk(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0;g=b;do{if((f|0)==2){if((h|0)==1){i=c[b+36>>2]&65535;break}else if((h|0)==3){i=a[b+41|0]|0;break}else if((h|0)==0){i=c[b+32>>2]&65535;break}else if((h|0)==2){i=a[b+40|0]|0;break}else{i=0;break}}else if((f|0)==1){j=c[d+(e<<2)>>2]|0;if(h>>>0>=56){i=0;break}if((a[j+(h*40|0)|0]&1)==0){i=0;break}k=c[j+(h*40|0)+12>>2]|0;if((k|0)>322){i=0;break}j=c[236048+(k<<2)>>2]|0;i=(a[g+(j>>>3)|0]&1<<(j&7)|0)!=0|0}else if((f|0)==3){if((h|0)>322){i=0;break}j=c[236048+(h<<2)>>2]|0;i=(a[g+(j>>>3)|0]&1<<(j&7)|0)!=0|0}else{i=0}}while(0);return i|0}function hl(b,d){b=b|0;d=d|0;var e=0,f=0;if(d>>>0>=56){e=0;return e|0}if((a[559896+(d*40|0)|0]&1)==0){e=0;return e|0}f=c[559908+(d*40|0)>>2]|0;if((f|0)>322){e=0;return e|0}d=c[236048+(f<<2)>>2]|0;e=(a[b+(d>>>3)|0]&1<<(d&7)|0)!=0;return e|0}function hm(a){a=a|0;aM(c[a+44>>2]|0);XZ(a);return}function hn(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((a|0)==0){return}b=a+4104|0;if((c[b>>2]|0)!=0){d=a+4100|0;e=0;do{XZ(c[(c[d>>2]|0)+(e<<4)>>2]|0);XZ(c[(c[d>>2]|0)+(e<<4)+4>>2]|0);f=c[(c[d>>2]|0)+(e<<4)+8>>2]|0;if((f|0)!=0){g=f+4|0;h=f|0;i=c[h>>2]|0;if((c[g>>2]|0)==0){j=i}else{k=0;l=i;while(1){XZ(c[l+(k<<3)>>2]|0);i=k+1|0;m=c[h>>2]|0;if(i>>>0<(c[g>>2]|0)>>>0){k=i;l=m}else{j=m;break}}}XZ(j);XZ(f)}e=e+1|0;}while(e>>>0<(c[b>>2]|0)>>>0)}b=c[a>>2]|0;if((b|0)!=0){gF(b)}XZ(c[a+4100>>2]|0);XZ(a);return}function ho(b,e,f,g,h,i){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0;if(e>>>0<19){j=2;return j|0}k=c[i>>2]|0;l=a[b]|0;m=l&255;n=c[15880+((m&15^15)<<2)>>2]^268435455;o=n>>>4^c[15880+((n&15^m>>>4)<<2)>>2];if(l<<24>>24!=66){j=3;return j|0}l=a[b+1|0]|0;m=l&255;n=c[15880+(((m^o)&15)<<2)>>2]^o>>>4;o=n>>>4^c[15880+((n&15^m>>>4)<<2)>>2];if(l<<24>>24!=80){j=3;return j|0}l=a[b+2|0]|0;m=l&255;n=c[15880+(((m^o)&15)<<2)>>2]^o>>>4;o=n>>>4^c[15880+((n&15^m>>>4)<<2)>>2];if(l<<24>>24!=83){j=3;return j|0}l=a[b+3|0]|0;m=l&255;n=c[15880+(((m^o)&15)<<2)>>2]^o>>>4;if(l<<24>>24!=49){j=3;return j|0}l=0;o=0;p=0;q=1;r=n>>>4^c[15880+((n&15^m>>>4)<<2)>>2];m=4;n=7;while(1){s=d[b+m|0]|0;t=c[15880+(((s^r)&15)<<2)>>2]^r>>>4;u=t>>>4^c[15880+((t&15^s>>>4)<<2)>>2];t=m+1|0;v=Yo(s&127,0,q,p)|0;w=Ye(v,F,o,l)|0;if((s&128|0)!=0){x=0;y=0;z=0;A=1;B=u;C=t;D=n;break}s=q<<7|0>>>25;v=p<<7|q>>>25;E=Ye(w,F,s,v)|0;l=F;o=E;p=v;q=s;r=u;m=t;n=n+1|0}while(1){n=d[b+C|0]|0;m=c[15880+(((n^B)&15)<<2)>>2]^B>>>4;r=m>>>4^c[15880+((m&15^n>>>4)<<2)>>2];m=C+1|0;q=Yo(n&127,0,A,z)|0;G=Ye(q,F,y,x)|0;if((n&128|0)!=0){H=0;I=0;J=0;K=1;L=r;M=m;N=D;break}n=A<<7|0>>>25;q=z<<7|A>>>25;p=Ye(G,F,n,q)|0;x=F;y=p;z=q;A=n;B=r;C=m;D=D+1|0}while(1){O=a[b+M|0]|0;D=O&255;C=c[15880+(((D^L)&15)<<2)>>2]^L>>>4;P=C>>>4^c[15880+((C&15^D>>>4)<<2)>>2];Q=M+1|0;C=Yo(D&127,0,K,J)|0;R=Ye(C,F,I,H)|0;if((D&128|0)!=0){break}D=K<<7|0>>>25;C=J<<7|K>>>25;B=Ye(R,F,D,C)|0;H=F;I=B;J=C;K=D;L=P;M=Q;N=N+1|0}M=w;w=G;G=R;if((G|0)==0){S=P;T=Q}else{R=Yo(O&127,0,K,J)|0;J=Ye(R,F,I,H)|0;H=P;P=Q;Q=0;while(1){I=d[b+P|0]|0;R=c[15880+(((I^H)&15)<<2)>>2]^H>>>4;U=R>>>4^c[15880+((R&15^I>>>4)<<2)>>2];I=Q+1|0;if(I>>>0<G>>>0){H=U;P=P+1|0;Q=I}else{break}}S=U;T=J+N|0}if(M>>>0>g>>>0){j=5;return j|0}if(w>>>0>k>>>0){j=6;return j|0}k=e-12|0;e=T;T=0;M=0;N=S;S=-1;J=0;L4274:while(1){U=e;Q=T;P=N;H=S;G=J;while(1){I=U;R=P;V=H;W=G;L4278:while(1){X=I;Y=R;while(1){if(X>>>0<k>>>0){Z=0;_=0;$=0;aa=1;ab=Y;ac=X}else{break L4274}while(1){K=d[b+ac|0]|0;O=c[15880+(((K^ab)&15)<<2)>>2]^ab>>>4;ad=O>>>4^c[15880+((O&15^K>>>4)<<2)>>2];ae=ac+1|0;O=Yo(K&127,0,aa,$)|0;af=Ye(O,F,_,Z)|0;if((K&128|0)!=0){break}K=aa<<7|0>>>25;O=$<<7|aa>>>25;L=Ye(af,F,K,O)|0;Z=F;_=L;$=O;aa=K;ab=ad;ac=ae}ag=af;ah=ag&3;if((ah|0)==0){ai=3052;break}else if((ah|0)==1){ai=3054;break}else if((ah|0)==2|(ah|0)==3){break L4278}else{X=ae;Y=ad}}if((ai|0)==3052){ai=0;K=(ag>>>2)+1|0;O=W;L=V;D=K;while(1){C=a[f+O|0]|0;a[h+O|0]=C;B=C&255;C=c[15880+(((B^L)&15)<<2)>>2]^L>>>4;A=C>>>4^c[15880+((C&15^B>>>4)<<2)>>2];B=D-1|0;if((B|0)==0){aj=ae;ak=ad;al=A;am=K;break}else{O=O+1|0;L=A;D=B}}}else if((ai|0)==3054){ai=0;D=(ag>>>2)+1|0;L=W;O=V;K=ad;B=ae;A=D;while(1){C=A-1|0;z=a[b+B|0]|0;y=z&255;x=c[15880+(((y^K)&15)<<2)>>2]^K>>>4;m=y>>>4;an=x>>>4^c[15880+((x&15^m)<<2)>>2];a[h+L|0]=z;z=c[15880+(((y^O)&15)<<2)>>2]^O>>>4;ao=z>>>4^c[15880+((z&15^m)<<2)>>2];if((C|0)==0){break}else{L=L+1|0;O=ao;K=an;B=B+1|0;A=C}}aj=D+ae|0;ak=an;al=ao;am=D}I=aj;R=ak;V=al;W=am+W|0}ap=(ag>>>2)+1|0;R=0;I=0;A=0;B=1;K=ad;O=ae;while(1){L=d[b+O|0]|0;C=c[15880+(((L^K)&15)<<2)>>2]^K>>>4;aq=C>>>4^c[15880+((C&15^L>>>4)<<2)>>2];ar=O+1|0;C=Yo(L&127,0,B,A)|0;as=Ye(C,F,I,R)|0;if((L&128|0)!=0){break}L=B<<7|0>>>25;C=A<<7|B>>>25;m=Ye(as,F,L,C)|0;R=F;I=m;A=C;B=L;K=aq;O=ar}O=as;K=O>>1;at=(O&1|0)==0?K:-K|0;if((ah|0)!=2){break}K=W;O=V;B=at+Q|0;A=ap;while(1){I=A-1|0;R=a[f+B|0]|0;a[h+K|0]=R;L=R&255;R=c[15880+(((L^O)&15)<<2)>>2]^O>>>4;au=R>>>4^c[15880+((R&15^L>>>4)<<2)>>2];if((I|0)==0){break}else{K=K+1|0;O=au;B=B+1|0;A=I}}U=ar;Q=ap+Q+at|0;P=aq;H=au;G=ap+W|0}G=W;H=V;P=at+M|0;U=ap;while(1){A=U-1|0;B=a[h+P|0]|0;a[h+G|0]=B;O=B&255;B=c[15880+(((O^H)&15)<<2)>>2]^H>>>4;av=B>>>4^c[15880+((B&15^O>>>4)<<2)>>2];if((A|0)==0){break}else{G=G+1|0;H=av;P=P+1|0;U=A}}e=ar;T=Q;M=ap+M+at|0;N=aq;S=av;J=ap+W|0}W=d[b+X|0]|0;ap=c[15880+(((W^Y)&15)<<2)>>2]^Y>>>4;Y=ap>>>4^c[15880+((ap&15^W>>>4)<<2)>>2];ap=d[b+(X+1)|0]|0;J=c[15880+(((ap^Y)&15)<<2)>>2]^Y>>>4;Y=J>>>4^c[15880+((J&15^ap>>>4)<<2)>>2];J=d[b+(X+2)|0]|0;av=c[15880+(((J^Y)&15)<<2)>>2]^Y>>>4;Y=av>>>4^c[15880+((av&15^J>>>4)<<2)>>2];av=d[b+(X+3)|0]|0;S=c[15880+(((av^Y)&15)<<2)>>2]^Y>>>4;Y=S>>>4^c[15880+((S&15^av>>>4)<<2)>>2];S=d[b+(X+4)|0]|0;aq=c[15880+(((S^Y)&15)<<2)>>2]^Y>>>4;Y=aq>>>4^c[15880+((aq&15^S>>>4)<<2)>>2];aq=ap<<8|W|J<<16|av<<24;av=d[b+(X+5)|0]|0;J=c[15880+(((av^Y)&15)<<2)>>2]^Y>>>4;Y=J>>>4^c[15880+((J&15^av>>>4)<<2)>>2];J=d[b+(X+6)|0]|0;W=c[15880+(((J^Y)&15)<<2)>>2]^Y>>>4;Y=W>>>4^c[15880+((W&15^J>>>4)<<2)>>2];W=d[b+(X+7)|0]|0;ap=c[15880+(((W^Y)&15)<<2)>>2]^Y>>>4;Y=~(ap>>>4^c[15880+((ap&15^W>>>4)<<2)>>2]);ap=(d[b+(X+9)|0]|0)<<8|(d[b+(X+8)|0]|0)|(d[b+(X+10)|0]|0)<<16|(d[b+(X+11)|0]|0)<<24;if((f|0)==0|(g|0)==0){aw=0}else{X=g;g=f;f=-1;while(1){b=X-1|0;N=d[g]|0;at=c[15880+(((N^f)&15)<<2)>>2]^f>>>4;ax=at>>>4^c[15880+((at&15^N>>>4)<<2)>>2];if((b|0)==0){break}else{X=b;g=g+1|0;f=ax}}aw=~ax}if((aw|0)!=(aq|0)){j=9;return j|0}if((av<<8|S|J<<16|W<<24|0)!=(~V|0)){j=10;return j|0}if((ap|0)!=(Y|0)){j=11;return j|0}c[i>>2]=w;j=1;return j|0}function hp(b,e,f,g,h,i){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0;j=c[i>>2]|0;if(e>>>0<=17){k=4;return k|0}l=a[b]|0;m=l&255;n=c[15880+((m&15^15)<<2)>>2]^268435455;o=n>>>4^c[15880+((n&15^m>>>4)<<2)>>2];if(l<<24>>24!=85){k=4;return k|0}l=a[b+1|0]|0;m=l&255;n=c[15880+(((m^o)&15)<<2)>>2]^o>>>4;o=n>>>4^c[15880+((n&15^m>>>4)<<2)>>2];if(l<<24>>24!=80){k=4;return k|0}l=a[b+2|0]|0;m=l&255;n=c[15880+(((m^o)&15)<<2)>>2]^o>>>4;o=n>>>4^c[15880+((n&15^m>>>4)<<2)>>2];if(l<<24>>24!=83){k=4;return k|0}l=a[b+3|0]|0;m=l&255;n=c[15880+(((m^o)&15)<<2)>>2]^o>>>4;if(l<<24>>24!=49){k=4;return k|0}l=0;o=0;p=0;q=1;r=4;s=n>>>4^c[15880+((n&15^m>>>4)<<2)>>2];while(1){if(r>>>0<e>>>0){m=d[b+r|0]|0;n=c[15880+(((m^s)&15)<<2)>>2]^s>>>4;t=n>>>4^c[15880+((n&15^m>>>4)<<2)>>2];n=r+1|0;u=Yo(m&127,0,q,p)|0;v=Ye(u,F,o,l)|0;if((m&128|0)==0){w=F;x=v;y=n;z=t}else{A=0;B=0;C=0;D=1;E=n;G=t;break}}else{w=l;x=o;y=r;z=s}t=q<<7|0>>>25;n=p<<7|q>>>25;m=Ye(x,w,t,n)|0;l=F;o=m;p=n;q=t;r=y;s=z}while(1){if(E>>>0<e>>>0){z=d[b+E|0]|0;s=c[15880+(((z^G)&15)<<2)>>2]^G>>>4;H=s>>>4^c[15880+((s&15^z>>>4)<<2)>>2];I=E+1|0;s=Yo(z&127,0,D,C)|0;J=Ye(s,F,B,A)|0;if((z&128|0)==0){K=F;L=J;M=I;N=H}else{break}}else{K=A;L=B;M=E;N=G}z=D<<7|0>>>25;s=C<<7|D>>>25;y=Ye(L,K,z,s)|0;A=F;B=y;C=s;D=z;E=M;G=N}N=v;v=J;J=(N|0)==(g|0);G=(v|0)==(g|0);if(!(J|G)){k=7;return k|0}M=J?v:N;c[i>>2]=M;if(j>>>0<M>>>0){k=6;return k|0}j=e-12|0;if(I>>>0<j>>>0){i=-1;E=-1;D=H;C=0;B=0;A=I;while(1){K=0;L=0;z=0;s=1;y=A;r=D;while(1){if(y>>>0<e>>>0){q=d[b+y|0]|0;p=c[15880+(((q^r)&15)<<2)>>2]^r>>>4;O=p>>>4^c[15880+((p&15^q>>>4)<<2)>>2];P=y+1|0;p=Yo(q&127,0,s,z)|0;Q=Ye(p,F,L,K)|0;if((q&128|0)==0){R=F;S=Q;T=P;U=O}else{break}}else{R=K;S=L;T=y;U=r}q=s<<7|0>>>25;p=z<<7|s>>>25;o=Ye(S,R,q,p)|0;K=F;L=o;z=p;s=q;y=T;r=U}r=Q;if((r|0)==0){V=P;W=B;X=C;Y=O;Z=E;_=i}else{y=i;s=E;z=C;L=B;K=r;while(1){q=K-1|0;if(L>>>0<g>>>0){p=a[f+L|0]|0;o=p&255;l=c[15880+(((o^s)&15)<<2)>>2]^s>>>4;$=p;aa=L+1|0;ab=l>>>4^c[15880+((l&15^o>>>4)<<2)>>2]}else{$=0;aa=L;ab=s}if(z>>>0<M>>>0){a[h+z|0]=$;o=$&255;l=c[15880+(((o^y)&15)<<2)>>2]^y>>>4;ac=l>>>4^c[15880+((l&15^o>>>4)<<2)>>2]}else{ac=y}if((q|0)==0){break}else{y=ac;s=ab;z=z+1|0;L=aa;K=q}}V=P;W=aa;X=r+C|0;Y=O;Z=ab;_=ac}while(1){if(V>>>0<e>>>0){K=a[b+V|0]|0;L=K&255;z=c[15880+(((L^Y)&15)<<2)>>2]^Y>>>4;ad=K;ae=V+1|0;af=z>>>4^c[15880+((z&15^L>>>4)<<2)>>2]}else{ad=0;ae=V;af=Y}if(W>>>0<g>>>0){L=a[f+W|0]|0;z=L&255;K=c[15880+(((z^Z)&15)<<2)>>2]^Z>>>4;ag=L;ah=W+1|0;ai=K>>>4^c[15880+((K&15^z>>>4)<<2)>>2]}else{ag=0;ah=W;ai=Z}z=ag^ad;if(X>>>0<M>>>0){a[h+X|0]=z;K=z&255;z=c[15880+(((K^_)&15)<<2)>>2]^_>>>4;aj=z>>>4^c[15880+((z&15^K>>>4)<<2)>>2]}else{aj=_}ak=X+1|0;if(ad<<24>>24==0){break}else{V=ae;W=ah;X=ak;Y=af;Z=ai;_=aj}}if(ae>>>0<j>>>0){i=aj;E=ai;D=af;C=ak;B=ah;A=ae}else{al=aj;am=ai;an=af;ao=ak;ap=ah;aq=ae;break}}}else{al=-1;am=-1;an=H;ao=0;ap=0;aq=I}if(ap>>>0<g>>>0){I=al;H=am;ae=ao;ah=ap;while(1){ak=a[f+ah|0]|0;af=ak&255;ai=c[15880+(((af^H)&15)<<2)>>2]^H>>>4;aj=af>>>4;ar=ai>>>4^c[15880+((ai&15^aj)<<2)>>2];ai=ah+1|0;if(ae>>>0<M>>>0){a[h+ae|0]=ak;ak=c[15880+(((af^I)&15)<<2)>>2]^I>>>4;as=ak>>>4^c[15880+((ak&15^aj)<<2)>>2]}else{as=I}if(ai>>>0<g>>>0){I=as;H=ar;ae=ae+1|0;ah=ai}else{break}}at=as;au=ar;av=g-ap+ao|0;aw=g}else{at=al;au=am;av=ao;aw=ap}if(av>>>0<M>>>0){ap=at;ao=au;am=av;av=aw;while(1){if(av>>>0<g>>>0){aw=a[f+av|0]|0;al=aw&255;ar=c[15880+(((al^ao)&15)<<2)>>2]^ao>>>4;ax=aw;ay=av+1|0;az=ar>>>4^c[15880+((ar&15^al>>>4)<<2)>>2]}else{ax=0;ay=av;az=ao}a[h+am|0]=ax;al=ax&255;ar=c[15880+(((al^ap)&15)<<2)>>2]^ap>>>4;aw=ar>>>4^c[15880+((ar&15^al>>>4)<<2)>>2];al=am+1|0;if(al>>>0<M>>>0){ap=aw;ao=az;am=al;av=ay}else{aA=aw;aB=az;break}}}else{aA=at;aB=au}if(aq>>>0<e>>>0){au=d[b+aq|0]|0;at=c[15880+(((au^an)&15)<<2)>>2]^an>>>4;aC=au;aD=aq+1|0;aE=at>>>4^c[15880+((at&15^au>>>4)<<2)>>2]}else{aC=0;aD=aq;aE=an}if(aD>>>0<e>>>0){an=d[b+aD|0]|0;aq=c[15880+(((an^aE)&15)<<2)>>2]^aE>>>4;aF=an<<8;aG=aD+1|0;aH=aq>>>4^c[15880+((aq&15^an>>>4)<<2)>>2]}else{aF=0;aG=aD;aH=aE}if(aG>>>0<e>>>0){aE=d[b+aG|0]|0;aD=c[15880+(((aE^aH)&15)<<2)>>2]^aH>>>4;aI=aE<<16;aJ=aG+1|0;aK=aD>>>4^c[15880+((aD&15^aE>>>4)<<2)>>2]}else{aI=0;aJ=aG;aK=aH}if(aJ>>>0<e>>>0){aH=d[b+aJ|0]|0;aG=c[15880+(((aH^aK)&15)<<2)>>2]^aK>>>4;aL=aH<<24;aM=aJ+1|0;aN=aG>>>4^c[15880+((aG&15^aH>>>4)<<2)>>2]}else{aL=0;aM=aJ;aN=aK}aK=aF|aC|aI|aL;if(aM>>>0<e>>>0){aL=d[b+aM|0]|0;aI=c[15880+(((aL^aN)&15)<<2)>>2]^aN>>>4;aO=aL;aP=aM+1|0;aQ=aI>>>4^c[15880+((aI&15^aL>>>4)<<2)>>2]}else{aO=0;aP=aM;aQ=aN}if(aP>>>0<e>>>0){aN=d[b+aP|0]|0;aM=c[15880+(((aN^aQ)&15)<<2)>>2]^aQ>>>4;aR=aN<<8;aS=aP+1|0;aT=aM>>>4^c[15880+((aM&15^aN>>>4)<<2)>>2]}else{aR=0;aS=aP;aT=aQ}if(aS>>>0<e>>>0){aQ=d[b+aS|0]|0;aP=c[15880+(((aQ^aT)&15)<<2)>>2]^aT>>>4;aU=aQ<<16;aV=aS+1|0;aW=aP>>>4^c[15880+((aP&15^aQ>>>4)<<2)>>2]}else{aU=0;aV=aS;aW=aT}if(aV>>>0<e>>>0){aT=d[b+aV|0]|0;aS=c[15880+(((aT^aW)&15)<<2)>>2]^aW>>>4;aX=aT<<24;aY=aV+1|0;aZ=aS>>>4^c[15880+((aS&15^aT>>>4)<<2)>>2]}else{aX=0;aY=aV;aZ=aW}aW=aR|aO|aU|aX;aX=~aB;if(aY>>>0<e>>>0){a_=d[b+aY|0]|0;a$=aY+1|0}else{a_=0;a$=aY}if(a$>>>0<e>>>0){a0=(d[b+a$|0]|0)<<8;a1=a$+1|0}else{a0=0;a1=a$}if(a1>>>0<e>>>0){a2=(d[b+a1|0]|0)<<16;a3=a1+1|0}else{a2=0;a3=a1}if(a3>>>0<e>>>0){a4=(d[b+a3|0]|0)<<24}else{a4=0}a3=~aA;if((a0|a_|a2|a4|0)!=(~aZ|0)){k=4;return k|0}if(!((aK|0)!=(aX|0)|J^1)){return((aW|0)==(a3|0)&(M|0)==(v|0)?1:8)|0}if((aW|0)!=(aX|0)|G^1){k=7;return k|0}k=(aK|0)==(a3|0)&(M|0)==(N|0)?1:8;return k|0}function hq(b,e,f,g,h,i){b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;if(e>>>0<8){j=4;return j|0}if((a[b]|0)!=80){j=4;return j|0}if((a[b+1|0]|0)!=65){j=4;return j|0}if((a[b+2|0]|0)!=84){j=4;return j|0}if((a[b+3|0]|0)!=67){j=4;return j|0}if((a[b+4|0]|0)!=72){j=4;return j|0}X5(h|0,f|0,g)|0;c[i>>2]=g;g=e-3|0;if(g>>>0<5){j=4;return j|0}f=e-2|0;k=5;while(1){l=k+3|0;m=d[b+(k+1)|0]<<8|d[b+k|0]<<16|d[b+(k+2)|0];if((m|0)==4542278){if((l|0)==(e|0)){j=1;n=3191;break}if((l|0)==(g|0)){n=3173;break}}if(l>>>0>f>>>0){j=4;n=3189;break}o=k+5|0;p=d[b+l|0]<<8|d[b+(k+4)|0];if((p|0)==0){if(o>>>0>g>>>0){j=4;n=3200;break}l=d[b+o|0]<<8|d[b+(k+6)|0];if((l|0)==0){j=4;n=3201;break}q=b+(k+7)|0;r=m;s=l;while(1){t=s-1|0;a[h+r|0]=a[q]|0;if((t|0)==0){break}else{r=r+1|0;s=t}}u=l;v=k+8|0}else{if(o>>>0>(e-p|0)>>>0){j=4;n=3194;break}else{w=o;x=m;y=p}while(1){s=y-1|0;a[h+x|0]=a[b+w|0]|0;if((s|0)==0){break}else{w=w+1|0;x=x+1|0;y=s}}u=p;v=p+o|0}l=u+m|0;if(l>>>0>(c[i>>2]|0)>>>0){c[i>>2]=l}if(v>>>0>g>>>0){j=4;n=3188;break}else{k=v}}if((n|0)==3191){return j|0}else if((n|0)==3201){return j|0}else if((n|0)==3200){return j|0}else if((n|0)==3189){return j|0}else if((n|0)==3173){c[i>>2]=d[b+(k+4)|0]<<8|d[b+g|0]<<16|d[b+(k+5)|0];j=1;return j|0}else if((n|0)==3194){return j|0}else if((n|0)==3188){return j|0}return 0}function hr(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0;d=i;i=i+8|0;e=d|0;f=c[198610]|0;a2(97808,85,1,((f|0)!=0?f:c[p>>2]|0)|0)|0;f=c[198610]|0;aY(((f|0)!=0?f:c[p>>2]|0)|0)|0;c[e>>2]=0;f=c5(b|0,78048)|0;if((f|0)==0){g=0;i=d;return g|0}b=XY(4)|0;if((b|0)==0){aQ(f|0)|0;g=0;i=d;return g|0}if((c[b-4>>2]&3|0)!=0){h=b;x=0;a[h]=x&255;x=x>>8;a[h+1|0]=x&255;x=x>>8;a[h+2|0]=x&255;x=x>>8;a[h+3|0]=x&255}h=b;eo(f|0,0,2)|0;j=cb(f|0)|0;ew(f|0);k=XY(j+1|0)|0;do{if((k|0)==0){l=0;m=3216}else{a[k+j|0]=0;if((d6(k|0,1,j|0,f|0)|0)!=(j|0)){l=k;m=3216;break}aQ(f|0)|0;c[e>>2]=k;do{if((Ya(k|0,96504,5)|0)==0){n=bu(k|0,92248)|0;if((n|0)==0){o=k;break}q=n+3|0;c[e>>2]=q;r=q;m=3211}else{r=k;m=3211}}while(0);do{if((m|0)==3211){q=X1(r|0)|0;n=XY(q+1|0)|0;if((n|0)==0){o=k;break}a[n+q|0]=0;q=bu(r|0,23064)|0;s=bu(r|0,100872)|0;if((q|0)==0|(s|0)==0){t=r;u=n}else{v=r;w=n;y=q;q=s;while(1){s=y-v|0;X5(w|0,v|0,s)|0;z=w+s|0;s=q+3|0;A=bu(s|0,23064)|0;B=bu(s|0,100872)|0;if((A|0)==0|(B|0)==0){t=s;u=z;break}else{v=s;w=z;y=A;q=B}}}q=X1(t|0)|0;X5(u|0,t|0,q)|0;a[u+q|0]=0;XZ(k);c[e>>2]=n;q=hs(e)|0;c[b>>2]=q;if((q|0)==0){o=n;break}XZ(n);g=h;i=d;return g|0}}while(0);XZ(o)}}while(0);if((m|0)==3216){XZ(l);aQ(f|0)|0}f=c[b>>2]|0;if((f|0)!=0){ht(f)}XZ(b);g=0;i=d;return g|0}function hs(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;d=i;i=i+16|0;e=d|0;f=d+8|0;g=XY(24)|0;if((g|0)==0){h=0;i=d;return h|0}if((c[g-4>>2]&3|0)!=0){X2(g|0,0,24)}j=g;k=c[b>>2]|0;while(1){l=k+1|0;if((bc(a[k]|0)|0)==0){break}else{k=l}}c[b>>2]=k;L4547:do{if((a[k]|0)==60){m=b1(k|0,62)|0;if((m|0)==0){n=0;break}o=m-l|0;p=XY(o+1|0)|0;if((p|0)==0){n=0;break}X5(p|0,l|0,o)|0;a[p+o|0]=0;o=p;while(1){if((bc(a[o]|0)|0)==0){q=o;break}else{o=o+1|0}}while(1){r=a[q]|0;if(r<<24>>24==0){s=0;break}if((bc(r<<24>>24|0)|0)==0){q=q+1|0}else{t=3239;break}}if((t|0)==3239){s=a[q]|0}r=(bc(s|0)|0)!=0?q:0;if((r|0)==0){u=dq(o|0)|0;c[g>>2]=u;if((u|0)==0){n=p;break}if((a[u]|0)==0){n=p;break}}else{u=r-o|0;v=XY(u+1|0)|0;if((v|0)==0){c[g>>2]=0;n=p;break}X5(v|0,o|0,u)|0;a[v+u|0]=0;c[g>>2]=v;if((a[v]|0)==0){n=p;break}v=dq(r|0)|0;if((v|0)==0){w=0}else{r=v+((X1(v|0)|0)-1)|0;if((a[r]|0)==47){a[r]=0}r=d8(v|0,31144,e|0)|0;L4572:do{if((r|0)==0){x=0}else{u=r;y=0;z=0;while(1){A=bu(u|0,27304)|0;if((A|0)==0){x=z;break L4572}B=A+2|0;C=cg(B|0,34)|0;if((C|0)==0){x=z;break L4572}if((C|0)!=(u+((X1(u|0)|0)-1)|0)){x=z;break L4572}D=A-u|0;A=XY(D+1|0)|0;if((A|0)==0){E=0}else{X5(A|0,u|0,D)|0;a[A+D|0]=0;E=A}A=C-B|0;C=XY(A+1|0)|0;if((C|0)==0){x=z;break L4572}X5(C|0,B|0,A)|0;a[C+A|0]=0;if((E|0)==0){x=z;break L4572}A=XY(12)|0;if((A|0)==0){x=z;break L4572}if((c[A-4>>2]&3|0)!=0){X2(A|0,0,12)}B=A;c[A>>2]=E;c[A+4>>2]=C;if((y|0)==0){F=B}else{c[y+8>>2]=B;F=z}C=d8(0,31144,e|0)|0;if((C|0)==0){x=F;break}else{u=C;y=B;z=F}}}}while(0);XZ(v);w=x}c[g+8>>2]=w}if(((bu(k|0,67440)|0)+1|0)==(m|0)){c[b>>2]=m+1}else{r=c[g>>2]|0;o=(X1(r|0)|0)+4|0;z=XY(o)|0;if((z|0)==0){n=p;break}bN(z|0,o|0,56488,(o=i,i=i+8|0,c[o>>2]=r,o)|0)|0;i=o;o=m+1|0;r=bu(o|0,47424)|0;y=b1(o|0,60)|0;u=bu(o|0,z|0)|0;if((u|0)==0){XZ(z);n=p;break}L4599:do{if((r|0)==0){t=3277}else{B=o;while(1){if(B>>>0>=r>>>0){break}if((bc(a[B]|0)|0)==0){t=3277;break L4599}else{B=B+1|0}}B=bu(r|0,40480)|0;if((B|0)==0){XZ(z);n=p;break L4547}C=r+9|0;A=B-C|0;B=XY(A+1|0)|0;if((B|0)==0){G=0}else{X5(B|0,C|0,A)|0;a[B+A|0]=0;G=B}c[g+4>>2]=G;H=u}}while(0);do{if((t|0)==3277){if((u|0)==(y|0)){r=y-o|0;m=XY(r+1|0)|0;if((m|0)==0){I=0}else{X5(m|0,o|0,r)|0;a[m+r|0]=0;I=m}c[g+4>>2]=I;H=y;break}c[f>>2]=y;m=b1(y|0,60)|0;r=bu(y|0,35776)|0;L4618:do{if((r|0)!=0&(m|0)!=0&m>>>0<r>>>0){v=0;B=0;while(1){A=hs(f)|0;if((A|0)==0){break}if((B|0)==0){J=A}else{c[B+16>>2]=A;J=v}C=c[f>>2]|0;D=b1(C|0,60)|0;K=bu(C|0,35776)|0;if((K|0)!=0&(D|0)!=0&D>>>0<K>>>0){v=J;B=A}else{L=J;M=C;break L4618}}XZ(z);n=p;break L4547}else{L=0;M=y}}while(0);c[g+12>>2]=L;r=bu(M|0,z|0)|0;if((r|0)!=0){H=r;break}XZ(z);n=p;break L4547}}while(0);c[b>>2]=H+(X1(z|0)|0);XZ(z)}XZ(p);h=j;i=d;return h|0}else{n=0}}while(0);XZ(n);ht(j);h=0;i=d;return h|0}function ht(a){a=a|0;var b=0,d=0;b=c[a+12>>2]|0;if((b|0)!=0){d=b;while(1){b=c[d+16>>2]|0;ht(d);if((b|0)==0){break}else{d=b}}}d=c[a+8>>2]|0;if((d|0)!=0){b=d;while(1){d=c[b+8>>2]|0;XZ(c[b>>2]|0);XZ(c[b+4>>2]|0);XZ(b);if((d|0)==0){break}else{b=d}}}XZ(c[a>>2]|0);XZ(c[a+4>>2]|0);XZ(a);return}function hu(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0;e=i;f=b;g=f-a|0;h=g>>2;do{if((h|0)==0){j=0}else{if(h>>>0<=65535){j=g;break}j=((g>>>0)/(h>>>0)|0|0)==4?g:-1}}while(0);k=XY(j)|0;if((k|0)==0){l=c[198610]|0;m=(l|0)!=0?l:c[p>>2]|0;ec(m|0,63392,(m=i,i=i+16|0,c[m>>2]=96632,c[m+8>>2]=150,m)|0)|0;i=m;m=c[198610]|0;l=(m|0)!=0?m:c[p>>2]|0;aY(l|0)|0;cd(2)}if((c[k-4>>2]&3|0)!=0){X2(k|0,0,j|0)}j=a;X5(k|0,j|0,g)|0;X9(j|0,b|0,d-f|0);f=d+(-h<<2)|0;X5(f|0,k|0,g)|0;XZ(k);i=e;return}function hv(a){a=a|0;return 1}function hw(d,e,f,g,h){d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;j=i;i=i+8256|0;k=j|0;l=j+8|0;m=j+64|0;n=j+4160|0;o=n|0;eG(k|0)|0;cT(o|0,4096,21928,bd(k|0)|0)|0;k=X1(o|0)|0;q=k>>>0>4096?0:4096-k|0;L4656:do{if((q|0)==0){r=97160;s=3315}else{t=n+k|0;do{if((q|0)==1){u=97160;v=t}else{w=n+(k+1)|0;a[t]=98;if((q|0)==2){u=97161;v=w;break}y=n+(k+2)|0;a[w]=109;if((q|0)==3){u=97162;v=y;break}w=n+(k+3)|0;a[y]=112;if((q|0)==4){u=97163;v=w;break}a[w]=0;break L4656}}while(0);a[v]=0;r=u;s=3315}}while(0);do{if((s|0)==3315){if((a[r]|0)==0){break}else{z=r}do{z=z+1|0;}while((a[z]|0)!=0)}}while(0);z=m|0;gr(z,625052,o);o=c5(z|0,85512)|0;if((o|0)==0){m=c[198610]|0;r=(m|0)!=0?m:c[p>>2]|0;ec(r|0,67376,(r=i,i=i+8|0,c[r>>2]=z,r)|0)|0;i=r;r=c[198610]|0;z=(r|0)!=0?r:c[p>>2]|0;aY(z|0)|0;A=0;i=j;return A|0}z=l|0;r=e*3|0;m=r+3&-4;u=ab(m,f)|0;v=u+54|0;a[z]=66;a[l+1|0]=77;a[l+2|0]=v&255;a[l+3|0]=v>>>8&255;a[l+4|0]=v>>>16&255;a[l+5|0]=v>>>24&255;v=l+6|0;x=0;a[v]=x&255;x=x>>8;a[v+1|0]=x&255;x=x>>8;a[v+2|0]=x&255;x=x>>8;a[v+3|0]=x&255;a[l+10|0]=54;a[l+11|0]=0;a[l+12|0]=0;a[l+13|0]=0;a[l+14|0]=40;a[l+15|0]=0;a[l+16|0]=0;a[l+17|0]=0;a[l+18|0]=e&255;a[l+19|0]=e>>>8&255;a[l+20|0]=e>>>16&255;a[l+21|0]=e>>>24&255;a[l+22|0]=f&255;a[l+23|0]=f>>>8&255;a[l+24|0]=f>>>16&255;a[l+25|0]=f>>>24&255;a[l+26|0]=1;a[l+27|0]=0;a[l+28|0]=24;X2(l+29|0,0,5);a[l+34|0]=u&255;a[l+35|0]=u>>>8&255;a[l+36|0]=u>>>16&255;a[l+37|0]=u>>>24&255;a[l+38|0]=19;a[l+39|0]=11;a[l+40|0]=0;a[l+41|0]=0;a[l+42|0]=19;a[l+43|0]=11;X2(l+44|0,0,10);l=(a2(z|0,1,54,o|0)|0)==54;do{if(l){z=(f|0)==0;do{if(z){B=0}else{u=f<<2;if(f>>>0<=65535){B=u;break}B=((u>>>0)/(f>>>0)|0|0)==4?u:-1}}while(0);u=XY(B)|0;if((u|0)==0){break}if((c[u-4>>2]&3|0)!=0){X2(u|0,0,B|0)}v=u;q=0;while(1){if((q|0)>=(f|0)){s=3333;break}k=XY(m)|0;if((k|0)==0){s=3332;break}if((c[k-4>>2]&3|0)!=0){X2(k|0,0,m|0)}c[v+(q<<2)>>2]=k;q=q+1|0}do{if((s|0)==3332){c[v+(q<<2)>>2]=0;s=3349}else if((s|0)==3333){do{if(h){if((f|0)>0){C=d;D=0}else{s=3347;break}while(1){k=c[v+(D<<2)>>2]|0;X5(k|0,C|0,r)|0;k=D+1|0;if((k|0)<(f|0)){C=C+g|0;D=k}else{s=3347;break}}}else{k=(f|0)>0;if((c[182940]|0)==1){if(!k){s=3347;break}if((e|0)==0){E=0;break}else{F=d;G=0}while(1){n=F;t=0;w=c[v+(G<<2)>>2]|0;while(1){y=c[n>>2]|0;a[w]=y&255;a[w+1|0]=y>>>8&255;a[w+2|0]=y>>>16&255;y=t+1|0;if(y>>>0<e>>>0){n=n+4|0;t=y;w=w+3|0}else{break}}w=G+1|0;if((w|0)<(f|0)){F=F+g|0;G=w}else{s=3347;break}}}else{if(!k){s=3347;break}if((e|0)==0){E=0;break}else{H=d;I=0}while(1){w=0;t=H;n=c[v+(I<<2)>>2]|0;while(1){y=b[t>>1]|0;J=y&255;a[n]=(J&255)>>>2&7|J<<3;a[n+1|0]=(y&65535)>>>5<<2&255|(y&65535)>>>9&3;J=(y&65535)>>>11&65535;a[n+2|0]=(J<<3|J>>>2)&255;J=w+1|0;if(J>>>0<e>>>0){w=J;t=t+2|0;n=n+3|0}else{break}}n=I+1|0;if((n|0)<(f|0)){H=H+g|0;I=n}else{s=3347;break}}}}}while(0);if((s|0)==3347){if(z){break}else{E=0}}while(1){a2(c[v+(E<<2)>>2]|0,1,m|0,o|0)|0;k=E+1|0;if(k>>>0<f>>>0){E=k}else{s=3349;break}}}}while(0);do{if((s|0)==3349){if((f|0)>0){K=0}else{break}do{XZ(c[v+(K<<2)>>2]|0);K=K+1|0;}while((K|0)<(f|0))}}while(0);XZ(u)}else{v=c[198610]|0;a2(56432,51,1,((v|0)!=0?v:c[p>>2]|0)|0)|0;v=c[198610]|0;aY(((v|0)!=0?v:c[p>>2]|0)|0)|0}}while(0);aQ(o|0)|0;A=l;i=j;return A|0}function hx(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;d=i;i=i+544|0;e=d|0;if((b|0)==0){i=d;return}f=b|0;if((c[f>>2]|0)!=0){g=e|0;h=d+512|0;do{if((a[620956]|0)!=0){j=gH(620956,0)|0;if((j|0)==0){k=XY(20)|0;if((k|0)==0){l=c[198610]|0;m=(l|0)!=0?l:c[p>>2]|0;a2(100800,53,1,m|0)|0;m=c[198610]|0;l=(m|0)!=0?m:c[p>>2]|0;aY(l|0)|0;break}if((c[k-4>>2]&3|0)!=0){X2(k|0,0,20)}n=k}else{n=j}X2(g|0,0,512);X2(h|0,0,32);j=b+8|0;k=c[j>>2]|0;do{if((k|0)!=0){l=0;m=k;while(1){if((a[(c[f>>2]|0)+(l*12|0)+4|0]&1)==0){o=m}else{bN(h|0,32,96480,(q=i,i=i+8|0,c[q>>2]=l,q)|0)|0;i=q;r=X1(g|0)|0;s=r>>>0>512?0:512-r|0;L4747:do{if((s|0)==0){t=h;u=3376}else{v=s;w=e+r|0;x=h;while(1){y=v-1|0;if((y|0)==0){break}z=a[x]|0;a[w]=z;if(z<<24>>24==0){break L4747}else{v=y;w=w+1|0;x=x+1|0}}a[w]=0;t=x;u=3376}}while(0);do{if((u|0)==3376){u=0;if((a[t]|0)==0){break}else{A=t}do{A=A+1|0;}while((a[A]|0)!=0)}}while(0);o=c[j>>2]|0}x=l+1|0;if(x>>>0<o>>>0){l=x;m=o}else{break}}if((a[g]|0)==0){break}a[e+((X1(g|0)|0)-1)|0]=0}}while(0);gK(n,794280,g);if(!(gL(n,620956)|0)){j=c[198610]|0;k=(j|0)!=0?j:c[p>>2]|0;ec(k|0,92144,(q=i,i=i+8|0,c[q>>2]=620956,q)|0)|0;i=q;k=c[198610]|0;j=(k|0)!=0?k:c[p>>2]|0;aY(j|0)|0}gF(n)}}while(0);n=b+8|0;q=c[f>>2]|0;if((c[n>>2]|0)==0){B=q}else{g=0;e=q;while(1){XZ(c[e+(g*12|0)+8>>2]|0);q=g+1|0;o=c[f>>2]|0;if(q>>>0<(c[n>>2]|0)>>>0){g=q;e=o}else{B=o;break}}}XZ(B)}XZ(b);i=d;return}function hy(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0;d=i;i=i+256|0;e=d|0;f=c[196481]|0;g=f+4|0;h=c[g>>2]|0;if(h>>>0>1){j=f|0;k=1;l=h;while(1){h=c[(c[j>>2]|0)+(k<<2)>>2]|0;if((h|0)==0){m=l}else{XZ(c[h+8>>2]|0);XZ(c[(c[j>>2]|0)+(k<<2)>>2]|0);c[(c[j>>2]|0)+(k<<2)>>2]=0;m=c[g>>2]|0}h=k+1|0;if(h>>>0<m>>>0){k=h;l=m}else{break}}}c[g>>2]=1;g=f+12|0;XZ(c[g>>2]|0);c[g>>2]=0;g=e|0;e=c[b+4>>2]|0;f=c[b>>2]|0;b=(a[f+(e*12|0)+4|0]&1)!=0?57128:56296;m=c[f+(e*12|0)>>2]|0;bN(g|0,256,35736,(f=i,i=i+24|0,c[f>>2]=e,c[f+8>>2]=b,c[f+16>>2]=m,f)|0)|0;i=f;m=c[196481]|0;b=m+4|0;L4781:do{if((c[b>>2]|0)>>>0<(c[m+8>>2]|0)>>>0){e=XY(12)|0;do{if((e|0)!=0){if((c[e-4>>2]&3|0)==0){break}X2(e|0,0,12)}}while(0);c[e+4>>2]=1;c[e>>2]=180;l=dq(g|0)|0;k=c[b>>2]|0;c[e+8>>2]=l;l=m|0;c[(c[l>>2]|0)+(k<<2)>>2]=e;k=c[b>>2]|0;c[b>>2]=k+1;if(k>>>0>1){n=k}else{break}while(1){k=n>>>1;j=c[l>>2]|0;h=j+(k<<2)|0;o=c[h>>2]|0;q=c[j+(n<<2)>>2]|0;if((c[q+4>>2]|0)>>>0<=(c[o+4>>2]|0)>>>0){break L4781}c[h>>2]=q;c[(c[l>>2]|0)+(n<<2)>>2]=o;if(n>>>0>3){n=k}else{break}}}}while(0);if((a[637400]&1)==0){i=d;return}n=c[198610]|0;ec(((n|0)!=0?n:c[p>>2]|0)|0,93640,(f=i,i=i+8|0,c[f>>2]=g,f)|0)|0;i=f;f=c[198610]|0;aY(((f|0)!=0?f:c[p>>2]|0)|0)|0;i=d;return}function hz(a,b,d){a=a|0;b=b|0;d=d|0;b=aR(d|0)|0;if((b|0)==0){return b|0}c[137895]=cX()|0;return b|0}function hA(a,b,c){a=a|0;b=b|0;c=c|0;return bE(b|0,c|0)|0}function hB(a){a=a|0;return aN()|0}function hC(a){a=a|0;return eV()|0}function hD(a,b){a=a|0;b=b|0;d_(b|0);return}function hE(a){a=a|0;dU();return}function hF(a){a=a|0;return cN()|0}function hG(a){a=a|0;return bk()|0}function hH(b,d){b=b|0;d=+d;var e=0,f=0,h=0,i=0,j=0.0;e=b+24|0;if((c[e>>2]|0)!=0){f=b+12|0;h=0;do{i=c[f>>2]|0;if((a[i+(h*136|0)+20|0]&1)==0){g[i+(h*136|0)+56>>2]=d;g[i+(h*136|0)+32>>2]=+g[i+(h*136|0)+48>>2]*d;g[i+(h*136|0)+36>>2]=+g[i+(h*136|0)+52>>2]*d;j=+g[i+(h*136|0)+60>>2];g[i+(h*136|0)+24>>2]=j+(+g[i+(h*136|0)+40>>2]-j)*d;j=+g[i+(h*136|0)+64>>2];g[i+(h*136|0)+28>>2]=j+(+g[i+(h*136|0)+44>>2]-j)*d}else{g[i+(h*136|0)+24>>2]=+g[i+(h*136|0)+40>>2];g[i+(h*136|0)+28>>2]=+g[i+(h*136|0)+44>>2];g[i+(h*136|0)+32>>2]=+g[i+(h*136|0)+48>>2];g[i+(h*136|0)+36>>2]=+g[i+(h*136|0)+52>>2]}h=h+1|0;}while(h>>>0<(c[e>>2]|0)>>>0)}e=c[b+16>>2]|0;fg[c[(c[b+4>>2]|0)+12>>2]&7](c[b>>2]|0,+g[e+24>>2],+g[e+28>>2],+g[e+32>>2],+g[e+36>>2]);return}function hI(){var b=0,d=0,e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0.0,aU=0.0,aW=0,aX=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0;b=i;i=i+9176|0;d=b|0;e=b+64|0;f=b+320|0;h=b+328|0;j=b+392|0;k=b+456|0;l=b+520|0;m=b+4616|0;n=b+8712|0;o=b+8728|0;q=b+8792|0;r=b+9048|0;s=b+9112|0;t=XY(32)|0;if((t|0)==0){u=0;i=b;return u|0}if((c[t-4>>2]&3|0)!=0){X2(t|0,0,32)}v=t;w=c[(c[199305]|0)+52>>2]|0;do{if((w|0)==0){x=c[198610]|0;y=(x|0)!=0?x:c[p>>2]|0;a2(94968,71,1,y|0)|0;y=c[198610]|0;x=(y|0)!=0?y:c[p>>2]|0;aY(x|0)|0}else{x=t+4|0;fc[w&127](c[199308]|0,x);y=t;c[y>>2]=c[199308];if((c[x>>2]|0)==0){break}z=gH(596368,0)|0;if((z|0)==0){A=c[198610]|0;B=(A|0)!=0?A:c[p>>2]|0;ec(B|0,96280,(C=i,i=i+8|0,c[C>>2]=596368,C)|0)|0;i=C;B=c[198610]|0;A=(B|0)!=0?B:c[p>>2]|0;aY(A|0)|0;break}A=z+4|0;B=A;while(1){D=c[B>>2]|0;if((D|0)==0){E=3440;break}if((cL(67048,c[D+4>>2]|0)|0)==0){E=3439;break}else{B=D+12|0}}L4834:do{if((E|0)==3439){c[(dS()|0)>>2]=0;B=aV(c[D+8>>2]|0,0,0)|0;if((c[(dS()|0)>>2]|0)!=0){E=3440;break}if((B|0)==0){break}G=B*136|0;if(B>>>0>65535){H=((G>>>0)/(B>>>0)|0|0)==136?G:-1}else{H=G}G=XY(H)|0;if((G|0)==0){c[t+12>>2]=0;break}if((c[G-4>>2]&3|0)!=0){X2(G|0,0,H|0)}I=G;G=t+12|0;c[G>>2]=I;J=t+24|0;c[J>>2]=B;B=j|0;K=k|0;L=l|0;M=m|0;N=n;O=o|0;P=q|0;Q=r|0;R=s|0;S=n+8|0;T=n|0;U=n+4|0;V=d|0;W=e|0;X=h|0;bN(B|0,64,31072,(C=i,i=i+8|0,c[C>>2]=0,C)|0)|0;i=C;L4847:do{if(gI(z,B,L)|0){Y=I;Z=0;L4848:while(1){bN(K|0,64,23008,(C=i,i=i+8|0,c[C>>2]=Z,C)|0)|0;i=C;_=Y+(Z*136|0)+69|0;$=A;while(1){aa=c[$>>2]|0;if((aa|0)==0){break}if((cL(K|0,c[aa+4>>2]|0)|0)==0){E=3454;break}else{$=aa+12|0}}L4853:do{if((E|0)==3454){E=0;$=64;ab=_;ac=c[aa+8>>2]|0;while(1){ad=$-1|0;if((ad|0)==0){break}ae=a[ac]|0;a[ab]=ae;if(ae<<24>>24==0){break L4853}else{$=ad;ab=ab+1|0;ac=ac+1|0}}a[ab]=0;if((a[ac]|0)==0){break}else{af=ac}do{af=af+1|0;}while((a[af]|0)!=0)}}while(0);gB(M,596368,L);X2(N|0,0,12);if((a[797396]&1)==0){if(!(h8(M,n,16,0)|0)){E=3462;break}}else{if(!(h8(M,n,0,16)|0)){E=3462;break}}c[Y+(Z*136|0)+8>>2]=c[S>>2];c[Y+(Z*136|0)+12>>2]=c[T>>2];c[Y+(Z*136|0)+16>>2]=c[U>>2];_=Y+(Z*136|0)+44|0;g[_>>2]=0.0;ac=Y+(Z*136|0)+40|0;g[ac>>2]=0.0;ab=Y+(Z*136|0)+52|0;g[ab>>2]=1.0;$=Y+(Z*136|0)+48|0;g[$>>2]=1.0;bN(O|0,64,96400,(C=i,i=i+8|0,c[C>>2]=Z,C)|0)|0;i=C;ad=A;while(1){ag=c[ad>>2]|0;if((ag|0)==0){break}if((cL(O|0,c[ag+4>>2]|0)|0)==0){E=3466;break}else{ad=ag+12|0}}do{if((E|0)==3466){E=0;ad=256;ae=0;ah=P;ai=c[ag+8>>2]|0;while(1){aj=ad-1|0;if((aj|0)==0){E=3469;break}ak=a[ai]|0;a[ah]=ak;if(ak<<24>>24==0){al=ae;break}else{ad=aj;ae=ae+1|0;ah=ah+1|0;ai=ai+1|0}}do{if((E|0)==3469){E=0;a[ah]=0;if((a[ai]|0)==0){al=ae;break}else{am=ai;an=ae}while(1){ad=am+1|0;aj=an+1|0;if((a[ad]|0)==0){al=aj;break}else{am=ad;an=aj}}}}while(0);if(al>>>0>=256){break}ae=gp(P,92056)|0;ai=ae+4|0;if((c[ai>>2]|0)>>>0<4){E=3473;break L4848}ah=ae|0;g[ac>>2]=+X0(c[c[ah>>2]>>2]|0);g[_>>2]=+X0(c[(c[ah>>2]|0)+8>>2]|0);g[$>>2]=+X0(c[(c[ah>>2]|0)+16>>2]|0);g[ab>>2]=+X0(c[(c[ah>>2]|0)+24>>2]|0);if((ae|0)==0){break}aj=c[ah>>2]|0;if((c[ai>>2]|0)==0){ao=aj}else{ad=0;ak=aj;while(1){XZ(c[ak+(ad<<3)>>2]|0);aj=ad+1|0;ap=c[ah>>2]|0;if(aj>>>0<(c[ai>>2]|0)>>>0){ad=aj;ak=ap}else{ao=ap;break}}}XZ(ao);XZ(ae)}}while(0);bN(Q|0,64,85488,(C=i,i=i+8|0,c[C>>2]=Z,C)|0)|0;i=C;ak=Y+(Z*136|0)+68|0;a[ak]=0;gJ(z,Q,ak)|0;bN(R|0,64,82024,(C=i,i=i+8|0,c[C>>2]=Z,C)|0)|0;i=C;ak=A;while(1){aq=c[ak>>2]|0;if((aq|0)==0){E=3482;break L4848}if((cL(R|0,c[aq+4>>2]|0)|0)==0){break}else{ak=aq+12|0}}c[(dS()|0)>>2]=0;ak=aV(c[aq+8>>2]|0,0,0)|0;if((c[(dS()|0)>>2]|0)!=0){E=3482;break}ad=(ak|0)==0;do{if(ad){ar=0}else{ai=ak*104|0;if(ak>>>0<=65535){ar=ai;break}ar=((ai>>>0)/(ak>>>0)|0|0)==104?ai:-1}}while(0);ai=XY(ar)|0;if((ai|0)==0){E=3489;break}if((c[ai-4>>2]&3|0)!=0){X2(ai|0,0,ar|0)}ah=ai;ai=Y+(Z*136|0)|0;c[ai>>2]=ah;ap=Y+(Z*136|0)+4|0;c[ap>>2]=ak;L4900:do{if(!ad){aj=c[T>>2]|0;as=c[U>>2]|0;bN(V|0,64,69968,(C=i,i=i+16|0,c[C>>2]=Z,c[C+8>>2]=0,C)|0)|0;i=C;at=A;while(1){au=c[at>>2]|0;if((au|0)==0){av=0;E=3500;break L4848}if((cL(V|0,c[au+4>>2]|0)|0)==0){break}else{at=au+12|0}}at=256;ae=0;aw=W;ax=c[au+8>>2]|0;while(1){ay=at-1|0;if((ay|0)==0){E=3497;break}az=a[ax]|0;a[aw]=az;if(az<<24>>24==0){aA=ae;break}else{at=ay;ae=ae+1|0;aw=aw+1|0;ax=ax+1|0}}do{if((E|0)==3497){E=0;a[aw]=0;if((a[ax]|0)==0){aA=ae;break}else{aB=ax;aC=ae}while(1){at=aB+1|0;ay=aC+1|0;if((a[at]|0)==0){aA=ay;break}else{aB=at;aC=ay}}}}while(0);if(aA>>>0<256){aD=ah;aE=0;aF=aj;aG=as}else{av=0;E=3500;break L4848}while(1){aH=gp(W,92056)|0;if((aH|0)==0){E=3502;break L4848}aI=aH+4|0;aJ=c[aI>>2]|0;if(aJ>>>0<6){E=3504;break L4848}aK=aH|0;ae=c[aK>>2]|0;ax=c[ae+8>>2]|0;aw=c[ae+16>>2]|0;aL=c[ae+24>>2]|0;ay=c[ae>>2]|0;ae=aD+(aE*104|0)+24|0;c[ae>>2]=0;c[ae+4>>2]=0;at=d8(ay|0,93176,f|0)|0;if((at|0)!=0){ay=at;do{at=0;while(1){if(at>>>0>=56){aM=0;aN=56;break}if((cL(c[848+(at<<3)>>2]|0,ay|0)|0)==0){E=3511;break}else{at=at+1|0}}if((E|0)==3511){E=0;aM=0;aN=c[852+(at<<3)>>2]|0}az=Yg(1,0,aN|0)|0;aO=F;aP=c[ae+4>>2]|aO;c[ae>>2]=c[ae>>2]|az;c[ae+4>>2]=aP;ay=d8(0,93176,f|0)|0;}while((ay|0)!=0)}L4928:do{if(!((c[ae>>2]&0|0)==0&(c[ae+4>>2]&524288|0)==0)){bN(X|0,64,62112,(C=i,i=i+16|0,c[C>>2]=Z,c[C+8>>2]=aE,C)|0)|0;i=C;ay=aD+(aE*104|0)+36|0;aP=A;while(1){aQ=c[aP>>2]|0;if((aQ|0)==0){break L4928}if((cL(X|0,c[aQ+4>>2]|0)|0)==0){break}else{aP=aQ+12|0}}aP=64;at=ay;az=c[aQ+8>>2]|0;while(1){aO=aP-1|0;if((aO|0)==0){break}aR=a[az]|0;a[at]=aR;if(aR<<24>>24==0){break L4928}else{aP=aO;at=at+1|0;az=az+1|0}}a[at]=0;if((a[az]|0)==0){break}else{aS=az}do{aS=aS+1|0;}while((a[aS]|0)!=0)}}while(0);aT=+(aF>>>0>>>0);g[aD+(aE*104|0)>>2]=+X0(ax)/aT;aU=+(aG>>>0>>>0);g[aD+(aE*104|0)+4>>2]=+X0(aw)/aU;if((cL(aL|0,61224)|0)==0){c[aD+(aE*104|0)+8>>2]=0}else{if((cL(aL|0,60112)|0)!=0){E=3526;break L4848}c[aD+(aE*104|0)+8>>2]=1}g[aD+(aE*104|0)+12>>2]=+X0(c[(c[aK>>2]|0)+32>>2]|0)/aT;g[aD+(aE*104|0)+16>>2]=+X0(c[(c[aK>>2]|0)+40>>2]|0)/aU;ae=c[aK>>2]|0;if((c[aI>>2]|0)==0){aW=ae}else{az=0;at=ae;while(1){XZ(c[at+(az<<3)>>2]|0);ae=az+1|0;aP=c[aK>>2]|0;if(ae>>>0<(c[aI>>2]|0)>>>0){az=ae;at=aP}else{aW=aP;break}}}XZ(aW);XZ(aH);at=aE+1|0;if(at>>>0>=(c[ap>>2]|0)>>>0){break L4900}az=c[ai>>2]|0;aw=c[T>>2]|0;ax=c[U>>2]|0;bN(V|0,64,69968,(C=i,i=i+16|0,c[C>>2]=Z,c[C+8>>2]=at,C)|0)|0;i=C;aP=A;while(1){aX=c[aP>>2]|0;if((aX|0)==0){av=at;E=3500;break L4848}if((cL(V|0,c[aX+4>>2]|0)|0)==0){break}else{aP=aX+12|0}}aP=256;ae=0;ay=W;aO=c[aX+8>>2]|0;while(1){aR=aP-1|0;if((aR|0)==0){E=3538;break}aZ=a[aO]|0;a[ay]=aZ;if(aZ<<24>>24==0){a_=ae;break}else{aP=aR;ae=ae+1|0;ay=ay+1|0;aO=aO+1|0}}do{if((E|0)==3538){E=0;a[ay]=0;if((a[aO]|0)==0){a_=ae;break}else{a$=aO;a0=ae}while(1){aP=a$+1|0;aR=a0+1|0;if((a[aP]|0)==0){a_=aR;break}else{a$=aP;a0=aR}}}}while(0);if(a_>>>0<256){aD=az;aE=at;aF=aw;aG=ax}else{av=at;E=3500;break L4848}}}}while(0);a[Y+(Z*136|0)+20|0]=0;g[Y+(Z*136|0)+60>>2]=+g[ac>>2]+ +g[$>>2]*.5;g[Y+(Z*136|0)+64>>2]=+g[_>>2]+ +g[ab>>2]*.5;ai=Z+1|0;a1=c[J>>2]|0;if(ai>>>0>=a1>>>0){E=3449;break}ap=c[G>>2]|0;bN(B|0,64,31072,(C=i,i=i+8|0,c[C>>2]=ai,C)|0)|0;i=C;if(gI(z,B,L)|0){Y=ap;Z=ai}else{a3=ai;E=3450;break L4847}}if((E|0)==3482){ai=c[198610]|0;ap=(ai|0)!=0?ai:c[p>>2]|0;ec(ap|0,78592,(C=i,i=i+8|0,c[C>>2]=R,C)|0)|0;i=C;ap=c[198610]|0;ai=(ap|0)!=0?ap:c[p>>2]|0;aY(ai|0)|0;a4=Z;break}else if((E|0)==3500){ai=c[198610]|0;ec(((ai|0)!=0?ai:c[p>>2]|0)|0,68800,(C=i,i=i+8|0,c[C>>2]=V,C)|0)|0;i=C;ai=c[198610]|0;aY(((ai|0)!=0?ai:c[p>>2]|0)|0)|0;a5=av}else if((E|0)==3502){ai=c[198610]|0;a2(67176,62,1,((ai|0)!=0?ai:c[p>>2]|0)|0)|0;ai=c[198610]|0;aY(((ai|0)!=0?ai:c[p>>2]|0)|0)|0;a5=aE}else if((E|0)==3462){ai=c[198610]|0;ec(((ai|0)!=0?ai:c[p>>2]|0)|0,100720,(C=i,i=i+8|0,c[C>>2]=L,C)|0)|0;i=C;ai=c[198610]|0;aY(((ai|0)!=0?ai:c[p>>2]|0)|0)|0;a4=Z;break}else if((E|0)==3526){ai=c[198610]|0;ec(((ai|0)!=0?ai:c[p>>2]|0)|0,59128,(C=i,i=i+8|0,c[C>>2]=aL,C)|0)|0;i=C;ai=c[198610]|0;aY(((ai|0)!=0?ai:c[p>>2]|0)|0)|0;ai=c[aK>>2]|0;if((c[aI>>2]|0)==0){a6=ai}else{ap=0;ah=ai;while(1){XZ(c[ah+(ap<<3)>>2]|0);ai=ap+1|0;ad=c[aK>>2]|0;if(ai>>>0<(c[aI>>2]|0)>>>0){ap=ai;ah=ad}else{a6=ad;break}}}XZ(a6);XZ(aH);a5=aE}else if((E|0)==3489){c[Y+(Z*136|0)>>2]=0;ah=c[198610]|0;a2(75328,58,1,((ah|0)!=0?ah:c[p>>2]|0)|0)|0;ah=c[198610]|0;aY(((ah|0)!=0?ah:c[p>>2]|0)|0)|0;a4=Z;break}else if((E|0)==3473){ah=c[198610]|0;ec(((ah|0)!=0?ah:c[p>>2]|0)|0,88576,(C=i,i=i+8|0,c[C>>2]=P,C)|0)|0;i=C;ah=c[198610]|0;aY(((ah|0)!=0?ah:c[p>>2]|0)|0)|0;a4=Z;break}else if((E|0)==3449){L4978:do{if((a1|0)!=0){ah=0;ap=a1;L4979:while(1){ad=c[G>>2]|0;ai=ad+(ah*136|0)+4|0;if((c[ai>>2]|0)==0){a7=ap;a8=ah+1|0}else{ak=ad+(ah*136|0)|0;as=ah+1|0;aj=0;do{ae=c[ak>>2]|0;a9=ae+(aj*104|0)+36|0;if((a[a9]|0)==0){c[ae+(aj*104|0)+32>>2]=(as>>>0)%(ap>>>0)|0}else{aO=0;while(1){if(aO>>>0>=ap>>>0){break L4979}if((cL(ad+(aO*136|0)+69|0,a9|0)|0)==0){break}else{aO=aO+1|0}}if((aO|0)<0){break L4979}c[ae+(aj*104|0)+32>>2]=aO}aj=aj+1|0;}while(aj>>>0<(c[ai>>2]|0)>>>0);a7=c[J>>2]|0;a8=as}if(a8>>>0<a7>>>0){ah=a8;ap=a7}else{break L4978}}ap=c[198610]|0;ec(((ap|0)!=0?ap:c[p>>2]|0)|0,35632,(C=i,i=i+8|0,c[C>>2]=a9,C)|0)|0;i=C;ap=c[198610]|0;aY(((ap|0)!=0?ap:c[p>>2]|0)|0)|0;ap=c[198610]|0;a2(40288,64,1,((ap|0)!=0?ap:c[p>>2]|0)|0)|0;ap=c[198610]|0;aY(((ap|0)!=0?ap:c[p>>2]|0)|0)|0;break L4834}}while(0);gF(z);Y=c[G>>2]|0;ap=t+16|0;c[ap>>2]=Y;fx[c[(c[x>>2]|0)+4>>2]&15](c[y>>2]|0,c[Y+8>>2]|0,c[Y+12>>2]|0,c[Y+16>>2]|0)|0;Y=c[ap>>2]|0;fg[c[(c[x>>2]|0)+12>>2]&7](c[y>>2]|0,+g[Y+24>>2],+g[Y+28>>2],+g[Y+32>>2],+g[Y+36>>2]);fc[c[(c[x>>2]|0)+16>>2]&127](c[y>>2]|0,(a[(c[ap>>2]|0)+68|0]&1)!=0);fc[c[c[x>>2]>>2]&127](c[y>>2]|0,1);a[t+8|0]=1;e9[c[(c[x>>2]|0)+20>>2]&7](c[y>>2]|0,+g[150116]);hH(v,1.0);c[t+28>>2]=(((c[t+20>>2]|0)+1|0)>>>0)%((c[J>>2]|0)>>>0)|0;u=v;i=b;return u|0}else if((E|0)==3504){ap=aH|0;Y=c[ap>>2]|0;if((aJ|0)==0){ba=Y}else{ah=0;ab=Y;while(1){XZ(c[ab+(ah<<3)>>2]|0);Y=ah+1|0;_=c[ap>>2]|0;if(Y>>>0<(c[aI>>2]|0)>>>0){ah=Y;ab=_}else{ba=_;break}}}XZ(ba);XZ(aH);ab=c[198610]|0;a2(65016,85,1,((ab|0)!=0?ab:c[p>>2]|0)|0)|0;ab=c[198610]|0;aY(((ab|0)!=0?ab:c[p>>2]|0)|0)|0;a5=aE}ab=c[198610]|0;ec(((ab|0)!=0?ab:c[p>>2]|0)|0,72368,(C=i,i=i+8|0,c[C>>2]=a5,C)|0)|0;i=C;ab=c[198610]|0;aY(((ab|0)!=0?ab:c[p>>2]|0)|0)|0;a4=Z}else{a3=0;E=3450}}while(0);if((E|0)==3450){J=c[198610]|0;G=(J|0)!=0?J:c[p>>2]|0;ec(G|0,27136,(C=i,i=i+8|0,c[C>>2]=B,C)|0)|0;i=C;G=c[198610]|0;J=(G|0)!=0?G:c[p>>2]|0;aY(J|0)|0;a4=a3}J=c[198610]|0;G=(J|0)!=0?J:c[p>>2]|0;ec(G|0,47248,(C=i,i=i+8|0,c[C>>2]=a4,C)|0)|0;i=C;G=c[198610]|0;J=(G|0)!=0?G:c[p>>2]|0;aY(J|0)|0}}while(0);if((E|0)==3440){y=c[198610]|0;x=(y|0)!=0?y:c[p>>2]|0;a2(56304,62,1,x|0)|0;x=c[198610]|0;y=(x|0)!=0?x:c[p>>2]|0;aY(y|0)|0}gF(z)}}while(0);E=t+24|0;C=t+12|0;a4=c[C>>2]|0;if((c[E>>2]|0)==0){bb=a4}else{a3=0;a5=a4;while(1){XZ(c[a5+(a3*136|0)>>2]|0);XZ(c[a5+(a3*136|0)+8>>2]|0);a4=a3+1|0;aE=c[C>>2]|0;if(a4>>>0<(c[E>>2]|0)>>>0){a3=a4;a5=aE}else{bb=aE;break}}}XZ(bb);bb=c[t+4>>2]|0;if((bb|0)!=0){fc[c[bb>>2]&127](c[t>>2]|0,0)}XZ(t);u=0;i=b;return u|0}function hJ(d){d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,R=0,S=0,T=0,V=0,W=0,X=0,Y=0.0,Z=0.0,_=0.0,$=0,aa=0,ac=0,ad=0,ae=0.0,af=0.0,ag=0.0,ah=0.0,ai=0.0,aj=0.0,ak=0,al=0,am=0.0,an=0.0,ao=0,ap=0,aq=0;e=i;f=d+64|0;XZ(c[f>>2]|0);g=d+76|0;XZ(c[g>>2]|0);h=d+80|0;XZ(c[h>>2]|0);j=d+92|0;XZ(c[j>>2]|0);k=d+104|0;XZ(c[k>>2]|0);l=d+96|0;XZ(c[l>>2]|0);m=d+120|0;XZ(c[m>>2]|0);X2(f|0,0,64);n=d|0;o=c[n>>2]|0;q=d+12|0;r=c[q>>2]|0;s=d+4|0;t=c[s>>2]|0;do{if((o|0)==(r|0)){if((t|0)!=(c[d+16>>2]|0)){u=3572;break}a[d+60|0]=1;v=1}else{u=3572}}while(0);if((u|0)==3572){c[d+36>>2]=218;c[d+40>>2]=274;a[d+60|0]=0;v=0}w=d+44|0;c[w>>2]=0;x=(r<<3)+56&-64;c[d+116>>2]=x;c[d+108>>2]=r;c[d+112>>2]=t;y=ab(x,t)|0;x=y>>3;if(x>>>0>65535){z=(y>>>3|0)==(x|0)?y:-1}else{z=y}y=XY(z)|0;if((y|0)==0){c[k>>2]=0;A=0;i=e;return A|0}if((c[y-4>>2]&3|0)!=0){X2(y|0,0,z|0)}c[k>>2]=y;y=c[d+24>>2]|0;if((y|0)!=0){k=(o<<2)+28&-32;c[d+100>>2]=k;o=ab(k,t)|0;t=o>>2;if(t>>>0>65535){B=(o>>>2|0)==(t|0)?o:-1}else{B=o}o=XY(B)|0;if((o|0)==0){c[l>>2]=0;A=0;i=e;return A|0}if((c[o-4>>2]&3|0)!=0){X2(o|0,0,B|0)}c[l>>2]=o}o=c[d+28>>2]|0;l=(o|0)==0;if(!l){B=(r<<2)+28&-32;c[d+124>>2]=B;r=ab(c[d+16>>2]|0,B)|0;B=r>>2;if(B>>>0>65535){C=(r>>>2|0)==(B|0)?r:-1}else{C=r}r=XY(C)|0;if((r|0)==0){c[m>>2]=0;A=0;i=e;return A|0}if((c[r-4>>2]&3|0)!=0){X2(r|0,0,C|0)}c[m>>2]=r}r=v<<24>>24==0;L5063:do{if(r){if((y|0)==3){c[d+48>>2]=112}else if((y|0)==2){c[d+48>>2]=116}else if((y|0)==4){c[d+48>>2]=70}else if((y|0)!=0){A=0;i=e;return A|0}if((o|0)==2){c[d+52>>2]=134;break}else if((o|0)==4){c[d+52>>2]=148;break}else if((o|0)==0){break}else{A=0;i=e;return A|0}}else{if((y|0)==(o|0)){c[d+56>>2]=52;A=1;i=e;return A|0}v=(y|0)==2;if(v&l){c[d+56>>2]=116;A=1;i=e;return A|0}if(!((y|0)!=3|l^1)){c[d+56>>2]=112;break}m=(y|0)==3;C=(o|0)==4;if(m&C){c[d+56>>2]=16;break}if(v&(o|0)==3){c[d+56>>2]=72;break}do{if(m){if((o|0)!=2){D=0;break}c[d+56>>2]=58;break L5063}else{if((y|0)==4){if(!l){D=0;break}c[d+56>>2]=70;break L5063}else if((y|0)!=0){D=0;break}if((o|0)==2){c[d+56>>2]=134;break L5063}else if((o|0)==4){c[d+56>>2]=148;break L5063}else{D=1;break}}}while(0);if(v&C){c[d+56>>2]=30;break}if(D&(o|0)==1){c[d+56>>2]=76;break}else{A=0;i=e;return A|0}}}while(0);if(!r){A=1;i=e;return A|0}r=c[d+32>>2]|0;L5115:do{if((r|0)==2){c[d+68>>2]=2;c[d+72>>2]=2;c[d+84>>2]=2;o=d+88|0;c[o>>2]=2;D=c[q>>2]|0;y=D<<1;l=D<<2;if(y>>>0>65535){E=(y&2147483646|0)==(y|0)?l:-1}else{E=l}l=XY(E)|0;do{if((l|0)!=0){if((c[l-4>>2]&3|0)==0){break}X2(l|0,0,E|0)}}while(0);C=d+64|0;c[C>>2]=l;v=c[q>>2]|0;y=v<<2;if(v>>>0>65535){F=(v&1073741823|0)==(v|0)?y:-1}else{F=y}y=XY(F)|0;do{if((y|0)!=0){if((c[y-4>>2]&3|0)==0){break}X2(y|0,0,F|0)}}while(0);c[g>>2]=y;l=d+16|0;v=ab(c[l>>2]|0,c[o>>2]|0)|0;D=v<<1;if(v>>>0>65535){G=(v&2147483647|0)==(v|0)?D:-1}else{G=D}D=XY(G)|0;do{if((D|0)!=0){if((c[D-4>>2]&3|0)==0){break}X2(D|0,0,G|0)}}while(0);c[h>>2]=D;o=c[l>>2]|0;y=o<<2;if(o>>>0>65535){H=(o&1073741823|0)==(o|0)?y:-1}else{H=y}y=XY(H)|0;do{if((y|0)!=0){if((c[y-4>>2]&3|0)==0){break}X2(y|0,0,H|0)}}while(0);c[j>>2]=y;if((c[C>>2]|0)==0){A=0;i=e;return A|0}if((c[h>>2]|0)==0){A=0;i=e;return A|0}D=c[n>>2]|0;o=c[q>>2]|0;v=(D<<16|0)/(o|0)|0;m=c[s>>2]|0;B=c[l>>2]|0;t=((m<<15|0)/(B|0)|0)-32768|0;k=(m<<16|0)/(B|0)|0;if((o|0)>0){m=((D<<15|0)/(o|0)|0)-32768|0;D=0;while(1){c[(c[g>>2]|0)+(D<<2)>>2]=m>>16;z=D<<1;x=z|1;b[(c[C>>2]|0)+(x<<1)>>1]=m>>>2&16383;I=c[C>>2]|0;b[I+(z<<1)>>1]=16384-(b[I+(x<<1)>>1]|0)&65535;x=D+1|0;if((x|0)<(o|0)){m=m+v|0;D=x}else{break}}J=c[l>>2]|0}else{J=B}if((J|0)>0){K=t;L=0}else{break}while(1){c[(c[j>>2]|0)+(L<<2)>>2]=K>>16;D=L<<1;v=D|1;b[(c[h>>2]|0)+(v<<1)>>1]=K>>>2&16383;m=c[h>>2]|0;b[m+(D<<1)>>1]=16384-(b[m+(v<<1)>>1]|0)&65535;v=L+1|0;if((v|0)>=(J|0)){break L5115}K=K+k|0;L=v}}else if((r|0)==1){c[d+68>>2]=1;c[d+72>>2]=1;c[d+84>>2]=1;k=d+88|0;c[k>>2]=1;t=c[q>>2]|0;B=t<<1;if(t>>>0>65535){M=(t&2147483647|0)==(t|0)?B:-1}else{M=B}B=XY(M)|0;do{if((B|0)!=0){if((c[B-4>>2]&3|0)==0){break}X2(B|0,0,M|0)}}while(0);t=d+64|0;c[t>>2]=B;l=c[q>>2]|0;v=l<<2;if(l>>>0>65535){N=(l&1073741823|0)==(l|0)?v:-1}else{N=v}v=XY(N)|0;do{if((v|0)!=0){if((c[v-4>>2]&3|0)==0){break}X2(v|0,0,N|0)}}while(0);c[g>>2]=v;B=d+16|0;l=ab(c[B>>2]|0,c[k>>2]|0)|0;m=l<<1;if(l>>>0>65535){O=(l&2147483647|0)==(l|0)?m:-1}else{O=m}m=XY(O)|0;do{if((m|0)!=0){if((c[m-4>>2]&3|0)==0){break}X2(m|0,0,O|0)}}while(0);c[h>>2]=m;k=c[B>>2]|0;v=k<<2;if(k>>>0>65535){P=(k&1073741823|0)==(k|0)?v:-1}else{P=v}v=XY(P)|0;do{if((v|0)!=0){if((c[v-4>>2]&3|0)==0){break}X2(v|0,0,P|0)}}while(0);c[j>>2]=v;if((c[t>>2]|0)==0){A=0;i=e;return A|0}if((c[h>>2]|0)==0){A=0;i=e;return A|0}m=c[n>>2]|0;k=c[q>>2]|0;l=(m<<16|0)/(k|0)|0;D=c[s>>2]|0;o=c[B>>2]|0;C=((D<<15|0)/(o|0)|0)-32768|0;y=(D<<16|0)/(o|0)|0;if((k|0)>0){D=((m<<15|0)/(k|0)|0)-32768|0;m=0;while(1){c[(c[g>>2]|0)+(m<<2)>>2]=D>>16;b[(c[t>>2]|0)+(m<<1)>>1]=16384;x=m+1|0;if((x|0)<(k|0)){D=D+l|0;m=x}else{break}}R=c[B>>2]|0}else{R=o}L5202:do{if((R|0)>0){m=C;l=0;while(1){c[(c[j>>2]|0)+(l<<2)>>2]=m>>16;b[(c[h>>2]|0)+(l<<1)>>1]=16384;D=l+1|0;if((D|0)>=(R|0)){break L5202}m=m+y|0;l=D}}}while(0);c[w>>2]=6}else if((r|0)==3){y=c[n>>2]|0;C=c[q>>2]|0;if((y|0)>(C|0)){o=((y|0)/(C|0)|0)-1|0;y=o>>>1|o;o=y>>>2|y;y=o>>>4|o;o=y>>>8|y;S=((o>>>16|o)<<3)+8|0}else{S=8}o=d+68|0;c[o>>2]=S;c[d+72>>2]=S;y=d+84|0;c[y>>2]=S;B=d+88|0;c[B>>2]=S;l=ab(S,C)|0;C=l<<1;if(l>>>0>65535){T=(l&2147483647|0)==(l|0)?C:-1}else{T=C}C=XY(T)|0;do{if((C|0)!=0){if((c[C-4>>2]&3|0)==0){break}X2(C|0,0,T|0)}}while(0);l=d+64|0;c[l>>2]=C;m=c[q>>2]|0;D=m<<2;if(m>>>0>65535){V=(m&1073741823|0)==(m|0)?D:-1}else{V=D}D=XY(V)|0;do{if((D|0)!=0){if((c[D-4>>2]&3|0)==0){break}X2(D|0,0,V|0)}}while(0);c[g>>2]=D;C=d+16|0;m=ab(c[C>>2]|0,c[B>>2]|0)|0;k=m<<1;if(m>>>0>65535){W=(m&2147483647|0)==(m|0)?k:-1}else{W=k}k=XY(W)|0;do{if((k|0)!=0){if((c[k-4>>2]&3|0)==0){break}X2(k|0,0,W|0)}}while(0);c[h>>2]=k;B=c[C>>2]|0;D=B<<2;if(B>>>0>65535){X=(B&1073741823|0)==(B|0)?D:-1}else{X=D}D=XY(X)|0;do{if((D|0)!=0){if((c[D-4>>2]&3|0)==0){break}X2(D|0,0,X|0)}}while(0);c[j>>2]=D;if((c[l>>2]|0)==0){A=0;i=e;return A|0}if((c[h>>2]|0)==0){A=0;i=e;return A|0}k=c[n>>2]|0;B=c[q>>2]|0;m=-32768-(S<<15)|0;t=((k<<15|0)/(B|0)|0)+m|0;v=(k<<16|0)/(B|0)|0;x=c[s>>2]|0;I=c[C>>2]|0;z=((x<<15|0)/(I|0)|0)+m|0;m=(x<<16|0)/(I|0)|0;if((k|0)>(B|0)){Y=+(B|0)/+(k|0)}else{Y=1.0}if((x|0)>(I|0)){Z=+(I|0)/+(x|0)}else{Z=1.0}x=c[o>>2]|0;L5251:do{if((B|0)>0){I=x<<15;_=+(x>>1|0);if((x|0)>0){$=0;aa=t}else{k=0;ac=t;while(1){c[(c[g>>2]|0)+(k<<2)>>2]=ac>>16;ad=k+1|0;if((ad|0)<(B|0)){k=ad;ac=ac+v|0}else{break L5251}}}while(1){c[(c[g>>2]|0)+($<<2)>>2]=aa>>16;ae=+((aa&65535)+I|0)*152587890625.0e-16;ac=ab($,x)|0;k=0;do{af=(ae- +(k|0))*3.141592653589793;ag=af/_;ah=Y*af;if(+Q(+ah)<1.0e-4){ai=16384.0}else{ai=+U(+ah)/ah*16384.0}if(+Q(+ag)<1.0e-4){aj=1.0}else{aj=+U(+ag)/ag}b[(c[l>>2]|0)+(k+ac<<1)>>1]=~~(Y*ai*aj);k=k+1|0;}while((k|0)<(x|0));k=$+1|0;if((k|0)<(B|0)){$=k;aa=aa+v|0}else{break}}}}while(0);v=c[C>>2]|0;B=c[y>>2]|0;if((v|0)<=0){break}x=B<<15;_=+(B>>1|0);if((B|0)>0){ak=0;al=z}else{l=0;t=z;while(1){c[(c[j>>2]|0)+(l<<2)>>2]=t>>16;o=l+1|0;if((o|0)>=(v|0)){break L5115}l=o;t=t+m|0}}while(1){c[(c[j>>2]|0)+(ak<<2)>>2]=al>>16;ae=+((al&65535)+x|0)*152587890625.0e-16;t=ab(ak,B)|0;l=0;do{ag=(ae- +(l|0))*3.141592653589793;ah=ag/_;af=Z*ag;if(+Q(+af)<1.0e-4){am=16384.0}else{am=+U(+af)/af*16384.0}if(+Q(+ah)<1.0e-4){an=1.0}else{an=+U(+ah)/ah}b[(c[h>>2]|0)+(l+t<<1)>>1]=~~(Z*am*an);l=l+1|0;}while((l|0)<(B|0));l=ak+1|0;if((l|0)>=(v|0)){break L5115}ak=l;al=al+m|0}}else{A=0;i=e;return A|0}}while(0);hZ(f,c[q>>2]|0,c[n>>2]|0);f=d+16|0;hZ(d+80|0,c[f>>2]|0,c[s>>2]|0);al=(c[n>>2]|0)-(c[d+68>>2]|0)|0;n=c[q>>2]|0;q=0;while(1){if((q|0)>=(n|0)){break}ao=c[(c[g>>2]|0)+(q<<2)>>2]|0;if((ao|0)>(al|0)|(ao|0)<0){u=3740;break}else{q=q+1|0}}if((u|0)==3740){al=c[p>>2]|0;ec(al|0,90040,(ap=i,i=i+16|0,c[ap>>2]=q,c[ap+8>>2]=ao,ap)|0)|0;i=ap;A=0;i=e;return A|0}ao=(c[s>>2]|0)-(c[d+84>>2]|0)|0;d=c[f>>2]|0;f=0;while(1){if((f|0)>=(d|0)){A=1;u=3758;break}aq=c[(c[j>>2]|0)+(f<<2)>>2]|0;if((aq|0)>(ao|0)|(aq|0)<0){break}else{f=f+1|0}}if((u|0)==3758){i=e;return A|0}ec(c[p>>2]|0,95472,(ap=i,i=i+16|0,c[ap>>2]=f,c[ap+8>>2]=aq,ap)|0)|0;i=ap;A=0;i=e;return A|0}function hK(a,c,d,e,f,g){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0;if((e|0)<=0){return}h=f>>1;f=g>>1;if((d|0)<=0){return}g=0;i=a;a=c;while(1){c=0;do{j=b[a+(c<<1)>>1]|0;b[i+(c<<1)>>1]=(j&65535)>>>1&32736|j&31;c=c+1|0;}while((c|0)<(d|0));c=g+1|0;if((c|0)<(e|0)){g=c;i=i+(h<<1)|0;a=a+(f<<1)|0}else{break}}return}function hL(a,c,d,e,f,g){a=a|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0;if((e|0)<=0){return}h=f>>1;f=g>>1;if((d|0)<=0){return}g=0;i=a;a=c;while(1){c=0;do{j=b[a+(c<<1)>>1]|0;b[i+(c<<1)>>1]=j<<1&-64|j&31|(j&65535)>>>4&32;c=c+1|0;}while((c|0)<(d|0));c=g+1|0;if((c|0)<(e|0)){g=c;i=i+(h<<1)|0;a=a+(f<<1)|0}else{break}}return}function hM(a,b,d,f,g,h){a=a|0;b=b|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0;if((f|0)<=0){return}i=g>>2;g=h>>1;if((d|0)<=0){return}h=0;j=a;a=b;while(1){b=0;do{k=e[a+(b<<1)>>1]|0;l=k>>>10&31;m=k>>>5&31;n=k&31;c[j+(b<<2)>>2]=n<<3|n>>>2|(m<<3|m>>>2)<<8|(l<<3|l>>>2)<<16|-16777216;b=b+1|0;}while((b|0)<(d|0));b=h+1|0;if((b|0)<(f|0)){h=b;j=j+(i<<2)|0;a=a+(g<<1)|0}else{break}}return}function hN(a,b,d,f,g,h){a=a|0;b=b|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;if((f|0)<=0){return}i=g>>2;g=h>>1;if((d|0)<=0){return}h=0;j=a;a=b;while(1){b=0;do{k=e[a+(b<<1)>>1]|0;l=k>>>5&63;m=k&31;c[j+(b<<2)>>2]=m<<3|m>>>2|(k>>>11<<3|k>>>13)<<16|(l<<2|l>>>4)<<8|-16777216;b=b+1|0;}while((b|0)<(d|0));b=h+1|0;if((b|0)<(f|0)){h=b;j=j+(i<<2)|0;a=a+(g<<1)|0}else{break}}return}function hO(b,c,d,f,g,h){b=b|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;if((f|0)<=0){return}i=(d|0)>0;j=h>>1;h=0;k=b;b=c;while(1){if(i){c=0;l=k;while(1){m=e[b+(c<<1)>>1]|0;a[l]=(m>>>2&7|m<<3)&255;a[l+1|0]=(m>>>5<<3|m>>>7&7)&255;a[l+2|0]=(m>>>10<<3|m>>>12&7)&255;m=c+1|0;if((m|0)<(d|0)){c=m;l=l+3|0}else{break}}}l=h+1|0;if((l|0)<(f|0)){h=l;k=k+g|0;b=b+(j<<1)|0}else{break}}return}function hP(b,c,d,f,g,h){b=b|0;c=c|0;d=d|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;if((f|0)<=0){return}i=(d|0)>0;j=h>>1;h=0;k=b;b=c;while(1){if(i){c=0;l=k;while(1){m=e[b+(c<<1)>>1]|0;a[l]=(m>>>2&7|m<<3)&255;a[l+1|0]=(m>>>5<<2|m>>>9&3)&255;a[l+2|0]=(m>>>11<<3|m>>>13)&255;m=c+1|0;if((m|0)<(d|0)){c=m;l=l+3|0}else{break}}}l=h+1|0;if((l|0)<(f|0)){h=l;k=k+g|0;b=b+(j<<1)|0}else{break}}return}function hQ(a,b,e,f,g,h){a=a|0;b=b|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;if((f|0)<=0){return}i=(e|0)>0;j=g>>2;g=0;k=a;a=b;while(1){if(i){b=a;l=0;while(1){c[k+(l<<2)>>2]=d[b]|0|(d[b+1|0]|0)<<8|(d[b+2|0]|0)<<16|-16777216;m=l+1|0;if((m|0)<(e|0)){b=b+3|0;l=m}else{break}}}l=g+1|0;if((l|0)<(f|0)){g=l;k=k+(j<<2)|0;a=a+h|0}else{break}}return}function hR(a,d,e,f,g,h){a=a|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0;if((f|0)<=0){return}i=(e|0)>0;j=g>>1;g=h>>2;h=0;k=a;a=d;while(1){if(i){d=0;do{l=c[a+(d<<2)>>2]|0;b[k+(d<<1)>>1]=(l>>>11<<5&992|l>>>3&31|l>>>19<<10&31744)&65535;d=d+1|0;}while((d|0)<(e|0))}d=h+1|0;if((d|0)<(f|0)){h=d;k=k+(j<<1)|0;a=a+(g<<2)|0}else{break}}return}function hS(b,d,e,f,g,h){b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0;if((f|0)<=0){return}i=(e|0)>0;j=h>>2;h=b;b=0;k=d;while(1){if(i){d=h;l=0;while(1){m=c[k+(l<<2)>>2]|0;a[d]=m&255;a[d+1|0]=m>>>8&255;a[d+2|0]=m>>>16&255;m=l+1|0;if((m|0)<(e|0)){d=d+3|0;l=m}else{break}}}l=b+1|0;if((l|0)<(f|0)){h=h+g|0;b=l;k=k+(j<<2)|0}else{break}}return}function hT(a,b,d,e,f,g){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0;if((e|0)<=0){return}h=(d|0)>0;i=f>>2;f=g>>2;g=a;a=0;j=b;while(1){if(h){b=0;do{k=c[j+(b<<2)>>2]|0;c[g+(b<<2)>>2]=k>>>16&255|k&-16711936|k<<16&16711680;b=b+1|0;}while((b|0)<(d|0))}b=a+1|0;if((b|0)<(e|0)){g=g+(i<<2)|0;a=b;j=j+(f<<2)|0}else{break}}return}function hU(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;f=c[a+104>>2]|0;g=a+16|0;h=c[g>>2]|0;if((h|0)<=0){return}i=a+92|0;j=a+116|0;k=a+12|0;l=a+88|0;m=e>>2;e=a+84|0;n=0;o=c[a+80>>2]|0;a=d;d=c[k>>2]|0;p=h;while(1){h=ab(c[j>>2]>>3,c[(c[i>>2]|0)+(n<<2)>>2]|0)|0;if((d|0)>0){q=0;do{r=c[e>>2]|0;if((r|0)==0){s=0;t=0;u=0;v=0}else{w=c[j>>2]>>3;x=0;y=0;z=f+(q+h<<3)|0;A=0;B=0;C=0;while(1){D=c[z>>2]|0;E=c[z+4>>2]|0;F=b[o+(A<<1)>>1]|0;G=ab(((E>>>16|0<<16)&65535)<<16>>16,F)|0;H=ab((E&65535)<<16>>16,F)|0;I=ab(((D>>>16|E<<16)&65535)<<16>>16,F)|0;E=A+1|0;J=G+(C<<16)>>16;K=H+(B<<16)>>16;L=I+(x<<16)>>16;M=(ab((D&65535)<<16>>16,F)|0)+(y<<16)>>16;if(E>>>0<r>>>0){x=L;y=M;z=z+(w<<3)|0;A=E;B=K;C=J}else{break}}s=L>>>3;t=M>>>3;u=K>>>3;v=J>>>3}C=v&65535;B=u&65535;A=s&65535;w=t&65535;if(C<<16>>16>255){N=-16777216}else{N=C<<16>>16<0?0:v<<24}if(B<<16>>16>255){O=16711680}else{O=B<<16>>16<0?0:u<<16&16711680}if(A<<16>>16>255){P=65280}else{P=A<<16>>16<0?0:s<<8&65280}if(w<<16>>16>255){Q=255}else{Q=w<<16>>16<0?0:t&255}c[a+(q<<2)>>2]=O|N|P|Q;q=q+1|0;R=c[k>>2]|0;}while((q|0)<(R|0));S=R;T=c[g>>2]|0}else{S=d;T=p}q=n+1|0;if((q|0)>=(T|0)){break}n=q;o=o+(c[l>>2]<<1)|0;a=a+(m<<2)|0;d=S;p=T}return}function hV(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;if((a[b+60|0]&1)!=0){fu[c[b+56>>2]&255](d,e,c[b+12>>2]|0,c[b+16>>2]|0,c[b+20>>2]|0,c[b+8>>2]|0);return}f=b+44|0;if((c[f>>2]|0)==0){if((c[b+24>>2]|0)==0){fy[c[b+36>>2]&511](b,e,c[b+8>>2]|0)}else{g=b+96|0;h=b+100|0;fu[c[b+48>>2]&255](c[g>>2]|0,e,c[b>>2]|0,c[b+4>>2]|0,c[h>>2]|0,c[b+8>>2]|0);fy[c[b+36>>2]&511](b,c[g>>2]|0,c[h>>2]|0)}h=c[b+40>>2]|0;if((c[b+28>>2]|0)==0){fy[h&511](b,d,c[b+20>>2]|0);return}else{g=b+120|0;i=b+124|0;fy[h&511](b,c[g>>2]|0,c[i>>2]|0);fu[c[b+52>>2]&255](d,c[g>>2]|0,c[b+12>>2]|0,c[b+16>>2]|0,c[b+20>>2]|0,c[i>>2]|0);return}}else{i=c[b+8>>2]|0;if((c[b+24>>2]|0)==0){j=e;k=i}else{g=b+96|0;h=b+100|0;fu[c[b+48>>2]&255](c[g>>2]|0,e,c[b>>2]|0,c[b+4>>2]|0,c[h>>2]|0,i);j=c[g>>2]|0;k=c[h>>2]|0}h=(c[b+28>>2]|0)!=0;g=b+20|0;if(h){l=b+124|0;m=c[b+120>>2]|0}else{l=g;m=d}i=b+12|0;e=b+16|0;fs[c[f>>2]&15](b,m,j,c[i>>2]|0,c[e>>2]|0,c[b>>2]|0,c[b+4>>2]|0,c[l>>2]|0,k);if(!h){return}fu[c[b+52>>2]&255](d,c[b+120>>2]|0,c[i>>2]|0,c[e>>2]|0,c[g>>2]|0,c[b+124>>2]|0);return}}function hW(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0;c=(e|0)>-1?e:-e|0;g=(f|0)>-1?f:-f|0;h=(g|0)<(c|0)?g:c;if((d|0)>0){i=b;j=a;k=0}else{return}while(1){X5(j|0,i|0,h)|0;a=k+1|0;if((a|0)<(d|0)){i=i+f|0;j=j+e|0;k=a}else{break}}return}function hX(a,d,e){a=a|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;f=a+112|0;g=c[f>>2]|0;if((g|0)<=0){return}h=a+64|0;i=a+108|0;j=e>>2;e=a+116|0;k=a+76|0;l=a+68|0;m=a+72|0;n=0;o=c[a+104>>2]|0;a=d;d=c[i>>2]|0;p=g;while(1){if((d|0)>0){g=0;q=c[h>>2]|0;while(1){r=c[(c[k>>2]|0)+(g<<2)>>2]|0;s=c[l>>2]|0;if((s|0)==0){t=0;u=0;v=0;w=0;x=0;y=0;z=0;A=0}else{B=0;C=0;D=0;E=0;F=0;while(1){G=c[a+(E+r<<2)>>2]|0;H=b[q+(E<<1)>>1]|0;I=((ab(G>>>17&32640,H)|0)>>>16)+(F&65535)|0;J=((ab(G>>>9&32640,H)|0)>>>16)+(B&65535)|0;K=((ab(G>>>1&32640,H)|0)>>>16)+(C&65535)|0;L=((ab(G<<7&32640,H)|0)>>>16)+(D&65535)|0;H=E+1|0;if(H>>>0<s>>>0){B=J&65535;C=K&65535;D=L&65535;E=H;F=I&65535}else{break}}F=K&65535;t=J&65535;u=0;v=0<<16|F>>>16;w=F<<16|0>>>16;x=0;y=L&65535;z=I<<16|0>>>16;A=0<<16|0>>>16}F=o+(g<<3)|0;c[F>>2]=y|A|w|u;c[F+4>>2]=x|z|v|t;F=g+1|0;M=c[i>>2]|0;if((F|0)<(M|0)){g=F;q=q+(c[m>>2]<<1)|0}else{break}}N=M;O=c[f>>2]|0}else{N=d;O=p}q=n+1|0;if((q|0)<(O|0)){n=q;o=o+(c[e>>2]>>3<<3)|0;a=a+(j<<2)|0;d=N;p=O}else{break}}return}function hY(a,b,d,e,f,g,h,i,j){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0;a=((g<<15|0)/(e|0)|0)-32768|0;k=(g<<16|0)/(e|0)|0;g=((h<<15|0)/(f|0)|0)-32768|0;l=(h<<16|0)/(f|0)|0;h=(a|0)<0?0:a;a=d;if((f|0)<=0){return}d=j>>2;j=i>>2;if((e|0)<=0){return}i=(g|0)<0?0:g;g=b;b=0;while(1){m=ab(i>>16,d)|0;n=h;o=0;while(1){c[g+(o<<2)>>2]=c[a+((n>>16)+m<<2)>>2];p=o+1|0;if((p|0)<(e|0)){n=n+k|0;o=p}else{break}}o=b+1|0;if((o|0)<(f|0)){i=i+l|0;g=g+(j<<2)|0;b=o}else{break}}return}function hZ(a,b,d){a=a|0;b=b|0;d=d|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=a+4|0;f=d-(c[e>>2]|0)|0;if((b|0)<=0){return}d=a+12|0;g=a|0;h=a+8|0;a=0;do{i=(c[d>>2]|0)+(a<<2)|0;j=c[i>>2]|0;k=j-f|0;l=-j|0;do{if((k|0)>0){c[i>>2]=f;m=c[g>>2]|0;n=ab(c[h>>2]|0,a)|0;o=m+(n<<1)|0;p=c[e>>2]|0;if((k|0)>(p|0)){X2(o|0,0,p<<1|0);break}else{q=o;X9(m+(n+k<<1)|0,q|0,p-k<<1|0);X2(q|0,0,k<<1|0);break}}}while(0);do{if((j|0)<0){k=(c[d>>2]|0)+(a<<2)|0;c[k>>2]=(c[k>>2]|0)-j;k=c[g>>2]|0;i=ab(c[h>>2]|0,a)|0;q=c[e>>2]|0;p=k+(i<<1)|0;if((q|0)<(l|0)){X2(p|0,0,q<<1|0);break}else{X9(p|0,k+(i-j<<1)|0,q+j<<1|0);X2(k+(i+j+(c[e>>2]|0)<<1)|0,0,l<<1|0);break}}}while(0);a=a+1|0;}while((a|0)<(b|0));return}function h_(d,e){d=d|0;e=e|0;var f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aW=0,aX=0,aZ=0,a_=0,a0=0,a1=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0;f=i;i=i+1824|0;h=f|0;j=f+8|0;k=f+1032|0;l=f+1040|0;m=f+1048|0;n=f+1112|0;o=f+1176|0;q=f+1184|0;r=f+1248|0;s=f+1312|0;t=f+1376|0;u=f+1440|0;v=f+1504|0;w=f+1568|0;x=f+1632|0;y=f+1696|0;z=f+1760|0;X2(e|0,0,109528);c[e>>2]=0;A=d+4|0;B=A;while(1){C=c[B>>2]|0;if((C|0)==0){break}if((cL(89960,c[C+4>>2]|0)|0)==0){D=3941;break}else{B=C+12|0}}do{if((D|0)==3941){c[(dS()|0)>>2]=0;B=aV(c[C+8>>2]|0,0,0)|0;if((c[(dS()|0)>>2]|0)!=0){break}if((B|0)==0){E=c[198610]|0;F=(E|0)!=0?E:c[p>>2]|0;a2(66720,55,1,F|0)|0;F=c[198610]|0;E=(F|0)!=0?F:c[p>>2]|0;aY(E|0)|0;G=0;i=f;return G|0}E=B>>>0<16?B:16;B=e+72|0;c[B>>2]=E;F=m|0;H=n|0;I=q|0;J=r|0;K=s|0;L=t|0;M=u|0;N=v|0;O=w|0;P=x|0;Q=y|0;R=z|0;L5543:do{if((E|0)!=0){S=0;while(1){bN(F|0,64,57136,(T=i,i=i+8|0,c[T>>2]=S,T)|0)|0;i=T;L5546:do{if(gI(d,F,e+76+(S*4148|0)|0)|0){bN(H|0,64,56368,(T=i,i=i+8|0,c[T>>2]=S,T)|0)|0;i=T;a[o]=0;if(gJ(d,H,o)|0){c[e+76+(S*4148|0)+4136>>2]=(a[o]&1)!=0?1:2}else{c[e+76+(S*4148|0)+4136>>2]=0}bN(I|0,64,55224,(T=i,i=i+8|0,c[T>>2]=S,T)|0)|0;i=T;U=A;while(1){V=c[U>>2]|0;if((V|0)==0){break}if((cL(I|0,c[V+4>>2]|0)|0)==0){D=3954;break}else{U=V+12|0}}do{if((D|0)==3954){D=0;U=64;W=0;X=J;Y=c[V+8>>2]|0;while(1){Z=U-1|0;if((Z|0)==0){D=3957;break}_=a[Y]|0;a[X]=_;if(_<<24>>24==0){$=W;break}else{U=Z;W=W+1|0;X=X+1|0;Y=Y+1|0}}do{if((D|0)==3957){D=0;a[X]=0;if((a[Y]|0)==0){$=W;break}else{aa=Y;ab=W}while(1){U=aa+1|0;Z=ab+1|0;if((a[U]|0)==0){$=Z;break}else{aa=U;ab=Z}}}}while(0);if($>>>0>=64){break}c[e+76+(S*4148|0)+4140>>2]=h3(J)|0}}while(0);X2(K|0,0,64);bN(L|0,64,54328,(T=i,i=i+8|0,c[T>>2]=S,T)|0)|0;i=T;W=A;while(1){ac=c[W>>2]|0;if((ac|0)==0){break}if((cL(L|0,c[ac+4>>2]|0)|0)==0){D=3964;break}else{W=ac+12|0}}do{if((D|0)==3964){D=0;W=64;Y=0;X=K;Z=c[ac+8>>2]|0;while(1){U=W-1|0;if((U|0)==0){D=3967;break}_=a[Z]|0;a[X]=_;if(_<<24>>24==0){ad=Y;break}else{W=U;Y=Y+1|0;X=X+1|0;Z=Z+1|0}}do{if((D|0)==3967){D=0;a[X]=0;if((a[Z]|0)==0){ad=Y;break}else{ae=Z;af=Y}while(1){W=ae+1|0;U=af+1|0;if((a[W]|0)==0){ad=U;break}else{ae=W;af=U}}}}while(0);if(ad>>>0>=64){break}c[e+76+(S*4148|0)+4144>>2]=aV(K|0,0,0)|0}}while(0);X2(M|0,0,64);X2(N|0,0,64);X2(O|0,0,64);bN(P|0,64,90392,(T=i,i=i+8|0,c[T>>2]=S,T)|0)|0;i=T;Y=A;while(1){ag=c[Y>>2]|0;if((ag|0)==0){break}if((cL(P|0,c[ag+4>>2]|0)|0)==0){D=3974;break}else{Y=ag+12|0}}L5586:do{if((D|0)==3974){D=0;Y=64;Z=M;X=c[ag+8>>2]|0;while(1){U=Y-1|0;if((U|0)==0){break}W=a[X]|0;a[Z]=W;if(W<<24>>24==0){break L5586}else{Y=U;Z=Z+1|0;X=X+1|0}}a[Z]=0;if((a[X]|0)==0){break}else{ah=X}do{ah=ah+1|0;}while((a[ah]|0)!=0)}}while(0);bN(P|0,64,90152,(T=i,i=i+8|0,c[T>>2]=S,T)|0)|0;i=T;X=A;while(1){ai=c[X>>2]|0;if((ai|0)==0){break}if((cL(P|0,c[ai+4>>2]|0)|0)==0){D=3982;break}else{X=ai+12|0}}L5598:do{if((D|0)==3982){D=0;X=64;Z=N;Y=c[ai+8>>2]|0;while(1){U=X-1|0;if((U|0)==0){break}W=a[Y]|0;a[Z]=W;if(W<<24>>24==0){break L5598}else{X=U;Z=Z+1|0;Y=Y+1|0}}a[Z]=0;if((a[Y]|0)==0){break}else{aj=Y}do{aj=aj+1|0;}while((a[aj]|0)!=0)}}while(0);bN(P|0,64,89800,(T=i,i=i+8|0,c[T>>2]=S,T)|0)|0;i=T;Y=A;while(1){ak=c[Y>>2]|0;if((ak|0)==0){break}if((cL(P|0,c[ak+4>>2]|0)|0)==0){D=3990;break}else{Y=ak+12|0}}L5610:do{if((D|0)==3990){D=0;Y=64;Z=O;X=c[ak+8>>2]|0;while(1){U=Y-1|0;if((U|0)==0){break}W=a[X]|0;a[Z]=W;if(W<<24>>24==0){break L5610}else{Y=U;Z=Z+1|0;X=X+1|0}}a[Z]=0;if((a[X]|0)==0){break}else{al=X}do{al=al+1|0;}while((a[al]|0)!=0)}}while(0);L5619:do{if((a[M]|0)==0){if((a[N]|0)!=0){break}if((a[O]|0)==0){am=1;break L5546}}else{X=64;Z=N;Y=M;while(1){U=X-1|0;if((U|0)==0){D=4e3;break}W=a[Y]|0;a[Z]=W;if(W<<24>>24==0){an=64;ao=O;ap=M;break}else{X=U;Z=Z+1|0;Y=Y+1|0}}do{if((D|0)==4e3){D=0;a[Z]=0;if((a[Y]|0)==0){an=64;ao=O;ap=M;break}else{aq=Y}while(1){X=aq+1|0;if((a[X]|0)==0){an=64;ao=O;ap=M;break}else{aq=X}}}}while(0);while(1){Y=an-1|0;if((Y|0)==0){break}Z=a[ap]|0;a[ao]=Z;if(Z<<24>>24==0){break L5619}else{an=Y;ao=ao+1|0;ap=ap+1|0}}a[ao]=0;if((a[ap]|0)==0){break}else{ar=ap}do{ar=ar+1|0;}while((a[ar]|0)!=0)}}while(0);a[e+76+(S*4148|0)+4104|0]=1;Y=e+76+(S*4148|0)+4108|0;c[Y>>2]=0;Z=e+76+(S*4148|0)+4112|0;c[Z>>2]=0;X=e+76+(S*4148|0)+4116|0;g[X>>2]=1.0;U=e+76+(S*4148|0)+4120|0;g[U>>2]=1.0;bN(R|0,64,37384,(T=i,i=i+8|0,c[T>>2]=S,T)|0)|0;i=T;gJ(d,R,e+76+(S*4148|0)+4132|0)|0;do{if((a[N]|0)!=0){if((cL(N|0,35032)|0)==0){c[Y>>2]=0;break}if((cL(N|0,34608)|0)==0){c[Y>>2]=2;break}if((cL(N|0,34160)|0)==0){c[Y>>2]=1;break}else{W=c[198610]|0;_=(W|0)!=0?W:c[p>>2]|0;a2(89496,40,1,_|0)|0;_=c[198610]|0;W=(_|0)!=0?_:c[p>>2]|0;aY(W|0)|0;am=0;break L5546}}}while(0);do{if((a[O]|0)!=0){if((cL(O|0,35032)|0)==0){c[Z>>2]=0;break}if((cL(O|0,34608)|0)==0){c[Z>>2]=2;break}if((cL(O|0,34160)|0)==0){c[Z>>2]=1;break}else{W=c[198610]|0;_=(W|0)!=0?W:c[p>>2]|0;a2(89496,40,1,_|0)|0;_=c[198610]|0;W=(_|0)!=0?_:c[p>>2]|0;aY(W|0)|0;am=0;break L5546}}}while(0);W=(c[Y>>2]|0)==1;bN(Q|0,64,89216,(T=i,i=i+8|0,c[T>>2]=S,T)|0)|0;i=T;L5660:do{if(W){_=A;while(1){as=c[_>>2]|0;if((as|0)==0){break}if((cL(Q|0,c[as+4>>2]|0)|0)==0){D=4025;break}else{_=as+12|0}}do{if((D|0)==4025){D=0;c[(dS()|0)>>2]=0;_=a$(c[as+8>>2]|0,0,0)|0;if((c[(dS()|0)>>2]|0)!=0){break}c[e+76+(S*4148|0)+4124>>2]=_;break L5660}}while(0);bN(Q|0,64,88928,(T=i,i=i+8|0,c[T>>2]=S,T)|0)|0;i=T;_=A;while(1){at=c[_>>2]|0;if((at|0)==0){break L5660}if((cL(Q|0,c[at+4>>2]|0)|0)==0){break}else{_=at+12|0}}c[(dS()|0)>>2]=0;_=a$(c[at+8>>2]|0,0,0)|0;if((c[(dS()|0)>>2]|0)!=0){break}c[e+76+(S*4148|0)+4124>>2]=_}else{_=A;while(1){au=c[_>>2]|0;if((au|0)==0){break}if((cL(Q|0,c[au+4>>2]|0)|0)==0){D=4034;break}else{_=au+12|0}}if((D|0)==4034){D=0;g[X>>2]=+X0(c[au+8>>2]|0);break}bN(Q|0,64,88928,(T=i,i=i+8|0,c[T>>2]=S,T)|0)|0;i=T;_=A;while(1){av=c[_>>2]|0;if((av|0)==0){break L5660}if((cL(Q|0,c[av+4>>2]|0)|0)==0){break}else{_=av+12|0}}g[X>>2]=+X0(c[av+8>>2]|0)}}while(0);X=(c[Z>>2]|0)==1;bN(Q|0,64,89216,(T=i,i=i+8|0,c[T>>2]=S,T)|0)|0;i=T;if(X){aw=A}else{X=A;while(1){ax=c[X>>2]|0;if((ax|0)==0){break}if((cL(Q|0,c[ax+4>>2]|0)|0)==0){D=4051;break}else{X=ax+12|0}}if((D|0)==4051){D=0;g[U>>2]=+X0(c[ax+8>>2]|0);am=1;break}bN(Q|0,64,88664,(T=i,i=i+8|0,c[T>>2]=S,T)|0)|0;i=T;X=A;while(1){ay=c[X>>2]|0;if((ay|0)==0){am=1;break L5546}if((cL(Q|0,c[ay+4>>2]|0)|0)==0){break}else{X=ay+12|0}}g[U>>2]=+X0(c[ay+8>>2]|0);am=1;break}while(1){az=c[aw>>2]|0;if((az|0)==0){break}if((cL(Q|0,c[az+4>>2]|0)|0)==0){D=4042;break}else{aw=az+12|0}}do{if((D|0)==4042){D=0;c[(dS()|0)>>2]=0;U=a$(c[az+8>>2]|0,0,0)|0;if((c[(dS()|0)>>2]|0)!=0){break}c[e+76+(S*4148|0)+4128>>2]=U;am=1;break L5546}}while(0);bN(Q|0,64,88664,(T=i,i=i+8|0,c[T>>2]=S,T)|0)|0;i=T;U=A;while(1){aA=c[U>>2]|0;if((aA|0)==0){am=1;break L5546}if((cL(Q|0,c[aA+4>>2]|0)|0)==0){break}else{U=aA+12|0}}c[(dS()|0)>>2]=0;U=a$(c[aA+8>>2]|0,0,0)|0;if((c[(dS()|0)>>2]|0)!=0){am=1;break}c[e+76+(S*4148|0)+4128>>2]=U;am=1}else{U=c[198610]|0;ec(((U|0)!=0?U:c[p>>2]|0)|0,90656,(T=i,i=i+8|0,c[T>>2]=F,T)|0)|0;i=T;U=c[198610]|0;aY(((U|0)!=0?U:c[p>>2]|0)|0)|0;am=0}}while(0);if(!am){G=0;break}S=S+1|0;if(S>>>0>=(c[B>>2]|0)>>>0){break L5543}}i=f;return G|0}}while(0);B=j|0;Q=A;while(1){aB=c[Q>>2]|0;if((aB|0)==0){break}if((cL(52584,c[aB+4>>2]|0)|0)==0){D=4061;break}else{Q=aB+12|0}}L5714:do{if((D|0)==4061){Q=1024;O=0;N=B;R=c[aB+8>>2]|0;while(1){M=Q-1|0;if((M|0)==0){D=4064;break}P=a[R]|0;a[N]=P;if(P<<24>>24==0){aC=O;break}else{Q=M;O=O+1|0;N=N+1|0;R=R+1|0}}do{if((D|0)==4064){a[N]=0;if((a[R]|0)==0){aC=O;break}else{aD=R;aE=O}while(1){Q=aD+1|0;M=aE+1|0;if((a[Q]|0)==0){aC=M;break}else{aD=Q;aE=M}}}}while(0);if(aC>>>0>=1024){break}O=d8(B|0,53448,k|0)|0;if((O|0)==0){break}R=e+66444|0;N=O;L5726:while(1){O=c[R>>2]|0;if(O>>>0>=8){break L5714}M=e+66448+(O*4168|0)+64|0;O=A;while(1){aF=c[O>>2]|0;if((aF|0)==0){break L5726}if((cL(N|0,c[aF+4>>2]|0)|0)==0){break}else{O=aF+12|0}}O=4096;Q=0;P=M;E=c[aF+8>>2]|0;while(1){S=O-1|0;if((S|0)==0){D=4076;break}U=a[E]|0;a[P]=U;if(U<<24>>24==0){aG=Q;break}else{O=S;Q=Q+1|0;P=P+1|0;E=E+1|0}}do{if((D|0)==4076){D=0;a[P]=0;if((a[E]|0)==0){aG=Q;break}else{aH=E;aI=Q}while(1){O=aH+1|0;M=aI+1|0;if((a[O]|0)==0){aG=M;break}else{aH=O;aI=M}}}}while(0);if(aG>>>0>=4096){break}Q=64;E=e+66448+((c[R>>2]|0)*4168|0)|0;P=N;while(1){M=Q-1|0;if((M|0)==0){D=4083;break}O=a[P]|0;a[E]=O;if(O<<24>>24==0){break}else{Q=M;E=E+1|0;P=P+1|0}}do{if((D|0)==4083){D=0;a[E]=0;if((a[P]|0)==0){break}else{aJ=P}do{aJ=aJ+1|0;}while((a[aJ]|0)!=0)}}while(0);bN(F|0,64,51752,(T=i,i=i+8|0,c[T>>2]=N,T)|0)|0;i=T;a[l]=0;if(gJ(d,F,l)|0){c[e+66448+((c[R>>2]|0)*4168|0)+4160>>2]=(a[l]&1)!=0?1:2}else{c[e+66448+((c[R>>2]|0)*4168|0)+4160>>2]=0}bN(H|0,64,50792,(T=i,i=i+8|0,c[T>>2]=N,T)|0)|0;i=T;P=A;while(1){aK=c[P>>2]|0;if((aK|0)==0){break}if((cL(H|0,c[aK+4>>2]|0)|0)==0){D=4091;break}else{P=aK+12|0}}do{if((D|0)==4091){D=0;P=64;E=0;Q=I;M=c[aK+8>>2]|0;while(1){O=P-1|0;if((O|0)==0){D=4094;break}S=a[M]|0;a[Q]=S;if(S<<24>>24==0){aL=E;break}else{P=O;E=E+1|0;Q=Q+1|0;M=M+1|0}}do{if((D|0)==4094){D=0;a[Q]=0;if((a[M]|0)==0){aL=E;break}else{aM=M;aN=E}while(1){P=aM+1|0;O=aN+1|0;if((a[P]|0)==0){aL=O;break}else{aM=P;aN=O}}}}while(0);if(aL>>>0>=64){break}E=h3(I)|0;c[e+66448+((c[R>>2]|0)*4168|0)+4164>>2]=E}}while(0);c[R>>2]=(c[R>>2]|0)+1;E=d8(0,53448,k|0)|0;if((E|0)==0){break L5714}else{N=E}}R=c[198610]|0;ec(((R|0)!=0?R:c[p>>2]|0)|0,91576,(T=i,i=i+8|0,c[T>>2]=N,T)|0)|0;i=T;R=c[198610]|0;aY(((R|0)!=0?R:c[p>>2]|0)|0)|0;G=0;i=f;return G|0}}while(0);R=A;while(1){aO=c[R>>2]|0;if((aO|0)==0){G=1;D=4182;break}if((cL(48296,c[aO+4>>2]|0)|0)==0){break}else{R=aO+12|0}}if((D|0)==4182){i=f;return G|0}R=1024;E=0;M=B;Q=c[aO+8>>2]|0;while(1){O=R-1|0;if((O|0)==0){D=4105;break}P=a[Q]|0;a[M]=P;if(P<<24>>24==0){aP=E;break}else{R=O;E=E+1|0;M=M+1|0;Q=Q+1|0}}do{if((D|0)==4105){a[M]=0;if((a[Q]|0)==0){aP=E;break}else{aQ=Q;aR=E}while(1){R=aQ+1|0;O=aR+1|0;if((a[R]|0)==0){aP=O;break}else{aQ=R;aR=O}}}}while(0);if(aP>>>0>=1024){G=1;i=f;return G|0}E=d8(B|0,53448,h|0)|0;L5789:do{if((E|0)!=0){Q=e+99792|0;M=E;L5791:while(1){N=c[Q>>2]|0;if(N>>>0>=64){break L5789}O=64;R=e+99796+(N*80|0)|0;P=M;while(1){S=O-1|0;if((S|0)==0){D=4114;break}U=a[P]|0;a[R]=U;if(U<<24>>24==0){break}else{O=S;R=R+1|0;P=P+1|0}}do{if((D|0)==4114){D=0;a[R]=0;if((a[P]|0)==0){break}else{aS=P}do{aS=aS+1|0;}while((a[aS]|0)!=0)}}while(0);bN(F|0,64,43960,(T=i,i=i+8|0,c[T>>2]=M,T)|0)|0;i=T;bN(H|0,64,43288,(T=i,i=i+8|0,c[T>>2]=M,T)|0)|0;i=T;bN(I|0,64,42584,(T=i,i=i+8|0,c[T>>2]=M,T)|0)|0;i=T;bN(J|0,64,41976,(T=i,i=i+8|0,c[T>>2]=M,T)|0)|0;i=T;bN(K|0,64,41352,(T=i,i=i+8|0,c[T>>2]=M,T)|0)|0;i=T;P=A;while(1){aT=c[P>>2]|0;if((aT|0)==0){D=4125;break L5791}if((cL(F|0,c[aT+4>>2]|0)|0)==0){break}else{P=aT+12|0}}P=64;R=0;O=L;S=c[aT+8>>2]|0;while(1){U=P-1|0;if((U|0)==0){D=4122;break}X=a[S]|0;a[O]=X;if(X<<24>>24==0){aU=R;break}else{P=U;R=R+1|0;O=O+1|0;S=S+1|0}}do{if((D|0)==4122){D=0;a[O]=0;if((a[S]|0)==0){aU=R;break}else{aW=S;aX=R}while(1){P=aW+1|0;U=aX+1|0;if((a[P]|0)==0){aU=U;break}else{aW=P;aX=U}}}}while(0);if(aU>>>0>=64){D=4125;break}do{if((cL(L|0,41056)|0)==0){c[e+99796+(N*80|0)+68>>2]=0;aZ=A;D=4139}else{if((cL(L|0,40360)|0)==0){c[e+99796+(N*80|0)+68>>2]=2;aZ=A;D=4139;break}if((cL(L|0,39488)|0)==0){c[e+99796+(N*80|0)+68>>2]=3;aZ=A;D=4139;break}if((cL(L|0,38888)|0)==0){c[e+99796+(N*80|0)+68>>2]=1;aZ=A;D=4139;break}if((cL(L|0,38264)|0)==0){c[e+99796+(N*80|0)+68>>2]=4;aZ=A;D=4139;break}if((cL(L|0,37952)|0)!=0){D=4137;break L5791}c[e+99796+(N*80|0)+68>>2]=5;a_=A}}while(0);L5831:do{if((D|0)==4139){while(1){D=0;a0=c[aZ>>2]|0;if((a0|0)==0){a1=A;break}if((cL(I|0,c[a0+4>>2]|0)|0)==0){D=4141;break}else{aZ=a0+12|0;D=4139}}do{if((D|0)==4141){D=0;c[(dS()|0)>>2]=0;R=aV(c[a0+8>>2]|0,0,0)|0;if((c[(dS()|0)>>2]|0)!=0){a1=A;break}if((R|0)==1){c[e+99796+(N*80|0)+72>>2]=2;a_=A;break L5831}else if((R|0)==2){c[e+99796+(N*80|0)+72>>2]=3;a_=A;break L5831}else{D=4145;break L5791}}}while(0);while(1){a3=c[a1>>2]|0;if((a3|0)==0){D=4150;break L5791}if((cL(H|0,c[a3+4>>2]|0)|0)==0){break}else{a1=a3+12|0}}c[(dS()|0)>>2]=0;R=aV(c[a3+8>>2]|0,0,16)|0;if((c[(dS()|0)>>2]|0)!=0){D=4150;break L5791}c[e+99796+(N*80|0)+72>>2]=1;c[e+99796+(N*80|0)+64>>2]=R;a_=A}}while(0);while(1){a4=c[a_>>2]|0;if((a4|0)==0){a5=A;break}if((cL(J|0,c[a4+4>>2]|0)|0)==0){D=4153;break}else{a_=a4+12|0}}do{if((D|0)==4153){D=0;c[(dS()|0)>>2]=0;R=aV(c[a4+8>>2]|0,0,16)|0;if((c[(dS()|0)>>2]|0)!=0){a5=A;break}b[e+99796+(N*80|0)+76>>1]=R&65535;a5=A}}while(0);while(1){a6=c[a5>>2]|0;if((a6|0)==0){break}if((cL(K|0,c[a6+4>>2]|0)|0)==0){D=4157;break}else{a5=a6+12|0}}do{if((D|0)==4157){D=0;c[(dS()|0)>>2]=0;R=aV(c[a6+8>>2]|0,0,16)|0;if((c[(dS()|0)>>2]|0)!=0){break}b[e+99796+(N*80|0)+78>>1]=R&65535}}while(0);c[Q>>2]=(c[Q>>2]|0)+1;M=d8(0,53448,h|0)|0;if((M|0)==0){break L5789}}if((D|0)==4137){M=c[198610]|0;Q=(M|0)!=0?M:c[p>>2]|0;a2(92488,39,1,Q|0)|0;Q=c[198610]|0;M=(Q|0)!=0?Q:c[p>>2]|0;aY(M|0)|0;G=0;i=f;return G|0}else if((D|0)==4145){M=c[198610]|0;a2(26056,52,1,((M|0)!=0?M:c[p>>2]|0)|0)|0;M=c[198610]|0;aY(((M|0)!=0?M:c[p>>2]|0)|0)|0;G=0;i=f;return G|0}else if((D|0)==4125){M=c[198610]|0;a2(92792,54,1,((M|0)!=0?M:c[p>>2]|0)|0)|0;M=c[198610]|0;aY(((M|0)!=0?M:c[p>>2]|0)|0)|0;G=0;i=f;return G|0}else if((D|0)==4150){M=c[198610]|0;a2(92064,54,1,((M|0)!=0?M:c[p>>2]|0)|0)|0;M=c[198610]|0;aY(((M|0)!=0?M:c[p>>2]|0)|0)|0;G=0;i=f;return G|0}}}while(0);gI(d,5e4,e+104916|0)|0;K=e+109016|0;J=A;while(1){a7=c[J>>2]|0;if((a7|0)==0){G=1;D=4180;break}if((cL(49120,c[a7+4>>2]|0)|0)==0){break}else{J=a7+12|0}}if((D|0)==4180){i=f;return G|0}J=512;H=K;I=c[a7+8>>2]|0;while(1){L=J-1|0;if((L|0)==0){break}F=a[I]|0;a[H]=F;if(F<<24>>24==0){G=1;D=4169;break}else{J=L;H=H+1|0;I=I+1|0}}if((D|0)==4169){i=f;return G|0}a[H]=0;if((a[I]|0)==0){G=1;i=f;return G|0}else{a8=I}while(1){J=a8+1|0;if((a[J]|0)==0){G=1;break}else{a8=J}}i=f;return G|0}}while(0);a8=c[198610]|0;a2(95400,50,1,((a8|0)!=0?a8:c[p>>2]|0)|0)|0;a8=c[198610]|0;aY(((a8|0)!=0?a8:c[p>>2]|0)|0)|0;G=0;i=f;return G|0}function h$(){return 798256|0}function h0(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;f=i;i=i+8200|0;g=f|0;h=f+4104|0;c[g>>2]=b;j=f+8|0;k=e+8|0;while(1){l=c[k>>2]|0;if((l|0)==0){break}if((cL(75296,c[l>>2]|0)|0)==0){m=4187;break}else{k=l+8|0}}do{if((m|0)==4187){k=c[l+4>>2]|0;if((k|0)==0){break}else{n=4096;o=0;q=j;r=k}while(1){k=n-1|0;if((k|0)==0){m=4191;break}e=a[r]|0;a[q]=e;if(e<<24>>24==0){s=o;break}else{n=k;o=o+1|0;q=q+1|0;r=r+1|0}}do{if((m|0)==4191){a[q]=0;if((a[r]|0)==0){s=o;break}else{t=r;u=o}while(1){k=t+1|0;e=u+1|0;if((a[k]|0)==0){s=e;break}else{t=k;u=e}}}}while(0);if(s>>>0>=4096){i=f;return b|0}XZ(b);c[g>>2]=0;e=h|0;gB(e,d,j);if((a[637400]&1)==0){v=gg(e,g)|0;w=(v|0)>-1;x=c[g>>2]|0;y=w?x:0;i=f;return y|0}k=c[198610]|0;ec(((k|0)!=0?k:c[p>>2]|0)|0,93184,(k=i,i=i+8|0,c[k>>2]=e,k)|0)|0;i=k;k=c[198610]|0;aY(((k|0)!=0?k:c[p>>2]|0)|0)|0;v=gg(e,g)|0;w=(v|0)>-1;x=c[g>>2]|0;y=w?x:0;i=f;return y|0}}while(0);a[j]=0;i=f;return b|0}function h1(a,b){a=a|0;b=b|0;var c=0,d=0;if((a|0)==0){c=b;return c|0}d=cg(a|0,46)|0;a=(d|0)==0?798256:d+1|0;if((cL(a|0,55776)|0)==0){c=0;return c|0}if((cL(a|0,94616)|0)==0){c=0;return c|0}if((cL(a|0,35576)|0)==0){c=2;return c|0}if((cL(a|0,93544)|0)==0){c=2;return c|0}else{return((cL(a|0,75176)|0)==0?2:b)|0}return 0}function h2(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;e=i;i=i+4096|0;f=e|0;g=b+72|0;h=c[g>>2]|0;if((h|0)!=0){j=f|0;k=0;l=h;while(1){h=b+76+(k*4148|0)|0;if((a[h]|0)==0){m=l}else{n=4096;o=j;p=h;while(1){q=n-1|0;if((q|0)==0){r=4221;break}s=a[p]|0;a[o]=s;if(s<<24>>24==0){break}else{n=q;o=o+1|0;p=p+1|0}}do{if((r|0)==4221){r=0;a[o]=0;if((a[p]|0)==0){break}else{t=p}do{t=t+1|0;}while((a[t]|0)!=0)}}while(0);gB(h,d,j);m=c[g>>2]|0}p=k+1|0;if(p>>>0<m>>>0){k=p;l=m}else{break}}}m=b+66444|0;if((c[m>>2]|0)!=0){l=f|0;k=0;do{g=b+66448+(k*4168|0)+64|0;j=4096;t=l;p=g;while(1){o=j-1|0;if((o|0)==0){r=4228;break}n=a[p]|0;a[t]=n;if(n<<24>>24==0){break}else{j=o;t=t+1|0;p=p+1|0}}do{if((r|0)==4228){r=0;a[t]=0;if((a[p]|0)==0){break}else{u=p}do{u=u+1|0;}while((a[u]|0)!=0)}}while(0);gB(g,d,l);k=k+1|0;}while(k>>>0<(c[m>>2]|0)>>>0)}m=b+104916|0;if((a[m]|0)==0){i=e;return}b=f|0;f=4096;k=b;l=m;while(1){u=f-1|0;if((u|0)==0){r=4235;break}p=a[l]|0;a[k]=p;if(p<<24>>24==0){break}else{f=u;k=k+1|0;l=l+1|0}}do{if((r|0)==4235){a[k]=0;if((a[l]|0)==0){break}else{v=l}do{v=v+1|0;}while((a[v]|0)!=0)}}while(0);gB(m,d,b);i=e;return}function h3(a){a=a|0;var b=0,d=0,e=0;b=i;if((cL(a|0,33704)|0)==0){d=0;i=b;return d|0}if((cL(a|0,33376)|0)==0){d=1;i=b;return d|0}if((cL(a|0,32920)|0)==0){d=2;i=b;return d|0}if((cL(a|0,32496)|0)==0){d=3;i=b;return d|0}e=c[198610]|0;ec(((e|0)!=0?e:c[p>>2]|0)|0,91040,(e=i,i=i+8|0,c[e>>2]=a,e)|0)|0;i=e;e=c[198610]|0;aY(((e|0)!=0?e:c[p>>2]|0)|0)|0;d=0;i=b;return d|0}function h4(b,e){b=b|0;e=+e;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0;b=XY(1032)|0;if((b|0)==0){f=0;return f|0}if((c[b-4>>2]&3|0)!=0){X2(b|0,0,1032)}g=b;h=~~+bH(+(e/10.0));i=b;j=(h|0)==0?1:h;c[i>>2]=j;h=XY(ab(j*12800|0,j)|0)|0;k=b+1028|0;c[k>>2]=h;if((h|0)==0){XZ(b);f=0;return f|0}else{l=0;m=j;n=h}while(1){h=ab(ab(m*50|0,m)|0,l)|0;c[g+4+(l<<2)>>2]=n+h;j=l*7|0;o=c[i>>2]|0;p=0;q=o;while(1){r=p*5|0;s=0;t=q;u=q;while(1){v=s+r|0;w=((1<<(v&7)&(d[17392+((v>>>3)+j)|0]|0)|0)!=0)<<31>>31;if((t|0)==0){x=0;y=u}else{v=0;z=u;while(1){if((z|0)==0){A=0}else{B=v+h|0;C=0;D=z;while(1){a[n+(B+(ab((((ab(D,p)|0)+C|0)*5|0)+s|0,D)|0))|0]=w;E=C+1|0;if(E>>>0<o>>>0){C=E;D=o}else{A=o;break}}}D=v+1|0;if(D>>>0<A>>>0){v=D;z=A}else{x=A;y=A;break}}}z=s+1|0;if(z>>>0<5){s=z;t=x;u=y}else{break}}u=p+1|0;if(u>>>0<10){p=u;q=y}else{break}}q=l+1|0;if(q>>>0>=256){f=b;break}l=q;m=o;n=c[k>>2]|0}return f|0}function h5(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;f=e|0;c[f>>2]=0;e=X1(d|0)|0;if((e|0)==0){return}g=b+4|0;h=b;b=0;i=0;j=0;while(1){k=XY(52)|0;if((k|0)==0){l=4283;break}if((c[k-4>>2]&3|0)!=0){X2(k|0,0,52)}m=k;c[k>>2]=c[g+(a[d+i|0]<<2)>>2];n=c[h>>2]|0;o=n*5|0;c[k+4>>2]=o;p=n*10|0;c[k+8>>2]=p;c[k+12>>2]=o;c[k+32>>2]=o;c[k+36>>2]=p;c[k+40>>2]=0;c[k+44>>2]=p;c[k+24>>2]=b;c[k+28>>2]=0;c[k+48>>2]=0;if((i|0)==0){c[f>>2]=m;q=c[h>>2]|0}else{c[j+48>>2]=m;q=n}n=i+1|0;if(n>>>0<e>>>0){b=(q*6|0)+b|0;i=n;j=m}else{l=4282;break}}if((l|0)==4283){return}else if((l|0)==4282){return}}function h6(a,b){a=a|0;b=b|0;var d=0;a=b|0;b=c[a>>2]|0;if((b|0)==0){c[a>>2]=0;return}else{d=b}while(1){b=c[d+48>>2]|0;XZ(d);if((b|0)==0){break}else{d=b}}c[a>>2]=0;return}function h7(a){a=a|0;XZ(c[a+1028>>2]|0);XZ(a);return}function h8(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0;h=i;i=i+1912|0;j=h|0;k=h+16|0;l=h+784|0;m=h+792|0;n=h+840|0;o=h+856|0;q=h+1880|0;r=h+1888|0;s=h+1904|0;if((bu(b|0,85688)|0)!=0){c[s>>2]=0;if((gg(b,s)|0)<0){t=c[198610]|0;u=(t|0)!=0?t:c[p>>2]|0;ec(u|0,55816,(v=i,i=i+8|0,c[v>>2]=b,v)|0)|0;i=v;u=c[198610]|0;t=(u|0)!=0?u:c[p>>2]|0;aY(t|0)|0;w=0;i=h;return w|0}t=c[s>>2]|0;if((a[t+2|0]|0)!=2){s=c[198610]|0;u=(s|0)!=0?s:c[p>>2]|0;a2(46640,56,1,u|0)|0;u=c[198610]|0;s=(u|0)!=0?u:c[p>>2]|0;aY(s|0)|0;XZ(t);w=0;i=h;return w|0}s=a[t+16|0]|0;u=d[t+13|0]<<8|d[t+12|0];x=d[t+15|0]<<8|d[t+14|0];if((a[637400]&1)!=0){y=s&255;z=c[198610]|0;A=(z|0)!=0?z:c[p>>2]|0;ec(A|0,39960,(v=i,i=i+24|0,c[v>>2]=u,c[v+8>>2]=x,c[v+16>>2]=y,v)|0)|0;i=v;y=c[198610]|0;A=(y|0)!=0?y:c[p>>2]|0;aY(A|0)|0}A=ab(x,u)|0;y=XY(A<<2)|0;z=y;B=e+8|0;c[B>>2]=z;c[e>>2]=u;c[e+4>>2]=x;if((y|0)==0){y=c[198610]|0;x=(y|0)!=0?y:c[p>>2]|0;a2(35472,52,1,x|0)|0;x=c[198610]|0;y=(x|0)!=0?x:c[p>>2]|0;aY(y|0)|0;XZ(t);w=0;i=h;return w|0}L6054:do{if((s<<24>>24|0)==32){if((A|0)==0){break}else{C=0;D=z}while(1){y=C<<2;c[D+(C<<2)>>2]=d[t+((y|1)+18)|0]<<8|d[t+(y+18)|0]<<g|d[t+((y|2)+18)|0]<<f|d[t+((y|3)+18)|0]<<24;y=C+1|0;if(y>>>0>=A>>>0){break L6054}C=y;D=c[B>>2]|0}}else if((s<<24>>24|0)==24){if((A|0)==0){break}else{E=0;F=z}while(1){y=E*3|0;c[F+(E<<2)>>2]=d[t+(y+18)|0]<<g|d[t+(y+19)|0]<<8|d[t+(y+20)|0]<<f|-16777216;y=E+1|0;if(y>>>0>=A>>>0){break L6054}E=y;F=c[B>>2]|0}}else{y=c[198610]|0;a2(30856,88,1,((y|0)!=0?y:c[p>>2]|0)|0)|0;y=c[198610]|0;aY(((y|0)!=0?y:c[p>>2]|0)|0)|0;XZ(t);XZ(c[B>>2]|0);c[B>>2]=0;w=0;i=h;return w|0}}while(0);XZ(t);w=1;i=h;return w|0}if((bu(b|0,94768)|0)==0){w=0;i=h;return w|0}if((a[637400]&1)!=0){t=c[198610]|0;B=(t|0)!=0?t:c[p>>2]|0;a2(66424,38,1,B|0)|0;B=c[198610]|0;t=(B|0)!=0?B:c[p>>2]|0;aY(t|0)|0}t=e+8|0;B=e|0;F=e+4|0;e=n;E=q|0;q=r;c[t>>2]=0;c[B>>2]=0;c[F>>2]=0;A=c5(b|0,23072)|0;if((A|0)==0){w=0;i=h;return w|0}eo(A|0,0,2)|0;b=cb(A|0)|0;ew(A|0);X2(m|0,0,48);c[e>>2]=c[476];c[e+4>>2]=c[477];c[e+8>>2]=c[478];c[e+12>>2]=c[479];X2(o|0,0,1024);if((d6(E|0,1,8,A|0)|0)==8){L6080:do{if((Ya(E|0,6928,8)|0)==0){z=cb(A|0)|0;do{if((z|0)<(b|0)&(z|0)>-1){s=l;D=s+1|0;C=s+2|0;y=s+3|0;x=r|0;u=r+4|0;G=r+8|0;H=n|0;I=n+4|0;J=n+8|0;K=n+9|0;L=n+10|0;M=n+11|0;N=n+12|0;O=k|0;P=0;Q=0;R=0;S=0;T=0;U=0;V=0;W=0;X=0;Y=0;Z=0;L6085:while(1){X2(q|0,0,12);c[l>>2]=0;if((d6(s|0,1,4,A|0)|0)!=4){_=4321;break}c[x>>2]=d[D]<<16|d[s]<<24|d[C]<<8|d[y];if((d6(u|0,1,4,A|0)|0)==4){$=0}else{_=4321;break}while(1){if($>>>0>=4){_=4325;break}if((Ya(u|0,c[17272+($<<3)>>2]|0,4)|0)==0){_=4324;break}else{$=$+1|0}}L6091:do{if((_|0)==4324){_=0;switch(c[17276+($<<3)>>2]|0){case 1:{_=4327;break L6085;break};case 2:{if(R|S|T){_=4329;break L6085}XZ(c[G>>2]|0);aa=c[x>>2]|0;ac=aa+4|0;ad=XY(ac)|0;if((ad|0)==0){_=4331;break L6085}if((c[ad-4>>2]&3|0)!=0){X2(ad|0,0,ac|0)}c[G>>2]=ad;if((d6(ad|0,1,ac|0,A|0)|0)!=(ac|0)){_=4335;break L6085}if((aa|0)!=13){_=4337;break L6085}aa=d[ad+1|0]<<16|d[ad]<<24|d[ad+2|0]<<8|d[ad+3|0];c[H>>2]=aa;ac=d[ad+5|0]<<16|d[ad+4|0]<<24|d[ad+6|0]<<8|d[ad+7|0];c[I>>2]=ac;ae=a[ad+8|0]|0;a[J]=ae;af=a[ad+9|0]|0;a[K]=af;ag=a[ad+10|0]|0;a[L]=ag;a[M]=a[ad+11|0]|0;ah=a[ad+12|0]|0;a[N]=ah;if((aa|0)==0|(ac|0)==0){_=4339;break L6085}switch(af<<24>>24){case 0:{ai=ae&255;aj=0;while(1){if(aj>>>0>=5){_=4347;break L6085}if((c[6904+(aj<<2)>>2]|0)==(ai|0)){break}else{aj=aj+1|0}}break};case 3:{aj=ae&255;ai=0;while(1){if(ai>>>0>=4){_=4350;break L6085}if((c[6888+(ai<<2)>>2]|0)==(aj|0)){break}else{ai=ai+1|0}}break};case 2:case 4:case 6:{if(!((ae<<24>>24|0)==8|(ae<<24>>24|0)==16)){_=4344;break L6085}break};default:{_=4351;break L6085}}if(ag<<24>>24!=0){_=4353;break L6085}XZ(ad);c[G>>2]=0;ak=U;al=0;am=0;an=1;ao=Q;ap=P;aq=af;ar=ac;as=ah;at=aa;au=ae;break L6091;break};case 4:{if(U|R^1|T|S){_=4358;break L6085}ai=c[x>>2]|0;if(((ai>>>0)%3|0|0)!=0){_=4360;break L6085}aj=(ai>>>0)/3|0;if(ai>>>0>770){_=4366;break L6085}if((d6(O|0,3,aj|0,A|0)|0)!=(aj|0)){_=4366;break L6085}if(ai>>>0>=3){ai=0;do{av=ai*3|0;c[o+(ai<<2)>>2]=d[k+av|0]<<16|d[k+(av+1)|0]<<8|d[k+(av+2)|0]|-16777216;ai=ai+1|0;}while(ai>>>0<aj>>>0)}if((eo(A|0,4,1)|0)>-1){ak=1;al=0;am=0;an=R;ao=Q;ap=P;aq=V;ar=W;as=X;at=Y;au=Z;break L6091}else{_=4366;break L6085}break};case 3:{if(T|R^1){_=4369;break L6085}if(!(V<<24>>24!=3|U)){_=4369;break L6085}aj=c[x>>2]|0;ai=aj+P|0;ae=X_(Q,ai)|0;if((ae|0)==0){aw=Q;_=4373;break L6085}if((d6(ae+P|0,1,aj|0,A|0)|0)!=(aj|0)){aw=ae;_=4373;break L6085}if((eo(A|0,4,1)|0)<0){aw=ae;_=4373;break L6085}else{ak=U;al=0;am=1;an=R;ao=ae;ap=ai;aq=V;ar=W;as=X;at=Y;au=Z;break L6091}break};case 5:{if(!(R&S)){_=4375;break L6085}if((eo(A|0,4,1)|0)<0){_=4377;break L6085}else{ak=U;al=1;am=1;an=1;ao=Q;ap=P;aq=V;ar=W;as=X;at=Y;au=Z;break L6091}break};default:{_=4325;break L6091}}}}while(0);if((_|0)==4325){_=0;if((eo(A|0,(c[x>>2]|0)+4|0,1)|0)<0){_=4326;break}else{ak=U;al=T;am=S;an=R;ao=Q;ap=P;aq=V;ar=W;as=X;at=Y;au=Z}}ai=cb(A|0)|0;if((ai|0)<(b|0)&(ai|0)>-1){P=ap;Q=ao;R=an;S=am;T=al;U=ak;V=aq;W=ar;X=as;Y=at;Z=au}else{_=4379;break}}if((_|0)==4321){Z=c[p>>2]|0;ec(Z|0,93272,(v=i,i=i+8|0,c[v>>2]=613,v)|0)|0;i=v;ax=0;ay=Q;break L6080}else if((_|0)==4326){ec(c[p>>2]|0,93272,(v=i,i=i+8|0,c[v>>2]=620,v)|0)|0;i=v;ax=0;ay=Q;break L6080}else if((_|0)==4327){ec(c[p>>2]|0,93272,(v=i,i=i+8|0,c[v>>2]=624,v)|0)|0;i=v;ax=0;ay=Q;break L6080}else if((_|0)==4329){ec(c[p>>2]|0,93272,(v=i,i=i+8|0,c[v>>2]=628,v)|0)|0;i=v;ax=0;ay=Q;break L6080}else if((_|0)==4331){c[G>>2]=0}else if((_|0)==4335){XZ(ad)}else if((_|0)==4337){ec(c[p>>2]|0,93272,(v=i,i=i+8|0,c[v>>2]=154,v)|0)|0;i=v;_=4354}else if((_|0)==4339){ec(c[p>>2]|0,93272,(v=i,i=i+8|0,c[v>>2]=165,v)|0)|0;i=v;_=4354}else if((_|0)==4344){ec(c[p>>2]|0,93272,(v=i,i=i+8|0,c[v>>2]=170,v)|0)|0;i=v;_=4354}else if((_|0)==4347){ec(c[p>>2]|0,93272,(v=i,i=i+8|0,c[v>>2]=186,v)|0)|0;i=v;_=4354}else if((_|0)==4350){ec(c[p>>2]|0,93272,(v=i,i=i+8|0,c[v>>2]=202,v)|0)|0;i=v;_=4354}else if((_|0)==4351){ec(c[p>>2]|0,93272,(v=i,i=i+8|0,c[v>>2]=205,v)|0)|0;i=v;_=4354}else if((_|0)==4353){ec(c[p>>2]|0,93272,(v=i,i=i+8|0,c[v>>2]=217,v)|0)|0;i=v;_=4354}else if((_|0)==4358){ec(c[p>>2]|0,93272,(v=i,i=i+8|0,c[v>>2]=638,v)|0)|0;i=v;ax=0;ay=Q;break L6080}else if((_|0)==4360){ec(c[p>>2]|0,93272,(v=i,i=i+8|0,c[v>>2]=641,v)|0)|0;i=v;ax=0;ay=Q;break L6080}else if((_|0)==4366){ec(c[p>>2]|0,93272,(v=i,i=i+8|0,c[v>>2]=644,v)|0)|0;i=v;ax=0;ay=Q;break L6080}else if((_|0)==4369){ec(c[p>>2]|0,93272,(v=i,i=i+8|0,c[v>>2]=651,v)|0)|0;i=v;ax=0;ay=Q;break L6080}else if((_|0)==4373){ec(c[p>>2]|0,93272,(v=i,i=i+8|0,c[v>>2]=654,v)|0)|0;i=v;ax=0;ay=aw;break L6080}else if((_|0)==4375){ec(c[p>>2]|0,93272,(v=i,i=i+8|0,c[v>>2]=661,v)|0)|0;i=v;ax=0;ay=Q;break L6080}else if((_|0)==4377){ec(c[p>>2]|0,93272,(v=i,i=i+8|0,c[v>>2]=664,v)|0)|0;i=v;ax=0;ay=Q;break L6080}else if((_|0)==4379){if(!(an&am&al)){az=ao;break}c[m+36>>2]=0;c[m+40>>2]=0;c[m+24>>2]=0;c[m+8>>2]=0;Z=m+20|0;c[Z>>2]=0;c[m+44>>2]=0;Y=XY(43784)|0;if((Y|0)==0){X=c[p>>2]|0;ec(X|0,93272,(v=i,i=i+8|0,c[v>>2]=675,v)|0)|0;i=v;ax=0;ay=ao;break L6080}X=m+28|0;c[X>>2]=Y;c[Y>>2]=0;c[Y+10992>>2]=0;c[Y+10996>>2]=0;c[Y+43780>>2]=1;c[Y+11e3>>2]=1;c[Y+11004>>2]=0;c[Y+11008>>2]=15;switch(aq&255|0){case 0:{aA=((ab(at,au&255)|0)+7|0)>>>3;break};case 2:{aA=((ab((au&255)*3|0,at)|0)+7|0)>>>3;break};case 3:{aA=((ab(at,au&255)|0)+7|0)>>>3;break};case 4:{aA=((ab((au&255)<<1,at)|0)+7|0)>>>3;break};case 6:{aA=((ab((au&255)<<2,at)|0)+7|0)>>>3;break};default:{aA=0}}Y=as<<24>>24==1;W=(ab(ar,aA+1|0)|0)<<(Y&1);V=XY(W)|0;if((V|0)==0){U=c[p>>2]|0;ec(U|0,93272,(v=i,i=i+8|0,c[v>>2]=683,v)|0)|0;i=v;ax=0;ay=ao;break L6080}c[m>>2]=ao;c[m+4>>2]=ap;c[m+16>>2]=W;c[m+12>>2]=V;W=(jA(m)|0)==1;U=c[X>>2]|0;if((U|0)!=0){XZ(U);c[X>>2]=0}if(!W){W=c[p>>2]|0;ec(W|0,93272,(v=i,i=i+8|0,c[v>>2]=693,v)|0)|0;i=v;ax=V;ay=ao;break L6080}c[B>>2]=at;c[F>>2]=ar;W=XY(ab(ar<<2,at)|0)|0;X=W;c[t>>2]=X;if((W|0)==0){W=c[p>>2]|0;ec(W|0,93272,(v=i,i=i+8|0,c[v>>2]=701,v)|0)|0;i=v;ax=V;ay=ao;break L6080}W=c[Z>>2]|0;Z=o|0;L6179:do{if(Y){U=j;T=j|0;S=j+4|0;R=j+9|0;P=j+8|0;x=0;O=W;N=V;M=at;L6181:while(1){L=c[6776+(x<<4)>>2]|0;do{if(M>>>0>L>>>0){K=c[I>>2]|0;J=c[6780+(x<<4)>>2]|0;if(K>>>0<=J>>>0){aB=N;aC=O;break}u=c[6784+(x<<4)>>2]|0;y=((M-1-L+u|0)>>>0)/(u>>>0)|0;C=c[6788+(x<<4)>>2]|0;s=((K-1-J+C|0)>>>0)/(C>>>0)|0;K=y<<2;aD=XY(ab(s,K)|0)|0;D=aD;if((aD|0)==0){break L6181}c[U>>2]=c[e>>2];c[U+4>>2]=c[e+4>>2];c[U+8>>2]=c[e+8>>2];c[U+12>>2]=c[e+12>>2];c[T>>2]=y;c[S>>2]=s;switch(d[R]|0){case 0:{aE=((ab(d[P]|0,y)|0)+7|0)>>>3;break};case 2:{aE=((ab(y*3|0,d[P]|0)|0)+7|0)>>>3;break};case 3:{aE=((ab(d[P]|0,y)|0)+7|0)>>>3;break};case 4:{aE=((ab(y<<1,d[P]|0)|0)+7|0)>>>3;break};case 6:{aE=((ab(d[P]|0,K)|0)+7|0)>>>3;break};default:{aE=0}}K=ab(aE+1|0,s)|0;if(K>>>0>O>>>0){_=4409;break L6181}if(!(jz(D,j,N,K,Z)|0)){_=4411;break L6181}ai=N+K|0;ae=O-K|0;if(!((s|0)==0|(y|0)==0)){K=D;D=X+((ab(c[H>>2]|0,J)|0)+L<<2)|0;J=0;while(1){aj=D;aa=0;while(1){c[aj>>2]=c[K+(aa<<2)>>2];ah=aa+1|0;if(ah>>>0<y>>>0){aj=aj+(u<<2)|0;aa=ah}else{break}}aa=J+1|0;aj=D+((ab(c[H>>2]|0,C)|0)<<2)|0;if(aa>>>0<s>>>0){K=K+(y<<2)|0;D=aj;J=aa}else{break}}}XZ(aD);aB=ai;aC=ae}else{aB=N;aC=O}}while(0);L=x+1|0;if(L>>>0>=7){break L6179}x=L;O=aC;N=aB;M=c[H>>2]|0}if((_|0)==4409){XZ(aD)}else if((_|0)==4411){XZ(aD)}ec(c[p>>2]|0,93272,(v=i,i=i+8|0,c[v>>2]=706,v)|0)|0;i=v;ax=V;ay=ao;break L6080}else{if(jz(X,n,V,W,Z)|0){break}ec(c[p>>2]|0,93272,(v=i,i=i+8|0,c[v>>2]=709,v)|0)|0;i=v;ax=V;ay=ao;break L6080}}while(0);aQ(A|0)|0;XZ(ao);XZ(V);if((f|0)==16&(g|0)==0){w=1;i=h;return w|0}Z=ab(c[F>>2]|0,c[B>>2]|0)|0;W=c[t>>2]|0;if((Z|0)==0){w=1;i=h;return w|0}else{aF=0}while(1){X=W+(aF<<2)|0;H=c[X>>2]|0;c[X>>2]=(H&255)<<g|H&-16777216|(H>>>16&255)<<f|H&65280;H=aF+1|0;if(H>>>0<Z>>>0){aF=H}else{w=1;break}}i=h;return w|0}if((_|0)==4354){XZ(ad);c[G>>2]=0}ec(c[p>>2]|0,93272,(v=i,i=i+8|0,c[v>>2]=631,v)|0)|0;i=v;ax=0;ay=Q;break L6080}else{az=0}}while(0);z=c[p>>2]|0;ec(z|0,93272,(v=i,i=i+8|0,c[v>>2]=672,v)|0)|0;i=v;ax=0;ay=az}else{z=c[p>>2]|0;ec(z|0,93272,(v=i,i=i+8|0,c[v>>2]=606,v)|0)|0;i=v;ax=0;ay=0}}while(0);aQ(A|0)|0;aG=ax;aH=ay}else{ay=c[p>>2]|0;ec(ay|0,93272,(v=i,i=i+8|0,c[v>>2]=603,v)|0)|0;i=v;aQ(A|0)|0;aG=0;aH=0}XZ(c[t>>2]|0);XZ(aH);XZ(aG);w=0;i=h;return w|0}function h9(a,b,c){a=a|0;b=b|0;c=c|0;return-1|0}function ia(a,b,c){a=a|0;b=b|0;c=c|0;return c|0}function ib(a){a=a|0;return 1}function ic(a){a=a|0;return 1}function id(a,b){a=a|0;b=b|0;return}function ie(a){a=a|0;return}function ig(a){a=a|0;return 1}function ih(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0.0,F=0,G=0,H=0,I=0,J=0,K=0.0,L=0.0,M=0.0,N=0,O=0.0,P=0.0,Q=0,R=0.0,S=0.0;d=~~(16777216.0/+h[b+16>>3]);e=c[b+8>>2]|0;if((e|0)==0){f=0;i=b+12|0;c[i>>2]=f;return}j=a+20|0;k=a+4|0;l=a+16|0;m=a+8|0;n=a+12|0;o=a;a=c[b>>2]|0;p=c[b+4>>2]|0;q=e;e=0;r=c[j>>2]|0;while(1){L6241:do{if((q|0)==0){s=a;t=r;u=4455}else{v=a;w=q;x=r;while(1){if(x>>>0<=16777215){y=x;z=w;A=v;break L6241}B=c[l>>2]|0;if((B|0)==0){C=c[n>>2]|0;c[l>>2]=C;D=C}else{D=B}B=D-1|0;c[l>>2]=B;E=+g[v>>2];g[(c[k>>2]|0)+(B<<2)>>2]=E;g[(c[k>>2]|0)+((c[n>>2]|0)+(c[l>>2]|0)<<2)>>2]=E;B=v+8|0;E=+g[v+4>>2];g[(c[m>>2]|0)+(c[l>>2]<<2)>>2]=E;g[(c[m>>2]|0)+((c[n>>2]|0)+(c[l>>2]|0)<<2)>>2]=E;C=(c[j>>2]|0)-16777216|0;c[j>>2]=C;F=w-1|0;if((F|0)==0){s=B;t=C;u=4455;break}else{v=B;w=F;x=C}}}}while(0);if((u|0)==4455){u=0;if(t>>>0<16777216){y=t;z=0;A=s}else{f=e;u=4463;break}}x=p;w=e;v=y;do{C=c[k>>2]|0;F=c[l>>2]|0;B=c[m>>2]|0;G=c[n>>2]|0;H=c[o>>2]|0;I=ab(G<<1,v>>>16)|0;J=I+G|0;E=+((v&65535)>>>0>>>0)*152587890625.0e-16;if((G|0)==0){K=0.0;L=0.0}else{M=0.0;N=0;O=0.0;while(1){P=+g[H+(N+I<<2)>>2]+E*+g[H+(J+N<<2)>>2];Q=N+F|0;R=O+ +g[C+(Q<<2)>>2]*P;S=M+ +g[B+(Q<<2)>>2]*P;Q=N+1|0;if(Q>>>0<G>>>0){M=S;N=Q;O=R}else{K=S;L=R;break}}}g[x>>2]=L;g[x+4>>2]=K;x=x+8|0;w=w+1|0;v=(c[j>>2]|0)+d|0;c[j>>2]=v;}while(v>>>0<16777216);if((z|0)==0){f=w;u=4461;break}else{a=A;p=x;q=z;e=w;r=v}}if((u|0)==4463){i=b+12|0;c[i>>2]=f;return}else if((u|0)==4461){i=b+12|0;c[i>>2]=f;return}}function ii(b){b=+b;var d=0,e=0,f=0,h=0,j=0.0,k=0,l=0,m=0,n=0,o=0.0,q=0.0,r=0.0,s=0.0,t=0.0,u=0.0,v=0,w=0,x=0.0,y=0.0,z=0.0,A=0,B=0.0,C=0.0,D=0,E=0,F=0.0,G=0.0,H=0;d=i;e=XY(28)|0;if((e|0)==0){f=0;i=d;return f|0}if((c[e-4>>2]&3|0)!=0){X2(e|0,0,28)}X2(e|0,0,28);h=e+12|0;if(b<1.0){j=b*.825;k=~~+aa(+(16.0/b))+3&-4}else{j=.825;k=16}c[h>>2]=k;l=k<<9;m=XY((l+(k<<2)<<2)+132|0)|0;k=m+132&-128;c[k-4>>2]=m;m=k;c[e+24>>2]=m;if((k|0)==0){XZ(c[m-4>>2]|0);XZ(e);f=0;i=d;return f|0}c[e>>2]=m;c[e+4>>2]=m+(l<<2);k=c[h>>2]|0;n=k<<1;c[e+8>>2]=m+(n+l<<2);b=1.0;o=0.0;q=1.0;r=1.0;s=0.0;l=0;while(1){t=s+r*q/(b*b);u=o+1.0;v=l+1|0;if(v>>>0<18){b=b*u;o=u;q=q*30.25;r=r*.25;s=t;l=v}else{break}}s=+(k|0)*.5;r=+(k<<8|0);if((k|0)>0){l=0;while(1){v=ab(l,n)|0;w=0;do{q=+((w<<8)+l|0)/r*2.0+-1.0;o=j*s*q*3.141592653589793;if(+Q(+o)<1.0e-5){x=1.0}else{x=+U(+o)/o}o=+R(+(1.0-q*q))*5.5;q=o*o;o=1.0;b=0.0;u=1.0;y=1.0;z=0.0;A=0;while(1){B=z+y*u/(o*o);C=b+1.0;D=A+1|0;if(D>>>0<18){o=o*C;b=C;u=q*u;y=y*.25;z=B;A=D}else{break}}g[m+(w+v<<2)>>2]=j*x*B/t;w=w+1|0;}while((w|0)<(k|0));w=l+1|0;if((w|0)<256){l=w}else{E=0;break}}while(1){l=E+1|0;w=ab(l,n)|0;v=E<<1;A=ab(v,k)|0;D=ab(v|1,k)|0;v=0;do{g[m+(v+D<<2)>>2]=+g[m+(v+w<<2)>>2]- +g[m+(v+A<<2)>>2];v=v+1|0;}while((v|0)<(k|0));if((l|0)<255){E=l}else{break}}E=k*510|0;n=k*511|0;v=0;do{B=+((v<<8)+256|0)/r*2.0+-1.0;x=j*s*B*3.141592653589793;if(+Q(+x)<1.0e-5){F=1.0}else{F=+U(+x)/x}x=+R(+(1.0-B*B))*5.5;B=x*x;x=1.0;z=0.0;y=1.0;u=1.0;q=0.0;A=0;while(1){G=q+u*y/(x*x);b=z+1.0;w=A+1|0;if(w>>>0<18){x=x*b;z=b;y=B*y;u=u*.25;q=G;A=w}else{break}}g[m+(v+n<<2)>>2]=j*F*G/t- +g[m+(v+E<<2)>>2];v=v+1|0;}while((v|0)<(k|0))}k=a[637400]|0;if((k&1)==0){H=k}else{k=c[198610]|0;v=(k|0)!=0?k:c[p>>2]|0;a2(94640,30,1,v|0)|0;v=c[198610]|0;k=(v|0)!=0?v:c[p>>2]|0;aY(k|0)|0;H=a[637400]|0}if((H&1)==0){f=e;i=d;return f|0}H=c[198610]|0;k=c[h>>2]|0;ec(((H|0)!=0?H:c[p>>2]|0)|0,66336,(H=i,i=i+16|0,c[H>>2]=8,c[H+8>>2]=k,H)|0)|0;i=H;H=c[198610]|0;aY(((H|0)!=0?H:c[p>>2]|0)|0)|0;f=e;i=d;return f|0}function ij(a){a=a|0;if((a|0)==0){XZ(a);return}XZ(c[(c[a+24>>2]|0)-4>>2]|0);XZ(a);return}function ik(b,c,d,e,f){b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;g=X1(e|0)|0;if(g>>>0<=c>>>0){h=c+1|0;do{if((h|0)==0){i=e}else{j=h;k=b;l=e;while(1){m=j-1|0;if((m|0)==0){n=4508;break}o=a[l]|0;a[k]=o;if(o<<24>>24==0){n=4569;break}else{j=m;k=k+1|0;l=l+1|0}}if((n|0)==4508){a[k]=0;i=l;break}else if((n|0)==4569){return}}}while(0);if((a[i]|0)==0){return}else{p=i}do{p=p+1|0;}while((a[p]|0)!=0);return}if(!f){f=c+1|0;p=c-2|0;L6336:do{if((p|0)==0){q=e;n=4516}else{i=p;h=b;j=e;while(1){m=i-1|0;if((m|0)==0){break}o=a[j]|0;a[h]=o;if(o<<24>>24==0){break L6336}else{i=m;h=h+1|0;j=j+1|0}}a[h]=0;q=j;n=4516}}while(0);do{if((n|0)==4516){if((a[q]|0)==0){break}else{r=q}do{r=r+1|0;}while((a[r]|0)!=0)}}while(0);r=X1(b|0)|0;q=r>>>0>f>>>0?0:f-r|0;if((q|0)==0){s=64976}else{f=b+r|0;do{if((q|0)==1){t=64976;u=f}else{j=b+(r+1)|0;a[f]=46;if((q|0)==2){t=64977;u=j;break}h=b+(r+2)|0;a[j]=46;if((q|0)==3){t=64978;u=h;break}j=b+(r+3)|0;a[h]=46;if((q|0)==4){t=64979;u=j;break}a[j]=0;return}}while(0);a[u]=0;s=t}if((a[s]|0)==0){return}else{v=s}do{v=v+1|0;}while((a[v]|0)!=0);return}v=g-c|0;g=(d>>>0)%(((v<<1)+4|0)>>>0)|0;d=v+4|0;s=g-2|0;t=d+v-g|0;if(g>>>0<2){u=c+1|0;do{if((u|0)==0){w=e}else{q=u;r=b;f=e;while(1){j=q-1|0;if((j|0)==0){n=4528;break}h=a[f]|0;a[r]=h;if(h<<24>>24==0){n=4560;break}else{q=j;r=r+1|0;f=f+1|0}}if((n|0)==4528){a[r]=0;w=f;break}else if((n|0)==4560){return}}}while(0);if((a[w]|0)==0){return}else{x=w}do{x=x+1|0;}while((a[x]|0)!=0);return}if(g>>>0<(v+2|0)>>>0){x=e+s|0;s=c+1|0;do{if((s|0)==0){y=x}else{w=s;u=b;q=x;while(1){j=w-1|0;if((j|0)==0){n=4535;break}h=a[q]|0;a[u]=h;if(h<<24>>24==0){n=4563;break}else{w=j;u=u+1|0;q=q+1|0}}if((n|0)==4563){return}else if((n|0)==4535){a[u]=0;y=q;break}}}while(0);if((a[y]|0)==0){return}else{z=y}do{z=z+1|0;}while((a[z]|0)!=0);return}if(g>>>0<d>>>0){d=e+v|0;v=c+1|0;do{if((v|0)==0){A=d}else{g=v;z=b;y=d;while(1){x=g-1|0;if((x|0)==0){n=4542;break}s=a[y]|0;a[z]=s;if(s<<24>>24==0){n=4567;break}else{g=x;z=z+1|0;y=y+1|0}}if((n|0)==4567){return}else if((n|0)==4542){a[z]=0;A=y;break}}}while(0);if((a[A]|0)==0){return}else{B=A}do{B=B+1|0;}while((a[B]|0)!=0);return}else{B=e+t|0;t=c+1|0;do{if((t|0)==0){C=B}else{c=t;e=b;A=B;while(1){d=c-1|0;if((d|0)==0){n=4548;break}v=a[A]|0;a[e]=v;if(v<<24>>24==0){n=4564;break}else{c=d;e=e+1|0;A=A+1|0}}if((n|0)==4548){a[e]=0;C=A;break}else if((n|0)==4564){return}}}while(0);if((a[C]|0)==0){return}else{D=C}do{D=D+1|0;}while((a[D]|0)!=0);return}}function il(b){b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;d=b+44|0;e=c[d>>2]|0;f=e+8|0;if((c[f>>2]|0)!=0){g=e|0;e=0;do{XZ(c[(c[g>>2]|0)+(e*12|0)>>2]|0);e=e+1|0;}while(e>>>0<(c[f>>2]|0)>>>0)}c[f>>2]=0;do{if((c[b+113712>>2]|0)==0){h=4582}else{f=c[d>>2]|0;if((f|0)==0){break}e=f+8|0;g=f+4|0;i=c[g>>2]|0;if((c[e>>2]|0)>>>0<i>>>0){j=f|0}else{k=(i<<1)+2|0;c[g>>2]=k;g=f|0;c[g>>2]=X_(c[g>>2]|0,k*12|0)|0;j=g}g=dq(88112)|0;c[(c[j>>2]|0)+((c[e>>2]|0)*12|0)>>2]=g;c[(c[j>>2]|0)+((c[e>>2]|0)*12|0)+4>>2]=51;c[(c[j>>2]|0)+((c[e>>2]|0)*12|0)+8>>2]=0;c[e>>2]=(c[e>>2]|0)+1;h=4582}}while(0);do{if((h|0)==4582){j=c[d>>2]|0;if((j|0)==0){break}b=j+8|0;e=j+4|0;g=c[e>>2]|0;if((c[b>>2]|0)>>>0<g>>>0){l=j|0}else{k=(g<<1)+2|0;c[e>>2]=k;e=j|0;c[e>>2]=X_(c[e>>2]|0,k*12|0)|0;l=e}e=dq(87816)|0;c[(c[l>>2]|0)+((c[b>>2]|0)*12|0)>>2]=e;c[(c[l>>2]|0)+((c[b>>2]|0)*12|0)+4>>2]=50;c[(c[l>>2]|0)+((c[b>>2]|0)*12|0)+8>>2]=0;c[b>>2]=(c[b>>2]|0)+1;b=c[d>>2]|0;if((b|0)==0){break}e=b+8|0;k=b+4|0;j=c[k>>2]|0;if((c[e>>2]|0)>>>0<j>>>0){m=b|0}else{g=(j<<1)+2|0;c[k>>2]=g;k=b|0;c[k>>2]=X_(c[k>>2]|0,g*12|0)|0;m=k}k=dq(87544)|0;c[(c[m>>2]|0)+((c[e>>2]|0)*12|0)>>2]=k;c[(c[m>>2]|0)+((c[e>>2]|0)*12|0)+4>>2]=53;c[(c[m>>2]|0)+((c[e>>2]|0)*12|0)+8>>2]=0;c[e>>2]=(c[e>>2]|0)+1;e=c[d>>2]|0;if((e|0)==0){break}k=e+8|0;g=e+4|0;b=c[g>>2]|0;if((c[k>>2]|0)>>>0<b>>>0){n=e|0}else{j=(b<<1)+2|0;c[g>>2]=j;g=e|0;c[g>>2]=X_(c[g>>2]|0,j*12|0)|0;n=g}g=dq(87256)|0;c[(c[n>>2]|0)+((c[k>>2]|0)*12|0)>>2]=g;c[(c[n>>2]|0)+((c[k>>2]|0)*12|0)+4>>2]=5;c[(c[n>>2]|0)+((c[k>>2]|0)*12|0)+8>>2]=0;c[k>>2]=(c[k>>2]|0)+1;k=c[d>>2]|0;if((k|0)==0){break}g=k+8|0;j=k+4|0;e=c[j>>2]|0;if((c[g>>2]|0)>>>0<e>>>0){o=k|0}else{b=(e<<1)+2|0;c[j>>2]=b;j=k|0;c[j>>2]=X_(c[j>>2]|0,b*12|0)|0;o=j}j=dq(87e3)|0;c[(c[o>>2]|0)+((c[g>>2]|0)*12|0)>>2]=j;c[(c[o>>2]|0)+((c[g>>2]|0)*12|0)+4>>2]=54;c[(c[o>>2]|0)+((c[g>>2]|0)*12|0)+8>>2]=0;c[g>>2]=(c[g>>2]|0)+1;g=c[d>>2]|0;if((g|0)==0){break}j=g+8|0;b=g+4|0;k=c[b>>2]|0;if((c[j>>2]|0)>>>0<k>>>0){p=g|0}else{e=(k<<1)+2|0;c[b>>2]=e;b=g|0;c[b>>2]=X_(c[b>>2]|0,e*12|0)|0;p=b}b=dq(86664)|0;c[(c[p>>2]|0)+((c[j>>2]|0)*12|0)>>2]=b;c[(c[p>>2]|0)+((c[j>>2]|0)*12|0)+4>>2]=55;c[(c[p>>2]|0)+((c[j>>2]|0)*12|0)+8>>2]=0;c[j>>2]=(c[j>>2]|0)+1;j=c[d>>2]|0;if((j|0)==0){break}b=j+8|0;e=j+4|0;g=c[e>>2]|0;if((c[b>>2]|0)>>>0<g>>>0){q=j|0}else{k=(g<<1)+2|0;c[e>>2]=k;e=j|0;c[e>>2]=X_(c[e>>2]|0,k*12|0)|0;q=e}e=dq(86392)|0;c[(c[q>>2]|0)+((c[b>>2]|0)*12|0)>>2]=e;c[(c[q>>2]|0)+((c[b>>2]|0)*12|0)+4>>2]=56;c[(c[q>>2]|0)+((c[b>>2]|0)*12|0)+8>>2]=0;c[b>>2]=(c[b>>2]|0)+1;b=c[d>>2]|0;if((b|0)==0){break}e=b+8|0;k=b+4|0;j=c[k>>2]|0;if((c[e>>2]|0)>>>0<j>>>0){r=b|0}else{g=(j<<1)+2|0;c[k>>2]=g;k=b|0;c[k>>2]=X_(c[k>>2]|0,g*12|0)|0;r=k}k=dq(86112)|0;c[(c[r>>2]|0)+((c[e>>2]|0)*12|0)>>2]=k;c[(c[r>>2]|0)+((c[e>>2]|0)*12|0)+4>>2]=57;c[(c[r>>2]|0)+((c[e>>2]|0)*12|0)+8>>2]=0;c[e>>2]=(c[e>>2]|0)+1}}while(0);do{if((a[794444]&1)!=0){if((a[795517]&1)!=0){break}if((c[184100]|0)!=0){r=c[d>>2]|0;if((r|0)==0){return}q=r+8|0;p=r+4|0;o=c[p>>2]|0;if((c[q>>2]|0)>>>0<o>>>0){s=r|0}else{n=(o<<1)+2|0;c[p>>2]=n;p=r|0;c[p>>2]=X_(c[p>>2]|0,n*12|0)|0;s=p}p=dq(85808)|0;c[(c[s>>2]|0)+((c[q>>2]|0)*12|0)>>2]=p;c[(c[s>>2]|0)+((c[q>>2]|0)*12|0)+4>>2]=64;c[(c[s>>2]|0)+((c[q>>2]|0)*12|0)+8>>2]=0;c[q>>2]=(c[q>>2]|0)+1}q=c[d>>2]|0;if((q|0)==0){return}p=q+8|0;n=q+4|0;r=c[n>>2]|0;if((c[p>>2]|0)>>>0<r>>>0){t=q|0}else{o=(r<<1)+2|0;c[n>>2]=o;n=q|0;c[n>>2]=X_(c[n>>2]|0,o*12|0)|0;t=n}n=dq(85472)|0;c[(c[t>>2]|0)+((c[p>>2]|0)*12|0)>>2]=n;c[(c[t>>2]|0)+((c[p>>2]|0)*12|0)+4>>2]=62;c[(c[t>>2]|0)+((c[p>>2]|0)*12|0)+8>>2]=0;c[p>>2]=(c[p>>2]|0)+1;p=c[d>>2]|0;if((p|0)==0){return}n=p+8|0;o=p+4|0;q=c[o>>2]|0;if((c[n>>2]|0)>>>0<q>>>0){u=p|0}else{r=(q<<1)+2|0;c[o>>2]=r;o=p|0;c[o>>2]=X_(c[o>>2]|0,r*12|0)|0;u=o}o=dq(84984)|0;c[(c[u>>2]|0)+((c[n>>2]|0)*12|0)>>2]=o;c[(c[u>>2]|0)+((c[n>>2]|0)*12|0)+4>>2]=63;c[(c[u>>2]|0)+((c[n>>2]|0)*12|0)+8>>2]=0;c[n>>2]=(c[n>>2]|0)+1;n=c[d>>2]|0;if((n|0)==0){return}o=n+8|0;r=n+4|0;p=c[r>>2]|0;if((c[o>>2]|0)>>>0<p>>>0){v=n|0}else{q=(p<<1)+2|0;c[r>>2]=q;r=n|0;c[r>>2]=X_(c[r>>2]|0,q*12|0)|0;v=r}r=dq(84640)|0;c[(c[v>>2]|0)+((c[o>>2]|0)*12|0)>>2]=r;c[(c[v>>2]|0)+((c[o>>2]|0)*12|0)+4>>2]=67;c[(c[v>>2]|0)+((c[o>>2]|0)*12|0)+8>>2]=0;c[o>>2]=(c[o>>2]|0)+1;o=c[d>>2]|0;if((o|0)==0){return}r=o+8|0;q=o+4|0;n=c[q>>2]|0;if((c[r>>2]|0)>>>0<n>>>0){w=o|0}else{p=(n<<1)+2|0;c[q>>2]=p;q=o|0;c[q>>2]=X_(c[q>>2]|0,p*12|0)|0;w=q}q=dq(84272)|0;c[(c[w>>2]|0)+((c[r>>2]|0)*12|0)>>2]=q;c[(c[w>>2]|0)+((c[r>>2]|0)*12|0)+4>>2]=80;c[(c[w>>2]|0)+((c[r>>2]|0)*12|0)+8>>2]=0;c[r>>2]=(c[r>>2]|0)+1;r=c[d>>2]|0;if((r|0)==0){return}q=r+8|0;p=r+4|0;o=c[p>>2]|0;if((c[q>>2]|0)>>>0<o>>>0){x=r|0}else{n=(o<<1)+2|0;c[p>>2]=n;p=r|0;c[p>>2]=X_(c[p>>2]|0,n*12|0)|0;x=p}p=dq(83912)|0;c[(c[x>>2]|0)+((c[q>>2]|0)*12|0)>>2]=p;c[(c[x>>2]|0)+((c[q>>2]|0)*12|0)+4>>2]=74;c[(c[x>>2]|0)+((c[q>>2]|0)*12|0)+8>>2]=0;c[q>>2]=(c[q>>2]|0)+1}}while(0);x=c[d>>2]|0;if((x|0)==0){return}w=x+8|0;v=x+4|0;u=c[v>>2]|0;if((c[w>>2]|0)>>>0<u>>>0){y=x|0}else{t=(u<<1)+2|0;c[v>>2]=t;v=x|0;c[v>>2]=X_(c[v>>2]|0,t*12|0)|0;y=v}v=dq(83544)|0;c[(c[y>>2]|0)+((c[w>>2]|0)*12|0)>>2]=v;c[(c[y>>2]|0)+((c[w>>2]|0)*12|0)+4>>2]=79;c[(c[y>>2]|0)+((c[w>>2]|0)*12|0)+8>>2]=0;c[w>>2]=(c[w>>2]|0)+1;w=c[d>>2]|0;if((w|0)==0){return}d=w+8|0;y=w+4|0;v=c[y>>2]|0;if((c[d>>2]|0)>>>0<v>>>0){z=w|0}else{t=(v<<1)+2|0;c[y>>2]=t;y=w|0;c[y>>2]=X_(c[y>>2]|0,t*12|0)|0;z=y}y=dq(83256)|0;c[(c[z>>2]|0)+((c[d>>2]|0)*12|0)>>2]=y;c[(c[z>>2]|0)+((c[d>>2]|0)*12|0)+4>>2]=81;c[(c[z>>2]|0)+((c[d>>2]|0)*12|0)+8>>2]=0;c[d>>2]=(c[d>>2]|0)+1;return}function im(d){d=d|0;var e=0,f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0;e=i;i=i+22120|0;f=e|0;h=e+16|0;j=e+528|0;k=e+1552|0;l=e+5648|0;m=e+9744|0;n=e+9768|0;o=e+9832|0;q=e+13928|0;r=e+18024|0;s=d+8|0;t=c[s>>2]|0;u=c[s+4>>2]|0;do{if((t&1|0)==0&(u&0|0)==0){if(!((t&2|0)==0&(u&0|0)==0)){v=1;break}if(!((t&4|0)==0&(u&0|0)==0)){v=2;break}if(!((t&8|0)==0&(u&0|0)==0)){v=3;break}if(!((t&32|0)==0&(u&0|0)==0)){v=5;break}if(!((t&16|0)==0&(u&0|0)==0)){v=4;break}if(!((t&128|0)==0&(u&0|0)==0)){v=8;break}v=(t&64|0)==0&(u&0|0)==0?10:7}else{v=0}}while(0);u=d+40|0;t=c[u>>2]|0;s=c[t+8>>2]|0;if((s|0)==0){w=0;x=0}else{y=s-1|0;s=c[t>>2]|0;w=c[s+(y*12|0)+4>>2]|0;x=c[s+(y*12|0)>>2]|0}y=c[199354]|0;do{if((y|0)!=0){if((c[y+24>>2]|0)==0){break}fj[c[y+20>>2]&3](c[199308]|0,244792,0,320,240,1.0)}}while(0);switch(w|0){case 64:case 57:case 56:case 54:case 53:case 21:case 5:case 4:case 55:{z=io(d,v)|0;i=e;return z|0};default:{}}if((w-12|0)>>>0<2){y=n|0;n=c[u>>2]|0;s=n+8|0;t=c[s>>2]|0;A=(t|0)==0;if(A){B=0}else{B=c[(c[n>>2]|0)+((t-1|0)*12|0)+4>>2]|0}C=(a[535105]&1)==0;D=C?1:c[182926]|0;E=C?1:c[182927]|0;L6564:do{switch(v|0){case 4:{G=d+48|0;if(!A){H=t-1|0;c[s>>2]=H;XZ(c[(c[n>>2]|0)+(H*12|0)>>2]|0)}if((G|0)!=0){c[G>>2]=c[(c[n>>2]|0)+((c[s>>2]|0)*12|0)+8>>2]}if((B|0)!=12){break L6564}if((a[535105]&1)!=0){break L6564}H=c[u>>2]|0;I=c[G>>2]|0;if((H|0)==0){break L6564}G=H+8|0;J=H+4|0;K=c[J>>2]|0;if((c[G>>2]|0)>>>0<K>>>0){L=H|0}else{M=(K<<1)+2|0;c[J>>2]=M;J=H|0;c[J>>2]=X_(c[J>>2]|0,M*12|0)|0;L=J}J=dq(798256)|0;c[(c[L>>2]|0)+((c[G>>2]|0)*12|0)>>2]=J;c[(c[L>>2]|0)+((c[G>>2]|0)*12|0)+4>>2]=13;c[(c[L>>2]|0)+((c[G>>2]|0)*12|0)+8>>2]=I;c[G>>2]=(c[G>>2]|0)+1;break};case 0:{do{if((B|0)==12){c[198597]=(c[198597]|0)-E;c[198599]=(c[198599]|0)+E}else{G=c[198599]|0;if(G>>>0<E>>>0){break}c[198599]=G-E}}while(0);G=c[(c[199354]|0)+16>>2]|0;if((G|0)==0){break L6564}fb[G&127](c[199308]|0);break};case 3:{do{if((B|0)==12){c[198596]=(c[198596]|0)+D;G=c[198598]|0;if(G>>>0<D>>>0){break}c[198598]=G-D}else{c[198598]=(c[198598]|0)+D}}while(0);G=c[(c[199354]|0)+16>>2]|0;if((G|0)==0){break L6564}fb[G&127](c[199308]|0);break};case 7:{G=d+48|0;if(!A){I=t-1|0;c[s>>2]=I;XZ(c[(c[n>>2]|0)+(I*12|0)>>2]|0)}if((G|0)==0){break L6564}c[G>>2]=c[(c[n>>2]|0)+((c[s>>2]|0)*12|0)+8>>2];break};case 9:{a[d+53|0]=1;break};case 8:{if(!C){break L6564}fc[c[(c[199305]|0)+44>>2]&127](c[199308]|0,m);if((B|0)==12){c[198598]=(c[198598]|0)+(c[198596]|0);c[198599]=(c[198599]|0)+(c[198597]|0);c[198596]=0;c[198597]=0}else{c[198598]=(c[m+16>>2]|0)-(c[198596]|0);c[198599]=(c[m+20>>2]|0)-(c[198597]|0)}G=c[(c[199354]|0)+16>>2]|0;if((G|0)==0){break L6564}fb[G&127](c[199308]|0);break};case 5:{G=d+48|0;if(!A){I=t-1|0;c[s>>2]=I;XZ(c[(c[n>>2]|0)+(I*12|0)>>2]|0)}if((G|0)!=0){c[G>>2]=c[(c[n>>2]|0)+((c[s>>2]|0)*12|0)+8>>2]}if((B|0)!=13){break L6564}I=c[u>>2]|0;J=c[G>>2]|0;if((I|0)==0){break L6564}G=I+8|0;M=I+4|0;H=c[M>>2]|0;if((c[G>>2]|0)>>>0<H>>>0){N=I|0}else{K=(H<<1)+2|0;c[M>>2]=K;M=I|0;c[M>>2]=X_(c[M>>2]|0,K*12|0)|0;N=M}M=dq(798256)|0;c[(c[N>>2]|0)+((c[G>>2]|0)*12|0)>>2]=M;c[(c[N>>2]|0)+((c[G>>2]|0)*12|0)+4>>2]=12;c[(c[N>>2]|0)+((c[G>>2]|0)*12|0)+8>>2]=J;c[G>>2]=(c[G>>2]|0)+1;break};case 1:{do{if((B|0)==12){c[198597]=(c[198597]|0)+E;G=c[198599]|0;if(G>>>0<E>>>0){break}c[198599]=G-E}else{c[198599]=(c[198599]|0)+E}}while(0);G=c[(c[199354]|0)+16>>2]|0;if((G|0)==0){break L6564}fb[G&127](c[199308]|0);break};case 2:{do{if((B|0)==12){c[198596]=(c[198596]|0)-D;c[198598]=(c[198598]|0)+D}else{G=c[198598]|0;if(G>>>0<D>>>0){break}c[198598]=G-D}}while(0);G=c[(c[199354]|0)+16>>2]|0;if((G|0)==0){break L6564}fb[G&127](c[199308]|0);break};default:{}}}while(0);N=c[u>>2]|0;s=c[N+8>>2]|0;if((s|0)==0){O=B}else{O=c[(c[N>>2]|0)+((s-1|0)*12|0)+4>>2]|0}iq(d);if((a[535105]&1)==0){if((O|0)==12){P=31048}else{P=(O|0)==13?30416:0}O=c[198596]|0;s=c[198597]|0;N=c[198598]|0;B=c[198599]|0;bN(y|0,64,30032,(Q=i,i=i+40|0,c[Q>>2]=P,c[Q+8>>2]=O,c[Q+16>>2]=s,c[Q+24>>2]=N,c[Q+32>>2]=B,Q)|0)|0;i=Q}else{c[198596]=0;c[198597]=0;B=c[182926]|0;N=(c[198598]|0)-1+B|0;s=N-((N>>>0)%(B>>>0)|0)|0;c[198598]=s;O=c[182927]|0;P=(c[198599]|0)-1+O|0;n=P-((P>>>0)%(O>>>0)|0)|0;c[198599]=n;t=(N>>>0)/(B>>>0)|0;B=(P>>>0)/(O>>>0)|0;bN(y|0,64,31480,(Q=i,i=i+40|0,c[Q>>2]=31920,c[Q+8>>2]=s,c[Q+16>>2]=n,c[Q+24>>2]=t,c[Q+32>>2]=B,Q)|0)|0;i=Q}if((a[y]|0)!=0){B=dq(y|0)|0;if((X1(B|0)|0)>>>0>48){a[B+46|0]=46;a[B+47|0]=46;a[B+48|0]=46;a[B+49|0]=0}y=(X1(B|0)|0)*6|0;t=y+15|0;n=(305-y|0)>>>1;s=d+28|0;O=c[s>>2]|0;P=d+32|0;N=n+5|0;A=c[P>>2]|0;m=y+5+N|0;C=A>>>1;if(m>>>0>N>>>0){L=112;do{G=ab(L,C)|0;J=L>>>1;M=N;do{K=((M>>>1)+J&1)+1|0;b[O+(M+G<<1)>>1]=(K<<13|K<<9|K<<5|12)&65535;M=M+1|0;}while(M>>>0<m>>>0);L=L+1|0;}while(L>>>0<128);R=c[s>>2]|0;S=c[P>>2]|0}else{R=O;S=A}A=y+10|0;y=n+A|0;O=S>>>1;if(y>>>0>n>>>0){L=107;do{m=ab(L,O)|0;C=L>>>1;M=n;do{G=((M>>>1)+C&1)+1|0;b[R+(M+m<<1)>>1]=(G<<13|G<<10|G<<5|12)&65535;M=M+1|0;}while(M>>>0<y>>>0);L=L+1|0;}while(L>>>0<112);T=c[s>>2]|0;U=c[P>>2]|0}else{T=R;U=S}S=n+t|0;t=co(S|0,-5|0)|0;R=t;t=U>>>1;if(F){L=107;do{y=ab(L,t)|0;O=L>>>1;M=R;do{m=((M>>>1)+O&1)+1|0;b[T+(M+y<<1)>>1]=(m<<13|m<<10|m<<5|12)&65535;M=M+1|0;}while(M>>>0<S>>>0);L=L+1|0;}while(L>>>0<128);V=c[s>>2]|0;W=c[P>>2]|0}else{V=T;W=U}U=N+A|0;A=W>>>1;if(U>>>0>N>>>0){T=A<<7;L=N;do{S=(L>>>1&1)+1|0;b[V+(L+T<<1)>>1]=(S<<13|S<<10|S<<5|12)&65535;L=L+1|0;}while(L>>>0<U>>>0);L=A*129|0;T=N;do{S=(T>>>1&1)+1|0;b[V+(T+L<<1)>>1]=(S<<13|S<<10|S<<5|12)&65535;T=T+1|0;}while(T>>>0<U>>>0);T=A*130|0;L=N;do{S=2-(L>>>1&1)|0;b[V+(L+T<<1)>>1]=(S<<13|S<<10|S<<5|12)&65535;L=L+1|0;}while(L>>>0<U>>>0);L=A*131|0;T=N;do{S=2-(T>>>1&1)|0;b[V+(T+L<<1)>>1]=(S<<13|S<<10|S<<5|12)&65535;T=T+1|0;}while(T>>>0<U>>>0);T=A*132|0;A=N;do{L=(A>>>1&1)+1|0;b[V+(A+T<<1)>>1]=(L<<13|L<<10|L<<5|12)&65535;A=A+1|0;}while(A>>>0<U>>>0);X=c[s>>2]|0;Y=c[P>>2]|0}else{X=V;Y=W}W=Y>>>1;Y=112;do{V=ab(Y,W)|0;P=Y>>>1;s=n;do{U=((s>>>1)+P&1)+1|0;b[X+(s+V<<1)>>1]=(U<<13|U<<10|U<<5|12)&65535;s=s+1|0;}while(s>>>0<N>>>0);Y=Y+1|0;}while(Y>>>0<133);ir(d,n+8|0,115,B,0);XZ(B)}B=c[198598]|0;if((B|0)==0){c[198598]=D;Z=D}else{Z=B}B=c[198599]|0;if((B|0)==0){c[198599]=E;_=E}else{_=B}g[4961]=+(Z>>>0>>>0)/+(_>>>0>>>0);_=c[(c[199354]|0)+16>>2]|0;if((_|0)==0){z=0;i=e;return z|0}fb[_&127](c[199308]|0);z=0;i=e;return z|0}_=d+52|0;L6709:do{switch(((a[_]&1)==0?v:10)|0){case 6:{c[d+48>>2]=0;a[_]=1;$=0;break};case 7:{a[_]=1;Z=c[u>>2]|0;B=c[Z+8>>2]|0;if(B>>>0>1){E=d+48|0;D=(E|0)==0;n=Z;Z=B;do{B=n+8|0;if((Z|0)!=0){Y=Z-1|0;c[B>>2]=Y;XZ(c[(c[n>>2]|0)+(Y*12|0)>>2]|0)}if(!D){c[E>>2]=c[(c[n>>2]|0)+((c[B>>2]|0)*12|0)+8>>2]}n=c[u>>2]|0;Z=c[n+8>>2]|0;}while(Z>>>0>1)}z=io(d,6)|0;i=e;return z|0};case 9:{a[d+53|0]=1;$=0;break};case 4:{Z=c[d+44>>2]|0;if((c[Z+8>>2]|0)==0){z=0;i=e;return z|0}n=d+48|0;E=c[n>>2]|0;D=c[Z>>2]|0;Z=c[D+(E*12|0)>>2]|0;B=c[D+(E*12|0)+4>>2]|0;D=B-26|0;do{if(!(D>>>0<24&((D>>>0)%3|0|0)==0|(B|0)==23|(B-68|0)>>>0<6)){if((B|0)==82|(B|0)==66|(B|0)==52|(B|0)==1){break}Y=w-26|0;N=(w|0)==23;if(Y>>>0<24&((Y>>>0)%3|0|0)==0|N){if(N){N=q|0;gr(N,x,Z);ip(d+4180|0,h1(N,3)|0,N)}else{gr(d+4256+(((Y>>>0)/3|0)*4148|0)|0,x,Z)}a[_]=1;Y=c[u>>2]|0;N=c[Y+8>>2]|0;if((N|0)==0){aa=0}else{X=c[(c[Y>>2]|0)+((N-1|0)*12|0)+4>>2]|0;if((X|0)==21){$=0;break L6709}else{aa=X}}X=(n|0)==0;W=aa;s=Y;Y=N;while(1){N=s+8|0;if((Y|0)!=0){V=Y-1|0;c[N>>2]=V;XZ(c[(c[s>>2]|0)+(V*12|0)>>2]|0)}if(!X){c[n>>2]=c[(c[s>>2]|0)+((c[N>>2]|0)*12|0)+8>>2]}N=c[u>>2]|0;V=c[N+8>>2]|0;if((V|0)==0){ac=W}else{ac=c[(c[N>>2]|0)+((V-1|0)*12|0)+4>>2]|0}if((ac|0)==21){$=0;break L6709}else{W=ac;s=N;Y=V}}}switch(w|0){case 82:{gr(596368,x,Z);Y=c[199350]|0;if((Y|0)!=0){s=Y+24|0;W=Y+12|0;X=c[W>>2]|0;if((c[s>>2]|0)==0){ad=X}else{V=0;N=X;while(1){XZ(c[N+(V*136|0)>>2]|0);XZ(c[N+(V*136|0)+8>>2]|0);X=V+1|0;P=c[W>>2]|0;if(X>>>0<(c[s>>2]|0)>>>0){V=X;N=P}else{ad=P;break}}}XZ(ad);N=c[Y+4>>2]|0;if((N|0)!=0){fc[c[N>>2]&127](c[Y>>2]|0,0)}XZ(Y)}N=hI()|0;c[199350]=N;if((N|0)==0){N=c[198610]|0;V=(N|0)!=0?N:c[p>>2]|0;a2(66256,45,1,V|0)|0;V=c[198610]|0;N=(V|0)!=0?V:c[p>>2]|0;aY(N|0)|0}a[_]=1;N=c[u>>2]|0;V=c[N+8>>2]|0;if((V|0)==0){ae=0}else{s=c[(c[N>>2]|0)+((V-1|0)*12|0)+4>>2]|0;if((s|0)==55){$=0;break L6709}else{ae=s}}s=(n|0)==0;W=ae;P=N;N=V;while(1){V=P+8|0;if((N|0)!=0){X=N-1|0;c[V>>2]=X;XZ(c[(c[P>>2]|0)+(X*12|0)>>2]|0)}if(!s){c[n>>2]=c[(c[P>>2]|0)+((c[V>>2]|0)*12|0)+8>>2]}V=c[u>>2]|0;X=c[V+8>>2]|0;if((X|0)==0){af=W}else{af=c[(c[V>>2]|0)+((X-1|0)*12|0)+4>>2]|0}if((af|0)==55){$=0;break L6709}else{W=af;P=V;N=X}}break};case 69:{N=4096;P=543313;W=x;while(1){s=N-1|0;if((s|0)==0){ag=4961;break}Y=a[W]|0;a[P]=Y;if(Y<<24>>24==0){break}else{N=s;P=P+1|0;W=W+1|0}}do{if((ag|0)==4961){a[P]=0;if((a[W]|0)==0){break}else{ah=W}do{ah=ah+1|0;}while((a[ah]|0)!=0)}}while(0);a[_]=1;W=c[u>>2]|0;P=c[W+8>>2]|0;if((P|0)==0){ai=0}else{N=c[(c[W>>2]|0)+((P-1|0)*12|0)+4>>2]|0;if((N|0)==56){$=0;break L6709}else{ai=N}}N=(n|0)==0;s=ai;Y=W;W=P;while(1){P=Y+8|0;if((W|0)!=0){X=W-1|0;c[P>>2]=X;XZ(c[(c[Y>>2]|0)+(X*12|0)>>2]|0)}if(!N){c[n>>2]=c[(c[Y>>2]|0)+((c[P>>2]|0)*12|0)+8>>2]}P=c[u>>2]|0;X=c[P+8>>2]|0;if((X|0)==0){aj=s}else{aj=c[(c[P>>2]|0)+((X-1|0)*12|0)+4>>2]|0}if((aj|0)==56){$=0;break L6709}else{s=aj;Y=P;W=X}}break};case 72:{W=4096;Y=715274;s=x;while(1){N=W-1|0;if((N|0)==0){ag=4933;break}X=a[s]|0;a[Y]=X;if(X<<24>>24==0){break}else{W=N;Y=Y+1|0;s=s+1|0}}do{if((ag|0)==4933){a[Y]=0;if((a[s]|0)==0){break}else{ak=s}do{ak=ak+1|0;}while((a[ak]|0)!=0)}}while(0);a[_]=1;s=c[u>>2]|0;Y=c[s+8>>2]|0;if((Y|0)==0){al=0}else{W=c[(c[s>>2]|0)+((Y-1|0)*12|0)+4>>2]|0;if((W|0)==56){$=0;break L6709}else{al=W}}W=(n|0)==0;N=al;X=s;s=Y;while(1){Y=X+8|0;if((s|0)!=0){P=s-1|0;c[Y>>2]=P;XZ(c[(c[X>>2]|0)+(P*12|0)>>2]|0)}if(!W){c[n>>2]=c[(c[X>>2]|0)+((c[Y>>2]|0)*12|0)+8>>2]}Y=c[u>>2]|0;P=c[Y+8>>2]|0;if((P|0)==0){am=N}else{am=c[(c[Y>>2]|0)+((P-1|0)*12|0)+4>>2]|0}if((am|0)==56){$=0;break L6709}else{N=am;X=Y;s=P}}break};case 51:{s=c[58922]|0;X=c[c[s+113712>>2]>>2]|0;N=c[X+(E*12|0)>>2]|0;W=4096;P=612764;Y=c[X+(E*12|0)+4>>2]|0;while(1){X=W-1|0;if((X|0)==0){ag=4879;break}V=a[Y]|0;a[P]=V;if(V<<24>>24==0){break}else{W=X;P=P+1|0;Y=Y+1|0}}do{if((ag|0)==4879){a[P]=0;if((a[Y]|0)==0){break}else{an=Y}do{an=an+1|0;}while((a[an]|0)!=0)}}while(0);Y=s+4176|0;L6849:do{if((N|0)==0){a[Y]=1;a[674314]=0}else{a[Y]=0;P=4096;W=674314;X=N;while(1){V=P-1|0;if((V|0)==0){break}U=a[X]|0;a[W]=U;if(U<<24>>24==0){break L6849}else{P=V;W=W+1|0;X=X+1|0}}a[W]=0;if((a[X]|0)==0){break}else{ao=X}do{ao=ao+1|0;}while((a[ao]|0)!=0)}}while(0);a[_]=1;N=c[u>>2]|0;Y=c[N+8>>2]|0;if((Y|0)==0){ap=0}else{s=c[(c[N>>2]|0)+((Y-1|0)*12|0)+4>>2]|0;if((s|0)==4){$=-1;break L6709}else{ap=s}}s=(n|0)==0;X=ap;W=N;N=Y;while(1){Y=W+8|0;if((N|0)!=0){P=N-1|0;c[Y>>2]=P;XZ(c[(c[W>>2]|0)+(P*12|0)>>2]|0)}if(!s){c[n>>2]=c[(c[W>>2]|0)+((c[Y>>2]|0)*12|0)+8>>2]}Y=c[u>>2]|0;P=c[Y+8>>2]|0;if((P|0)==0){aq=X}else{aq=c[(c[Y>>2]|0)+((P-1|0)*12|0)+4>>2]|0}if((aq|0)==4){$=-1;break L6709}else{X=aq;W=Y;N=P}}break};case 52:{a[_]=1;N=c[u>>2]|0;W=c[N+8>>2]|0;if((W|0)==0){ar=0}else{X=c[(c[N>>2]|0)+((W-1|0)*12|0)+4>>2]|0;if((X|0)==4){$=0;break L6709}else{ar=X}}X=(n|0)==0;s=ar;P=N;N=W;while(1){W=P+8|0;if((N|0)!=0){Y=N-1|0;c[W>>2]=Y;XZ(c[(c[P>>2]|0)+(Y*12|0)>>2]|0)}if(!X){c[n>>2]=c[(c[P>>2]|0)+((c[W>>2]|0)*12|0)+8>>2]}W=c[u>>2]|0;Y=c[W+8>>2]|0;if((Y|0)==0){as=s}else{as=c[(c[W>>2]|0)+((Y-1|0)*12|0)+4>>2]|0}if((as|0)==4){$=0;break L6709}else{s=as;P=W;N=Y}}break};case 68:{N=4096;P=633281;s=x;while(1){X=N-1|0;if((X|0)==0){ag=4900;break}Y=a[s]|0;a[P]=Y;if(Y<<24>>24==0){break}else{N=X;P=P+1|0;s=s+1|0}}do{if((ag|0)==4900){a[P]=0;if((a[s]|0)==0){break}else{at=s}do{at=at+1|0;}while((a[at]|0)!=0)}}while(0);s=4096;P=d+54|0;N=x;while(1){X=s-1|0;if((X|0)==0){ag=4905;break}Y=a[N]|0;a[P]=Y;if(Y<<24>>24==0){break}else{s=X;P=P+1|0;N=N+1|0}}do{if((ag|0)==4905){a[P]=0;if((a[N]|0)==0){break}else{au=N}do{au=au+1|0;}while((a[au]|0)!=0)}}while(0);a[_]=1;N=c[u>>2]|0;P=c[N+8>>2]|0;if((P|0)==0){av=0}else{s=c[(c[N>>2]|0)+((P-1|0)*12|0)+4>>2]|0;if((s|0)==56){$=0;break L6709}else{av=s}}s=(n|0)==0;X=av;Y=N;N=P;while(1){P=Y+8|0;if((N|0)!=0){W=N-1|0;c[P>>2]=W;XZ(c[(c[Y>>2]|0)+(W*12|0)>>2]|0)}if(!s){c[n>>2]=c[(c[Y>>2]|0)+((c[P>>2]|0)*12|0)+8>>2]}P=c[u>>2]|0;W=c[P+8>>2]|0;if((W|0)==0){aw=X}else{aw=c[(c[P>>2]|0)+((W-1|0)*12|0)+4>>2]|0}if((aw|0)==56){$=0;break L6709}else{X=aw;Y=P;N=W}}break};case 66:{N=r|0;gr(N,x,Z);Y=h|0;f5(1,0);fw[c[184102]&31]()|0;X=fw[c[184100]&31]()|0;if((X|0)!=0){s=X-1|0;X2(f|0,0,16);c[f>>2]=N;X=c[184101]|0;ft[X&63](s,f)|0;f6(s);bN(Y|0,512,63680,(Q=i,i=i+8|0,c[Q>>2]=N,Q)|0)|0;i=Q;if((a[637400]&1)!=0){s=c[198610]|0;X=(s|0)!=0?s:c[p>>2]|0;ec(X|0,93640,(Q=i,i=i+8|0,c[Q>>2]=Y,Q)|0)|0;i=Q;X=c[198610]|0;s=(X|0)!=0?X:c[p>>2]|0;aY(s|0)|0}s=c[196481]|0;X=s+4|0;W=c[X>>2]|0;if(W>>>0>1){P=s|0;V=1;U=W;while(1){W=c[(c[P>>2]|0)+(V<<2)>>2]|0;if((W|0)==0){ax=U}else{XZ(c[W+8>>2]|0);XZ(c[(c[P>>2]|0)+(V<<2)>>2]|0);c[(c[P>>2]|0)+(V<<2)>>2]=0;ax=c[X>>2]|0}W=V+1|0;if(W>>>0<ax>>>0){V=W;U=ax}else{break}}}c[X>>2]=1;U=s+12|0;XZ(c[U>>2]|0);c[U>>2]=0;U=c[196481]|0;V=U+4|0;L6932:do{if((c[V>>2]|0)>>>0<(c[U+8>>2]|0)>>>0){P=XY(12)|0;do{if((P|0)!=0){if((c[P-4>>2]&3|0)==0){break}X2(P|0,0,12)}}while(0);c[P+4>>2]=0;c[P>>2]=180;W=dq(Y|0)|0;A=c[V>>2]|0;c[P+8>>2]=W;W=U|0;c[(c[W>>2]|0)+(A<<2)>>2]=P;A=c[V>>2]|0;c[V>>2]=A+1;if(A>>>0>1){ay=A}else{break}while(1){A=ay>>>1;T=c[W>>2]|0;L=T+(A<<2)|0;S=c[L>>2]|0;R=c[T+(ay<<2)>>2]|0;if((c[R+4>>2]|0)>>>0<=(c[S+4>>2]|0)>>>0){break L6932}c[L>>2]=R;c[(c[W>>2]|0)+(ay<<2)>>2]=S;if(ay>>>0>3){ay=A}else{break}}}}while(0);f7(N);f8();f5(0,0)}V=794432;U=c[V+4>>2]|0;Y=794432;c[Y>>2]=c[V>>2]|1;c[Y+4>>2]=U;a[_]=1;U=c[u>>2]|0;Y=c[U+8>>2]|0;if((Y|0)==0){az=0;aA=U;aB=Y}else{V=c[(c[U>>2]|0)+((Y-1|0)*12|0)+4>>2]|0;if((V|0)==4){$=-1;break L6709}else{az=V;aA=U;aB=Y}}while(1){Y=aA+8|0;if((aB|0)==0){aC=0;aD=aA;aE=aA|0}else{U=aB-1|0;c[Y>>2]=U;V=aA|0;XZ(c[(c[V>>2]|0)+(U*12|0)>>2]|0);aC=c[Y>>2]|0;aD=c[u>>2]|0;aE=V}c[n>>2]=c[(c[aE>>2]|0)+(aC*12|0)+8>>2];V=c[aD+8>>2]|0;if((V|0)==0){aF=az}else{aF=c[(c[aD>>2]|0)+((V-1|0)*12|0)+4>>2]|0}if((aF|0)==4){$=-1;break L6709}else{az=aF;aA=aD;aB=V}}break};case 73:{N=4096;V=629148;Y=x;while(1){U=N-1|0;if((U|0)==0){ag=4975;break}s=a[Y]|0;a[V]=s;if(s<<24>>24==0){break}else{N=U;V=V+1|0;Y=Y+1|0}}do{if((ag|0)==4975){a[V]=0;if((a[Y]|0)==0){break}else{aG=Y}do{aG=aG+1|0;}while((a[aG]|0)!=0)}}while(0);a[_]=1;Y=c[u>>2]|0;V=c[Y+8>>2]|0;if((V|0)==0){aH=0}else{N=c[(c[Y>>2]|0)+((V-1|0)*12|0)+4>>2]|0;if((N|0)==56){$=0;break L6709}else{aH=N}}N=(n|0)==0;U=aH;s=Y;Y=V;while(1){V=s+8|0;if((Y|0)!=0){X=Y-1|0;c[V>>2]=X;XZ(c[(c[s>>2]|0)+(X*12|0)>>2]|0)}if(!N){c[n>>2]=c[(c[s>>2]|0)+((c[V>>2]|0)*12|0)+8>>2]}V=c[u>>2]|0;X=c[V+8>>2]|0;if((X|0)==0){aI=U}else{aI=c[(c[V>>2]|0)+((X-1|0)*12|0)+4>>2]|0}if((aI|0)==56){$=0;break L6709}else{U=aI;s=V;Y=X}}break};case 71:{Y=4096;s=707082;U=x;while(1){N=Y-1|0;if((N|0)==0){ag=4919;break}X=a[U]|0;a[s]=X;if(X<<24>>24==0){break}else{Y=N;s=s+1|0;U=U+1|0}}do{if((ag|0)==4919){a[s]=0;if((a[U]|0)==0){break}else{aJ=U}do{aJ=aJ+1|0;}while((a[aJ]|0)!=0)}}while(0);a[_]=1;U=c[u>>2]|0;s=c[U+8>>2]|0;if((s|0)==0){aK=0}else{Y=c[(c[U>>2]|0)+((s-1|0)*12|0)+4>>2]|0;if((Y|0)==56){$=0;break L6709}else{aK=Y}}Y=(n|0)==0;N=aK;X=U;U=s;while(1){s=X+8|0;if((U|0)!=0){V=U-1|0;c[s>>2]=V;XZ(c[(c[X>>2]|0)+(V*12|0)>>2]|0)}if(!Y){c[n>>2]=c[(c[X>>2]|0)+((c[s>>2]|0)*12|0)+8>>2]}s=c[u>>2]|0;V=c[s+8>>2]|0;if((V|0)==0){aL=N}else{aL=c[(c[s>>2]|0)+((V-1|0)*12|0)+4>>2]|0}if((aL|0)==56){$=0;break L6709}else{N=aL;X=s;U=V}}break};case 70:{U=4096;X=711178;N=x;while(1){Y=U-1|0;if((Y|0)==0){ag=4947;break}V=a[N]|0;a[X]=V;if(V<<24>>24==0){break}else{U=Y;X=X+1|0;N=N+1|0}}do{if((ag|0)==4947){a[X]=0;if((a[N]|0)==0){break}else{aM=N}do{aM=aM+1|0;}while((a[aM]|0)!=0)}}while(0);a[_]=1;N=c[u>>2]|0;X=c[N+8>>2]|0;if((X|0)==0){aN=0}else{U=c[(c[N>>2]|0)+((X-1|0)*12|0)+4>>2]|0;if((U|0)==56){$=0;break L6709}else{aN=U}}U=(n|0)==0;Y=aN;V=N;N=X;while(1){X=V+8|0;if((N|0)!=0){s=N-1|0;c[X>>2]=s;XZ(c[(c[V>>2]|0)+(s*12|0)>>2]|0)}if(!U){c[n>>2]=c[(c[V>>2]|0)+((c[X>>2]|0)*12|0)+8>>2]}X=c[u>>2]|0;s=c[X+8>>2]|0;if((s|0)==0){aO=Y}else{aO=c[(c[X>>2]|0)+((s-1|0)*12|0)+4>>2]|0}if((aO|0)==56){$=0;break L6709}else{Y=aO;V=X;N=s}}break};default:{gr(674314,x,Z);N=794432;V=c[N+4>>2]|0;Y=794432;c[Y>>2]=c[N>>2]|2;c[Y+4>>2]=V;a[_]=1;V=c[u>>2]|0;Y=c[V+8>>2]|0;if((Y|0)==0){aP=0;aQ=V;aR=Y;ag=4989}else{N=c[(c[V>>2]|0)+((Y-1|0)*12|0)+4>>2]|0;if((N|0)!=4){aP=N;aQ=V;aR=Y;ag=4989}}if((ag|0)==4989){while(1){ag=0;Y=aQ+8|0;if((aR|0)==0){aS=0;aT=aQ;aU=aQ|0}else{V=aR-1|0;c[Y>>2]=V;N=aQ|0;XZ(c[(c[N>>2]|0)+(V*12|0)>>2]|0);aS=c[Y>>2]|0;aT=c[u>>2]|0;aU=N}c[n>>2]=c[(c[aU>>2]|0)+(aS*12|0)+8>>2];N=c[aT+8>>2]|0;if((N|0)==0){aV=aP}else{aV=c[(c[aT>>2]|0)+((N-1|0)*12|0)+4>>2]|0}if((aV|0)==4){break}else{aP=aV;aQ=aT;aR=N;ag=4989}}}a[d+53|0]=1;$=-1;break L6709}}}}while(0);E=o|0;gr(E,x,Z);D=c[u>>2]|0;N=c[n>>2]|0;if((D|0)!=0){Y=D+8|0;V=D+4|0;U=c[V>>2]|0;if((c[Y>>2]|0)>>>0<U>>>0){aW=D|0}else{s=(U<<1)+2|0;c[V>>2]=s;V=D|0;c[V>>2]=X_(c[V>>2]|0,s*12|0)|0;aW=V}V=dq(E|0)|0;c[(c[aW>>2]|0)+((c[Y>>2]|0)*12|0)>>2]=V;c[(c[aW>>2]|0)+((c[Y>>2]|0)*12|0)+4>>2]=B;c[(c[aW>>2]|0)+((c[Y>>2]|0)*12|0)+8>>2]=N;c[Y>>2]=(c[Y>>2]|0)+1}c[n>>2]=0;a[_]=1;$=0;break};case 3:{Y=d+48|0;N=(c[Y>>2]|0)+8|0;V=c[(c[d+44>>2]|0)+8>>2]|0;if(N>>>0<V>>>0){c[Y>>2]=N;$=0;break L6709}else{c[Y>>2]=V-1;$=0;break L6709}break};case 5:{V=c[u>>2]|0;Y=V+8|0;if((c[Y>>2]|0)>>>0<=1){$=0;break L6709}a[_]=1;N=d+48|0;E=c[Y>>2]|0;if((E|0)!=0){s=E-1|0;c[Y>>2]=s;XZ(c[(c[V>>2]|0)+(s*12|0)>>2]|0)}if((N|0)==0){$=0;break L6709}c[N>>2]=c[(c[V>>2]|0)+((c[Y>>2]|0)*12|0)+8>>2];$=0;break};case 1:{Y=d+48|0;V=(c[Y>>2]|0)+1|0;if(V>>>0<(c[(c[d+44>>2]|0)+8>>2]|0)>>>0){c[Y>>2]=V;$=0;break L6709}else{c[Y>>2]=0;$=0;break L6709}break};case 0:{Y=d+48|0;V=c[Y>>2]|0;if((V|0)==0){c[Y>>2]=(c[(c[d+44>>2]|0)+8>>2]|0)-1;$=0;break L6709}else{c[Y>>2]=V-1;$=0;break L6709}break};case 2:{V=d+48|0;Y=c[V>>2]|0;if(Y>>>0>8){c[V>>2]=Y-8;$=0;break L6709}else{c[V>>2]=0;$=0;break L6709}break};default:{$=0}}}while(0);aW=c[u>>2]|0;u=c[aW+8>>2]|0;if((u|0)==0){aX=w;aZ=x}else{x=u-1|0;u=c[aW>>2]|0;aX=c[u+(x*12|0)+4>>2]|0;aZ=c[u+(x*12|0)>>2]|0}L7054:do{if((a[_]&1)!=0){do{if((aX|0)!=1){x=aX-26|0;if(x>>>0<24&((x>>>0)%3|0|0)==0|(aX|0)==23|(aX-68|0)>>>0<6){break}if(!((aX|0)==82|(aX|0)==66|(aX|0)==52|(aX|0)==51)){break L7054}}}while(0);a[_]=0;n=d+44|0;B=c[n>>2]|0;Z=B+8|0;if((c[Z>>2]|0)!=0){x=B|0;B=0;do{XZ(c[(c[x>>2]|0)+(B*12|0)>>2]|0);B=B+1|0;}while(B>>>0<(c[Z>>2]|0)>>>0)}c[Z>>2]=0;L7065:do{if((aX|0)==51){B=k|0;x=l|0;u=d+113712|0;aW=c[u>>2]|0;w=c[aW+4>>2]|0;if((w|0)==0){break}else{a_=0;a$=aW}while(1){aW=c[a$>>2]|0;o=c[aW+(a_*12|0)>>2]|0;ag=c[aW+(a_*12|0)+8>>2]|0;L7069:do{if((o|0)==0){aW=4096;aR=B;aT=ag;while(1){aQ=aW-1|0;if((aQ|0)==0){break}aV=a[aT]|0;a[aR]=aV;if(aV<<24>>24==0){break L7069}else{aW=aQ;aR=aR+1|0;aT=aT+1|0}}a[aR]=0;if((a[aT]|0)==0){break}else{a0=aT}do{a0=a0+1|0;}while((a[a0]|0)!=0)}else{aT=cg(o|0,47)|0;gs(x,(aT|0)==0?o:aT+1|0,798256);bN(B|0,4096,33696,(Q=i,i=i+16|0,c[Q>>2]=x,c[Q+8>>2]=ag,Q)|0)|0;i=Q}}while(0);ag=c[n>>2]|0;if((ag|0)!=0){o=ag+8|0;aT=ag+4|0;aR=c[aT>>2]|0;if((c[o>>2]|0)>>>0<aR>>>0){a1=ag|0}else{aW=(aR<<1)+2|0;c[aT>>2]=aW;aT=ag|0;c[aT>>2]=X_(c[aT>>2]|0,aW*12|0)|0;a1=aT}aT=dq(B|0)|0;c[(c[a1>>2]|0)+((c[o>>2]|0)*12|0)>>2]=aT;c[(c[a1>>2]|0)+((c[o>>2]|0)*12|0)+4>>2]=0;c[(c[a1>>2]|0)+((c[o>>2]|0)*12|0)+8>>2]=0;c[o>>2]=(c[o>>2]|0)+1}o=a_+1|0;if(o>>>0>=w>>>0){break L7065}a_=o;a$=c[u>>2]|0}}else{u=c[n>>2]|0;w=j|0;if((a[aZ]|0)==0){if((u|0)==0){break}B=u+8|0;x=u+4|0;o=c[x>>2]|0;if((c[B>>2]|0)>>>0<o>>>0){a3=u|0}else{aT=(o<<1)+2|0;c[x>>2]=aT;x=u|0;c[x>>2]=X_(c[x>>2]|0,aT*12|0)|0;a3=x}x=dq(36576)|0;c[(c[a3>>2]|0)+((c[B>>2]|0)*12|0)>>2]=x;c[(c[a3>>2]|0)+((c[B>>2]|0)*12|0)+4>>2]=aX;c[(c[a3>>2]|0)+((c[B>>2]|0)*12|0)+8>>2]=0;c[B>>2]=(c[B>>2]|0)+1;break}do{if((aX|0)==52){a4=798256}else if((aX|0)==23){a4=36168}else{B=aX-26|0;if(B>>>0<24&((B>>>0)%3|0|0)==0){a4=35624;break}if((aX|0)==82){a4=35024;break}if((aX-68|0)>>>0<6){a4=798256;break}B=c[d+4168>>2]|0;if((B|0)==0){a4=732280;break}if((a[B]|0)==0){a[w]=0;a4=w;break}else{bN(w|0,1024,34600,(Q=i,i=i+8|0,c[Q>>2]=B,Q)|0)|0;i=Q;a4=w;break}}}while(0);w=gq(aZ,a4,1)|0;if((w|0)==0){break}B=w|0;x=w+4|0;dh(c[B>>2]|0,c[x>>2]|0,8,32);aT=(aX-68|0)>>>0<6;o=(u|0)==0;if(!(o|aT^1)){aW=u+8|0;ag=u+4|0;aR=c[ag>>2]|0;if((c[aW>>2]|0)>>>0<aR>>>0){a5=u|0}else{aQ=(aR<<1)+2|0;c[ag>>2]=aQ;ag=u|0;c[ag>>2]=X_(c[ag>>2]|0,aQ*12|0)|0;a5=ag}ag=dq(34136)|0;c[(c[a5>>2]|0)+((c[aW>>2]|0)*12|0)>>2]=ag;c[(c[a5>>2]|0)+((c[aW>>2]|0)*12|0)+4>>2]=3;c[(c[a5>>2]|0)+((c[aW>>2]|0)*12|0)+8>>2]=0;c[aW>>2]=(c[aW>>2]|0)+1}aW=c[x>>2]|0;do{if((aW|0)==0){a6=c[B>>2]|0}else{ag=u+8|0;aQ=u+4|0;aR=u|0;if(aT){aV=0;aP=aW;while(1){aS=c[B>>2]|0;do{if((a[aS+(aV<<3)+4|0]&1)==0){a7=aP}else{aU=c[aS+(aV<<3)>>2]|0;if((a[aZ]|0)==0){a8=aU}else{aO=cg(aU|0,47)|0;a8=(aO|0)==0?aU:aO+1|0}if(o){a7=aP;break}aO=c[aQ>>2]|0;if((c[ag>>2]|0)>>>0>=aO>>>0){aU=(aO<<1)+2|0;c[aQ>>2]=aU;c[aR>>2]=X_(c[aR>>2]|0,aU*12|0)|0}aU=dq(a8|0)|0;c[(c[aR>>2]|0)+((c[ag>>2]|0)*12|0)>>2]=aU;c[(c[aR>>2]|0)+((c[ag>>2]|0)*12|0)+4>>2]=aX;c[(c[aR>>2]|0)+((c[ag>>2]|0)*12|0)+8>>2]=0;c[ag>>2]=(c[ag>>2]|0)+1;a7=c[x>>2]|0}}while(0);aS=aV+1|0;if(aS>>>0<a7>>>0){aV=aS;aP=a7}else{a9=a7;break}}}else{aP=0;aV=aW;while(1){aS=c[B>>2]|0;aU=a[aS+(aP<<3)+4|0]|0;aO=c[aS+(aP<<3)>>2]|0;if((a[aZ]|0)==0){ba=aO}else{aS=cg(aO|0,47)|0;ba=(aS|0)==0?aO:aS+1|0}aS=(aU&1)!=0?aX:0;if(o){bb=aV}else{aU=c[aQ>>2]|0;if((c[ag>>2]|0)>>>0>=aU>>>0){aO=(aU<<1)+2|0;c[aQ>>2]=aO;c[aR>>2]=X_(c[aR>>2]|0,aO*12|0)|0}aO=dq(ba|0)|0;c[(c[aR>>2]|0)+((c[ag>>2]|0)*12|0)>>2]=aO;c[(c[aR>>2]|0)+((c[ag>>2]|0)*12|0)+4>>2]=aS;c[(c[aR>>2]|0)+((c[ag>>2]|0)*12|0)+8>>2]=0;c[ag>>2]=(c[ag>>2]|0)+1;bb=c[x>>2]|0}aS=aP+1|0;if(aS>>>0<bb>>>0){aP=aS;aV=bb}else{a9=bb;break}}}aV=c[B>>2]|0;if((a9|0)==0){a6=aV;break}else{bc=0;bd=aV}while(1){XZ(c[bd+(bc<<3)>>2]|0);aV=bc+1|0;aP=c[B>>2]|0;if(aV>>>0<(c[x>>2]|0)>>>0){bc=aV;bd=aP}else{a6=aP;break}}}}while(0);XZ(a6);XZ(w)}}while(0);Z=d+48|0;x=c[(c[n>>2]|0)+8>>2]|0;B=(x|0)==0;if(!((c[Z>>2]|0)>>>0<x>>>0|B)){c[Z>>2]=x-1;break}if(!B){break}c[Z>>2]=0}}while(0);iq(d);z=$;i=e;return z|0}function io(b,d){b=b|0;d=d|0;var f=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0.0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0.0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0.0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0.0,aU=0,aV=0.0,aW=0,aX=0.0,aZ=0,a_=0.0,a$=0.0,a0=0,a1=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0;f=i;i=i+13184|0;j=f|0;k=f+128|0;l=f+192|0;m=f+256|0;n=f+320|0;o=f+384|0;q=f+448|0;r=f+512|0;s=f+4608|0;t=f+4672|0;u=f+8768|0;v=f+9024|0;w=f+9088|0;c[b+32>>2]=640;do{if((d|0)==6){x=0;y=0}else{z=c[b+48>>2]|0;A=c[c[b+44>>2]>>2]|0;B=c[A+(z*12|0)>>2]|0;C=c[A+(z*12|0)+4>>2]|0;if((C|0)==66){x=b+54|0;y=66;break}else if((C|0)==52){x=798256;y=52;break}else{x=B;y=C;break}}}while(0);C=b+40|0;B=c[C>>2]|0;z=B+8|0;A=c[z>>2]|0;if((A|0)==0){D=0}else{D=c[(c[B>>2]|0)+((A-1|0)*12|0)+4>>2]|0}E=b+52|0;G=(a[E]&1)==0?d:10;L7162:do{switch(G|0){case 2:case 3:case 4:case 8:{d=(G|0)==4;if((y|0)==50&d){H=b+54|0;I=b+48|0;J=c[I>>2]|0;if((B|0)!=0){K=B+4|0;L=c[K>>2]|0;if(A>>>0<L>>>0){M=B|0}else{N=(L<<1)+2|0;c[K>>2]=N;K=B|0;c[K>>2]=X_(c[K>>2]|0,N*12|0)|0;M=K}K=dq(H|0)|0;c[(c[M>>2]|0)+((c[z>>2]|0)*12|0)>>2]=K;c[(c[M>>2]|0)+((c[z>>2]|0)*12|0)+4>>2]=1;c[(c[M>>2]|0)+((c[z>>2]|0)*12|0)+8>>2]=J;c[z>>2]=(c[z>>2]|0)+1}c[I>>2]=0;a[E]=1;break L7162}do{if((y|0)==51){if(!d){break L7162}}else{if((y-68|0)>>>0<6&d){break}L7177:do{switch(y|0){case 64:case 57:case 56:case 54:case 53:case 21:case 5:case 4:case 55:case 66:case 52:{if(!d){break L7177}I=b+48|0;J=c[I>>2]|0;if((B|0)!=0){K=B+4|0;H=c[K>>2]|0;if(A>>>0<H>>>0){O=B|0}else{N=(H<<1)+2|0;c[K>>2]=N;K=B|0;c[K>>2]=X_(c[K>>2]|0,N*12|0)|0;O=K}K=dq(x|0)|0;c[(c[O>>2]|0)+((c[z>>2]|0)*12|0)>>2]=K;c[(c[O>>2]|0)+((c[z>>2]|0)*12|0)+4>>2]=y;c[(c[O>>2]|0)+((c[z>>2]|0)*12|0)+8>>2]=J;c[z>>2]=(c[z>>2]|0)+1}c[I>>2]=0;a[E]=1;break L7162;break};default:{if(!((y|0)==12&d)){break L7177}I=c[b+48>>2]|0;if((B|0)!=0){J=B+4|0;K=c[J>>2]|0;if(A>>>0<K>>>0){P=B|0}else{N=(K<<1)+2|0;c[J>>2]=N;J=B|0;c[J>>2]=X_(c[J>>2]|0,N*12|0)|0;P=J}J=dq(798256)|0;c[(c[P>>2]|0)+((c[z>>2]|0)*12|0)>>2]=J;c[(c[P>>2]|0)+((c[z>>2]|0)*12|0)+4>>2]=12;c[(c[P>>2]|0)+((c[z>>2]|0)*12|0)+8>>2]=I;c[z>>2]=(c[z>>2]|0)+1}fc[c[(c[199305]|0)+44>>2]&127](c[199308]|0,794384);g[4961]=+((c[198598]|0)>>>0>>>0)/+((c[198599]|0)>>>0>>>0);c[133777]=7;I=c[(c[199354]|0)+12>>2]|0;if((I|0)==0){break L7162}fc[I&127](c[199308]|0,7);break L7162}}}while(0);I=b+113708|0;J=c[I>>2]|0;if((y-6|0)>>>0<15){switch(y|0){case 11:{do{if((G|0)==3){N=c[133777]|0;if(N>>>0>=7){break}c[133777]=N+1}else if((G|0)==8){c[133777]=4}else if((G|0)==2){N=c[133777]|0;if((N|0)==0){break}c[133777]=N-1}}while(0);N=c[(c[199354]|0)+12>>2]|0;if((N|0)==0){break L7162}fc[N&127](c[199308]|0,c[133777]|0);break L7162;break};case 15:{if((G|0)==3){N=c[198602]|0;if(N>>>0<3){K=N+1|0;c[198602]=K;Q=K}else{Q=N}fc[c[(c[199305]|0)+40>>2]&127](c[199308]|0,Q);break L7162}else if((G|0)==8){g[139947]=.004999999888241291;a[559785]=1;fc[c[(c[199305]|0)+40>>2]&127](c[199308]|0,c[198602]|0);break L7162}else if((G|0)==2){N=c[198602]|0;if((N|0)==0){R=0}else{K=N-1|0;c[198602]=K;R=K}fc[c[(c[199305]|0)+40>>2]&127](c[199308]|0,R);break L7162}else{break L7162}break};case 10:{do{if((G|0)==8){a[535105]=0}else{if((G-2|0)>>>0>=3){break}a[535105]=a[535105]&1^1}}while(0);K=c[(c[199354]|0)+16>>2]|0;if((K|0)==0){break L7162}fb[K&127](c[199308]|0);break L7162;break};case 7:{if((G|0)==8){S=1}else{S=a[535096]&1^1}a[535096]=S;K=c[c[199354]>>2]|0;if((K|0)==0){break L7162}fy[K&511](c[199308]|0,1,(S&1)!=0);break L7162;break};case 14:{if(!d){break L7162}a[535072]=a[535072]&1^1;a[797241]=a[736440]&1;a[797242]=0;gD();K=c[184111]|0;do{if((K|0)!=0){if((a[797241]&1)!=0){break}fz[K&8191]()}}while(0);gE();if((a[797243]&1)!=0){c[199308]=0}if((a[797244]&1)!=0){c[199307]=0}if((a[797245]&1)!=0){c[199309]=0}a[797243]=0;a[797244]=0;a[797245]=0;gC();a[797241]=0;K=c[199306]|0;if((K|0)==0){break L7162}fb[c[K+4>>2]&127](c[199309]|0);break L7162;break};case 16:{if((G|0)==8){a[535088]=1;break L7162}else if((G|0)==2|(G|0)==3|(G|0)==4){a[535088]=a[535088]&1^1;break L7162}else{break L7162}break};case 9:{if((G|0)==2){K=c[198603]|0;if((K|0)==0){break L7162}c[198603]=K-1;K=c[(c[199354]|0)+16>>2]|0;if((K|0)==0){break L7162}fb[K&127](c[199308]|0);break L7162}else if((G|0)==8){c[198603]=0;K=c[(c[199354]|0)+16>>2]|0;if((K|0)==0){break L7162}fb[K&127](c[199308]|0);break L7162}else{if(!((G|0)==3&(c[198603]|0)==0)){break L7162}c[198603]=1;K=c[(c[199354]|0)+16>>2]|0;if((K|0)==0){break L7162}fb[K&127](c[199308]|0);break L7162}break};case 17:{if((G|0)==8){a[535089]=0;break L7162}else if((G|0)==2|(G|0)==3|(G|0)==4){a[535089]=a[535089]&1^1;break L7162}else{break L7162}break};case 18:{if((G|0)==3|(G|0)==4){K=c[133773]|0;if(K>>>0>=3){break L7162}c[133773]=K+1;break L7162}else if((G|0)==8){c[133773]=0;break L7162}else if((G|0)==2){K=c[133773]|0;if((K|0)==0){break L7162}c[133773]=K-1;break L7162}else{break L7162}break};case 19:{if((G|0)==8){K=785752;c[K>>2]=0;c[K+4>>2]=0;break L7162}else if((G|0)!=4){break L7162}if((a[543312]&1)!=0){break L7162}K=785752;N=c[K>>2]|0;H=c[K+4>>2]|0;K=0;L=H>>>0>K>>>0|H>>>0==K>>>0&N>>>0>2048>>>0?2048:N;if(L>>>0<2){break L7162}else{T=0;U=0;V=0}do{N=769368+(T<<3)|0;V=Ye(c[N>>2]|0,c[N+4>>2]|0,V,U)|0;U=F;T=T+1|0;}while(T>>>0<L>>>0);N=Ym(V,U,L,0)|0;W=1.0e6/(+(N>>>0)+ +(F|0)*4294967296.0);N=u|0;bN(N|0,256,51848,(X=i,i=i+8|0,h[X>>3]=W,X)|0)|0;i=X;K=c[196481]|0;H=K+4|0;L7282:do{if((c[H>>2]|0)>>>0<(c[K+8>>2]|0)>>>0){Y=XY(12)|0;do{if((Y|0)!=0){if((c[Y-4>>2]&3|0)==0){break}X2(Y|0,0,12)}}while(0);c[Y+4>>2]=1;c[Y>>2]=180;Z=dq(N|0)|0;_=c[H>>2]|0;c[Y+8>>2]=Z;Z=K|0;c[(c[Z>>2]|0)+(_<<2)>>2]=Y;_=c[H>>2]|0;c[H>>2]=_+1;if(_>>>0>1){$=_}else{break}while(1){_=$>>>1;aa=c[Z>>2]|0;ab=aa+(_<<2)|0;ac=c[ab>>2]|0;ad=c[aa+($<<2)>>2]|0;if((c[ad+4>>2]|0)>>>0<=(c[ac+4>>2]|0)>>>0){break L7282}c[ab>>2]=ad;c[(c[Z>>2]|0)+($<<2)>>2]=ac;if($>>>0>3){$=_}else{break}}}}while(0);if((a[637400]&1)!=0){H=c[198610]|0;K=(H|0)!=0?H:c[p>>2]|0;ec(K|0,93640,(X=i,i=i+8|0,c[X>>2]=N,X)|0)|0;i=X;K=c[198610]|0;H=(K|0)!=0?K:c[p>>2]|0;aY(H|0)|0}g[135827]=W;gv();ae=+((c[137895]|0)>>>0>>>0)/+g[137896];h[92065]=ae;h[92071]=ae;fc[c[(c[199305]|0)+8>>2]&127](c[199308]|0,0);break L7162;break};default:{break L7162}}}if((y-22|0)>>>0<28){H=w|0;K=y-26|0;L=y-27|0;Z=y-28|0;if((y|0)==24){if(!((c[(c[199305]|0)+20>>2]|0)!=0&d)){break L7162}if((a[637400]&1)!=0){Y=c[198610]|0;_=(Y|0)!=0?Y:c[p>>2]|0;a2(89184,31,1,_|0)|0;_=c[198610]|0;Y=(_|0)!=0?_:c[p>>2]|0;aY(Y|0)|0}Y=b+4252|0;_=c[Y>>2]|0;L7304:do{if((_|0)!=0){ac=3;ad=0;while(1){ab=h1(b+4256+(ad*4148|0)|0,3)|0;if(!((ab|0)==0|(ab|0)==2)){break L7304}if((ac|0)==3){af=ab}else{if((ac|0)==(ab|0)){af=ac}else{break L7304}}ab=ad+1|0;if(ab>>>0<_>>>0){ac=af;ad=ab}else{break}}if((af|0)==3){break}gr(H,(a[543313]|0)!=0?543313:629148,(af|0)==2?88912:88560);ad=XY(20)|0;if((ad|0)==0){break L7162}if((c[ad-4>>2]&3|0)!=0){X2(ad|0,0,20)}ac=ad;ad=q|0;ab=r|0;aa=s|0;ag=t|0;ah=j|0;bN(ah|0,128,53432,(X=i,i=i+8|0,c[X>>2]=c[Y>>2],X)|0)|0;i=X;gK(ac,89960,ah);if((c[Y>>2]|0)!=0){ai=l|0;aj=k|0;ak=0;do{bN(ad|0,64,57136,(X=i,i=i+8|0,c[X>>2]=ak,X)|0)|0;i=X;gK(ac,ad,b+4256+(ak*4148|0)|0);al=b+4256+(ak*4148|0)+4136|0;if((c[al>>2]|0)!=0){bN(ad|0,64,56368,(X=i,i=i+8|0,c[X>>2]=ak,X)|0)|0;i=X;gK(ac,ad,(c[al>>2]|0)==1?98168:44720)}bN(ad|0,64,55224,(X=i,i=i+8|0,c[X>>2]=ak,X)|0)|0;i=X;al=c[b+4256+(ak*4148|0)+4140>>2]|0;if((al|0)==1){am=33376}else if((al|0)==2){am=32920}else if((al|0)==3){am=32496}else if((al|0)==0){am=33704}else{am=31936}gK(ac,ad,am);al=b+4256+(ak*4148|0)+4144|0;if((c[al>>2]|0)!=0){bN(ad|0,64,54328,(X=i,i=i+8|0,c[X>>2]=ak,X)|0)|0;i=X;an=c[al>>2]|0;bN(ah|0,128,53432,(X=i,i=i+8|0,c[X>>2]=an,X)|0)|0;i=X;gK(ac,ad,ah)}bN(ai|0,64,37384,(X=i,i=i+8|0,c[X>>2]=ak,X)|0)|0;i=X;gK(ac,ai,(a[b+4256+(ak*4148|0)+4132|0]&1)!=0?98168:44720);do{if((a[b+4256+(ak*4148|0)+4104|0]&1)!=0){an=c[b+4256+(ak*4148|0)+4108>>2]|0;ae=+g[b+4256+(ak*4148|0)+4116>>2];al=c[b+4256+(ak*4148|0)+4124>>2]|0;bN(aj|0,64,36184,(X=i,i=i+16|0,c[X>>2]=39200,c[X+8>>2]=ak,X)|0)|0;i=X;if((an|0)==2){ao=34608}else if((an|0)==1){ao=34160}else if((an|0)==0){ao=35032}else{ao=37720}gK(ac,aj,ao);bN(aj|0,64,35704,(X=i,i=i+16|0,c[X>>2]=39200,c[X+8>>2]=ak,X)|0)|0;i=X;if((an|0)==1){bN(ah|0,128,53432,(X=i,i=i+8|0,c[X>>2]=al,X)|0)|0;i=X;gK(ac,aj,ah)}else{ap=ae;bN(ah|0,128,29648,(X=i,i=i+8|0,h[X>>3]=ap,X)|0)|0;i=X;gK(ac,aj,ah)}al=c[b+4256+(ak*4148|0)+4112>>2]|0;ap=+g[b+4256+(ak*4148|0)+4120>>2];an=c[b+4256+(ak*4148|0)+4128>>2]|0;bN(aj|0,64,36184,(X=i,i=i+16|0,c[X>>2]=36584,c[X+8>>2]=ak,X)|0)|0;i=X;if((al|0)==2){aq=34608}else if((al|0)==1){aq=34160}else if((al|0)==0){aq=35032}else{aq=37720}gK(ac,aj,aq);bN(aj|0,64,35704,(X=i,i=i+16|0,c[X>>2]=36584,c[X+8>>2]=ak,X)|0)|0;i=X;if((al|0)==1){bN(ah|0,128,53432,(X=i,i=i+8|0,c[X>>2]=an,X)|0)|0;i=X;gK(ac,aj,ah);break}else{ae=ap;bN(ah|0,128,29648,(X=i,i=i+8|0,h[X>>3]=ae,X)|0)|0;i=X;gK(ac,aj,ah);break}}}while(0);ak=ak+1|0;}while(ak>>>0<(c[Y>>2]|0)>>>0)}ak=b+70624|0;do{if((c[ak>>2]|0)!=0){X2(ab|0,0,4096);aj=4096;ai=ab;ad=b+70628|0;while(1){an=aj-1|0;if((an|0)==0){ar=5257;break}al=a[ad]|0;a[ai]=al;if(al<<24>>24==0){break}else{aj=an;ai=ai+1|0;ad=ad+1|0}}do{if((ar|0)==5257){a[ai]=0;if((a[ad]|0)==0){break}else{as=ad}do{as=as+1|0;}while((a[as]|0)!=0)}}while(0);if((c[ak>>2]|0)>>>0>1){ad=1;do{ai=X1(ab|0)|0;aj=ai>>>0>4096?0:4096-ai|0;L7367:do{if((aj|0)==0){at=53448;ar=5264}else{an=r+ai|0;do{if((aj|0)==1){au=53448;av=an}else{al=r+(ai+1)|0;a[an]=59;if((aj|0)==2){au=53449;av=al;break}a[al]=0;break L7367}}while(0);a[av]=0;at=au;ar=5264}}while(0);do{if((ar|0)==5264){ar=0;if((a[at]|0)==0){break}else{aw=at}do{aw=aw+1|0;}while((a[aw]|0)!=0)}}while(0);aj=b+70628+(ad*4168|0)|0;ai=X1(ab|0)|0;an=ai>>>0>4096?0:4096-ai|0;L7378:do{if((an|0)==0){ax=aj;ar=5271}else{al=an;ay=r+ai|0;az=aj;while(1){aA=al-1|0;if((aA|0)==0){break}aB=a[az]|0;a[ay]=aB;if(aB<<24>>24==0){break L7378}else{al=aA;ay=ay+1|0;az=az+1|0}}a[ay]=0;ax=az;ar=5271}}while(0);do{if((ar|0)==5271){ar=0;if((a[ax]|0)==0){break}else{aC=ax}do{aC=aC+1|0;}while((a[aC]|0)!=0)}}while(0);ad=ad+1|0;}while(ad>>>0<(c[ak>>2]|0)>>>0)}gK(ac,52584,ab);if((c[ak>>2]|0)==0){break}else{aD=0}do{ad=b+70628+(aD*4168|0)|0;gK(ac,ad,b+70628+(aD*4168|0)+64|0);az=b+70628+(aD*4168|0)+4160|0;if((c[az>>2]|0)!=0){bN(aa|0,64,51752,(X=i,i=i+8|0,c[X>>2]=ad,X)|0)|0;i=X;gK(ac,aa,(c[az>>2]|0)!=1?98168:44720)}bN(aa|0,64,50792,(X=i,i=i+8|0,c[X>>2]=ad,X)|0)|0;i=X;ad=c[b+70628+(aD*4168|0)+4164>>2]|0;if((ad|0)==1){aE=33376}else if((ad|0)==2){aE=32920}else if((ad|0)==3){aE=32496}else if((ad|0)==0){aE=33704}else{aE=31936}gK(ac,aa,aE);aD=aD+1|0;}while(aD>>>0<(c[ak>>2]|0)>>>0)}}while(0);ak=b+109096|0;if((a[ak]|0)!=0){gK(ac,5e4,ak)}ak=b+113196|0;if((a[ak]|0)!=0){gK(ac,49120,ak)}ak=b+103972|0;L7408:do{if((c[ak>>2]|0)!=0){X2(ag|0,0,4096);aa=4096;ab=ag;ad=b+103976|0;while(1){az=aa-1|0;if((az|0)==0){ar=5291;break}ay=a[ad]|0;a[ab]=ay;if(ay<<24>>24==0){break}else{aa=az;ab=ab+1|0;ad=ad+1|0}}do{if((ar|0)==5291){a[ab]=0;if((a[ad]|0)==0){break}else{aF=ad}do{aF=aF+1|0;}while((a[aF]|0)!=0)}}while(0);if((c[ak>>2]|0)>>>0>1){ad=1;do{ab=X1(ag|0)|0;aa=ab>>>0>4096?0:4096-ab|0;L7421:do{if((aa|0)==0){aG=53448;ar=5298}else{az=t+ab|0;do{if((aa|0)==1){aH=53448;aI=az}else{ay=t+(ab+1)|0;a[az]=59;if((aa|0)==2){aH=53449;aI=ay;break}a[ay]=0;break L7421}}while(0);a[aI]=0;aG=aH;ar=5298}}while(0);do{if((ar|0)==5298){ar=0;if((a[aG]|0)==0){break}else{aJ=aG}do{aJ=aJ+1|0;}while((a[aJ]|0)!=0)}}while(0);aa=b+103976+(ad*80|0)|0;ab=X1(ag|0)|0;az=ab>>>0>4096?0:4096-ab|0;L7432:do{if((az|0)==0){aK=aa;ar=5305}else{ay=az;aj=t+ab|0;ai=aa;while(1){an=ay-1|0;if((an|0)==0){break}al=a[ai]|0;a[aj]=al;if(al<<24>>24==0){break L7432}else{ay=an;aj=aj+1|0;ai=ai+1|0}}a[aj]=0;aK=ai;ar=5305}}while(0);do{if((ar|0)==5305){ar=0;if((a[aK]|0)==0){break}else{aL=aK}do{aL=aL+1|0;}while((a[aL]|0)!=0)}}while(0);ad=ad+1|0;}while(ad>>>0<(c[ak>>2]|0)>>>0)}gK(ac,48296,ag);if((c[ak>>2]|0)==0){break}ad=k|0;ai=l|0;aj=m|0;aa=n|0;ab=o|0;az=0;while(1){ay=b+103976+(az*80|0)|0;bN(ad|0,64,43960,(X=i,i=i+8|0,c[X>>2]=ay,X)|0)|0;i=X;bN(ai|0,64,43288,(X=i,i=i+8|0,c[X>>2]=ay,X)|0)|0;i=X;bN(aj|0,64,42584,(X=i,i=i+8|0,c[X>>2]=ay,X)|0)|0;i=X;bN(aa|0,64,41976,(X=i,i=i+8|0,c[X>>2]=ay,X)|0)|0;i=X;bN(ab|0,64,41352,(X=i,i=i+8|0,c[X>>2]=ay,X)|0)|0;i=X;switch(c[b+103976+(az*80|0)+68>>2]|0){case 5:{aM=37952;break};case 0:{aM=41056;break};case 4:{aM=38264;break};case 2:{aM=40360;break};case 3:{aM=39488;break};case 1:{aM=38888;break};default:{aM=37720}}gK(ac,ad,aM);bN(ah|0,128,39632,(X=i,i=i+8|0,c[X>>2]=e[b+103976+(az*80|0)+76>>1]|0,X)|0)|0;i=X;gK(ac,aa,ah);bN(ah|0,128,39632,(X=i,i=i+8|0,c[X>>2]=e[b+103976+(az*80|0)+78>>1]|0,X)|0)|0;i=X;gK(ac,ab,ah);ay=c[b+103976+(az*80|0)+72>>2]|0;if((ay|0)==2){bN(ah|0,128,53432,(X=i,i=i+8|0,c[X>>2]=1,X)|0)|0;i=X;gK(ac,aj,ah)}else if((ay|0)==3){bN(ah|0,128,53432,(X=i,i=i+8|0,c[X>>2]=2,X)|0)|0;i=X;gK(ac,aj,ah)}else if((ay|0)==1){bN(ah|0,128,39632,(X=i,i=i+8|0,c[X>>2]=c[b+103976+(az*80|0)+64>>2],X)|0)|0;i=X;gK(ac,ai,ah)}az=az+1|0;if(az>>>0>=(c[ak>>2]|0)>>>0){break L7408}}}}while(0);gL(ac,H)|0;gF(ac);ip(0,af,H);break L7162}}while(0);H=h1(798256,2)|0;ip(0,(H|0)==3?2:H,0);break L7162}else if((y|0)==25){do{if((G|0)==8){c[b+4252>>2]=0}else if((G|0)==2){H=b+4252|0;Y=c[H>>2]|0;if((Y|0)==0){break}c[H>>2]=Y-1}else if((G|0)==3|(G|0)==4){Y=b+4252|0;H=c[Y>>2]|0;if(H>>>0>=8){break}c[Y>>2]=H+1}}while(0);a[E]=1;break L7162}else if((y|0)==22){if((G|0)==8){a[535096]=1;break L7162}else if((G|0)==2|(G|0)==3|(G|0)==4){a[535096]=a[535096]&1^1;break L7162}else{break L7162}}else{H=(y|0)==23;if(!(((K>>>0)%3|0|0)==0|H)){if(((L>>>0)%3|0|0)==0){Y=(L>>>0)/3|0;if((G|0)==8){c[b+4256+(Y*4148|0)+4136>>2]=0;break L7162}else if((G|0)==2|(G|0)==3|(G|0)==4){_=b+4256+(Y*4148|0)+4136|0;c[_>>2]=(((c[_>>2]|0)+((G|0)==2?2:1)|0)>>>0)%3|0;break L7162}else{break L7162}}if(((Z>>>0)%3|0|0)!=0){break L7162}_=(Z>>>0)/3|0;if((G|0)==8){g[b+4256+(_*4148|0)+4120>>2]=0.0;g[b+4256+(_*4148|0)+4116>>2]=0.0;a[b+4256+(_*4148|0)+4104|0]=0;break L7162}else if((G|0)==2|(G|0)==3|(G|0)==4){Y=b+4256+(_*4148|0)+4116|0;N=((~~+g[Y>>2]+((G|0)==2?5:1)|0)>>>0)%6|0;a[b+4256+(_*4148|0)+4104|0]=(N|0)!=0|0;W=+(N>>>0>>>0);g[b+4256+(_*4148|0)+4120>>2]=W;g[Y>>2]=W;break L7162}else{break L7162}}if(H){aN=b+4256+(((K>>>0)/3|0)*4148|0)|0}else{aN=0}if((G|0)==8){if((aN|0)==0){break L7162}a[aN|0]=0;break L7162}else if((G|0)!=4){break L7162}H=b+48|0;Y=c[H>>2]|0;if((B|0)!=0){_=B+4|0;N=c[_>>2]|0;if(A>>>0<N>>>0){aO=B|0}else{ak=(N<<1)+2|0;c[_>>2]=ak;_=B|0;c[_>>2]=X_(c[_>>2]|0,ak*12|0)|0;aO=_}_=dq(543313)|0;c[(c[aO>>2]|0)+((c[z>>2]|0)*12|0)>>2]=_;c[(c[aO>>2]|0)+((c[z>>2]|0)*12|0)+4>>2]=y;c[(c[aO>>2]|0)+((c[z>>2]|0)*12|0)+8>>2]=Y;c[z>>2]=(c[z>>2]|0)+1}c[H>>2]=0;a[E]=1;break L7162}}if(y>>>0>65535){H=y-65536|0;if((G|0)==8){Y=c[184120]|0;c[(c[Y+4100>>2]|0)+(H<<4)+12>>2]=0;a[Y+4108|0]=1;break L7162}else if((G|0)==2){Y=c[184120]|0;_=c[Y+4100>>2]|0;ak=_+(H<<4)+12|0;N=c[(c[_+(H<<4)+8>>2]|0)+4>>2]|0;c[ak>>2]=(((c[ak>>2]|0)-1+N|0)>>>0)%(N>>>0)|0;a[Y+4108|0]=1;break L7162}else if((G|0)==3|(G|0)==4){Y=c[184120]|0;N=c[Y+4100>>2]|0;ak=N+(H<<4)+12|0;c[ak>>2]=(((c[ak>>2]|0)+1|0)>>>0)%((c[(c[N+(H<<4)+8>>2]|0)+4>>2]|0)>>>0)|0;a[Y+4108|0]=1;break L7162}else{break L7162}}L7510:do{switch(y|0){case 85:{if((G|0)==8){c[I>>2]=0;break L7162}else if((G|0)==2){if((J|0)==0){break L7162}c[I>>2]=J-1;break L7162}else if((G|0)==3){if(J>>>0>=7){break L7162}c[I>>2]=J+1;break L7162}else{break L7162}break};case 86:{Y=(c[199306]|0)+20|0;if((c[Y>>2]|0)==0){H=595748+(J<<2)|0;if((G|0)==8){c[H>>2]=J;aP=J}else if((G|0)==2){N=(c[H>>2]|0)-1|0;c[H>>2]=N;aP=N}else if((G|0)==3){N=(c[H>>2]|0)+1|0;c[H>>2]=N;aP=N}else{aP=c[H>>2]|0}if((aP|0)<-1){c[H>>2]=-1;break L7162}if((aP|0)<=7){break L7162}c[H>>2]=7;break L7162}else{H=595780+(J<<2)|0;N=c[H>>2]|0;if((G|0)==8){c[H>>2]=0;aQ=0}else if((G|0)==2){ak=N-1|0;c[H>>2]=ak;aQ=ak}else if((G|0)==3){ak=N+1|0;c[H>>2]=ak;aQ=ak}else{aQ=N}N=c[596324+(J<<2)>>2]|0;if((N|0)==1){aR=80}else if((N|0)==2){aR=144}else if((N|0)==0){aR=48}else{aR=16}fa[c[Y>>2]&15](c[199309]|0,aQ,J,0,aR);break L7162}break};case 78:{if((G|0)==8|(G|0)==2){Y=794432;N=c[Y+4>>2]|0;ak=794432;c[ak>>2]=c[Y>>2]&-257;c[ak+4>>2]=N;break L7162}else if((G|0)==3){N=794432;ak=c[N+4>>2]|0;Y=794432;c[Y>>2]=c[N>>2]|256;c[Y+4>>2]=ak;break L7162}else{break L7162}break};case 83:{if((G|0)==2){W=+g[150116]+-.009999999776482582;g[150116]=W;aS=1;aT=W;ar=5442}else if((G|0)==3|(G|0)==4){W=+g[150116]+.009999999776482582;g[150116]=W;aS=1;aT=W;ar=5442}else if((G|0)==8){g[150116]=1.0;aU=1;aV=1.0}else{aS=0;aT=+g[150116];ar=5442}do{if((ar|0)==5442){if(aT<0.0){g[150116]=0.0;aU=aS;aV=0.0;break}if(aT<=1.0){aU=aS;aV=aT;break}g[150116]=1.0;aU=aS;aV=1.0}}while(0);ac=c[199350]|0;if(!(aU&(ac|0)!=0)){break L7162}e9[c[(c[ac+4>>2]|0)+20>>2]&7](c[ac>>2]|0,aV);break L7162;break};case 84:{if((G|0)==2){W=+g[150117]+-.009999999776482582;g[150117]=W;aW=1;aX=W;ar=5453}else if((G|0)==3|(G|0)==4){W=+g[150117]+.009999999776482582;g[150117]=W;aW=1;aX=W;ar=5453}else if((G|0)==8){g[150117]=1.0;aZ=1;a_=1.0}else{aW=0;aX=+g[150117];ar=5453}do{if((ar|0)==5453){if(aX<.009999999776482582){g[150117]=.009999999776482582;aZ=aW;a_=.009999999776482582;break}if(aX<=2.0){aZ=aW;a_=aX;break}g[150117]=2.0;aZ=aW;a_=2.0}}while(0);ac=c[199350]|0;if(!(aZ&(ac|0)!=0)){break L7162}hH(ac,a_);break L7162;break};case 75:{if((G|0)==8){a[736529]=0;break L7162}else{a[736529]=a[736529]&1^1;break L7162}break};case 76:{if((G|0)==3){W=+g[139947];if(W<.2){g[139947]=W+.001}a[559785]=1;break L7162}else if((G|0)==8){g[139947]=.004999999888241291;a[559785]=1;break L7162}else if((G|0)==2){W=+g[139947];if(W>0.0){ae=W+-.001;g[139947]=ae;a$=ae}else{a$=W}if(a$<5.0e-4){a[559785]=0;g[139947]=0.0;break L7162}else{a[559785]=1;break L7162}}else{break L7162}break};case 80:{if(!d){break L7162}if((a[794444]&1)==0){break L7162}ac=794432;ak=c[ac+4>>2]|0;Y=794432;c[Y>>2]=c[ac>>2]|1;c[Y+4>>2]=ak;a0=-1;i=f;return a0|0};case 81:{if(!d){break L7162}ak=794432;Y=c[ak+4>>2]|0;ac=794432;c[ac>>2]=c[ak>>2]&-2;c[ac+4>>2]=Y;a0=-1;i=f;return a0|0};case 60:{if((G-3|0)>>>0<2|(G|0)==2){a[794446]=a[794446]&1^1;break L7162}if((G|0)!=8){break L7162}a[794446]=1;break L7162;break};case 62:case 63:{if((G|0)==4){if((y|0)==62){f2()}else{f1()}Y=794432;ac=c[Y+4>>2]|0;ak=794432;c[ak>>2]=c[Y>>2]|1;c[ak+4>>2]=ac;a0=-1;i=f;return a0|0}else if((G|0)==8){c[182916]=0;break L7162}else if((G|0)==2){ac=c[182916]|0;if((ac|0)==0){break L7162}c[182916]=ac-1;break L7162}else if((G|0)==3){c[182916]=(c[182916]|0)+1;break L7162}else{break L7162}break};case 59:{if((G-3|0)>>>0<2){c[158313]=(c[158313]|0)+1;break L7162}if((G|0)==8){c[158313]=1;break L7162}else if((G|0)!=2){break L7162}ac=c[158313]|0;if(ac>>>0<=1){break L7162}c[158313]=ac-1;break L7162;break};case 82:{if((G|0)==4){ac=b+48|0;ak=c[ac>>2]|0;if((B|0)!=0){Y=B+4|0;N=c[Y>>2]|0;if(A>>>0<N>>>0){a1=B|0}else{H=(N<<1)+2|0;c[Y>>2]=H;Y=B|0;c[Y>>2]=X_(c[Y>>2]|0,H*12|0)|0;a1=Y}Y=dq(715274)|0;c[(c[a1>>2]|0)+((c[z>>2]|0)*12|0)>>2]=Y;c[(c[a1>>2]|0)+((c[z>>2]|0)*12|0)+4>>2]=82;c[(c[a1>>2]|0)+((c[z>>2]|0)*12|0)+8>>2]=ak;c[z>>2]=(c[z>>2]|0)+1}c[ac>>2]=0;a[E]=1;break L7162}else if((G|0)!=8){break L7162}ac=c[199350]|0;if((ac|0)!=0){ak=ac+24|0;Y=ac+12|0;H=c[Y>>2]|0;if((c[ak>>2]|0)==0){a3=H}else{N=0;_=H;while(1){XZ(c[_+(N*136|0)>>2]|0);XZ(c[_+(N*136|0)+8>>2]|0);H=N+1|0;ah=c[Y>>2]|0;if(H>>>0<(c[ak>>2]|0)>>>0){N=H;_=ah}else{a3=ah;break}}}XZ(a3);_=c[ac+4>>2]|0;if((_|0)!=0){fc[c[_>>2]&127](c[ac>>2]|0,0)}XZ(ac)}c[199350]=0;a[596368]=0;break L7162;break};case 65:{_=fw[c[184100]&31]()|0;N=fw[c[184098]&31]()|0;if((G-3|0)>>>0<2){a4=1}else{ak=(G|0)==2;if(ak){a4=ak<<31>>31}else{break L7162}}ak=_+1|0;f5(1,0);f6(((N+ak+a4|0)>>>0)%(ak>>>0)|0);f5(0,0);break L7162;break};case 79:{if(!d){break L7162}ak=794432;N=c[ak+4>>2]|0|0;_=794432;c[_>>2]=c[ak>>2]&-1026|1024;c[_+4>>2]=N;a0=-1;i=f;return a0|0};case 58:{if((G|0)==8){a[633244]=0;N=c[196482]|0;if((N|0)!=0){XZ(c[N>>2]|0);XZ(c[N+12>>2]|0);XZ(N)}c[196482]=0;XZ(c[196483]|0);c[196483]=0;break L7162}else if(!((G|0)==4|(G|0)==3|(G|0)==2)){break L7162}N=a[633244]&1;a[633244]=N^1;if(N<<24>>24==0){f0();break L7162}N=c[196482]|0;if((N|0)!=0){XZ(c[N>>2]|0);XZ(c[N+12>>2]|0);XZ(N)}c[196482]=0;XZ(c[196483]|0);c[196483]=0;break L7162;break};case 68:{break};case 71:{if((G|0)!=8){break L7162}a[707082]=0;break L7162;break};case 72:{if((G|0)!=8){break L7162}a[715274]=0;break L7162;break};case 70:{if((G|0)!=8){break L7162}a[711178]=0;break L7162;break};case 69:{if((G|0)!=8){break L7162}a[543313]=0;break L7162;break};case 73:{if((G|0)!=8){break L7162}a[629148]=0;break L7162;break};case 74:{if(!d){break L7162}f3();N=794432;_=c[N+4>>2]|0;ak=794432;c[ak>>2]=c[N>>2]|1;c[ak+4>>2]=_;a0=-1;i=f;return a0|0};case 87:{_=637404+(J<<2)|0;ak=c[_>>2]|0;N=0;while(1){if(N>>>0>=8){a5=0;break}if((ak|0)==(c[2048+(N<<2)>>2]|0)){a5=N;break}else{N=N+1|0}}if((G|0)==2){a6=c[2048+((a5+7&7)<<2)>>2]|0}else if((G|0)==3|(G|0)==4){a6=c[2048+((a5+1&7)<<2)>>2]|0}else if((G|0)==8){a6=1}else{break L7162}c[_>>2]=a6;fc[c[59472]&127](J,a6);break L7162;break};case 88:{N=596324+(J<<2)|0;ak=c[N>>2]|0;ac=ak+4|0;c[N>>2]=ac;if((G|0)==8){c[N>>2]=1;a7=1}else if((G|0)==2){Y=ak+3|0;c[N>>2]=Y;a7=Y}else if((G|0)==3){Y=ak+5|0;c[N>>2]=Y;a7=Y}else{a7=ac}ac=a7&3;c[N>>2]=ac;N=c[(c[199306]|0)+20>>2]|0;if((N|0)==0){break L7162}if((ac|0)==2){a8=128}else if((ac|0)==0){a8=32}else if((ac|0)==1){a8=64}else{break L7162}fa[N&15](c[199309]|0,c[595780+(J<<2)>>2]|0,J,0,a8);break L7162;break};case 89:case 90:case 91:case 92:case 93:case 94:case 95:case 96:case 97:case 98:case 99:case 100:case 101:case 102:case 103:case 104:{N=c[(c[199306]|0)+20>>2]|0;if((N|0)==0){break L7510}if((G|0)==2){a9=2}else if((G|0)==8){a9=8}else{ac=(G|0)==3;if(ac){a9=ac?4:0}else{break L7510}}ac=y-89|0;fa[N&15](c[199309]|0,c[595780+(ac<<2)>>2]|0,J,c[2152+(ac<<2)>>2]|0,a9);break};case 67:{if(!d){break L7162}do{if((a[551539]&1)!=0|(c[184103]|0)!=0){ac=c[199354]|0;do{if((ac|0)!=0){N=c[ac+24>>2]|0;if((N|0)==0){break}fy[N&511](c[199308]|0,0,0)}}while(0);if((c[199305]|0)==0){break}fW()}}while(0);fV();break L7162;break};default:{break L7162}}}while(0);if((G|0)!=8){break L7162}a[633281]=0;a[b+54|0]=0;break L7162}}while(0);d=b+48|0;J=c[d>>2]|0;if((B|0)!=0){I=B+4|0;K=c[I>>2]|0;if(A>>>0<K>>>0){ba=B|0}else{Z=(K<<1)+2|0;c[I>>2]=Z;I=B|0;c[I>>2]=X_(c[I>>2]|0,Z*12|0)|0;ba=I}I=dq(798256)|0;c[(c[ba>>2]|0)+((c[z>>2]|0)*12|0)>>2]=I;c[(c[ba>>2]|0)+((c[z>>2]|0)*12|0)+4>>2]=y;c[(c[ba>>2]|0)+((c[z>>2]|0)*12|0)+8>>2]=J;c[z>>2]=(c[z>>2]|0)+1}c[d>>2]=0;a[E]=1;break};case 1:{d=b+48|0;J=(c[d>>2]|0)+1|0;if(J>>>0<(c[(c[b+44>>2]|0)+8>>2]|0)>>>0){c[d>>2]=J;break L7162}else{c[d>>2]=0;break L7162}break};case 5:{if(A>>>0<=1){break L7162}d=b+48|0;J=A-1|0;c[z>>2]=J;I=B|0;XZ(c[(c[I>>2]|0)+(J*12|0)>>2]|0);if((d|0)!=0){c[d>>2]=c[(c[I>>2]|0)+((c[z>>2]|0)*12|0)+8>>2]}a[E]=1;break};case 6:{c[b+48>>2]=0;a[E]=1;break};case 9:{a[b+53|0]=1;break};case 0:{I=b+48|0;d=c[I>>2]|0;if((d|0)==0){c[I>>2]=(c[(c[b+44>>2]|0)+8>>2]|0)-1;break L7162}else{c[I>>2]=d-1;break L7162}break};default:{}}}while(0);z=c[C>>2]|0;C=c[z+8>>2]|0;if((C|0)==0){bb=D}else{bb=c[(c[z>>2]|0)+((C-1|0)*12|0)+4>>2]|0}L7744:do{if(!((a[E]&1)==0|(bb|0)==1)){C=bb-26|0;if(C>>>0<24&((C>>>0)%3|0|0)==0|(bb|0)==23|(bb-68|0)>>>0<6){break}if((bb|0)==82|(bb|0)==66|(bb|0)==52|(bb|0)==51){break}a[E]=0;switch(bb|0){case 5:{C=b+44|0;z=c[C>>2]|0;D=z+8|0;if((c[D>>2]|0)!=0){B=z|0;z=0;do{XZ(c[(c[B>>2]|0)+(z*12|0)>>2]|0);z=z+1|0;}while(z>>>0<(c[D>>2]|0)>>>0)}c[D>>2]=0;z=c[C>>2]|0;if((z|0)==0){break L7744}B=z+8|0;A=z+4|0;ba=c[A>>2]|0;if((c[B>>2]|0)>>>0<ba>>>0){bc=z|0}else{y=(ba<<1)+2|0;c[A>>2]=y;A=z|0;c[A>>2]=X_(c[A>>2]|0,y*12|0)|0;bc=A}A=dq(27120)|0;c[(c[bc>>2]|0)+((c[B>>2]|0)*12|0)>>2]=A;c[(c[bc>>2]|0)+((c[B>>2]|0)*12|0)+4>>2]=21;c[(c[bc>>2]|0)+((c[B>>2]|0)*12|0)+8>>2]=0;c[B>>2]=(c[B>>2]|0)+1;B=c[C>>2]|0;if((B|0)==0){break L7744}A=B+8|0;y=B+4|0;z=c[y>>2]|0;if((c[A>>2]|0)>>>0<z>>>0){bd=B|0}else{ba=(z<<1)+2|0;c[y>>2]=ba;y=B|0;c[y>>2]=X_(c[y>>2]|0,ba*12|0)|0;bd=y}y=dq(26448)|0;c[(c[bd>>2]|0)+((c[A>>2]|0)*12|0)>>2]=y;c[(c[bd>>2]|0)+((c[A>>2]|0)*12|0)+4>>2]=10;c[(c[bd>>2]|0)+((c[A>>2]|0)*12|0)+8>>2]=0;c[A>>2]=(c[A>>2]|0)+1;A=c[C>>2]|0;if((A|0)==0){break L7744}y=A+8|0;ba=A+4|0;B=c[ba>>2]|0;if((c[y>>2]|0)>>>0<B>>>0){be=A|0}else{z=(B<<1)+2|0;c[ba>>2]=z;ba=A|0;c[ba>>2]=X_(c[ba>>2]|0,z*12|0)|0;be=ba}ba=dq(26040)|0;c[(c[be>>2]|0)+((c[y>>2]|0)*12|0)>>2]=ba;c[(c[be>>2]|0)+((c[y>>2]|0)*12|0)+4>>2]=11;c[(c[be>>2]|0)+((c[y>>2]|0)*12|0)+8>>2]=0;c[y>>2]=(c[y>>2]|0)+1;y=c[C>>2]|0;if((y|0)==0){break L7744}ba=y+8|0;z=y+4|0;A=c[z>>2]|0;if((c[ba>>2]|0)>>>0<A>>>0){bf=y|0}else{B=(A<<1)+2|0;c[z>>2]=B;z=y|0;c[z>>2]=X_(c[z>>2]|0,B*12|0)|0;bf=z}z=dq(25528)|0;c[(c[bf>>2]|0)+((c[ba>>2]|0)*12|0)>>2]=z;c[(c[bf>>2]|0)+((c[ba>>2]|0)*12|0)+4>>2]=12;c[(c[bf>>2]|0)+((c[ba>>2]|0)*12|0)+8>>2]=0;c[ba>>2]=(c[ba>>2]|0)+1;ba=c[C>>2]|0;if((ba|0)==0){break L7744}z=ba+8|0;B=ba+4|0;y=c[B>>2]|0;if((c[z>>2]|0)>>>0<y>>>0){bg=ba|0}else{A=(y<<1)+2|0;c[B>>2]=A;B=ba|0;c[B>>2]=X_(c[B>>2]|0,A*12|0)|0;bg=B}B=dq(25168)|0;c[(c[bg>>2]|0)+((c[z>>2]|0)*12|0)>>2]=B;c[(c[bg>>2]|0)+((c[z>>2]|0)*12|0)+4>>2]=14;c[(c[bg>>2]|0)+((c[z>>2]|0)*12|0)+8>>2]=0;c[z>>2]=(c[z>>2]|0)+1;z=c[C>>2]|0;if((z|0)==0){break L7744}B=z+8|0;A=z+4|0;ba=c[A>>2]|0;if((c[B>>2]|0)>>>0<ba>>>0){bh=z|0}else{y=(ba<<1)+2|0;c[A>>2]=y;A=z|0;c[A>>2]=X_(c[A>>2]|0,y*12|0)|0;bh=A}A=dq(24896)|0;c[(c[bh>>2]|0)+((c[B>>2]|0)*12|0)>>2]=A;c[(c[bh>>2]|0)+((c[B>>2]|0)*12|0)+4>>2]=15;c[(c[bh>>2]|0)+((c[B>>2]|0)*12|0)+8>>2]=0;c[B>>2]=(c[B>>2]|0)+1;B=c[C>>2]|0;if((B|0)==0){break L7744}A=B+8|0;y=B+4|0;z=c[y>>2]|0;if((c[A>>2]|0)>>>0<z>>>0){bi=B|0}else{ba=(z<<1)+2|0;c[y>>2]=ba;y=B|0;c[y>>2]=X_(c[y>>2]|0,ba*12|0)|0;bi=y}y=dq(24576)|0;c[(c[bi>>2]|0)+((c[A>>2]|0)*12|0)>>2]=y;c[(c[bi>>2]|0)+((c[A>>2]|0)*12|0)+4>>2]=16;c[(c[bi>>2]|0)+((c[A>>2]|0)*12|0)+8>>2]=0;c[A>>2]=(c[A>>2]|0)+1;A=c[C>>2]|0;if((A|0)==0){break L7744}y=A+8|0;ba=A+4|0;B=c[ba>>2]|0;if((c[y>>2]|0)>>>0<B>>>0){bj=A|0}else{z=(B<<1)+2|0;c[ba>>2]=z;ba=A|0;c[ba>>2]=X_(c[ba>>2]|0,z*12|0)|0;bj=ba}ba=dq(24248)|0;c[(c[bj>>2]|0)+((c[y>>2]|0)*12|0)>>2]=ba;c[(c[bj>>2]|0)+((c[y>>2]|0)*12|0)+4>>2]=17;c[(c[bj>>2]|0)+((c[y>>2]|0)*12|0)+8>>2]=0;c[y>>2]=(c[y>>2]|0)+1;y=c[C>>2]|0;if((y|0)==0){break L7744}ba=y+8|0;z=y+4|0;A=c[z>>2]|0;if((c[ba>>2]|0)>>>0<A>>>0){bk=y|0}else{B=(A<<1)+2|0;c[z>>2]=B;z=y|0;c[z>>2]=X_(c[z>>2]|0,B*12|0)|0;bk=z}z=dq(23752)|0;c[(c[bk>>2]|0)+((c[ba>>2]|0)*12|0)>>2]=z;c[(c[bk>>2]|0)+((c[ba>>2]|0)*12|0)+4>>2]=18;c[(c[bk>>2]|0)+((c[ba>>2]|0)*12|0)+8>>2]=0;c[ba>>2]=(c[ba>>2]|0)+1;ba=c[C>>2]|0;if((ba|0)==0){break L7744}z=ba+8|0;B=ba+4|0;y=c[B>>2]|0;if((c[z>>2]|0)>>>0<y>>>0){bl=ba|0}else{A=(y<<1)+2|0;c[B>>2]=A;B=ba|0;c[B>>2]=X_(c[B>>2]|0,A*12|0)|0;bl=B}B=dq(23400)|0;c[(c[bl>>2]|0)+((c[z>>2]|0)*12|0)>>2]=B;c[(c[bl>>2]|0)+((c[z>>2]|0)*12|0)+4>>2]=19;c[(c[bl>>2]|0)+((c[z>>2]|0)*12|0)+8>>2]=0;c[z>>2]=(c[z>>2]|0)+1;break L7744;break};case 54:{z=b+44|0;B=c[z>>2]|0;A=B+8|0;if((c[A>>2]|0)!=0){ba=B|0;B=0;do{XZ(c[(c[ba>>2]|0)+(B*12|0)>>2]|0);B=B+1|0;}while(B>>>0<(c[A>>2]|0)>>>0)}c[A>>2]=0;B=c[z>>2]|0;if((B|0)==0){break L7744}ba=B+8|0;C=B+4|0;D=c[C>>2]|0;if((c[ba>>2]|0)>>>0<D>>>0){bm=B|0}else{y=(D<<1)+2|0;c[C>>2]=y;C=B|0;c[C>>2]=X_(c[C>>2]|0,y*12|0)|0;bm=C}C=dq(21992)|0;c[(c[bm>>2]|0)+((c[ba>>2]|0)*12|0)>>2]=C;c[(c[bm>>2]|0)+((c[ba>>2]|0)*12|0)+4>>2]=75;c[(c[bm>>2]|0)+((c[ba>>2]|0)*12|0)+8>>2]=0;c[ba>>2]=(c[ba>>2]|0)+1;ba=c[z>>2]|0;if((ba|0)==0){break L7744}C=ba+8|0;y=ba+4|0;B=c[y>>2]|0;if((c[C>>2]|0)>>>0<B>>>0){bn=ba|0}else{D=(B<<1)+2|0;c[y>>2]=D;y=ba|0;c[y>>2]=X_(c[y>>2]|0,D*12|0)|0;bn=y}y=dq(21640)|0;c[(c[bn>>2]|0)+((c[C>>2]|0)*12|0)>>2]=y;c[(c[bn>>2]|0)+((c[C>>2]|0)*12|0)+4>>2]=76;c[(c[bn>>2]|0)+((c[C>>2]|0)*12|0)+8>>2]=0;c[C>>2]=(c[C>>2]|0)+1;break L7744;break};case 64:{C=b+44|0;y=c[C>>2]|0;D=y+8|0;if((c[D>>2]|0)!=0){ba=y|0;y=0;do{XZ(c[(c[ba>>2]|0)+(y*12|0)>>2]|0);y=y+1|0;}while(y>>>0<(c[D>>2]|0)>>>0)}c[D>>2]=0;y=c[C>>2]|0;if((y|0)==0){break L7744}ba=y+8|0;z=y+4|0;A=c[z>>2]|0;if((c[ba>>2]|0)>>>0<A>>>0){bo=y|0}else{B=(A<<1)+2|0;c[z>>2]=B;z=y|0;c[z>>2]=X_(c[z>>2]|0,B*12|0)|0;bo=z}z=dq(22992)|0;c[(c[bo>>2]|0)+((c[ba>>2]|0)*12|0)>>2]=z;c[(c[bo>>2]|0)+((c[ba>>2]|0)*12|0)+4>>2]=65;c[(c[bo>>2]|0)+((c[ba>>2]|0)*12|0)+8>>2]=0;c[ba>>2]=(c[ba>>2]|0)+1;ba=c[C>>2]|0;if((ba|0)==0){break L7744}z=ba+8|0;B=ba+4|0;y=c[B>>2]|0;if((c[z>>2]|0)>>>0<y>>>0){bp=ba|0}else{A=(y<<1)+2|0;c[B>>2]=A;B=ba|0;c[B>>2]=X_(c[B>>2]|0,A*12|0)|0;bp=B}B=dq(22344)|0;c[(c[bp>>2]|0)+((c[z>>2]|0)*12|0)>>2]=B;c[(c[bp>>2]|0)+((c[z>>2]|0)*12|0)+4>>2]=66;c[(c[bp>>2]|0)+((c[z>>2]|0)*12|0)+8>>2]=0;c[z>>2]=(c[z>>2]|0)+1;break L7744;break};case 55:{z=b+44|0;B=c[z>>2]|0;A=B+8|0;if((c[A>>2]|0)!=0){ba=B|0;B=0;do{XZ(c[(c[ba>>2]|0)+(B*12|0)>>2]|0);B=B+1|0;}while(B>>>0<(c[A>>2]|0)>>>0)}c[A>>2]=0;B=c[z>>2]|0;do{if((B|0)!=0){ba=B+8|0;C=B+4|0;D=c[C>>2]|0;if((c[ba>>2]|0)>>>0<D>>>0){bq=B|0}else{y=(D<<1)+2|0;c[C>>2]=y;C=B|0;c[C>>2]=X_(c[C>>2]|0,y*12|0)|0;bq=C}C=dq(98512)|0;c[(c[bq>>2]|0)+((c[ba>>2]|0)*12|0)>>2]=C;c[(c[bq>>2]|0)+((c[ba>>2]|0)*12|0)+4>>2]=82;c[(c[bq>>2]|0)+((c[ba>>2]|0)*12|0)+8>>2]=0;c[ba>>2]=(c[ba>>2]|0)+1;ba=c[z>>2]|0;if((ba|0)==0){break}C=ba+8|0;y=ba+4|0;D=c[y>>2]|0;if((c[C>>2]|0)>>>0<D>>>0){br=ba|0}else{G=(D<<1)+2|0;c[y>>2]=G;y=ba|0;c[y>>2]=X_(c[y>>2]|0,G*12|0)|0;br=y}y=dq(98152)|0;c[(c[br>>2]|0)+((c[C>>2]|0)*12|0)>>2]=y;c[(c[br>>2]|0)+((c[C>>2]|0)*12|0)+4>>2]=83;c[(c[br>>2]|0)+((c[C>>2]|0)*12|0)+8>>2]=0;c[C>>2]=(c[C>>2]|0)+1;C=c[z>>2]|0;if((C|0)==0){break}y=C+8|0;G=C+4|0;ba=c[G>>2]|0;if((c[y>>2]|0)>>>0<ba>>>0){bs=C|0}else{D=(ba<<1)+2|0;c[G>>2]=D;G=C|0;c[G>>2]=X_(c[G>>2]|0,D*12|0)|0;bs=G}G=dq(97632)|0;c[(c[bs>>2]|0)+((c[y>>2]|0)*12|0)>>2]=G;c[(c[bs>>2]|0)+((c[y>>2]|0)*12|0)+4>>2]=84;c[(c[bs>>2]|0)+((c[y>>2]|0)*12|0)+8>>2]=0;c[y>>2]=(c[y>>2]|0)+1;y=c[z>>2]|0;if((y|0)==0){break}G=y+8|0;D=y+4|0;C=c[D>>2]|0;if((c[G>>2]|0)>>>0<C>>>0){bt=y|0}else{ba=(C<<1)+2|0;c[D>>2]=ba;D=y|0;c[D>>2]=X_(c[D>>2]|0,ba*12|0)|0;bt=D}D=dq(97184)|0;c[(c[bt>>2]|0)+((c[G>>2]|0)*12|0)>>2]=D;c[(c[bt>>2]|0)+((c[G>>2]|0)*12|0)+4>>2]=85;c[(c[bt>>2]|0)+((c[G>>2]|0)*12|0)+8>>2]=0;c[G>>2]=(c[G>>2]|0)+1;G=c[z>>2]|0;if((G|0)==0){break}D=G+8|0;ba=G+4|0;y=c[ba>>2]|0;if((c[D>>2]|0)>>>0<y>>>0){bu=G|0}else{C=(y<<1)+2|0;c[ba>>2]=C;ba=G|0;c[ba>>2]=X_(c[ba>>2]|0,C*12|0)|0;bu=ba}ba=dq(96800)|0;c[(c[bu>>2]|0)+((c[D>>2]|0)*12|0)>>2]=ba;c[(c[bu>>2]|0)+((c[D>>2]|0)*12|0)+4>>2]=86;c[(c[bu>>2]|0)+((c[D>>2]|0)*12|0)+8>>2]=0;c[D>>2]=(c[D>>2]|0)+1;D=c[z>>2]|0;if((D|0)==0){break}ba=D+8|0;C=D+4|0;G=c[C>>2]|0;if((c[ba>>2]|0)>>>0<G>>>0){bv=D|0}else{y=(G<<1)+2|0;c[C>>2]=y;C=D|0;c[C>>2]=X_(c[C>>2]|0,y*12|0)|0;bv=C}C=dq(96384)|0;c[(c[bv>>2]|0)+((c[ba>>2]|0)*12|0)>>2]=C;c[(c[bv>>2]|0)+((c[ba>>2]|0)*12|0)+4>>2]=87;c[(c[bv>>2]|0)+((c[ba>>2]|0)*12|0)+8>>2]=0;c[ba>>2]=(c[ba>>2]|0)+1}}while(0);B=c[199306]|0;if((B|0)==0){break L7744}if((c[B+20>>2]|0)==0){break L7744}B=c[z>>2]|0;if((B|0)==0){break L7744}A=B+8|0;ba=B+4|0;C=c[ba>>2]|0;if((c[A>>2]|0)>>>0<C>>>0){bw=B|0}else{y=(C<<1)+2|0;c[ba>>2]=y;ba=B|0;c[ba>>2]=X_(c[ba>>2]|0,y*12|0)|0;bw=ba}ba=dq(95680)|0;c[(c[bw>>2]|0)+((c[A>>2]|0)*12|0)>>2]=ba;c[(c[bw>>2]|0)+((c[A>>2]|0)*12|0)+4>>2]=88;c[(c[bw>>2]|0)+((c[A>>2]|0)*12|0)+8>>2]=0;c[A>>2]=(c[A>>2]|0)+1;A=c[z>>2]|0;if((A|0)==0){break L7744}ba=A+8|0;y=A+4|0;B=c[y>>2]|0;if((c[ba>>2]|0)>>>0<B>>>0){bx=A|0}else{C=(B<<1)+2|0;c[y>>2]=C;y=A|0;c[y>>2]=X_(c[y>>2]|0,C*12|0)|0;bx=y}y=dq(35344)|0;c[(c[bx>>2]|0)+((c[ba>>2]|0)*12|0)>>2]=y;c[(c[bx>>2]|0)+((c[ba>>2]|0)*12|0)+4>>2]=89;c[(c[bx>>2]|0)+((c[ba>>2]|0)*12|0)+8>>2]=0;c[ba>>2]=(c[ba>>2]|0)+1;ba=c[z>>2]|0;if((ba|0)==0){break L7744}y=ba+8|0;C=ba+4|0;A=c[C>>2]|0;if((c[y>>2]|0)>>>0<A>>>0){by=ba|0}else{B=(A<<1)+2|0;c[C>>2]=B;C=ba|0;c[C>>2]=X_(c[C>>2]|0,B*12|0)|0;by=C}C=dq(30624)|0;c[(c[by>>2]|0)+((c[y>>2]|0)*12|0)>>2]=C;c[(c[by>>2]|0)+((c[y>>2]|0)*12|0)+4>>2]=90;c[(c[by>>2]|0)+((c[y>>2]|0)*12|0)+8>>2]=0;c[y>>2]=(c[y>>2]|0)+1;y=c[z>>2]|0;if((y|0)==0){break L7744}C=y+8|0;B=y+4|0;ba=c[B>>2]|0;if((c[C>>2]|0)>>>0<ba>>>0){bz=y|0}else{A=(ba<<1)+2|0;c[B>>2]=A;B=y|0;c[B>>2]=X_(c[B>>2]|0,A*12|0)|0;bz=B}B=dq(26664)|0;c[(c[bz>>2]|0)+((c[C>>2]|0)*12|0)>>2]=B;c[(c[bz>>2]|0)+((c[C>>2]|0)*12|0)+4>>2]=91;c[(c[bz>>2]|0)+((c[C>>2]|0)*12|0)+8>>2]=0;c[C>>2]=(c[C>>2]|0)+1;C=c[z>>2]|0;if((C|0)==0){break L7744}B=C+8|0;A=C+4|0;y=c[A>>2]|0;if((c[B>>2]|0)>>>0<y>>>0){bA=C|0}else{ba=(y<<1)+2|0;c[A>>2]=ba;A=C|0;c[A>>2]=X_(c[A>>2]|0,ba*12|0)|0;bA=A}A=dq(22464)|0;c[(c[bA>>2]|0)+((c[B>>2]|0)*12|0)>>2]=A;c[(c[bA>>2]|0)+((c[B>>2]|0)*12|0)+4>>2]=92;c[(c[bA>>2]|0)+((c[B>>2]|0)*12|0)+8>>2]=0;c[B>>2]=(c[B>>2]|0)+1;B=c[z>>2]|0;if((B|0)==0){break L7744}A=B+8|0;ba=B+4|0;C=c[ba>>2]|0;if((c[A>>2]|0)>>>0<C>>>0){bB=B|0}else{y=(C<<1)+2|0;c[ba>>2]=y;ba=B|0;c[ba>>2]=X_(c[ba>>2]|0,y*12|0)|0;bB=ba}ba=dq(93552)|0;c[(c[bB>>2]|0)+((c[A>>2]|0)*12|0)>>2]=ba;c[(c[bB>>2]|0)+((c[A>>2]|0)*12|0)+4>>2]=93;c[(c[bB>>2]|0)+((c[A>>2]|0)*12|0)+8>>2]=0;c[A>>2]=(c[A>>2]|0)+1;A=c[z>>2]|0;if((A|0)==0){break L7744}ba=A+8|0;y=A+4|0;B=c[y>>2]|0;if((c[ba>>2]|0)>>>0<B>>>0){bC=A|0}else{C=(B<<1)+2|0;c[y>>2]=C;y=A|0;c[y>>2]=X_(c[y>>2]|0,C*12|0)|0;bC=y}y=dq(93168)|0;c[(c[bC>>2]|0)+((c[ba>>2]|0)*12|0)>>2]=y;c[(c[bC>>2]|0)+((c[ba>>2]|0)*12|0)+4>>2]=94;c[(c[bC>>2]|0)+((c[ba>>2]|0)*12|0)+8>>2]=0;c[ba>>2]=(c[ba>>2]|0)+1;ba=c[z>>2]|0;if((ba|0)==0){break L7744}y=ba+8|0;C=ba+4|0;A=c[C>>2]|0;if((c[y>>2]|0)>>>0<A>>>0){bD=ba|0}else{B=(A<<1)+2|0;c[C>>2]=B;C=ba|0;c[C>>2]=X_(c[C>>2]|0,B*12|0)|0;bD=C}C=dq(92784)|0;c[(c[bD>>2]|0)+((c[y>>2]|0)*12|0)>>2]=C;c[(c[bD>>2]|0)+((c[y>>2]|0)*12|0)+4>>2]=95;c[(c[bD>>2]|0)+((c[y>>2]|0)*12|0)+8>>2]=0;c[y>>2]=(c[y>>2]|0)+1;y=c[z>>2]|0;if((y|0)==0){break L7744}C=y+8|0;B=y+4|0;ba=c[B>>2]|0;if((c[C>>2]|0)>>>0<ba>>>0){bE=y|0}else{A=(ba<<1)+2|0;c[B>>2]=A;B=y|0;c[B>>2]=X_(c[B>>2]|0,A*12|0)|0;bE=B}B=dq(92480)|0;c[(c[bE>>2]|0)+((c[C>>2]|0)*12|0)>>2]=B;c[(c[bE>>2]|0)+((c[C>>2]|0)*12|0)+4>>2]=96;c[(c[bE>>2]|0)+((c[C>>2]|0)*12|0)+8>>2]=0;c[C>>2]=(c[C>>2]|0)+1;C=c[z>>2]|0;if((C|0)==0){break L7744}B=C+8|0;A=C+4|0;y=c[A>>2]|0;if((c[B>>2]|0)>>>0<y>>>0){bF=C|0}else{ba=(y<<1)+2|0;c[A>>2]=ba;A=C|0;c[A>>2]=X_(c[A>>2]|0,ba*12|0)|0;bF=A}A=dq(100096)|0;c[(c[bF>>2]|0)+((c[B>>2]|0)*12|0)>>2]=A;c[(c[bF>>2]|0)+((c[B>>2]|0)*12|0)+4>>2]=97;c[(c[bF>>2]|0)+((c[B>>2]|0)*12|0)+8>>2]=0;c[B>>2]=(c[B>>2]|0)+1;B=c[z>>2]|0;if((B|0)==0){break L7744}A=B+8|0;ba=B+4|0;C=c[ba>>2]|0;if((c[A>>2]|0)>>>0<C>>>0){bG=B|0}else{y=(C<<1)+2|0;c[ba>>2]=y;ba=B|0;c[ba>>2]=X_(c[ba>>2]|0,y*12|0)|0;bG=ba}ba=dq(95616)|0;c[(c[bG>>2]|0)+((c[A>>2]|0)*12|0)>>2]=ba;c[(c[bG>>2]|0)+((c[A>>2]|0)*12|0)+4>>2]=98;c[(c[bG>>2]|0)+((c[A>>2]|0)*12|0)+8>>2]=0;c[A>>2]=(c[A>>2]|0)+1;A=c[z>>2]|0;if((A|0)==0){break L7744}ba=A+8|0;y=A+4|0;B=c[y>>2]|0;if((c[ba>>2]|0)>>>0<B>>>0){bH=A|0}else{C=(B<<1)+2|0;c[y>>2]=C;y=A|0;c[y>>2]=X_(c[y>>2]|0,C*12|0)|0;bH=y}y=dq(91032)|0;c[(c[bH>>2]|0)+((c[ba>>2]|0)*12|0)>>2]=y;c[(c[bH>>2]|0)+((c[ba>>2]|0)*12|0)+4>>2]=99;c[(c[bH>>2]|0)+((c[ba>>2]|0)*12|0)+8>>2]=0;c[ba>>2]=(c[ba>>2]|0)+1;ba=c[z>>2]|0;if((ba|0)==0){break L7744}y=ba+8|0;C=ba+4|0;A=c[C>>2]|0;if((c[y>>2]|0)>>>0<A>>>0){bI=ba|0}else{B=(A<<1)+2|0;c[C>>2]=B;C=ba|0;c[C>>2]=X_(c[C>>2]|0,B*12|0)|0;bI=C}C=dq(90648)|0;c[(c[bI>>2]|0)+((c[y>>2]|0)*12|0)>>2]=C;c[(c[bI>>2]|0)+((c[y>>2]|0)*12|0)+4>>2]=100;c[(c[bI>>2]|0)+((c[y>>2]|0)*12|0)+8>>2]=0;c[y>>2]=(c[y>>2]|0)+1;y=c[z>>2]|0;if((y|0)==0){break L7744}C=y+8|0;B=y+4|0;ba=c[B>>2]|0;if((c[C>>2]|0)>>>0<ba>>>0){bJ=y|0}else{A=(ba<<1)+2|0;c[B>>2]=A;B=y|0;c[B>>2]=X_(c[B>>2]|0,A*12|0)|0;bJ=B}B=dq(53072)|0;c[(c[bJ>>2]|0)+((c[C>>2]|0)*12|0)>>2]=B;c[(c[bJ>>2]|0)+((c[C>>2]|0)*12|0)+4>>2]=101;c[(c[bJ>>2]|0)+((c[C>>2]|0)*12|0)+8>>2]=0;c[C>>2]=(c[C>>2]|0)+1;C=c[z>>2]|0;if((C|0)==0){break L7744}B=C+8|0;A=C+4|0;y=c[A>>2]|0;if((c[B>>2]|0)>>>0<y>>>0){bK=C|0}else{ba=(y<<1)+2|0;c[A>>2]=ba;A=C|0;c[A>>2]=X_(c[A>>2]|0,ba*12|0)|0;bK=A}A=dq(90144)|0;c[(c[bK>>2]|0)+((c[B>>2]|0)*12|0)>>2]=A;c[(c[bK>>2]|0)+((c[B>>2]|0)*12|0)+4>>2]=102;c[(c[bK>>2]|0)+((c[B>>2]|0)*12|0)+8>>2]=0;c[B>>2]=(c[B>>2]|0)+1;B=c[z>>2]|0;if((B|0)==0){break L7744}A=B+8|0;ba=B+4|0;C=c[ba>>2]|0;if((c[A>>2]|0)>>>0<C>>>0){bL=B|0}else{y=(C<<1)+2|0;c[ba>>2]=y;ba=B|0;c[ba>>2]=X_(c[ba>>2]|0,y*12|0)|0;bL=ba}ba=dq(89792)|0;c[(c[bL>>2]|0)+((c[A>>2]|0)*12|0)>>2]=ba;c[(c[bL>>2]|0)+((c[A>>2]|0)*12|0)+4>>2]=103;c[(c[bL>>2]|0)+((c[A>>2]|0)*12|0)+8>>2]=0;c[A>>2]=(c[A>>2]|0)+1;A=c[z>>2]|0;if((A|0)==0){break L7744}ba=A+8|0;y=A+4|0;B=c[y>>2]|0;if((c[ba>>2]|0)>>>0<B>>>0){bM=A|0}else{C=(B<<1)+2|0;c[y>>2]=C;y=A|0;c[y>>2]=X_(c[y>>2]|0,C*12|0)|0;bM=y}y=dq(89488)|0;c[(c[bM>>2]|0)+((c[ba>>2]|0)*12|0)>>2]=y;c[(c[bM>>2]|0)+((c[ba>>2]|0)*12|0)+4>>2]=104;c[(c[bM>>2]|0)+((c[ba>>2]|0)*12|0)+8>>2]=0;c[ba>>2]=(c[ba>>2]|0)+1;break L7744;break};case 56:{ba=b+44|0;y=c[ba>>2]|0;C=y+8|0;if((c[C>>2]|0)!=0){A=y|0;y=0;do{XZ(c[(c[A>>2]|0)+(y*12|0)>>2]|0);y=y+1|0;}while(y>>>0<(c[C>>2]|0)>>>0)}c[C>>2]=0;y=c[ba>>2]|0;if((y|0)==0){break L7744}A=y+8|0;z=y+4|0;B=c[z>>2]|0;if((c[A>>2]|0)>>>0<B>>>0){bO=y|0}else{D=(B<<1)+2|0;c[z>>2]=D;z=y|0;c[z>>2]=X_(c[z>>2]|0,D*12|0)|0;bO=z}z=dq(101144)|0;c[(c[bO>>2]|0)+((c[A>>2]|0)*12|0)>>2]=z;c[(c[bO>>2]|0)+((c[A>>2]|0)*12|0)+4>>2]=68;c[(c[bO>>2]|0)+((c[A>>2]|0)*12|0)+8>>2]=0;c[A>>2]=(c[A>>2]|0)+1;A=c[ba>>2]|0;if((A|0)==0){break L7744}z=A+8|0;D=A+4|0;y=c[D>>2]|0;if((c[z>>2]|0)>>>0<y>>>0){bP=A|0}else{B=(y<<1)+2|0;c[D>>2]=B;D=A|0;c[D>>2]=X_(c[D>>2]|0,B*12|0)|0;bP=D}D=dq(100696)|0;c[(c[bP>>2]|0)+((c[z>>2]|0)*12|0)>>2]=D;c[(c[bP>>2]|0)+((c[z>>2]|0)*12|0)+4>>2]=69;c[(c[bP>>2]|0)+((c[z>>2]|0)*12|0)+8>>2]=0;c[z>>2]=(c[z>>2]|0)+1;z=c[ba>>2]|0;if((z|0)==0){break L7744}D=z+8|0;B=z+4|0;A=c[B>>2]|0;if((c[D>>2]|0)>>>0<A>>>0){bQ=z|0}else{y=(A<<1)+2|0;c[B>>2]=y;B=z|0;c[B>>2]=X_(c[B>>2]|0,y*12|0)|0;bQ=B}B=dq(100016)|0;c[(c[bQ>>2]|0)+((c[D>>2]|0)*12|0)>>2]=B;c[(c[bQ>>2]|0)+((c[D>>2]|0)*12|0)+4>>2]=70;c[(c[bQ>>2]|0)+((c[D>>2]|0)*12|0)+8>>2]=0;c[D>>2]=(c[D>>2]|0)+1;D=c[ba>>2]|0;if((D|0)==0){break L7744}B=D+8|0;y=D+4|0;z=c[y>>2]|0;if((c[B>>2]|0)>>>0<z>>>0){bR=D|0}else{A=(z<<1)+2|0;c[y>>2]=A;y=D|0;c[y>>2]=X_(c[y>>2]|0,A*12|0)|0;bR=y}y=dq(99616)|0;c[(c[bR>>2]|0)+((c[B>>2]|0)*12|0)>>2]=y;c[(c[bR>>2]|0)+((c[B>>2]|0)*12|0)+4>>2]=71;c[(c[bR>>2]|0)+((c[B>>2]|0)*12|0)+8>>2]=0;c[B>>2]=(c[B>>2]|0)+1;B=c[ba>>2]|0;if((B|0)==0){break L7744}y=B+8|0;A=B+4|0;D=c[A>>2]|0;if((c[y>>2]|0)>>>0<D>>>0){bS=B|0}else{z=(D<<1)+2|0;c[A>>2]=z;A=B|0;c[A>>2]=X_(c[A>>2]|0,z*12|0)|0;bS=A}A=dq(99248)|0;c[(c[bS>>2]|0)+((c[y>>2]|0)*12|0)>>2]=A;c[(c[bS>>2]|0)+((c[y>>2]|0)*12|0)+4>>2]=72;c[(c[bS>>2]|0)+((c[y>>2]|0)*12|0)+8>>2]=0;c[y>>2]=(c[y>>2]|0)+1;y=c[ba>>2]|0;if((y|0)==0){break L7744}A=y+8|0;z=y+4|0;B=c[z>>2]|0;if((c[A>>2]|0)>>>0<B>>>0){bT=y|0}else{D=(B<<1)+2|0;c[z>>2]=D;z=y|0;c[z>>2]=X_(c[z>>2]|0,D*12|0)|0;bT=z}z=dq(98880)|0;c[(c[bT>>2]|0)+((c[A>>2]|0)*12|0)>>2]=z;c[(c[bT>>2]|0)+((c[A>>2]|0)*12|0)+4>>2]=73;c[(c[bT>>2]|0)+((c[A>>2]|0)*12|0)+8>>2]=0;c[A>>2]=(c[A>>2]|0)+1;break L7744;break};case 57:{A=b+44|0;z=c[A>>2]|0;D=z+8|0;if((c[D>>2]|0)!=0){y=z|0;z=0;do{XZ(c[(c[y>>2]|0)+(z*12|0)>>2]|0);z=z+1|0;}while(z>>>0<(c[D>>2]|0)>>>0)}c[D>>2]=0;z=c[A>>2]|0;if((z|0)==0){break L7744}y=z+8|0;ba=z+4|0;C=c[ba>>2]|0;if((c[y>>2]|0)>>>0<C>>>0){bU=z|0}else{B=(C<<1)+2|0;c[ba>>2]=B;ba=z|0;c[ba>>2]=X_(c[ba>>2]|0,B*12|0)|0;bU=ba}ba=dq(21040)|0;c[(c[bU>>2]|0)+((c[y>>2]|0)*12|0)>>2]=ba;c[(c[bU>>2]|0)+((c[y>>2]|0)*12|0)+4>>2]=58;c[(c[bU>>2]|0)+((c[y>>2]|0)*12|0)+8>>2]=0;c[y>>2]=(c[y>>2]|0)+1;y=c[A>>2]|0;if((y|0)==0){break L7744}ba=y+8|0;B=y+4|0;z=c[B>>2]|0;if((c[ba>>2]|0)>>>0<z>>>0){bV=y|0}else{C=(z<<1)+2|0;c[B>>2]=C;B=y|0;c[B>>2]=X_(c[B>>2]|0,C*12|0)|0;bV=B}B=dq(20712)|0;c[(c[bV>>2]|0)+((c[ba>>2]|0)*12|0)>>2]=B;c[(c[bV>>2]|0)+((c[ba>>2]|0)*12|0)+4>>2]=59;c[(c[bV>>2]|0)+((c[ba>>2]|0)*12|0)+8>>2]=0;c[ba>>2]=(c[ba>>2]|0)+1;ba=c[A>>2]|0;if((ba|0)==0){break L7744}B=ba+8|0;C=ba+4|0;y=c[C>>2]|0;if((c[B>>2]|0)>>>0<y>>>0){bW=ba|0}else{z=(y<<1)+2|0;c[C>>2]=z;C=ba|0;c[C>>2]=X_(c[C>>2]|0,z*12|0)|0;bW=C}C=dq(20408)|0;c[(c[bW>>2]|0)+((c[B>>2]|0)*12|0)>>2]=C;c[(c[bW>>2]|0)+((c[B>>2]|0)*12|0)+4>>2]=60;c[(c[bW>>2]|0)+((c[B>>2]|0)*12|0)+8>>2]=0;c[B>>2]=(c[B>>2]|0)+1;B=c[A>>2]|0;if((B|0)==0){break L7744}C=B+8|0;z=B+4|0;ba=c[z>>2]|0;if((c[C>>2]|0)>>>0<ba>>>0){bX=B|0}else{y=(ba<<1)+2|0;c[z>>2]=y;z=B|0;c[z>>2]=X_(c[z>>2]|0,y*12|0)|0;bX=z}z=dq(20064)|0;c[(c[bX>>2]|0)+((c[C>>2]|0)*12|0)>>2]=z;c[(c[bX>>2]|0)+((c[C>>2]|0)*12|0)+4>>2]=78;c[(c[bX>>2]|0)+((c[C>>2]|0)*12|0)+8>>2]=0;c[C>>2]=(c[C>>2]|0)+1;break L7744;break};case 53:{C=b+44|0;z=c[C>>2]|0;y=z+8|0;if((c[y>>2]|0)!=0){B=z|0;z=0;do{XZ(c[(c[B>>2]|0)+(z*12|0)>>2]|0);z=z+1|0;}while(z>>>0<(c[y>>2]|0)>>>0)}c[y>>2]=0;z=c[184120]|0;if((z|0)==0){B=c[C>>2]|0;if((B|0)==0){break L7744}A=B+8|0;D=B+4|0;ba=c[D>>2]|0;if((c[A>>2]|0)>>>0<ba>>>0){bY=B|0}else{G=(ba<<1)+2|0;c[D>>2]=G;D=B|0;c[D>>2]=X_(c[D>>2]|0,G*12|0)|0;bY=D}D=dq(21288)|0;c[(c[bY>>2]|0)+((c[A>>2]|0)*12|0)>>2]=D;c[(c[bY>>2]|0)+((c[A>>2]|0)*12|0)+4>>2]=65535;c[(c[bY>>2]|0)+((c[A>>2]|0)*12|0)+8>>2]=0;c[A>>2]=(c[A>>2]|0)+1;break L7744}A=c[z+4104>>2]|0;if((A|0)==0){break L7744}else{bZ=0;b_=z}while(1){z=c[C>>2]|0;D=c[(c[b_+4100>>2]|0)+(bZ<<4)>>2]|0;G=bZ+65536|0;if((z|0)!=0){B=z+8|0;ba=z+4|0;a9=c[ba>>2]|0;if((c[B>>2]|0)>>>0<a9>>>0){b$=z|0}else{a8=(a9<<1)+2|0;c[ba>>2]=a8;ba=z|0;c[ba>>2]=X_(c[ba>>2]|0,a8*12|0)|0;b$=ba}ba=dq(D|0)|0;c[(c[b$>>2]|0)+((c[B>>2]|0)*12|0)>>2]=ba;c[(c[b$>>2]|0)+((c[B>>2]|0)*12|0)+4>>2]=G;c[(c[b$>>2]|0)+((c[B>>2]|0)*12|0)+8>>2]=0;c[B>>2]=(c[B>>2]|0)+1}B=bZ+1|0;if(B>>>0>=A>>>0){break L7744}bZ=B;b_=c[184120]|0}break};case 21:{A=v|0;C=b+44|0;y=c[C>>2]|0;B=y+8|0;if((c[B>>2]|0)!=0){G=y|0;y=0;do{XZ(c[(c[G>>2]|0)+(y*12|0)>>2]|0);y=y+1|0;}while(y>>>0<(c[B>>2]|0)>>>0)}c[B>>2]=0;y=c[C>>2]|0;do{if((y|0)!=0){G=y+8|0;ba=y+4|0;D=c[ba>>2]|0;if((c[G>>2]|0)>>>0<D>>>0){b0=y|0}else{a8=(D<<1)+2|0;c[ba>>2]=a8;ba=y|0;c[ba>>2]=X_(c[ba>>2]|0,a8*12|0)|0;b0=ba}ba=dq(29656)|0;c[(c[b0>>2]|0)+((c[G>>2]|0)*12|0)>>2]=ba;c[(c[b0>>2]|0)+((c[G>>2]|0)*12|0)+4>>2]=24;c[(c[b0>>2]|0)+((c[G>>2]|0)*12|0)+8>>2]=0;c[G>>2]=(c[G>>2]|0)+1;G=c[C>>2]|0;if((G|0)==0){break}ba=G+8|0;a8=G+4|0;D=c[a8>>2]|0;if((c[ba>>2]|0)>>>0<D>>>0){b1=G|0}else{z=(D<<1)+2|0;c[a8>>2]=z;a8=G|0;c[a8>>2]=X_(c[a8>>2]|0,z*12|0)|0;b1=a8}a8=dq(29280)|0;c[(c[b1>>2]|0)+((c[ba>>2]|0)*12|0)>>2]=a8;c[(c[b1>>2]|0)+((c[ba>>2]|0)*12|0)+4>>2]=22;c[(c[b1>>2]|0)+((c[ba>>2]|0)*12|0)+8>>2]=0;c[ba>>2]=(c[ba>>2]|0)+1;ba=c[C>>2]|0;if((ba|0)==0){break}a8=ba+8|0;z=ba+4|0;G=c[z>>2]|0;if((c[a8>>2]|0)>>>0<G>>>0){b2=ba|0}else{D=(G<<1)+2|0;c[z>>2]=D;z=ba|0;c[z>>2]=X_(c[z>>2]|0,D*12|0)|0;b2=z}z=dq(28960)|0;c[(c[b2>>2]|0)+((c[a8>>2]|0)*12|0)>>2]=z;c[(c[b2>>2]|0)+((c[a8>>2]|0)*12|0)+4>>2]=23;c[(c[b2>>2]|0)+((c[a8>>2]|0)*12|0)+8>>2]=0;c[a8>>2]=(c[a8>>2]|0)+1;a8=c[C>>2]|0;if((a8|0)==0){break}z=a8+8|0;D=a8+4|0;ba=c[D>>2]|0;if((c[z>>2]|0)>>>0<ba>>>0){b3=a8|0}else{G=(ba<<1)+2|0;c[D>>2]=G;D=a8|0;c[D>>2]=X_(c[D>>2]|0,G*12|0)|0;b3=D}D=dq(28648)|0;c[(c[b3>>2]|0)+((c[z>>2]|0)*12|0)>>2]=D;c[(c[b3>>2]|0)+((c[z>>2]|0)*12|0)+4>>2]=25;c[(c[b3>>2]|0)+((c[z>>2]|0)*12|0)+8>>2]=0;c[z>>2]=(c[z>>2]|0)+1}}while(0);y=b+4252|0;if((c[y>>2]|0)==0){break L7744}else{b4=0}do{bN(A|0,64,28360,(X=i,i=i+8|0,c[X>>2]=b4,X)|0)|0;i=X;B=c[C>>2]|0;z=b4*3|0;D=z+26|0;if((B|0)!=0){G=B+8|0;a8=B+4|0;ba=c[a8>>2]|0;if((c[G>>2]|0)>>>0<ba>>>0){b5=B|0}else{a9=(ba<<1)+2|0;c[a8>>2]=a9;a8=B|0;c[a8>>2]=X_(c[a8>>2]|0,a9*12|0)|0;b5=a8}a8=dq(A|0)|0;c[(c[b5>>2]|0)+((c[G>>2]|0)*12|0)>>2]=a8;c[(c[b5>>2]|0)+((c[G>>2]|0)*12|0)+4>>2]=D;c[(c[b5>>2]|0)+((c[G>>2]|0)*12|0)+8>>2]=0;c[G>>2]=(c[G>>2]|0)+1}bN(A|0,64,27984,(X=i,i=i+8|0,c[X>>2]=b4,X)|0)|0;i=X;G=c[C>>2]|0;D=z+27|0;if((G|0)!=0){a8=G+8|0;a9=G+4|0;B=c[a9>>2]|0;if((c[a8>>2]|0)>>>0<B>>>0){b6=G|0}else{ba=(B<<1)+2|0;c[a9>>2]=ba;a9=G|0;c[a9>>2]=X_(c[a9>>2]|0,ba*12|0)|0;b6=a9}a9=dq(A|0)|0;c[(c[b6>>2]|0)+((c[a8>>2]|0)*12|0)>>2]=a9;c[(c[b6>>2]|0)+((c[a8>>2]|0)*12|0)+4>>2]=D;c[(c[b6>>2]|0)+((c[a8>>2]|0)*12|0)+8>>2]=0;c[a8>>2]=(c[a8>>2]|0)+1}bN(A|0,64,27584,(X=i,i=i+8|0,c[X>>2]=b4,X)|0)|0;i=X;a8=c[C>>2]|0;D=z+28|0;if((a8|0)!=0){z=a8+8|0;a9=a8+4|0;ba=c[a9>>2]|0;if((c[z>>2]|0)>>>0<ba>>>0){b7=a8|0}else{G=(ba<<1)+2|0;c[a9>>2]=G;a9=a8|0;c[a9>>2]=X_(c[a9>>2]|0,G*12|0)|0;b7=a9}a9=dq(A|0)|0;c[(c[b7>>2]|0)+((c[z>>2]|0)*12|0)>>2]=a9;c[(c[b7>>2]|0)+((c[z>>2]|0)*12|0)+4>>2]=D;c[(c[b7>>2]|0)+((c[z>>2]|0)*12|0)+8>>2]=0;c[z>>2]=(c[z>>2]|0)+1}b4=b4+1|0;}while(b4>>>0<(c[y>>2]|0)>>>0);break};default:{il(b);break L7744}}}}while(0);iq(b);a0=0;i=f;return a0|0}
function T_(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,y=0,z=0,A=0,B=0;f=i;i=i+1344|0;g=f|0;h=f+16|0;j=f+32|0;k=f+56|0;l=f+232|0;m=f+320|0;ce(m|0,99128,(n=i,i=i+16|0,c[n>>2]=96728,c[n+8>>2]=6,n)|0)|0;i=n;o=X1(m|0)|0;p=e+4|0;q=e+8|0;r=c[q>>2]|0;s=(c[p>>2]|0)-r|0;t=s>>>0<o>>>0?s:o;o=e|0;s=(c[o>>2]|0)+r|0;X5(s|0,m|0,t)|0;c[q>>2]=(c[q>>2]|0)+t;t=(X1(1093765)|0)+1|0;ce(m|0,67448,(n=i,i=i+24|0,c[n>>2]=t,c[n+8>>2]=1093765,c[n+16>>2]=0,n)|0)|0;i=n;t=(X1(m|0)|0)+1|0;s=c[q>>2]|0;r=(c[p>>2]|0)-s|0;u=r>>>0<t>>>0?r:t;t=(c[o>>2]|0)+s|0;X5(t|0,m|0,u)|0;c[q>>2]=(c[q>>2]|0)+u;T$(e,56496,1393568,145816,17);T$(e,47440,1041656,105760,9);T$(e,40488,1041704,105976,1158);u=k|0;X5(u|0,1183776,22)|0;m=k+22|0;X5(m|0,1183798,22)|0;m=k+44|0;X5(m|0,1183820,22)|0;m=k+66|0;X5(m|0,1183842,22)|0;m=k+88|0;X5(m|0,1183864,22)|0;m=k+110|0;X5(m|0,1183886,22)|0;m=k+132|0;X5(m|0,1183908,22)|0;m=k+154|0;X5(m|0,1183930,22)|0;T$(e,35784,u,142504,128);u=c[263194]|0;m=j|0;ce(m|0,37584,(n=i,i=i+16|0,c[n>>2]=31152,c[n+8>>2]=65536,n)|0)|0;i=n;k=j+11|0;a[k]=0;j=c[q>>2]|0;t=(c[p>>2]|0)-j|0;s=t>>>0<11?t:11;t=(c[o>>2]|0)+j|0;X5(t|0,m|0,s)|0;t=(c[q>>2]|0)+s|0;c[q>>2]=t;s=(c[p>>2]|0)-t|0;j=s>>>0<65536?s:65536;s=(c[o>>2]|0)+t|0;X5(s|0,u|0,j)|0;c[q>>2]=(c[q>>2]|0)+j;j=c[263191]|0;ce(m|0,37584,(n=i,i=i+16|0,c[n>>2]=27312,c[n+8>>2]=131072,n)|0)|0;i=n;a[k]=0;u=c[q>>2]|0;s=(c[p>>2]|0)-u|0;t=s>>>0<11?s:11;s=(c[o>>2]|0)+u|0;X5(s|0,m|0,t)|0;s=(c[q>>2]|0)+t|0;c[q>>2]=s;t=(c[p>>2]|0)-s|0;u=t>>>0<131072?t:131072;t=(c[o>>2]|0)+s|0;X5(t|0,j|0,u)|0;c[q>>2]=(c[q>>2]|0)+u;u=c[263193]|0;ce(m|0,37584,(n=i,i=i+16|0,c[n>>2]=23080,c[n+8>>2]=131072,n)|0)|0;i=n;a[k]=0;j=c[q>>2]|0;t=(c[p>>2]|0)-j|0;s=t>>>0<11?t:11;t=(c[o>>2]|0)+j|0;X5(t|0,m|0,s)|0;t=(c[q>>2]|0)+s|0;c[q>>2]=t;s=(c[p>>2]|0)-t|0;j=s>>>0<131072?s:131072;s=(c[o>>2]|0)+t|0;X5(s|0,u|0,j)|0;c[q>>2]=(c[q>>2]|0)+j;j=c[263195]|0;ce(m|0,37584,(n=i,i=i+16|0,c[n>>2]=100888,c[n+8>>2]=32768,n)|0)|0;i=n;a[k]=0;u=c[q>>2]|0;s=(c[p>>2]|0)-u|0;t=s>>>0<11?s:11;s=(c[o>>2]|0)+u|0;X5(s|0,m|0,t)|0;s=(c[q>>2]|0)+t|0;c[q>>2]=s;t=(c[p>>2]|0)-s|0;u=t>>>0<32768?t:32768;t=(c[o>>2]|0)+s|0;X5(t|0,j|0,u)|0;c[q>>2]=(c[q>>2]|0)+u;u=g|0;g=h|0;if((c[109245]|0)!=0){c[199301]=0;c[109245]=0;X5(503096,437048,64)|0}X5(840944,437624,65536)|0;X5(u|0,436864,16)|0;X5(g|0,436880,16)|0;X5(906480,436864,16)|0;X5(906496,436880,16)|0;X5(436864,u|0,16)|0;X5(436880,g|0,16)|0;g=a[436865]&128;if((g|0)!=0){c[199301]=g;c[109245]=g;X5(437048,503096,64)|0;X5(503096,436984,64)|0}g=c[109224]|0;u=g>>>8;a[906512]=g&255;a[906513]=u&255;c[109224]=u<<8&65280|g&255;g=c[109225]|0;a[906514]=g&255;c[109225]=g&255;g=c[109226]|0;a[906515]=g&255;c[109226]=g&255;g=c[109227]|0;a[906516]=g&255;c[109227]=g&255;g=c[109228]|0;a[906517]=g&255;c[109228]=g&255;g=c[109229]|0;a[906518]=g&255;c[109229]=g&255;a[906519]=0;g=c[109231]|0;u=g>>>8;a[906520]=g&255;a[906521]=u&255;c[109231]=(u<<8&65280|g&255)<<16>>16;g=c[109230]|0;u=g>>>8;a[906522]=g&255;a[906523]=u&255;c[109230]=(u<<8&65280|g&255)<<16>>16;X5(906524,795648,128)|0;g=0;u=906652;while(1){h=0;j=u;while(1){t=796036+(g*140|0)+(h<<2)|0;s=c[t>>2]|0;r=s>>>8;a[j]=s&255;a[j+1|0]=r&255;v=(r<<8&65280|s&255)<<16>>16;c[796036+(g*140|0)+(h+12<<2)>>2]=v;c[t>>2]=v;v=h+1|0;if((v|0)<12){h=v;j=j+2|0}else{break}}j=796136+(g*140|0)|0;h=c[j>>2]|0;v=h>>>8;a[u+24|0]=h&255;a[u+25|0]=v&255;c[j>>2]=v<<8&65280|h&255;h=796140+(g*140|0)|0;v=c[h>>2]|0;j=v>>>8;a[u+26|0]=v&255;a[u+27|0]=j&255;c[h>>2]=j<<8&65280|v&255;v=796164+(g*140|0)|0;j=c[v>>2]|0;h=j>>>8;a[u+28|0]=j&255;a[u+29|0]=h&255;c[v>>2]=h<<8&65280|j&255;j=796168+(g*140|0)|0;h=c[j>>2]|0;v=h>>>8;a[u+30|0]=h&255;a[u+31|0]=v&255;c[j>>2]=(v<<8&65280|h&255)<<16>>16;h=796132+(g*140|0)|0;v=c[h>>2]|0;a[u+32|0]=v&255;c[h>>2]=v&255;v=796144+(g*140|0)|0;h=c[v>>2]|0;a[u+33|0]=h&255;c[v>>2]=h&255;h=796156+(g*140|0)|0;v=c[h>>2]|0;a[u+34|0]=v&255;c[h>>2]=v&255;v=796160+(g*140|0)|0;h=c[v>>2]|0;a[u+35|0]=h&255;c[v>>2]=h&255;h=796172+(g*140|0)|0;v=a[h]|0;a[u+36|0]=v;a[h]=v;a[u+37|0]=0;v=g+1|0;if((v|0)<8){g=v;u=u+38|0}else{w=0;y=906956;break}}while(1){u=c[198976]|0;g=c[u+(w<<3)>>2]|0;v=c[u+(w<<3)+4>>2]|0;u=g>>>8;a[y]=g&255;a[y+1|0]=u&255;c[795776+(w<<3)>>2]=(u<<8&65280|g&255)<<16>>16;g=v>>>8;a[y+2|0]=v&255;a[y+3|0]=g&255;c[795780+(w<<3)>>2]=(g<<8&65280|v&255)<<16>>16;v=w+1|0;if((v|0)<8){w=v;y=y+4|0}else{break}}c[198976]=795776;X5(795840,795776,64)|0;y=c[198977]|0;a[906988]=y&255;c[198977]=y&255;y=c[198978]|0;a[906989]=y&255;c[198978]=y&255;y=c[198979]|0;w=y>>>8;a[906990]=y&255;a[906991]=w&255;c[198979]=w<<8&65280|y&255;y=c[198980]|0;w=y>>>8;a[906992]=y&255;a[906993]=w&255;c[198980]=w<<8&65280|y&255;y=c[198981]|0;w=y>>>8;a[906994]=y&255;a[906995]=w&255;c[198981]=w<<8&65280|y&255;y=c[198982]|0;w=y>>>8;a[906996]=y&255;a[906997]=w&255;c[198982]=w<<8&65280|y&255;y=c[198983]|0;a[906998]=y&255;c[198983]=y&255;y=c[198984]|0;a[906999]=y&255;c[198984]=y&255;a[907e3]=a[795940]|0;a[907001]=a[795941]|0;a[907002]=a[795942]|0;y=c[198986]|0;a[907003]=y&255;c[198986]=y&255;y=c[198987]|0;a[907004]=y&255;c[198987]=y&255;y=c[198988]|0;a[907005]=y&255;c[198988]=y&255;y=c[198989]|0;a[907006]=y&255;c[198989]=y&255;y=c[198990]|0;a[907007]=y&255;c[198990]=y&255;y=c[198991]|0;w=y>>>8;a[907008]=y&255;a[907009]=w&255;c[198991]=w<<8&65280|y&255;y=c[198992]|0;a[907010]=y&255;c[198992]=y&255;y=c[198993]|0;a[907011]=y&255;c[198993]=y&255;y=c[198994]|0;a[907012]=y&255;c[198994]=y&255;y=c[198995]|0;a[907013]=y&255;c[198995]=y&255;y=c[198996]|0;a[907014]=y&255;c[198996]=y&255;y=c[198997]|0;a[907015]=y&255;c[198997]=y&255;y=c[199003]|0;w=y>>>8;a[907016]=y&255;a[907017]=w&255;c[199003]=(w<<8&65280|y&255)<<16>>16;y=c[199004]|0;w=y>>>8;a[907018]=y&255;a[907019]=w&255;c[199004]=(w<<8&65280|y&255)<<16>>16;y=c[199005]|0;w=y>>>8;a[907020]=y&255;a[907021]=w&255;c[199005]=(w<<8&65280|y&255)<<16>>16;y=c[199006]|0;w=y>>>8;a[907022]=y&255;a[907023]=w&255;c[199006]=(w<<8&65280|y&255)<<16>>16;y=c[199007]|0;w=y>>>8;a[907024]=y&255;a[907025]=w&255;c[199007]=(w<<8&65280|y&255)<<16>>16;y=c[199008]|0;w=y>>>8;a[907026]=y&255;a[907027]=w&255;c[199008]=(w<<8&65280|y&255)<<16>>16;y=c[198998]|0;w=y>>>8;a[907028]=y&255;a[907029]=w&255;c[198998]=w<<8&65280|y&255;y=c[198999]|0;w=y>>>8;a[907030]=y&255;a[907031]=w&255;c[198999]=w<<8&65280|y&255;y=c[199e3]|0;w=y>>>8;a[907032]=y&255;a[907033]=w&255;c[199e3]=(w<<8&65280|y&255)<<16>>16;y=c[199002]|0;w=y>>>8;a[907034]=y&255;a[907035]=w&255;c[199002]=w<<8&65280|y&255;y=c[199001]|0;a[907036]=y&255;c[199001]=y&255;a[907037]=0;c[109200]=((a[436874]|0)-1&255)+1;y=d[436865]|0;c[109202]=y&1;w=c[109198]|0;v=w>>>8;a[907038]=w&255;a[907039]=v&255;c[109198]=(v<<8&65280|w&255)<<16>>16;w=c[109201]|0;a[907040]=w&255;c[109201]=w&255;w=c[109203]|0;a[907041]=w&255;c[109203]=w&255;a[907042]=0;c[109206]=((a[436875]|0)-1&255)+1;c[109208]=y>>>1&1;w=c[109204]|0;v=w>>>8;a[907043]=w&255;a[907044]=v&255;c[109204]=(v<<8&65280|w&255)<<16>>16;w=c[109207]|0;a[907045]=w&255;c[109207]=w&255;w=c[109209]|0;a[907046]=w&255;c[109209]=w&255;a[907047]=0;c[109212]=((a[436876]|0)-1&255)+1;c[109214]=y>>>2&1;y=c[109210]|0;w=y>>>8;a[907048]=y&255;a[907049]=w&255;c[109210]=(w<<8&65280|y&255)<<16>>16;y=c[109213]|0;a[907050]=y&255;c[109213]=y&255;y=c[109215]|0;a[907051]=y&255;c[109215]=y&255;a[907052]=0;c[109211]=4;c[109205]=7;c[109199]=7;a[907053]=0;y=c[59e3]|0;a[907054]=y&255;a[907055]=y>>>8&255;a[907056]=y>>>16&255;a[907057]=y>>>24&255;y=c[42380]|0;a[907058]=y&255;a[907059]=y>>>8&255;a[907060]=y>>>16&255;a[907061]=y>>>24&255;ce(m|0,37584,(n=i,i=i+16|0,c[n>>2]=96512,c[n+8>>2]=69640,n)|0)|0;i=n;a[k]=0;y=c[q>>2]|0;w=(c[p>>2]|0)-y|0;v=w>>>0<11?w:11;w=(c[o>>2]|0)+y|0;X5(w|0,m|0,v)|0;w=(c[q>>2]|0)+v|0;c[q>>2]=w;v=(c[p>>2]|0)-w|0;y=v>>>0<69640?v:69640;v=(c[o>>2]|0)+w|0;X5(v|0,840944,y)|0;c[q>>2]=(c[q>>2]|0)+y;y=l|0;X2(y|0,0,84);a[y]=3;a[l+1|0]=a[236008]|0;a[l+7|0]=a[236010]|0;a[l+2|0]=a[236009]|0;a[l+8|0]=a[236011]|0;v=a[238618]|0;a[l+13|0]=(v&255)>>>4&3;w=a[238638]|0;a[l+14|0]=(w&255)>>>4&3;g=a[509608]|0;a[l+15|0]=(g&255)>>>3&1;u=l+25|0;x=b[254816]|0;a[u]=x&255;x=x>>8;a[u+1|0]=x&255;u=l+27|0;x=b[254817]|0;a[u]=x&255;x=x>>8;a[u+1|0]=x&255;u=l+29|0;x=b[254818]|0;a[u]=x&255;x=x>>8;a[u+1|0]=x&255;u=l+31|0;x=b[254819]|0;a[u]=x&255;x=x>>8;a[u+1|0]=x&255;u=l+33|0;x=b[254820]|0;a[u]=x&255;x=x>>8;a[u+1|0]=x&255;u=l+35|0;x=b[254821]|0;a[u]=x&255;x=x>>8;a[u+1|0]=x&255;u=l+37|0;x=b[254822]|0;a[u]=x&255;x=x>>8;a[u+1|0]=x&255;u=l+39|0;x=b[254823]|0;a[u]=x&255;x=x>>8;a[u+1|0]=x&255;a[l+41|0]=a[238608]|0;a[l+42|0]=a[238609]|0;u=l+43|0;x=b[119305]|0;a[u]=x&255;x=x>>8;a[u+1|0]=x&255;u=l+45|0;x=b[119306]|0;a[u]=x&255;x=x>>8;a[u+1|0]=x&255;u=l+47|0;x=b[119307]|0;a[u]=x&255;x=x>>8;a[u+1|0]=x&255;u=l+49|0;x=b[119308]|0;a[u]=x&255;x=x>>8;a[u+1|0]=x&255;a[l+51|0]=v;a[l+52|0]=a[238628]|0;a[l+53|0]=a[238629]|0;v=l+54|0;x=b[119315]|0;a[v]=x&255;x=x>>8;a[v+1|0]=x&255;v=l+56|0;x=b[119316]|0;a[v]=x&255;x=x>>8;a[v+1|0]=x&255;v=l+58|0;x=b[119317]|0;a[v]=x&255;x=x>>8;a[v+1|0]=x&255;v=l+60|0;x=b[119318]|0;a[v]=x&255;x=x>>8;a[v+1|0]=x&255;a[l+62|0]=w;w=l+63|0;x=b[84744]|0;a[w]=x&255;x=x>>8;a[w+1|0]=x&255;w=l+65|0;x=b[84745]|0;a[w]=x&255;x=x>>8;a[w+1|0]=x&255;a[l+67|0]=a[169492]|0;a[l+68|0]=a[169493]|0;a[l+69|0]=a[169494]|0;w=l+70|0;x=b[254812]|0;a[w]=x&255;x=x>>8;a[w+1|0]=x&255;w=l+72|0;x=b[254813]|0;a[w]=x&255;x=x>>8;a[w+1|0]=x&255;w=l+74|0;x=b[254808]|0;a[w]=x&255;x=x>>8;a[w+1|0]=x&255;w=l+76|0;x=b[254809]|0;a[w]=x&255;x=x>>8;a[w+1|0]=x&255;a[l+78|0]=g;a[l+79|0]=a[509600]|0;a[l+80|0]=a[509601]|0;a[l+81|0]=a[238600]|0;a[l+82|0]=a[238601]|0;a[l+83|0]=a[238604]|0;a[l+84|0]=a[238605]|0;a[l+24|0]=a[238560]|0;T$(e,92256,y,145576,10);T$(e,88720,798960,101728,16);if((a[799121]|0)!=0){c[277210]=1106800;T$(e,85568,1106800,133840,79)}if((a[799123]|0)!=0){a[808082]=a[808082]&60|a[808120]|a[808122]&-128|((a[808121]|0)==0)<<1|a[808123]<<6;T$(e,82120,808112,105448,13);T$(e,78736,808080,105232,9)}y=a[799122]|0;if(y<<24>>24==1){T$(e,75456,1182304,137848,194);z=a[799122]|0}else{z=y}if(z<<24>>24==2){T$(e,72520,1181224,137416,18);A=a[799122]|0}else{A=z}if(A<<24>>24==4){T$(e,70056,1129624,135736,70)}if((a[799124]|0)!=0){A=c[263197]|0;ce(m|0,37584,(n=i,i=i+16|0,c[n>>2]=68888,c[n+8>>2]=8192,n)|0)|0;i=n;a[k]=0;z=c[q>>2]|0;y=(c[p>>2]|0)-z|0;l=y>>>0<11?y:11;y=(c[o>>2]|0)+z|0;X5(y|0,m|0,l)|0;y=(c[q>>2]|0)+l|0;c[q>>2]=y;l=(c[p>>2]|0)-y|0;z=l>>>0<8192?l:8192;l=(c[o>>2]|0)+y|0;X5(l|0,A|0,z)|0;c[q>>2]=(c[q>>2]|0)+z}if((a[799129]|0)==1){T$(e,67256,808032,102112,5)}if((a[799128]|0)!=0){T$(e,65120,1044512,133768,3);z=c[263198]|0;ce(m|0,37584,(n=i,i=i+16|0,c[n>>2]=63528,c[n+8>>2]=8192,n)|0)|0;i=n;a[k]=0;A=c[q>>2]|0;l=(c[p>>2]|0)-A|0;y=l>>>0<11?l:11;l=(c[o>>2]|0)+A|0;X5(l|0,m|0,y)|0;l=(c[q>>2]|0)+y|0;c[q>>2]=l;y=(c[p>>2]|0)-l|0;A=y>>>0<8192?y:8192;y=(c[o>>2]|0)+l|0;X5(y|0,z|0,A)|0;c[q>>2]=(c[q>>2]|0)+A}if((a[799126]|0)!=0){a[235424]=a[237800]|0;a[235425]=a[237792]|0;a[235426]=a[237784]|0;a[235427]=a[237776]|0;a[235428]=a[237768]|0;a[235429]=a[237760]|0;a[235430]=a[237752]|0;a[235431]=a[237744]|0;a[235432]=a[237736]|0;a[235433]=a[237728]|0;a[235434]=a[237720]|0;a[235435]=a[237712]|0;a[235436]=a[237704]|0;a[235437]=a[237696]|0;a[235438]=a[237688]|0;a[235439]=a[237680]|0;a[235440]=a[237664]|0;a[235441]=a[237648]|0;a[235442]=a[237640]|0;a[235443]=a[237632]|0;a[235444]=a[237624]|0;a[235445]=(a[237672]|0)!=0|0;a[235446]=(a[237656]|0)!=0|0;a[235447]=a[237616]|0;a[235448]=a[237608]|0;a[235449]=a[237600]|0;a[235450]=a[237592]|0;a[235451]=a[237584]|0;a[235452]=a[237576]|0;a[235453]=a[237568]|0;a[235454]=a[237560]|0;a[235455]=a[237552]|0;a[235456]=a[237544]|0;a[235457]=a[237536]|0;a[235458]=a[237528]|0;a[235459]=a[237520]|0;a[235460]=a[237512]|0;a[235461]=a[237504]|0;a[235462]=a[237496]|0;a[235463]=a[237488]|0;a[235464]=a[237480]|0;a[235465]=a[237472]|0;a[235466]=a[237464]|0;a[235467]=a[237456]|0;c[58867]=c[198898];c[58868]=c[198894];c[58869]=c[198890];a[235480]=a[237448]|0;a[235481]=a[237440]|0;a[235482]=a[237432]|0;c[58871]=c[58912];c[58872]=c[58914];c[58873]=c[58920];c[58874]=c[199378];c[58875]=c[199376];A=c[199386]|0;z=0;do{a[235504+z|0]=a[A+z|0]|0;z=z+1|0;}while((z|0)<64);c[58892]=c[199382];c[58893]=c[199380];c[58894]=c[199384];z=0;do{a[235580+(z<<1)|0]=a[797712+(z<<1)|0]|0;a[235581+(z<<1)|0]=a[797713+(z<<1)|0]|0;z=z+1|0;}while((z|0)<32);T$(e,62160,235424,102280,123)}if((a[799130]|0)==0){B=0}else{c[42378]=c[58916];c[42379]=c[58918];T$(e,61248,169512,102232,2);B=a[799130]|0}if((a[799127]|B)<<24>>24!=0){ce(m|0,37584,(n=i,i=i+16|0,c[n>>2]=60128,c[n+8>>2]=20,n)|0)|0;i=n;a[k]=0;k=c[q>>2]|0;n=(c[p>>2]|0)-k|0;B=n>>>0<11?n:11;n=(c[o>>2]|0)+k|0;X5(n|0,m|0,B)|0;m=(c[q>>2]|0)+B|0;c[q>>2]=m;B=(c[p>>2]|0)-m|0;p=B>>>0<20?B:20;B=(c[o>>2]|0)+m|0;X5(B|0,1041680,p)|0;c[q>>2]=(c[q>>2]|0)+p}if((a[799131]|0)==0){i=f;return}T$(e,59224,1394256,146224,15);i=f;return}function T$(d,f,g,h,j){d=d|0;f=f|0;g=g|0;h=h|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0;k=i;i=i+32|0;l=k|0;m=k+24|0;do{if((j|0)>0){n=0;o=0;while(1){do{if((e[h+(o*24|0)+16>>1]|0)>6){p=n}else{if((e[h+(o*24|0)+18>>1]|0)<=6){p=n;break}q=c[h+(o*24|0)+8>>2]|0;r=c[h+(o*24|0)+12>>2]|0;if((r|0)==3|(r|0)==6){s=q<<2}else if((r|0)==2|(r|0)==5){s=q<<1}else{s=q}p=s+n|0}}while(0);q=o+1|0;if((q|0)<(j|0)){n=p;o=q}else{break}}o=XY(p)|0;n=m;q=0;r=o;while(1){L6415:do{if((e[h+(q*24|0)+18>>1]|0)<7){t=r}else{if((e[h+(q*24|0)+16>>1]|0)>6){t=r;break}u=g+(c[h+(q*24|0)>>2]|0)|0;v=c[h+(q*24|0)+12>>2]|0;do{if((v-4|0)>>>0<3){w=c[u>>2]|0;x=5300}else{if((v|0)!=7){w=u;x=5300;break}c[m>>2]=(c[u>>2]|0)-(c[g+(c[h+(q*24|0)+4>>2]|0)>>2]|0);y=n}}while(0);L6422:do{if((x|0)==5300){x=0;switch(v|0){case 2:case 5:{u=h+(q*24|0)+8|0;if((c[u>>2]|0)>0){z=0;A=r}else{t=r;break L6415}while(1){B=b[w+(z<<1)>>1]|0;a[A]=(B&65535)>>>8&255;C=A+2|0;a[A+1|0]=B&255;B=z+1|0;if((B|0)<(c[u>>2]|0)){z=B;A=C}else{t=C;break L6415}}break};case 6:case 3:{u=h+(q*24|0)+8|0;if((c[u>>2]|0)>0){D=0;E=r}else{t=r;break L6415}while(1){C=c[w+(D<<2)>>2]|0;a[E]=C>>>24&255;a[E+1|0]=C>>>16&255;a[E+2|0]=C>>>8&255;B=E+4|0;a[E+3|0]=C&255;C=D+1|0;if((C|0)<(c[u>>2]|0)){D=C;E=B}else{t=B;break L6415}}break};case 0:{y=w;break L6422;break};case 1:case 4:{u=h+(q*24|0)+8|0;X9(r|0,w|0,c[u>>2]|0);t=r+(c[u>>2]|0)|0;break L6415;break};default:{t=r;break L6415}}}}while(0);v=c[h+(q*24|0)+8>>2]|0;if((v|0)==8){u=y;B=c[u>>2]|0;C=c[u+4>>2]|0;a[r]=(C>>>24|0<<8)&255;a[r+1|0]=(C>>>16|0<<16)&255;a[r+2|0]=(C>>>8|0<<24)&255;a[r+3|0]=C&255;a[r+4|0]=(B>>>24|C<<8)&255;a[r+5|0]=(B>>>16|C<<16)&255;a[r+6|0]=(B>>>8|C<<24)&255;a[r+7|0]=B&255;t=r+8|0;break}else if((v|0)==1){a[r]=a[y]|0;t=r+1|0;break}else if((v|0)==2){B=b[y>>1]|0;a[r]=(B&65535)>>>8&255;a[r+1|0]=B&255;t=r+2|0;break}else if((v|0)==4){v=c[y>>2]|0;a[r]=v>>>24&255;a[r+1|0]=v>>>16&255;a[r+2|0]=v>>>8&255;a[r+3|0]=v&255;t=r+4|0;break}else{t=r;break}}}while(0);v=q+1|0;if((v|0)<(j|0)){q=v;r=t}else{break}}r=l|0;if((p|0)<1e6){F=o;G=p;H=r;break}ce(r|0,37568,(I=i,i=i+8|0,c[I>>2]=f,I)|0)|0;i=I;a[l+6|0]=p>>>24&255;a[l+7|0]=p>>>16&255;a[l+8|0]=p>>>8&255;a[l+9|0]=p&255;J=o;K=p;L=r;M=l+11|0;a[M]=0;N=d+4|0;O=c[N>>2]|0;P=d+8|0;Q=c[P>>2]|0;R=O-Q|0;S=R>>>0<11;T=S?R:11;U=d|0;V=c[U>>2]|0;W=V+Q|0;X5(W|0,L|0,T)|0;X=c[P>>2]|0;Y=X+T|0;c[P>>2]=Y;Z=c[N>>2]|0;_=Z-Y|0;$=_>>>0<K>>>0;aa=$?_:K;ab=c[U>>2]|0;ac=ab+Y|0;X5(ac|0,J|0,aa)|0;ad=c[P>>2]|0;ae=ad+aa|0;c[P>>2]=ae;XZ(J);i=k;return}else{F=XY(0)|0;G=0;H=l|0}}while(0);ce(H|0,37584,(I=i,i=i+16|0,c[I>>2]=f,c[I+8>>2]=G,I)|0)|0;i=I;J=F;K=G;L=H;M=l+11|0;a[M]=0;N=d+4|0;O=c[N>>2]|0;P=d+8|0;Q=c[P>>2]|0;R=O-Q|0;S=R>>>0<11;T=S?R:11;U=d|0;V=c[U>>2]|0;W=V+Q|0;X5(W|0,L|0,T)|0;X=c[P>>2]|0;Y=X+T|0;c[P>>2]=Y;Z=c[N>>2]|0;_=Z-Y|0;$=_>>>0<K>>>0;aa=$?_:K;ab=c[U>>2]|0;ac=ab+Y|0;X5(ac|0,J|0,aa)|0;ad=c[P>>2]|0;ae=ad+aa|0;c[P>>2]=ae;XZ(J);i=k;return}function T0(b,e,f,g){b=b|0;e=e|0;f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;h=i;i=i+24|0;j=h|0;k=b+8|0;l=c[k>>2]|0;m=j|0;n=b+4|0;o=c[n>>2]|0;p=o-l|0;q=p>>>0<11?p:11;p=b|0;b=(c[p>>2]|0)+l|0;X5(m|0,b|0,q)|0;c[k>>2]=l+q;a[j+q|0]=0;do{if((q|0)==11){if((bJ(m|0,e|0,3)|0)!=0){break}if((a[j+3|0]|0)!=58){break}b=j+4|0;if((a[b]|0)==45){r=d[j+7|0]<<16|d[j+6|0]<<24|d[j+8|0]<<8|d[j+9|0]}else{r=e1(b|0)|0}if((r|0)<1){break}b=(r|0)>(g|0);s=b?r-g|0:0;t=b?g:r;X2(f|0,0,g|0);b=c[k>>2]|0;u=(c[n>>2]|0)-b|0;v=u>>>0<t>>>0?u:t;u=(c[p>>2]|0)+b|0;X5(f|0,u|0,v)|0;c[k>>2]=(c[k>>2]|0)+v;if((v|0)!=(t|0)){if(l>>>0>(c[n>>2]|0)>>>0){w=-1;i=h;return w|0}c[k>>2]=l;w=-1;i=h;return w|0}if((s|0)==0){w=1;i=h;return w|0}t=XY(s)|0;v=c[k>>2]|0;u=(c[n>>2]|0)-v|0;b=u>>>0<s>>>0?u:s;u=(c[p>>2]|0)+v|0;X5(t|0,u|0,b)|0;c[k>>2]=(c[k>>2]|0)+b;XZ(t);if((b|0)==(s|0)){w=1;i=h;return w|0}if(l>>>0>(c[n>>2]|0)>>>0){w=-1;i=h;return w|0}c[k>>2]=l;w=-1;i=h;return w|0}}while(0);if(l>>>0>o>>>0){w=-1;i=h;return w|0}c[k>>2]=l;w=-1;i=h;return w|0}function T1(f,g,h,i,j){f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;if((h|0)>0){k=i;l=0}else{return}while(1){do{if((e[g+(l*24|0)+16>>1]|0|0)>(j|0)){m=k}else{i=b[g+(l*24|0)+18>>1]|0;if((i&65535|0)<=(j|0)){m=k;break}n=(i&65535)<7?1044504:f;i=g+(l*24|0)|0;o=c[i>>2]|0;p=n+o|0;q=g+(l*24|0)+12|0;r=c[q>>2]|0;if((r-4|0)>>>0<3){s=c[p>>2]|0}else{s=p}L6488:do{switch(r|0){case 0:case 7:{p=c[g+(l*24|0)+8>>2]|0;if((p|0)==2){if((o|0)<0){t=k+2|0;break L6488}else{b[s>>1]=(d[k]|0)<<8|(d[k+1|0]|0);t=k+2|0;break L6488}}else if((p|0)==4){if((o|0)<0){t=k+4|0;break L6488}else{c[s>>2]=(d[k+1|0]|0)<<16|(d[k]|0)<<24|(d[k+2|0]|0)<<8|(d[k+3|0]|0);t=k+4|0;break L6488}}else if((p|0)==8){if((o|0)<0){t=k+8|0;break L6488}else{u=d[k+4|0]|0;v=d[k+5|0]|0;w=d[k+6|0]|0;x=(d[k+1|0]|0)<<16|0>>>16|((d[k]|0)<<24|0>>>8)|((d[k+2|0]|0)<<8|0>>>24)|(d[k+3|0]|0)|(0<<24|u>>>8)|(0<<16|v>>>16)|(0<<8|w>>>24)|0;y=s;c[y>>2]=0<<16|0>>>16|(0<<24|0>>>8)|(0<<8|0>>>24)|(u<<24|0>>>8)|(v<<16|0>>>16)|(w<<8|0>>>24)|(d[k+7|0]|0);c[y+4>>2]=x;t=k+8|0;break L6488}}else if((p|0)==1){p=k+1|0;if((o|0)<0){t=p;break L6488}a[s]=a[k]|0;t=p;break L6488}else{t=k;break L6488}break};case 1:case 4:{p=g+(l*24|0)+8|0;if((o|0)>-1){X9(s|0,k|0,c[p>>2]|0)}t=k+(c[p>>2]|0)|0;break};case 2:case 5:{p=g+(l*24|0)+8|0;x=c[p>>2]|0;if((o|0)<0){t=k+(x<<1)|0;break L6488}if((x|0)>0){z=k;A=0}else{t=k;break L6488}while(1){x=z+2|0;b[s+(A<<1)>>1]=(d[z]|0)<<8|(d[z+1|0]|0);y=A+1|0;if((y|0)<(c[p>>2]|0)){z=x;A=y}else{t=x;break}}break};case 3:case 6:{p=g+(l*24|0)+8|0;x=c[p>>2]|0;if((o|0)<0){t=k+(x<<2)|0;break L6488}if((x|0)>0){B=k;C=0}else{t=k;break L6488}while(1){x=B+4|0;c[s+(C<<2)>>2]=(d[B+1|0]|0)<<16|(d[B]|0)<<24|(d[B+2|0]|0)<<8|(d[B+3|0]|0);y=C+1|0;if((y|0)<(c[p>>2]|0)){B=x;C=y}else{t=x;break}}break};default:{t=k}}}while(0);if((c[q>>2]|0)!=7){m=t;break}c[s>>2]=(c[n+(c[g+(l*24|0)+4>>2]|0)>>2]|0)+(c[n+(c[i>>2]|0)>>2]|0);m=t}}while(0);o=l+1|0;if((o|0)<(h|0)){k=m;l=o}else{break}}return}function T2(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0;b=c[199384]|0;if(b>>>0>=32){return}e=c[199386]|0;f=c[42462]|0;g=c[42464]|0;h=c[42466]|0;i=c[199380]|0;j=b;b=a[169832]|0;k=a[169840]|0;while(1){l=(c[274486]|0)-1048576|0;m=c[263192]|0;n=0;o=h;p=g;q=f;r=b;s=k;while(1){t=(1<<(n&3))+255|0;u=(t&(o^p))+t|0;t=(n>>>0>3?u+15|0:u)&255;u=797712+(t<<1)|0;v=d[u]|0;w=d[15104+(v<<2)|0]|0;x=797713+(t<<1)|0;t=a[x]|0;y=t&255;z=q>>>15&1^y;A=r&255;B=s&255;C=B-w|0;if(A>>>0>C>>>0){D=w-1|0;w=A+D-B&255;a[169832]=w;B=D&255;a[169840]=B;E=1;F=(q<<1|1)-z|0;G=B;H=w}else{w=C&255;a[169840]=w;E=0;F=z+(q<<1)|0;G=w;H=r}if((G&255)<127){w=0;z=G;C=H;B=a[169880]|0;D=c[42468]|0;while(1){I=w+1|0;J=z<<1|1;K=C<<1|(B&255)>>>7;A=B<<1;L=D-1|0;if((L|0)==0){M=c[199376]|0;if(M>>>0<l>>>0){N=M}else{O=M;do{O=O-l|0;}while(O>>>0>=l>>>0);c[199376]=O;N=O}c[199376]=N+1;P=a[m+(N+1048576)|0]|0;Q=8}else{P=A;Q=L}if((J&255)<127){w=I;z=J;C=K;B=P;D=Q}else{break}}a[169840]=J;a[169832]=K;a[169880]=P;c[42468]=Q;R=I;S=K;T=J}else{R=0;S=H;T=G}U=E|p<<1;V=y+(o<<1)|0;if(((d[15107+(v<<2)|0]|0)&E|0)!=0){a[x]=t^1}do{if((E|0)==0){if((R|0)==0){break}a[u]=a[15106+(v<<2)|0]|0}else{a[u]=a[15105+(v<<2)|0]|0}}while(0);v=n+1|0;if(v>>>0<8){n=v;o=V;p=U;q=F;r=S;s=T}else{break}}a[e+i|0]=F&255;W=i+1&63;X=j+1|0;if(X>>>0<32){f=F;g=U;h=V;i=W;j=X;b=S;k=T}else{break}}c[42462]=F;c[42464]=U;c[42466]=V;c[199380]=W;c[199384]=X;return}function T3(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0;b=c[199384]|0;if(b>>>0>=32){return}e=c[199386]|0;f=a[169752]|0;g=c[42450]|0;h=c[42452]|0;i=c[42448]|0;j=c[199380]|0;k=b;while(1){b=0;l=i;m=f;n=g;o=h;while(1){p=l>>>2&3;q=l>>>14&3;r=l>>>16&3;do{if((p|0)==(q|0)){s=(p|0)!=(r|0)|0}else{if((q|0)==(r|0)){s=2;break}s=4-((p|0)==(r|0))|0}}while(0);t=0;while(1){if(t>>>0>=4){u=t;v=5416;break}if((c[169776+(t<<2)>>2]|0)==(p|0)){v=5415;break}else{t=t+1|0}}if((v|0)==5415){v=0;if((t|0)!=0){u=t;v=5416}}if((v|0)==5416){while(1){v=0;w=u-1|0;c[169776+(u<<2)>>2]=c[169776+(w<<2)>>2];if((w|0)==0){break}else{u=w;v=5416}}}c[42444]=p;c[42440]=c[42444];c[42441]=c[42445];c[42442]=c[42446];c[42443]=c[42447];t=0;while(1){if(t>>>0>=4){x=t;v=5421;break}if((c[169760+(t<<2)>>2]|0)==(r|0)){v=5420;break}else{t=t+1|0}}if((v|0)==5420){v=0;if((t|0)!=0){x=t;v=5421}}if((v|0)==5421){while(1){v=0;w=x-1|0;c[169760+(x<<2)>>2]=c[169760+(w<<2)>>2];if((w|0)==0){break}else{x=w;v=5421}}}c[42440]=r;t=0;while(1){if(t>>>0>=4){y=t;v=5426;break}if((c[169760+(t<<2)>>2]|0)==(q|0)){v=5425;break}else{t=t+1|0}}if((v|0)==5425){v=0;if((t|0)!=0){y=t;v=5426}}if((v|0)==5426){while(1){v=0;r=y-1|0;c[169760+(y<<2)>>2]=c[169760+(r<<2)>>2];if((r|0)==0){break}else{y=r;v=5426}}}c[42440]=q;t=0;while(1){if(t>>>0>=4){z=t;v=5431;break}if((c[169760+(t<<2)>>2]|0)==(p|0)){v=5430;break}else{t=t+1|0}}if((v|0)==5430){v=0;if((t|0)!=0){z=t;v=5431}}if((v|0)==5431){while(1){v=0;q=z-1|0;c[169760+(z<<2)>>2]=c[169760+(q<<2)>>2];if((q|0)==0){break}else{z=q;v=5431}}}c[42440]=p;t=(c[274486]|0)-1048576|0;q=c[263192]|0;r=1;w=s;A=m;B=a[169744]|0;C=n;D=o;while(1){E=797712+(w<<1)|0;F=d[E]|0;G=d[15104+(F<<2)|0]|0;H=B&255;I=A&255;J=I-G|0;if(H>>>0>J>>>0){K=G-1|0;G=H-I+K&255;a[169744]=G;L=1;M=K&255;N=G}else{L=0;M=J&255;N=B}if((M&255)<127){J=M;G=1;K=N;I=a[169824]|0;H=c[42454]|0;while(1){O=J<<1|1;P=K<<1|(I&255)>>>7;Q=I<<1;R=H-1|0;if((R|0)==0){S=c[199376]|0;if(S>>>0<t>>>0){T=S}else{U=S;do{U=U-t|0;}while(U>>>0>=t>>>0);c[199376]=U;T=U}c[199376]=T+1;V=a[q+(T+1048576)|0]|0;W=8}else{V=Q;W=R}if((O&255)<127){J=O;G=G+1|0;K=P;I=V;H=W}else{break}}a[169744]=P;a[169824]=V;c[42454]=W;X=G;Y=O;Z=P}else{X=0;Y=M;Z=N}_=C<<1|L;H=797713+(w<<1)|0;I=a[H]|0;$=(I&255)+(D<<1)|0;if(((d[15107+(F<<2)|0]|0)&L|0)!=0){a[H]=I^1}do{if((L|0)==0){if((X|0)==0){break}a[E]=a[15106+(F<<2)|0]|0}else{a[E]=a[15105+(F<<2)|0]|0}}while(0);aa=$^_;if(r>>>0>=2){break}r=r+1|0;w=(w<<1)+5+(aa&1)|0;A=Y;B=Z;C=_;D=$}ab=(c[169760+((aa&3)<<2)>>2]|0)+(l<<2)|0;D=b+1|0;if(D>>>0<8){b=D;l=ab;m=Y;n=_;o=$}else{break}}o=(c[242744+((ab>>>8&255)<<2)>>2]|0)+(c[243768+((ab&255)<<2)>>2]|0)|0;a[e+j|0]=o>>>8&255;a[e+(j+1&63)|0]=o&255;ac=j+2&63;ad=k+2|0;if(ad>>>0<32){f=Y;g=_;h=$;i=ab;j=ac;k=ad}else{break}}a[169752]=Y;c[42450]=_;c[42452]=$;c[42448]=ab;c[199380]=ac;c[199384]=ad;return}function T4(){var b=0,d=0;a[237800]=0;a[237792]=0;a[237784]=0;a[237776]=0;a[237768]=0;a[237760]=0;a[237752]=0;a[237744]=0;a[237736]=0;a[237728]=0;a[237720]=0;a[237712]=0;c[199378]=3;c[199382]=0;c[199380]=0;c[199384]=0;a[237704]=0;a[237696]=0;a[237688]=0;a[237680]=0;a[237664]=0;a[237648]=0;a[237640]=0;a[237632]=0;a[237624]=0;a[237672]=0;a[237656]=0;a[237616]=0;a[237608]=0;a[237600]=0;a[237592]=0;a[237584]=0;a[237576]=0;a[237568]=0;a[237560]=0;a[237552]=0;a[237544]=0;a[237536]=0;a[237528]=0;a[237520]=0;a[237512]=0;a[237504]=0;a[237496]=0;a[237488]=0;a[237480]=0;b=(c[274486]|0)-1048576|0;d=0;while(1){if(d>>>0<b>>>0){break}else{d=d-b|0}}c[198898]=d+1048576;a[237472]=1;d=1048576;while(1){if(d>>>0<b>>>0){break}else{d=d-b|0}}c[198894]=d+1048576;a[237464]=2;d=2097152;while(1){if(d>>>0<b>>>0){break}else{d=d-b|0}}c[198890]=d+1048576;a[237456]=0;a[237448]=0;a[237440]=0;a[237432]=0;if((a[799127]|0)==0){return}c[58912]=0;c[58914]=3;c[58920]=0;return}function T5(){var b=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0;b=c[199384]|0;if(b>>>0>=32){return}e=c[199386]|0;f=a[169536]|0;g=c[42422]|0;h=c[42424]|0;i=c[42418]|0;j=c[42420]|0;k=c[199380]|0;l=b;b=a[169720]|0;while(1){m=0;n=j;o=i;p=f;q=g;r=h;while(1){s=n&15;t=n>>>28;u=o&15;do{if((s|0)==(t|0)){v=(s|0)!=(u|0)|0}else{if((t|0)==(u|0)){v=2;break}v=4-((s|0)==(u|0))|0}}while(0);w=0;while(1){if(w>>>0>=16){x=w;y=5480;break}if((c[169608+(w<<2)>>2]|0)==(s|0)){y=5479;break}else{w=w+1|0}}if((y|0)==5479){y=0;if((w|0)!=0){x=w;y=5480}}if((y|0)==5480){while(1){y=0;z=x-1|0;c[169608+(x<<2)>>2]=c[169608+(z<<2)>>2];if((z|0)==0){break}else{x=z;y=5480}}}c[42402]=s;X5(169544,169608,64)|0;w=0;while(1){if(w>>>0>=16){A=w;y=5485;break}if((c[169544+(w<<2)>>2]|0)==(u|0)){y=5484;break}else{w=w+1|0}}if((y|0)==5484){y=0;if((w|0)!=0){A=w;y=5485}}if((y|0)==5485){while(1){y=0;z=A-1|0;c[169544+(A<<2)>>2]=c[169544+(z<<2)>>2];if((z|0)==0){break}else{A=z;y=5485}}}c[42386]=u;w=0;while(1){if(w>>>0>=16){B=w;y=5490;break}if((c[169544+(w<<2)>>2]|0)==(t|0)){y=5489;break}else{w=w+1|0}}if((y|0)==5489){y=0;if((w|0)!=0){B=w;y=5490}}if((y|0)==5490){while(1){y=0;u=B-1|0;c[169544+(B<<2)>>2]=c[169544+(u<<2)>>2];if((u|0)==0){break}else{B=u;y=5490}}}c[42386]=t;w=0;while(1){if(w>>>0>=16){C=w;y=5495;break}if((c[169544+(w<<2)>>2]|0)==(s|0)){y=5494;break}else{w=w+1|0}}if((y|0)==5494){y=0;if((w|0)!=0){C=w;y=5495}}if((y|0)==5495){while(1){y=0;u=C-1|0;c[169544+(C<<2)>>2]=c[169544+(u<<2)>>2];if((u|0)==0){break}else{C=u;y=5495}}}c[42386]=s;w=(c[274486]|0)-1048576|0;u=c[263192]|0;z=0;D=1;E=p;F=a[169528]|0;G=q;H=r;while(1){I=797712+(z<<1)|0;J=d[I]|0;K=d[15104+(J<<2)|0]|0;L=F&255;M=E&255;N=M-K|0;if(L>>>0>N>>>0){O=K-1|0;K=L-M+O&255;a[169528]=K;P=1;Q=O&255;R=K}else{P=0;Q=N&255;R=F}if((Q&255)<127){N=Q;K=1;O=R;M=a[169712]|0;L=c[42426]|0;while(1){S=N<<1|1;T=O<<1|(M&255)>>>7;U=M<<1;V=L-1|0;if((V|0)==0){W=c[199376]|0;if(W>>>0<w>>>0){X=W}else{Y=W;do{Y=Y-w|0;}while(Y>>>0>=w>>>0);c[199376]=Y;X=Y}c[199376]=X+1;Z=a[u+(X+1048576)|0]|0;_=8}else{Z=U;_=V}if((S&255)<127){N=S;K=K+1|0;O=T;M=Z;L=_}else{break}}a[169528]=T;a[169712]=Z;c[42426]=_;$=K;aa=S;ab=T}else{$=0;aa=Q;ab=R}ac=G<<1|P;L=797713+(z<<1)|0;M=a[L]|0;O=M&255;ad=(H<<1)+O|0;if(((d[15107+(J<<2)|0]|0)&P|0)!=0){a[L]=M^1}do{if((P|0)==0){if(($|0)==0){break}a[I]=a[15106+(J<<2)|0]|0}else{a[I]=a[15105+(J<<2)|0]|0}}while(0);if(D>>>0>=4){break}z=(d[(O^P)+(7640+(z<<1))|0]|0)+((z|0)==1?v:0)|0;D=D+1|0;E=aa;F=ab;G=ac;H=ad}ae=t|o<<4;af=(c[169544+(((ad^ac)&15)<<2)>>2]|0)+(n<<4)|0;H=m+1|0;if(H>>>0<8){m=H;n=af;o=ae;p=aa;q=ac;r=ad}else{break}}r=(c[240696+((af>>>8&255)<<2)>>2]|0)+(c[241720+((af&255)<<2)>>2]|0)+(c[239672+((af>>>16&255)<<2)>>2]|0)+(c[238648+(af>>>24<<2)>>2]|0)|0;a[e+k|0]=r>>>24&255;a[e+(k+1&63)|0]=r>>>16&255;q=k+2&63;p=l+2|0;a[169728+(b&255)|0]=r>>>8&255;o=b+2&255;a[169728+(b+1&255)|0]=r&255;if(o<<24>>24==16){r=0;n=q;m=p;while(1){a[e+n|0]=a[169728+r|0]|0;H=n+1&63;G=m+1|0;F=r+1|0;if(F>>>0<16){r=F;n=H;m=G}else{ag=G;ah=H;ai=0;break}}}else{ag=p;ah=q;ai=o}if(ag>>>0<32){f=aa;g=ac;h=ad;i=ae;j=af;k=ah;l=ag;b=ai}else{break}}a[169536]=aa;c[42422]=ac;c[42424]=ad;c[42418]=ae;c[42420]=af;c[199380]=ah;c[199384]=ag;a[169720]=ai;return}function T6(){var a=0,b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;c[199386]=XY(64)|0;c[199378]=3;c[199382]=0;c[199380]=0;c[199384]=0;a=0;do{b=a>>>7;d=b&1;e=a>>>6&1;f=a>>>5&1;g=a>>>4&1;h=a>>>3&1;i=a>>>2&1;j=a>>>1&1;k=j<<12;l=a&1;m=l<<4;c[242744+(a<<2)>>2]=(d<<15|e<<7|f<<14|g<<6|h<<13|i<<5)+(k|m);n=j<<8;c[243768+(a<<2)>>2]=(d<<11|e<<3|f<<10|g<<2|h<<9|i<<1)+(n|l);c[238648+(a<<2)>>2]=(e<<23|b<<31|f<<15|g<<7|h<<30|i<<22|j<<14)+(l<<6);c[239672+(a<<2)>>2]=(d<<29|e<<21|f<<13|g<<5|h<<28|i<<20|k)+m;c[240696+(a<<2)>>2]=(d<<27|e<<19|f<<11|g<<3|h<<26|i<<18|j<<10)+(l<<2);c[241720+(a<<2)>>2]=(d<<25|e<<17|f<<9|g<<1|h<<24|i<<16|n)+l;a=a+1|0;}while(a>>>0<256);return}function T7(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;if((a[1044434]|0)==0){g=0}else{g=(d[1044432]|0)>1|0}if((a[1044435]|0)==0){h=0}else{h=(d[1044432]|0)>1|0}i=f<<24>>24==0;f=a[1106149]|0;do{if(e<<24>>24==0){if((b-5|0)>>>0<2){j=1;break}j=(a[1106151]|0)!=0|0}else{j=0}}while(0);do{if((a[1106152]|0)==0){c[277224]=8;k=160936;l=161640;m=161096;n=161800;o=(h|0)!=0?161256:161448;p=(g|0)!=0?161352:161544}else{b=i&f<<24>>24!=0;e=(g|0)!=0;if(j<<24>>24==0){q=e?161320:161512;r=(h|0)!=0?161224:161416;if(b){c[277224]=4;k=160968;l=161672;m=161128;n=161768;o=r;p=q;break}else{c[277224]=8;k=160904;l=161608;m=161064;n=161768;o=r;p=q;break}}else{q=e?161384:161576;e=(h|0)!=0?161288:161480;if(b){c[277224]=4;k=161e3;l=161704;m=161160;n=161832;o=e;p=q;break}else{c[277224]=8;k=161032;l=161736;m=161192;n=161832;o=e;p=q;break}}}}while(0);c[281364]=c[k>>2];c[281366]=c[l>>2];c[281368]=c[m>>2];c[281362]=c[n>>2];c[281370]=c[p>>2];c[281372]=c[o>>2];do{if((a[807394]|0)==0){s=0}else{h=c[263195]|0;j=d[h+8497|0]|0;g=(j&128|0)!=0?4:1;if((j&64|0)==0){s=g;break}s=(a[h+8496|0]&2)==0?g+1|0:g|2}}while(0);c[281363]=c[k+(s<<2)>>2];c[281365]=c[l+(s<<2)>>2];c[281367]=c[m+(s<<2)>>2];c[281361]=c[n+(s<<2)>>2];c[281369]=c[p+(s<<2)>>2];c[281371]=c[o+(s<<2)>>2];return}function T8(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;e=8;f=(c[263194]|0)+d|0;d=b;b=0;while(1){g=a[f]|0;if(g<<24>>24==0){h=0;i=0}else{j=g&255;h=c[238048+((j&15)<<2)>>2]|0;i=c[238048+(j>>>4<<2)>>2]|0}j=a[f+1|0]|0;if(j<<24>>24==0){k=h;l=i}else{g=j&255;k=c[238112+((g&15)<<2)>>2]|h;l=c[238112+(g>>>4<<2)>>2]|i}g=a[f+16|0]|0;if(g<<24>>24==0){m=k;n=l}else{j=g&255;m=c[238176+((j&15)<<2)>>2]|k;n=c[238176+(j>>>4<<2)>>2]|l}j=a[f+17|0]|0;if(j<<24>>24==0){o=m;p=n}else{g=j&255;o=c[238240+((g&15)<<2)>>2]|m;p=c[238240+(g>>>4<<2)>>2]|n}c[d>>2]=p;c[d+4>>2]=o;q=p|b|o;g=e-1&255;if(g<<24>>24==0){break}else{e=g;f=f+2|0;d=d+8|0;b=q}}return((q|0)!=0?1:2)|0}function T9(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0;e=b;b=0;f=8;g=(c[263194]|0)+d|0;while(1){d=a[g]|0;if(d<<24>>24==0){h=0;i=0}else{j=d&255;h=c[238048+((j&15)<<2)>>2]|0;i=c[238048+(j>>>4<<2)>>2]|0}j=a[g+1|0]|0;if(j<<24>>24==0){k=h;l=i}else{d=j&255;k=c[238112+((d&15)<<2)>>2]|h;l=c[238112+(d>>>4<<2)>>2]|i}c[e>>2]=l;c[e+4>>2]=k;m=l|b|k;d=f-1&255;if(d<<24>>24==0){break}else{e=e+8|0;b=m;f=d;g=g+2|0}}return((m|0)!=0?1:2)|0}function Ua(b){b=b|0;var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;L6801:do{if((a[799127]|0)==0&(b&65535)>18495){e=a[1044496]|0}else{switch(b&65535|0){case 18464:{e=a[237616]|0;break L6801;break};case 18465:{e=a[237608]|0;break L6801;break};case 18466:{e=a[237600]|0;break L6801;break};case 18467:{e=a[237592]|0;break L6801;break};case 18468:{e=a[237584]|0;break L6801;break};case 18469:{e=a[237576]|0;break L6801;break};case 18435:{e=a[237784]|0;break L6801;break};case 18449:{e=a[237704]|0;break L6801;break};case 18450:{e=a[237696]|0;break L6801;break};case 18451:{e=a[237688]|0;break L6801;break};case 18452:{e=a[237680]|0;break L6801;break};case 18454:{e=a[237648]|0;break L6801;break};case 18455:{e=a[237640]|0;break L6801;break};case 18456:{e=a[237632]|0;break L6801;break};case 18458:{if((a[237624]|0)!=7){e=0;break L6801}f=d[237664]<<8|d[237680];g=a[237632]|0;if((g&8)==0){h=f}else{h=f<<16>>16}f=h+(d[237696]<<8|d[237704]|d[237688]<<16)|0;i=(c[274486]|0)-1048576|0;j=f;while(1){if(j>>>0<i>>>0){break}else{j=j-i|0}}i=a[(c[263192]|0)+(j+1048576)|0]|0;k=g&255;if((k&96|0)!=96){e=i;break L6801}if((k&16|0)==0){a[237704]=f&255;a[237696]=f>>>8&255;a[237688]=f>>>16&255;e=i;break L6801}else{a[237680]=h<<1&255;a[237664]=h>>>7&255;e=i;break L6801}break};case 18444:{i=a[237712]|0;a[237712]=i&127;e=i;break L6801;break};case 18453:{e=a[237664]|0;break L6801;break};case 18436:{e=a[237776]|0;break L6801;break};case 18448:{if((a[237624]|0)!=7){e=0;break L6801}i=d[237696]<<8|d[237704]|d[237688]<<16;k=d[237664]<<8|d[237680];l=a[237632]|0;if((l&8)==0){m=k}else{m=k<<16>>16}if((l&2)==0){n=i}else{k=m+1|0;a[237680]=k&255;a[237664]=k>>>8&255;n=m+i|0}k=(c[274486]|0)-1048576|0;o=n;while(1){if(o>>>0<k>>>0){break}else{o=o-k|0}}k=a[(c[263192]|0)+(o+1048576)|0]|0;f=l&255;if((f&2|0)!=0){e=k;break L6801}if((f&1|0)==0){p=1}else{p=d[237640]<<8|d[237648]}if((l&4)==0){q=p}else{q=p<<16>>16}if((l&16)==0){f=q+i|0;a[237704]=f&255;a[237696]=f>>>8&255;a[237688]=f>>>16&255;e=k;break L6801}else{f=q+m|0;a[237680]=f&255;a[237664]=f>>>8&255;e=k;break L6801}break};case 18471:{e=a[237560]|0;break L6801;break};case 18472:{e=a[237552]|0;break L6801;break};case 18473:{e=a[237544]|0;break L6801;break};case 18474:{e=a[237536]|0;break L6801;break};case 18475:{e=a[237528]|0;break L6801;break};case 18476:{e=a[237520]|0;break L6801;break};case 18477:{e=a[237512]|0;break L6801;break};case 18478:{e=a[237504]|0;break L6801;break};case 18498:{k=a[237432]|0;a[237432]=k&127;e=k;break L6801;break};case 18433:{e=a[237800]|0;break L6801;break};case 18434:{e=a[237792]|0;break L6801;break};case 18479:{k=a[237496]|0;a[237496]=k&127;e=k;break L6801;break};case 18480:{e=a[237488]|0;break L6801;break};case 18481:{e=a[237480]|0;break L6801;break};case 18482:{e=a[237472]|0;break L6801;break};case 18483:{e=a[237464]|0;break L6801;break};case 18484:{e=a[237456]|0;break L6801;break};case 18496:{e=a[237448]|0;break L6801;break};case 18497:{if((c[58912]|0)>>>0<2){e=0;break L6801}a[237432]=-128;k=c[58920]|0;f=a[1041680+k|0]|0;c[58920]=k+1&15;e=f;break L6801;break};case 18470:{e=a[237568]|0;break L6801;break};case 18441:{e=a[237736]|0;break L6801;break};case 18440:{e=a[237744]|0;break L6801;break};case 18443:{e=a[237720]|0;break L6801;break};case 18438:{e=a[237760]|0;break L6801;break};case 18439:{e=a[237752]|0;break L6801;break};case 18442:{e=a[237728]|0;break L6801;break};case 18437:{e=a[237768]|0;break L6801;break};case 18432:{f=(d[237728]<<8|d[237736])-1&65535;a[237736]=f&255;a[237728]=(f&65535)>>>8&255;do{if((c[199384]|0)==0){f=c[199378]|0;if((f|0)==0){T2();break}else if((f|0)==1){T3();break}else if((f|0)==2){T5();break}else{e=0;break L6801}}}while(0);i=c[199382]|0;l=a[(c[199386]|0)+i|0]|0;c[199382]=i+1&63;c[199384]=(c[199384]|0)-1;e=l;break L6801;break};default:{e=a[1044496]|0;break L6801}}}}while(0);return e|0}function Ub(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;e=(c[263194]|0)+d|0;d=8;f=b;b=0;while(1){g=a[e]|0;if(g<<24>>24==0){h=0;i=0}else{j=g&255;h=c[238048+((j&15)<<2)>>2]|0;i=c[238048+(j>>>4<<2)>>2]|0}j=a[e+1|0]|0;if(j<<24>>24==0){k=h;l=i}else{g=j&255;k=c[238112+((g&15)<<2)>>2]|h;l=c[238112+(g>>>4<<2)>>2]|i}g=a[e+16|0]|0;if(g<<24>>24==0){m=k;n=l}else{j=g&255;m=c[238176+((j&15)<<2)>>2]|k;n=c[238176+(j>>>4<<2)>>2]|l}j=a[e+17|0]|0;if(j<<24>>24==0){o=m;p=n}else{g=j&255;o=c[238240+((g&15)<<2)>>2]|m;p=c[238240+(g>>>4<<2)>>2]|n}g=a[e+32|0]|0;if(g<<24>>24==0){q=o;r=p}else{j=g&255;q=c[238304+((j&15)<<2)>>2]|o;r=c[238304+(j>>>4<<2)>>2]|p}j=a[e+33|0]|0;if(j<<24>>24==0){s=q;t=r}else{g=j&255;s=c[238368+((g&15)<<2)>>2]|q;t=c[238368+(g>>>4<<2)>>2]|r}g=a[e+48|0]|0;if(g<<24>>24==0){u=s;v=t}else{j=g&255;u=c[238432+((j&15)<<2)>>2]|s;v=c[238432+(j>>>4<<2)>>2]|t}j=a[e+49|0]|0;if(j<<24>>24==0){w=u;x=v}else{g=j&255;w=c[238496+((g&15)<<2)>>2]|u;x=c[238496+(g>>>4<<2)>>2]|v}c[f>>2]=x;c[f+4>>2]=w;y=x|b|w;g=d-1&255;if(g<<24>>24==0){break}else{e=e+2|0;d=g;f=f+8|0;b=y}}return((y|0)!=0?1:2)|0}function Uc(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=c[263194]|0;h=g+e|0;i=g+(((f|0)==1023?-32736:32)+e)|0;e=8;f=b;b=0;while(1){g=a[509928+(d[h]|0)|0]|0;if(g<<24>>24==0){j=0}else{j=c[238048+((g&255)<<2)>>2]|0}g=a[509928+(d[i]|0)|0]|0;if(g<<24>>24==0){k=0}else{k=c[238048+((g&255)<<2)>>2]|0}g=a[509928+(d[h+1|0]|0)|0]|0;if(g<<24>>24==0){l=j}else{l=c[238112+((g&255)<<2)>>2]|j}g=a[509928+(d[i+1|0]|0)|0]|0;if(g<<24>>24==0){m=k}else{m=c[238112+((g&255)<<2)>>2]|k}g=a[509928+(d[h+16|0]|0)|0]|0;if(g<<24>>24==0){n=l}else{n=c[238176+((g&255)<<2)>>2]|l}g=a[509928+(d[i+16|0]|0)|0]|0;if(g<<24>>24==0){o=m}else{o=c[238176+((g&255)<<2)>>2]|m}g=a[509928+(d[h+17|0]|0)|0]|0;if(g<<24>>24==0){p=n}else{p=c[238240+((g&255)<<2)>>2]|n}g=a[509928+(d[i+17|0]|0)|0]|0;if(g<<24>>24==0){q=o}else{q=c[238240+((g&255)<<2)>>2]|o}c[f>>2]=p;c[f+4>>2]=q;r=p|b|q;g=e-1&255;if(g<<24>>24==0){break}else{h=h+2|0;i=i+2|0;e=g;f=f+8|0;b=r}}return((r|0)!=0?1:2)|0}function Ud(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;g=c[263194]|0;h=g+e|0;i=g+(((f|0)==1023?-32736:32)+e)|0;e=8;f=b;b=0;while(1){g=a[509672+(d[h]|0)|0]|0;if(g<<24>>24==0){j=0}else{j=c[238048+((g&255)<<2)>>2]|0}g=a[509672+(d[i]|0)|0]|0;if(g<<24>>24==0){k=0}else{k=c[238048+((g&255)<<2)>>2]|0}g=a[509672+(d[h+1|0]|0)|0]|0;if(g<<24>>24==0){l=j}else{l=c[238112+((g&255)<<2)>>2]|j}g=a[509672+(d[i+1|0]|0)|0]|0;if(g<<24>>24==0){m=k}else{m=c[238112+((g&255)<<2)>>2]|k}g=a[509672+(d[h+16|0]|0)|0]|0;if(g<<24>>24==0){n=l}else{n=c[238176+((g&255)<<2)>>2]|l}g=a[509672+(d[i+16|0]|0)|0]|0;if(g<<24>>24==0){o=m}else{o=c[238176+((g&255)<<2)>>2]|m}g=a[509672+(d[h+17|0]|0)|0]|0;if(g<<24>>24==0){p=n}else{p=c[238240+((g&255)<<2)>>2]|n}g=a[509672+(d[i+17|0]|0)|0]|0;if(g<<24>>24==0){q=o}else{q=c[238240+((g&255)<<2)>>2]|o}c[f>>2]=p;c[f+4>>2]=q;r=p|b|q;g=e-1&255;if(g<<24>>24==0){break}else{h=h+2|0;i=i+2|0;e=g;f=f+8|0;b=r}}return((r|0)!=0?1:2)|0}function Ue(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=c[263194]|0;h=g+e|0;i=g+(((f|0)==1023?-16368:16)+e)|0;e=8;f=b;b=0;while(1){g=a[509928+(d[h]|0)|0]|0;if(g<<24>>24==0){j=0}else{j=c[238048+((g&255)<<2)>>2]|0}g=a[509928+(d[i]|0)|0]|0;if(g<<24>>24==0){k=0}else{k=c[238048+((g&255)<<2)>>2]|0}g=a[509928+(d[h+1|0]|0)|0]|0;if(g<<24>>24==0){l=j}else{l=c[238112+((g&255)<<2)>>2]|j}g=a[509928+(d[i+1|0]|0)|0]|0;if(g<<24>>24==0){m=k}else{m=c[238112+((g&255)<<2)>>2]|k}c[f>>2]=l;c[f+4>>2]=m;n=l|b|m;g=e-1&255;if(g<<24>>24==0){break}else{h=h+2|0;i=i+2|0;e=g;f=f+8|0;b=n}}return((n|0)!=0?1:2)|0}function Uf(b,e,f){b=b|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;g=c[263194]|0;h=g+e|0;i=g+(((f|0)==1023?-16368:16)+e)|0;e=8;f=b;b=0;while(1){g=a[509672+(d[h]|0)|0]|0;if(g<<24>>24==0){j=0}else{j=c[238048+((g&255)<<2)>>2]|0}g=a[509672+(d[i]|0)|0]|0;if(g<<24>>24==0){k=0}else{k=c[238048+((g&255)<<2)>>2]|0}g=a[509672+(d[h+1|0]|0)|0]|0;if(g<<24>>24==0){l=j}else{l=c[238112+((g&255)<<2)>>2]|j}g=a[509672+(d[i+1|0]|0)|0]|0;if(g<<24>>24==0){m=k}else{m=c[238112+((g&255)<<2)>>2]|k}c[f>>2]=l;c[f+4>>2]=m;n=l|b|m;g=e-1&255;if(g<<24>>24==0){break}else{h=h+2|0;i=i+2|0;e=g;f=f+8|0;b=n}}return((n|0)!=0?1:2)|0}function Ug(e,f,g,h,i,j){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;k=e&1023;l=c[348606]|0;m=(k<<l)+(c[348604]|0)|0;if((e&256|0)==0){n=m}else{n=(c[348602]|0)+m|0}m=n&65535;n=m>>>(l>>>0);l=(e&16384|0)!=0;o=n<<6;do{if(l){p=(c[348622]|0)+o|0;if((a[(c[348618]|0)+n|0]|0)!=0){q=p;break}r=fi[c[348636]&63](p,m,k)|0;a[(c[348618]|0)+n|0]=r;q=p}else{p=(c[348624]|0)+o|0;if((a[(c[348620]|0)+n|0]|0)!=0){q=p;break}r=fi[c[348638]&63](p,m,k)|0;a[(c[348620]|0)+n|0]=r;q=p}}while(0);if((a[(c[348620]|0)+n|0]|0)==2){return}if((a[1394464]|0)==0){s=1106168+((e>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){n=d[1044485]|0;c[276541]=7080+(n<<5);k=0;do{m=k<<1&2;o=k&2;p=k&4;r=0;do{b[1125528+(k<<9)+(r<<1)>>1]=d[(r>>>1&28|o)+(7080+(n<<5))|0]<<6|d[(r<<2&28|m)+(7080+(n<<5))|0]<<11|d[(r>>>3&24|p)+(7080+(n<<5))|0];r=r+1|0;}while(r>>>0<256);k=k+1|0;}while(k>>>0<8);a[1106089]=0}s=1125528+((e>>>10&7)<<9)|0}c[277226]=s;c[277225]=(a[1108928]|0)!=0?1393712:s;s=l?7-h|0:h;if((e&32768|0)==0){t=s+g|0}else{t=56-g+s|0}s=a[q+t|0]|0;if(!(s<<24>>24!=0&(j|0)>0)){return}t=i-1|0;i=s&255;if((t|0)>-1){u=j;v=f}else{return}while(1){f=t;do{j=(f<<1)+v|0;if((d[1108908]|0)>(d[(c[277219]|0)+j|0]|0)){s=b[(c[277225]|0)+(i<<1)>>1]|0;q=j+1|0;b[(c[277218]|0)+(q<<1)>>1]=s;b[(c[277218]|0)+(j<<1)>>1]=s;s=a[1108909]|0;a[(c[277219]|0)+q|0]=s;a[(c[277219]|0)+j|0]=s}f=f-1|0;}while((f|0)>-1);f=u-1|0;if((f|0)>0){u=f;v=(c[277223]|0)+v|0}else{break}}return}function Uh(f,g,h,i,j,k){f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;l=f&1023;m=c[348606]|0;n=(l<<m)+(c[348604]|0)|0;if((f&256|0)==0){o=n}else{o=(c[348602]|0)+n|0}n=o&65535;o=n>>>(m>>>0);m=(f&16384|0)!=0;p=o<<6;do{if(m){q=(c[348622]|0)+p|0;if((a[(c[348618]|0)+o|0]|0)!=0){r=q;break}s=fi[c[348636]&63](q,n,l)|0;a[(c[348618]|0)+o|0]=s;r=q}else{q=(c[348624]|0)+p|0;if((a[(c[348620]|0)+o|0]|0)!=0){r=q;break}s=fi[c[348638]&63](q,n,l)|0;a[(c[348620]|0)+o|0]=s;r=q}}while(0);if((a[(c[348620]|0)+o|0]|0)==2){return}if((a[1394464]|0)==0){t=1106168+((f>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){o=d[1044485]|0;c[276541]=7080+(o<<5);l=0;do{n=l<<1&2;p=l&2;q=l&4;s=0;do{b[1125528+(l<<9)+(s<<1)>>1]=d[(s>>>1&28|p)+(7080+(o<<5))|0]<<6|d[(s<<2&28|n)+(7080+(o<<5))|0]<<11|d[(s>>>3&24|q)+(7080+(o<<5))|0];s=s+1|0;}while(s>>>0<256);l=l+1|0;}while(l>>>0<8);a[1106089]=0}t=1125528+((f>>>10&7)<<9)|0}c[277226]=t;c[277225]=(a[1108928]|0)!=0?1393712:t;t=m?7-i|0:i;if((f&32768|0)==0){u=t+h|0}else{u=56-h+t|0}t=a[r+u|0]|0;if(!(t<<24>>24!=0&(k|0)>0)){return}u=j-1|0;j=(u|0)>-1;r=t&255;t=k;k=g;while(1){if(j){g=u;do{h=(g<<1)+k|0;if((d[1108908]|0)>(d[(c[277219]|0)+h|0]|0)){f=e[(c[277225]|0)+(r<<1)>>1]|0;i=(a[(c[277215]|0)+h|0]&32)==0;if(i){m=c[277228]|0;v=m;w=m&-2082}else{m=e[(c[277213]|0)+(h<<1)>>1]|0;v=m;w=m&63454}if(i){x=c[277228]|0}else{x=e[(c[277213]|0)+(h<<1)>>1]|0}i=((x^f)&2081|e[(c[277220]|0)+((f&2081&v)+((w+(f&63454)|0)>>>1)<<1)>>1])&65535;f=h+1|0;b[(c[277218]|0)+(f<<1)>>1]=i;b[(c[277218]|0)+(h<<1)>>1]=i;i=a[1108909]|0;a[(c[277219]|0)+f|0]=i;a[(c[277219]|0)+h|0]=i}g=g-1|0;}while((g|0)>-1)}g=t-1|0;if((g|0)>0){t=g;k=(c[277223]|0)+k|0}else{break}}return}function Ui(f,g,h,i,j,k){f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;l=f&1023;m=c[348606]|0;n=(l<<m)+(c[348604]|0)|0;if((f&256|0)==0){o=n}else{o=(c[348602]|0)+n|0}n=o&65535;o=n>>>(m>>>0);m=(f&16384|0)!=0;p=o<<6;do{if(m){q=(c[348622]|0)+p|0;if((a[(c[348618]|0)+o|0]|0)!=0){r=q;break}s=fi[c[348636]&63](q,n,l)|0;a[(c[348618]|0)+o|0]=s;r=q}else{q=(c[348624]|0)+p|0;if((a[(c[348620]|0)+o|0]|0)!=0){r=q;break}s=fi[c[348638]&63](q,n,l)|0;a[(c[348620]|0)+o|0]=s;r=q}}while(0);if((a[(c[348620]|0)+o|0]|0)==2){return}if((a[1394464]|0)==0){t=1106168+((f>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){o=d[1044485]|0;c[276541]=7080+(o<<5);l=0;do{n=l<<1&2;p=l&2;q=l&4;s=0;do{b[1125528+(l<<9)+(s<<1)>>1]=d[(s>>>1&28|p)+(7080+(o<<5))|0]<<6|d[(s<<2&28|n)+(7080+(o<<5))|0]<<11|d[(s>>>3&24|q)+(7080+(o<<5))|0];s=s+1|0;}while(s>>>0<256);l=l+1|0;}while(l>>>0<8);a[1106089]=0}t=1125528+((f>>>10&7)<<9)|0}c[277226]=t;c[277225]=(a[1108928]|0)!=0?1393712:t;t=m?7-i|0:i;if((f&32768|0)==0){u=t+h|0}else{u=56-h+t|0}t=a[r+u|0]|0;if(!(t<<24>>24!=0&(k|0)>0)){return}u=j-1|0;j=t&255;if((u|0)>-1){v=k;w=g}else{return}while(1){g=u;do{k=(g<<1)+w|0;if((d[1108908]|0)>(d[(c[277219]|0)+k|0]|0)){t=e[(c[277225]|0)+(j<<1)>>1]|0;r=c[277228]|0;h=(((t&63454)+(r&-2082)|0)>>>1)+(r&2081&t)|0;if((a[1108928]|0)==0){x=h&65535}else{x=(e[(c[277220]|0)+(h<<1)>>1]|(t^r)&2081)&65535}r=k+1|0;b[(c[277218]|0)+(r<<1)>>1]=x;b[(c[277218]|0)+(k<<1)>>1]=x;t=a[1108909]|0;a[(c[277219]|0)+r|0]=t;a[(c[277219]|0)+k|0]=t}g=g-1|0;}while((g|0)>-1);g=v-1|0;if((g|0)>0){v=g;w=(c[277223]|0)+w|0}else{break}}return}function Uj(f,g,h,i,j,k){f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;l=f&1023;m=c[348606]|0;n=(l<<m)+(c[348604]|0)|0;if((f&256|0)==0){o=n}else{o=(c[348602]|0)+n|0}n=o&65535;o=n>>>(m>>>0);m=(f&16384|0)!=0;p=o<<6;do{if(m){q=(c[348622]|0)+p|0;if((a[(c[348618]|0)+o|0]|0)!=0){r=q;break}s=fi[c[348636]&63](q,n,l)|0;a[(c[348618]|0)+o|0]=s;r=q}else{q=(c[348624]|0)+p|0;if((a[(c[348620]|0)+o|0]|0)!=0){r=q;break}s=fi[c[348638]&63](q,n,l)|0;a[(c[348620]|0)+o|0]=s;r=q}}while(0);if((a[(c[348620]|0)+o|0]|0)==2){return}if((a[1394464]|0)==0){t=1106168+((f>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){o=d[1044485]|0;c[276541]=7080+(o<<5);l=0;do{n=l<<1&2;p=l&2;q=l&4;s=0;do{b[1125528+(l<<9)+(s<<1)>>1]=d[(s>>>1&28|p)+(7080+(o<<5))|0]<<6|d[(s<<2&28|n)+(7080+(o<<5))|0]<<11|d[(s>>>3&24|q)+(7080+(o<<5))|0];s=s+1|0;}while(s>>>0<256);l=l+1|0;}while(l>>>0<8);a[1106089]=0}t=1125528+((f>>>10&7)<<9)|0}c[277226]=t;c[277225]=(a[1108928]|0)!=0?1393712:t;t=m?7-i|0:i;if((f&32768|0)==0){u=t+h|0}else{u=56-h+t|0}t=a[r+u|0]|0;if(!(t<<24>>24!=0&(k|0)>0)){return}u=j-1|0;j=(u|0)>-1;r=t&255;t=k;k=g;while(1){if(j){g=u;do{h=(g<<1)+k|0;if((d[1108908]|0)>(d[(c[277219]|0)+h|0]|0)){do{if((a[1108928]|0)==0){f=b[(c[277225]|0)+(r<<1)>>1]|0;i=f&65535;m=i&63454;if((a[(c[277215]|0)+h|0]&32)==0){l=c[277228]|0;v=(e[(c[277220]|0)+((((l&-2082)+m|0)>>>1)+(i&2081&l)<<1)>>1]|(l^i)&2081)&65535;break}else{i=b[(c[277213]|0)+(h<<1)>>1]|0;v=(((i&63454)+m|0)>>>1)+(i&f&2081)&65535;break}}else{f=e[(c[277225]|0)+(r<<1)>>1]|0;i=(a[(c[277215]|0)+h|0]&32)==0;if(i){m=c[277228]|0;w=m;x=m&-2082}else{m=e[(c[277213]|0)+(h<<1)>>1]|0;w=m;x=m&63454}if(i){y=c[277228]|0}else{y=e[(c[277213]|0)+(h<<1)>>1]|0}v=((y^f)&2081|e[(c[277220]|0)+((f&2081&w)+((x+(f&63454)|0)>>>1)<<1)>>1])&65535}}while(0);f=h+1|0;b[(c[277218]|0)+(f<<1)>>1]=v;b[(c[277218]|0)+(h<<1)>>1]=v;i=a[1108909]|0;a[(c[277219]|0)+f|0]=i;a[(c[277219]|0)+h|0]=i}g=g-1|0;}while((g|0)>-1)}g=t-1|0;if((g|0)>0){t=g;k=(c[277223]|0)+k|0}else{break}}return}function Uk(e,f,g,h,i,j){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;k=e&1023;l=c[348606]|0;m=(k<<l)+(c[348604]|0)|0;if((e&256|0)==0){n=m}else{n=(c[348602]|0)+m|0}m=n&65535;n=m>>>(l>>>0);l=(e&16384|0)!=0;o=n<<6;do{if(l){p=(c[348622]|0)+o|0;if((a[(c[348618]|0)+n|0]|0)!=0){q=p;break}r=fi[c[348636]&63](p,m,k)|0;a[(c[348618]|0)+n|0]=r;q=p}else{p=(c[348624]|0)+o|0;if((a[(c[348620]|0)+n|0]|0)!=0){q=p;break}r=fi[c[348638]&63](p,m,k)|0;a[(c[348620]|0)+n|0]=r;q=p}}while(0);if((a[(c[348620]|0)+n|0]|0)==2){return}if((a[1394464]|0)==0){s=1106168+((e>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){n=d[1044485]|0;c[276541]=7080+(n<<5);k=0;do{m=k<<1&2;o=k&2;p=k&4;r=0;do{b[1125528+(k<<9)+(r<<1)>>1]=d[(r>>>1&28|o)+(7080+(n<<5))|0]<<6|d[(r<<2&28|m)+(7080+(n<<5))|0]<<11|d[(r>>>3&24|p)+(7080+(n<<5))|0];r=r+1|0;}while(r>>>0<256);k=k+1|0;}while(k>>>0<8);a[1106089]=0}s=1125528+((e>>>10&7)<<9)|0}c[277226]=s;c[277225]=(a[1108928]|0)!=0?1393712:s;s=l?7-h|0:h;if((e&32768|0)==0){t=s+g|0}else{t=56-g+s|0}s=a[q+t|0]|0;if(!(s<<24>>24!=0&(j|0)>0)){return}t=i-1|0;i=(t|0)>-1;q=s&255;s=j;j=f;while(1){if(i){f=t;do{g=(f<<1)+j|0;if((d[1108908]|0)>(d[(c[277219]|0)+g|0]|0)){e=b[(c[277225]|0)+(q<<1)>>1]|0;if((a[(c[277215]|0)+g|0]&32)==0){u=c[277228]&65535}else{u=b[(c[277213]|0)+(g<<1)>>1]|0}h=e&-2048;l=u&-2048;k=(h&65535)>(l&65535)?h-l&65535:0;l=e&2016;h=u&2016;if((l&65535)>(h&65535)){v=(l-h&65535)+k&65535}else{v=k}k=e&31;e=u&31;if((k&65535)>(e&65535)){w=(k-e&65535)+v&65535}else{w=v}e=g+1|0;b[(c[277218]|0)+(e<<1)>>1]=w;b[(c[277218]|0)+(g<<1)>>1]=w;k=a[1108909]|0;a[(c[277219]|0)+e|0]=k;a[(c[277219]|0)+g|0]=k}f=f-1|0;}while((f|0)>-1)}f=s-1|0;if((f|0)>0){s=f;j=(c[277223]|0)+j|0}else{break}}return}function Ul(e,f,g,h,i,j){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;k=e&1023;l=c[348606]|0;m=(k<<l)+(c[348604]|0)|0;if((e&256|0)==0){n=m}else{n=(c[348602]|0)+m|0}m=n&65535;n=m>>>(l>>>0);l=(e&16384|0)!=0;o=n<<6;do{if(l){p=(c[348622]|0)+o|0;if((a[(c[348618]|0)+n|0]|0)!=0){q=p;break}r=fi[c[348636]&63](p,m,k)|0;a[(c[348618]|0)+n|0]=r;q=p}else{p=(c[348624]|0)+o|0;if((a[(c[348620]|0)+n|0]|0)!=0){q=p;break}r=fi[c[348638]&63](p,m,k)|0;a[(c[348620]|0)+n|0]=r;q=p}}while(0);if((a[(c[348620]|0)+n|0]|0)==2){return}if((a[1394464]|0)==0){s=1106168+((e>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){n=d[1044485]|0;c[276541]=7080+(n<<5);k=0;do{m=k<<1&2;o=k&2;p=k&4;r=0;do{b[1125528+(k<<9)+(r<<1)>>1]=d[(r>>>1&28|o)+(7080+(n<<5))|0]<<6|d[(r<<2&28|m)+(7080+(n<<5))|0]<<11|d[(r>>>3&24|p)+(7080+(n<<5))|0];r=r+1|0;}while(r>>>0<256);k=k+1|0;}while(k>>>0<8);a[1106089]=0}s=1125528+((e>>>10&7)<<9)|0}c[277226]=s;c[277225]=(a[1108928]|0)!=0?1393712:s;s=l?7-h|0:h;if((e&32768|0)==0){t=s+g|0}else{t=56-g+s|0}s=a[q+t|0]|0;if(!(s<<24>>24!=0&(j|0)>0)){return}t=i-1|0;i=(t|0)>-1;q=s&255;s=j;j=f;while(1){if(i){f=t;do{g=(f<<1)+j|0;if((d[1108908]|0)>(d[(c[277219]|0)+g|0]|0)){e=b[(c[277225]|0)+(q<<1)>>1]|0;do{if((a[1108928]|0)==0){u=b[(c[277221]|0)+(((e&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{h=c[277228]&65535;l=e&-2048;k=h&-2048;n=(l&65535)>(k&65535)?l-k&65535:0;k=e&2016;l=h&2016;if((k&65535)>(l&65535)){v=(k-l&65535)+n&65535}else{v=n}n=e&31;l=h&31;if((n&65535)<=(l&65535)){u=v;break}u=(n-l&65535)+v&65535}}while(0);e=g+1|0;b[(c[277218]|0)+(e<<1)>>1]=u;b[(c[277218]|0)+(g<<1)>>1]=u;l=a[1108909]|0;a[(c[277219]|0)+e|0]=l;a[(c[277219]|0)+g|0]=l}f=f-1|0;}while((f|0)>-1)}f=s-1|0;if((f|0)>0){s=f;j=(c[277223]|0)+j|0}else{break}}return}function Um(e,f,g,h,i,j){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;k=e&1023;l=c[348606]|0;m=(k<<l)+(c[348604]|0)|0;if((e&256|0)==0){n=m}else{n=(c[348602]|0)+m|0}m=n&65535;n=m>>>(l>>>0);l=(e&16384|0)!=0;o=n<<6;do{if(l){p=(c[348622]|0)+o|0;if((a[(c[348618]|0)+n|0]|0)!=0){q=p;break}r=fi[c[348636]&63](p,m,k)|0;a[(c[348618]|0)+n|0]=r;q=p}else{p=(c[348624]|0)+o|0;if((a[(c[348620]|0)+n|0]|0)!=0){q=p;break}r=fi[c[348638]&63](p,m,k)|0;a[(c[348620]|0)+n|0]=r;q=p}}while(0);if((a[(c[348620]|0)+n|0]|0)==2){return}if((a[1394464]|0)==0){s=1106168+((e>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){n=d[1044485]|0;c[276541]=7080+(n<<5);k=0;do{m=k<<1&2;o=k&2;p=k&4;r=0;do{b[1125528+(k<<9)+(r<<1)>>1]=d[(r>>>1&28|o)+(7080+(n<<5))|0]<<6|d[(r<<2&28|m)+(7080+(n<<5))|0]<<11|d[(r>>>3&24|p)+(7080+(n<<5))|0];r=r+1|0;}while(r>>>0<256);k=k+1|0;}while(k>>>0<8);a[1106089]=0}s=1125528+((e>>>10&7)<<9)|0}c[277226]=s;c[277225]=(a[1108928]|0)!=0?1393712:s;s=l?7-h|0:h;if((e&32768|0)==0){t=s+g|0}else{t=56-g+s|0}s=a[q+t|0]|0;if(!(s<<24>>24!=0&(j|0)>0)){return}t=i-1|0;i=(t|0)>-1;q=s&255;s=j;j=f;while(1){if(i){f=t;do{g=(f<<1)+j|0;if((d[1108908]|0)>(d[(c[277219]|0)+g|0]|0)){do{if((a[1108928]|0)==0){e=b[(c[277225]|0)+(q<<1)>>1]|0;if((a[(c[277215]|0)+g|0]&32)!=0){u=b[(c[277221]|0)+((e&65535|67616)-(b[(c[277213]|0)+(g<<1)>>1]&63454)>>1<<1)>>1]|0;break}h=c[277228]&65535;l=e&-2048;k=h&-2048;n=(l&65535)>(k&65535)?l-k&65535:0;k=e&2016;l=h&2016;if((k&65535)>(l&65535)){v=(k-l&65535)+n&65535}else{v=n}n=e&31;e=h&31;if((n&65535)<=(e&65535)){u=v;break}u=(n-e&65535)+v&65535}else{e=b[(c[277225]|0)+(q<<1)>>1]|0;if((a[(c[277215]|0)+g|0]&32)==0){w=c[277228]&65535}else{w=b[(c[277213]|0)+(g<<1)>>1]|0}n=e&-2048;h=w&-2048;l=(n&65535)>(h&65535)?n-h&65535:0;h=e&2016;n=w&2016;if((h&65535)>(n&65535)){x=(h-n&65535)+l&65535}else{x=l}l=e&31;e=w&31;if((l&65535)<=(e&65535)){u=x;break}u=(l-e&65535)+x&65535}}while(0);e=g+1|0;b[(c[277218]|0)+(e<<1)>>1]=u;b[(c[277218]|0)+(g<<1)>>1]=u;l=a[1108909]|0;a[(c[277219]|0)+e|0]=l;a[(c[277219]|0)+g|0]=l}f=f-1|0;}while((f|0)>-1)}f=s-1|0;if((f|0)>0){s=f;j=(c[277223]|0)+j|0}else{break}}return}function Un(e,f,g,h,i,j){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;k=e&1023;l=c[348606]|0;m=(k<<l)+(c[348604]|0)|0;if((e&256|0)==0){n=m}else{n=(c[348602]|0)+m|0}m=n&65535;n=m>>>(l>>>0);l=(e&16384|0)!=0;o=n<<6;do{if(l){p=(c[348622]|0)+o|0;if((a[(c[348618]|0)+n|0]|0)!=0){q=p;break}r=fi[c[348636]&63](p,m,k)|0;a[(c[348618]|0)+n|0]=r;q=p}else{p=(c[348624]|0)+o|0;if((a[(c[348620]|0)+n|0]|0)!=0){q=p;break}r=fi[c[348638]&63](p,m,k)|0;a[(c[348620]|0)+n|0]=r;q=p}}while(0);if((a[(c[348620]|0)+n|0]|0)==2){return}if((a[1394464]|0)==0){s=1106168+((e>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){n=d[1044485]|0;c[276541]=7080+(n<<5);k=0;do{m=k<<1&2;o=k&2;p=k&4;r=0;do{b[1125528+(k<<9)+(r<<1)>>1]=d[(r>>>1&28|o)+(7080+(n<<5))|0]<<6|d[(r<<2&28|m)+(7080+(n<<5))|0]<<11|d[(r>>>3&24|p)+(7080+(n<<5))|0];r=r+1|0;}while(r>>>0<256);k=k+1|0;}while(k>>>0<8);a[1106089]=0}s=1125528+((e>>>10&7)<<9)|0}c[277226]=s;c[277225]=(a[1108928]|0)!=0?1393712:s;if((e&49152|0)==0){if((j|0)<=0){return}s=h&255;k=s-1&255;n=k<<24>>24==0;r=q+i|0;p=j;m=f;while(1){switch(g|0){case 7:{t=6038;break};case 5:{u=s;t=6030;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+m|0]|0)){o=a[r]|0;if(o<<24>>24==0){break}v=b[(c[277225]|0)+((o&255)<<1)>>1]|0;o=m+1|0;b[(c[277218]|0)+(o<<1)>>1]=v;b[(c[277218]|0)+(m<<1)>>1]=v;v=a[1108909]|0;a[(c[277219]|0)+o|0]=v;a[(c[277219]|0)+m|0]=v}}while(0);if(!n){w=k;t=6014}break};case 1:{w=s;t=6014;break};case 2:{x=s;t=6018;break};case 6:{y=s;t=6034;break};case 3:{z=s;t=6022;break};case 4:{A=s;t=6026;break};default:{}}if((t|0)==6014){t=0;v=m+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+v|0]|0)){o=a[r+1|0]|0;if(o<<24>>24==0){break}B=b[(c[277225]|0)+((o&255)<<1)>>1]|0;o=m+3|0;b[(c[277218]|0)+(o<<1)>>1]=B;b[(c[277218]|0)+(v<<1)>>1]=B;B=a[1108909]|0;a[(c[277219]|0)+o|0]=B;a[(c[277219]|0)+v|0]=B}}while(0);v=w-1&255;if(v<<24>>24!=0){x=v;t=6018}}if((t|0)==6018){t=0;v=m+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+v|0]|0)){B=a[r+2|0]|0;if(B<<24>>24==0){break}o=b[(c[277225]|0)+((B&255)<<1)>>1]|0;B=m+5|0;b[(c[277218]|0)+(B<<1)>>1]=o;b[(c[277218]|0)+(v<<1)>>1]=o;o=a[1108909]|0;a[(c[277219]|0)+B|0]=o;a[(c[277219]|0)+v|0]=o}}while(0);v=x-1&255;if(v<<24>>24!=0){z=v;t=6022}}if((t|0)==6022){t=0;v=m+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+v|0]|0)){o=a[r+3|0]|0;if(o<<24>>24==0){break}B=b[(c[277225]|0)+((o&255)<<1)>>1]|0;o=m+7|0;b[(c[277218]|0)+(o<<1)>>1]=B;b[(c[277218]|0)+(v<<1)>>1]=B;B=a[1108909]|0;a[(c[277219]|0)+o|0]=B;a[(c[277219]|0)+v|0]=B}}while(0);v=z-1&255;if(v<<24>>24!=0){A=v;t=6026}}if((t|0)==6026){t=0;v=m+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+v|0]|0)){B=a[r+4|0]|0;if(B<<24>>24==0){break}o=b[(c[277225]|0)+((B&255)<<1)>>1]|0;B=m+9|0;b[(c[277218]|0)+(B<<1)>>1]=o;b[(c[277218]|0)+(v<<1)>>1]=o;o=a[1108909]|0;a[(c[277219]|0)+B|0]=o;a[(c[277219]|0)+v|0]=o}}while(0);v=A-1&255;if(v<<24>>24!=0){u=v;t=6030}}if((t|0)==6030){t=0;v=m+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+v|0]|0)){o=a[r+5|0]|0;if(o<<24>>24==0){break}B=b[(c[277225]|0)+((o&255)<<1)>>1]|0;o=m+11|0;b[(c[277218]|0)+(o<<1)>>1]=B;b[(c[277218]|0)+(v<<1)>>1]=B;B=a[1108909]|0;a[(c[277219]|0)+o|0]=B;a[(c[277219]|0)+v|0]=B}}while(0);v=u-1&255;if(v<<24>>24!=0){y=v;t=6034}}if((t|0)==6034){t=0;v=m+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+v|0]|0)){B=a[r+6|0]|0;if(B<<24>>24==0){break}o=b[(c[277225]|0)+((B&255)<<1)>>1]|0;B=m+13|0;b[(c[277218]|0)+(B<<1)>>1]=o;b[(c[277218]|0)+(v<<1)>>1]=o;o=a[1108909]|0;a[(c[277219]|0)+B|0]=o;a[(c[277219]|0)+v|0]=o}}while(0);if(y<<24>>24!=1){t=6038}}do{if((t|0)==6038){t=0;v=m+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+v|0]|0)){break}o=a[r+7|0]|0;if(o<<24>>24==0){break}B=b[(c[277225]|0)+((o&255)<<1)>>1]|0;o=m+15|0;b[(c[277218]|0)+(o<<1)>>1]=B;b[(c[277218]|0)+(v<<1)>>1]=B;B=a[1108909]|0;a[(c[277219]|0)+o|0]=B;a[(c[277219]|0)+v|0]=B}}while(0);B=p-1|0;if((B|0)>0){r=r+8|0;p=B;m=(c[277223]|0)+m|0}else{break}}return}if((e&32768|0)==0){if((j|0)<=0){return}e=h&255;m=e-1&255;p=m<<24>>24==0;r=q+i|0;y=j;u=f;while(1){switch(g|0){case 2:{C=e;t=6054;break};case 5:{D=e;t=6066;break};case 6:{E=e;t=6070;break};case 7:{t=6074;break};case 3:{F=e;t=6058;break};case 4:{G=e;t=6062;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+u|0]|0)){A=a[r+7|0]|0;if(A<<24>>24==0){break}z=b[(c[277225]|0)+((A&255)<<1)>>1]|0;A=u+1|0;b[(c[277218]|0)+(A<<1)>>1]=z;b[(c[277218]|0)+(u<<1)>>1]=z;z=a[1108909]|0;a[(c[277219]|0)+A|0]=z;a[(c[277219]|0)+u|0]=z}}while(0);if(!p){H=m;t=6050}break};case 1:{H=e;t=6050;break};default:{}}if((t|0)==6050){t=0;z=u+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+z|0]|0)){A=a[r+6|0]|0;if(A<<24>>24==0){break}x=b[(c[277225]|0)+((A&255)<<1)>>1]|0;A=u+3|0;b[(c[277218]|0)+(A<<1)>>1]=x;b[(c[277218]|0)+(z<<1)>>1]=x;x=a[1108909]|0;a[(c[277219]|0)+A|0]=x;a[(c[277219]|0)+z|0]=x}}while(0);z=H-1&255;if(z<<24>>24!=0){C=z;t=6054}}if((t|0)==6054){t=0;z=u+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+z|0]|0)){x=a[r+5|0]|0;if(x<<24>>24==0){break}A=b[(c[277225]|0)+((x&255)<<1)>>1]|0;x=u+5|0;b[(c[277218]|0)+(x<<1)>>1]=A;b[(c[277218]|0)+(z<<1)>>1]=A;A=a[1108909]|0;a[(c[277219]|0)+x|0]=A;a[(c[277219]|0)+z|0]=A}}while(0);z=C-1&255;if(z<<24>>24!=0){F=z;t=6058}}if((t|0)==6058){t=0;z=u+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+z|0]|0)){A=a[r+4|0]|0;if(A<<24>>24==0){break}x=b[(c[277225]|0)+((A&255)<<1)>>1]|0;A=u+7|0;b[(c[277218]|0)+(A<<1)>>1]=x;b[(c[277218]|0)+(z<<1)>>1]=x;x=a[1108909]|0;a[(c[277219]|0)+A|0]=x;a[(c[277219]|0)+z|0]=x}}while(0);z=F-1&255;if(z<<24>>24!=0){G=z;t=6062}}if((t|0)==6062){t=0;z=u+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+z|0]|0)){x=a[r+3|0]|0;if(x<<24>>24==0){break}A=b[(c[277225]|0)+((x&255)<<1)>>1]|0;x=u+9|0;b[(c[277218]|0)+(x<<1)>>1]=A;b[(c[277218]|0)+(z<<1)>>1]=A;A=a[1108909]|0;a[(c[277219]|0)+x|0]=A;a[(c[277219]|0)+z|0]=A}}while(0);z=G-1&255;if(z<<24>>24!=0){D=z;t=6066}}if((t|0)==6066){t=0;z=u+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+z|0]|0)){A=a[r+2|0]|0;if(A<<24>>24==0){break}x=b[(c[277225]|0)+((A&255)<<1)>>1]|0;A=u+11|0;b[(c[277218]|0)+(A<<1)>>1]=x;b[(c[277218]|0)+(z<<1)>>1]=x;x=a[1108909]|0;a[(c[277219]|0)+A|0]=x;a[(c[277219]|0)+z|0]=x}}while(0);z=D-1&255;if(z<<24>>24!=0){E=z;t=6070}}if((t|0)==6070){t=0;z=u+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+z|0]|0)){x=a[r+1|0]|0;if(x<<24>>24==0){break}A=b[(c[277225]|0)+((x&255)<<1)>>1]|0;x=u+13|0;b[(c[277218]|0)+(x<<1)>>1]=A;b[(c[277218]|0)+(z<<1)>>1]=A;A=a[1108909]|0;a[(c[277219]|0)+x|0]=A;a[(c[277219]|0)+z|0]=A}}while(0);if(E<<24>>24!=1){t=6074}}do{if((t|0)==6074){t=0;z=u+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+z|0]|0)){break}A=a[r]|0;if(A<<24>>24==0){break}x=b[(c[277225]|0)+((A&255)<<1)>>1]|0;A=u+15|0;b[(c[277218]|0)+(A<<1)>>1]=x;b[(c[277218]|0)+(z<<1)>>1]=x;x=a[1108909]|0;a[(c[277219]|0)+A|0]=x;a[(c[277219]|0)+z|0]=x}}while(0);x=y-1|0;if((x|0)>0){r=r+8|0;y=x;u=(c[277223]|0)+u|0}else{break}}return}u=q+(56-i)|0;i=(j|0)>0;if(l){if(!i){return}l=h&255;q=l-1&255;y=q<<24>>24==0;r=u;E=j;D=f;while(1){switch(g|0){case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+D|0]|0)){G=a[r+7|0]|0;if(G<<24>>24==0){break}F=b[(c[277225]|0)+((G&255)<<1)>>1]|0;G=D+1|0;b[(c[277218]|0)+(G<<1)>>1]=F;b[(c[277218]|0)+(D<<1)>>1]=F;F=a[1108909]|0;a[(c[277219]|0)+G|0]=F;a[(c[277219]|0)+D|0]=F}}while(0);if(!y){I=q;t=6121}break};case 1:{I=l;t=6121;break};case 2:{J=l;t=6125;break};case 3:{K=l;t=6129;break};case 4:{L=l;t=6133;break};case 5:{M=l;t=6137;break};case 6:{N=l;t=6141;break};case 7:{t=6145;break};default:{}}if((t|0)==6121){t=0;F=D+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+F|0]|0)){G=a[r+6|0]|0;if(G<<24>>24==0){break}C=b[(c[277225]|0)+((G&255)<<1)>>1]|0;G=D+3|0;b[(c[277218]|0)+(G<<1)>>1]=C;b[(c[277218]|0)+(F<<1)>>1]=C;C=a[1108909]|0;a[(c[277219]|0)+G|0]=C;a[(c[277219]|0)+F|0]=C}}while(0);F=I-1&255;if(F<<24>>24!=0){J=F;t=6125}}if((t|0)==6125){t=0;F=D+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+F|0]|0)){C=a[r+5|0]|0;if(C<<24>>24==0){break}G=b[(c[277225]|0)+((C&255)<<1)>>1]|0;C=D+5|0;b[(c[277218]|0)+(C<<1)>>1]=G;b[(c[277218]|0)+(F<<1)>>1]=G;G=a[1108909]|0;a[(c[277219]|0)+C|0]=G;a[(c[277219]|0)+F|0]=G}}while(0);F=J-1&255;if(F<<24>>24!=0){K=F;t=6129}}if((t|0)==6129){t=0;F=D+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+F|0]|0)){G=a[r+4|0]|0;if(G<<24>>24==0){break}C=b[(c[277225]|0)+((G&255)<<1)>>1]|0;G=D+7|0;b[(c[277218]|0)+(G<<1)>>1]=C;b[(c[277218]|0)+(F<<1)>>1]=C;C=a[1108909]|0;a[(c[277219]|0)+G|0]=C;a[(c[277219]|0)+F|0]=C}}while(0);F=K-1&255;if(F<<24>>24!=0){L=F;t=6133}}if((t|0)==6133){t=0;F=D+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+F|0]|0)){C=a[r+3|0]|0;if(C<<24>>24==0){break}G=b[(c[277225]|0)+((C&255)<<1)>>1]|0;C=D+9|0;b[(c[277218]|0)+(C<<1)>>1]=G;b[(c[277218]|0)+(F<<1)>>1]=G;G=a[1108909]|0;a[(c[277219]|0)+C|0]=G;a[(c[277219]|0)+F|0]=G}}while(0);F=L-1&255;if(F<<24>>24!=0){M=F;t=6137}}if((t|0)==6137){t=0;F=D+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+F|0]|0)){G=a[r+2|0]|0;if(G<<24>>24==0){break}C=b[(c[277225]|0)+((G&255)<<1)>>1]|0;G=D+11|0;b[(c[277218]|0)+(G<<1)>>1]=C;b[(c[277218]|0)+(F<<1)>>1]=C;C=a[1108909]|0;a[(c[277219]|0)+G|0]=C;a[(c[277219]|0)+F|0]=C}}while(0);F=M-1&255;if(F<<24>>24!=0){N=F;t=6141}}if((t|0)==6141){t=0;F=D+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+F|0]|0)){C=a[r+1|0]|0;if(C<<24>>24==0){break}G=b[(c[277225]|0)+((C&255)<<1)>>1]|0;C=D+13|0;b[(c[277218]|0)+(C<<1)>>1]=G;b[(c[277218]|0)+(F<<1)>>1]=G;G=a[1108909]|0;a[(c[277219]|0)+C|0]=G;a[(c[277219]|0)+F|0]=G}}while(0);if(N<<24>>24!=1){t=6145}}do{if((t|0)==6145){t=0;F=D+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+F|0]|0)){break}G=a[r]|0;if(G<<24>>24==0){break}C=b[(c[277225]|0)+((G&255)<<1)>>1]|0;G=D+15|0;b[(c[277218]|0)+(G<<1)>>1]=C;b[(c[277218]|0)+(F<<1)>>1]=C;C=a[1108909]|0;a[(c[277219]|0)+G|0]=C;a[(c[277219]|0)+F|0]=C}}while(0);C=E-1|0;if((C|0)>0){r=r-8|0;E=C;D=(c[277223]|0)+D|0}else{break}}return}else{if(!i){return}i=h&255;h=i-1&255;D=h<<24>>24==0;E=u;u=j;j=f;while(1){switch(g|0){case 3:{O=i;t=6096;break};case 4:{P=i;t=6100;break};case 5:{Q=i;t=6104;break};case 6:{R=i;t=6108;break};case 7:{t=6112;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+j|0]|0)){f=a[E]|0;if(f<<24>>24==0){break}r=b[(c[277225]|0)+((f&255)<<1)>>1]|0;f=j+1|0;b[(c[277218]|0)+(f<<1)>>1]=r;b[(c[277218]|0)+(j<<1)>>1]=r;r=a[1108909]|0;a[(c[277219]|0)+f|0]=r;a[(c[277219]|0)+j|0]=r}}while(0);if(!D){S=h;t=6088}break};case 1:{S=i;t=6088;break};case 2:{T=i;t=6092;break};default:{}}if((t|0)==6088){t=0;r=j+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+r|0]|0)){f=a[E+1|0]|0;if(f<<24>>24==0){break}N=b[(c[277225]|0)+((f&255)<<1)>>1]|0;f=j+3|0;b[(c[277218]|0)+(f<<1)>>1]=N;b[(c[277218]|0)+(r<<1)>>1]=N;N=a[1108909]|0;a[(c[277219]|0)+f|0]=N;a[(c[277219]|0)+r|0]=N}}while(0);r=S-1&255;if(r<<24>>24!=0){T=r;t=6092}}if((t|0)==6092){t=0;r=j+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+r|0]|0)){N=a[E+2|0]|0;if(N<<24>>24==0){break}f=b[(c[277225]|0)+((N&255)<<1)>>1]|0;N=j+5|0;b[(c[277218]|0)+(N<<1)>>1]=f;b[(c[277218]|0)+(r<<1)>>1]=f;f=a[1108909]|0;a[(c[277219]|0)+N|0]=f;a[(c[277219]|0)+r|0]=f}}while(0);r=T-1&255;if(r<<24>>24!=0){O=r;t=6096}}if((t|0)==6096){t=0;r=j+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+r|0]|0)){f=a[E+3|0]|0;if(f<<24>>24==0){break}N=b[(c[277225]|0)+((f&255)<<1)>>1]|0;f=j+7|0;b[(c[277218]|0)+(f<<1)>>1]=N;b[(c[277218]|0)+(r<<1)>>1]=N;N=a[1108909]|0;a[(c[277219]|0)+f|0]=N;a[(c[277219]|0)+r|0]=N}}while(0);r=O-1&255;if(r<<24>>24!=0){P=r;t=6100}}if((t|0)==6100){t=0;r=j+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+r|0]|0)){N=a[E+4|0]|0;if(N<<24>>24==0){break}f=b[(c[277225]|0)+((N&255)<<1)>>1]|0;N=j+9|0;b[(c[277218]|0)+(N<<1)>>1]=f;b[(c[277218]|0)+(r<<1)>>1]=f;f=a[1108909]|0;a[(c[277219]|0)+N|0]=f;a[(c[277219]|0)+r|0]=f}}while(0);r=P-1&255;if(r<<24>>24!=0){Q=r;t=6104}}if((t|0)==6104){t=0;r=j+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+r|0]|0)){f=a[E+5|0]|0;if(f<<24>>24==0){break}N=b[(c[277225]|0)+((f&255)<<1)>>1]|0;f=j+11|0;b[(c[277218]|0)+(f<<1)>>1]=N;b[(c[277218]|0)+(r<<1)>>1]=N;N=a[1108909]|0;a[(c[277219]|0)+f|0]=N;a[(c[277219]|0)+r|0]=N}}while(0);r=Q-1&255;if(r<<24>>24!=0){R=r;t=6108}}if((t|0)==6108){t=0;r=j+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+r|0]|0)){N=a[E+6|0]|0;if(N<<24>>24==0){break}f=b[(c[277225]|0)+((N&255)<<1)>>1]|0;N=j+13|0;b[(c[277218]|0)+(N<<1)>>1]=f;b[(c[277218]|0)+(r<<1)>>1]=f;f=a[1108909]|0;a[(c[277219]|0)+N|0]=f;a[(c[277219]|0)+r|0]=f}}while(0);if(R<<24>>24!=1){t=6112}}do{if((t|0)==6112){t=0;r=j+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+r|0]|0)){break}f=a[E+7|0]|0;if(f<<24>>24==0){break}N=b[(c[277225]|0)+((f&255)<<1)>>1]|0;f=j+15|0;b[(c[277218]|0)+(f<<1)>>1]=N;b[(c[277218]|0)+(r<<1)>>1]=N;N=a[1108909]|0;a[(c[277219]|0)+f|0]=N;a[(c[277219]|0)+r|0]=N}}while(0);N=u-1|0;if((N|0)>0){E=E-8|0;u=N;j=(c[277223]|0)+j|0}else{break}}return}}function Uo(f,g,h,i,j,k){f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0;l=f&1023;m=c[348606]|0;n=(l<<m)+(c[348604]|0)|0;if((f&256|0)==0){o=n}else{o=(c[348602]|0)+n|0}n=o&65535;o=n>>>(m>>>0);m=(f&16384|0)!=0;p=o<<6;do{if(m){q=(c[348622]|0)+p|0;if((a[(c[348618]|0)+o|0]|0)!=0){r=q;break}s=fi[c[348636]&63](q,n,l)|0;a[(c[348618]|0)+o|0]=s;r=q}else{q=(c[348624]|0)+p|0;if((a[(c[348620]|0)+o|0]|0)!=0){r=q;break}s=fi[c[348638]&63](q,n,l)|0;a[(c[348620]|0)+o|0]=s;r=q}}while(0);if((a[(c[348620]|0)+o|0]|0)==2){return}if((a[1394464]|0)==0){t=1106168+((f>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){o=d[1044485]|0;c[276541]=7080+(o<<5);l=0;do{n=l<<1&2;p=l&2;q=l&4;s=0;do{b[1125528+(l<<9)+(s<<1)>>1]=d[(s>>>1&28|p)+(7080+(o<<5))|0]<<6|d[(s<<2&28|n)+(7080+(o<<5))|0]<<11|d[(s>>>3&24|q)+(7080+(o<<5))|0];s=s+1|0;}while(s>>>0<256);l=l+1|0;}while(l>>>0<8);a[1106089]=0}t=1125528+((f>>>10&7)<<9)|0}c[277226]=t;c[277225]=(a[1108928]|0)!=0?1393712:t;if((f&49152|0)==0){if((k|0)<=0){return}t=i&255;l=t-1&255;o=l<<24>>24==0;s=r+j|0;q=k;n=g;while(1){switch(h|0){case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+n|0]|0)){p=a[s]|0;if(p<<24>>24==0){break}u=e[(c[277225]|0)+((p&255)<<1)>>1]|0;p=(a[(c[277215]|0)+n|0]&32)==0;if(p){v=c[277228]|0;w=v;x=v&-2082}else{v=e[(c[277213]|0)+(n<<1)>>1]|0;w=v;x=v&63454}if(p){y=c[277228]|0}else{y=e[(c[277213]|0)+(n<<1)>>1]|0}p=((y^u)&2081|e[(c[277220]|0)+((u&2081&w)+((x+(u&63454)|0)>>>1)<<1)>>1])&65535;u=n+1|0;b[(c[277218]|0)+(u<<1)>>1]=p;b[(c[277218]|0)+(n<<1)>>1]=p;p=a[1108909]|0;a[(c[277219]|0)+u|0]=p;a[(c[277219]|0)+n|0]=p}}while(0);if(!o){z=l;A=6190}break};case 1:{z=t;A=6190;break};case 2:{B=t;A=6200;break};case 3:{C=t;A=6210;break};case 4:{D=t;A=6220;break};case 5:{E=t;A=6230;break};case 6:{F=t;A=6240;break};case 7:{A=6250;break};default:{}}if((A|0)==6190){A=0;p=n+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){u=a[s+1|0]|0;if(u<<24>>24==0){break}v=e[(c[277225]|0)+((u&255)<<1)>>1]|0;u=(a[(c[277215]|0)+p|0]&32)==0;if(u){G=c[277228]|0;H=G;I=G&-2082}else{G=e[(c[277213]|0)+(p<<1)>>1]|0;H=G;I=G&63454}if(u){J=c[277228]|0}else{J=e[(c[277213]|0)+(p<<1)>>1]|0}u=((J^v)&2081|e[(c[277220]|0)+((v&2081&H)+((I+(v&63454)|0)>>>1)<<1)>>1])&65535;v=n+3|0;b[(c[277218]|0)+(v<<1)>>1]=u;b[(c[277218]|0)+(p<<1)>>1]=u;u=a[1108909]|0;a[(c[277219]|0)+v|0]=u;a[(c[277219]|0)+p|0]=u}}while(0);p=z-1&255;if(p<<24>>24!=0){B=p;A=6200}}if((A|0)==6200){A=0;p=n+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){u=a[s+2|0]|0;if(u<<24>>24==0){break}v=e[(c[277225]|0)+((u&255)<<1)>>1]|0;u=(a[(c[277215]|0)+p|0]&32)==0;if(u){G=c[277228]|0;K=G;L=G&-2082}else{G=e[(c[277213]|0)+(p<<1)>>1]|0;K=G;L=G&63454}if(u){M=c[277228]|0}else{M=e[(c[277213]|0)+(p<<1)>>1]|0}u=((M^v)&2081|e[(c[277220]|0)+((v&2081&K)+((L+(v&63454)|0)>>>1)<<1)>>1])&65535;v=n+5|0;b[(c[277218]|0)+(v<<1)>>1]=u;b[(c[277218]|0)+(p<<1)>>1]=u;u=a[1108909]|0;a[(c[277219]|0)+v|0]=u;a[(c[277219]|0)+p|0]=u}}while(0);p=B-1&255;if(p<<24>>24!=0){C=p;A=6210}}if((A|0)==6210){A=0;p=n+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){u=a[s+3|0]|0;if(u<<24>>24==0){break}v=e[(c[277225]|0)+((u&255)<<1)>>1]|0;u=(a[(c[277215]|0)+p|0]&32)==0;if(u){G=c[277228]|0;N=G;O=G&-2082}else{G=e[(c[277213]|0)+(p<<1)>>1]|0;N=G;O=G&63454}if(u){P=c[277228]|0}else{P=e[(c[277213]|0)+(p<<1)>>1]|0}u=((P^v)&2081|e[(c[277220]|0)+((v&2081&N)+((O+(v&63454)|0)>>>1)<<1)>>1])&65535;v=n+7|0;b[(c[277218]|0)+(v<<1)>>1]=u;b[(c[277218]|0)+(p<<1)>>1]=u;u=a[1108909]|0;a[(c[277219]|0)+v|0]=u;a[(c[277219]|0)+p|0]=u}}while(0);p=C-1&255;if(p<<24>>24!=0){D=p;A=6220}}if((A|0)==6220){A=0;p=n+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){u=a[s+4|0]|0;if(u<<24>>24==0){break}v=e[(c[277225]|0)+((u&255)<<1)>>1]|0;u=(a[(c[277215]|0)+p|0]&32)==0;if(u){G=c[277228]|0;Q=G;R=G&-2082}else{G=e[(c[277213]|0)+(p<<1)>>1]|0;Q=G;R=G&63454}if(u){S=c[277228]|0}else{S=e[(c[277213]|0)+(p<<1)>>1]|0}u=((S^v)&2081|e[(c[277220]|0)+((v&2081&Q)+((R+(v&63454)|0)>>>1)<<1)>>1])&65535;v=n+9|0;b[(c[277218]|0)+(v<<1)>>1]=u;b[(c[277218]|0)+(p<<1)>>1]=u;u=a[1108909]|0;a[(c[277219]|0)+v|0]=u;a[(c[277219]|0)+p|0]=u}}while(0);p=D-1&255;if(p<<24>>24!=0){E=p;A=6230}}if((A|0)==6230){A=0;p=n+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){u=a[s+5|0]|0;if(u<<24>>24==0){break}v=e[(c[277225]|0)+((u&255)<<1)>>1]|0;u=(a[(c[277215]|0)+p|0]&32)==0;if(u){G=c[277228]|0;T=G;U=G&-2082}else{G=e[(c[277213]|0)+(p<<1)>>1]|0;T=G;U=G&63454}if(u){V=c[277228]|0}else{V=e[(c[277213]|0)+(p<<1)>>1]|0}u=((V^v)&2081|e[(c[277220]|0)+((v&2081&T)+((U+(v&63454)|0)>>>1)<<1)>>1])&65535;v=n+11|0;b[(c[277218]|0)+(v<<1)>>1]=u;b[(c[277218]|0)+(p<<1)>>1]=u;u=a[1108909]|0;a[(c[277219]|0)+v|0]=u;a[(c[277219]|0)+p|0]=u}}while(0);p=E-1&255;if(p<<24>>24!=0){F=p;A=6240}}if((A|0)==6240){A=0;p=n+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){u=a[s+6|0]|0;if(u<<24>>24==0){break}v=e[(c[277225]|0)+((u&255)<<1)>>1]|0;u=(a[(c[277215]|0)+p|0]&32)==0;if(u){G=c[277228]|0;W=G;X=G&-2082}else{G=e[(c[277213]|0)+(p<<1)>>1]|0;W=G;X=G&63454}if(u){Y=c[277228]|0}else{Y=e[(c[277213]|0)+(p<<1)>>1]|0}u=((Y^v)&2081|e[(c[277220]|0)+((v&2081&W)+((X+(v&63454)|0)>>>1)<<1)>>1])&65535;v=n+13|0;b[(c[277218]|0)+(v<<1)>>1]=u;b[(c[277218]|0)+(p<<1)>>1]=u;u=a[1108909]|0;a[(c[277219]|0)+v|0]=u;a[(c[277219]|0)+p|0]=u}}while(0);if(F<<24>>24!=1){A=6250}}do{if((A|0)==6250){A=0;p=n+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+p|0]|0)){break}u=a[s+7|0]|0;if(u<<24>>24==0){break}v=e[(c[277225]|0)+((u&255)<<1)>>1]|0;u=(a[(c[277215]|0)+p|0]&32)==0;if(u){G=c[277228]|0;Z=G;_=G&-2082}else{G=e[(c[277213]|0)+(p<<1)>>1]|0;Z=G;_=G&63454}if(u){$=c[277228]|0}else{$=e[(c[277213]|0)+(p<<1)>>1]|0}u=(($^v)&2081|e[(c[277220]|0)+((v&2081&Z)+((_+(v&63454)|0)>>>1)<<1)>>1])&65535;v=n+15|0;b[(c[277218]|0)+(v<<1)>>1]=u;b[(c[277218]|0)+(p<<1)>>1]=u;u=a[1108909]|0;a[(c[277219]|0)+v|0]=u;a[(c[277219]|0)+p|0]=u}}while(0);u=q-1|0;if((u|0)>0){s=s+8|0;q=u;n=(c[277223]|0)+n|0}else{break}}return}if((f&32768|0)==0){if((k|0)<=0){return}f=i&255;n=f-1&255;q=n<<24>>24==0;s=r+j|0;_=k;Z=g;while(1){switch(h|0){case 7:{A=6334;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+Z|0]|0)){$=a[s+7|0]|0;if($<<24>>24==0){break}F=e[(c[277225]|0)+(($&255)<<1)>>1]|0;$=(a[(c[277215]|0)+Z|0]&32)==0;if($){X=c[277228]|0;aa=X;ab=X&-2082}else{X=e[(c[277213]|0)+(Z<<1)>>1]|0;aa=X;ab=X&63454}if($){ac=c[277228]|0}else{ac=e[(c[277213]|0)+(Z<<1)>>1]|0}$=((ac^F)&2081|e[(c[277220]|0)+((F&2081&aa)+((ab+(F&63454)|0)>>>1)<<1)>>1])&65535;F=Z+1|0;b[(c[277218]|0)+(F<<1)>>1]=$;b[(c[277218]|0)+(Z<<1)>>1]=$;$=a[1108909]|0;a[(c[277219]|0)+F|0]=$;a[(c[277219]|0)+Z|0]=$}}while(0);if(!q){ad=n;A=6274}break};case 1:{ad=f;A=6274;break};case 2:{ae=f;A=6284;break};case 3:{af=f;A=6294;break};case 4:{ag=f;A=6304;break};case 5:{ah=f;A=6314;break};case 6:{ai=f;A=6324;break};default:{}}if((A|0)==6274){A=0;$=Z+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+$|0]|0)){F=a[s+6|0]|0;if(F<<24>>24==0){break}X=e[(c[277225]|0)+((F&255)<<1)>>1]|0;F=(a[(c[277215]|0)+$|0]&32)==0;if(F){W=c[277228]|0;aj=W;ak=W&-2082}else{W=e[(c[277213]|0)+($<<1)>>1]|0;aj=W;ak=W&63454}if(F){al=c[277228]|0}else{al=e[(c[277213]|0)+($<<1)>>1]|0}F=((al^X)&2081|e[(c[277220]|0)+((X&2081&aj)+((ak+(X&63454)|0)>>>1)<<1)>>1])&65535;X=Z+3|0;b[(c[277218]|0)+(X<<1)>>1]=F;b[(c[277218]|0)+($<<1)>>1]=F;F=a[1108909]|0;a[(c[277219]|0)+X|0]=F;a[(c[277219]|0)+$|0]=F}}while(0);$=ad-1&255;if($<<24>>24!=0){ae=$;A=6284}}if((A|0)==6284){A=0;$=Z+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+$|0]|0)){F=a[s+5|0]|0;if(F<<24>>24==0){break}X=e[(c[277225]|0)+((F&255)<<1)>>1]|0;F=(a[(c[277215]|0)+$|0]&32)==0;if(F){W=c[277228]|0;am=W;an=W&-2082}else{W=e[(c[277213]|0)+($<<1)>>1]|0;am=W;an=W&63454}if(F){ao=c[277228]|0}else{ao=e[(c[277213]|0)+($<<1)>>1]|0}F=((ao^X)&2081|e[(c[277220]|0)+((X&2081&am)+((an+(X&63454)|0)>>>1)<<1)>>1])&65535;X=Z+5|0;b[(c[277218]|0)+(X<<1)>>1]=F;b[(c[277218]|0)+($<<1)>>1]=F;F=a[1108909]|0;a[(c[277219]|0)+X|0]=F;a[(c[277219]|0)+$|0]=F}}while(0);$=ae-1&255;if($<<24>>24!=0){af=$;A=6294}}if((A|0)==6294){A=0;$=Z+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+$|0]|0)){F=a[s+4|0]|0;if(F<<24>>24==0){break}X=e[(c[277225]|0)+((F&255)<<1)>>1]|0;F=(a[(c[277215]|0)+$|0]&32)==0;if(F){W=c[277228]|0;ap=W;aq=W&-2082}else{W=e[(c[277213]|0)+($<<1)>>1]|0;ap=W;aq=W&63454}if(F){ar=c[277228]|0}else{ar=e[(c[277213]|0)+($<<1)>>1]|0}F=((ar^X)&2081|e[(c[277220]|0)+((X&2081&ap)+((aq+(X&63454)|0)>>>1)<<1)>>1])&65535;X=Z+7|0;b[(c[277218]|0)+(X<<1)>>1]=F;b[(c[277218]|0)+($<<1)>>1]=F;F=a[1108909]|0;a[(c[277219]|0)+X|0]=F;a[(c[277219]|0)+$|0]=F}}while(0);$=af-1&255;if($<<24>>24!=0){ag=$;A=6304}}if((A|0)==6304){A=0;$=Z+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+$|0]|0)){F=a[s+3|0]|0;if(F<<24>>24==0){break}X=e[(c[277225]|0)+((F&255)<<1)>>1]|0;F=(a[(c[277215]|0)+$|0]&32)==0;if(F){W=c[277228]|0;as=W;at=W&-2082}else{W=e[(c[277213]|0)+($<<1)>>1]|0;as=W;at=W&63454}if(F){au=c[277228]|0}else{au=e[(c[277213]|0)+($<<1)>>1]|0}F=((au^X)&2081|e[(c[277220]|0)+((X&2081&as)+((at+(X&63454)|0)>>>1)<<1)>>1])&65535;X=Z+9|0;b[(c[277218]|0)+(X<<1)>>1]=F;b[(c[277218]|0)+($<<1)>>1]=F;F=a[1108909]|0;a[(c[277219]|0)+X|0]=F;a[(c[277219]|0)+$|0]=F}}while(0);$=ag-1&255;if($<<24>>24!=0){ah=$;A=6314}}if((A|0)==6314){A=0;$=Z+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+$|0]|0)){F=a[s+2|0]|0;if(F<<24>>24==0){break}X=e[(c[277225]|0)+((F&255)<<1)>>1]|0;F=(a[(c[277215]|0)+$|0]&32)==0;if(F){W=c[277228]|0;av=W;aw=W&-2082}else{W=e[(c[277213]|0)+($<<1)>>1]|0;av=W;aw=W&63454}if(F){ax=c[277228]|0}else{ax=e[(c[277213]|0)+($<<1)>>1]|0}F=((ax^X)&2081|e[(c[277220]|0)+((X&2081&av)+((aw+(X&63454)|0)>>>1)<<1)>>1])&65535;X=Z+11|0;b[(c[277218]|0)+(X<<1)>>1]=F;b[(c[277218]|0)+($<<1)>>1]=F;F=a[1108909]|0;a[(c[277219]|0)+X|0]=F;a[(c[277219]|0)+$|0]=F}}while(0);$=ah-1&255;if($<<24>>24!=0){ai=$;A=6324}}if((A|0)==6324){A=0;$=Z+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+$|0]|0)){F=a[s+1|0]|0;if(F<<24>>24==0){break}X=e[(c[277225]|0)+((F&255)<<1)>>1]|0;F=(a[(c[277215]|0)+$|0]&32)==0;if(F){W=c[277228]|0;ay=W;az=W&-2082}else{W=e[(c[277213]|0)+($<<1)>>1]|0;ay=W;az=W&63454}if(F){aA=c[277228]|0}else{aA=e[(c[277213]|0)+($<<1)>>1]|0}F=((aA^X)&2081|e[(c[277220]|0)+((X&2081&ay)+((az+(X&63454)|0)>>>1)<<1)>>1])&65535;X=Z+13|0;b[(c[277218]|0)+(X<<1)>>1]=F;b[(c[277218]|0)+($<<1)>>1]=F;F=a[1108909]|0;a[(c[277219]|0)+X|0]=F;a[(c[277219]|0)+$|0]=F}}while(0);if(ai<<24>>24!=1){A=6334}}do{if((A|0)==6334){A=0;$=Z+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+$|0]|0)){break}F=a[s]|0;if(F<<24>>24==0){break}X=e[(c[277225]|0)+((F&255)<<1)>>1]|0;F=(a[(c[277215]|0)+$|0]&32)==0;if(F){W=c[277228]|0;aB=W;aC=W&-2082}else{W=e[(c[277213]|0)+($<<1)>>1]|0;aB=W;aC=W&63454}if(F){aD=c[277228]|0}else{aD=e[(c[277213]|0)+($<<1)>>1]|0}F=((aD^X)&2081|e[(c[277220]|0)+((X&2081&aB)+((aC+(X&63454)|0)>>>1)<<1)>>1])&65535;X=Z+15|0;b[(c[277218]|0)+(X<<1)>>1]=F;b[(c[277218]|0)+($<<1)>>1]=F;F=a[1108909]|0;a[(c[277219]|0)+X|0]=F;a[(c[277219]|0)+$|0]=F}}while(0);F=_-1|0;if((F|0)>0){s=s+8|0;_=F;Z=(c[277223]|0)+Z|0}else{break}}return}Z=r+(56-j)|0;j=(k|0)>0;if(m){if(!j){return}m=i&255;r=m-1&255;_=r<<24>>24==0;s=Z;aC=k;aB=g;while(1){switch(h|0){case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+aB|0]|0)){aD=a[s+7|0]|0;if(aD<<24>>24==0){break}ai=e[(c[277225]|0)+((aD&255)<<1)>>1]|0;aD=(a[(c[277215]|0)+aB|0]&32)==0;if(aD){az=c[277228]|0;aE=az;aF=az&-2082}else{az=e[(c[277213]|0)+(aB<<1)>>1]|0;aE=az;aF=az&63454}if(aD){aG=c[277228]|0}else{aG=e[(c[277213]|0)+(aB<<1)>>1]|0}aD=((aG^ai)&2081|e[(c[277220]|0)+((ai&2081&aE)+((aF+(ai&63454)|0)>>>1)<<1)>>1])&65535;ai=aB+1|0;b[(c[277218]|0)+(ai<<1)>>1]=aD;b[(c[277218]|0)+(aB<<1)>>1]=aD;aD=a[1108909]|0;a[(c[277219]|0)+ai|0]=aD;a[(c[277219]|0)+aB|0]=aD}}while(0);if(!_){aH=r;A=6441}break};case 1:{aH=m;A=6441;break};case 2:{aI=m;A=6451;break};case 3:{aJ=m;A=6461;break};case 7:{A=6501;break};case 5:{aK=m;A=6481;break};case 6:{aL=m;A=6491;break};case 4:{aM=m;A=6471;break};default:{}}if((A|0)==6441){A=0;aD=aB+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+aD|0]|0)){ai=a[s+6|0]|0;if(ai<<24>>24==0){break}az=e[(c[277225]|0)+((ai&255)<<1)>>1]|0;ai=(a[(c[277215]|0)+aD|0]&32)==0;if(ai){ay=c[277228]|0;aN=ay;aO=ay&-2082}else{ay=e[(c[277213]|0)+(aD<<1)>>1]|0;aN=ay;aO=ay&63454}if(ai){aP=c[277228]|0}else{aP=e[(c[277213]|0)+(aD<<1)>>1]|0}ai=((aP^az)&2081|e[(c[277220]|0)+((az&2081&aN)+((aO+(az&63454)|0)>>>1)<<1)>>1])&65535;az=aB+3|0;b[(c[277218]|0)+(az<<1)>>1]=ai;b[(c[277218]|0)+(aD<<1)>>1]=ai;ai=a[1108909]|0;a[(c[277219]|0)+az|0]=ai;a[(c[277219]|0)+aD|0]=ai}}while(0);aD=aH-1&255;if(aD<<24>>24!=0){aI=aD;A=6451}}if((A|0)==6451){A=0;aD=aB+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+aD|0]|0)){ai=a[s+5|0]|0;if(ai<<24>>24==0){break}az=e[(c[277225]|0)+((ai&255)<<1)>>1]|0;ai=(a[(c[277215]|0)+aD|0]&32)==0;if(ai){ay=c[277228]|0;aQ=ay;aR=ay&-2082}else{ay=e[(c[277213]|0)+(aD<<1)>>1]|0;aQ=ay;aR=ay&63454}if(ai){aS=c[277228]|0}else{aS=e[(c[277213]|0)+(aD<<1)>>1]|0}ai=((aS^az)&2081|e[(c[277220]|0)+((az&2081&aQ)+((aR+(az&63454)|0)>>>1)<<1)>>1])&65535;az=aB+5|0;b[(c[277218]|0)+(az<<1)>>1]=ai;b[(c[277218]|0)+(aD<<1)>>1]=ai;ai=a[1108909]|0;a[(c[277219]|0)+az|0]=ai;a[(c[277219]|0)+aD|0]=ai}}while(0);aD=aI-1&255;if(aD<<24>>24!=0){aJ=aD;A=6461}}if((A|0)==6461){A=0;aD=aB+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+aD|0]|0)){ai=a[s+4|0]|0;if(ai<<24>>24==0){break}az=e[(c[277225]|0)+((ai&255)<<1)>>1]|0;ai=(a[(c[277215]|0)+aD|0]&32)==0;if(ai){ay=c[277228]|0;aT=ay;aU=ay&-2082}else{ay=e[(c[277213]|0)+(aD<<1)>>1]|0;aT=ay;aU=ay&63454}if(ai){aV=c[277228]|0}else{aV=e[(c[277213]|0)+(aD<<1)>>1]|0}ai=((aV^az)&2081|e[(c[277220]|0)+((az&2081&aT)+((aU+(az&63454)|0)>>>1)<<1)>>1])&65535;az=aB+7|0;b[(c[277218]|0)+(az<<1)>>1]=ai;b[(c[277218]|0)+(aD<<1)>>1]=ai;ai=a[1108909]|0;a[(c[277219]|0)+az|0]=ai;a[(c[277219]|0)+aD|0]=ai}}while(0);aD=aJ-1&255;if(aD<<24>>24!=0){aM=aD;A=6471}}if((A|0)==6471){A=0;aD=aB+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+aD|0]|0)){ai=a[s+3|0]|0;if(ai<<24>>24==0){break}az=e[(c[277225]|0)+((ai&255)<<1)>>1]|0;ai=(a[(c[277215]|0)+aD|0]&32)==0;if(ai){ay=c[277228]|0;aW=ay;aX=ay&-2082}else{ay=e[(c[277213]|0)+(aD<<1)>>1]|0;aW=ay;aX=ay&63454}if(ai){aY=c[277228]|0}else{aY=e[(c[277213]|0)+(aD<<1)>>1]|0}ai=((aY^az)&2081|e[(c[277220]|0)+((az&2081&aW)+((aX+(az&63454)|0)>>>1)<<1)>>1])&65535;az=aB+9|0;b[(c[277218]|0)+(az<<1)>>1]=ai;b[(c[277218]|0)+(aD<<1)>>1]=ai;ai=a[1108909]|0;a[(c[277219]|0)+az|0]=ai;a[(c[277219]|0)+aD|0]=ai}}while(0);aD=aM-1&255;if(aD<<24>>24!=0){aK=aD;A=6481}}if((A|0)==6481){A=0;aD=aB+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+aD|0]|0)){ai=a[s+2|0]|0;if(ai<<24>>24==0){break}az=e[(c[277225]|0)+((ai&255)<<1)>>1]|0;ai=(a[(c[277215]|0)+aD|0]&32)==0;if(ai){ay=c[277228]|0;aZ=ay;a_=ay&-2082}else{ay=e[(c[277213]|0)+(aD<<1)>>1]|0;aZ=ay;a_=ay&63454}if(ai){a$=c[277228]|0}else{a$=e[(c[277213]|0)+(aD<<1)>>1]|0}ai=((a$^az)&2081|e[(c[277220]|0)+((az&2081&aZ)+((a_+(az&63454)|0)>>>1)<<1)>>1])&65535;az=aB+11|0;b[(c[277218]|0)+(az<<1)>>1]=ai;b[(c[277218]|0)+(aD<<1)>>1]=ai;ai=a[1108909]|0;a[(c[277219]|0)+az|0]=ai;a[(c[277219]|0)+aD|0]=ai}}while(0);aD=aK-1&255;if(aD<<24>>24!=0){aL=aD;A=6491}}if((A|0)==6491){A=0;aD=aB+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+aD|0]|0)){ai=a[s+1|0]|0;if(ai<<24>>24==0){break}az=e[(c[277225]|0)+((ai&255)<<1)>>1]|0;ai=(a[(c[277215]|0)+aD|0]&32)==0;if(ai){ay=c[277228]|0;a0=ay;a1=ay&-2082}else{ay=e[(c[277213]|0)+(aD<<1)>>1]|0;a0=ay;a1=ay&63454}if(ai){a2=c[277228]|0}else{a2=e[(c[277213]|0)+(aD<<1)>>1]|0}ai=((a2^az)&2081|e[(c[277220]|0)+((az&2081&a0)+((a1+(az&63454)|0)>>>1)<<1)>>1])&65535;az=aB+13|0;b[(c[277218]|0)+(az<<1)>>1]=ai;b[(c[277218]|0)+(aD<<1)>>1]=ai;ai=a[1108909]|0;a[(c[277219]|0)+az|0]=ai;a[(c[277219]|0)+aD|0]=ai}}while(0);if(aL<<24>>24!=1){A=6501}}do{if((A|0)==6501){A=0;aD=aB+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+aD|0]|0)){break}ai=a[s]|0;if(ai<<24>>24==0){break}az=e[(c[277225]|0)+((ai&255)<<1)>>1]|0;ai=(a[(c[277215]|0)+aD|0]&32)==0;if(ai){ay=c[277228]|0;a3=ay;a4=ay&-2082}else{ay=e[(c[277213]|0)+(aD<<1)>>1]|0;a3=ay;a4=ay&63454}if(ai){a5=c[277228]|0}else{a5=e[(c[277213]|0)+(aD<<1)>>1]|0}ai=((a5^az)&2081|e[(c[277220]|0)+((az&2081&a3)+((a4+(az&63454)|0)>>>1)<<1)>>1])&65535;az=aB+15|0;b[(c[277218]|0)+(az<<1)>>1]=ai;b[(c[277218]|0)+(aD<<1)>>1]=ai;ai=a[1108909]|0;a[(c[277219]|0)+az|0]=ai;a[(c[277219]|0)+aD|0]=ai}}while(0);ai=aC-1|0;if((ai|0)>0){s=s-8|0;aC=ai;aB=(c[277223]|0)+aB|0}else{break}}return}else{if(!j){return}j=i&255;i=j-1&255;aB=i<<24>>24==0;aC=Z;Z=k;k=g;while(1){switch(h|0){case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+k|0]|0)){g=a[aC]|0;if(g<<24>>24==0){break}s=e[(c[277225]|0)+((g&255)<<1)>>1]|0;g=(a[(c[277215]|0)+k|0]&32)==0;if(g){a4=c[277228]|0;a6=a4;a7=a4&-2082}else{a4=e[(c[277213]|0)+(k<<1)>>1]|0;a6=a4;a7=a4&63454}if(g){a8=c[277228]|0}else{a8=e[(c[277213]|0)+(k<<1)>>1]|0}g=((a8^s)&2081|e[(c[277220]|0)+((s&2081&a6)+((a7+(s&63454)|0)>>>1)<<1)>>1])&65535;s=k+1|0;b[(c[277218]|0)+(s<<1)>>1]=g;b[(c[277218]|0)+(k<<1)>>1]=g;g=a[1108909]|0;a[(c[277219]|0)+s|0]=g;a[(c[277219]|0)+k|0]=g}}while(0);if(!aB){a9=i;A=6360}break};case 3:{ba=j;A=6380;break};case 7:{A=6420;break};case 5:{bb=j;A=6400;break};case 6:{bc=j;A=6410;break};case 2:{bd=j;A=6370;break};case 1:{a9=j;A=6360;break};case 4:{be=j;A=6390;break};default:{}}if((A|0)==6360){A=0;g=k+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+g|0]|0)){s=a[aC+1|0]|0;if(s<<24>>24==0){break}a4=e[(c[277225]|0)+((s&255)<<1)>>1]|0;s=(a[(c[277215]|0)+g|0]&32)==0;if(s){a3=c[277228]|0;bf=a3;bg=a3&-2082}else{a3=e[(c[277213]|0)+(g<<1)>>1]|0;bf=a3;bg=a3&63454}if(s){bh=c[277228]|0}else{bh=e[(c[277213]|0)+(g<<1)>>1]|0}s=((bh^a4)&2081|e[(c[277220]|0)+((a4&2081&bf)+((bg+(a4&63454)|0)>>>1)<<1)>>1])&65535;a4=k+3|0;b[(c[277218]|0)+(a4<<1)>>1]=s;b[(c[277218]|0)+(g<<1)>>1]=s;s=a[1108909]|0;a[(c[277219]|0)+a4|0]=s;a[(c[277219]|0)+g|0]=s}}while(0);g=a9-1&255;if(g<<24>>24!=0){bd=g;A=6370}}if((A|0)==6370){A=0;g=k+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+g|0]|0)){s=a[aC+2|0]|0;if(s<<24>>24==0){break}a4=e[(c[277225]|0)+((s&255)<<1)>>1]|0;s=(a[(c[277215]|0)+g|0]&32)==0;if(s){a3=c[277228]|0;bi=a3;bj=a3&-2082}else{a3=e[(c[277213]|0)+(g<<1)>>1]|0;bi=a3;bj=a3&63454}if(s){bk=c[277228]|0}else{bk=e[(c[277213]|0)+(g<<1)>>1]|0}s=((bk^a4)&2081|e[(c[277220]|0)+((a4&2081&bi)+((bj+(a4&63454)|0)>>>1)<<1)>>1])&65535;a4=k+5|0;b[(c[277218]|0)+(a4<<1)>>1]=s;b[(c[277218]|0)+(g<<1)>>1]=s;s=a[1108909]|0;a[(c[277219]|0)+a4|0]=s;a[(c[277219]|0)+g|0]=s}}while(0);g=bd-1&255;if(g<<24>>24!=0){ba=g;A=6380}}if((A|0)==6380){A=0;g=k+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+g|0]|0)){s=a[aC+3|0]|0;if(s<<24>>24==0){break}a4=e[(c[277225]|0)+((s&255)<<1)>>1]|0;s=(a[(c[277215]|0)+g|0]&32)==0;if(s){a3=c[277228]|0;bl=a3;bm=a3&-2082}else{a3=e[(c[277213]|0)+(g<<1)>>1]|0;bl=a3;bm=a3&63454}if(s){bn=c[277228]|0}else{bn=e[(c[277213]|0)+(g<<1)>>1]|0}s=((bn^a4)&2081|e[(c[277220]|0)+((a4&2081&bl)+((bm+(a4&63454)|0)>>>1)<<1)>>1])&65535;a4=k+7|0;b[(c[277218]|0)+(a4<<1)>>1]=s;b[(c[277218]|0)+(g<<1)>>1]=s;s=a[1108909]|0;a[(c[277219]|0)+a4|0]=s;a[(c[277219]|0)+g|0]=s}}while(0);g=ba-1&255;if(g<<24>>24!=0){be=g;A=6390}}if((A|0)==6390){A=0;g=k+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+g|0]|0)){s=a[aC+4|0]|0;if(s<<24>>24==0){break}a4=e[(c[277225]|0)+((s&255)<<1)>>1]|0;s=(a[(c[277215]|0)+g|0]&32)==0;if(s){a3=c[277228]|0;bo=a3;bp=a3&-2082}else{a3=e[(c[277213]|0)+(g<<1)>>1]|0;bo=a3;bp=a3&63454}if(s){bq=c[277228]|0}else{bq=e[(c[277213]|0)+(g<<1)>>1]|0}s=((bq^a4)&2081|e[(c[277220]|0)+((a4&2081&bo)+((bp+(a4&63454)|0)>>>1)<<1)>>1])&65535;a4=k+9|0;b[(c[277218]|0)+(a4<<1)>>1]=s;b[(c[277218]|0)+(g<<1)>>1]=s;s=a[1108909]|0;a[(c[277219]|0)+a4|0]=s;a[(c[277219]|0)+g|0]=s}}while(0);g=be-1&255;if(g<<24>>24!=0){bb=g;A=6400}}if((A|0)==6400){A=0;g=k+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+g|0]|0)){s=a[aC+5|0]|0;if(s<<24>>24==0){break}a4=e[(c[277225]|0)+((s&255)<<1)>>1]|0;s=(a[(c[277215]|0)+g|0]&32)==0;if(s){a3=c[277228]|0;br=a3;bs=a3&-2082}else{a3=e[(c[277213]|0)+(g<<1)>>1]|0;br=a3;bs=a3&63454}if(s){bt=c[277228]|0}else{bt=e[(c[277213]|0)+(g<<1)>>1]|0}s=((bt^a4)&2081|e[(c[277220]|0)+((a4&2081&br)+((bs+(a4&63454)|0)>>>1)<<1)>>1])&65535;a4=k+11|0;b[(c[277218]|0)+(a4<<1)>>1]=s;b[(c[277218]|0)+(g<<1)>>1]=s;s=a[1108909]|0;a[(c[277219]|0)+a4|0]=s;a[(c[277219]|0)+g|0]=s}}while(0);g=bb-1&255;if(g<<24>>24!=0){bc=g;A=6410}}if((A|0)==6410){A=0;g=k+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+g|0]|0)){s=a[aC+6|0]|0;if(s<<24>>24==0){break}a4=e[(c[277225]|0)+((s&255)<<1)>>1]|0;s=(a[(c[277215]|0)+g|0]&32)==0;if(s){a3=c[277228]|0;bu=a3;bv=a3&-2082}else{a3=e[(c[277213]|0)+(g<<1)>>1]|0;bu=a3;bv=a3&63454}if(s){bw=c[277228]|0}else{bw=e[(c[277213]|0)+(g<<1)>>1]|0}s=((bw^a4)&2081|e[(c[277220]|0)+((a4&2081&bu)+((bv+(a4&63454)|0)>>>1)<<1)>>1])&65535;a4=k+13|0;b[(c[277218]|0)+(a4<<1)>>1]=s;b[(c[277218]|0)+(g<<1)>>1]=s;s=a[1108909]|0;a[(c[277219]|0)+a4|0]=s;a[(c[277219]|0)+g|0]=s}}while(0);if(bc<<24>>24!=1){A=6420}}do{if((A|0)==6420){A=0;g=k+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+g|0]|0)){break}s=a[aC+7|0]|0;if(s<<24>>24==0){break}a4=e[(c[277225]|0)+((s&255)<<1)>>1]|0;s=(a[(c[277215]|0)+g|0]&32)==0;if(s){a3=c[277228]|0;bx=a3;by=a3&-2082}else{a3=e[(c[277213]|0)+(g<<1)>>1]|0;bx=a3;by=a3&63454}if(s){bz=c[277228]|0}else{bz=e[(c[277213]|0)+(g<<1)>>1]|0}s=((bz^a4)&2081|e[(c[277220]|0)+((a4&2081&bx)+((by+(a4&63454)|0)>>>1)<<1)>>1])&65535;a4=k+15|0;b[(c[277218]|0)+(a4<<1)>>1]=s;b[(c[277218]|0)+(g<<1)>>1]=s;s=a[1108909]|0;a[(c[277219]|0)+a4|0]=s;a[(c[277219]|0)+g|0]=s}}while(0);s=Z-1|0;if((s|0)>0){aC=aC-8|0;Z=s;k=(c[277223]|0)+k|0}else{break}}return}}function Up(f,g,h,i,j,k){f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0;l=f&1023;m=c[348606]|0;n=(l<<m)+(c[348604]|0)|0;if((f&256|0)==0){o=n}else{o=(c[348602]|0)+n|0}n=o&65535;o=n>>>(m>>>0);m=(f&16384|0)!=0;p=o<<6;do{if(m){q=(c[348622]|0)+p|0;if((a[(c[348618]|0)+o|0]|0)!=0){r=q;break}s=fi[c[348636]&63](q,n,l)|0;a[(c[348618]|0)+o|0]=s;r=q}else{q=(c[348624]|0)+p|0;if((a[(c[348620]|0)+o|0]|0)!=0){r=q;break}s=fi[c[348638]&63](q,n,l)|0;a[(c[348620]|0)+o|0]=s;r=q}}while(0);if((a[(c[348620]|0)+o|0]|0)==2){return}if((a[1394464]|0)==0){t=1106168+((f>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){o=d[1044485]|0;c[276541]=7080+(o<<5);l=0;do{n=l<<1&2;p=l&2;q=l&4;s=0;do{b[1125528+(l<<9)+(s<<1)>>1]=d[(s>>>1&28|p)+(7080+(o<<5))|0]<<6|d[(s<<2&28|n)+(7080+(o<<5))|0]<<11|d[(s>>>3&24|q)+(7080+(o<<5))|0];s=s+1|0;}while(s>>>0<256);l=l+1|0;}while(l>>>0<8);a[1106089]=0}t=1125528+((f>>>10&7)<<9)|0}c[277226]=t;c[277225]=(a[1108928]|0)!=0?1393712:t;if((f&49152|0)==0){if((k|0)<=0){return}t=i&255;l=t-1&255;o=l<<24>>24==0;s=r+j|0;q=k;n=g;while(1){switch(h|0){case 7:{u=6584;break};case 5:{v=t;u=6572;break};case 4:{w=t;u=6566;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+n|0]|0)){p=a[s]|0;if(p<<24>>24==0){break}x=e[(c[277225]|0)+((p&255)<<1)>>1]|0;p=c[277228]|0;y=(((x&63454)+(p&-2082)|0)>>>1)+(p&2081&x)|0;if((a[1108928]|0)==0){z=y&65535}else{z=(e[(c[277220]|0)+(y<<1)>>1]|(x^p)&2081)&65535}p=n+1|0;b[(c[277218]|0)+(p<<1)>>1]=z;b[(c[277218]|0)+(n<<1)>>1]=z;x=a[1108909]|0;a[(c[277219]|0)+p|0]=x;a[(c[277219]|0)+n|0]=x}}while(0);if(!o){A=l;u=6548}break};case 2:{B=t;u=6554;break};case 3:{C=t;u=6560;break};case 1:{A=t;u=6548;break};case 6:{D=t;u=6578;break};default:{}}if((u|0)==6548){u=0;x=n+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+x|0]|0)){p=a[s+1|0]|0;if(p<<24>>24==0){break}y=e[(c[277225]|0)+((p&255)<<1)>>1]|0;p=c[277228]|0;E=(((y&63454)+(p&-2082)|0)>>>1)+(p&2081&y)|0;if((a[1108928]|0)==0){F=E&65535}else{F=(e[(c[277220]|0)+(E<<1)>>1]|(y^p)&2081)&65535}p=n+3|0;b[(c[277218]|0)+(p<<1)>>1]=F;b[(c[277218]|0)+(x<<1)>>1]=F;y=a[1108909]|0;a[(c[277219]|0)+p|0]=y;a[(c[277219]|0)+x|0]=y}}while(0);x=A-1&255;if(x<<24>>24!=0){B=x;u=6554}}if((u|0)==6554){u=0;x=n+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+x|0]|0)){y=a[s+2|0]|0;if(y<<24>>24==0){break}p=e[(c[277225]|0)+((y&255)<<1)>>1]|0;y=c[277228]|0;E=(((p&63454)+(y&-2082)|0)>>>1)+(y&2081&p)|0;if((a[1108928]|0)==0){G=E&65535}else{G=(e[(c[277220]|0)+(E<<1)>>1]|(p^y)&2081)&65535}y=n+5|0;b[(c[277218]|0)+(y<<1)>>1]=G;b[(c[277218]|0)+(x<<1)>>1]=G;p=a[1108909]|0;a[(c[277219]|0)+y|0]=p;a[(c[277219]|0)+x|0]=p}}while(0);x=B-1&255;if(x<<24>>24!=0){C=x;u=6560}}if((u|0)==6560){u=0;x=n+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+x|0]|0)){p=a[s+3|0]|0;if(p<<24>>24==0){break}y=e[(c[277225]|0)+((p&255)<<1)>>1]|0;p=c[277228]|0;E=(((y&63454)+(p&-2082)|0)>>>1)+(p&2081&y)|0;if((a[1108928]|0)==0){H=E&65535}else{H=(e[(c[277220]|0)+(E<<1)>>1]|(y^p)&2081)&65535}p=n+7|0;b[(c[277218]|0)+(p<<1)>>1]=H;b[(c[277218]|0)+(x<<1)>>1]=H;y=a[1108909]|0;a[(c[277219]|0)+p|0]=y;a[(c[277219]|0)+x|0]=y}}while(0);x=C-1&255;if(x<<24>>24!=0){w=x;u=6566}}if((u|0)==6566){u=0;x=n+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+x|0]|0)){y=a[s+4|0]|0;if(y<<24>>24==0){break}p=e[(c[277225]|0)+((y&255)<<1)>>1]|0;y=c[277228]|0;E=(((p&63454)+(y&-2082)|0)>>>1)+(y&2081&p)|0;if((a[1108928]|0)==0){I=E&65535}else{I=(e[(c[277220]|0)+(E<<1)>>1]|(p^y)&2081)&65535}y=n+9|0;b[(c[277218]|0)+(y<<1)>>1]=I;b[(c[277218]|0)+(x<<1)>>1]=I;p=a[1108909]|0;a[(c[277219]|0)+y|0]=p;a[(c[277219]|0)+x|0]=p}}while(0);x=w-1&255;if(x<<24>>24!=0){v=x;u=6572}}if((u|0)==6572){u=0;x=n+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+x|0]|0)){p=a[s+5|0]|0;if(p<<24>>24==0){break}y=e[(c[277225]|0)+((p&255)<<1)>>1]|0;p=c[277228]|0;E=(((y&63454)+(p&-2082)|0)>>>1)+(p&2081&y)|0;if((a[1108928]|0)==0){J=E&65535}else{J=(e[(c[277220]|0)+(E<<1)>>1]|(y^p)&2081)&65535}p=n+11|0;b[(c[277218]|0)+(p<<1)>>1]=J;b[(c[277218]|0)+(x<<1)>>1]=J;y=a[1108909]|0;a[(c[277219]|0)+p|0]=y;a[(c[277219]|0)+x|0]=y}}while(0);x=v-1&255;if(x<<24>>24!=0){D=x;u=6578}}if((u|0)==6578){u=0;x=n+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+x|0]|0)){y=a[s+6|0]|0;if(y<<24>>24==0){break}p=e[(c[277225]|0)+((y&255)<<1)>>1]|0;y=c[277228]|0;E=(((p&63454)+(y&-2082)|0)>>>1)+(y&2081&p)|0;if((a[1108928]|0)==0){K=E&65535}else{K=(e[(c[277220]|0)+(E<<1)>>1]|(p^y)&2081)&65535}y=n+13|0;b[(c[277218]|0)+(y<<1)>>1]=K;b[(c[277218]|0)+(x<<1)>>1]=K;p=a[1108909]|0;a[(c[277219]|0)+y|0]=p;a[(c[277219]|0)+x|0]=p}}while(0);if(D<<24>>24!=1){u=6584}}do{if((u|0)==6584){u=0;x=n+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+x|0]|0)){break}p=a[s+7|0]|0;if(p<<24>>24==0){break}y=e[(c[277225]|0)+((p&255)<<1)>>1]|0;p=c[277228]|0;E=(((y&63454)+(p&-2082)|0)>>>1)+(p&2081&y)|0;if((a[1108928]|0)==0){L=E&65535}else{L=(e[(c[277220]|0)+(E<<1)>>1]|(y^p)&2081)&65535}p=n+15|0;b[(c[277218]|0)+(p<<1)>>1]=L;b[(c[277218]|0)+(x<<1)>>1]=L;y=a[1108909]|0;a[(c[277219]|0)+p|0]=y;a[(c[277219]|0)+x|0]=y}}while(0);y=q-1|0;if((y|0)>0){s=s+8|0;q=y;n=(c[277223]|0)+n|0}else{break}}return}if((f&32768|0)==0){if((k|0)<=0){return}f=i&255;n=f-1&255;q=n<<24>>24==0;s=r+j|0;L=k;D=g;while(1){switch(h|0){case 2:{M=f;u=6606;break};case 3:{N=f;u=6612;break};case 7:{u=6636;break};case 5:{O=f;u=6624;break};case 6:{P=f;u=6630;break};case 4:{Q=f;u=6618;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+D|0]|0)){K=a[s+7|0]|0;if(K<<24>>24==0){break}v=e[(c[277225]|0)+((K&255)<<1)>>1]|0;K=c[277228]|0;J=(((v&63454)+(K&-2082)|0)>>>1)+(K&2081&v)|0;if((a[1108928]|0)==0){R=J&65535}else{R=(e[(c[277220]|0)+(J<<1)>>1]|(v^K)&2081)&65535}K=D+1|0;b[(c[277218]|0)+(K<<1)>>1]=R;b[(c[277218]|0)+(D<<1)>>1]=R;v=a[1108909]|0;a[(c[277219]|0)+K|0]=v;a[(c[277219]|0)+D|0]=v}}while(0);if(!q){S=n;u=6600}break};case 1:{S=f;u=6600;break};default:{}}if((u|0)==6600){u=0;v=D+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+v|0]|0)){K=a[s+6|0]|0;if(K<<24>>24==0){break}J=e[(c[277225]|0)+((K&255)<<1)>>1]|0;K=c[277228]|0;w=(((J&63454)+(K&-2082)|0)>>>1)+(K&2081&J)|0;if((a[1108928]|0)==0){T=w&65535}else{T=(e[(c[277220]|0)+(w<<1)>>1]|(J^K)&2081)&65535}K=D+3|0;b[(c[277218]|0)+(K<<1)>>1]=T;b[(c[277218]|0)+(v<<1)>>1]=T;J=a[1108909]|0;a[(c[277219]|0)+K|0]=J;a[(c[277219]|0)+v|0]=J}}while(0);v=S-1&255;if(v<<24>>24!=0){M=v;u=6606}}if((u|0)==6606){u=0;v=D+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+v|0]|0)){J=a[s+5|0]|0;if(J<<24>>24==0){break}K=e[(c[277225]|0)+((J&255)<<1)>>1]|0;J=c[277228]|0;w=(((K&63454)+(J&-2082)|0)>>>1)+(J&2081&K)|0;if((a[1108928]|0)==0){U=w&65535}else{U=(e[(c[277220]|0)+(w<<1)>>1]|(K^J)&2081)&65535}J=D+5|0;b[(c[277218]|0)+(J<<1)>>1]=U;b[(c[277218]|0)+(v<<1)>>1]=U;K=a[1108909]|0;a[(c[277219]|0)+J|0]=K;a[(c[277219]|0)+v|0]=K}}while(0);v=M-1&255;if(v<<24>>24!=0){N=v;u=6612}}if((u|0)==6612){u=0;v=D+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+v|0]|0)){K=a[s+4|0]|0;if(K<<24>>24==0){break}J=e[(c[277225]|0)+((K&255)<<1)>>1]|0;K=c[277228]|0;w=(((J&63454)+(K&-2082)|0)>>>1)+(K&2081&J)|0;if((a[1108928]|0)==0){V=w&65535}else{V=(e[(c[277220]|0)+(w<<1)>>1]|(J^K)&2081)&65535}K=D+7|0;b[(c[277218]|0)+(K<<1)>>1]=V;b[(c[277218]|0)+(v<<1)>>1]=V;J=a[1108909]|0;a[(c[277219]|0)+K|0]=J;a[(c[277219]|0)+v|0]=J}}while(0);v=N-1&255;if(v<<24>>24!=0){Q=v;u=6618}}if((u|0)==6618){u=0;v=D+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+v|0]|0)){J=a[s+3|0]|0;if(J<<24>>24==0){break}K=e[(c[277225]|0)+((J&255)<<1)>>1]|0;J=c[277228]|0;w=(((K&63454)+(J&-2082)|0)>>>1)+(J&2081&K)|0;if((a[1108928]|0)==0){W=w&65535}else{W=(e[(c[277220]|0)+(w<<1)>>1]|(K^J)&2081)&65535}J=D+9|0;b[(c[277218]|0)+(J<<1)>>1]=W;b[(c[277218]|0)+(v<<1)>>1]=W;K=a[1108909]|0;a[(c[277219]|0)+J|0]=K;a[(c[277219]|0)+v|0]=K}}while(0);v=Q-1&255;if(v<<24>>24!=0){O=v;u=6624}}if((u|0)==6624){u=0;v=D+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+v|0]|0)){K=a[s+2|0]|0;if(K<<24>>24==0){break}J=e[(c[277225]|0)+((K&255)<<1)>>1]|0;K=c[277228]|0;w=(((J&63454)+(K&-2082)|0)>>>1)+(K&2081&J)|0;if((a[1108928]|0)==0){X=w&65535}else{X=(e[(c[277220]|0)+(w<<1)>>1]|(J^K)&2081)&65535}K=D+11|0;b[(c[277218]|0)+(K<<1)>>1]=X;b[(c[277218]|0)+(v<<1)>>1]=X;J=a[1108909]|0;a[(c[277219]|0)+K|0]=J;a[(c[277219]|0)+v|0]=J}}while(0);v=O-1&255;if(v<<24>>24!=0){P=v;u=6630}}if((u|0)==6630){u=0;v=D+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+v|0]|0)){J=a[s+1|0]|0;if(J<<24>>24==0){break}K=e[(c[277225]|0)+((J&255)<<1)>>1]|0;J=c[277228]|0;w=(((K&63454)+(J&-2082)|0)>>>1)+(J&2081&K)|0;if((a[1108928]|0)==0){Y=w&65535}else{Y=(e[(c[277220]|0)+(w<<1)>>1]|(K^J)&2081)&65535}J=D+13|0;b[(c[277218]|0)+(J<<1)>>1]=Y;b[(c[277218]|0)+(v<<1)>>1]=Y;K=a[1108909]|0;a[(c[277219]|0)+J|0]=K;a[(c[277219]|0)+v|0]=K}}while(0);if(P<<24>>24!=1){u=6636}}do{if((u|0)==6636){u=0;v=D+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+v|0]|0)){break}K=a[s]|0;if(K<<24>>24==0){break}J=e[(c[277225]|0)+((K&255)<<1)>>1]|0;K=c[277228]|0;w=(((J&63454)+(K&-2082)|0)>>>1)+(K&2081&J)|0;if((a[1108928]|0)==0){Z=w&65535}else{Z=(e[(c[277220]|0)+(w<<1)>>1]|(J^K)&2081)&65535}K=D+15|0;b[(c[277218]|0)+(K<<1)>>1]=Z;b[(c[277218]|0)+(v<<1)>>1]=Z;J=a[1108909]|0;a[(c[277219]|0)+K|0]=J;a[(c[277219]|0)+v|0]=J}}while(0);J=L-1|0;if((J|0)>0){s=s+8|0;L=J;D=(c[277223]|0)+D|0}else{break}}return}D=r+(56-j)|0;j=(k|0)>0;if(m){if(!j){return}m=i&255;r=m-1&255;L=r<<24>>24==0;s=D;Z=k;P=g;while(1){switch(h|0){case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+P|0]|0)){Y=a[s+7|0]|0;if(Y<<24>>24==0){break}O=e[(c[277225]|0)+((Y&255)<<1)>>1]|0;Y=c[277228]|0;X=(((O&63454)+(Y&-2082)|0)>>>1)+(Y&2081&O)|0;if((a[1108928]|0)==0){_=X&65535}else{_=(e[(c[277220]|0)+(X<<1)>>1]|(O^Y)&2081)&65535}Y=P+1|0;b[(c[277218]|0)+(Y<<1)>>1]=_;b[(c[277218]|0)+(P<<1)>>1]=_;O=a[1108909]|0;a[(c[277219]|0)+Y|0]=O;a[(c[277219]|0)+P|0]=O}}while(0);if(!L){$=r;u=6703}break};case 1:{$=m;u=6703;break};case 6:{aa=m;u=6733;break};case 7:{u=6739;break};case 4:{ab=m;u=6721;break};case 5:{ac=m;u=6727;break};case 2:{ad=m;u=6709;break};case 3:{ae=m;u=6715;break};default:{}}if((u|0)==6703){u=0;O=P+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+O|0]|0)){Y=a[s+6|0]|0;if(Y<<24>>24==0){break}X=e[(c[277225]|0)+((Y&255)<<1)>>1]|0;Y=c[277228]|0;Q=(((X&63454)+(Y&-2082)|0)>>>1)+(Y&2081&X)|0;if((a[1108928]|0)==0){af=Q&65535}else{af=(e[(c[277220]|0)+(Q<<1)>>1]|(X^Y)&2081)&65535}Y=P+3|0;b[(c[277218]|0)+(Y<<1)>>1]=af;b[(c[277218]|0)+(O<<1)>>1]=af;X=a[1108909]|0;a[(c[277219]|0)+Y|0]=X;a[(c[277219]|0)+O|0]=X}}while(0);O=$-1&255;if(O<<24>>24!=0){ad=O;u=6709}}if((u|0)==6709){u=0;O=P+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+O|0]|0)){X=a[s+5|0]|0;if(X<<24>>24==0){break}Y=e[(c[277225]|0)+((X&255)<<1)>>1]|0;X=c[277228]|0;Q=(((Y&63454)+(X&-2082)|0)>>>1)+(X&2081&Y)|0;if((a[1108928]|0)==0){ag=Q&65535}else{ag=(e[(c[277220]|0)+(Q<<1)>>1]|(Y^X)&2081)&65535}X=P+5|0;b[(c[277218]|0)+(X<<1)>>1]=ag;b[(c[277218]|0)+(O<<1)>>1]=ag;Y=a[1108909]|0;a[(c[277219]|0)+X|0]=Y;a[(c[277219]|0)+O|0]=Y}}while(0);O=ad-1&255;if(O<<24>>24!=0){ae=O;u=6715}}if((u|0)==6715){u=0;O=P+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+O|0]|0)){Y=a[s+4|0]|0;if(Y<<24>>24==0){break}X=e[(c[277225]|0)+((Y&255)<<1)>>1]|0;Y=c[277228]|0;Q=(((X&63454)+(Y&-2082)|0)>>>1)+(Y&2081&X)|0;if((a[1108928]|0)==0){ah=Q&65535}else{ah=(e[(c[277220]|0)+(Q<<1)>>1]|(X^Y)&2081)&65535}Y=P+7|0;b[(c[277218]|0)+(Y<<1)>>1]=ah;b[(c[277218]|0)+(O<<1)>>1]=ah;X=a[1108909]|0;a[(c[277219]|0)+Y|0]=X;a[(c[277219]|0)+O|0]=X}}while(0);O=ae-1&255;if(O<<24>>24!=0){ab=O;u=6721}}if((u|0)==6721){u=0;O=P+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+O|0]|0)){X=a[s+3|0]|0;if(X<<24>>24==0){break}Y=e[(c[277225]|0)+((X&255)<<1)>>1]|0;X=c[277228]|0;Q=(((Y&63454)+(X&-2082)|0)>>>1)+(X&2081&Y)|0;if((a[1108928]|0)==0){ai=Q&65535}else{ai=(e[(c[277220]|0)+(Q<<1)>>1]|(Y^X)&2081)&65535}X=P+9|0;b[(c[277218]|0)+(X<<1)>>1]=ai;b[(c[277218]|0)+(O<<1)>>1]=ai;Y=a[1108909]|0;a[(c[277219]|0)+X|0]=Y;a[(c[277219]|0)+O|0]=Y}}while(0);O=ab-1&255;if(O<<24>>24!=0){ac=O;u=6727}}if((u|0)==6727){u=0;O=P+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+O|0]|0)){Y=a[s+2|0]|0;if(Y<<24>>24==0){break}X=e[(c[277225]|0)+((Y&255)<<1)>>1]|0;Y=c[277228]|0;Q=(((X&63454)+(Y&-2082)|0)>>>1)+(Y&2081&X)|0;if((a[1108928]|0)==0){aj=Q&65535}else{aj=(e[(c[277220]|0)+(Q<<1)>>1]|(X^Y)&2081)&65535}Y=P+11|0;b[(c[277218]|0)+(Y<<1)>>1]=aj;b[(c[277218]|0)+(O<<1)>>1]=aj;X=a[1108909]|0;a[(c[277219]|0)+Y|0]=X;a[(c[277219]|0)+O|0]=X}}while(0);O=ac-1&255;if(O<<24>>24!=0){aa=O;u=6733}}if((u|0)==6733){u=0;O=P+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+O|0]|0)){X=a[s+1|0]|0;if(X<<24>>24==0){break}Y=e[(c[277225]|0)+((X&255)<<1)>>1]|0;X=c[277228]|0;Q=(((Y&63454)+(X&-2082)|0)>>>1)+(X&2081&Y)|0;if((a[1108928]|0)==0){ak=Q&65535}else{ak=(e[(c[277220]|0)+(Q<<1)>>1]|(Y^X)&2081)&65535}X=P+13|0;b[(c[277218]|0)+(X<<1)>>1]=ak;b[(c[277218]|0)+(O<<1)>>1]=ak;Y=a[1108909]|0;a[(c[277219]|0)+X|0]=Y;a[(c[277219]|0)+O|0]=Y}}while(0);if(aa<<24>>24!=1){u=6739}}do{if((u|0)==6739){u=0;O=P+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+O|0]|0)){break}Y=a[s]|0;if(Y<<24>>24==0){break}X=e[(c[277225]|0)+((Y&255)<<1)>>1]|0;Y=c[277228]|0;Q=(((X&63454)+(Y&-2082)|0)>>>1)+(Y&2081&X)|0;if((a[1108928]|0)==0){al=Q&65535}else{al=(e[(c[277220]|0)+(Q<<1)>>1]|(X^Y)&2081)&65535}Y=P+15|0;b[(c[277218]|0)+(Y<<1)>>1]=al;b[(c[277218]|0)+(O<<1)>>1]=al;X=a[1108909]|0;a[(c[277219]|0)+Y|0]=X;a[(c[277219]|0)+O|0]=X}}while(0);X=Z-1|0;if((X|0)>0){s=s-8|0;Z=X;P=(c[277223]|0)+P|0}else{break}}return}else{if(!j){return}j=i&255;i=j-1&255;P=i<<24>>24==0;Z=D;D=k;k=g;while(1){switch(h|0){case 6:{am=j;u=6684;break};case 7:{u=6690;break};case 3:{an=j;u=6666;break};case 1:{ao=j;u=6654;break};case 2:{ap=j;u=6660;break};case 4:{aq=j;u=6672;break};case 5:{ar=j;u=6678;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+k|0]|0)){g=a[Z]|0;if(g<<24>>24==0){break}s=e[(c[277225]|0)+((g&255)<<1)>>1]|0;g=c[277228]|0;al=(((s&63454)+(g&-2082)|0)>>>1)+(g&2081&s)|0;if((a[1108928]|0)==0){as=al&65535}else{as=(e[(c[277220]|0)+(al<<1)>>1]|(s^g)&2081)&65535}g=k+1|0;b[(c[277218]|0)+(g<<1)>>1]=as;b[(c[277218]|0)+(k<<1)>>1]=as;s=a[1108909]|0;a[(c[277219]|0)+g|0]=s;a[(c[277219]|0)+k|0]=s}}while(0);if(!P){ao=i;u=6654}break};default:{}}if((u|0)==6654){u=0;s=k+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+s|0]|0)){g=a[Z+1|0]|0;if(g<<24>>24==0){break}al=e[(c[277225]|0)+((g&255)<<1)>>1]|0;g=c[277228]|0;aa=(((al&63454)+(g&-2082)|0)>>>1)+(g&2081&al)|0;if((a[1108928]|0)==0){at=aa&65535}else{at=(e[(c[277220]|0)+(aa<<1)>>1]|(al^g)&2081)&65535}g=k+3|0;b[(c[277218]|0)+(g<<1)>>1]=at;b[(c[277218]|0)+(s<<1)>>1]=at;al=a[1108909]|0;a[(c[277219]|0)+g|0]=al;a[(c[277219]|0)+s|0]=al}}while(0);s=ao-1&255;if(s<<24>>24!=0){ap=s;u=6660}}if((u|0)==6660){u=0;s=k+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+s|0]|0)){al=a[Z+2|0]|0;if(al<<24>>24==0){break}g=e[(c[277225]|0)+((al&255)<<1)>>1]|0;al=c[277228]|0;aa=(((g&63454)+(al&-2082)|0)>>>1)+(al&2081&g)|0;if((a[1108928]|0)==0){au=aa&65535}else{au=(e[(c[277220]|0)+(aa<<1)>>1]|(g^al)&2081)&65535}al=k+5|0;b[(c[277218]|0)+(al<<1)>>1]=au;b[(c[277218]|0)+(s<<1)>>1]=au;g=a[1108909]|0;a[(c[277219]|0)+al|0]=g;a[(c[277219]|0)+s|0]=g}}while(0);s=ap-1&255;if(s<<24>>24!=0){an=s;u=6666}}if((u|0)==6666){u=0;s=k+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+s|0]|0)){g=a[Z+3|0]|0;if(g<<24>>24==0){break}al=e[(c[277225]|0)+((g&255)<<1)>>1]|0;g=c[277228]|0;aa=(((al&63454)+(g&-2082)|0)>>>1)+(g&2081&al)|0;if((a[1108928]|0)==0){av=aa&65535}else{av=(e[(c[277220]|0)+(aa<<1)>>1]|(al^g)&2081)&65535}g=k+7|0;b[(c[277218]|0)+(g<<1)>>1]=av;b[(c[277218]|0)+(s<<1)>>1]=av;al=a[1108909]|0;a[(c[277219]|0)+g|0]=al;a[(c[277219]|0)+s|0]=al}}while(0);s=an-1&255;if(s<<24>>24!=0){aq=s;u=6672}}if((u|0)==6672){u=0;s=k+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+s|0]|0)){al=a[Z+4|0]|0;if(al<<24>>24==0){break}g=e[(c[277225]|0)+((al&255)<<1)>>1]|0;al=c[277228]|0;aa=(((g&63454)+(al&-2082)|0)>>>1)+(al&2081&g)|0;if((a[1108928]|0)==0){aw=aa&65535}else{aw=(e[(c[277220]|0)+(aa<<1)>>1]|(g^al)&2081)&65535}al=k+9|0;b[(c[277218]|0)+(al<<1)>>1]=aw;b[(c[277218]|0)+(s<<1)>>1]=aw;g=a[1108909]|0;a[(c[277219]|0)+al|0]=g;a[(c[277219]|0)+s|0]=g}}while(0);s=aq-1&255;if(s<<24>>24!=0){ar=s;u=6678}}if((u|0)==6678){u=0;s=k+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+s|0]|0)){g=a[Z+5|0]|0;if(g<<24>>24==0){break}al=e[(c[277225]|0)+((g&255)<<1)>>1]|0;g=c[277228]|0;aa=(((al&63454)+(g&-2082)|0)>>>1)+(g&2081&al)|0;if((a[1108928]|0)==0){ax=aa&65535}else{ax=(e[(c[277220]|0)+(aa<<1)>>1]|(al^g)&2081)&65535}g=k+11|0;b[(c[277218]|0)+(g<<1)>>1]=ax;b[(c[277218]|0)+(s<<1)>>1]=ax;al=a[1108909]|0;a[(c[277219]|0)+g|0]=al;a[(c[277219]|0)+s|0]=al}}while(0);s=ar-1&255;if(s<<24>>24!=0){am=s;u=6684}}if((u|0)==6684){u=0;s=k+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+s|0]|0)){al=a[Z+6|0]|0;if(al<<24>>24==0){break}g=e[(c[277225]|0)+((al&255)<<1)>>1]|0;al=c[277228]|0;aa=(((g&63454)+(al&-2082)|0)>>>1)+(al&2081&g)|0;if((a[1108928]|0)==0){ay=aa&65535}else{ay=(e[(c[277220]|0)+(aa<<1)>>1]|(g^al)&2081)&65535}al=k+13|0;b[(c[277218]|0)+(al<<1)>>1]=ay;b[(c[277218]|0)+(s<<1)>>1]=ay;g=a[1108909]|0;a[(c[277219]|0)+al|0]=g;a[(c[277219]|0)+s|0]=g}}while(0);if(am<<24>>24!=1){u=6690}}do{if((u|0)==6690){u=0;s=k+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+s|0]|0)){break}g=a[Z+7|0]|0;if(g<<24>>24==0){break}al=e[(c[277225]|0)+((g&255)<<1)>>1]|0;g=c[277228]|0;aa=(((al&63454)+(g&-2082)|0)>>>1)+(g&2081&al)|0;if((a[1108928]|0)==0){az=aa&65535}else{az=(e[(c[277220]|0)+(aa<<1)>>1]|(al^g)&2081)&65535}g=k+15|0;b[(c[277218]|0)+(g<<1)>>1]=az;b[(c[277218]|0)+(s<<1)>>1]=az;al=a[1108909]|0;a[(c[277219]|0)+g|0]=al;a[(c[277219]|0)+s|0]=al}}while(0);al=D-1|0;if((al|0)>0){Z=Z-8|0;D=al;k=(c[277223]|0)+k|0}else{break}}return}}function Uq(f,g,h,i,j,k){f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0;l=f&1023;m=c[348606]|0;n=(l<<m)+(c[348604]|0)|0;if((f&256|0)==0){o=n}else{o=(c[348602]|0)+n|0}n=o&65535;o=n>>>(m>>>0);m=(f&16384|0)!=0;p=o<<6;do{if(m){q=(c[348622]|0)+p|0;if((a[(c[348618]|0)+o|0]|0)!=0){r=q;break}s=fi[c[348636]&63](q,n,l)|0;a[(c[348618]|0)+o|0]=s;r=q}else{q=(c[348624]|0)+p|0;if((a[(c[348620]|0)+o|0]|0)!=0){r=q;break}s=fi[c[348638]&63](q,n,l)|0;a[(c[348620]|0)+o|0]=s;r=q}}while(0);if((a[(c[348620]|0)+o|0]|0)==2){return}if((a[1394464]|0)==0){t=1106168+((f>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){o=d[1044485]|0;c[276541]=7080+(o<<5);l=0;do{n=l<<1&2;p=l&2;q=l&4;s=0;do{b[1125528+(l<<9)+(s<<1)>>1]=d[(s>>>1&28|p)+(7080+(o<<5))|0]<<6|d[(s<<2&28|n)+(7080+(o<<5))|0]<<11|d[(s>>>3&24|q)+(7080+(o<<5))|0];s=s+1|0;}while(s>>>0<256);l=l+1|0;}while(l>>>0<8);a[1106089]=0}t=1125528+((f>>>10&7)<<9)|0}c[277226]=t;c[277225]=(a[1108928]|0)!=0?1393712:t;if((f&49152|0)==0){if((k|0)<=0){return}t=i&255;l=t-1&255;o=l<<24>>24==0;s=r+j|0;q=k;n=g;while(1){switch(h|0){case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+n|0]|0)){p=a[s]|0;u=p&255;if(p<<24>>24==0){break}do{if((a[1108928]|0)==0){p=b[(c[277225]|0)+(u<<1)>>1]|0;v=p&65535;w=v&63454;if((a[(c[277215]|0)+n|0]&32)==0){x=c[277228]|0;y=(e[(c[277220]|0)+((((x&-2082)+w|0)>>>1)+(v&2081&x)<<1)>>1]|(x^v)&2081)&65535;break}else{v=b[(c[277213]|0)+(n<<1)>>1]|0;y=(((v&63454)+w|0)>>>1)+(v&p&2081)&65535;break}}else{p=e[(c[277225]|0)+(u<<1)>>1]|0;v=(a[(c[277215]|0)+n|0]&32)==0;if(v){w=c[277228]|0;z=w;A=w&-2082}else{w=e[(c[277213]|0)+(n<<1)>>1]|0;z=w;A=w&63454}if(v){B=c[277228]|0}else{B=e[(c[277213]|0)+(n<<1)>>1]|0}y=((B^p)&2081|e[(c[277220]|0)+((p&2081&z)+((A+(p&63454)|0)>>>1)<<1)>>1])&65535}}while(0);u=n+1|0;b[(c[277218]|0)+(u<<1)>>1]=y;b[(c[277218]|0)+(n<<1)>>1]=y;p=a[1108909]|0;a[(c[277219]|0)+u|0]=p;a[(c[277219]|0)+n|0]=p}}while(0);if(!o){C=l;D=6791}break};case 1:{C=t;D=6791;break};case 2:{E=t;D=6806;break};case 3:{F=t;D=6821;break};case 4:{G=t;D=6836;break};case 5:{H=t;D=6851;break};case 6:{I=t;D=6866;break};case 7:{D=6881;break};default:{}}if((D|0)==6791){D=0;p=n+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){u=a[s+1|0]|0;v=u&255;if(u<<24>>24==0){break}do{if((a[1108928]|0)==0){u=b[(c[277225]|0)+(v<<1)>>1]|0;w=u&65535;x=w&63454;if((a[(c[277215]|0)+p|0]&32)==0){J=c[277228]|0;K=(e[(c[277220]|0)+((((J&-2082)+x|0)>>>1)+(w&2081&J)<<1)>>1]|(J^w)&2081)&65535;break}else{w=b[(c[277213]|0)+(p<<1)>>1]|0;K=(((w&63454)+x|0)>>>1)+(w&u&2081)&65535;break}}else{u=e[(c[277225]|0)+(v<<1)>>1]|0;w=(a[(c[277215]|0)+p|0]&32)==0;if(w){x=c[277228]|0;L=x;M=x&-2082}else{x=e[(c[277213]|0)+(p<<1)>>1]|0;L=x;M=x&63454}if(w){N=c[277228]|0}else{N=e[(c[277213]|0)+(p<<1)>>1]|0}K=((N^u)&2081|e[(c[277220]|0)+((u&2081&L)+((M+(u&63454)|0)>>>1)<<1)>>1])&65535}}while(0);v=n+3|0;b[(c[277218]|0)+(v<<1)>>1]=K;b[(c[277218]|0)+(p<<1)>>1]=K;u=a[1108909]|0;a[(c[277219]|0)+v|0]=u;a[(c[277219]|0)+p|0]=u}}while(0);p=C-1&255;if(p<<24>>24!=0){E=p;D=6806}}if((D|0)==6806){D=0;p=n+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){u=a[s+2|0]|0;v=u&255;if(u<<24>>24==0){break}do{if((a[1108928]|0)==0){u=b[(c[277225]|0)+(v<<1)>>1]|0;w=u&65535;x=w&63454;if((a[(c[277215]|0)+p|0]&32)==0){J=c[277228]|0;O=(e[(c[277220]|0)+((((J&-2082)+x|0)>>>1)+(w&2081&J)<<1)>>1]|(J^w)&2081)&65535;break}else{w=b[(c[277213]|0)+(p<<1)>>1]|0;O=(((w&63454)+x|0)>>>1)+(w&u&2081)&65535;break}}else{u=e[(c[277225]|0)+(v<<1)>>1]|0;w=(a[(c[277215]|0)+p|0]&32)==0;if(w){x=c[277228]|0;P=x;Q=x&-2082}else{x=e[(c[277213]|0)+(p<<1)>>1]|0;P=x;Q=x&63454}if(w){R=c[277228]|0}else{R=e[(c[277213]|0)+(p<<1)>>1]|0}O=((R^u)&2081|e[(c[277220]|0)+((u&2081&P)+((Q+(u&63454)|0)>>>1)<<1)>>1])&65535}}while(0);v=n+5|0;b[(c[277218]|0)+(v<<1)>>1]=O;b[(c[277218]|0)+(p<<1)>>1]=O;u=a[1108909]|0;a[(c[277219]|0)+v|0]=u;a[(c[277219]|0)+p|0]=u}}while(0);p=E-1&255;if(p<<24>>24!=0){F=p;D=6821}}if((D|0)==6821){D=0;p=n+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){u=a[s+3|0]|0;v=u&255;if(u<<24>>24==0){break}do{if((a[1108928]|0)==0){u=b[(c[277225]|0)+(v<<1)>>1]|0;w=u&65535;x=w&63454;if((a[(c[277215]|0)+p|0]&32)==0){J=c[277228]|0;S=(e[(c[277220]|0)+((((J&-2082)+x|0)>>>1)+(w&2081&J)<<1)>>1]|(J^w)&2081)&65535;break}else{w=b[(c[277213]|0)+(p<<1)>>1]|0;S=(((w&63454)+x|0)>>>1)+(w&u&2081)&65535;break}}else{u=e[(c[277225]|0)+(v<<1)>>1]|0;w=(a[(c[277215]|0)+p|0]&32)==0;if(w){x=c[277228]|0;T=x;U=x&-2082}else{x=e[(c[277213]|0)+(p<<1)>>1]|0;T=x;U=x&63454}if(w){V=c[277228]|0}else{V=e[(c[277213]|0)+(p<<1)>>1]|0}S=((V^u)&2081|e[(c[277220]|0)+((u&2081&T)+((U+(u&63454)|0)>>>1)<<1)>>1])&65535}}while(0);v=n+7|0;b[(c[277218]|0)+(v<<1)>>1]=S;b[(c[277218]|0)+(p<<1)>>1]=S;u=a[1108909]|0;a[(c[277219]|0)+v|0]=u;a[(c[277219]|0)+p|0]=u}}while(0);p=F-1&255;if(p<<24>>24!=0){G=p;D=6836}}if((D|0)==6836){D=0;p=n+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){u=a[s+4|0]|0;v=u&255;if(u<<24>>24==0){break}do{if((a[1108928]|0)==0){u=b[(c[277225]|0)+(v<<1)>>1]|0;w=u&65535;x=w&63454;if((a[(c[277215]|0)+p|0]&32)==0){J=c[277228]|0;W=(e[(c[277220]|0)+((((J&-2082)+x|0)>>>1)+(w&2081&J)<<1)>>1]|(J^w)&2081)&65535;break}else{w=b[(c[277213]|0)+(p<<1)>>1]|0;W=(((w&63454)+x|0)>>>1)+(w&u&2081)&65535;break}}else{u=e[(c[277225]|0)+(v<<1)>>1]|0;w=(a[(c[277215]|0)+p|0]&32)==0;if(w){x=c[277228]|0;X=x;Y=x&-2082}else{x=e[(c[277213]|0)+(p<<1)>>1]|0;X=x;Y=x&63454}if(w){Z=c[277228]|0}else{Z=e[(c[277213]|0)+(p<<1)>>1]|0}W=((Z^u)&2081|e[(c[277220]|0)+((u&2081&X)+((Y+(u&63454)|0)>>>1)<<1)>>1])&65535}}while(0);v=n+9|0;b[(c[277218]|0)+(v<<1)>>1]=W;b[(c[277218]|0)+(p<<1)>>1]=W;u=a[1108909]|0;a[(c[277219]|0)+v|0]=u;a[(c[277219]|0)+p|0]=u}}while(0);p=G-1&255;if(p<<24>>24!=0){H=p;D=6851}}if((D|0)==6851){D=0;p=n+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){u=a[s+5|0]|0;v=u&255;if(u<<24>>24==0){break}do{if((a[1108928]|0)==0){u=b[(c[277225]|0)+(v<<1)>>1]|0;w=u&65535;x=w&63454;if((a[(c[277215]|0)+p|0]&32)==0){J=c[277228]|0;_=(e[(c[277220]|0)+((((J&-2082)+x|0)>>>1)+(w&2081&J)<<1)>>1]|(J^w)&2081)&65535;break}else{w=b[(c[277213]|0)+(p<<1)>>1]|0;_=(((w&63454)+x|0)>>>1)+(w&u&2081)&65535;break}}else{u=e[(c[277225]|0)+(v<<1)>>1]|0;w=(a[(c[277215]|0)+p|0]&32)==0;if(w){x=c[277228]|0;$=x;aa=x&-2082}else{x=e[(c[277213]|0)+(p<<1)>>1]|0;$=x;aa=x&63454}if(w){ab=c[277228]|0}else{ab=e[(c[277213]|0)+(p<<1)>>1]|0}_=((ab^u)&2081|e[(c[277220]|0)+((u&2081&$)+((aa+(u&63454)|0)>>>1)<<1)>>1])&65535}}while(0);v=n+11|0;b[(c[277218]|0)+(v<<1)>>1]=_;b[(c[277218]|0)+(p<<1)>>1]=_;u=a[1108909]|0;a[(c[277219]|0)+v|0]=u;a[(c[277219]|0)+p|0]=u}}while(0);p=H-1&255;if(p<<24>>24!=0){I=p;D=6866}}if((D|0)==6866){D=0;p=n+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){u=a[s+6|0]|0;v=u&255;if(u<<24>>24==0){break}do{if((a[1108928]|0)==0){u=b[(c[277225]|0)+(v<<1)>>1]|0;w=u&65535;x=w&63454;if((a[(c[277215]|0)+p|0]&32)==0){J=c[277228]|0;ac=(e[(c[277220]|0)+((((J&-2082)+x|0)>>>1)+(w&2081&J)<<1)>>1]|(J^w)&2081)&65535;break}else{w=b[(c[277213]|0)+(p<<1)>>1]|0;ac=(((w&63454)+x|0)>>>1)+(w&u&2081)&65535;break}}else{u=e[(c[277225]|0)+(v<<1)>>1]|0;w=(a[(c[277215]|0)+p|0]&32)==0;if(w){x=c[277228]|0;ad=x;ae=x&-2082}else{x=e[(c[277213]|0)+(p<<1)>>1]|0;ad=x;ae=x&63454}if(w){af=c[277228]|0}else{af=e[(c[277213]|0)+(p<<1)>>1]|0}ac=((af^u)&2081|e[(c[277220]|0)+((u&2081&ad)+((ae+(u&63454)|0)>>>1)<<1)>>1])&65535}}while(0);v=n+13|0;b[(c[277218]|0)+(v<<1)>>1]=ac;b[(c[277218]|0)+(p<<1)>>1]=ac;u=a[1108909]|0;a[(c[277219]|0)+v|0]=u;a[(c[277219]|0)+p|0]=u}}while(0);if(I<<24>>24!=1){D=6881}}do{if((D|0)==6881){D=0;p=n+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+p|0]|0)){break}u=a[s+7|0]|0;v=u&255;if(u<<24>>24==0){break}do{if((a[1108928]|0)==0){u=b[(c[277225]|0)+(v<<1)>>1]|0;w=u&65535;x=w&63454;if((a[(c[277215]|0)+p|0]&32)==0){J=c[277228]|0;ag=(e[(c[277220]|0)+((((J&-2082)+x|0)>>>1)+(w&2081&J)<<1)>>1]|(J^w)&2081)&65535;break}else{w=b[(c[277213]|0)+(p<<1)>>1]|0;ag=(((w&63454)+x|0)>>>1)+(w&u&2081)&65535;break}}else{u=e[(c[277225]|0)+(v<<1)>>1]|0;w=(a[(c[277215]|0)+p|0]&32)==0;if(w){x=c[277228]|0;ah=x;ai=x&-2082}else{x=e[(c[277213]|0)+(p<<1)>>1]|0;ah=x;ai=x&63454}if(w){aj=c[277228]|0}else{aj=e[(c[277213]|0)+(p<<1)>>1]|0}ag=((aj^u)&2081|e[(c[277220]|0)+((u&2081&ah)+((ai+(u&63454)|0)>>>1)<<1)>>1])&65535}}while(0);v=n+15|0;b[(c[277218]|0)+(v<<1)>>1]=ag;b[(c[277218]|0)+(p<<1)>>1]=ag;u=a[1108909]|0;a[(c[277219]|0)+v|0]=u;a[(c[277219]|0)+p|0]=u}}while(0);u=q-1|0;if((u|0)>0){s=s+8|0;q=u;n=(c[277223]|0)+n|0}else{break}}return}if((f&32768|0)==0){if((k|0)<=0){return}f=i&255;n=f-1&255;q=n<<24>>24==0;s=r+j|0;ag=k;ai=g;while(1){switch(h|0){case 7:{D=7005;break};case 6:{ak=f;D=6990;break};case 5:{al=f;D=6975;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+ai|0]|0)){ah=a[s+7|0]|0;aj=ah&255;if(ah<<24>>24==0){break}do{if((a[1108928]|0)==0){ah=b[(c[277225]|0)+(aj<<1)>>1]|0;I=ah&65535;ac=I&63454;if((a[(c[277215]|0)+ai|0]&32)==0){ae=c[277228]|0;am=(e[(c[277220]|0)+((((ae&-2082)+ac|0)>>>1)+(I&2081&ae)<<1)>>1]|(ae^I)&2081)&65535;break}else{I=b[(c[277213]|0)+(ai<<1)>>1]|0;am=(((I&63454)+ac|0)>>>1)+(I&ah&2081)&65535;break}}else{ah=e[(c[277225]|0)+(aj<<1)>>1]|0;I=(a[(c[277215]|0)+ai|0]&32)==0;if(I){ac=c[277228]|0;an=ac;ao=ac&-2082}else{ac=e[(c[277213]|0)+(ai<<1)>>1]|0;an=ac;ao=ac&63454}if(I){ap=c[277228]|0}else{ap=e[(c[277213]|0)+(ai<<1)>>1]|0}am=((ap^ah)&2081|e[(c[277220]|0)+((ah&2081&an)+((ao+(ah&63454)|0)>>>1)<<1)>>1])&65535}}while(0);aj=ai+1|0;b[(c[277218]|0)+(aj<<1)>>1]=am;b[(c[277218]|0)+(ai<<1)>>1]=am;p=a[1108909]|0;a[(c[277219]|0)+aj|0]=p;a[(c[277219]|0)+ai|0]=p}}while(0);if(!q){aq=n;D=6915}break};case 1:{aq=f;D=6915;break};case 2:{ar=f;D=6930;break};case 3:{as=f;D=6945;break};case 4:{at=f;D=6960;break};default:{}}if((D|0)==6915){D=0;p=ai+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){aj=a[s+6|0]|0;ah=aj&255;if(aj<<24>>24==0){break}do{if((a[1108928]|0)==0){aj=b[(c[277225]|0)+(ah<<1)>>1]|0;I=aj&65535;ac=I&63454;if((a[(c[277215]|0)+p|0]&32)==0){ae=c[277228]|0;au=(e[(c[277220]|0)+((((ae&-2082)+ac|0)>>>1)+(I&2081&ae)<<1)>>1]|(ae^I)&2081)&65535;break}else{I=b[(c[277213]|0)+(p<<1)>>1]|0;au=(((I&63454)+ac|0)>>>1)+(I&aj&2081)&65535;break}}else{aj=e[(c[277225]|0)+(ah<<1)>>1]|0;I=(a[(c[277215]|0)+p|0]&32)==0;if(I){ac=c[277228]|0;av=ac;aw=ac&-2082}else{ac=e[(c[277213]|0)+(p<<1)>>1]|0;av=ac;aw=ac&63454}if(I){ax=c[277228]|0}else{ax=e[(c[277213]|0)+(p<<1)>>1]|0}au=((ax^aj)&2081|e[(c[277220]|0)+((aj&2081&av)+((aw+(aj&63454)|0)>>>1)<<1)>>1])&65535}}while(0);ah=ai+3|0;b[(c[277218]|0)+(ah<<1)>>1]=au;b[(c[277218]|0)+(p<<1)>>1]=au;aj=a[1108909]|0;a[(c[277219]|0)+ah|0]=aj;a[(c[277219]|0)+p|0]=aj}}while(0);p=aq-1&255;if(p<<24>>24!=0){ar=p;D=6930}}if((D|0)==6930){D=0;p=ai+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){aj=a[s+5|0]|0;ah=aj&255;if(aj<<24>>24==0){break}do{if((a[1108928]|0)==0){aj=b[(c[277225]|0)+(ah<<1)>>1]|0;I=aj&65535;ac=I&63454;if((a[(c[277215]|0)+p|0]&32)==0){ae=c[277228]|0;ay=(e[(c[277220]|0)+((((ae&-2082)+ac|0)>>>1)+(I&2081&ae)<<1)>>1]|(ae^I)&2081)&65535;break}else{I=b[(c[277213]|0)+(p<<1)>>1]|0;ay=(((I&63454)+ac|0)>>>1)+(I&aj&2081)&65535;break}}else{aj=e[(c[277225]|0)+(ah<<1)>>1]|0;I=(a[(c[277215]|0)+p|0]&32)==0;if(I){ac=c[277228]|0;az=ac;aA=ac&-2082}else{ac=e[(c[277213]|0)+(p<<1)>>1]|0;az=ac;aA=ac&63454}if(I){aB=c[277228]|0}else{aB=e[(c[277213]|0)+(p<<1)>>1]|0}ay=((aB^aj)&2081|e[(c[277220]|0)+((aj&2081&az)+((aA+(aj&63454)|0)>>>1)<<1)>>1])&65535}}while(0);ah=ai+5|0;b[(c[277218]|0)+(ah<<1)>>1]=ay;b[(c[277218]|0)+(p<<1)>>1]=ay;aj=a[1108909]|0;a[(c[277219]|0)+ah|0]=aj;a[(c[277219]|0)+p|0]=aj}}while(0);p=ar-1&255;if(p<<24>>24!=0){as=p;D=6945}}if((D|0)==6945){D=0;p=ai+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){aj=a[s+4|0]|0;ah=aj&255;if(aj<<24>>24==0){break}do{if((a[1108928]|0)==0){aj=b[(c[277225]|0)+(ah<<1)>>1]|0;I=aj&65535;ac=I&63454;if((a[(c[277215]|0)+p|0]&32)==0){ae=c[277228]|0;aC=(e[(c[277220]|0)+((((ae&-2082)+ac|0)>>>1)+(I&2081&ae)<<1)>>1]|(ae^I)&2081)&65535;break}else{I=b[(c[277213]|0)+(p<<1)>>1]|0;aC=(((I&63454)+ac|0)>>>1)+(I&aj&2081)&65535;break}}else{aj=e[(c[277225]|0)+(ah<<1)>>1]|0;I=(a[(c[277215]|0)+p|0]&32)==0;if(I){ac=c[277228]|0;aD=ac;aE=ac&-2082}else{ac=e[(c[277213]|0)+(p<<1)>>1]|0;aD=ac;aE=ac&63454}if(I){aF=c[277228]|0}else{aF=e[(c[277213]|0)+(p<<1)>>1]|0}aC=((aF^aj)&2081|e[(c[277220]|0)+((aj&2081&aD)+((aE+(aj&63454)|0)>>>1)<<1)>>1])&65535}}while(0);ah=ai+7|0;b[(c[277218]|0)+(ah<<1)>>1]=aC;b[(c[277218]|0)+(p<<1)>>1]=aC;aj=a[1108909]|0;a[(c[277219]|0)+ah|0]=aj;a[(c[277219]|0)+p|0]=aj}}while(0);p=as-1&255;if(p<<24>>24!=0){at=p;D=6960}}if((D|0)==6960){D=0;p=ai+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){aj=a[s+3|0]|0;ah=aj&255;if(aj<<24>>24==0){break}do{if((a[1108928]|0)==0){aj=b[(c[277225]|0)+(ah<<1)>>1]|0;I=aj&65535;ac=I&63454;if((a[(c[277215]|0)+p|0]&32)==0){ae=c[277228]|0;aG=(e[(c[277220]|0)+((((ae&-2082)+ac|0)>>>1)+(I&2081&ae)<<1)>>1]|(ae^I)&2081)&65535;break}else{I=b[(c[277213]|0)+(p<<1)>>1]|0;aG=(((I&63454)+ac|0)>>>1)+(I&aj&2081)&65535;break}}else{aj=e[(c[277225]|0)+(ah<<1)>>1]|0;I=(a[(c[277215]|0)+p|0]&32)==0;if(I){ac=c[277228]|0;aH=ac;aI=ac&-2082}else{ac=e[(c[277213]|0)+(p<<1)>>1]|0;aH=ac;aI=ac&63454}if(I){aJ=c[277228]|0}else{aJ=e[(c[277213]|0)+(p<<1)>>1]|0}aG=((aJ^aj)&2081|e[(c[277220]|0)+((aj&2081&aH)+((aI+(aj&63454)|0)>>>1)<<1)>>1])&65535}}while(0);ah=ai+9|0;b[(c[277218]|0)+(ah<<1)>>1]=aG;b[(c[277218]|0)+(p<<1)>>1]=aG;aj=a[1108909]|0;a[(c[277219]|0)+ah|0]=aj;a[(c[277219]|0)+p|0]=aj}}while(0);p=at-1&255;if(p<<24>>24!=0){al=p;D=6975}}if((D|0)==6975){D=0;p=ai+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){aj=a[s+2|0]|0;ah=aj&255;if(aj<<24>>24==0){break}do{if((a[1108928]|0)==0){aj=b[(c[277225]|0)+(ah<<1)>>1]|0;I=aj&65535;ac=I&63454;if((a[(c[277215]|0)+p|0]&32)==0){ae=c[277228]|0;aK=(e[(c[277220]|0)+((((ae&-2082)+ac|0)>>>1)+(I&2081&ae)<<1)>>1]|(ae^I)&2081)&65535;break}else{I=b[(c[277213]|0)+(p<<1)>>1]|0;aK=(((I&63454)+ac|0)>>>1)+(I&aj&2081)&65535;break}}else{aj=e[(c[277225]|0)+(ah<<1)>>1]|0;I=(a[(c[277215]|0)+p|0]&32)==0;if(I){ac=c[277228]|0;aL=ac;aM=ac&-2082}else{ac=e[(c[277213]|0)+(p<<1)>>1]|0;aL=ac;aM=ac&63454}if(I){aN=c[277228]|0}else{aN=e[(c[277213]|0)+(p<<1)>>1]|0}aK=((aN^aj)&2081|e[(c[277220]|0)+((aj&2081&aL)+((aM+(aj&63454)|0)>>>1)<<1)>>1])&65535}}while(0);ah=ai+11|0;b[(c[277218]|0)+(ah<<1)>>1]=aK;b[(c[277218]|0)+(p<<1)>>1]=aK;aj=a[1108909]|0;a[(c[277219]|0)+ah|0]=aj;a[(c[277219]|0)+p|0]=aj}}while(0);p=al-1&255;if(p<<24>>24!=0){ak=p;D=6990}}if((D|0)==6990){D=0;p=ai+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){aj=a[s+1|0]|0;ah=aj&255;if(aj<<24>>24==0){break}do{if((a[1108928]|0)==0){aj=b[(c[277225]|0)+(ah<<1)>>1]|0;I=aj&65535;ac=I&63454;if((a[(c[277215]|0)+p|0]&32)==0){ae=c[277228]|0;aO=(e[(c[277220]|0)+((((ae&-2082)+ac|0)>>>1)+(I&2081&ae)<<1)>>1]|(ae^I)&2081)&65535;break}else{I=b[(c[277213]|0)+(p<<1)>>1]|0;aO=(((I&63454)+ac|0)>>>1)+(I&aj&2081)&65535;break}}else{aj=e[(c[277225]|0)+(ah<<1)>>1]|0;I=(a[(c[277215]|0)+p|0]&32)==0;if(I){ac=c[277228]|0;aP=ac;aQ=ac&-2082}else{ac=e[(c[277213]|0)+(p<<1)>>1]|0;aP=ac;aQ=ac&63454}if(I){aR=c[277228]|0}else{aR=e[(c[277213]|0)+(p<<1)>>1]|0}aO=((aR^aj)&2081|e[(c[277220]|0)+((aj&2081&aP)+((aQ+(aj&63454)|0)>>>1)<<1)>>1])&65535}}while(0);ah=ai+13|0;b[(c[277218]|0)+(ah<<1)>>1]=aO;b[(c[277218]|0)+(p<<1)>>1]=aO;aj=a[1108909]|0;a[(c[277219]|0)+ah|0]=aj;a[(c[277219]|0)+p|0]=aj}}while(0);if(ak<<24>>24!=1){D=7005}}do{if((D|0)==7005){D=0;p=ai+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+p|0]|0)){break}aj=a[s]|0;ah=aj&255;if(aj<<24>>24==0){break}do{if((a[1108928]|0)==0){aj=b[(c[277225]|0)+(ah<<1)>>1]|0;I=aj&65535;ac=I&63454;if((a[(c[277215]|0)+p|0]&32)==0){ae=c[277228]|0;aS=(e[(c[277220]|0)+((((ae&-2082)+ac|0)>>>1)+(I&2081&ae)<<1)>>1]|(ae^I)&2081)&65535;break}else{I=b[(c[277213]|0)+(p<<1)>>1]|0;aS=(((I&63454)+ac|0)>>>1)+(I&aj&2081)&65535;break}}else{aj=e[(c[277225]|0)+(ah<<1)>>1]|0;I=(a[(c[277215]|0)+p|0]&32)==0;if(I){ac=c[277228]|0;aT=ac;aU=ac&-2082}else{ac=e[(c[277213]|0)+(p<<1)>>1]|0;aT=ac;aU=ac&63454}if(I){aV=c[277228]|0}else{aV=e[(c[277213]|0)+(p<<1)>>1]|0}aS=((aV^aj)&2081|e[(c[277220]|0)+((aj&2081&aT)+((aU+(aj&63454)|0)>>>1)<<1)>>1])&65535}}while(0);ah=ai+15|0;b[(c[277218]|0)+(ah<<1)>>1]=aS;b[(c[277218]|0)+(p<<1)>>1]=aS;aj=a[1108909]|0;a[(c[277219]|0)+ah|0]=aj;a[(c[277219]|0)+p|0]=aj}}while(0);aj=ag-1|0;if((aj|0)>0){s=s+8|0;ag=aj;ai=(c[277223]|0)+ai|0}else{break}}return}ai=r+(56-j)|0;j=(k|0)>0;if(m){if(!j){return}m=i&255;r=m-1&255;ag=r<<24>>24==0;s=ai;aS=k;aU=g;while(1){switch(h|0){case 1:{aW=m;D=7162;break};case 4:{aX=m;D=7207;break};case 5:{aY=m;D=7222;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+aU|0]|0)){aT=a[s+7|0]|0;aV=aT&255;if(aT<<24>>24==0){break}do{if((a[1108928]|0)==0){aT=b[(c[277225]|0)+(aV<<1)>>1]|0;ak=aT&65535;aO=ak&63454;if((a[(c[277215]|0)+aU|0]&32)==0){aQ=c[277228]|0;aZ=(e[(c[277220]|0)+((((aQ&-2082)+aO|0)>>>1)+(ak&2081&aQ)<<1)>>1]|(aQ^ak)&2081)&65535;break}else{ak=b[(c[277213]|0)+(aU<<1)>>1]|0;aZ=(((ak&63454)+aO|0)>>>1)+(ak&aT&2081)&65535;break}}else{aT=e[(c[277225]|0)+(aV<<1)>>1]|0;ak=(a[(c[277215]|0)+aU|0]&32)==0;if(ak){aO=c[277228]|0;a_=aO;a$=aO&-2082}else{aO=e[(c[277213]|0)+(aU<<1)>>1]|0;a_=aO;a$=aO&63454}if(ak){a0=c[277228]|0}else{a0=e[(c[277213]|0)+(aU<<1)>>1]|0}aZ=((a0^aT)&2081|e[(c[277220]|0)+((aT&2081&a_)+((a$+(aT&63454)|0)>>>1)<<1)>>1])&65535}}while(0);aV=aU+1|0;b[(c[277218]|0)+(aV<<1)>>1]=aZ;b[(c[277218]|0)+(aU<<1)>>1]=aZ;p=a[1108909]|0;a[(c[277219]|0)+aV|0]=p;a[(c[277219]|0)+aU|0]=p}}while(0);if(!ag){aW=r;D=7162}break};case 6:{a1=m;D=7237;break};case 7:{D=7252;break};case 2:{a2=m;D=7177;break};case 3:{a3=m;D=7192;break};default:{}}if((D|0)==7162){D=0;p=aU+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){aV=a[s+6|0]|0;aT=aV&255;if(aV<<24>>24==0){break}do{if((a[1108928]|0)==0){aV=b[(c[277225]|0)+(aT<<1)>>1]|0;ak=aV&65535;aO=ak&63454;if((a[(c[277215]|0)+p|0]&32)==0){aQ=c[277228]|0;a4=(e[(c[277220]|0)+((((aQ&-2082)+aO|0)>>>1)+(ak&2081&aQ)<<1)>>1]|(aQ^ak)&2081)&65535;break}else{ak=b[(c[277213]|0)+(p<<1)>>1]|0;a4=(((ak&63454)+aO|0)>>>1)+(ak&aV&2081)&65535;break}}else{aV=e[(c[277225]|0)+(aT<<1)>>1]|0;ak=(a[(c[277215]|0)+p|0]&32)==0;if(ak){aO=c[277228]|0;a5=aO;a6=aO&-2082}else{aO=e[(c[277213]|0)+(p<<1)>>1]|0;a5=aO;a6=aO&63454}if(ak){a7=c[277228]|0}else{a7=e[(c[277213]|0)+(p<<1)>>1]|0}a4=((a7^aV)&2081|e[(c[277220]|0)+((aV&2081&a5)+((a6+(aV&63454)|0)>>>1)<<1)>>1])&65535}}while(0);aT=aU+3|0;b[(c[277218]|0)+(aT<<1)>>1]=a4;b[(c[277218]|0)+(p<<1)>>1]=a4;aV=a[1108909]|0;a[(c[277219]|0)+aT|0]=aV;a[(c[277219]|0)+p|0]=aV}}while(0);p=aW-1&255;if(p<<24>>24!=0){a2=p;D=7177}}if((D|0)==7177){D=0;p=aU+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){aV=a[s+5|0]|0;aT=aV&255;if(aV<<24>>24==0){break}do{if((a[1108928]|0)==0){aV=b[(c[277225]|0)+(aT<<1)>>1]|0;ak=aV&65535;aO=ak&63454;if((a[(c[277215]|0)+p|0]&32)==0){aQ=c[277228]|0;a8=(e[(c[277220]|0)+((((aQ&-2082)+aO|0)>>>1)+(ak&2081&aQ)<<1)>>1]|(aQ^ak)&2081)&65535;break}else{ak=b[(c[277213]|0)+(p<<1)>>1]|0;a8=(((ak&63454)+aO|0)>>>1)+(ak&aV&2081)&65535;break}}else{aV=e[(c[277225]|0)+(aT<<1)>>1]|0;ak=(a[(c[277215]|0)+p|0]&32)==0;if(ak){aO=c[277228]|0;a9=aO;ba=aO&-2082}else{aO=e[(c[277213]|0)+(p<<1)>>1]|0;a9=aO;ba=aO&63454}if(ak){bb=c[277228]|0}else{bb=e[(c[277213]|0)+(p<<1)>>1]|0}a8=((bb^aV)&2081|e[(c[277220]|0)+((aV&2081&a9)+((ba+(aV&63454)|0)>>>1)<<1)>>1])&65535}}while(0);aT=aU+5|0;b[(c[277218]|0)+(aT<<1)>>1]=a8;b[(c[277218]|0)+(p<<1)>>1]=a8;aV=a[1108909]|0;a[(c[277219]|0)+aT|0]=aV;a[(c[277219]|0)+p|0]=aV}}while(0);p=a2-1&255;if(p<<24>>24!=0){a3=p;D=7192}}if((D|0)==7192){D=0;p=aU+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){aV=a[s+4|0]|0;aT=aV&255;if(aV<<24>>24==0){break}do{if((a[1108928]|0)==0){aV=b[(c[277225]|0)+(aT<<1)>>1]|0;ak=aV&65535;aO=ak&63454;if((a[(c[277215]|0)+p|0]&32)==0){aQ=c[277228]|0;bc=(e[(c[277220]|0)+((((aQ&-2082)+aO|0)>>>1)+(ak&2081&aQ)<<1)>>1]|(aQ^ak)&2081)&65535;break}else{ak=b[(c[277213]|0)+(p<<1)>>1]|0;bc=(((ak&63454)+aO|0)>>>1)+(ak&aV&2081)&65535;break}}else{aV=e[(c[277225]|0)+(aT<<1)>>1]|0;ak=(a[(c[277215]|0)+p|0]&32)==0;if(ak){aO=c[277228]|0;bd=aO;be=aO&-2082}else{aO=e[(c[277213]|0)+(p<<1)>>1]|0;bd=aO;be=aO&63454}if(ak){bf=c[277228]|0}else{bf=e[(c[277213]|0)+(p<<1)>>1]|0}bc=((bf^aV)&2081|e[(c[277220]|0)+((aV&2081&bd)+((be+(aV&63454)|0)>>>1)<<1)>>1])&65535}}while(0);aT=aU+7|0;b[(c[277218]|0)+(aT<<1)>>1]=bc;b[(c[277218]|0)+(p<<1)>>1]=bc;aV=a[1108909]|0;a[(c[277219]|0)+aT|0]=aV;a[(c[277219]|0)+p|0]=aV}}while(0);p=a3-1&255;if(p<<24>>24!=0){aX=p;D=7207}}if((D|0)==7207){D=0;p=aU+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){aV=a[s+3|0]|0;aT=aV&255;if(aV<<24>>24==0){break}do{if((a[1108928]|0)==0){aV=b[(c[277225]|0)+(aT<<1)>>1]|0;ak=aV&65535;aO=ak&63454;if((a[(c[277215]|0)+p|0]&32)==0){aQ=c[277228]|0;bg=(e[(c[277220]|0)+((((aQ&-2082)+aO|0)>>>1)+(ak&2081&aQ)<<1)>>1]|(aQ^ak)&2081)&65535;break}else{ak=b[(c[277213]|0)+(p<<1)>>1]|0;bg=(((ak&63454)+aO|0)>>>1)+(ak&aV&2081)&65535;break}}else{aV=e[(c[277225]|0)+(aT<<1)>>1]|0;ak=(a[(c[277215]|0)+p|0]&32)==0;if(ak){aO=c[277228]|0;bh=aO;bi=aO&-2082}else{aO=e[(c[277213]|0)+(p<<1)>>1]|0;bh=aO;bi=aO&63454}if(ak){bj=c[277228]|0}else{bj=e[(c[277213]|0)+(p<<1)>>1]|0}bg=((bj^aV)&2081|e[(c[277220]|0)+((aV&2081&bh)+((bi+(aV&63454)|0)>>>1)<<1)>>1])&65535}}while(0);aT=aU+9|0;b[(c[277218]|0)+(aT<<1)>>1]=bg;b[(c[277218]|0)+(p<<1)>>1]=bg;aV=a[1108909]|0;a[(c[277219]|0)+aT|0]=aV;a[(c[277219]|0)+p|0]=aV}}while(0);p=aX-1&255;if(p<<24>>24!=0){aY=p;D=7222}}if((D|0)==7222){D=0;p=aU+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){aV=a[s+2|0]|0;aT=aV&255;if(aV<<24>>24==0){break}do{if((a[1108928]|0)==0){aV=b[(c[277225]|0)+(aT<<1)>>1]|0;ak=aV&65535;aO=ak&63454;if((a[(c[277215]|0)+p|0]&32)==0){aQ=c[277228]|0;bk=(e[(c[277220]|0)+((((aQ&-2082)+aO|0)>>>1)+(ak&2081&aQ)<<1)>>1]|(aQ^ak)&2081)&65535;break}else{ak=b[(c[277213]|0)+(p<<1)>>1]|0;bk=(((ak&63454)+aO|0)>>>1)+(ak&aV&2081)&65535;break}}else{aV=e[(c[277225]|0)+(aT<<1)>>1]|0;ak=(a[(c[277215]|0)+p|0]&32)==0;if(ak){aO=c[277228]|0;bl=aO;bm=aO&-2082}else{aO=e[(c[277213]|0)+(p<<1)>>1]|0;bl=aO;bm=aO&63454}if(ak){bn=c[277228]|0}else{bn=e[(c[277213]|0)+(p<<1)>>1]|0}bk=((bn^aV)&2081|e[(c[277220]|0)+((aV&2081&bl)+((bm+(aV&63454)|0)>>>1)<<1)>>1])&65535}}while(0);aT=aU+11|0;b[(c[277218]|0)+(aT<<1)>>1]=bk;b[(c[277218]|0)+(p<<1)>>1]=bk;aV=a[1108909]|0;a[(c[277219]|0)+aT|0]=aV;a[(c[277219]|0)+p|0]=aV}}while(0);p=aY-1&255;if(p<<24>>24!=0){a1=p;D=7237}}if((D|0)==7237){D=0;p=aU+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){aV=a[s+1|0]|0;aT=aV&255;if(aV<<24>>24==0){break}do{if((a[1108928]|0)==0){aV=b[(c[277225]|0)+(aT<<1)>>1]|0;ak=aV&65535;aO=ak&63454;if((a[(c[277215]|0)+p|0]&32)==0){aQ=c[277228]|0;bo=(e[(c[277220]|0)+((((aQ&-2082)+aO|0)>>>1)+(ak&2081&aQ)<<1)>>1]|(aQ^ak)&2081)&65535;break}else{ak=b[(c[277213]|0)+(p<<1)>>1]|0;bo=(((ak&63454)+aO|0)>>>1)+(ak&aV&2081)&65535;break}}else{aV=e[(c[277225]|0)+(aT<<1)>>1]|0;ak=(a[(c[277215]|0)+p|0]&32)==0;if(ak){aO=c[277228]|0;bp=aO;bq=aO&-2082}else{aO=e[(c[277213]|0)+(p<<1)>>1]|0;bp=aO;bq=aO&63454}if(ak){br=c[277228]|0}else{br=e[(c[277213]|0)+(p<<1)>>1]|0}bo=((br^aV)&2081|e[(c[277220]|0)+((aV&2081&bp)+((bq+(aV&63454)|0)>>>1)<<1)>>1])&65535}}while(0);aT=aU+13|0;b[(c[277218]|0)+(aT<<1)>>1]=bo;b[(c[277218]|0)+(p<<1)>>1]=bo;aV=a[1108909]|0;a[(c[277219]|0)+aT|0]=aV;a[(c[277219]|0)+p|0]=aV}}while(0);if(a1<<24>>24!=1){D=7252}}do{if((D|0)==7252){D=0;p=aU+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+p|0]|0)){break}aV=a[s]|0;aT=aV&255;if(aV<<24>>24==0){break}do{if((a[1108928]|0)==0){aV=b[(c[277225]|0)+(aT<<1)>>1]|0;ak=aV&65535;aO=ak&63454;if((a[(c[277215]|0)+p|0]&32)==0){aQ=c[277228]|0;bs=(e[(c[277220]|0)+((((aQ&-2082)+aO|0)>>>1)+(ak&2081&aQ)<<1)>>1]|(aQ^ak)&2081)&65535;break}else{ak=b[(c[277213]|0)+(p<<1)>>1]|0;bs=(((ak&63454)+aO|0)>>>1)+(ak&aV&2081)&65535;break}}else{aV=e[(c[277225]|0)+(aT<<1)>>1]|0;ak=(a[(c[277215]|0)+p|0]&32)==0;if(ak){aO=c[277228]|0;bt=aO;bu=aO&-2082}else{aO=e[(c[277213]|0)+(p<<1)>>1]|0;bt=aO;bu=aO&63454}if(ak){bv=c[277228]|0}else{bv=e[(c[277213]|0)+(p<<1)>>1]|0}bs=((bv^aV)&2081|e[(c[277220]|0)+((aV&2081&bt)+((bu+(aV&63454)|0)>>>1)<<1)>>1])&65535}}while(0);aT=aU+15|0;b[(c[277218]|0)+(aT<<1)>>1]=bs;b[(c[277218]|0)+(p<<1)>>1]=bs;aV=a[1108909]|0;a[(c[277219]|0)+aT|0]=aV;a[(c[277219]|0)+p|0]=aV}}while(0);aV=aS-1|0;if((aV|0)>0){s=s-8|0;aS=aV;aU=(c[277223]|0)+aU|0}else{break}}return}else{if(!j){return}j=i&255;i=j-1&255;aU=i<<24>>24==0;aS=ai;ai=k;k=g;while(1){switch(h|0){case 2:{bw=j;D=7056;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+k|0]|0)){g=a[aS]|0;s=g&255;if(g<<24>>24==0){break}do{if((a[1108928]|0)==0){g=b[(c[277225]|0)+(s<<1)>>1]|0;bs=g&65535;bu=bs&63454;if((a[(c[277215]|0)+k|0]&32)==0){bt=c[277228]|0;bx=(e[(c[277220]|0)+((((bt&-2082)+bu|0)>>>1)+(bs&2081&bt)<<1)>>1]|(bt^bs)&2081)&65535;break}else{bs=b[(c[277213]|0)+(k<<1)>>1]|0;bx=(((bs&63454)+bu|0)>>>1)+(bs&g&2081)&65535;break}}else{g=e[(c[277225]|0)+(s<<1)>>1]|0;bs=(a[(c[277215]|0)+k|0]&32)==0;if(bs){bu=c[277228]|0;by=bu;bz=bu&-2082}else{bu=e[(c[277213]|0)+(k<<1)>>1]|0;by=bu;bz=bu&63454}if(bs){bA=c[277228]|0}else{bA=e[(c[277213]|0)+(k<<1)>>1]|0}bx=((bA^g)&2081|e[(c[277220]|0)+((g&2081&by)+((bz+(g&63454)|0)>>>1)<<1)>>1])&65535}}while(0);s=k+1|0;b[(c[277218]|0)+(s<<1)>>1]=bx;b[(c[277218]|0)+(k<<1)>>1]=bx;p=a[1108909]|0;a[(c[277219]|0)+s|0]=p;a[(c[277219]|0)+k|0]=p}}while(0);if(!aU){bB=i;D=7041}break};case 3:{bC=j;D=7071;break};case 1:{bB=j;D=7041;break};case 4:{bD=j;D=7086;break};case 7:{D=7131;break};case 6:{bE=j;D=7116;break};case 5:{bF=j;D=7101;break};default:{}}if((D|0)==7041){D=0;p=k+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){s=a[aS+1|0]|0;g=s&255;if(s<<24>>24==0){break}do{if((a[1108928]|0)==0){s=b[(c[277225]|0)+(g<<1)>>1]|0;bs=s&65535;bu=bs&63454;if((a[(c[277215]|0)+p|0]&32)==0){bt=c[277228]|0;bG=(e[(c[277220]|0)+((((bt&-2082)+bu|0)>>>1)+(bs&2081&bt)<<1)>>1]|(bt^bs)&2081)&65535;break}else{bs=b[(c[277213]|0)+(p<<1)>>1]|0;bG=(((bs&63454)+bu|0)>>>1)+(bs&s&2081)&65535;break}}else{s=e[(c[277225]|0)+(g<<1)>>1]|0;bs=(a[(c[277215]|0)+p|0]&32)==0;if(bs){bu=c[277228]|0;bH=bu;bI=bu&-2082}else{bu=e[(c[277213]|0)+(p<<1)>>1]|0;bH=bu;bI=bu&63454}if(bs){bJ=c[277228]|0}else{bJ=e[(c[277213]|0)+(p<<1)>>1]|0}bG=((bJ^s)&2081|e[(c[277220]|0)+((s&2081&bH)+((bI+(s&63454)|0)>>>1)<<1)>>1])&65535}}while(0);g=k+3|0;b[(c[277218]|0)+(g<<1)>>1]=bG;b[(c[277218]|0)+(p<<1)>>1]=bG;s=a[1108909]|0;a[(c[277219]|0)+g|0]=s;a[(c[277219]|0)+p|0]=s}}while(0);p=bB-1&255;if(p<<24>>24!=0){bw=p;D=7056}}if((D|0)==7056){D=0;p=k+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){s=a[aS+2|0]|0;g=s&255;if(s<<24>>24==0){break}do{if((a[1108928]|0)==0){s=b[(c[277225]|0)+(g<<1)>>1]|0;bs=s&65535;bu=bs&63454;if((a[(c[277215]|0)+p|0]&32)==0){bt=c[277228]|0;bK=(e[(c[277220]|0)+((((bt&-2082)+bu|0)>>>1)+(bs&2081&bt)<<1)>>1]|(bt^bs)&2081)&65535;break}else{bs=b[(c[277213]|0)+(p<<1)>>1]|0;bK=(((bs&63454)+bu|0)>>>1)+(bs&s&2081)&65535;break}}else{s=e[(c[277225]|0)+(g<<1)>>1]|0;bs=(a[(c[277215]|0)+p|0]&32)==0;if(bs){bu=c[277228]|0;bL=bu;bM=bu&-2082}else{bu=e[(c[277213]|0)+(p<<1)>>1]|0;bL=bu;bM=bu&63454}if(bs){bN=c[277228]|0}else{bN=e[(c[277213]|0)+(p<<1)>>1]|0}bK=((bN^s)&2081|e[(c[277220]|0)+((s&2081&bL)+((bM+(s&63454)|0)>>>1)<<1)>>1])&65535}}while(0);g=k+5|0;b[(c[277218]|0)+(g<<1)>>1]=bK;b[(c[277218]|0)+(p<<1)>>1]=bK;s=a[1108909]|0;a[(c[277219]|0)+g|0]=s;a[(c[277219]|0)+p|0]=s}}while(0);p=bw-1&255;if(p<<24>>24!=0){bC=p;D=7071}}if((D|0)==7071){D=0;p=k+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){s=a[aS+3|0]|0;g=s&255;if(s<<24>>24==0){break}do{if((a[1108928]|0)==0){s=b[(c[277225]|0)+(g<<1)>>1]|0;bs=s&65535;bu=bs&63454;if((a[(c[277215]|0)+p|0]&32)==0){bt=c[277228]|0;bO=(e[(c[277220]|0)+((((bt&-2082)+bu|0)>>>1)+(bs&2081&bt)<<1)>>1]|(bt^bs)&2081)&65535;break}else{bs=b[(c[277213]|0)+(p<<1)>>1]|0;bO=(((bs&63454)+bu|0)>>>1)+(bs&s&2081)&65535;break}}else{s=e[(c[277225]|0)+(g<<1)>>1]|0;bs=(a[(c[277215]|0)+p|0]&32)==0;if(bs){bu=c[277228]|0;bP=bu;bQ=bu&-2082}else{bu=e[(c[277213]|0)+(p<<1)>>1]|0;bP=bu;bQ=bu&63454}if(bs){bR=c[277228]|0}else{bR=e[(c[277213]|0)+(p<<1)>>1]|0}bO=((bR^s)&2081|e[(c[277220]|0)+((s&2081&bP)+((bQ+(s&63454)|0)>>>1)<<1)>>1])&65535}}while(0);g=k+7|0;b[(c[277218]|0)+(g<<1)>>1]=bO;b[(c[277218]|0)+(p<<1)>>1]=bO;s=a[1108909]|0;a[(c[277219]|0)+g|0]=s;a[(c[277219]|0)+p|0]=s}}while(0);p=bC-1&255;if(p<<24>>24!=0){bD=p;D=7086}}if((D|0)==7086){D=0;p=k+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){s=a[aS+4|0]|0;g=s&255;if(s<<24>>24==0){break}do{if((a[1108928]|0)==0){s=b[(c[277225]|0)+(g<<1)>>1]|0;bs=s&65535;bu=bs&63454;if((a[(c[277215]|0)+p|0]&32)==0){bt=c[277228]|0;bS=(e[(c[277220]|0)+((((bt&-2082)+bu|0)>>>1)+(bs&2081&bt)<<1)>>1]|(bt^bs)&2081)&65535;break}else{bs=b[(c[277213]|0)+(p<<1)>>1]|0;bS=(((bs&63454)+bu|0)>>>1)+(bs&s&2081)&65535;break}}else{s=e[(c[277225]|0)+(g<<1)>>1]|0;bs=(a[(c[277215]|0)+p|0]&32)==0;if(bs){bu=c[277228]|0;bT=bu;bU=bu&-2082}else{bu=e[(c[277213]|0)+(p<<1)>>1]|0;bT=bu;bU=bu&63454}if(bs){bV=c[277228]|0}else{bV=e[(c[277213]|0)+(p<<1)>>1]|0}bS=((bV^s)&2081|e[(c[277220]|0)+((s&2081&bT)+((bU+(s&63454)|0)>>>1)<<1)>>1])&65535}}while(0);g=k+9|0;b[(c[277218]|0)+(g<<1)>>1]=bS;b[(c[277218]|0)+(p<<1)>>1]=bS;s=a[1108909]|0;a[(c[277219]|0)+g|0]=s;a[(c[277219]|0)+p|0]=s}}while(0);p=bD-1&255;if(p<<24>>24!=0){bF=p;D=7101}}if((D|0)==7101){D=0;p=k+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){s=a[aS+5|0]|0;g=s&255;if(s<<24>>24==0){break}do{if((a[1108928]|0)==0){s=b[(c[277225]|0)+(g<<1)>>1]|0;bs=s&65535;bu=bs&63454;if((a[(c[277215]|0)+p|0]&32)==0){bt=c[277228]|0;bW=(e[(c[277220]|0)+((((bt&-2082)+bu|0)>>>1)+(bs&2081&bt)<<1)>>1]|(bt^bs)&2081)&65535;break}else{bs=b[(c[277213]|0)+(p<<1)>>1]|0;bW=(((bs&63454)+bu|0)>>>1)+(bs&s&2081)&65535;break}}else{s=e[(c[277225]|0)+(g<<1)>>1]|0;bs=(a[(c[277215]|0)+p|0]&32)==0;if(bs){bu=c[277228]|0;bX=bu;bY=bu&-2082}else{bu=e[(c[277213]|0)+(p<<1)>>1]|0;bX=bu;bY=bu&63454}if(bs){bZ=c[277228]|0}else{bZ=e[(c[277213]|0)+(p<<1)>>1]|0}bW=((bZ^s)&2081|e[(c[277220]|0)+((s&2081&bX)+((bY+(s&63454)|0)>>>1)<<1)>>1])&65535}}while(0);g=k+11|0;b[(c[277218]|0)+(g<<1)>>1]=bW;b[(c[277218]|0)+(p<<1)>>1]=bW;s=a[1108909]|0;a[(c[277219]|0)+g|0]=s;a[(c[277219]|0)+p|0]=s}}while(0);p=bF-1&255;if(p<<24>>24!=0){bE=p;D=7116}}if((D|0)==7116){D=0;p=k+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){s=a[aS+6|0]|0;g=s&255;if(s<<24>>24==0){break}do{if((a[1108928]|0)==0){s=b[(c[277225]|0)+(g<<1)>>1]|0;bs=s&65535;bu=bs&63454;if((a[(c[277215]|0)+p|0]&32)==0){bt=c[277228]|0;b_=(e[(c[277220]|0)+((((bt&-2082)+bu|0)>>>1)+(bs&2081&bt)<<1)>>1]|(bt^bs)&2081)&65535;break}else{bs=b[(c[277213]|0)+(p<<1)>>1]|0;b_=(((bs&63454)+bu|0)>>>1)+(bs&s&2081)&65535;break}}else{s=e[(c[277225]|0)+(g<<1)>>1]|0;bs=(a[(c[277215]|0)+p|0]&32)==0;if(bs){bu=c[277228]|0;b$=bu;b0=bu&-2082}else{bu=e[(c[277213]|0)+(p<<1)>>1]|0;b$=bu;b0=bu&63454}if(bs){b1=c[277228]|0}else{b1=e[(c[277213]|0)+(p<<1)>>1]|0}b_=((b1^s)&2081|e[(c[277220]|0)+((s&2081&b$)+((b0+(s&63454)|0)>>>1)<<1)>>1])&65535}}while(0);g=k+13|0;b[(c[277218]|0)+(g<<1)>>1]=b_;b[(c[277218]|0)+(p<<1)>>1]=b_;s=a[1108909]|0;a[(c[277219]|0)+g|0]=s;a[(c[277219]|0)+p|0]=s}}while(0);if(bE<<24>>24!=1){D=7131}}do{if((D|0)==7131){D=0;p=k+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+p|0]|0)){break}s=a[aS+7|0]|0;g=s&255;if(s<<24>>24==0){break}do{if((a[1108928]|0)==0){s=b[(c[277225]|0)+(g<<1)>>1]|0;bs=s&65535;bu=bs&63454;if((a[(c[277215]|0)+p|0]&32)==0){bt=c[277228]|0;b2=(e[(c[277220]|0)+((((bt&-2082)+bu|0)>>>1)+(bs&2081&bt)<<1)>>1]|(bt^bs)&2081)&65535;break}else{bs=b[(c[277213]|0)+(p<<1)>>1]|0;b2=(((bs&63454)+bu|0)>>>1)+(bs&s&2081)&65535;break}}else{s=e[(c[277225]|0)+(g<<1)>>1]|0;bs=(a[(c[277215]|0)+p|0]&32)==0;if(bs){bu=c[277228]|0;b3=bu;b4=bu&-2082}else{bu=e[(c[277213]|0)+(p<<1)>>1]|0;b3=bu;b4=bu&63454}if(bs){b5=c[277228]|0}else{b5=e[(c[277213]|0)+(p<<1)>>1]|0}b2=((b5^s)&2081|e[(c[277220]|0)+((s&2081&b3)+((b4+(s&63454)|0)>>>1)<<1)>>1])&65535}}while(0);g=k+15|0;b[(c[277218]|0)+(g<<1)>>1]=b2;b[(c[277218]|0)+(p<<1)>>1]=b2;s=a[1108909]|0;a[(c[277219]|0)+g|0]=s;a[(c[277219]|0)+p|0]=s}}while(0);s=ai-1|0;if((s|0)>0){aS=aS-8|0;ai=s;k=(c[277223]|0)+k|0}else{break}}return}}function Ur(e,f,g,h,i,j){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0;k=e&1023;l=c[348606]|0;m=(k<<l)+(c[348604]|0)|0;if((e&256|0)==0){n=m}else{n=(c[348602]|0)+m|0}m=n&65535;n=m>>>(l>>>0);l=(e&16384|0)!=0;o=n<<6;do{if(l){p=(c[348622]|0)+o|0;if((a[(c[348618]|0)+n|0]|0)!=0){q=p;break}r=fi[c[348636]&63](p,m,k)|0;a[(c[348618]|0)+n|0]=r;q=p}else{p=(c[348624]|0)+o|0;if((a[(c[348620]|0)+n|0]|0)!=0){q=p;break}r=fi[c[348638]&63](p,m,k)|0;a[(c[348620]|0)+n|0]=r;q=p}}while(0);if((a[(c[348620]|0)+n|0]|0)==2){return}if((a[1394464]|0)==0){s=1106168+((e>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){n=d[1044485]|0;c[276541]=7080+(n<<5);k=0;do{m=k<<1&2;o=k&2;p=k&4;r=0;do{b[1125528+(k<<9)+(r<<1)>>1]=d[(r>>>1&28|o)+(7080+(n<<5))|0]<<6|d[(r<<2&28|m)+(7080+(n<<5))|0]<<11|d[(r>>>3&24|p)+(7080+(n<<5))|0];r=r+1|0;}while(r>>>0<256);k=k+1|0;}while(k>>>0<8);a[1106089]=0}s=1125528+((e>>>10&7)<<9)|0}c[277226]=s;c[277225]=(a[1108928]|0)!=0?1393712:s;if((e&49152|0)==0){if((j|0)<=0){return}s=h&255;k=s-1&255;n=k<<24>>24==0;r=q+i|0;p=j;m=f;while(1){switch(g|0){case 4:{t=s;u=7342;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+m|0]|0)){o=a[r]|0;if(o<<24>>24==0){break}v=b[(c[277225]|0)+((o&255)<<1)>>1]|0;if((a[(c[277215]|0)+m|0]&32)==0){w=c[277228]&65535}else{w=b[(c[277213]|0)+(m<<1)>>1]|0}o=v&-2048;x=w&-2048;y=(o&65535)>(x&65535)?o-x&65535:0;x=v&2016;o=w&2016;if((x&65535)>(o&65535)){z=(x-o&65535)+y&65535}else{z=y}y=v&31;v=w&31;if((y&65535)>(v&65535)){A=(y-v&65535)+z&65535}else{A=z}v=m+1|0;b[(c[277218]|0)+(v<<1)>>1]=A;b[(c[277218]|0)+(m<<1)>>1]=A;y=a[1108909]|0;a[(c[277219]|0)+v|0]=y;a[(c[277219]|0)+m|0]=y}}while(0);if(!n){B=k;u=7309}break};case 6:{C=s;u=7364;break};case 1:{B=s;u=7309;break};case 7:{u=7375;break};case 5:{D=s;u=7353;break};case 2:{E=s;u=7320;break};case 3:{F=s;u=7331;break};default:{}}if((u|0)==7309){u=0;y=m+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+y|0]|0)){v=a[r+1|0]|0;if(v<<24>>24==0){break}o=b[(c[277225]|0)+((v&255)<<1)>>1]|0;if((a[(c[277215]|0)+y|0]&32)==0){G=c[277228]&65535}else{G=b[(c[277213]|0)+(y<<1)>>1]|0}v=o&-2048;x=G&-2048;H=(v&65535)>(x&65535)?v-x&65535:0;x=o&2016;v=G&2016;if((x&65535)>(v&65535)){I=(x-v&65535)+H&65535}else{I=H}H=o&31;o=G&31;if((H&65535)>(o&65535)){J=(H-o&65535)+I&65535}else{J=I}o=m+3|0;b[(c[277218]|0)+(o<<1)>>1]=J;b[(c[277218]|0)+(y<<1)>>1]=J;H=a[1108909]|0;a[(c[277219]|0)+o|0]=H;a[(c[277219]|0)+y|0]=H}}while(0);y=B-1&255;if(y<<24>>24!=0){E=y;u=7320}}if((u|0)==7320){u=0;y=m+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+y|0]|0)){H=a[r+2|0]|0;if(H<<24>>24==0){break}o=b[(c[277225]|0)+((H&255)<<1)>>1]|0;if((a[(c[277215]|0)+y|0]&32)==0){K=c[277228]&65535}else{K=b[(c[277213]|0)+(y<<1)>>1]|0}H=o&-2048;v=K&-2048;x=(H&65535)>(v&65535)?H-v&65535:0;v=o&2016;H=K&2016;if((v&65535)>(H&65535)){L=(v-H&65535)+x&65535}else{L=x}x=o&31;o=K&31;if((x&65535)>(o&65535)){M=(x-o&65535)+L&65535}else{M=L}o=m+5|0;b[(c[277218]|0)+(o<<1)>>1]=M;b[(c[277218]|0)+(y<<1)>>1]=M;x=a[1108909]|0;a[(c[277219]|0)+o|0]=x;a[(c[277219]|0)+y|0]=x}}while(0);y=E-1&255;if(y<<24>>24!=0){F=y;u=7331}}if((u|0)==7331){u=0;y=m+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+y|0]|0)){x=a[r+3|0]|0;if(x<<24>>24==0){break}o=b[(c[277225]|0)+((x&255)<<1)>>1]|0;if((a[(c[277215]|0)+y|0]&32)==0){N=c[277228]&65535}else{N=b[(c[277213]|0)+(y<<1)>>1]|0}x=o&-2048;H=N&-2048;v=(x&65535)>(H&65535)?x-H&65535:0;H=o&2016;x=N&2016;if((H&65535)>(x&65535)){O=(H-x&65535)+v&65535}else{O=v}v=o&31;o=N&31;if((v&65535)>(o&65535)){P=(v-o&65535)+O&65535}else{P=O}o=m+7|0;b[(c[277218]|0)+(o<<1)>>1]=P;b[(c[277218]|0)+(y<<1)>>1]=P;v=a[1108909]|0;a[(c[277219]|0)+o|0]=v;a[(c[277219]|0)+y|0]=v}}while(0);y=F-1&255;if(y<<24>>24!=0){t=y;u=7342}}if((u|0)==7342){u=0;y=m+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+y|0]|0)){v=a[r+4|0]|0;if(v<<24>>24==0){break}o=b[(c[277225]|0)+((v&255)<<1)>>1]|0;if((a[(c[277215]|0)+y|0]&32)==0){Q=c[277228]&65535}else{Q=b[(c[277213]|0)+(y<<1)>>1]|0}v=o&-2048;x=Q&-2048;H=(v&65535)>(x&65535)?v-x&65535:0;x=o&2016;v=Q&2016;if((x&65535)>(v&65535)){R=(x-v&65535)+H&65535}else{R=H}H=o&31;o=Q&31;if((H&65535)>(o&65535)){S=(H-o&65535)+R&65535}else{S=R}o=m+9|0;b[(c[277218]|0)+(o<<1)>>1]=S;b[(c[277218]|0)+(y<<1)>>1]=S;H=a[1108909]|0;a[(c[277219]|0)+o|0]=H;a[(c[277219]|0)+y|0]=H}}while(0);y=t-1&255;if(y<<24>>24!=0){D=y;u=7353}}if((u|0)==7353){u=0;y=m+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+y|0]|0)){H=a[r+5|0]|0;if(H<<24>>24==0){break}o=b[(c[277225]|0)+((H&255)<<1)>>1]|0;if((a[(c[277215]|0)+y|0]&32)==0){T=c[277228]&65535}else{T=b[(c[277213]|0)+(y<<1)>>1]|0}H=o&-2048;v=T&-2048;x=(H&65535)>(v&65535)?H-v&65535:0;v=o&2016;H=T&2016;if((v&65535)>(H&65535)){U=(v-H&65535)+x&65535}else{U=x}x=o&31;o=T&31;if((x&65535)>(o&65535)){V=(x-o&65535)+U&65535}else{V=U}o=m+11|0;b[(c[277218]|0)+(o<<1)>>1]=V;b[(c[277218]|0)+(y<<1)>>1]=V;x=a[1108909]|0;a[(c[277219]|0)+o|0]=x;a[(c[277219]|0)+y|0]=x}}while(0);y=D-1&255;if(y<<24>>24!=0){C=y;u=7364}}if((u|0)==7364){u=0;y=m+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+y|0]|0)){x=a[r+6|0]|0;if(x<<24>>24==0){break}o=b[(c[277225]|0)+((x&255)<<1)>>1]|0;if((a[(c[277215]|0)+y|0]&32)==0){W=c[277228]&65535}else{W=b[(c[277213]|0)+(y<<1)>>1]|0}x=o&-2048;H=W&-2048;v=(x&65535)>(H&65535)?x-H&65535:0;H=o&2016;x=W&2016;if((H&65535)>(x&65535)){X=(H-x&65535)+v&65535}else{X=v}v=o&31;o=W&31;if((v&65535)>(o&65535)){Y=(v-o&65535)+X&65535}else{Y=X}o=m+13|0;b[(c[277218]|0)+(o<<1)>>1]=Y;b[(c[277218]|0)+(y<<1)>>1]=Y;v=a[1108909]|0;a[(c[277219]|0)+o|0]=v;a[(c[277219]|0)+y|0]=v}}while(0);if(C<<24>>24!=1){u=7375}}do{if((u|0)==7375){u=0;y=m+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+y|0]|0)){break}v=a[r+7|0]|0;if(v<<24>>24==0){break}o=b[(c[277225]|0)+((v&255)<<1)>>1]|0;if((a[(c[277215]|0)+y|0]&32)==0){Z=c[277228]&65535}else{Z=b[(c[277213]|0)+(y<<1)>>1]|0}v=o&-2048;x=Z&-2048;H=(v&65535)>(x&65535)?v-x&65535:0;x=o&2016;v=Z&2016;if((x&65535)>(v&65535)){_=(x-v&65535)+H&65535}else{_=H}H=o&31;o=Z&31;if((H&65535)>(o&65535)){$=(H-o&65535)+_&65535}else{$=_}o=m+15|0;b[(c[277218]|0)+(o<<1)>>1]=$;b[(c[277218]|0)+(y<<1)>>1]=$;H=a[1108909]|0;a[(c[277219]|0)+o|0]=H;a[(c[277219]|0)+y|0]=H}}while(0);H=p-1|0;if((H|0)>0){r=r+8|0;p=H;m=(c[277223]|0)+m|0}else{break}}return}if((e&32768|0)==0){if((j|0)<=0){return}e=h&255;m=e-1&255;p=m<<24>>24==0;r=q+i|0;$=j;_=f;while(1){switch(g|0){case 1:{aa=e;u=7401;break};case 2:{ab=e;u=7412;break};case 5:{ac=e;u=7445;break};case 7:{u=7467;break};case 4:{ad=e;u=7434;break};case 3:{ae=e;u=7423;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+_|0]|0)){Z=a[r+7|0]|0;if(Z<<24>>24==0){break}C=b[(c[277225]|0)+((Z&255)<<1)>>1]|0;if((a[(c[277215]|0)+_|0]&32)==0){af=c[277228]&65535}else{af=b[(c[277213]|0)+(_<<1)>>1]|0}Z=C&-2048;Y=af&-2048;X=(Z&65535)>(Y&65535)?Z-Y&65535:0;Y=C&2016;Z=af&2016;if((Y&65535)>(Z&65535)){ag=(Y-Z&65535)+X&65535}else{ag=X}X=C&31;C=af&31;if((X&65535)>(C&65535)){ah=(X-C&65535)+ag&65535}else{ah=ag}C=_+1|0;b[(c[277218]|0)+(C<<1)>>1]=ah;b[(c[277218]|0)+(_<<1)>>1]=ah;X=a[1108909]|0;a[(c[277219]|0)+C|0]=X;a[(c[277219]|0)+_|0]=X}}while(0);if(!p){aa=m;u=7401}break};case 6:{ai=e;u=7456;break};default:{}}if((u|0)==7401){u=0;X=_+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+X|0]|0)){C=a[r+6|0]|0;if(C<<24>>24==0){break}Z=b[(c[277225]|0)+((C&255)<<1)>>1]|0;if((a[(c[277215]|0)+X|0]&32)==0){aj=c[277228]&65535}else{aj=b[(c[277213]|0)+(X<<1)>>1]|0}C=Z&-2048;Y=aj&-2048;W=(C&65535)>(Y&65535)?C-Y&65535:0;Y=Z&2016;C=aj&2016;if((Y&65535)>(C&65535)){ak=(Y-C&65535)+W&65535}else{ak=W}W=Z&31;Z=aj&31;if((W&65535)>(Z&65535)){al=(W-Z&65535)+ak&65535}else{al=ak}Z=_+3|0;b[(c[277218]|0)+(Z<<1)>>1]=al;b[(c[277218]|0)+(X<<1)>>1]=al;W=a[1108909]|0;a[(c[277219]|0)+Z|0]=W;a[(c[277219]|0)+X|0]=W}}while(0);X=aa-1&255;if(X<<24>>24!=0){ab=X;u=7412}}if((u|0)==7412){u=0;X=_+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+X|0]|0)){W=a[r+5|0]|0;if(W<<24>>24==0){break}Z=b[(c[277225]|0)+((W&255)<<1)>>1]|0;if((a[(c[277215]|0)+X|0]&32)==0){am=c[277228]&65535}else{am=b[(c[277213]|0)+(X<<1)>>1]|0}W=Z&-2048;C=am&-2048;Y=(W&65535)>(C&65535)?W-C&65535:0;C=Z&2016;W=am&2016;if((C&65535)>(W&65535)){an=(C-W&65535)+Y&65535}else{an=Y}Y=Z&31;Z=am&31;if((Y&65535)>(Z&65535)){ao=(Y-Z&65535)+an&65535}else{ao=an}Z=_+5|0;b[(c[277218]|0)+(Z<<1)>>1]=ao;b[(c[277218]|0)+(X<<1)>>1]=ao;Y=a[1108909]|0;a[(c[277219]|0)+Z|0]=Y;a[(c[277219]|0)+X|0]=Y}}while(0);X=ab-1&255;if(X<<24>>24!=0){ae=X;u=7423}}if((u|0)==7423){u=0;X=_+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+X|0]|0)){Y=a[r+4|0]|0;if(Y<<24>>24==0){break}Z=b[(c[277225]|0)+((Y&255)<<1)>>1]|0;if((a[(c[277215]|0)+X|0]&32)==0){ap=c[277228]&65535}else{ap=b[(c[277213]|0)+(X<<1)>>1]|0}Y=Z&-2048;W=ap&-2048;C=(Y&65535)>(W&65535)?Y-W&65535:0;W=Z&2016;Y=ap&2016;if((W&65535)>(Y&65535)){aq=(W-Y&65535)+C&65535}else{aq=C}C=Z&31;Z=ap&31;if((C&65535)>(Z&65535)){ar=(C-Z&65535)+aq&65535}else{ar=aq}Z=_+7|0;b[(c[277218]|0)+(Z<<1)>>1]=ar;b[(c[277218]|0)+(X<<1)>>1]=ar;C=a[1108909]|0;a[(c[277219]|0)+Z|0]=C;a[(c[277219]|0)+X|0]=C}}while(0);X=ae-1&255;if(X<<24>>24!=0){ad=X;u=7434}}if((u|0)==7434){u=0;X=_+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+X|0]|0)){C=a[r+3|0]|0;if(C<<24>>24==0){break}Z=b[(c[277225]|0)+((C&255)<<1)>>1]|0;if((a[(c[277215]|0)+X|0]&32)==0){as=c[277228]&65535}else{as=b[(c[277213]|0)+(X<<1)>>1]|0}C=Z&-2048;Y=as&-2048;W=(C&65535)>(Y&65535)?C-Y&65535:0;Y=Z&2016;C=as&2016;if((Y&65535)>(C&65535)){at=(Y-C&65535)+W&65535}else{at=W}W=Z&31;Z=as&31;if((W&65535)>(Z&65535)){au=(W-Z&65535)+at&65535}else{au=at}Z=_+9|0;b[(c[277218]|0)+(Z<<1)>>1]=au;b[(c[277218]|0)+(X<<1)>>1]=au;W=a[1108909]|0;a[(c[277219]|0)+Z|0]=W;a[(c[277219]|0)+X|0]=W}}while(0);X=ad-1&255;if(X<<24>>24!=0){ac=X;u=7445}}if((u|0)==7445){u=0;X=_+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+X|0]|0)){W=a[r+2|0]|0;if(W<<24>>24==0){break}Z=b[(c[277225]|0)+((W&255)<<1)>>1]|0;if((a[(c[277215]|0)+X|0]&32)==0){av=c[277228]&65535}else{av=b[(c[277213]|0)+(X<<1)>>1]|0}W=Z&-2048;C=av&-2048;Y=(W&65535)>(C&65535)?W-C&65535:0;C=Z&2016;W=av&2016;if((C&65535)>(W&65535)){aw=(C-W&65535)+Y&65535}else{aw=Y}Y=Z&31;Z=av&31;if((Y&65535)>(Z&65535)){ax=(Y-Z&65535)+aw&65535}else{ax=aw}Z=_+11|0;b[(c[277218]|0)+(Z<<1)>>1]=ax;b[(c[277218]|0)+(X<<1)>>1]=ax;Y=a[1108909]|0;a[(c[277219]|0)+Z|0]=Y;a[(c[277219]|0)+X|0]=Y}}while(0);X=ac-1&255;if(X<<24>>24!=0){ai=X;u=7456}}if((u|0)==7456){u=0;X=_+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+X|0]|0)){Y=a[r+1|0]|0;if(Y<<24>>24==0){break}Z=b[(c[277225]|0)+((Y&255)<<1)>>1]|0;if((a[(c[277215]|0)+X|0]&32)==0){ay=c[277228]&65535}else{ay=b[(c[277213]|0)+(X<<1)>>1]|0}Y=Z&-2048;W=ay&-2048;C=(Y&65535)>(W&65535)?Y-W&65535:0;W=Z&2016;Y=ay&2016;if((W&65535)>(Y&65535)){az=(W-Y&65535)+C&65535}else{az=C}C=Z&31;Z=ay&31;if((C&65535)>(Z&65535)){aA=(C-Z&65535)+az&65535}else{aA=az}Z=_+13|0;b[(c[277218]|0)+(Z<<1)>>1]=aA;b[(c[277218]|0)+(X<<1)>>1]=aA;C=a[1108909]|0;a[(c[277219]|0)+Z|0]=C;a[(c[277219]|0)+X|0]=C}}while(0);if(ai<<24>>24!=1){u=7467}}do{if((u|0)==7467){u=0;X=_+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+X|0]|0)){break}C=a[r]|0;if(C<<24>>24==0){break}Z=b[(c[277225]|0)+((C&255)<<1)>>1]|0;if((a[(c[277215]|0)+X|0]&32)==0){aB=c[277228]&65535}else{aB=b[(c[277213]|0)+(X<<1)>>1]|0}C=Z&-2048;Y=aB&-2048;W=(C&65535)>(Y&65535)?C-Y&65535:0;Y=Z&2016;C=aB&2016;if((Y&65535)>(C&65535)){aC=(Y-C&65535)+W&65535}else{aC=W}W=Z&31;Z=aB&31;if((W&65535)>(Z&65535)){aD=(W-Z&65535)+aC&65535}else{aD=aC}Z=_+15|0;b[(c[277218]|0)+(Z<<1)>>1]=aD;b[(c[277218]|0)+(X<<1)>>1]=aD;W=a[1108909]|0;a[(c[277219]|0)+Z|0]=W;a[(c[277219]|0)+X|0]=W}}while(0);W=$-1|0;if((W|0)>0){r=r+8|0;$=W;_=(c[277223]|0)+_|0}else{break}}return}_=q+(56-i)|0;i=(j|0)>0;if(l){if(!i){return}l=h&255;q=l-1&255;$=q<<24>>24==0;r=_;aD=j;aC=f;while(1){switch(g|0){case 5:{aE=l;u=7628;break};case 6:{aF=l;u=7639;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+aC|0]|0)){aB=a[r+7|0]|0;if(aB<<24>>24==0){break}ai=b[(c[277225]|0)+((aB&255)<<1)>>1]|0;if((a[(c[277215]|0)+aC|0]&32)==0){aG=c[277228]&65535}else{aG=b[(c[277213]|0)+(aC<<1)>>1]|0}aB=ai&-2048;aA=aG&-2048;az=(aB&65535)>(aA&65535)?aB-aA&65535:0;aA=ai&2016;aB=aG&2016;if((aA&65535)>(aB&65535)){aH=(aA-aB&65535)+az&65535}else{aH=az}az=ai&31;ai=aG&31;if((az&65535)>(ai&65535)){aI=(az-ai&65535)+aH&65535}else{aI=aH}ai=aC+1|0;b[(c[277218]|0)+(ai<<1)>>1]=aI;b[(c[277218]|0)+(aC<<1)>>1]=aI;az=a[1108909]|0;a[(c[277219]|0)+ai|0]=az;a[(c[277219]|0)+aC|0]=az}}while(0);if(!$){aJ=q;u=7584}break};case 3:{aK=l;u=7606;break};case 4:{aL=l;u=7617;break};case 2:{aM=l;u=7595;break};case 1:{aJ=l;u=7584;break};case 7:{u=7650;break};default:{}}if((u|0)==7584){u=0;az=aC+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+az|0]|0)){ai=a[r+6|0]|0;if(ai<<24>>24==0){break}aB=b[(c[277225]|0)+((ai&255)<<1)>>1]|0;if((a[(c[277215]|0)+az|0]&32)==0){aN=c[277228]&65535}else{aN=b[(c[277213]|0)+(az<<1)>>1]|0}ai=aB&-2048;aA=aN&-2048;ay=(ai&65535)>(aA&65535)?ai-aA&65535:0;aA=aB&2016;ai=aN&2016;if((aA&65535)>(ai&65535)){aO=(aA-ai&65535)+ay&65535}else{aO=ay}ay=aB&31;aB=aN&31;if((ay&65535)>(aB&65535)){aP=(ay-aB&65535)+aO&65535}else{aP=aO}aB=aC+3|0;b[(c[277218]|0)+(aB<<1)>>1]=aP;b[(c[277218]|0)+(az<<1)>>1]=aP;ay=a[1108909]|0;a[(c[277219]|0)+aB|0]=ay;a[(c[277219]|0)+az|0]=ay}}while(0);az=aJ-1&255;if(az<<24>>24!=0){aM=az;u=7595}}if((u|0)==7595){u=0;az=aC+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+az|0]|0)){ay=a[r+5|0]|0;if(ay<<24>>24==0){break}aB=b[(c[277225]|0)+((ay&255)<<1)>>1]|0;if((a[(c[277215]|0)+az|0]&32)==0){aQ=c[277228]&65535}else{aQ=b[(c[277213]|0)+(az<<1)>>1]|0}ay=aB&-2048;ai=aQ&-2048;aA=(ay&65535)>(ai&65535)?ay-ai&65535:0;ai=aB&2016;ay=aQ&2016;if((ai&65535)>(ay&65535)){aR=(ai-ay&65535)+aA&65535}else{aR=aA}aA=aB&31;aB=aQ&31;if((aA&65535)>(aB&65535)){aS=(aA-aB&65535)+aR&65535}else{aS=aR}aB=aC+5|0;b[(c[277218]|0)+(aB<<1)>>1]=aS;b[(c[277218]|0)+(az<<1)>>1]=aS;aA=a[1108909]|0;a[(c[277219]|0)+aB|0]=aA;a[(c[277219]|0)+az|0]=aA}}while(0);az=aM-1&255;if(az<<24>>24!=0){aK=az;u=7606}}if((u|0)==7606){u=0;az=aC+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+az|0]|0)){aA=a[r+4|0]|0;if(aA<<24>>24==0){break}aB=b[(c[277225]|0)+((aA&255)<<1)>>1]|0;if((a[(c[277215]|0)+az|0]&32)==0){aT=c[277228]&65535}else{aT=b[(c[277213]|0)+(az<<1)>>1]|0}aA=aB&-2048;ay=aT&-2048;ai=(aA&65535)>(ay&65535)?aA-ay&65535:0;ay=aB&2016;aA=aT&2016;if((ay&65535)>(aA&65535)){aU=(ay-aA&65535)+ai&65535}else{aU=ai}ai=aB&31;aB=aT&31;if((ai&65535)>(aB&65535)){aV=(ai-aB&65535)+aU&65535}else{aV=aU}aB=aC+7|0;b[(c[277218]|0)+(aB<<1)>>1]=aV;b[(c[277218]|0)+(az<<1)>>1]=aV;ai=a[1108909]|0;a[(c[277219]|0)+aB|0]=ai;a[(c[277219]|0)+az|0]=ai}}while(0);az=aK-1&255;if(az<<24>>24!=0){aL=az;u=7617}}if((u|0)==7617){u=0;az=aC+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+az|0]|0)){ai=a[r+3|0]|0;if(ai<<24>>24==0){break}aB=b[(c[277225]|0)+((ai&255)<<1)>>1]|0;if((a[(c[277215]|0)+az|0]&32)==0){aW=c[277228]&65535}else{aW=b[(c[277213]|0)+(az<<1)>>1]|0}ai=aB&-2048;aA=aW&-2048;ay=(ai&65535)>(aA&65535)?ai-aA&65535:0;aA=aB&2016;ai=aW&2016;if((aA&65535)>(ai&65535)){aX=(aA-ai&65535)+ay&65535}else{aX=ay}ay=aB&31;aB=aW&31;if((ay&65535)>(aB&65535)){aY=(ay-aB&65535)+aX&65535}else{aY=aX}aB=aC+9|0;b[(c[277218]|0)+(aB<<1)>>1]=aY;b[(c[277218]|0)+(az<<1)>>1]=aY;ay=a[1108909]|0;a[(c[277219]|0)+aB|0]=ay;a[(c[277219]|0)+az|0]=ay}}while(0);az=aL-1&255;if(az<<24>>24!=0){aE=az;u=7628}}if((u|0)==7628){u=0;az=aC+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+az|0]|0)){ay=a[r+2|0]|0;if(ay<<24>>24==0){break}aB=b[(c[277225]|0)+((ay&255)<<1)>>1]|0;if((a[(c[277215]|0)+az|0]&32)==0){aZ=c[277228]&65535}else{aZ=b[(c[277213]|0)+(az<<1)>>1]|0}ay=aB&-2048;ai=aZ&-2048;aA=(ay&65535)>(ai&65535)?ay-ai&65535:0;ai=aB&2016;ay=aZ&2016;if((ai&65535)>(ay&65535)){a_=(ai-ay&65535)+aA&65535}else{a_=aA}aA=aB&31;aB=aZ&31;if((aA&65535)>(aB&65535)){a$=(aA-aB&65535)+a_&65535}else{a$=a_}aB=aC+11|0;b[(c[277218]|0)+(aB<<1)>>1]=a$;b[(c[277218]|0)+(az<<1)>>1]=a$;aA=a[1108909]|0;a[(c[277219]|0)+aB|0]=aA;a[(c[277219]|0)+az|0]=aA}}while(0);az=aE-1&255;if(az<<24>>24!=0){aF=az;u=7639}}if((u|0)==7639){u=0;az=aC+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+az|0]|0)){aA=a[r+1|0]|0;if(aA<<24>>24==0){break}aB=b[(c[277225]|0)+((aA&255)<<1)>>1]|0;if((a[(c[277215]|0)+az|0]&32)==0){a0=c[277228]&65535}else{a0=b[(c[277213]|0)+(az<<1)>>1]|0}aA=aB&-2048;ay=a0&-2048;ai=(aA&65535)>(ay&65535)?aA-ay&65535:0;ay=aB&2016;aA=a0&2016;if((ay&65535)>(aA&65535)){a1=(ay-aA&65535)+ai&65535}else{a1=ai}ai=aB&31;aB=a0&31;if((ai&65535)>(aB&65535)){a2=(ai-aB&65535)+a1&65535}else{a2=a1}aB=aC+13|0;b[(c[277218]|0)+(aB<<1)>>1]=a2;b[(c[277218]|0)+(az<<1)>>1]=a2;ai=a[1108909]|0;a[(c[277219]|0)+aB|0]=ai;a[(c[277219]|0)+az|0]=ai}}while(0);if(aF<<24>>24!=1){u=7650}}do{if((u|0)==7650){u=0;az=aC+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+az|0]|0)){break}ai=a[r]|0;if(ai<<24>>24==0){break}aB=b[(c[277225]|0)+((ai&255)<<1)>>1]|0;if((a[(c[277215]|0)+az|0]&32)==0){a3=c[277228]&65535}else{a3=b[(c[277213]|0)+(az<<1)>>1]|0}ai=aB&-2048;aA=a3&-2048;ay=(ai&65535)>(aA&65535)?ai-aA&65535:0;aA=aB&2016;ai=a3&2016;if((aA&65535)>(ai&65535)){a4=(aA-ai&65535)+ay&65535}else{a4=ay}ay=aB&31;aB=a3&31;if((ay&65535)>(aB&65535)){a5=(ay-aB&65535)+a4&65535}else{a5=a4}aB=aC+15|0;b[(c[277218]|0)+(aB<<1)>>1]=a5;b[(c[277218]|0)+(az<<1)>>1]=a5;ay=a[1108909]|0;a[(c[277219]|0)+aB|0]=ay;a[(c[277219]|0)+az|0]=ay}}while(0);ay=aD-1|0;if((ay|0)>0){r=r-8|0;aD=ay;aC=(c[277223]|0)+aC|0}else{break}}return}else{if(!i){return}i=h&255;h=i-1&255;aC=h<<24>>24==0;aD=_;_=j;j=f;while(1){switch(g|0){case 4:{a6=i;u=7528;break};case 5:{a7=i;u=7539;break};case 1:{a8=i;u=7495;break};case 6:{a9=i;u=7550;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+j|0]|0)){f=a[aD]|0;if(f<<24>>24==0){break}r=b[(c[277225]|0)+((f&255)<<1)>>1]|0;if((a[(c[277215]|0)+j|0]&32)==0){ba=c[277228]&65535}else{ba=b[(c[277213]|0)+(j<<1)>>1]|0}f=r&-2048;a5=ba&-2048;a4=(f&65535)>(a5&65535)?f-a5&65535:0;a5=r&2016;f=ba&2016;if((a5&65535)>(f&65535)){bb=(a5-f&65535)+a4&65535}else{bb=a4}a4=r&31;r=ba&31;if((a4&65535)>(r&65535)){bc=(a4-r&65535)+bb&65535}else{bc=bb}r=j+1|0;b[(c[277218]|0)+(r<<1)>>1]=bc;b[(c[277218]|0)+(j<<1)>>1]=bc;a4=a[1108909]|0;a[(c[277219]|0)+r|0]=a4;a[(c[277219]|0)+j|0]=a4}}while(0);if(!aC){a8=h;u=7495}break};case 2:{bd=i;u=7506;break};case 3:{be=i;u=7517;break};case 7:{u=7561;break};default:{}}if((u|0)==7495){u=0;a4=j+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+a4|0]|0)){r=a[aD+1|0]|0;if(r<<24>>24==0){break}f=b[(c[277225]|0)+((r&255)<<1)>>1]|0;if((a[(c[277215]|0)+a4|0]&32)==0){bf=c[277228]&65535}else{bf=b[(c[277213]|0)+(a4<<1)>>1]|0}r=f&-2048;a5=bf&-2048;a3=(r&65535)>(a5&65535)?r-a5&65535:0;a5=f&2016;r=bf&2016;if((a5&65535)>(r&65535)){bg=(a5-r&65535)+a3&65535}else{bg=a3}a3=f&31;f=bf&31;if((a3&65535)>(f&65535)){bh=(a3-f&65535)+bg&65535}else{bh=bg}f=j+3|0;b[(c[277218]|0)+(f<<1)>>1]=bh;b[(c[277218]|0)+(a4<<1)>>1]=bh;a3=a[1108909]|0;a[(c[277219]|0)+f|0]=a3;a[(c[277219]|0)+a4|0]=a3}}while(0);a4=a8-1&255;if(a4<<24>>24!=0){bd=a4;u=7506}}if((u|0)==7506){u=0;a4=j+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+a4|0]|0)){a3=a[aD+2|0]|0;if(a3<<24>>24==0){break}f=b[(c[277225]|0)+((a3&255)<<1)>>1]|0;if((a[(c[277215]|0)+a4|0]&32)==0){bi=c[277228]&65535}else{bi=b[(c[277213]|0)+(a4<<1)>>1]|0}a3=f&-2048;r=bi&-2048;a5=(a3&65535)>(r&65535)?a3-r&65535:0;r=f&2016;a3=bi&2016;if((r&65535)>(a3&65535)){bj=(r-a3&65535)+a5&65535}else{bj=a5}a5=f&31;f=bi&31;if((a5&65535)>(f&65535)){bk=(a5-f&65535)+bj&65535}else{bk=bj}f=j+5|0;b[(c[277218]|0)+(f<<1)>>1]=bk;b[(c[277218]|0)+(a4<<1)>>1]=bk;a5=a[1108909]|0;a[(c[277219]|0)+f|0]=a5;a[(c[277219]|0)+a4|0]=a5}}while(0);a4=bd-1&255;if(a4<<24>>24!=0){be=a4;u=7517}}if((u|0)==7517){u=0;a4=j+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+a4|0]|0)){a5=a[aD+3|0]|0;if(a5<<24>>24==0){break}f=b[(c[277225]|0)+((a5&255)<<1)>>1]|0;if((a[(c[277215]|0)+a4|0]&32)==0){bl=c[277228]&65535}else{bl=b[(c[277213]|0)+(a4<<1)>>1]|0}a5=f&-2048;a3=bl&-2048;r=(a5&65535)>(a3&65535)?a5-a3&65535:0;a3=f&2016;a5=bl&2016;if((a3&65535)>(a5&65535)){bm=(a3-a5&65535)+r&65535}else{bm=r}r=f&31;f=bl&31;if((r&65535)>(f&65535)){bn=(r-f&65535)+bm&65535}else{bn=bm}f=j+7|0;b[(c[277218]|0)+(f<<1)>>1]=bn;b[(c[277218]|0)+(a4<<1)>>1]=bn;r=a[1108909]|0;a[(c[277219]|0)+f|0]=r;a[(c[277219]|0)+a4|0]=r}}while(0);a4=be-1&255;if(a4<<24>>24!=0){a6=a4;u=7528}}if((u|0)==7528){u=0;a4=j+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+a4|0]|0)){r=a[aD+4|0]|0;if(r<<24>>24==0){break}f=b[(c[277225]|0)+((r&255)<<1)>>1]|0;if((a[(c[277215]|0)+a4|0]&32)==0){bo=c[277228]&65535}else{bo=b[(c[277213]|0)+(a4<<1)>>1]|0}r=f&-2048;a5=bo&-2048;a3=(r&65535)>(a5&65535)?r-a5&65535:0;a5=f&2016;r=bo&2016;if((a5&65535)>(r&65535)){bp=(a5-r&65535)+a3&65535}else{bp=a3}a3=f&31;f=bo&31;if((a3&65535)>(f&65535)){bq=(a3-f&65535)+bp&65535}else{bq=bp}f=j+9|0;b[(c[277218]|0)+(f<<1)>>1]=bq;b[(c[277218]|0)+(a4<<1)>>1]=bq;a3=a[1108909]|0;a[(c[277219]|0)+f|0]=a3;a[(c[277219]|0)+a4|0]=a3}}while(0);a4=a6-1&255;if(a4<<24>>24!=0){a7=a4;u=7539}}if((u|0)==7539){u=0;a4=j+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+a4|0]|0)){a3=a[aD+5|0]|0;if(a3<<24>>24==0){break}f=b[(c[277225]|0)+((a3&255)<<1)>>1]|0;if((a[(c[277215]|0)+a4|0]&32)==0){br=c[277228]&65535}else{br=b[(c[277213]|0)+(a4<<1)>>1]|0}a3=f&-2048;r=br&-2048;a5=(a3&65535)>(r&65535)?a3-r&65535:0;r=f&2016;a3=br&2016;if((r&65535)>(a3&65535)){bs=(r-a3&65535)+a5&65535}else{bs=a5}a5=f&31;f=br&31;if((a5&65535)>(f&65535)){bt=(a5-f&65535)+bs&65535}else{bt=bs}f=j+11|0;b[(c[277218]|0)+(f<<1)>>1]=bt;b[(c[277218]|0)+(a4<<1)>>1]=bt;a5=a[1108909]|0;a[(c[277219]|0)+f|0]=a5;a[(c[277219]|0)+a4|0]=a5}}while(0);a4=a7-1&255;if(a4<<24>>24!=0){a9=a4;u=7550}}if((u|0)==7550){u=0;a4=j+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+a4|0]|0)){a5=a[aD+6|0]|0;if(a5<<24>>24==0){break}f=b[(c[277225]|0)+((a5&255)<<1)>>1]|0;if((a[(c[277215]|0)+a4|0]&32)==0){bu=c[277228]&65535}else{bu=b[(c[277213]|0)+(a4<<1)>>1]|0}a5=f&-2048;a3=bu&-2048;r=(a5&65535)>(a3&65535)?a5-a3&65535:0;a3=f&2016;a5=bu&2016;if((a3&65535)>(a5&65535)){bv=(a3-a5&65535)+r&65535}else{bv=r}r=f&31;f=bu&31;if((r&65535)>(f&65535)){bw=(r-f&65535)+bv&65535}else{bw=bv}f=j+13|0;b[(c[277218]|0)+(f<<1)>>1]=bw;b[(c[277218]|0)+(a4<<1)>>1]=bw;r=a[1108909]|0;a[(c[277219]|0)+f|0]=r;a[(c[277219]|0)+a4|0]=r}}while(0);if(a9<<24>>24!=1){u=7561}}do{if((u|0)==7561){u=0;a4=j+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+a4|0]|0)){break}r=a[aD+7|0]|0;if(r<<24>>24==0){break}f=b[(c[277225]|0)+((r&255)<<1)>>1]|0;if((a[(c[277215]|0)+a4|0]&32)==0){bx=c[277228]&65535}else{bx=b[(c[277213]|0)+(a4<<1)>>1]|0}r=f&-2048;a5=bx&-2048;a3=(r&65535)>(a5&65535)?r-a5&65535:0;a5=f&2016;r=bx&2016;if((a5&65535)>(r&65535)){by=(a5-r&65535)+a3&65535}else{by=a3}a3=f&31;f=bx&31;if((a3&65535)>(f&65535)){bz=(a3-f&65535)+by&65535}else{bz=by}f=j+15|0;b[(c[277218]|0)+(f<<1)>>1]=bz;b[(c[277218]|0)+(a4<<1)>>1]=bz;a3=a[1108909]|0;a[(c[277219]|0)+f|0]=a3;a[(c[277219]|0)+a4|0]=a3}}while(0);a3=_-1|0;if((a3|0)>0){aD=aD-8|0;_=a3;j=(c[277223]|0)+j|0}else{break}}return}}function Us(e,f,g,h,i,j){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0;k=e&1023;l=c[348606]|0;m=(k<<l)+(c[348604]|0)|0;if((e&256|0)==0){n=m}else{n=(c[348602]|0)+m|0}m=n&65535;n=m>>>(l>>>0);l=(e&16384|0)!=0;o=n<<6;do{if(l){p=(c[348622]|0)+o|0;if((a[(c[348618]|0)+n|0]|0)!=0){q=p;break}r=fi[c[348636]&63](p,m,k)|0;a[(c[348618]|0)+n|0]=r;q=p}else{p=(c[348624]|0)+o|0;if((a[(c[348620]|0)+n|0]|0)!=0){q=p;break}r=fi[c[348638]&63](p,m,k)|0;a[(c[348620]|0)+n|0]=r;q=p}}while(0);if((a[(c[348620]|0)+n|0]|0)==2){return}if((a[1394464]|0)==0){s=1106168+((e>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){n=d[1044485]|0;c[276541]=7080+(n<<5);k=0;do{m=k<<1&2;o=k&2;p=k&4;r=0;do{b[1125528+(k<<9)+(r<<1)>>1]=d[(r>>>1&28|o)+(7080+(n<<5))|0]<<6|d[(r<<2&28|m)+(7080+(n<<5))|0]<<11|d[(r>>>3&24|p)+(7080+(n<<5))|0];r=r+1|0;}while(r>>>0<256);k=k+1|0;}while(k>>>0<8);a[1106089]=0}s=1125528+((e>>>10&7)<<9)|0}c[277226]=s;c[277225]=(a[1108928]|0)!=0?1393712:s;if((e&49152|0)==0){if((j|0)<=0){return}s=h&255;k=s-1&255;n=k<<24>>24==0;r=q+i|0;p=j;m=f;while(1){switch(g|0){case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+m|0]|0)){o=a[r]|0;if(o<<24>>24==0){break}t=b[(c[277225]|0)+((o&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){u=b[(c[277221]|0)+(((t&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{o=c[277228]&65535;v=t&-2048;w=o&-2048;x=(v&65535)>(w&65535)?v-w&65535:0;w=t&2016;v=o&2016;if((w&65535)>(v&65535)){y=(w-v&65535)+x&65535}else{y=x}x=t&31;v=o&31;if((x&65535)<=(v&65535)){u=y;break}u=(x-v&65535)+y&65535}}while(0);t=m+1|0;b[(c[277218]|0)+(t<<1)>>1]=u;b[(c[277218]|0)+(m<<1)>>1]=u;v=a[1108909]|0;a[(c[277219]|0)+t|0]=v;a[(c[277219]|0)+m|0]=v}}while(0);if(!n){z=k;A=7702}break};case 1:{z=s;A=7702;break};case 2:{B=s;A=7712;break};case 3:{C=s;A=7722;break};case 4:{D=s;A=7732;break};case 5:{E=s;A=7742;break};case 6:{F=s;A=7752;break};case 7:{A=7762;break};default:{}}if((A|0)==7702){A=0;v=m+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+v|0]|0)){t=a[r+1|0]|0;if(t<<24>>24==0){break}x=b[(c[277225]|0)+((t&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){G=b[(c[277221]|0)+(((x&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{t=c[277228]&65535;o=x&-2048;w=t&-2048;H=(o&65535)>(w&65535)?o-w&65535:0;w=x&2016;o=t&2016;if((w&65535)>(o&65535)){I=(w-o&65535)+H&65535}else{I=H}H=x&31;o=t&31;if((H&65535)<=(o&65535)){G=I;break}G=(H-o&65535)+I&65535}}while(0);x=m+3|0;b[(c[277218]|0)+(x<<1)>>1]=G;b[(c[277218]|0)+(v<<1)>>1]=G;o=a[1108909]|0;a[(c[277219]|0)+x|0]=o;a[(c[277219]|0)+v|0]=o}}while(0);v=z-1&255;if(v<<24>>24!=0){B=v;A=7712}}if((A|0)==7712){A=0;v=m+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+v|0]|0)){o=a[r+2|0]|0;if(o<<24>>24==0){break}x=b[(c[277225]|0)+((o&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){J=b[(c[277221]|0)+(((x&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{o=c[277228]&65535;H=x&-2048;t=o&-2048;w=(H&65535)>(t&65535)?H-t&65535:0;t=x&2016;H=o&2016;if((t&65535)>(H&65535)){K=(t-H&65535)+w&65535}else{K=w}w=x&31;H=o&31;if((w&65535)<=(H&65535)){J=K;break}J=(w-H&65535)+K&65535}}while(0);x=m+5|0;b[(c[277218]|0)+(x<<1)>>1]=J;b[(c[277218]|0)+(v<<1)>>1]=J;H=a[1108909]|0;a[(c[277219]|0)+x|0]=H;a[(c[277219]|0)+v|0]=H}}while(0);v=B-1&255;if(v<<24>>24!=0){C=v;A=7722}}if((A|0)==7722){A=0;v=m+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+v|0]|0)){H=a[r+3|0]|0;if(H<<24>>24==0){break}x=b[(c[277225]|0)+((H&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){L=b[(c[277221]|0)+(((x&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{H=c[277228]&65535;w=x&-2048;o=H&-2048;t=(w&65535)>(o&65535)?w-o&65535:0;o=x&2016;w=H&2016;if((o&65535)>(w&65535)){M=(o-w&65535)+t&65535}else{M=t}t=x&31;w=H&31;if((t&65535)<=(w&65535)){L=M;break}L=(t-w&65535)+M&65535}}while(0);x=m+7|0;b[(c[277218]|0)+(x<<1)>>1]=L;b[(c[277218]|0)+(v<<1)>>1]=L;w=a[1108909]|0;a[(c[277219]|0)+x|0]=w;a[(c[277219]|0)+v|0]=w}}while(0);v=C-1&255;if(v<<24>>24!=0){D=v;A=7732}}if((A|0)==7732){A=0;v=m+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+v|0]|0)){w=a[r+4|0]|0;if(w<<24>>24==0){break}x=b[(c[277225]|0)+((w&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){N=b[(c[277221]|0)+(((x&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{w=c[277228]&65535;t=x&-2048;H=w&-2048;o=(t&65535)>(H&65535)?t-H&65535:0;H=x&2016;t=w&2016;if((H&65535)>(t&65535)){O=(H-t&65535)+o&65535}else{O=o}o=x&31;t=w&31;if((o&65535)<=(t&65535)){N=O;break}N=(o-t&65535)+O&65535}}while(0);x=m+9|0;b[(c[277218]|0)+(x<<1)>>1]=N;b[(c[277218]|0)+(v<<1)>>1]=N;t=a[1108909]|0;a[(c[277219]|0)+x|0]=t;a[(c[277219]|0)+v|0]=t}}while(0);v=D-1&255;if(v<<24>>24!=0){E=v;A=7742}}if((A|0)==7742){A=0;v=m+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+v|0]|0)){t=a[r+5|0]|0;if(t<<24>>24==0){break}x=b[(c[277225]|0)+((t&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){P=b[(c[277221]|0)+(((x&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{t=c[277228]&65535;o=x&-2048;w=t&-2048;H=(o&65535)>(w&65535)?o-w&65535:0;w=x&2016;o=t&2016;if((w&65535)>(o&65535)){Q=(w-o&65535)+H&65535}else{Q=H}H=x&31;o=t&31;if((H&65535)<=(o&65535)){P=Q;break}P=(H-o&65535)+Q&65535}}while(0);x=m+11|0;b[(c[277218]|0)+(x<<1)>>1]=P;b[(c[277218]|0)+(v<<1)>>1]=P;o=a[1108909]|0;a[(c[277219]|0)+x|0]=o;a[(c[277219]|0)+v|0]=o}}while(0);v=E-1&255;if(v<<24>>24!=0){F=v;A=7752}}if((A|0)==7752){A=0;v=m+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+v|0]|0)){o=a[r+6|0]|0;if(o<<24>>24==0){break}x=b[(c[277225]|0)+((o&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){R=b[(c[277221]|0)+(((x&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{o=c[277228]&65535;H=x&-2048;t=o&-2048;w=(H&65535)>(t&65535)?H-t&65535:0;t=x&2016;H=o&2016;if((t&65535)>(H&65535)){S=(t-H&65535)+w&65535}else{S=w}w=x&31;H=o&31;if((w&65535)<=(H&65535)){R=S;break}R=(w-H&65535)+S&65535}}while(0);x=m+13|0;b[(c[277218]|0)+(x<<1)>>1]=R;b[(c[277218]|0)+(v<<1)>>1]=R;H=a[1108909]|0;a[(c[277219]|0)+x|0]=H;a[(c[277219]|0)+v|0]=H}}while(0);if(F<<24>>24!=1){A=7762}}do{if((A|0)==7762){A=0;v=m+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+v|0]|0)){break}H=a[r+7|0]|0;if(H<<24>>24==0){break}x=b[(c[277225]|0)+((H&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){T=b[(c[277221]|0)+(((x&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{H=c[277228]&65535;w=x&-2048;o=H&-2048;t=(w&65535)>(o&65535)?w-o&65535:0;o=x&2016;w=H&2016;if((o&65535)>(w&65535)){U=(o-w&65535)+t&65535}else{U=t}t=x&31;w=H&31;if((t&65535)<=(w&65535)){T=U;break}T=(t-w&65535)+U&65535}}while(0);x=m+15|0;b[(c[277218]|0)+(x<<1)>>1]=T;b[(c[277218]|0)+(v<<1)>>1]=T;w=a[1108909]|0;a[(c[277219]|0)+x|0]=w;a[(c[277219]|0)+v|0]=w}}while(0);w=p-1|0;if((w|0)>0){r=r+8|0;p=w;m=(c[277223]|0)+m|0}else{break}}return}if((e&32768|0)==0){if((j|0)<=0){return}e=h&255;m=e-1&255;p=m<<24>>24==0;r=q+i|0;T=j;U=f;while(1){switch(g|0){case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+U|0]|0)){F=a[r+7|0]|0;if(F<<24>>24==0){break}R=b[(c[277225]|0)+((F&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){V=b[(c[277221]|0)+(((R&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{F=c[277228]&65535;S=R&-2048;E=F&-2048;P=(S&65535)>(E&65535)?S-E&65535:0;E=R&2016;S=F&2016;if((E&65535)>(S&65535)){W=(E-S&65535)+P&65535}else{W=P}P=R&31;S=F&31;if((P&65535)<=(S&65535)){V=W;break}V=(P-S&65535)+W&65535}}while(0);R=U+1|0;b[(c[277218]|0)+(R<<1)>>1]=V;b[(c[277218]|0)+(U<<1)>>1]=V;v=a[1108909]|0;a[(c[277219]|0)+R|0]=v;a[(c[277219]|0)+U|0]=v}}while(0);if(!p){X=m;A=7786}break};case 1:{X=e;A=7786;break};case 2:{Y=e;A=7796;break};case 3:{Z=e;A=7806;break};case 4:{_=e;A=7816;break};case 5:{$=e;A=7826;break};case 6:{aa=e;A=7836;break};case 7:{A=7846;break};default:{}}if((A|0)==7786){A=0;v=U+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+v|0]|0)){R=a[r+6|0]|0;if(R<<24>>24==0){break}S=b[(c[277225]|0)+((R&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){ab=b[(c[277221]|0)+(((S&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{R=c[277228]&65535;P=S&-2048;F=R&-2048;E=(P&65535)>(F&65535)?P-F&65535:0;F=S&2016;P=R&2016;if((F&65535)>(P&65535)){ac=(F-P&65535)+E&65535}else{ac=E}E=S&31;P=R&31;if((E&65535)<=(P&65535)){ab=ac;break}ab=(E-P&65535)+ac&65535}}while(0);S=U+3|0;b[(c[277218]|0)+(S<<1)>>1]=ab;b[(c[277218]|0)+(v<<1)>>1]=ab;P=a[1108909]|0;a[(c[277219]|0)+S|0]=P;a[(c[277219]|0)+v|0]=P}}while(0);v=X-1&255;if(v<<24>>24!=0){Y=v;A=7796}}if((A|0)==7796){A=0;v=U+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+v|0]|0)){P=a[r+5|0]|0;if(P<<24>>24==0){break}S=b[(c[277225]|0)+((P&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){ad=b[(c[277221]|0)+(((S&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{P=c[277228]&65535;E=S&-2048;R=P&-2048;F=(E&65535)>(R&65535)?E-R&65535:0;R=S&2016;E=P&2016;if((R&65535)>(E&65535)){ae=(R-E&65535)+F&65535}else{ae=F}F=S&31;E=P&31;if((F&65535)<=(E&65535)){ad=ae;break}ad=(F-E&65535)+ae&65535}}while(0);S=U+5|0;b[(c[277218]|0)+(S<<1)>>1]=ad;b[(c[277218]|0)+(v<<1)>>1]=ad;E=a[1108909]|0;a[(c[277219]|0)+S|0]=E;a[(c[277219]|0)+v|0]=E}}while(0);v=Y-1&255;if(v<<24>>24!=0){Z=v;A=7806}}if((A|0)==7806){A=0;v=U+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+v|0]|0)){E=a[r+4|0]|0;if(E<<24>>24==0){break}S=b[(c[277225]|0)+((E&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){af=b[(c[277221]|0)+(((S&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{E=c[277228]&65535;F=S&-2048;P=E&-2048;R=(F&65535)>(P&65535)?F-P&65535:0;P=S&2016;F=E&2016;if((P&65535)>(F&65535)){ag=(P-F&65535)+R&65535}else{ag=R}R=S&31;F=E&31;if((R&65535)<=(F&65535)){af=ag;break}af=(R-F&65535)+ag&65535}}while(0);S=U+7|0;b[(c[277218]|0)+(S<<1)>>1]=af;b[(c[277218]|0)+(v<<1)>>1]=af;F=a[1108909]|0;a[(c[277219]|0)+S|0]=F;a[(c[277219]|0)+v|0]=F}}while(0);v=Z-1&255;if(v<<24>>24!=0){_=v;A=7816}}if((A|0)==7816){A=0;v=U+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+v|0]|0)){F=a[r+3|0]|0;if(F<<24>>24==0){break}S=b[(c[277225]|0)+((F&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){ah=b[(c[277221]|0)+(((S&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{F=c[277228]&65535;R=S&-2048;E=F&-2048;P=(R&65535)>(E&65535)?R-E&65535:0;E=S&2016;R=F&2016;if((E&65535)>(R&65535)){ai=(E-R&65535)+P&65535}else{ai=P}P=S&31;R=F&31;if((P&65535)<=(R&65535)){ah=ai;break}ah=(P-R&65535)+ai&65535}}while(0);S=U+9|0;b[(c[277218]|0)+(S<<1)>>1]=ah;b[(c[277218]|0)+(v<<1)>>1]=ah;R=a[1108909]|0;a[(c[277219]|0)+S|0]=R;a[(c[277219]|0)+v|0]=R}}while(0);v=_-1&255;if(v<<24>>24!=0){$=v;A=7826}}if((A|0)==7826){A=0;v=U+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+v|0]|0)){R=a[r+2|0]|0;if(R<<24>>24==0){break}S=b[(c[277225]|0)+((R&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aj=b[(c[277221]|0)+(((S&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{R=c[277228]&65535;P=S&-2048;F=R&-2048;E=(P&65535)>(F&65535)?P-F&65535:0;F=S&2016;P=R&2016;if((F&65535)>(P&65535)){ak=(F-P&65535)+E&65535}else{ak=E}E=S&31;P=R&31;if((E&65535)<=(P&65535)){aj=ak;break}aj=(E-P&65535)+ak&65535}}while(0);S=U+11|0;b[(c[277218]|0)+(S<<1)>>1]=aj;b[(c[277218]|0)+(v<<1)>>1]=aj;P=a[1108909]|0;a[(c[277219]|0)+S|0]=P;a[(c[277219]|0)+v|0]=P}}while(0);v=$-1&255;if(v<<24>>24!=0){aa=v;A=7836}}if((A|0)==7836){A=0;v=U+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+v|0]|0)){P=a[r+1|0]|0;if(P<<24>>24==0){break}S=b[(c[277225]|0)+((P&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){al=b[(c[277221]|0)+(((S&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{P=c[277228]&65535;E=S&-2048;R=P&-2048;F=(E&65535)>(R&65535)?E-R&65535:0;R=S&2016;E=P&2016;if((R&65535)>(E&65535)){am=(R-E&65535)+F&65535}else{am=F}F=S&31;E=P&31;if((F&65535)<=(E&65535)){al=am;break}al=(F-E&65535)+am&65535}}while(0);S=U+13|0;b[(c[277218]|0)+(S<<1)>>1]=al;b[(c[277218]|0)+(v<<1)>>1]=al;E=a[1108909]|0;a[(c[277219]|0)+S|0]=E;a[(c[277219]|0)+v|0]=E}}while(0);if(aa<<24>>24!=1){A=7846}}do{if((A|0)==7846){A=0;v=U+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+v|0]|0)){break}E=a[r]|0;if(E<<24>>24==0){break}S=b[(c[277225]|0)+((E&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){an=b[(c[277221]|0)+(((S&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{E=c[277228]&65535;F=S&-2048;P=E&-2048;R=(F&65535)>(P&65535)?F-P&65535:0;P=S&2016;F=E&2016;if((P&65535)>(F&65535)){ao=(P-F&65535)+R&65535}else{ao=R}R=S&31;F=E&31;if((R&65535)<=(F&65535)){an=ao;break}an=(R-F&65535)+ao&65535}}while(0);S=U+15|0;b[(c[277218]|0)+(S<<1)>>1]=an;b[(c[277218]|0)+(v<<1)>>1]=an;F=a[1108909]|0;a[(c[277219]|0)+S|0]=F;a[(c[277219]|0)+v|0]=F}}while(0);F=T-1|0;if((F|0)>0){r=r+8|0;T=F;U=(c[277223]|0)+U|0}else{break}}return}U=q+(56-i)|0;i=(j|0)>0;if(l){if(!i){return}l=h&255;q=l-1&255;T=q<<24>>24==0;r=U;an=j;ao=f;while(1){switch(g|0){case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+ao|0]|0)){aa=a[r+7|0]|0;if(aa<<24>>24==0){break}al=b[(c[277225]|0)+((aa&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){ap=b[(c[277221]|0)+(((al&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{aa=c[277228]&65535;am=al&-2048;$=aa&-2048;aj=(am&65535)>($&65535)?am-$&65535:0;$=al&2016;am=aa&2016;if(($&65535)>(am&65535)){aq=($-am&65535)+aj&65535}else{aq=aj}aj=al&31;am=aa&31;if((aj&65535)<=(am&65535)){ap=aq;break}ap=(aj-am&65535)+aq&65535}}while(0);al=ao+1|0;b[(c[277218]|0)+(al<<1)>>1]=ap;b[(c[277218]|0)+(ao<<1)>>1]=ap;v=a[1108909]|0;a[(c[277219]|0)+al|0]=v;a[(c[277219]|0)+ao|0]=v}}while(0);if(!T){ar=q;A=7953}break};case 5:{as=l;A=7993;break};case 2:{at=l;A=7963;break};case 3:{au=l;A=7973;break};case 4:{av=l;A=7983;break};case 6:{aw=l;A=8003;break};case 1:{ar=l;A=7953;break};case 7:{A=8013;break};default:{}}if((A|0)==7953){A=0;v=ao+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+v|0]|0)){al=a[r+6|0]|0;if(al<<24>>24==0){break}am=b[(c[277225]|0)+((al&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){ax=b[(c[277221]|0)+(((am&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{al=c[277228]&65535;aj=am&-2048;aa=al&-2048;$=(aj&65535)>(aa&65535)?aj-aa&65535:0;aa=am&2016;aj=al&2016;if((aa&65535)>(aj&65535)){ay=(aa-aj&65535)+$&65535}else{ay=$}$=am&31;aj=al&31;if(($&65535)<=(aj&65535)){ax=ay;break}ax=($-aj&65535)+ay&65535}}while(0);am=ao+3|0;b[(c[277218]|0)+(am<<1)>>1]=ax;b[(c[277218]|0)+(v<<1)>>1]=ax;aj=a[1108909]|0;a[(c[277219]|0)+am|0]=aj;a[(c[277219]|0)+v|0]=aj}}while(0);v=ar-1&255;if(v<<24>>24!=0){at=v;A=7963}}if((A|0)==7963){A=0;v=ao+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+v|0]|0)){aj=a[r+5|0]|0;if(aj<<24>>24==0){break}am=b[(c[277225]|0)+((aj&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){az=b[(c[277221]|0)+(((am&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{aj=c[277228]&65535;$=am&-2048;al=aj&-2048;aa=($&65535)>(al&65535)?$-al&65535:0;al=am&2016;$=aj&2016;if((al&65535)>($&65535)){aA=(al-$&65535)+aa&65535}else{aA=aa}aa=am&31;$=aj&31;if((aa&65535)<=($&65535)){az=aA;break}az=(aa-$&65535)+aA&65535}}while(0);am=ao+5|0;b[(c[277218]|0)+(am<<1)>>1]=az;b[(c[277218]|0)+(v<<1)>>1]=az;$=a[1108909]|0;a[(c[277219]|0)+am|0]=$;a[(c[277219]|0)+v|0]=$}}while(0);v=at-1&255;if(v<<24>>24!=0){au=v;A=7973}}if((A|0)==7973){A=0;v=ao+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+v|0]|0)){$=a[r+4|0]|0;if($<<24>>24==0){break}am=b[(c[277225]|0)+(($&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aB=b[(c[277221]|0)+(((am&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{$=c[277228]&65535;aa=am&-2048;aj=$&-2048;al=(aa&65535)>(aj&65535)?aa-aj&65535:0;aj=am&2016;aa=$&2016;if((aj&65535)>(aa&65535)){aC=(aj-aa&65535)+al&65535}else{aC=al}al=am&31;aa=$&31;if((al&65535)<=(aa&65535)){aB=aC;break}aB=(al-aa&65535)+aC&65535}}while(0);am=ao+7|0;b[(c[277218]|0)+(am<<1)>>1]=aB;b[(c[277218]|0)+(v<<1)>>1]=aB;aa=a[1108909]|0;a[(c[277219]|0)+am|0]=aa;a[(c[277219]|0)+v|0]=aa}}while(0);v=au-1&255;if(v<<24>>24!=0){av=v;A=7983}}if((A|0)==7983){A=0;v=ao+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+v|0]|0)){aa=a[r+3|0]|0;if(aa<<24>>24==0){break}am=b[(c[277225]|0)+((aa&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aD=b[(c[277221]|0)+(((am&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{aa=c[277228]&65535;al=am&-2048;$=aa&-2048;aj=(al&65535)>($&65535)?al-$&65535:0;$=am&2016;al=aa&2016;if(($&65535)>(al&65535)){aE=($-al&65535)+aj&65535}else{aE=aj}aj=am&31;al=aa&31;if((aj&65535)<=(al&65535)){aD=aE;break}aD=(aj-al&65535)+aE&65535}}while(0);am=ao+9|0;b[(c[277218]|0)+(am<<1)>>1]=aD;b[(c[277218]|0)+(v<<1)>>1]=aD;al=a[1108909]|0;a[(c[277219]|0)+am|0]=al;a[(c[277219]|0)+v|0]=al}}while(0);v=av-1&255;if(v<<24>>24!=0){as=v;A=7993}}if((A|0)==7993){A=0;v=ao+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+v|0]|0)){al=a[r+2|0]|0;if(al<<24>>24==0){break}am=b[(c[277225]|0)+((al&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aF=b[(c[277221]|0)+(((am&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{al=c[277228]&65535;aj=am&-2048;aa=al&-2048;$=(aj&65535)>(aa&65535)?aj-aa&65535:0;aa=am&2016;aj=al&2016;if((aa&65535)>(aj&65535)){aG=(aa-aj&65535)+$&65535}else{aG=$}$=am&31;aj=al&31;if(($&65535)<=(aj&65535)){aF=aG;break}aF=($-aj&65535)+aG&65535}}while(0);am=ao+11|0;b[(c[277218]|0)+(am<<1)>>1]=aF;b[(c[277218]|0)+(v<<1)>>1]=aF;aj=a[1108909]|0;a[(c[277219]|0)+am|0]=aj;a[(c[277219]|0)+v|0]=aj}}while(0);v=as-1&255;if(v<<24>>24!=0){aw=v;A=8003}}if((A|0)==8003){A=0;v=ao+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+v|0]|0)){aj=a[r+1|0]|0;if(aj<<24>>24==0){break}am=b[(c[277225]|0)+((aj&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aH=b[(c[277221]|0)+(((am&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{aj=c[277228]&65535;$=am&-2048;al=aj&-2048;aa=($&65535)>(al&65535)?$-al&65535:0;al=am&2016;$=aj&2016;if((al&65535)>($&65535)){aI=(al-$&65535)+aa&65535}else{aI=aa}aa=am&31;$=aj&31;if((aa&65535)<=($&65535)){aH=aI;break}aH=(aa-$&65535)+aI&65535}}while(0);am=ao+13|0;b[(c[277218]|0)+(am<<1)>>1]=aH;b[(c[277218]|0)+(v<<1)>>1]=aH;$=a[1108909]|0;a[(c[277219]|0)+am|0]=$;a[(c[277219]|0)+v|0]=$}}while(0);if(aw<<24>>24!=1){A=8013}}do{if((A|0)==8013){A=0;v=ao+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+v|0]|0)){break}$=a[r]|0;if($<<24>>24==0){break}am=b[(c[277225]|0)+(($&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aJ=b[(c[277221]|0)+(((am&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{$=c[277228]&65535;aa=am&-2048;aj=$&-2048;al=(aa&65535)>(aj&65535)?aa-aj&65535:0;aj=am&2016;aa=$&2016;if((aj&65535)>(aa&65535)){aK=(aj-aa&65535)+al&65535}else{aK=al}al=am&31;aa=$&31;if((al&65535)<=(aa&65535)){aJ=aK;break}aJ=(al-aa&65535)+aK&65535}}while(0);am=ao+15|0;b[(c[277218]|0)+(am<<1)>>1]=aJ;b[(c[277218]|0)+(v<<1)>>1]=aJ;aa=a[1108909]|0;a[(c[277219]|0)+am|0]=aa;a[(c[277219]|0)+v|0]=aa}}while(0);aa=an-1|0;if((aa|0)>0){r=r-8|0;an=aa;ao=(c[277223]|0)+ao|0}else{break}}return}else{if(!i){return}i=h&255;h=i-1&255;ao=h<<24>>24==0;an=U;U=j;j=f;while(1){switch(g|0){case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+j|0]|0)){f=a[an]|0;if(f<<24>>24==0){break}r=b[(c[277225]|0)+((f&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aL=b[(c[277221]|0)+(((r&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{f=c[277228]&65535;aJ=r&-2048;aK=f&-2048;aw=(aJ&65535)>(aK&65535)?aJ-aK&65535:0;aK=r&2016;aJ=f&2016;if((aK&65535)>(aJ&65535)){aM=(aK-aJ&65535)+aw&65535}else{aM=aw}aw=r&31;aJ=f&31;if((aw&65535)<=(aJ&65535)){aL=aM;break}aL=(aw-aJ&65535)+aM&65535}}while(0);r=j+1|0;b[(c[277218]|0)+(r<<1)>>1]=aL;b[(c[277218]|0)+(j<<1)>>1]=aL;v=a[1108909]|0;a[(c[277219]|0)+r|0]=v;a[(c[277219]|0)+j|0]=v}}while(0);if(!ao){aN=h;A=7872}break};case 5:{aO=i;A=7912;break};case 4:{aP=i;A=7902;break};case 7:{A=7932;break};case 6:{aQ=i;A=7922;break};case 2:{aR=i;A=7882;break};case 3:{aS=i;A=7892;break};case 1:{aN=i;A=7872;break};default:{}}if((A|0)==7872){A=0;v=j+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+v|0]|0)){r=a[an+1|0]|0;if(r<<24>>24==0){break}aJ=b[(c[277225]|0)+((r&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aT=b[(c[277221]|0)+(((aJ&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{r=c[277228]&65535;aw=aJ&-2048;f=r&-2048;aK=(aw&65535)>(f&65535)?aw-f&65535:0;f=aJ&2016;aw=r&2016;if((f&65535)>(aw&65535)){aU=(f-aw&65535)+aK&65535}else{aU=aK}aK=aJ&31;aw=r&31;if((aK&65535)<=(aw&65535)){aT=aU;break}aT=(aK-aw&65535)+aU&65535}}while(0);aJ=j+3|0;b[(c[277218]|0)+(aJ<<1)>>1]=aT;b[(c[277218]|0)+(v<<1)>>1]=aT;aw=a[1108909]|0;a[(c[277219]|0)+aJ|0]=aw;a[(c[277219]|0)+v|0]=aw}}while(0);v=aN-1&255;if(v<<24>>24!=0){aR=v;A=7882}}if((A|0)==7882){A=0;v=j+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+v|0]|0)){aw=a[an+2|0]|0;if(aw<<24>>24==0){break}aJ=b[(c[277225]|0)+((aw&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aV=b[(c[277221]|0)+(((aJ&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{aw=c[277228]&65535;aK=aJ&-2048;r=aw&-2048;f=(aK&65535)>(r&65535)?aK-r&65535:0;r=aJ&2016;aK=aw&2016;if((r&65535)>(aK&65535)){aW=(r-aK&65535)+f&65535}else{aW=f}f=aJ&31;aK=aw&31;if((f&65535)<=(aK&65535)){aV=aW;break}aV=(f-aK&65535)+aW&65535}}while(0);aJ=j+5|0;b[(c[277218]|0)+(aJ<<1)>>1]=aV;b[(c[277218]|0)+(v<<1)>>1]=aV;aK=a[1108909]|0;a[(c[277219]|0)+aJ|0]=aK;a[(c[277219]|0)+v|0]=aK}}while(0);v=aR-1&255;if(v<<24>>24!=0){aS=v;A=7892}}if((A|0)==7892){A=0;v=j+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+v|0]|0)){aK=a[an+3|0]|0;if(aK<<24>>24==0){break}aJ=b[(c[277225]|0)+((aK&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aX=b[(c[277221]|0)+(((aJ&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{aK=c[277228]&65535;f=aJ&-2048;aw=aK&-2048;r=(f&65535)>(aw&65535)?f-aw&65535:0;aw=aJ&2016;f=aK&2016;if((aw&65535)>(f&65535)){aY=(aw-f&65535)+r&65535}else{aY=r}r=aJ&31;f=aK&31;if((r&65535)<=(f&65535)){aX=aY;break}aX=(r-f&65535)+aY&65535}}while(0);aJ=j+7|0;b[(c[277218]|0)+(aJ<<1)>>1]=aX;b[(c[277218]|0)+(v<<1)>>1]=aX;f=a[1108909]|0;a[(c[277219]|0)+aJ|0]=f;a[(c[277219]|0)+v|0]=f}}while(0);v=aS-1&255;if(v<<24>>24!=0){aP=v;A=7902}}if((A|0)==7902){A=0;v=j+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+v|0]|0)){f=a[an+4|0]|0;if(f<<24>>24==0){break}aJ=b[(c[277225]|0)+((f&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aZ=b[(c[277221]|0)+(((aJ&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{f=c[277228]&65535;r=aJ&-2048;aK=f&-2048;aw=(r&65535)>(aK&65535)?r-aK&65535:0;aK=aJ&2016;r=f&2016;if((aK&65535)>(r&65535)){a_=(aK-r&65535)+aw&65535}else{a_=aw}aw=aJ&31;r=f&31;if((aw&65535)<=(r&65535)){aZ=a_;break}aZ=(aw-r&65535)+a_&65535}}while(0);aJ=j+9|0;b[(c[277218]|0)+(aJ<<1)>>1]=aZ;b[(c[277218]|0)+(v<<1)>>1]=aZ;r=a[1108909]|0;a[(c[277219]|0)+aJ|0]=r;a[(c[277219]|0)+v|0]=r}}while(0);v=aP-1&255;if(v<<24>>24!=0){aO=v;A=7912}}if((A|0)==7912){A=0;v=j+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+v|0]|0)){r=a[an+5|0]|0;if(r<<24>>24==0){break}aJ=b[(c[277225]|0)+((r&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){a$=b[(c[277221]|0)+(((aJ&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{r=c[277228]&65535;aw=aJ&-2048;f=r&-2048;aK=(aw&65535)>(f&65535)?aw-f&65535:0;f=aJ&2016;aw=r&2016;if((f&65535)>(aw&65535)){a0=(f-aw&65535)+aK&65535}else{a0=aK}aK=aJ&31;aw=r&31;if((aK&65535)<=(aw&65535)){a$=a0;break}a$=(aK-aw&65535)+a0&65535}}while(0);aJ=j+11|0;b[(c[277218]|0)+(aJ<<1)>>1]=a$;b[(c[277218]|0)+(v<<1)>>1]=a$;aw=a[1108909]|0;a[(c[277219]|0)+aJ|0]=aw;a[(c[277219]|0)+v|0]=aw}}while(0);v=aO-1&255;if(v<<24>>24!=0){aQ=v;A=7922}}if((A|0)==7922){A=0;v=j+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+v|0]|0)){aw=a[an+6|0]|0;if(aw<<24>>24==0){break}aJ=b[(c[277225]|0)+((aw&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){a1=b[(c[277221]|0)+(((aJ&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{aw=c[277228]&65535;aK=aJ&-2048;r=aw&-2048;f=(aK&65535)>(r&65535)?aK-r&65535:0;r=aJ&2016;aK=aw&2016;if((r&65535)>(aK&65535)){a2=(r-aK&65535)+f&65535}else{a2=f}f=aJ&31;aK=aw&31;if((f&65535)<=(aK&65535)){a1=a2;break}a1=(f-aK&65535)+a2&65535}}while(0);aJ=j+13|0;b[(c[277218]|0)+(aJ<<1)>>1]=a1;b[(c[277218]|0)+(v<<1)>>1]=a1;aK=a[1108909]|0;a[(c[277219]|0)+aJ|0]=aK;a[(c[277219]|0)+v|0]=aK}}while(0);if(aQ<<24>>24!=1){A=7932}}do{if((A|0)==7932){A=0;v=j+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+v|0]|0)){break}aK=a[an+7|0]|0;if(aK<<24>>24==0){break}aJ=b[(c[277225]|0)+((aK&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){a3=b[(c[277221]|0)+(((aJ&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{aK=c[277228]&65535;f=aJ&-2048;aw=aK&-2048;r=(f&65535)>(aw&65535)?f-aw&65535:0;aw=aJ&2016;f=aK&2016;if((aw&65535)>(f&65535)){a4=(aw-f&65535)+r&65535}else{a4=r}r=aJ&31;f=aK&31;if((r&65535)<=(f&65535)){a3=a4;break}a3=(r-f&65535)+a4&65535}}while(0);aJ=j+15|0;b[(c[277218]|0)+(aJ<<1)>>1]=a3;b[(c[277218]|0)+(v<<1)>>1]=a3;f=a[1108909]|0;a[(c[277219]|0)+aJ|0]=f;a[(c[277219]|0)+v|0]=f}}while(0);f=U-1|0;if((f|0)>0){an=an-8|0;U=f;j=(c[277223]|0)+j|0}else{break}}return}}function Ut(e,f,g,h,i,j){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0;k=e&1023;l=c[348606]|0;m=(k<<l)+(c[348604]|0)|0;if((e&256|0)==0){n=m}else{n=(c[348602]|0)+m|0}m=n&65535;n=m>>>(l>>>0);l=(e&16384|0)!=0;o=n<<6;do{if(l){p=(c[348622]|0)+o|0;if((a[(c[348618]|0)+n|0]|0)!=0){q=p;break}r=fi[c[348636]&63](p,m,k)|0;a[(c[348618]|0)+n|0]=r;q=p}else{p=(c[348624]|0)+o|0;if((a[(c[348620]|0)+n|0]|0)!=0){q=p;break}r=fi[c[348638]&63](p,m,k)|0;a[(c[348620]|0)+n|0]=r;q=p}}while(0);if((a[(c[348620]|0)+n|0]|0)==2){return}if((a[1394464]|0)==0){s=1106168+((e>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){n=d[1044485]|0;c[276541]=7080+(n<<5);k=0;do{m=k<<1&2;o=k&2;p=k&4;r=0;do{b[1125528+(k<<9)+(r<<1)>>1]=d[(r>>>1&28|o)+(7080+(n<<5))|0]<<6|d[(r<<2&28|m)+(7080+(n<<5))|0]<<11|d[(r>>>3&24|p)+(7080+(n<<5))|0];r=r+1|0;}while(r>>>0<256);k=k+1|0;}while(k>>>0<8);a[1106089]=0}s=1125528+((e>>>10&7)<<9)|0}c[277226]=s;c[277225]=(a[1108928]|0)!=0?1393712:s;if((e&49152|0)==0){if((j|0)<=0){return}s=h&255;k=s-1&255;n=k<<24>>24==0;r=q+i|0;p=j;m=f;while(1){switch(g|0){case 6:{t=s;u=8162;break};case 7:{u=8180;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+m|0]|0)){o=a[r]|0;v=o&255;if(o<<24>>24==0){break}do{if((a[1108928]|0)==0){o=b[(c[277225]|0)+(v<<1)>>1]|0;if((a[(c[277215]|0)+m|0]&32)!=0){w=b[(c[277221]|0)+((o&65535|67616)-(b[(c[277213]|0)+(m<<1)>>1]&63454)>>1<<1)>>1]|0;break}x=c[277228]&65535;y=o&-2048;z=x&-2048;A=(y&65535)>(z&65535)?y-z&65535:0;z=o&2016;y=x&2016;if((z&65535)>(y&65535)){B=(z-y&65535)+A&65535}else{B=A}A=o&31;o=x&31;if((A&65535)<=(o&65535)){w=B;break}w=(A-o&65535)+B&65535}else{o=b[(c[277225]|0)+(v<<1)>>1]|0;if((a[(c[277215]|0)+m|0]&32)==0){C=c[277228]&65535}else{C=b[(c[277213]|0)+(m<<1)>>1]|0}A=o&-2048;x=C&-2048;y=(A&65535)>(x&65535)?A-x&65535:0;x=o&2016;A=C&2016;if((x&65535)>(A&65535)){D=(x-A&65535)+y&65535}else{D=y}y=o&31;o=C&31;if((y&65535)<=(o&65535)){w=D;break}w=(y-o&65535)+D&65535}}while(0);v=m+1|0;b[(c[277218]|0)+(v<<1)>>1]=w;b[(c[277218]|0)+(m<<1)>>1]=w;o=a[1108909]|0;a[(c[277219]|0)+v|0]=o;a[(c[277219]|0)+m|0]=o}}while(0);if(!n){E=k;u=8072}break};case 1:{E=s;u=8072;break};case 2:{F=s;u=8090;break};case 3:{G=s;u=8108;break};case 4:{H=s;u=8126;break};case 5:{I=s;u=8144;break};default:{}}if((u|0)==8072){u=0;o=m+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){v=a[r+1|0]|0;y=v&255;if(v<<24>>24==0){break}do{if((a[1108928]|0)==0){v=b[(c[277225]|0)+(y<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){J=b[(c[277221]|0)+((v&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}A=c[277228]&65535;x=v&-2048;z=A&-2048;K=(x&65535)>(z&65535)?x-z&65535:0;z=v&2016;x=A&2016;if((z&65535)>(x&65535)){L=(z-x&65535)+K&65535}else{L=K}K=v&31;v=A&31;if((K&65535)<=(v&65535)){J=L;break}J=(K-v&65535)+L&65535}else{v=b[(c[277225]|0)+(y<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){M=c[277228]&65535}else{M=b[(c[277213]|0)+(o<<1)>>1]|0}K=v&-2048;A=M&-2048;x=(K&65535)>(A&65535)?K-A&65535:0;A=v&2016;K=M&2016;if((A&65535)>(K&65535)){N=(A-K&65535)+x&65535}else{N=x}x=v&31;v=M&31;if((x&65535)<=(v&65535)){J=N;break}J=(x-v&65535)+N&65535}}while(0);y=m+3|0;b[(c[277218]|0)+(y<<1)>>1]=J;b[(c[277218]|0)+(o<<1)>>1]=J;v=a[1108909]|0;a[(c[277219]|0)+y|0]=v;a[(c[277219]|0)+o|0]=v}}while(0);o=E-1&255;if(o<<24>>24!=0){F=o;u=8090}}if((u|0)==8090){u=0;o=m+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){v=a[r+2|0]|0;y=v&255;if(v<<24>>24==0){break}do{if((a[1108928]|0)==0){v=b[(c[277225]|0)+(y<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){O=b[(c[277221]|0)+((v&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}x=c[277228]&65535;K=v&-2048;A=x&-2048;z=(K&65535)>(A&65535)?K-A&65535:0;A=v&2016;K=x&2016;if((A&65535)>(K&65535)){P=(A-K&65535)+z&65535}else{P=z}z=v&31;v=x&31;if((z&65535)<=(v&65535)){O=P;break}O=(z-v&65535)+P&65535}else{v=b[(c[277225]|0)+(y<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){Q=c[277228]&65535}else{Q=b[(c[277213]|0)+(o<<1)>>1]|0}z=v&-2048;x=Q&-2048;K=(z&65535)>(x&65535)?z-x&65535:0;x=v&2016;z=Q&2016;if((x&65535)>(z&65535)){R=(x-z&65535)+K&65535}else{R=K}K=v&31;v=Q&31;if((K&65535)<=(v&65535)){O=R;break}O=(K-v&65535)+R&65535}}while(0);y=m+5|0;b[(c[277218]|0)+(y<<1)>>1]=O;b[(c[277218]|0)+(o<<1)>>1]=O;v=a[1108909]|0;a[(c[277219]|0)+y|0]=v;a[(c[277219]|0)+o|0]=v}}while(0);o=F-1&255;if(o<<24>>24!=0){G=o;u=8108}}if((u|0)==8108){u=0;o=m+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){v=a[r+3|0]|0;y=v&255;if(v<<24>>24==0){break}do{if((a[1108928]|0)==0){v=b[(c[277225]|0)+(y<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){S=b[(c[277221]|0)+((v&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}K=c[277228]&65535;z=v&-2048;x=K&-2048;A=(z&65535)>(x&65535)?z-x&65535:0;x=v&2016;z=K&2016;if((x&65535)>(z&65535)){T=(x-z&65535)+A&65535}else{T=A}A=v&31;v=K&31;if((A&65535)<=(v&65535)){S=T;break}S=(A-v&65535)+T&65535}else{v=b[(c[277225]|0)+(y<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){U=c[277228]&65535}else{U=b[(c[277213]|0)+(o<<1)>>1]|0}A=v&-2048;K=U&-2048;z=(A&65535)>(K&65535)?A-K&65535:0;K=v&2016;A=U&2016;if((K&65535)>(A&65535)){V=(K-A&65535)+z&65535}else{V=z}z=v&31;v=U&31;if((z&65535)<=(v&65535)){S=V;break}S=(z-v&65535)+V&65535}}while(0);y=m+7|0;b[(c[277218]|0)+(y<<1)>>1]=S;b[(c[277218]|0)+(o<<1)>>1]=S;v=a[1108909]|0;a[(c[277219]|0)+y|0]=v;a[(c[277219]|0)+o|0]=v}}while(0);o=G-1&255;if(o<<24>>24!=0){H=o;u=8126}}if((u|0)==8126){u=0;o=m+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){v=a[r+4|0]|0;y=v&255;if(v<<24>>24==0){break}do{if((a[1108928]|0)==0){v=b[(c[277225]|0)+(y<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){W=b[(c[277221]|0)+((v&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}z=c[277228]&65535;A=v&-2048;K=z&-2048;x=(A&65535)>(K&65535)?A-K&65535:0;K=v&2016;A=z&2016;if((K&65535)>(A&65535)){X=(K-A&65535)+x&65535}else{X=x}x=v&31;v=z&31;if((x&65535)<=(v&65535)){W=X;break}W=(x-v&65535)+X&65535}else{v=b[(c[277225]|0)+(y<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){Y=c[277228]&65535}else{Y=b[(c[277213]|0)+(o<<1)>>1]|0}x=v&-2048;z=Y&-2048;A=(x&65535)>(z&65535)?x-z&65535:0;z=v&2016;x=Y&2016;if((z&65535)>(x&65535)){Z=(z-x&65535)+A&65535}else{Z=A}A=v&31;v=Y&31;if((A&65535)<=(v&65535)){W=Z;break}W=(A-v&65535)+Z&65535}}while(0);y=m+9|0;b[(c[277218]|0)+(y<<1)>>1]=W;b[(c[277218]|0)+(o<<1)>>1]=W;v=a[1108909]|0;a[(c[277219]|0)+y|0]=v;a[(c[277219]|0)+o|0]=v}}while(0);o=H-1&255;if(o<<24>>24!=0){I=o;u=8144}}if((u|0)==8144){u=0;o=m+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){v=a[r+5|0]|0;y=v&255;if(v<<24>>24==0){break}do{if((a[1108928]|0)==0){v=b[(c[277225]|0)+(y<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){_=b[(c[277221]|0)+((v&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}A=c[277228]&65535;x=v&-2048;z=A&-2048;K=(x&65535)>(z&65535)?x-z&65535:0;z=v&2016;x=A&2016;if((z&65535)>(x&65535)){$=(z-x&65535)+K&65535}else{$=K}K=v&31;v=A&31;if((K&65535)<=(v&65535)){_=$;break}_=(K-v&65535)+$&65535}else{v=b[(c[277225]|0)+(y<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){aa=c[277228]&65535}else{aa=b[(c[277213]|0)+(o<<1)>>1]|0}K=v&-2048;A=aa&-2048;x=(K&65535)>(A&65535)?K-A&65535:0;A=v&2016;K=aa&2016;if((A&65535)>(K&65535)){ab=(A-K&65535)+x&65535}else{ab=x}x=v&31;v=aa&31;if((x&65535)<=(v&65535)){_=ab;break}_=(x-v&65535)+ab&65535}}while(0);y=m+11|0;b[(c[277218]|0)+(y<<1)>>1]=_;b[(c[277218]|0)+(o<<1)>>1]=_;v=a[1108909]|0;a[(c[277219]|0)+y|0]=v;a[(c[277219]|0)+o|0]=v}}while(0);o=I-1&255;if(o<<24>>24!=0){t=o;u=8162}}if((u|0)==8162){u=0;o=m+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){v=a[r+6|0]|0;y=v&255;if(v<<24>>24==0){break}do{if((a[1108928]|0)==0){v=b[(c[277225]|0)+(y<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){ac=b[(c[277221]|0)+((v&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}x=c[277228]&65535;K=v&-2048;A=x&-2048;z=(K&65535)>(A&65535)?K-A&65535:0;A=v&2016;K=x&2016;if((A&65535)>(K&65535)){ad=(A-K&65535)+z&65535}else{ad=z}z=v&31;v=x&31;if((z&65535)<=(v&65535)){ac=ad;break}ac=(z-v&65535)+ad&65535}else{v=b[(c[277225]|0)+(y<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){ae=c[277228]&65535}else{ae=b[(c[277213]|0)+(o<<1)>>1]|0}z=v&-2048;x=ae&-2048;K=(z&65535)>(x&65535)?z-x&65535:0;x=v&2016;z=ae&2016;if((x&65535)>(z&65535)){af=(x-z&65535)+K&65535}else{af=K}K=v&31;v=ae&31;if((K&65535)<=(v&65535)){ac=af;break}ac=(K-v&65535)+af&65535}}while(0);y=m+13|0;b[(c[277218]|0)+(y<<1)>>1]=ac;b[(c[277218]|0)+(o<<1)>>1]=ac;v=a[1108909]|0;a[(c[277219]|0)+y|0]=v;a[(c[277219]|0)+o|0]=v}}while(0);if(t<<24>>24!=1){u=8180}}do{if((u|0)==8180){u=0;o=m+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+o|0]|0)){break}v=a[r+7|0]|0;y=v&255;if(v<<24>>24==0){break}do{if((a[1108928]|0)==0){v=b[(c[277225]|0)+(y<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){ag=b[(c[277221]|0)+((v&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}K=c[277228]&65535;z=v&-2048;x=K&-2048;A=(z&65535)>(x&65535)?z-x&65535:0;x=v&2016;z=K&2016;if((x&65535)>(z&65535)){ah=(x-z&65535)+A&65535}else{ah=A}A=v&31;v=K&31;if((A&65535)<=(v&65535)){ag=ah;break}ag=(A-v&65535)+ah&65535}else{v=b[(c[277225]|0)+(y<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){ai=c[277228]&65535}else{ai=b[(c[277213]|0)+(o<<1)>>1]|0}A=v&-2048;K=ai&-2048;z=(A&65535)>(K&65535)?A-K&65535:0;K=v&2016;A=ai&2016;if((K&65535)>(A&65535)){aj=(K-A&65535)+z&65535}else{aj=z}z=v&31;v=ai&31;if((z&65535)<=(v&65535)){ag=aj;break}ag=(z-v&65535)+aj&65535}}while(0);y=m+15|0;b[(c[277218]|0)+(y<<1)>>1]=ag;b[(c[277218]|0)+(o<<1)>>1]=ag;v=a[1108909]|0;a[(c[277219]|0)+y|0]=v;a[(c[277219]|0)+o|0]=v}}while(0);v=p-1|0;if((v|0)>0){r=r+8|0;p=v;m=(c[277223]|0)+m|0}else{break}}return}if((e&32768|0)==0){if((j|0)<=0){return}e=h&255;m=e-1&255;p=m<<24>>24==0;r=q+i|0;ag=j;aj=f;while(1){switch(g|0){case 2:{ak=e;u=8238;break};case 3:{al=e;u=8256;break};case 5:{am=e;u=8292;break};case 6:{an=e;u=8310;break};case 4:{ao=e;u=8274;break};case 1:{ap=e;u=8220;break};case 7:{u=8328;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+aj|0]|0)){ai=a[r+7|0]|0;ah=ai&255;if(ai<<24>>24==0){break}do{if((a[1108928]|0)==0){ai=b[(c[277225]|0)+(ah<<1)>>1]|0;if((a[(c[277215]|0)+aj|0]&32)!=0){aq=b[(c[277221]|0)+((ai&65535|67616)-(b[(c[277213]|0)+(aj<<1)>>1]&63454)>>1<<1)>>1]|0;break}t=c[277228]&65535;ac=ai&-2048;af=t&-2048;ae=(ac&65535)>(af&65535)?ac-af&65535:0;af=ai&2016;ac=t&2016;if((af&65535)>(ac&65535)){ar=(af-ac&65535)+ae&65535}else{ar=ae}ae=ai&31;ai=t&31;if((ae&65535)<=(ai&65535)){aq=ar;break}aq=(ae-ai&65535)+ar&65535}else{ai=b[(c[277225]|0)+(ah<<1)>>1]|0;if((a[(c[277215]|0)+aj|0]&32)==0){as=c[277228]&65535}else{as=b[(c[277213]|0)+(aj<<1)>>1]|0}ae=ai&-2048;t=as&-2048;ac=(ae&65535)>(t&65535)?ae-t&65535:0;t=ai&2016;ae=as&2016;if((t&65535)>(ae&65535)){at=(t-ae&65535)+ac&65535}else{at=ac}ac=ai&31;ai=as&31;if((ac&65535)<=(ai&65535)){aq=at;break}aq=(ac-ai&65535)+at&65535}}while(0);ah=aj+1|0;b[(c[277218]|0)+(ah<<1)>>1]=aq;b[(c[277218]|0)+(aj<<1)>>1]=aq;o=a[1108909]|0;a[(c[277219]|0)+ah|0]=o;a[(c[277219]|0)+aj|0]=o}}while(0);if(!p){ap=m;u=8220}break};default:{}}if((u|0)==8220){u=0;o=aj+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){ah=a[r+6|0]|0;ai=ah&255;if(ah<<24>>24==0){break}do{if((a[1108928]|0)==0){ah=b[(c[277225]|0)+(ai<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){au=b[(c[277221]|0)+((ah&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}ac=c[277228]&65535;ae=ah&-2048;t=ac&-2048;af=(ae&65535)>(t&65535)?ae-t&65535:0;t=ah&2016;ae=ac&2016;if((t&65535)>(ae&65535)){av=(t-ae&65535)+af&65535}else{av=af}af=ah&31;ah=ac&31;if((af&65535)<=(ah&65535)){au=av;break}au=(af-ah&65535)+av&65535}else{ah=b[(c[277225]|0)+(ai<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){aw=c[277228]&65535}else{aw=b[(c[277213]|0)+(o<<1)>>1]|0}af=ah&-2048;ac=aw&-2048;ae=(af&65535)>(ac&65535)?af-ac&65535:0;ac=ah&2016;af=aw&2016;if((ac&65535)>(af&65535)){ax=(ac-af&65535)+ae&65535}else{ax=ae}ae=ah&31;ah=aw&31;if((ae&65535)<=(ah&65535)){au=ax;break}au=(ae-ah&65535)+ax&65535}}while(0);ai=aj+3|0;b[(c[277218]|0)+(ai<<1)>>1]=au;b[(c[277218]|0)+(o<<1)>>1]=au;ah=a[1108909]|0;a[(c[277219]|0)+ai|0]=ah;a[(c[277219]|0)+o|0]=ah}}while(0);o=ap-1&255;if(o<<24>>24!=0){ak=o;u=8238}}if((u|0)==8238){u=0;o=aj+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){ah=a[r+5|0]|0;ai=ah&255;if(ah<<24>>24==0){break}do{if((a[1108928]|0)==0){ah=b[(c[277225]|0)+(ai<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){ay=b[(c[277221]|0)+((ah&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}ae=c[277228]&65535;af=ah&-2048;ac=ae&-2048;t=(af&65535)>(ac&65535)?af-ac&65535:0;ac=ah&2016;af=ae&2016;if((ac&65535)>(af&65535)){az=(ac-af&65535)+t&65535}else{az=t}t=ah&31;ah=ae&31;if((t&65535)<=(ah&65535)){ay=az;break}ay=(t-ah&65535)+az&65535}else{ah=b[(c[277225]|0)+(ai<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){aA=c[277228]&65535}else{aA=b[(c[277213]|0)+(o<<1)>>1]|0}t=ah&-2048;ae=aA&-2048;af=(t&65535)>(ae&65535)?t-ae&65535:0;ae=ah&2016;t=aA&2016;if((ae&65535)>(t&65535)){aB=(ae-t&65535)+af&65535}else{aB=af}af=ah&31;ah=aA&31;if((af&65535)<=(ah&65535)){ay=aB;break}ay=(af-ah&65535)+aB&65535}}while(0);ai=aj+5|0;b[(c[277218]|0)+(ai<<1)>>1]=ay;b[(c[277218]|0)+(o<<1)>>1]=ay;ah=a[1108909]|0;a[(c[277219]|0)+ai|0]=ah;a[(c[277219]|0)+o|0]=ah}}while(0);o=ak-1&255;if(o<<24>>24!=0){al=o;u=8256}}if((u|0)==8256){u=0;o=aj+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){ah=a[r+4|0]|0;ai=ah&255;if(ah<<24>>24==0){break}do{if((a[1108928]|0)==0){ah=b[(c[277225]|0)+(ai<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){aC=b[(c[277221]|0)+((ah&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}af=c[277228]&65535;t=ah&-2048;ae=af&-2048;ac=(t&65535)>(ae&65535)?t-ae&65535:0;ae=ah&2016;t=af&2016;if((ae&65535)>(t&65535)){aD=(ae-t&65535)+ac&65535}else{aD=ac}ac=ah&31;ah=af&31;if((ac&65535)<=(ah&65535)){aC=aD;break}aC=(ac-ah&65535)+aD&65535}else{ah=b[(c[277225]|0)+(ai<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){aE=c[277228]&65535}else{aE=b[(c[277213]|0)+(o<<1)>>1]|0}ac=ah&-2048;af=aE&-2048;t=(ac&65535)>(af&65535)?ac-af&65535:0;af=ah&2016;ac=aE&2016;if((af&65535)>(ac&65535)){aF=(af-ac&65535)+t&65535}else{aF=t}t=ah&31;ah=aE&31;if((t&65535)<=(ah&65535)){aC=aF;break}aC=(t-ah&65535)+aF&65535}}while(0);ai=aj+7|0;b[(c[277218]|0)+(ai<<1)>>1]=aC;b[(c[277218]|0)+(o<<1)>>1]=aC;ah=a[1108909]|0;a[(c[277219]|0)+ai|0]=ah;a[(c[277219]|0)+o|0]=ah}}while(0);o=al-1&255;if(o<<24>>24!=0){ao=o;u=8274}}if((u|0)==8274){u=0;o=aj+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){ah=a[r+3|0]|0;ai=ah&255;if(ah<<24>>24==0){break}do{if((a[1108928]|0)==0){ah=b[(c[277225]|0)+(ai<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){aG=b[(c[277221]|0)+((ah&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}t=c[277228]&65535;ac=ah&-2048;af=t&-2048;ae=(ac&65535)>(af&65535)?ac-af&65535:0;af=ah&2016;ac=t&2016;if((af&65535)>(ac&65535)){aH=(af-ac&65535)+ae&65535}else{aH=ae}ae=ah&31;ah=t&31;if((ae&65535)<=(ah&65535)){aG=aH;break}aG=(ae-ah&65535)+aH&65535}else{ah=b[(c[277225]|0)+(ai<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){aI=c[277228]&65535}else{aI=b[(c[277213]|0)+(o<<1)>>1]|0}ae=ah&-2048;t=aI&-2048;ac=(ae&65535)>(t&65535)?ae-t&65535:0;t=ah&2016;ae=aI&2016;if((t&65535)>(ae&65535)){aJ=(t-ae&65535)+ac&65535}else{aJ=ac}ac=ah&31;ah=aI&31;if((ac&65535)<=(ah&65535)){aG=aJ;break}aG=(ac-ah&65535)+aJ&65535}}while(0);ai=aj+9|0;b[(c[277218]|0)+(ai<<1)>>1]=aG;b[(c[277218]|0)+(o<<1)>>1]=aG;ah=a[1108909]|0;a[(c[277219]|0)+ai|0]=ah;a[(c[277219]|0)+o|0]=ah}}while(0);o=ao-1&255;if(o<<24>>24!=0){am=o;u=8292}}if((u|0)==8292){u=0;o=aj+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){ah=a[r+2|0]|0;ai=ah&255;if(ah<<24>>24==0){break}do{if((a[1108928]|0)==0){ah=b[(c[277225]|0)+(ai<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){aK=b[(c[277221]|0)+((ah&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}ac=c[277228]&65535;ae=ah&-2048;t=ac&-2048;af=(ae&65535)>(t&65535)?ae-t&65535:0;t=ah&2016;ae=ac&2016;if((t&65535)>(ae&65535)){aL=(t-ae&65535)+af&65535}else{aL=af}af=ah&31;ah=ac&31;if((af&65535)<=(ah&65535)){aK=aL;break}aK=(af-ah&65535)+aL&65535}else{ah=b[(c[277225]|0)+(ai<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){aM=c[277228]&65535}else{aM=b[(c[277213]|0)+(o<<1)>>1]|0}af=ah&-2048;ac=aM&-2048;ae=(af&65535)>(ac&65535)?af-ac&65535:0;ac=ah&2016;af=aM&2016;if((ac&65535)>(af&65535)){aN=(ac-af&65535)+ae&65535}else{aN=ae}ae=ah&31;ah=aM&31;if((ae&65535)<=(ah&65535)){aK=aN;break}aK=(ae-ah&65535)+aN&65535}}while(0);ai=aj+11|0;b[(c[277218]|0)+(ai<<1)>>1]=aK;b[(c[277218]|0)+(o<<1)>>1]=aK;ah=a[1108909]|0;a[(c[277219]|0)+ai|0]=ah;a[(c[277219]|0)+o|0]=ah}}while(0);o=am-1&255;if(o<<24>>24!=0){an=o;u=8310}}if((u|0)==8310){u=0;o=aj+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){ah=a[r+1|0]|0;ai=ah&255;if(ah<<24>>24==0){break}do{if((a[1108928]|0)==0){ah=b[(c[277225]|0)+(ai<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){aO=b[(c[277221]|0)+((ah&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}ae=c[277228]&65535;af=ah&-2048;ac=ae&-2048;t=(af&65535)>(ac&65535)?af-ac&65535:0;ac=ah&2016;af=ae&2016;if((ac&65535)>(af&65535)){aP=(ac-af&65535)+t&65535}else{aP=t}t=ah&31;ah=ae&31;if((t&65535)<=(ah&65535)){aO=aP;break}aO=(t-ah&65535)+aP&65535}else{ah=b[(c[277225]|0)+(ai<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){aQ=c[277228]&65535}else{aQ=b[(c[277213]|0)+(o<<1)>>1]|0}t=ah&-2048;ae=aQ&-2048;af=(t&65535)>(ae&65535)?t-ae&65535:0;ae=ah&2016;t=aQ&2016;if((ae&65535)>(t&65535)){aR=(ae-t&65535)+af&65535}else{aR=af}af=ah&31;ah=aQ&31;if((af&65535)<=(ah&65535)){aO=aR;break}aO=(af-ah&65535)+aR&65535}}while(0);ai=aj+13|0;b[(c[277218]|0)+(ai<<1)>>1]=aO;b[(c[277218]|0)+(o<<1)>>1]=aO;ah=a[1108909]|0;a[(c[277219]|0)+ai|0]=ah;a[(c[277219]|0)+o|0]=ah}}while(0);if(an<<24>>24!=1){u=8328}}do{if((u|0)==8328){u=0;o=aj+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+o|0]|0)){break}ah=a[r]|0;ai=ah&255;if(ah<<24>>24==0){break}do{if((a[1108928]|0)==0){ah=b[(c[277225]|0)+(ai<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){aS=b[(c[277221]|0)+((ah&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}af=c[277228]&65535;t=ah&-2048;ae=af&-2048;ac=(t&65535)>(ae&65535)?t-ae&65535:0;ae=ah&2016;t=af&2016;if((ae&65535)>(t&65535)){aT=(ae-t&65535)+ac&65535}else{aT=ac}ac=ah&31;ah=af&31;if((ac&65535)<=(ah&65535)){aS=aT;break}aS=(ac-ah&65535)+aT&65535}else{ah=b[(c[277225]|0)+(ai<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){aU=c[277228]&65535}else{aU=b[(c[277213]|0)+(o<<1)>>1]|0}ac=ah&-2048;af=aU&-2048;t=(ac&65535)>(af&65535)?ac-af&65535:0;af=ah&2016;ac=aU&2016;if((af&65535)>(ac&65535)){aV=(af-ac&65535)+t&65535}else{aV=t}t=ah&31;ah=aU&31;if((t&65535)<=(ah&65535)){aS=aV;break}aS=(t-ah&65535)+aV&65535}}while(0);ai=aj+15|0;b[(c[277218]|0)+(ai<<1)>>1]=aS;b[(c[277218]|0)+(o<<1)>>1]=aS;ah=a[1108909]|0;a[(c[277219]|0)+ai|0]=ah;a[(c[277219]|0)+o|0]=ah}}while(0);ah=ag-1|0;if((ah|0)>0){r=r+8|0;ag=ah;aj=(c[277223]|0)+aj|0}else{break}}return}aj=q+(56-i)|0;i=(j|0)>0;if(l){if(!i){return}l=h&255;q=l-1&255;ag=q<<24>>24==0;r=aj;aS=j;aV=f;while(1){switch(g|0){case 3:{aW=l;u=8551;break};case 4:{aX=l;u=8569;break};case 2:{aY=l;u=8533;break};case 7:{u=8623;break};case 5:{aZ=l;u=8587;break};case 6:{a_=l;u=8605;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+aV|0]|0)){aU=a[r+7|0]|0;aT=aU&255;if(aU<<24>>24==0){break}do{if((a[1108928]|0)==0){aU=b[(c[277225]|0)+(aT<<1)>>1]|0;if((a[(c[277215]|0)+aV|0]&32)!=0){a$=b[(c[277221]|0)+((aU&65535|67616)-(b[(c[277213]|0)+(aV<<1)>>1]&63454)>>1<<1)>>1]|0;break}an=c[277228]&65535;aO=aU&-2048;aR=an&-2048;aQ=(aO&65535)>(aR&65535)?aO-aR&65535:0;aR=aU&2016;aO=an&2016;if((aR&65535)>(aO&65535)){a0=(aR-aO&65535)+aQ&65535}else{a0=aQ}aQ=aU&31;aU=an&31;if((aQ&65535)<=(aU&65535)){a$=a0;break}a$=(aQ-aU&65535)+a0&65535}else{aU=b[(c[277225]|0)+(aT<<1)>>1]|0;if((a[(c[277215]|0)+aV|0]&32)==0){a1=c[277228]&65535}else{a1=b[(c[277213]|0)+(aV<<1)>>1]|0}aQ=aU&-2048;an=a1&-2048;aO=(aQ&65535)>(an&65535)?aQ-an&65535:0;an=aU&2016;aQ=a1&2016;if((an&65535)>(aQ&65535)){a2=(an-aQ&65535)+aO&65535}else{a2=aO}aO=aU&31;aU=a1&31;if((aO&65535)<=(aU&65535)){a$=a2;break}a$=(aO-aU&65535)+a2&65535}}while(0);aT=aV+1|0;b[(c[277218]|0)+(aT<<1)>>1]=a$;b[(c[277218]|0)+(aV<<1)>>1]=a$;o=a[1108909]|0;a[(c[277219]|0)+aT|0]=o;a[(c[277219]|0)+aV|0]=o}}while(0);if(!ag){a3=q;u=8515}break};case 1:{a3=l;u=8515;break};default:{}}if((u|0)==8515){u=0;o=aV+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){aT=a[r+6|0]|0;aU=aT&255;if(aT<<24>>24==0){break}do{if((a[1108928]|0)==0){aT=b[(c[277225]|0)+(aU<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){a4=b[(c[277221]|0)+((aT&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}aO=c[277228]&65535;aQ=aT&-2048;an=aO&-2048;aR=(aQ&65535)>(an&65535)?aQ-an&65535:0;an=aT&2016;aQ=aO&2016;if((an&65535)>(aQ&65535)){a5=(an-aQ&65535)+aR&65535}else{a5=aR}aR=aT&31;aT=aO&31;if((aR&65535)<=(aT&65535)){a4=a5;break}a4=(aR-aT&65535)+a5&65535}else{aT=b[(c[277225]|0)+(aU<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){a6=c[277228]&65535}else{a6=b[(c[277213]|0)+(o<<1)>>1]|0}aR=aT&-2048;aO=a6&-2048;aQ=(aR&65535)>(aO&65535)?aR-aO&65535:0;aO=aT&2016;aR=a6&2016;if((aO&65535)>(aR&65535)){a7=(aO-aR&65535)+aQ&65535}else{a7=aQ}aQ=aT&31;aT=a6&31;if((aQ&65535)<=(aT&65535)){a4=a7;break}a4=(aQ-aT&65535)+a7&65535}}while(0);aU=aV+3|0;b[(c[277218]|0)+(aU<<1)>>1]=a4;b[(c[277218]|0)+(o<<1)>>1]=a4;aT=a[1108909]|0;a[(c[277219]|0)+aU|0]=aT;a[(c[277219]|0)+o|0]=aT}}while(0);o=a3-1&255;if(o<<24>>24!=0){aY=o;u=8533}}if((u|0)==8533){u=0;o=aV+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){aT=a[r+5|0]|0;aU=aT&255;if(aT<<24>>24==0){break}do{if((a[1108928]|0)==0){aT=b[(c[277225]|0)+(aU<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){a8=b[(c[277221]|0)+((aT&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}aQ=c[277228]&65535;aR=aT&-2048;aO=aQ&-2048;an=(aR&65535)>(aO&65535)?aR-aO&65535:0;aO=aT&2016;aR=aQ&2016;if((aO&65535)>(aR&65535)){a9=(aO-aR&65535)+an&65535}else{a9=an}an=aT&31;aT=aQ&31;if((an&65535)<=(aT&65535)){a8=a9;break}a8=(an-aT&65535)+a9&65535}else{aT=b[(c[277225]|0)+(aU<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){ba=c[277228]&65535}else{ba=b[(c[277213]|0)+(o<<1)>>1]|0}an=aT&-2048;aQ=ba&-2048;aR=(an&65535)>(aQ&65535)?an-aQ&65535:0;aQ=aT&2016;an=ba&2016;if((aQ&65535)>(an&65535)){bb=(aQ-an&65535)+aR&65535}else{bb=aR}aR=aT&31;aT=ba&31;if((aR&65535)<=(aT&65535)){a8=bb;break}a8=(aR-aT&65535)+bb&65535}}while(0);aU=aV+5|0;b[(c[277218]|0)+(aU<<1)>>1]=a8;b[(c[277218]|0)+(o<<1)>>1]=a8;aT=a[1108909]|0;a[(c[277219]|0)+aU|0]=aT;a[(c[277219]|0)+o|0]=aT}}while(0);o=aY-1&255;if(o<<24>>24!=0){aW=o;u=8551}}if((u|0)==8551){u=0;o=aV+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){aT=a[r+4|0]|0;aU=aT&255;if(aT<<24>>24==0){break}do{if((a[1108928]|0)==0){aT=b[(c[277225]|0)+(aU<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){bc=b[(c[277221]|0)+((aT&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}aR=c[277228]&65535;an=aT&-2048;aQ=aR&-2048;aO=(an&65535)>(aQ&65535)?an-aQ&65535:0;aQ=aT&2016;an=aR&2016;if((aQ&65535)>(an&65535)){bd=(aQ-an&65535)+aO&65535}else{bd=aO}aO=aT&31;aT=aR&31;if((aO&65535)<=(aT&65535)){bc=bd;break}bc=(aO-aT&65535)+bd&65535}else{aT=b[(c[277225]|0)+(aU<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){be=c[277228]&65535}else{be=b[(c[277213]|0)+(o<<1)>>1]|0}aO=aT&-2048;aR=be&-2048;an=(aO&65535)>(aR&65535)?aO-aR&65535:0;aR=aT&2016;aO=be&2016;if((aR&65535)>(aO&65535)){bf=(aR-aO&65535)+an&65535}else{bf=an}an=aT&31;aT=be&31;if((an&65535)<=(aT&65535)){bc=bf;break}bc=(an-aT&65535)+bf&65535}}while(0);aU=aV+7|0;b[(c[277218]|0)+(aU<<1)>>1]=bc;b[(c[277218]|0)+(o<<1)>>1]=bc;aT=a[1108909]|0;a[(c[277219]|0)+aU|0]=aT;a[(c[277219]|0)+o|0]=aT}}while(0);o=aW-1&255;if(o<<24>>24!=0){aX=o;u=8569}}if((u|0)==8569){u=0;o=aV+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){aT=a[r+3|0]|0;aU=aT&255;if(aT<<24>>24==0){break}do{if((a[1108928]|0)==0){aT=b[(c[277225]|0)+(aU<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){bg=b[(c[277221]|0)+((aT&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}an=c[277228]&65535;aO=aT&-2048;aR=an&-2048;aQ=(aO&65535)>(aR&65535)?aO-aR&65535:0;aR=aT&2016;aO=an&2016;if((aR&65535)>(aO&65535)){bh=(aR-aO&65535)+aQ&65535}else{bh=aQ}aQ=aT&31;aT=an&31;if((aQ&65535)<=(aT&65535)){bg=bh;break}bg=(aQ-aT&65535)+bh&65535}else{aT=b[(c[277225]|0)+(aU<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){bi=c[277228]&65535}else{bi=b[(c[277213]|0)+(o<<1)>>1]|0}aQ=aT&-2048;an=bi&-2048;aO=(aQ&65535)>(an&65535)?aQ-an&65535:0;an=aT&2016;aQ=bi&2016;if((an&65535)>(aQ&65535)){bj=(an-aQ&65535)+aO&65535}else{bj=aO}aO=aT&31;aT=bi&31;if((aO&65535)<=(aT&65535)){bg=bj;break}bg=(aO-aT&65535)+bj&65535}}while(0);aU=aV+9|0;b[(c[277218]|0)+(aU<<1)>>1]=bg;b[(c[277218]|0)+(o<<1)>>1]=bg;aT=a[1108909]|0;a[(c[277219]|0)+aU|0]=aT;a[(c[277219]|0)+o|0]=aT}}while(0);o=aX-1&255;if(o<<24>>24!=0){aZ=o;u=8587}}if((u|0)==8587){u=0;o=aV+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){aT=a[r+2|0]|0;aU=aT&255;if(aT<<24>>24==0){break}do{if((a[1108928]|0)==0){aT=b[(c[277225]|0)+(aU<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){bk=b[(c[277221]|0)+((aT&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}aO=c[277228]&65535;aQ=aT&-2048;an=aO&-2048;aR=(aQ&65535)>(an&65535)?aQ-an&65535:0;an=aT&2016;aQ=aO&2016;if((an&65535)>(aQ&65535)){bl=(an-aQ&65535)+aR&65535}else{bl=aR}aR=aT&31;aT=aO&31;if((aR&65535)<=(aT&65535)){bk=bl;break}bk=(aR-aT&65535)+bl&65535}else{aT=b[(c[277225]|0)+(aU<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){bm=c[277228]&65535}else{bm=b[(c[277213]|0)+(o<<1)>>1]|0}aR=aT&-2048;aO=bm&-2048;aQ=(aR&65535)>(aO&65535)?aR-aO&65535:0;aO=aT&2016;aR=bm&2016;if((aO&65535)>(aR&65535)){bn=(aO-aR&65535)+aQ&65535}else{bn=aQ}aQ=aT&31;aT=bm&31;if((aQ&65535)<=(aT&65535)){bk=bn;break}bk=(aQ-aT&65535)+bn&65535}}while(0);aU=aV+11|0;b[(c[277218]|0)+(aU<<1)>>1]=bk;b[(c[277218]|0)+(o<<1)>>1]=bk;aT=a[1108909]|0;a[(c[277219]|0)+aU|0]=aT;a[(c[277219]|0)+o|0]=aT}}while(0);o=aZ-1&255;if(o<<24>>24!=0){a_=o;u=8605}}if((u|0)==8605){u=0;o=aV+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){aT=a[r+1|0]|0;aU=aT&255;if(aT<<24>>24==0){break}do{if((a[1108928]|0)==0){aT=b[(c[277225]|0)+(aU<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){bo=b[(c[277221]|0)+((aT&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}aQ=c[277228]&65535;aR=aT&-2048;aO=aQ&-2048;an=(aR&65535)>(aO&65535)?aR-aO&65535:0;aO=aT&2016;aR=aQ&2016;if((aO&65535)>(aR&65535)){bp=(aO-aR&65535)+an&65535}else{bp=an}an=aT&31;aT=aQ&31;if((an&65535)<=(aT&65535)){bo=bp;break}bo=(an-aT&65535)+bp&65535}else{aT=b[(c[277225]|0)+(aU<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){bq=c[277228]&65535}else{bq=b[(c[277213]|0)+(o<<1)>>1]|0}an=aT&-2048;aQ=bq&-2048;aR=(an&65535)>(aQ&65535)?an-aQ&65535:0;aQ=aT&2016;an=bq&2016;if((aQ&65535)>(an&65535)){br=(aQ-an&65535)+aR&65535}else{br=aR}aR=aT&31;aT=bq&31;if((aR&65535)<=(aT&65535)){bo=br;break}bo=(aR-aT&65535)+br&65535}}while(0);aU=aV+13|0;b[(c[277218]|0)+(aU<<1)>>1]=bo;b[(c[277218]|0)+(o<<1)>>1]=bo;aT=a[1108909]|0;a[(c[277219]|0)+aU|0]=aT;a[(c[277219]|0)+o|0]=aT}}while(0);if(a_<<24>>24!=1){u=8623}}do{if((u|0)==8623){u=0;o=aV+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+o|0]|0)){break}aT=a[r]|0;aU=aT&255;if(aT<<24>>24==0){break}do{if((a[1108928]|0)==0){aT=b[(c[277225]|0)+(aU<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){bs=b[(c[277221]|0)+((aT&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}aR=c[277228]&65535;an=aT&-2048;aQ=aR&-2048;aO=(an&65535)>(aQ&65535)?an-aQ&65535:0;aQ=aT&2016;an=aR&2016;if((aQ&65535)>(an&65535)){bt=(aQ-an&65535)+aO&65535}else{bt=aO}aO=aT&31;aT=aR&31;if((aO&65535)<=(aT&65535)){bs=bt;break}bs=(aO-aT&65535)+bt&65535}else{aT=b[(c[277225]|0)+(aU<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){bu=c[277228]&65535}else{bu=b[(c[277213]|0)+(o<<1)>>1]|0}aO=aT&-2048;aR=bu&-2048;an=(aO&65535)>(aR&65535)?aO-aR&65535:0;aR=aT&2016;aO=bu&2016;if((aR&65535)>(aO&65535)){bv=(aR-aO&65535)+an&65535}else{bv=an}an=aT&31;aT=bu&31;if((an&65535)<=(aT&65535)){bs=bv;break}bs=(an-aT&65535)+bv&65535}}while(0);aU=aV+15|0;b[(c[277218]|0)+(aU<<1)>>1]=bs;b[(c[277218]|0)+(o<<1)>>1]=bs;aT=a[1108909]|0;a[(c[277219]|0)+aU|0]=aT;a[(c[277219]|0)+o|0]=aT}}while(0);aT=aS-1|0;if((aT|0)>0){r=r-8|0;aS=aT;aV=(c[277223]|0)+aV|0}else{break}}return}else{if(!i){return}i=h&255;h=i-1&255;aV=h<<24>>24==0;aS=aj;aj=j;j=f;while(1){switch(g|0){case 4:{bw=i;u=8424;break};case 1:{bx=i;u=8370;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+j|0]|0)){f=a[aS]|0;r=f&255;if(f<<24>>24==0){break}do{if((a[1108928]|0)==0){f=b[(c[277225]|0)+(r<<1)>>1]|0;if((a[(c[277215]|0)+j|0]&32)!=0){by=b[(c[277221]|0)+((f&65535|67616)-(b[(c[277213]|0)+(j<<1)>>1]&63454)>>1<<1)>>1]|0;break}bs=c[277228]&65535;bv=f&-2048;bu=bs&-2048;bt=(bv&65535)>(bu&65535)?bv-bu&65535:0;bu=f&2016;bv=bs&2016;if((bu&65535)>(bv&65535)){bz=(bu-bv&65535)+bt&65535}else{bz=bt}bt=f&31;f=bs&31;if((bt&65535)<=(f&65535)){by=bz;break}by=(bt-f&65535)+bz&65535}else{f=b[(c[277225]|0)+(r<<1)>>1]|0;if((a[(c[277215]|0)+j|0]&32)==0){bA=c[277228]&65535}else{bA=b[(c[277213]|0)+(j<<1)>>1]|0}bt=f&-2048;bs=bA&-2048;bv=(bt&65535)>(bs&65535)?bt-bs&65535:0;bs=f&2016;bt=bA&2016;if((bs&65535)>(bt&65535)){bB=(bs-bt&65535)+bv&65535}else{bB=bv}bv=f&31;f=bA&31;if((bv&65535)<=(f&65535)){by=bB;break}by=(bv-f&65535)+bB&65535}}while(0);r=j+1|0;b[(c[277218]|0)+(r<<1)>>1]=by;b[(c[277218]|0)+(j<<1)>>1]=by;o=a[1108909]|0;a[(c[277219]|0)+r|0]=o;a[(c[277219]|0)+j|0]=o}}while(0);if(!aV){bx=h;u=8370}break};case 7:{u=8478;break};case 2:{bC=i;u=8388;break};case 6:{bD=i;u=8460;break};case 5:{bE=i;u=8442;break};case 3:{bF=i;u=8406;break};default:{}}if((u|0)==8370){u=0;o=j+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){r=a[aS+1|0]|0;f=r&255;if(r<<24>>24==0){break}do{if((a[1108928]|0)==0){r=b[(c[277225]|0)+(f<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){bG=b[(c[277221]|0)+((r&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}bv=c[277228]&65535;bt=r&-2048;bs=bv&-2048;bu=(bt&65535)>(bs&65535)?bt-bs&65535:0;bs=r&2016;bt=bv&2016;if((bs&65535)>(bt&65535)){bH=(bs-bt&65535)+bu&65535}else{bH=bu}bu=r&31;r=bv&31;if((bu&65535)<=(r&65535)){bG=bH;break}bG=(bu-r&65535)+bH&65535}else{r=b[(c[277225]|0)+(f<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){bI=c[277228]&65535}else{bI=b[(c[277213]|0)+(o<<1)>>1]|0}bu=r&-2048;bv=bI&-2048;bt=(bu&65535)>(bv&65535)?bu-bv&65535:0;bv=r&2016;bu=bI&2016;if((bv&65535)>(bu&65535)){bJ=(bv-bu&65535)+bt&65535}else{bJ=bt}bt=r&31;r=bI&31;if((bt&65535)<=(r&65535)){bG=bJ;break}bG=(bt-r&65535)+bJ&65535}}while(0);f=j+3|0;b[(c[277218]|0)+(f<<1)>>1]=bG;b[(c[277218]|0)+(o<<1)>>1]=bG;r=a[1108909]|0;a[(c[277219]|0)+f|0]=r;a[(c[277219]|0)+o|0]=r}}while(0);o=bx-1&255;if(o<<24>>24!=0){bC=o;u=8388}}if((u|0)==8388){u=0;o=j+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){r=a[aS+2|0]|0;f=r&255;if(r<<24>>24==0){break}do{if((a[1108928]|0)==0){r=b[(c[277225]|0)+(f<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){bK=b[(c[277221]|0)+((r&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}bt=c[277228]&65535;bu=r&-2048;bv=bt&-2048;bs=(bu&65535)>(bv&65535)?bu-bv&65535:0;bv=r&2016;bu=bt&2016;if((bv&65535)>(bu&65535)){bL=(bv-bu&65535)+bs&65535}else{bL=bs}bs=r&31;r=bt&31;if((bs&65535)<=(r&65535)){bK=bL;break}bK=(bs-r&65535)+bL&65535}else{r=b[(c[277225]|0)+(f<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){bM=c[277228]&65535}else{bM=b[(c[277213]|0)+(o<<1)>>1]|0}bs=r&-2048;bt=bM&-2048;bu=(bs&65535)>(bt&65535)?bs-bt&65535:0;bt=r&2016;bs=bM&2016;if((bt&65535)>(bs&65535)){bN=(bt-bs&65535)+bu&65535}else{bN=bu}bu=r&31;r=bM&31;if((bu&65535)<=(r&65535)){bK=bN;break}bK=(bu-r&65535)+bN&65535}}while(0);f=j+5|0;b[(c[277218]|0)+(f<<1)>>1]=bK;b[(c[277218]|0)+(o<<1)>>1]=bK;r=a[1108909]|0;a[(c[277219]|0)+f|0]=r;a[(c[277219]|0)+o|0]=r}}while(0);o=bC-1&255;if(o<<24>>24!=0){bF=o;u=8406}}if((u|0)==8406){u=0;o=j+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){r=a[aS+3|0]|0;f=r&255;if(r<<24>>24==0){break}do{if((a[1108928]|0)==0){r=b[(c[277225]|0)+(f<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){bO=b[(c[277221]|0)+((r&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}bu=c[277228]&65535;bs=r&-2048;bt=bu&-2048;bv=(bs&65535)>(bt&65535)?bs-bt&65535:0;bt=r&2016;bs=bu&2016;if((bt&65535)>(bs&65535)){bP=(bt-bs&65535)+bv&65535}else{bP=bv}bv=r&31;r=bu&31;if((bv&65535)<=(r&65535)){bO=bP;break}bO=(bv-r&65535)+bP&65535}else{r=b[(c[277225]|0)+(f<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){bQ=c[277228]&65535}else{bQ=b[(c[277213]|0)+(o<<1)>>1]|0}bv=r&-2048;bu=bQ&-2048;bs=(bv&65535)>(bu&65535)?bv-bu&65535:0;bu=r&2016;bv=bQ&2016;if((bu&65535)>(bv&65535)){bR=(bu-bv&65535)+bs&65535}else{bR=bs}bs=r&31;r=bQ&31;if((bs&65535)<=(r&65535)){bO=bR;break}bO=(bs-r&65535)+bR&65535}}while(0);f=j+7|0;b[(c[277218]|0)+(f<<1)>>1]=bO;b[(c[277218]|0)+(o<<1)>>1]=bO;r=a[1108909]|0;a[(c[277219]|0)+f|0]=r;a[(c[277219]|0)+o|0]=r}}while(0);o=bF-1&255;if(o<<24>>24!=0){bw=o;u=8424}}if((u|0)==8424){u=0;o=j+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){r=a[aS+4|0]|0;f=r&255;if(r<<24>>24==0){break}do{if((a[1108928]|0)==0){r=b[(c[277225]|0)+(f<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){bS=b[(c[277221]|0)+((r&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}bs=c[277228]&65535;bv=r&-2048;bu=bs&-2048;bt=(bv&65535)>(bu&65535)?bv-bu&65535:0;bu=r&2016;bv=bs&2016;if((bu&65535)>(bv&65535)){bT=(bu-bv&65535)+bt&65535}else{bT=bt}bt=r&31;r=bs&31;if((bt&65535)<=(r&65535)){bS=bT;break}bS=(bt-r&65535)+bT&65535}else{r=b[(c[277225]|0)+(f<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){bU=c[277228]&65535}else{bU=b[(c[277213]|0)+(o<<1)>>1]|0}bt=r&-2048;bs=bU&-2048;bv=(bt&65535)>(bs&65535)?bt-bs&65535:0;bs=r&2016;bt=bU&2016;if((bs&65535)>(bt&65535)){bV=(bs-bt&65535)+bv&65535}else{bV=bv}bv=r&31;r=bU&31;if((bv&65535)<=(r&65535)){bS=bV;break}bS=(bv-r&65535)+bV&65535}}while(0);f=j+9|0;b[(c[277218]|0)+(f<<1)>>1]=bS;b[(c[277218]|0)+(o<<1)>>1]=bS;r=a[1108909]|0;a[(c[277219]|0)+f|0]=r;a[(c[277219]|0)+o|0]=r}}while(0);o=bw-1&255;if(o<<24>>24!=0){bE=o;u=8442}}if((u|0)==8442){u=0;o=j+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){r=a[aS+5|0]|0;f=r&255;if(r<<24>>24==0){break}do{if((a[1108928]|0)==0){r=b[(c[277225]|0)+(f<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){bW=b[(c[277221]|0)+((r&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}bv=c[277228]&65535;bt=r&-2048;bs=bv&-2048;bu=(bt&65535)>(bs&65535)?bt-bs&65535:0;bs=r&2016;bt=bv&2016;if((bs&65535)>(bt&65535)){bX=(bs-bt&65535)+bu&65535}else{bX=bu}bu=r&31;r=bv&31;if((bu&65535)<=(r&65535)){bW=bX;break}bW=(bu-r&65535)+bX&65535}else{r=b[(c[277225]|0)+(f<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){bY=c[277228]&65535}else{bY=b[(c[277213]|0)+(o<<1)>>1]|0}bu=r&-2048;bv=bY&-2048;bt=(bu&65535)>(bv&65535)?bu-bv&65535:0;bv=r&2016;bu=bY&2016;if((bv&65535)>(bu&65535)){bZ=(bv-bu&65535)+bt&65535}else{bZ=bt}bt=r&31;r=bY&31;if((bt&65535)<=(r&65535)){bW=bZ;break}bW=(bt-r&65535)+bZ&65535}}while(0);f=j+11|0;b[(c[277218]|0)+(f<<1)>>1]=bW;b[(c[277218]|0)+(o<<1)>>1]=bW;r=a[1108909]|0;a[(c[277219]|0)+f|0]=r;a[(c[277219]|0)+o|0]=r}}while(0);o=bE-1&255;if(o<<24>>24!=0){bD=o;u=8460}}if((u|0)==8460){u=0;o=j+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){r=a[aS+6|0]|0;f=r&255;if(r<<24>>24==0){break}do{if((a[1108928]|0)==0){r=b[(c[277225]|0)+(f<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){b_=b[(c[277221]|0)+((r&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}bt=c[277228]&65535;bu=r&-2048;bv=bt&-2048;bs=(bu&65535)>(bv&65535)?bu-bv&65535:0;bv=r&2016;bu=bt&2016;if((bv&65535)>(bu&65535)){b$=(bv-bu&65535)+bs&65535}else{b$=bs}bs=r&31;r=bt&31;if((bs&65535)<=(r&65535)){b_=b$;break}b_=(bs-r&65535)+b$&65535}else{r=b[(c[277225]|0)+(f<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){b0=c[277228]&65535}else{b0=b[(c[277213]|0)+(o<<1)>>1]|0}bs=r&-2048;bt=b0&-2048;bu=(bs&65535)>(bt&65535)?bs-bt&65535:0;bt=r&2016;bs=b0&2016;if((bt&65535)>(bs&65535)){b1=(bt-bs&65535)+bu&65535}else{b1=bu}bu=r&31;r=b0&31;if((bu&65535)<=(r&65535)){b_=b1;break}b_=(bu-r&65535)+b1&65535}}while(0);f=j+13|0;b[(c[277218]|0)+(f<<1)>>1]=b_;b[(c[277218]|0)+(o<<1)>>1]=b_;r=a[1108909]|0;a[(c[277219]|0)+f|0]=r;a[(c[277219]|0)+o|0]=r}}while(0);if(bD<<24>>24!=1){u=8478}}do{if((u|0)==8478){u=0;o=j+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+o|0]|0)){break}r=a[aS+7|0]|0;f=r&255;if(r<<24>>24==0){break}do{if((a[1108928]|0)==0){r=b[(c[277225]|0)+(f<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){b2=b[(c[277221]|0)+((r&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}bu=c[277228]&65535;bs=r&-2048;bt=bu&-2048;bv=(bs&65535)>(bt&65535)?bs-bt&65535:0;bt=r&2016;bs=bu&2016;if((bt&65535)>(bs&65535)){b3=(bt-bs&65535)+bv&65535}else{b3=bv}bv=r&31;r=bu&31;if((bv&65535)<=(r&65535)){b2=b3;break}b2=(bv-r&65535)+b3&65535}else{r=b[(c[277225]|0)+(f<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){b4=c[277228]&65535}else{b4=b[(c[277213]|0)+(o<<1)>>1]|0}bv=r&-2048;bu=b4&-2048;bs=(bv&65535)>(bu&65535)?bv-bu&65535:0;bu=r&2016;bv=b4&2016;if((bu&65535)>(bv&65535)){b5=(bu-bv&65535)+bs&65535}else{b5=bs}bs=r&31;r=b4&31;if((bs&65535)<=(r&65535)){b2=b5;break}b2=(bs-r&65535)+b5&65535}}while(0);f=j+15|0;b[(c[277218]|0)+(f<<1)>>1]=b2;b[(c[277218]|0)+(o<<1)>>1]=b2;r=a[1108909]|0;a[(c[277219]|0)+f|0]=r;a[(c[277219]|0)+o|0]=r}}while(0);r=aj-1|0;if((r|0)>0){aS=aS-8|0;aj=r;j=(c[277223]|0)+j|0}else{break}}return}}function Uu(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0;i=e&1023;j=c[348606]|0;k=(i<<j)+(c[348604]|0)|0;if((e&256|0)==0){l=k}else{l=(c[348602]|0)+k|0}k=l&65535;l=k>>>(j>>>0);j=(e&16384|0)!=0;m=l<<6;do{if(j){n=(c[348622]|0)+m|0;if((a[(c[348618]|0)+l|0]|0)!=0){o=n;break}p=fi[c[348636]&63](n,k,i)|0;a[(c[348618]|0)+l|0]=p;o=n}else{n=(c[348624]|0)+m|0;if((a[(c[348620]|0)+l|0]|0)!=0){o=n;break}p=fi[c[348638]&63](n,k,i)|0;a[(c[348620]|0)+l|0]=p;o=n}}while(0);if((a[(c[348620]|0)+l|0]|0)==2){return}if((a[1394464]|0)==0){q=1106168+((e>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){l=d[1044485]|0;c[276541]=7080+(l<<5);i=0;do{k=i<<1&2;m=i&2;n=i&4;p=0;do{b[1125528+(i<<9)+(p<<1)>>1]=d[(p>>>1&28|m)+(7080+(l<<5))|0]<<6|d[(p<<2&28|k)+(7080+(l<<5))|0]<<11|d[(p>>>3&24|n)+(7080+(l<<5))|0];p=p+1|0;}while(p>>>0<256);i=i+1|0;}while(i>>>0<8);a[1106089]=0}q=1125528+((e>>>10&7)<<9)|0}c[277226]=q;c[277225]=(a[1108928]|0)!=0?1393712:q;if((e&49152|0)==0){if((h|0)<=0){return}q=o+g|0;i=h;l=f;while(1){p=a[1108908]|0;n=c[277219]|0;do{if((p&255)>(d[n+l|0]|0)){k=a[q]|0;if(k<<24>>24==0){r=p;s=n;break}m=b[(c[277225]|0)+((k&255)<<1)>>1]|0;k=l+1|0;b[(c[277218]|0)+(k<<1)>>1]=m;b[(c[277218]|0)+(l<<1)>>1]=m;m=a[1108909]|0;a[(c[277219]|0)+k|0]=m;a[(c[277219]|0)+l|0]=m;r=a[1108908]|0;s=c[277219]|0}else{r=p;s=n}}while(0);n=l+2|0;do{if((r&255)>(d[s+n|0]|0)){p=a[q+1|0]|0;if(p<<24>>24==0){t=r;u=s;break}m=b[(c[277225]|0)+((p&255)<<1)>>1]|0;p=l+3|0;b[(c[277218]|0)+(p<<1)>>1]=m;b[(c[277218]|0)+(n<<1)>>1]=m;m=a[1108909]|0;a[(c[277219]|0)+p|0]=m;a[(c[277219]|0)+n|0]=m;t=a[1108908]|0;u=c[277219]|0}else{t=r;u=s}}while(0);n=l+4|0;do{if((t&255)>(d[u+n|0]|0)){m=a[q+2|0]|0;if(m<<24>>24==0){v=t;w=u;break}p=b[(c[277225]|0)+((m&255)<<1)>>1]|0;m=l+5|0;b[(c[277218]|0)+(m<<1)>>1]=p;b[(c[277218]|0)+(n<<1)>>1]=p;p=a[1108909]|0;a[(c[277219]|0)+m|0]=p;a[(c[277219]|0)+n|0]=p;v=a[1108908]|0;w=c[277219]|0}else{v=t;w=u}}while(0);n=l+6|0;do{if((v&255)>(d[w+n|0]|0)){p=a[q+3|0]|0;if(p<<24>>24==0){x=v;y=w;break}m=b[(c[277225]|0)+((p&255)<<1)>>1]|0;p=l+7|0;b[(c[277218]|0)+(p<<1)>>1]=m;b[(c[277218]|0)+(n<<1)>>1]=m;m=a[1108909]|0;a[(c[277219]|0)+p|0]=m;a[(c[277219]|0)+n|0]=m;x=a[1108908]|0;y=c[277219]|0}else{x=v;y=w}}while(0);n=l+8|0;do{if((x&255)>(d[y+n|0]|0)){m=a[q+4|0]|0;if(m<<24>>24==0){z=x;A=y;break}p=b[(c[277225]|0)+((m&255)<<1)>>1]|0;m=l+9|0;b[(c[277218]|0)+(m<<1)>>1]=p;b[(c[277218]|0)+(n<<1)>>1]=p;p=a[1108909]|0;a[(c[277219]|0)+m|0]=p;a[(c[277219]|0)+n|0]=p;z=a[1108908]|0;A=c[277219]|0}else{z=x;A=y}}while(0);n=l+10|0;do{if((z&255)>(d[A+n|0]|0)){p=a[q+5|0]|0;if(p<<24>>24==0){B=z;C=A;break}m=b[(c[277225]|0)+((p&255)<<1)>>1]|0;p=l+11|0;b[(c[277218]|0)+(p<<1)>>1]=m;b[(c[277218]|0)+(n<<1)>>1]=m;m=a[1108909]|0;a[(c[277219]|0)+p|0]=m;a[(c[277219]|0)+n|0]=m;B=a[1108908]|0;C=c[277219]|0}else{B=z;C=A}}while(0);n=l+12|0;do{if((B&255)>(d[C+n|0]|0)){m=a[q+6|0]|0;if(m<<24>>24==0){D=B;E=C;break}p=b[(c[277225]|0)+((m&255)<<1)>>1]|0;m=l+13|0;b[(c[277218]|0)+(m<<1)>>1]=p;b[(c[277218]|0)+(n<<1)>>1]=p;p=a[1108909]|0;a[(c[277219]|0)+m|0]=p;a[(c[277219]|0)+n|0]=p;D=a[1108908]|0;E=c[277219]|0}else{D=B;E=C}}while(0);n=l+14|0;do{if((D&255)>(d[E+n|0]|0)){p=a[q+7|0]|0;if(p<<24>>24==0){break}m=b[(c[277225]|0)+((p&255)<<1)>>1]|0;p=l+15|0;b[(c[277218]|0)+(p<<1)>>1]=m;b[(c[277218]|0)+(n<<1)>>1]=m;m=a[1108909]|0;a[(c[277219]|0)+p|0]=m;a[(c[277219]|0)+n|0]=m}}while(0);n=i-1|0;if((n|0)<=0){break}q=q+8|0;i=n;l=(c[277223]|0)+l|0}return}if((e&32768|0)==0){if((h|0)<=0){return}e=o+g|0;l=h;i=f;while(1){q=a[1108908]|0;E=c[277219]|0;do{if((q&255)>(d[E+i|0]|0)){D=a[e+7|0]|0;if(D<<24>>24==0){F=q;G=E;break}C=b[(c[277225]|0)+((D&255)<<1)>>1]|0;D=i+1|0;b[(c[277218]|0)+(D<<1)>>1]=C;b[(c[277218]|0)+(i<<1)>>1]=C;C=a[1108909]|0;a[(c[277219]|0)+D|0]=C;a[(c[277219]|0)+i|0]=C;F=a[1108908]|0;G=c[277219]|0}else{F=q;G=E}}while(0);E=i+2|0;do{if((F&255)>(d[G+E|0]|0)){q=a[e+6|0]|0;if(q<<24>>24==0){H=F;I=G;break}C=b[(c[277225]|0)+((q&255)<<1)>>1]|0;q=i+3|0;b[(c[277218]|0)+(q<<1)>>1]=C;b[(c[277218]|0)+(E<<1)>>1]=C;C=a[1108909]|0;a[(c[277219]|0)+q|0]=C;a[(c[277219]|0)+E|0]=C;H=a[1108908]|0;I=c[277219]|0}else{H=F;I=G}}while(0);E=i+4|0;do{if((H&255)>(d[I+E|0]|0)){C=a[e+5|0]|0;if(C<<24>>24==0){J=H;K=I;break}q=b[(c[277225]|0)+((C&255)<<1)>>1]|0;C=i+5|0;b[(c[277218]|0)+(C<<1)>>1]=q;b[(c[277218]|0)+(E<<1)>>1]=q;q=a[1108909]|0;a[(c[277219]|0)+C|0]=q;a[(c[277219]|0)+E|0]=q;J=a[1108908]|0;K=c[277219]|0}else{J=H;K=I}}while(0);E=i+6|0;do{if((J&255)>(d[K+E|0]|0)){q=a[e+4|0]|0;if(q<<24>>24==0){L=J;M=K;break}C=b[(c[277225]|0)+((q&255)<<1)>>1]|0;q=i+7|0;b[(c[277218]|0)+(q<<1)>>1]=C;b[(c[277218]|0)+(E<<1)>>1]=C;C=a[1108909]|0;a[(c[277219]|0)+q|0]=C;a[(c[277219]|0)+E|0]=C;L=a[1108908]|0;M=c[277219]|0}else{L=J;M=K}}while(0);E=i+8|0;do{if((L&255)>(d[M+E|0]|0)){C=a[e+3|0]|0;if(C<<24>>24==0){N=L;O=M;break}q=b[(c[277225]|0)+((C&255)<<1)>>1]|0;C=i+9|0;b[(c[277218]|0)+(C<<1)>>1]=q;b[(c[277218]|0)+(E<<1)>>1]=q;q=a[1108909]|0;a[(c[277219]|0)+C|0]=q;a[(c[277219]|0)+E|0]=q;N=a[1108908]|0;O=c[277219]|0}else{N=L;O=M}}while(0);E=i+10|0;do{if((N&255)>(d[O+E|0]|0)){q=a[e+2|0]|0;if(q<<24>>24==0){P=N;Q=O;break}C=b[(c[277225]|0)+((q&255)<<1)>>1]|0;q=i+11|0;b[(c[277218]|0)+(q<<1)>>1]=C;b[(c[277218]|0)+(E<<1)>>1]=C;C=a[1108909]|0;a[(c[277219]|0)+q|0]=C;a[(c[277219]|0)+E|0]=C;P=a[1108908]|0;Q=c[277219]|0}else{P=N;Q=O}}while(0);E=i+12|0;do{if((P&255)>(d[Q+E|0]|0)){C=a[e+1|0]|0;if(C<<24>>24==0){R=P;S=Q;break}q=b[(c[277225]|0)+((C&255)<<1)>>1]|0;C=i+13|0;b[(c[277218]|0)+(C<<1)>>1]=q;b[(c[277218]|0)+(E<<1)>>1]=q;q=a[1108909]|0;a[(c[277219]|0)+C|0]=q;a[(c[277219]|0)+E|0]=q;R=a[1108908]|0;S=c[277219]|0}else{R=P;S=Q}}while(0);E=i+14|0;do{if((R&255)>(d[S+E|0]|0)){q=a[e]|0;if(q<<24>>24==0){break}C=b[(c[277225]|0)+((q&255)<<1)>>1]|0;q=i+15|0;b[(c[277218]|0)+(q<<1)>>1]=C;b[(c[277218]|0)+(E<<1)>>1]=C;C=a[1108909]|0;a[(c[277219]|0)+q|0]=C;a[(c[277219]|0)+E|0]=C}}while(0);E=l-1|0;if((E|0)<=0){break}e=e+8|0;l=E;i=(c[277223]|0)+i|0}return}i=o+(56-g)|0;g=(h|0)>0;if(j){if(g){T=i;U=h;V=f}else{return}while(1){j=a[1108908]|0;o=c[277219]|0;do{if((j&255)>(d[o+V|0]|0)){l=a[T+7|0]|0;if(l<<24>>24==0){W=j;X=o;break}e=b[(c[277225]|0)+((l&255)<<1)>>1]|0;l=V+1|0;b[(c[277218]|0)+(l<<1)>>1]=e;b[(c[277218]|0)+(V<<1)>>1]=e;e=a[1108909]|0;a[(c[277219]|0)+l|0]=e;a[(c[277219]|0)+V|0]=e;W=a[1108908]|0;X=c[277219]|0}else{W=j;X=o}}while(0);o=V+2|0;do{if((W&255)>(d[X+o|0]|0)){j=a[T+6|0]|0;if(j<<24>>24==0){Y=W;Z=X;break}e=b[(c[277225]|0)+((j&255)<<1)>>1]|0;j=V+3|0;b[(c[277218]|0)+(j<<1)>>1]=e;b[(c[277218]|0)+(o<<1)>>1]=e;e=a[1108909]|0;a[(c[277219]|0)+j|0]=e;a[(c[277219]|0)+o|0]=e;Y=a[1108908]|0;Z=c[277219]|0}else{Y=W;Z=X}}while(0);o=V+4|0;do{if((Y&255)>(d[Z+o|0]|0)){e=a[T+5|0]|0;if(e<<24>>24==0){_=Y;$=Z;break}j=b[(c[277225]|0)+((e&255)<<1)>>1]|0;e=V+5|0;b[(c[277218]|0)+(e<<1)>>1]=j;b[(c[277218]|0)+(o<<1)>>1]=j;j=a[1108909]|0;a[(c[277219]|0)+e|0]=j;a[(c[277219]|0)+o|0]=j;_=a[1108908]|0;$=c[277219]|0}else{_=Y;$=Z}}while(0);o=V+6|0;do{if((_&255)>(d[$+o|0]|0)){j=a[T+4|0]|0;if(j<<24>>24==0){aa=_;ab=$;break}e=b[(c[277225]|0)+((j&255)<<1)>>1]|0;j=V+7|0;b[(c[277218]|0)+(j<<1)>>1]=e;b[(c[277218]|0)+(o<<1)>>1]=e;e=a[1108909]|0;a[(c[277219]|0)+j|0]=e;a[(c[277219]|0)+o|0]=e;aa=a[1108908]|0;ab=c[277219]|0}else{aa=_;ab=$}}while(0);o=V+8|0;do{if((aa&255)>(d[ab+o|0]|0)){e=a[T+3|0]|0;if(e<<24>>24==0){ac=aa;ad=ab;break}j=b[(c[277225]|0)+((e&255)<<1)>>1]|0;e=V+9|0;b[(c[277218]|0)+(e<<1)>>1]=j;b[(c[277218]|0)+(o<<1)>>1]=j;j=a[1108909]|0;a[(c[277219]|0)+e|0]=j;a[(c[277219]|0)+o|0]=j;ac=a[1108908]|0;ad=c[277219]|0}else{ac=aa;ad=ab}}while(0);o=V+10|0;do{if((ac&255)>(d[ad+o|0]|0)){j=a[T+2|0]|0;if(j<<24>>24==0){ae=ac;af=ad;break}e=b[(c[277225]|0)+((j&255)<<1)>>1]|0;j=V+11|0;b[(c[277218]|0)+(j<<1)>>1]=e;b[(c[277218]|0)+(o<<1)>>1]=e;e=a[1108909]|0;a[(c[277219]|0)+j|0]=e;a[(c[277219]|0)+o|0]=e;ae=a[1108908]|0;af=c[277219]|0}else{ae=ac;af=ad}}while(0);o=V+12|0;do{if((ae&255)>(d[af+o|0]|0)){e=a[T+1|0]|0;if(e<<24>>24==0){ag=ae;ah=af;break}j=b[(c[277225]|0)+((e&255)<<1)>>1]|0;e=V+13|0;b[(c[277218]|0)+(e<<1)>>1]=j;b[(c[277218]|0)+(o<<1)>>1]=j;j=a[1108909]|0;a[(c[277219]|0)+e|0]=j;a[(c[277219]|0)+o|0]=j;ag=a[1108908]|0;ah=c[277219]|0}else{ag=ae;ah=af}}while(0);o=V+14|0;do{if((ag&255)>(d[ah+o|0]|0)){j=a[T]|0;if(j<<24>>24==0){break}e=b[(c[277225]|0)+((j&255)<<1)>>1]|0;j=V+15|0;b[(c[277218]|0)+(j<<1)>>1]=e;b[(c[277218]|0)+(o<<1)>>1]=e;e=a[1108909]|0;a[(c[277219]|0)+j|0]=e;a[(c[277219]|0)+o|0]=e}}while(0);o=U-1|0;if((o|0)<=0){break}T=T-8|0;U=o;V=(c[277223]|0)+V|0}return}else{if(g){ai=i;aj=h;ak=f}else{return}while(1){f=a[1108908]|0;h=c[277219]|0;do{if((f&255)>(d[h+ak|0]|0)){i=a[ai]|0;if(i<<24>>24==0){al=f;am=h;break}g=b[(c[277225]|0)+((i&255)<<1)>>1]|0;i=ak+1|0;b[(c[277218]|0)+(i<<1)>>1]=g;b[(c[277218]|0)+(ak<<1)>>1]=g;g=a[1108909]|0;a[(c[277219]|0)+i|0]=g;a[(c[277219]|0)+ak|0]=g;al=a[1108908]|0;am=c[277219]|0}else{al=f;am=h}}while(0);h=ak+2|0;do{if((al&255)>(d[am+h|0]|0)){f=a[ai+1|0]|0;if(f<<24>>24==0){an=al;ao=am;break}g=b[(c[277225]|0)+((f&255)<<1)>>1]|0;f=ak+3|0;b[(c[277218]|0)+(f<<1)>>1]=g;b[(c[277218]|0)+(h<<1)>>1]=g;g=a[1108909]|0;a[(c[277219]|0)+f|0]=g;a[(c[277219]|0)+h|0]=g;an=a[1108908]|0;ao=c[277219]|0}else{an=al;ao=am}}while(0);h=ak+4|0;do{if((an&255)>(d[ao+h|0]|0)){g=a[ai+2|0]|0;if(g<<24>>24==0){ap=an;aq=ao;break}f=b[(c[277225]|0)+((g&255)<<1)>>1]|0;g=ak+5|0;b[(c[277218]|0)+(g<<1)>>1]=f;b[(c[277218]|0)+(h<<1)>>1]=f;f=a[1108909]|0;a[(c[277219]|0)+g|0]=f;a[(c[277219]|0)+h|0]=f;ap=a[1108908]|0;aq=c[277219]|0}else{ap=an;aq=ao}}while(0);h=ak+6|0;do{if((ap&255)>(d[aq+h|0]|0)){f=a[ai+3|0]|0;if(f<<24>>24==0){ar=ap;as=aq;break}g=b[(c[277225]|0)+((f&255)<<1)>>1]|0;f=ak+7|0;b[(c[277218]|0)+(f<<1)>>1]=g;b[(c[277218]|0)+(h<<1)>>1]=g;g=a[1108909]|0;a[(c[277219]|0)+f|0]=g;a[(c[277219]|0)+h|0]=g;ar=a[1108908]|0;as=c[277219]|0}else{ar=ap;as=aq}}while(0);h=ak+8|0;do{if((ar&255)>(d[as+h|0]|0)){g=a[ai+4|0]|0;if(g<<24>>24==0){at=ar;au=as;break}f=b[(c[277225]|0)+((g&255)<<1)>>1]|0;g=ak+9|0;b[(c[277218]|0)+(g<<1)>>1]=f;b[(c[277218]|0)+(h<<1)>>1]=f;f=a[1108909]|0;a[(c[277219]|0)+g|0]=f;a[(c[277219]|0)+h|0]=f;at=a[1108908]|0;au=c[277219]|0}else{at=ar;au=as}}while(0);h=ak+10|0;do{if((at&255)>(d[au+h|0]|0)){f=a[ai+5|0]|0;if(f<<24>>24==0){av=at;aw=au;break}g=b[(c[277225]|0)+((f&255)<<1)>>1]|0;f=ak+11|0;b[(c[277218]|0)+(f<<1)>>1]=g;b[(c[277218]|0)+(h<<1)>>1]=g;g=a[1108909]|0;a[(c[277219]|0)+f|0]=g;a[(c[277219]|0)+h|0]=g;av=a[1108908]|0;aw=c[277219]|0}else{av=at;aw=au}}while(0);h=ak+12|0;do{if((av&255)>(d[aw+h|0]|0)){g=a[ai+6|0]|0;if(g<<24>>24==0){ax=av;ay=aw;break}f=b[(c[277225]|0)+((g&255)<<1)>>1]|0;g=ak+13|0;b[(c[277218]|0)+(g<<1)>>1]=f;b[(c[277218]|0)+(h<<1)>>1]=f;f=a[1108909]|0;a[(c[277219]|0)+g|0]=f;a[(c[277219]|0)+h|0]=f;ax=a[1108908]|0;ay=c[277219]|0}else{ax=av;ay=aw}}while(0);h=ak+14|0;do{if((ax&255)>(d[ay+h|0]|0)){f=a[ai+7|0]|0;if(f<<24>>24==0){break}g=b[(c[277225]|0)+((f&255)<<1)>>1]|0;f=ak+15|0;b[(c[277218]|0)+(f<<1)>>1]=g;b[(c[277218]|0)+(h<<1)>>1]=g;g=a[1108909]|0;a[(c[277219]|0)+f|0]=g;a[(c[277219]|0)+h|0]=g}}while(0);h=aj-1|0;if((h|0)<=0){break}ai=ai-8|0;aj=h;ak=(c[277223]|0)+ak|0}return}}function Uv(f,g,h,i){f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0;j=f&1023;k=c[348606]|0;l=(j<<k)+(c[348604]|0)|0;if((f&256|0)==0){m=l}else{m=(c[348602]|0)+l|0}l=m&65535;m=l>>>(k>>>0);k=(f&16384|0)!=0;n=m<<6;do{if(k){o=(c[348622]|0)+n|0;if((a[(c[348618]|0)+m|0]|0)!=0){p=o;break}q=fi[c[348636]&63](o,l,j)|0;a[(c[348618]|0)+m|0]=q;p=o}else{o=(c[348624]|0)+n|0;if((a[(c[348620]|0)+m|0]|0)!=0){p=o;break}q=fi[c[348638]&63](o,l,j)|0;a[(c[348620]|0)+m|0]=q;p=o}}while(0);if((a[(c[348620]|0)+m|0]|0)==2){return}if((a[1394464]|0)==0){r=1106168+((f>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){m=d[1044485]|0;c[276541]=7080+(m<<5);j=0;do{l=j<<1&2;n=j&2;o=j&4;q=0;do{b[1125528+(j<<9)+(q<<1)>>1]=d[(q>>>1&28|n)+(7080+(m<<5))|0]<<6|d[(q<<2&28|l)+(7080+(m<<5))|0]<<11|d[(q>>>3&24|o)+(7080+(m<<5))|0];q=q+1|0;}while(q>>>0<256);j=j+1|0;}while(j>>>0<8);a[1106089]=0}r=1125528+((f>>>10&7)<<9)|0}c[277226]=r;c[277225]=(a[1108928]|0)!=0?1393712:r;if((f&49152|0)==0){if((i|0)<=0){return}r=p+h|0;j=i;m=g;while(1){q=a[1108908]|0;o=c[277219]|0;do{if((q&255)>(d[o+m|0]|0)){l=a[r]|0;if(l<<24>>24==0){s=q;t=o;break}n=e[(c[277225]|0)+((l&255)<<1)>>1]|0;l=(a[(c[277215]|0)+m|0]&32)==0;if(l){u=c[277228]|0;v=u;w=u&-2082}else{u=e[(c[277213]|0)+(m<<1)>>1]|0;v=u;w=u&63454}if(l){x=c[277228]|0}else{x=e[(c[277213]|0)+(m<<1)>>1]|0}l=((x^n)&2081|e[(c[277220]|0)+((n&2081&v)+((w+(n&63454)|0)>>>1)<<1)>>1])&65535;n=m+1|0;b[(c[277218]|0)+(n<<1)>>1]=l;b[(c[277218]|0)+(m<<1)>>1]=l;l=a[1108909]|0;a[(c[277219]|0)+n|0]=l;a[(c[277219]|0)+m|0]=l;s=a[1108908]|0;t=c[277219]|0}else{s=q;t=o}}while(0);o=m+2|0;do{if((s&255)>(d[t+o|0]|0)){q=a[r+1|0]|0;if(q<<24>>24==0){y=s;z=t;break}l=e[(c[277225]|0)+((q&255)<<1)>>1]|0;q=(a[(c[277215]|0)+o|0]&32)==0;if(q){n=c[277228]|0;A=n;B=n&-2082}else{n=e[(c[277213]|0)+(o<<1)>>1]|0;A=n;B=n&63454}if(q){C=c[277228]|0}else{C=e[(c[277213]|0)+(o<<1)>>1]|0}q=((C^l)&2081|e[(c[277220]|0)+((l&2081&A)+((B+(l&63454)|0)>>>1)<<1)>>1])&65535;l=m+3|0;b[(c[277218]|0)+(l<<1)>>1]=q;b[(c[277218]|0)+(o<<1)>>1]=q;q=a[1108909]|0;a[(c[277219]|0)+l|0]=q;a[(c[277219]|0)+o|0]=q;y=a[1108908]|0;z=c[277219]|0}else{y=s;z=t}}while(0);o=m+4|0;do{if((y&255)>(d[z+o|0]|0)){q=a[r+2|0]|0;if(q<<24>>24==0){D=y;E=z;break}l=e[(c[277225]|0)+((q&255)<<1)>>1]|0;q=(a[(c[277215]|0)+o|0]&32)==0;if(q){n=c[277228]|0;F=n;G=n&-2082}else{n=e[(c[277213]|0)+(o<<1)>>1]|0;F=n;G=n&63454}if(q){H=c[277228]|0}else{H=e[(c[277213]|0)+(o<<1)>>1]|0}q=((H^l)&2081|e[(c[277220]|0)+((l&2081&F)+((G+(l&63454)|0)>>>1)<<1)>>1])&65535;l=m+5|0;b[(c[277218]|0)+(l<<1)>>1]=q;b[(c[277218]|0)+(o<<1)>>1]=q;q=a[1108909]|0;a[(c[277219]|0)+l|0]=q;a[(c[277219]|0)+o|0]=q;D=a[1108908]|0;E=c[277219]|0}else{D=y;E=z}}while(0);o=m+6|0;do{if((D&255)>(d[E+o|0]|0)){q=a[r+3|0]|0;if(q<<24>>24==0){I=D;J=E;break}l=e[(c[277225]|0)+((q&255)<<1)>>1]|0;q=(a[(c[277215]|0)+o|0]&32)==0;if(q){n=c[277228]|0;K=n;L=n&-2082}else{n=e[(c[277213]|0)+(o<<1)>>1]|0;K=n;L=n&63454}if(q){M=c[277228]|0}else{M=e[(c[277213]|0)+(o<<1)>>1]|0}q=((M^l)&2081|e[(c[277220]|0)+((l&2081&K)+((L+(l&63454)|0)>>>1)<<1)>>1])&65535;l=m+7|0;b[(c[277218]|0)+(l<<1)>>1]=q;b[(c[277218]|0)+(o<<1)>>1]=q;q=a[1108909]|0;a[(c[277219]|0)+l|0]=q;a[(c[277219]|0)+o|0]=q;I=a[1108908]|0;J=c[277219]|0}else{I=D;J=E}}while(0);o=m+8|0;do{if((I&255)>(d[J+o|0]|0)){q=a[r+4|0]|0;if(q<<24>>24==0){N=I;O=J;break}l=e[(c[277225]|0)+((q&255)<<1)>>1]|0;q=(a[(c[277215]|0)+o|0]&32)==0;if(q){n=c[277228]|0;P=n;Q=n&-2082}else{n=e[(c[277213]|0)+(o<<1)>>1]|0;P=n;Q=n&63454}if(q){R=c[277228]|0}else{R=e[(c[277213]|0)+(o<<1)>>1]|0}q=((R^l)&2081|e[(c[277220]|0)+((l&2081&P)+((Q+(l&63454)|0)>>>1)<<1)>>1])&65535;l=m+9|0;b[(c[277218]|0)+(l<<1)>>1]=q;b[(c[277218]|0)+(o<<1)>>1]=q;q=a[1108909]|0;a[(c[277219]|0)+l|0]=q;a[(c[277219]|0)+o|0]=q;N=a[1108908]|0;O=c[277219]|0}else{N=I;O=J}}while(0);o=m+10|0;do{if((N&255)>(d[O+o|0]|0)){q=a[r+5|0]|0;if(q<<24>>24==0){S=N;T=O;break}l=e[(c[277225]|0)+((q&255)<<1)>>1]|0;q=(a[(c[277215]|0)+o|0]&32)==0;if(q){n=c[277228]|0;U=n;V=n&-2082}else{n=e[(c[277213]|0)+(o<<1)>>1]|0;U=n;V=n&63454}if(q){W=c[277228]|0}else{W=e[(c[277213]|0)+(o<<1)>>1]|0}q=((W^l)&2081|e[(c[277220]|0)+((l&2081&U)+((V+(l&63454)|0)>>>1)<<1)>>1])&65535;l=m+11|0;b[(c[277218]|0)+(l<<1)>>1]=q;b[(c[277218]|0)+(o<<1)>>1]=q;q=a[1108909]|0;a[(c[277219]|0)+l|0]=q;a[(c[277219]|0)+o|0]=q;S=a[1108908]|0;T=c[277219]|0}else{S=N;T=O}}while(0);o=m+12|0;do{if((S&255)>(d[T+o|0]|0)){q=a[r+6|0]|0;if(q<<24>>24==0){X=S;Y=T;break}l=e[(c[277225]|0)+((q&255)<<1)>>1]|0;q=(a[(c[277215]|0)+o|0]&32)==0;if(q){n=c[277228]|0;Z=n;_=n&-2082}else{n=e[(c[277213]|0)+(o<<1)>>1]|0;Z=n;_=n&63454}if(q){$=c[277228]|0}else{$=e[(c[277213]|0)+(o<<1)>>1]|0}q=(($^l)&2081|e[(c[277220]|0)+((l&2081&Z)+((_+(l&63454)|0)>>>1)<<1)>>1])&65535;l=m+13|0;b[(c[277218]|0)+(l<<1)>>1]=q;b[(c[277218]|0)+(o<<1)>>1]=q;q=a[1108909]|0;a[(c[277219]|0)+l|0]=q;a[(c[277219]|0)+o|0]=q;X=a[1108908]|0;Y=c[277219]|0}else{X=S;Y=T}}while(0);o=m+14|0;do{if((X&255)>(d[Y+o|0]|0)){q=a[r+7|0]|0;if(q<<24>>24==0){break}l=e[(c[277225]|0)+((q&255)<<1)>>1]|0;q=(a[(c[277215]|0)+o|0]&32)==0;if(q){n=c[277228]|0;aa=n;ab=n&-2082}else{n=e[(c[277213]|0)+(o<<1)>>1]|0;aa=n;ab=n&63454}if(q){ac=c[277228]|0}else{ac=e[(c[277213]|0)+(o<<1)>>1]|0}q=((ac^l)&2081|e[(c[277220]|0)+((l&2081&aa)+((ab+(l&63454)|0)>>>1)<<1)>>1])&65535;l=m+15|0;b[(c[277218]|0)+(l<<1)>>1]=q;b[(c[277218]|0)+(o<<1)>>1]=q;q=a[1108909]|0;a[(c[277219]|0)+l|0]=q;a[(c[277219]|0)+o|0]=q}}while(0);o=j-1|0;if((o|0)<=0){break}r=r+8|0;j=o;m=(c[277223]|0)+m|0}return}if((f&32768|0)==0){if((i|0)<=0){return}f=p+h|0;m=i;j=g;while(1){r=a[1108908]|0;ab=c[277219]|0;do{if((r&255)>(d[ab+j|0]|0)){aa=a[f+7|0]|0;if(aa<<24>>24==0){ad=r;ae=ab;break}ac=e[(c[277225]|0)+((aa&255)<<1)>>1]|0;aa=(a[(c[277215]|0)+j|0]&32)==0;if(aa){Y=c[277228]|0;af=Y;ag=Y&-2082}else{Y=e[(c[277213]|0)+(j<<1)>>1]|0;af=Y;ag=Y&63454}if(aa){ah=c[277228]|0}else{ah=e[(c[277213]|0)+(j<<1)>>1]|0}aa=((ah^ac)&2081|e[(c[277220]|0)+((ac&2081&af)+((ag+(ac&63454)|0)>>>1)<<1)>>1])&65535;ac=j+1|0;b[(c[277218]|0)+(ac<<1)>>1]=aa;b[(c[277218]|0)+(j<<1)>>1]=aa;aa=a[1108909]|0;a[(c[277219]|0)+ac|0]=aa;a[(c[277219]|0)+j|0]=aa;ad=a[1108908]|0;ae=c[277219]|0}else{ad=r;ae=ab}}while(0);ab=j+2|0;do{if((ad&255)>(d[ae+ab|0]|0)){r=a[f+6|0]|0;if(r<<24>>24==0){ai=ad;aj=ae;break}aa=e[(c[277225]|0)+((r&255)<<1)>>1]|0;r=(a[(c[277215]|0)+ab|0]&32)==0;if(r){ac=c[277228]|0;ak=ac;al=ac&-2082}else{ac=e[(c[277213]|0)+(ab<<1)>>1]|0;ak=ac;al=ac&63454}if(r){am=c[277228]|0}else{am=e[(c[277213]|0)+(ab<<1)>>1]|0}r=((am^aa)&2081|e[(c[277220]|0)+((aa&2081&ak)+((al+(aa&63454)|0)>>>1)<<1)>>1])&65535;aa=j+3|0;b[(c[277218]|0)+(aa<<1)>>1]=r;b[(c[277218]|0)+(ab<<1)>>1]=r;r=a[1108909]|0;a[(c[277219]|0)+aa|0]=r;a[(c[277219]|0)+ab|0]=r;ai=a[1108908]|0;aj=c[277219]|0}else{ai=ad;aj=ae}}while(0);ab=j+4|0;do{if((ai&255)>(d[aj+ab|0]|0)){r=a[f+5|0]|0;if(r<<24>>24==0){an=ai;ao=aj;break}aa=e[(c[277225]|0)+((r&255)<<1)>>1]|0;r=(a[(c[277215]|0)+ab|0]&32)==0;if(r){ac=c[277228]|0;ap=ac;aq=ac&-2082}else{ac=e[(c[277213]|0)+(ab<<1)>>1]|0;ap=ac;aq=ac&63454}if(r){ar=c[277228]|0}else{ar=e[(c[277213]|0)+(ab<<1)>>1]|0}r=((ar^aa)&2081|e[(c[277220]|0)+((aa&2081&ap)+((aq+(aa&63454)|0)>>>1)<<1)>>1])&65535;aa=j+5|0;b[(c[277218]|0)+(aa<<1)>>1]=r;b[(c[277218]|0)+(ab<<1)>>1]=r;r=a[1108909]|0;a[(c[277219]|0)+aa|0]=r;a[(c[277219]|0)+ab|0]=r;an=a[1108908]|0;ao=c[277219]|0}else{an=ai;ao=aj}}while(0);ab=j+6|0;do{if((an&255)>(d[ao+ab|0]|0)){r=a[f+4|0]|0;if(r<<24>>24==0){as=an;at=ao;break}aa=e[(c[277225]|0)+((r&255)<<1)>>1]|0;r=(a[(c[277215]|0)+ab|0]&32)==0;if(r){ac=c[277228]|0;au=ac;av=ac&-2082}else{ac=e[(c[277213]|0)+(ab<<1)>>1]|0;au=ac;av=ac&63454}if(r){aw=c[277228]|0}else{aw=e[(c[277213]|0)+(ab<<1)>>1]|0}r=((aw^aa)&2081|e[(c[277220]|0)+((aa&2081&au)+((av+(aa&63454)|0)>>>1)<<1)>>1])&65535;aa=j+7|0;b[(c[277218]|0)+(aa<<1)>>1]=r;b[(c[277218]|0)+(ab<<1)>>1]=r;r=a[1108909]|0;a[(c[277219]|0)+aa|0]=r;a[(c[277219]|0)+ab|0]=r;as=a[1108908]|0;at=c[277219]|0}else{as=an;at=ao}}while(0);ab=j+8|0;do{if((as&255)>(d[at+ab|0]|0)){r=a[f+3|0]|0;if(r<<24>>24==0){ax=as;ay=at;break}aa=e[(c[277225]|0)+((r&255)<<1)>>1]|0;r=(a[(c[277215]|0)+ab|0]&32)==0;if(r){ac=c[277228]|0;az=ac;aA=ac&-2082}else{ac=e[(c[277213]|0)+(ab<<1)>>1]|0;az=ac;aA=ac&63454}if(r){aB=c[277228]|0}else{aB=e[(c[277213]|0)+(ab<<1)>>1]|0}r=((aB^aa)&2081|e[(c[277220]|0)+((aa&2081&az)+((aA+(aa&63454)|0)>>>1)<<1)>>1])&65535;aa=j+9|0;b[(c[277218]|0)+(aa<<1)>>1]=r;b[(c[277218]|0)+(ab<<1)>>1]=r;r=a[1108909]|0;a[(c[277219]|0)+aa|0]=r;a[(c[277219]|0)+ab|0]=r;ax=a[1108908]|0;ay=c[277219]|0}else{ax=as;ay=at}}while(0);ab=j+10|0;do{if((ax&255)>(d[ay+ab|0]|0)){r=a[f+2|0]|0;if(r<<24>>24==0){aC=ax;aD=ay;break}aa=e[(c[277225]|0)+((r&255)<<1)>>1]|0;r=(a[(c[277215]|0)+ab|0]&32)==0;if(r){ac=c[277228]|0;aE=ac;aF=ac&-2082}else{ac=e[(c[277213]|0)+(ab<<1)>>1]|0;aE=ac;aF=ac&63454}if(r){aG=c[277228]|0}else{aG=e[(c[277213]|0)+(ab<<1)>>1]|0}r=((aG^aa)&2081|e[(c[277220]|0)+((aa&2081&aE)+((aF+(aa&63454)|0)>>>1)<<1)>>1])&65535;aa=j+11|0;b[(c[277218]|0)+(aa<<1)>>1]=r;b[(c[277218]|0)+(ab<<1)>>1]=r;r=a[1108909]|0;a[(c[277219]|0)+aa|0]=r;a[(c[277219]|0)+ab|0]=r;aC=a[1108908]|0;aD=c[277219]|0}else{aC=ax;aD=ay}}while(0);ab=j+12|0;do{if((aC&255)>(d[aD+ab|0]|0)){r=a[f+1|0]|0;if(r<<24>>24==0){aH=aC;aI=aD;break}aa=e[(c[277225]|0)+((r&255)<<1)>>1]|0;r=(a[(c[277215]|0)+ab|0]&32)==0;if(r){ac=c[277228]|0;aJ=ac;aK=ac&-2082}else{ac=e[(c[277213]|0)+(ab<<1)>>1]|0;aJ=ac;aK=ac&63454}if(r){aL=c[277228]|0}else{aL=e[(c[277213]|0)+(ab<<1)>>1]|0}r=((aL^aa)&2081|e[(c[277220]|0)+((aa&2081&aJ)+((aK+(aa&63454)|0)>>>1)<<1)>>1])&65535;aa=j+13|0;b[(c[277218]|0)+(aa<<1)>>1]=r;b[(c[277218]|0)+(ab<<1)>>1]=r;r=a[1108909]|0;a[(c[277219]|0)+aa|0]=r;a[(c[277219]|0)+ab|0]=r;aH=a[1108908]|0;aI=c[277219]|0}else{aH=aC;aI=aD}}while(0);ab=j+14|0;do{if((aH&255)>(d[aI+ab|0]|0)){r=a[f]|0;if(r<<24>>24==0){break}aa=e[(c[277225]|0)+((r&255)<<1)>>1]|0;r=(a[(c[277215]|0)+ab|0]&32)==0;if(r){ac=c[277228]|0;aM=ac;aN=ac&-2082}else{ac=e[(c[277213]|0)+(ab<<1)>>1]|0;aM=ac;aN=ac&63454}if(r){aO=c[277228]|0}else{aO=e[(c[277213]|0)+(ab<<1)>>1]|0}r=((aO^aa)&2081|e[(c[277220]|0)+((aa&2081&aM)+((aN+(aa&63454)|0)>>>1)<<1)>>1])&65535;aa=j+15|0;b[(c[277218]|0)+(aa<<1)>>1]=r;b[(c[277218]|0)+(ab<<1)>>1]=r;r=a[1108909]|0;a[(c[277219]|0)+aa|0]=r;a[(c[277219]|0)+ab|0]=r}}while(0);ab=m-1|0;if((ab|0)<=0){break}f=f+8|0;m=ab;j=(c[277223]|0)+j|0}return}j=p+(56-h)|0;h=(i|0)>0;if(k){if(h){aP=j;aQ=i;aR=g}else{return}while(1){k=a[1108908]|0;p=c[277219]|0;do{if((k&255)>(d[p+aR|0]|0)){m=a[aP+7|0]|0;if(m<<24>>24==0){aS=k;aT=p;break}f=e[(c[277225]|0)+((m&255)<<1)>>1]|0;m=(a[(c[277215]|0)+aR|0]&32)==0;if(m){aN=c[277228]|0;aU=aN;aV=aN&-2082}else{aN=e[(c[277213]|0)+(aR<<1)>>1]|0;aU=aN;aV=aN&63454}if(m){aW=c[277228]|0}else{aW=e[(c[277213]|0)+(aR<<1)>>1]|0}m=((aW^f)&2081|e[(c[277220]|0)+((f&2081&aU)+((aV+(f&63454)|0)>>>1)<<1)>>1])&65535;f=aR+1|0;b[(c[277218]|0)+(f<<1)>>1]=m;b[(c[277218]|0)+(aR<<1)>>1]=m;m=a[1108909]|0;a[(c[277219]|0)+f|0]=m;a[(c[277219]|0)+aR|0]=m;aS=a[1108908]|0;aT=c[277219]|0}else{aS=k;aT=p}}while(0);p=aR+2|0;do{if((aS&255)>(d[aT+p|0]|0)){k=a[aP+6|0]|0;if(k<<24>>24==0){aX=aS;aY=aT;break}m=e[(c[277225]|0)+((k&255)<<1)>>1]|0;k=(a[(c[277215]|0)+p|0]&32)==0;if(k){f=c[277228]|0;aZ=f;a_=f&-2082}else{f=e[(c[277213]|0)+(p<<1)>>1]|0;aZ=f;a_=f&63454}if(k){a$=c[277228]|0}else{a$=e[(c[277213]|0)+(p<<1)>>1]|0}k=((a$^m)&2081|e[(c[277220]|0)+((m&2081&aZ)+((a_+(m&63454)|0)>>>1)<<1)>>1])&65535;m=aR+3|0;b[(c[277218]|0)+(m<<1)>>1]=k;b[(c[277218]|0)+(p<<1)>>1]=k;k=a[1108909]|0;a[(c[277219]|0)+m|0]=k;a[(c[277219]|0)+p|0]=k;aX=a[1108908]|0;aY=c[277219]|0}else{aX=aS;aY=aT}}while(0);p=aR+4|0;do{if((aX&255)>(d[aY+p|0]|0)){k=a[aP+5|0]|0;if(k<<24>>24==0){a0=aX;a1=aY;break}m=e[(c[277225]|0)+((k&255)<<1)>>1]|0;k=(a[(c[277215]|0)+p|0]&32)==0;if(k){f=c[277228]|0;a2=f;a3=f&-2082}else{f=e[(c[277213]|0)+(p<<1)>>1]|0;a2=f;a3=f&63454}if(k){a4=c[277228]|0}else{a4=e[(c[277213]|0)+(p<<1)>>1]|0}k=((a4^m)&2081|e[(c[277220]|0)+((m&2081&a2)+((a3+(m&63454)|0)>>>1)<<1)>>1])&65535;m=aR+5|0;b[(c[277218]|0)+(m<<1)>>1]=k;b[(c[277218]|0)+(p<<1)>>1]=k;k=a[1108909]|0;a[(c[277219]|0)+m|0]=k;a[(c[277219]|0)+p|0]=k;a0=a[1108908]|0;a1=c[277219]|0}else{a0=aX;a1=aY}}while(0);p=aR+6|0;do{if((a0&255)>(d[a1+p|0]|0)){k=a[aP+4|0]|0;if(k<<24>>24==0){a5=a0;a6=a1;break}m=e[(c[277225]|0)+((k&255)<<1)>>1]|0;k=(a[(c[277215]|0)+p|0]&32)==0;if(k){f=c[277228]|0;a7=f;a8=f&-2082}else{f=e[(c[277213]|0)+(p<<1)>>1]|0;a7=f;a8=f&63454}if(k){a9=c[277228]|0}else{a9=e[(c[277213]|0)+(p<<1)>>1]|0}k=((a9^m)&2081|e[(c[277220]|0)+((m&2081&a7)+((a8+(m&63454)|0)>>>1)<<1)>>1])&65535;m=aR+7|0;b[(c[277218]|0)+(m<<1)>>1]=k;b[(c[277218]|0)+(p<<1)>>1]=k;k=a[1108909]|0;a[(c[277219]|0)+m|0]=k;a[(c[277219]|0)+p|0]=k;a5=a[1108908]|0;a6=c[277219]|0}else{a5=a0;a6=a1}}while(0);p=aR+8|0;do{if((a5&255)>(d[a6+p|0]|0)){k=a[aP+3|0]|0;if(k<<24>>24==0){ba=a5;bb=a6;break}m=e[(c[277225]|0)+((k&255)<<1)>>1]|0;k=(a[(c[277215]|0)+p|0]&32)==0;if(k){f=c[277228]|0;bc=f;bd=f&-2082}else{f=e[(c[277213]|0)+(p<<1)>>1]|0;bc=f;bd=f&63454}if(k){be=c[277228]|0}else{be=e[(c[277213]|0)+(p<<1)>>1]|0}k=((be^m)&2081|e[(c[277220]|0)+((m&2081&bc)+((bd+(m&63454)|0)>>>1)<<1)>>1])&65535;m=aR+9|0;b[(c[277218]|0)+(m<<1)>>1]=k;b[(c[277218]|0)+(p<<1)>>1]=k;k=a[1108909]|0;a[(c[277219]|0)+m|0]=k;a[(c[277219]|0)+p|0]=k;ba=a[1108908]|0;bb=c[277219]|0}else{ba=a5;bb=a6}}while(0);p=aR+10|0;do{if((ba&255)>(d[bb+p|0]|0)){k=a[aP+2|0]|0;if(k<<24>>24==0){bf=ba;bg=bb;break}m=e[(c[277225]|0)+((k&255)<<1)>>1]|0;k=(a[(c[277215]|0)+p|0]&32)==0;if(k){f=c[277228]|0;bh=f;bi=f&-2082}else{f=e[(c[277213]|0)+(p<<1)>>1]|0;bh=f;bi=f&63454}if(k){bj=c[277228]|0}else{bj=e[(c[277213]|0)+(p<<1)>>1]|0}k=((bj^m)&2081|e[(c[277220]|0)+((m&2081&bh)+((bi+(m&63454)|0)>>>1)<<1)>>1])&65535;m=aR+11|0;b[(c[277218]|0)+(m<<1)>>1]=k;b[(c[277218]|0)+(p<<1)>>1]=k;k=a[1108909]|0;a[(c[277219]|0)+m|0]=k;a[(c[277219]|0)+p|0]=k;bf=a[1108908]|0;bg=c[277219]|0}else{bf=ba;bg=bb}}while(0);p=aR+12|0;do{if((bf&255)>(d[bg+p|0]|0)){k=a[aP+1|0]|0;if(k<<24>>24==0){bk=bf;bl=bg;break}m=e[(c[277225]|0)+((k&255)<<1)>>1]|0;k=(a[(c[277215]|0)+p|0]&32)==0;if(k){f=c[277228]|0;bm=f;bn=f&-2082}else{f=e[(c[277213]|0)+(p<<1)>>1]|0;bm=f;bn=f&63454}if(k){bo=c[277228]|0}else{bo=e[(c[277213]|0)+(p<<1)>>1]|0}k=((bo^m)&2081|e[(c[277220]|0)+((m&2081&bm)+((bn+(m&63454)|0)>>>1)<<1)>>1])&65535;m=aR+13|0;b[(c[277218]|0)+(m<<1)>>1]=k;b[(c[277218]|0)+(p<<1)>>1]=k;k=a[1108909]|0;a[(c[277219]|0)+m|0]=k;a[(c[277219]|0)+p|0]=k;bk=a[1108908]|0;bl=c[277219]|0}else{bk=bf;bl=bg}}while(0);p=aR+14|0;do{if((bk&255)>(d[bl+p|0]|0)){k=a[aP]|0;if(k<<24>>24==0){break}m=e[(c[277225]|0)+((k&255)<<1)>>1]|0;k=(a[(c[277215]|0)+p|0]&32)==0;if(k){f=c[277228]|0;bp=f;bq=f&-2082}else{f=e[(c[277213]|0)+(p<<1)>>1]|0;bp=f;bq=f&63454}if(k){br=c[277228]|0}else{br=e[(c[277213]|0)+(p<<1)>>1]|0}k=((br^m)&2081|e[(c[277220]|0)+((m&2081&bp)+((bq+(m&63454)|0)>>>1)<<1)>>1])&65535;m=aR+15|0;b[(c[277218]|0)+(m<<1)>>1]=k;b[(c[277218]|0)+(p<<1)>>1]=k;k=a[1108909]|0;a[(c[277219]|0)+m|0]=k;a[(c[277219]|0)+p|0]=k}}while(0);p=aQ-1|0;if((p|0)<=0){break}aP=aP-8|0;aQ=p;aR=(c[277223]|0)+aR|0}return}else{if(h){bs=j;bt=i;bu=g}else{return}while(1){g=a[1108908]|0;i=c[277219]|0;do{if((g&255)>(d[i+bu|0]|0)){j=a[bs]|0;if(j<<24>>24==0){bv=g;bw=i;break}h=e[(c[277225]|0)+((j&255)<<1)>>1]|0;j=(a[(c[277215]|0)+bu|0]&32)==0;if(j){aR=c[277228]|0;bx=aR;by=aR&-2082}else{aR=e[(c[277213]|0)+(bu<<1)>>1]|0;bx=aR;by=aR&63454}if(j){bz=c[277228]|0}else{bz=e[(c[277213]|0)+(bu<<1)>>1]|0}j=((bz^h)&2081|e[(c[277220]|0)+((h&2081&bx)+((by+(h&63454)|0)>>>1)<<1)>>1])&65535;h=bu+1|0;b[(c[277218]|0)+(h<<1)>>1]=j;b[(c[277218]|0)+(bu<<1)>>1]=j;j=a[1108909]|0;a[(c[277219]|0)+h|0]=j;a[(c[277219]|0)+bu|0]=j;bv=a[1108908]|0;bw=c[277219]|0}else{bv=g;bw=i}}while(0);i=bu+2|0;do{if((bv&255)>(d[bw+i|0]|0)){g=a[bs+1|0]|0;if(g<<24>>24==0){bA=bv;bB=bw;break}j=e[(c[277225]|0)+((g&255)<<1)>>1]|0;g=(a[(c[277215]|0)+i|0]&32)==0;if(g){h=c[277228]|0;bC=h;bD=h&-2082}else{h=e[(c[277213]|0)+(i<<1)>>1]|0;bC=h;bD=h&63454}if(g){bE=c[277228]|0}else{bE=e[(c[277213]|0)+(i<<1)>>1]|0}g=((bE^j)&2081|e[(c[277220]|0)+((j&2081&bC)+((bD+(j&63454)|0)>>>1)<<1)>>1])&65535;j=bu+3|0;b[(c[277218]|0)+(j<<1)>>1]=g;b[(c[277218]|0)+(i<<1)>>1]=g;g=a[1108909]|0;a[(c[277219]|0)+j|0]=g;a[(c[277219]|0)+i|0]=g;bA=a[1108908]|0;bB=c[277219]|0}else{bA=bv;bB=bw}}while(0);i=bu+4|0;do{if((bA&255)>(d[bB+i|0]|0)){g=a[bs+2|0]|0;if(g<<24>>24==0){bF=bA;bG=bB;break}j=e[(c[277225]|0)+((g&255)<<1)>>1]|0;g=(a[(c[277215]|0)+i|0]&32)==0;if(g){h=c[277228]|0;bH=h;bI=h&-2082}else{h=e[(c[277213]|0)+(i<<1)>>1]|0;bH=h;bI=h&63454}if(g){bJ=c[277228]|0}else{bJ=e[(c[277213]|0)+(i<<1)>>1]|0}g=((bJ^j)&2081|e[(c[277220]|0)+((j&2081&bH)+((bI+(j&63454)|0)>>>1)<<1)>>1])&65535;j=bu+5|0;b[(c[277218]|0)+(j<<1)>>1]=g;b[(c[277218]|0)+(i<<1)>>1]=g;g=a[1108909]|0;a[(c[277219]|0)+j|0]=g;a[(c[277219]|0)+i|0]=g;bF=a[1108908]|0;bG=c[277219]|0}else{bF=bA;bG=bB}}while(0);i=bu+6|0;do{if((bF&255)>(d[bG+i|0]|0)){g=a[bs+3|0]|0;if(g<<24>>24==0){bK=bF;bL=bG;break}j=e[(c[277225]|0)+((g&255)<<1)>>1]|0;g=(a[(c[277215]|0)+i|0]&32)==0;if(g){h=c[277228]|0;bM=h;bN=h&-2082}else{h=e[(c[277213]|0)+(i<<1)>>1]|0;bM=h;bN=h&63454}if(g){bO=c[277228]|0}else{bO=e[(c[277213]|0)+(i<<1)>>1]|0}g=((bO^j)&2081|e[(c[277220]|0)+((j&2081&bM)+((bN+(j&63454)|0)>>>1)<<1)>>1])&65535;j=bu+7|0;b[(c[277218]|0)+(j<<1)>>1]=g;b[(c[277218]|0)+(i<<1)>>1]=g;g=a[1108909]|0;a[(c[277219]|0)+j|0]=g;a[(c[277219]|0)+i|0]=g;bK=a[1108908]|0;bL=c[277219]|0}else{bK=bF;bL=bG}}while(0);i=bu+8|0;do{if((bK&255)>(d[bL+i|0]|0)){g=a[bs+4|0]|0;if(g<<24>>24==0){bP=bK;bQ=bL;break}j=e[(c[277225]|0)+((g&255)<<1)>>1]|0;g=(a[(c[277215]|0)+i|0]&32)==0;if(g){h=c[277228]|0;bR=h;bS=h&-2082}else{h=e[(c[277213]|0)+(i<<1)>>1]|0;bR=h;bS=h&63454}if(g){bT=c[277228]|0}else{bT=e[(c[277213]|0)+(i<<1)>>1]|0}g=((bT^j)&2081|e[(c[277220]|0)+((j&2081&bR)+((bS+(j&63454)|0)>>>1)<<1)>>1])&65535;j=bu+9|0;b[(c[277218]|0)+(j<<1)>>1]=g;b[(c[277218]|0)+(i<<1)>>1]=g;g=a[1108909]|0;a[(c[277219]|0)+j|0]=g;a[(c[277219]|0)+i|0]=g;bP=a[1108908]|0;bQ=c[277219]|0}else{bP=bK;bQ=bL}}while(0);i=bu+10|0;do{if((bP&255)>(d[bQ+i|0]|0)){g=a[bs+5|0]|0;if(g<<24>>24==0){bU=bP;bV=bQ;break}j=e[(c[277225]|0)+((g&255)<<1)>>1]|0;g=(a[(c[277215]|0)+i|0]&32)==0;if(g){h=c[277228]|0;bW=h;bX=h&-2082}else{h=e[(c[277213]|0)+(i<<1)>>1]|0;bW=h;bX=h&63454}if(g){bY=c[277228]|0}else{bY=e[(c[277213]|0)+(i<<1)>>1]|0}g=((bY^j)&2081|e[(c[277220]|0)+((j&2081&bW)+((bX+(j&63454)|0)>>>1)<<1)>>1])&65535;j=bu+11|0;b[(c[277218]|0)+(j<<1)>>1]=g;b[(c[277218]|0)+(i<<1)>>1]=g;g=a[1108909]|0;a[(c[277219]|0)+j|0]=g;a[(c[277219]|0)+i|0]=g;bU=a[1108908]|0;bV=c[277219]|0}else{bU=bP;bV=bQ}}while(0);i=bu+12|0;do{if((bU&255)>(d[bV+i|0]|0)){g=a[bs+6|0]|0;if(g<<24>>24==0){bZ=bU;b_=bV;break}j=e[(c[277225]|0)+((g&255)<<1)>>1]|0;g=(a[(c[277215]|0)+i|0]&32)==0;if(g){h=c[277228]|0;b$=h;b0=h&-2082}else{h=e[(c[277213]|0)+(i<<1)>>1]|0;b$=h;b0=h&63454}if(g){b1=c[277228]|0}else{b1=e[(c[277213]|0)+(i<<1)>>1]|0}g=((b1^j)&2081|e[(c[277220]|0)+((j&2081&b$)+((b0+(j&63454)|0)>>>1)<<1)>>1])&65535;j=bu+13|0;b[(c[277218]|0)+(j<<1)>>1]=g;b[(c[277218]|0)+(i<<1)>>1]=g;g=a[1108909]|0;a[(c[277219]|0)+j|0]=g;a[(c[277219]|0)+i|0]=g;bZ=a[1108908]|0;b_=c[277219]|0}else{bZ=bU;b_=bV}}while(0);i=bu+14|0;do{if((bZ&255)>(d[b_+i|0]|0)){g=a[bs+7|0]|0;if(g<<24>>24==0){break}j=e[(c[277225]|0)+((g&255)<<1)>>1]|0;g=(a[(c[277215]|0)+i|0]&32)==0;if(g){h=c[277228]|0;b2=h;b3=h&-2082}else{h=e[(c[277213]|0)+(i<<1)>>1]|0;b2=h;b3=h&63454}if(g){b4=c[277228]|0}else{b4=e[(c[277213]|0)+(i<<1)>>1]|0}g=((b4^j)&2081|e[(c[277220]|0)+((j&2081&b2)+((b3+(j&63454)|0)>>>1)<<1)>>1])&65535;j=bu+15|0;b[(c[277218]|0)+(j<<1)>>1]=g;b[(c[277218]|0)+(i<<1)>>1]=g;g=a[1108909]|0;a[(c[277219]|0)+j|0]=g;a[(c[277219]|0)+i|0]=g}}while(0);i=bt-1|0;if((i|0)<=0){break}bs=bs-8|0;bt=i;bu=(c[277223]|0)+bu|0}return}}function Uw(f,g,h,i){f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0;j=f&1023;k=c[348606]|0;l=(j<<k)+(c[348604]|0)|0;if((f&256|0)==0){m=l}else{m=(c[348602]|0)+l|0}l=m&65535;m=l>>>(k>>>0);k=(f&16384|0)!=0;n=m<<6;do{if(k){o=(c[348622]|0)+n|0;if((a[(c[348618]|0)+m|0]|0)!=0){p=o;break}q=fi[c[348636]&63](o,l,j)|0;a[(c[348618]|0)+m|0]=q;p=o}else{o=(c[348624]|0)+n|0;if((a[(c[348620]|0)+m|0]|0)!=0){p=o;break}q=fi[c[348638]&63](o,l,j)|0;a[(c[348620]|0)+m|0]=q;p=o}}while(0);if((a[(c[348620]|0)+m|0]|0)==2){return}if((a[1394464]|0)==0){r=1106168+((f>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){m=d[1044485]|0;c[276541]=7080+(m<<5);j=0;do{l=j<<1&2;n=j&2;o=j&4;q=0;do{b[1125528+(j<<9)+(q<<1)>>1]=d[(q>>>1&28|n)+(7080+(m<<5))|0]<<6|d[(q<<2&28|l)+(7080+(m<<5))|0]<<11|d[(q>>>3&24|o)+(7080+(m<<5))|0];q=q+1|0;}while(q>>>0<256);j=j+1|0;}while(j>>>0<8);a[1106089]=0}r=1125528+((f>>>10&7)<<9)|0}c[277226]=r;c[277225]=(a[1108928]|0)!=0?1393712:r;if((f&49152|0)==0){if((i|0)<=0){return}r=p+h|0;j=i;m=g;while(1){q=a[1108908]|0;o=c[277219]|0;do{if((q&255)>(d[o+m|0]|0)){l=a[r]|0;if(l<<24>>24==0){s=q;t=o;break}n=e[(c[277225]|0)+((l&255)<<1)>>1]|0;l=c[277228]|0;u=(((n&63454)+(l&-2082)|0)>>>1)+(l&2081&n)|0;if((a[1108928]|0)==0){v=u&65535}else{v=(e[(c[277220]|0)+(u<<1)>>1]|(n^l)&2081)&65535}l=m+1|0;b[(c[277218]|0)+(l<<1)>>1]=v;b[(c[277218]|0)+(m<<1)>>1]=v;n=a[1108909]|0;a[(c[277219]|0)+l|0]=n;a[(c[277219]|0)+m|0]=n;s=a[1108908]|0;t=c[277219]|0}else{s=q;t=o}}while(0);o=m+2|0;do{if((s&255)>(d[t+o|0]|0)){q=a[r+1|0]|0;if(q<<24>>24==0){w=s;x=t;break}n=e[(c[277225]|0)+((q&255)<<1)>>1]|0;q=c[277228]|0;l=(((n&63454)+(q&-2082)|0)>>>1)+(q&2081&n)|0;if((a[1108928]|0)==0){y=l&65535}else{y=(e[(c[277220]|0)+(l<<1)>>1]|(n^q)&2081)&65535}q=m+3|0;b[(c[277218]|0)+(q<<1)>>1]=y;b[(c[277218]|0)+(o<<1)>>1]=y;n=a[1108909]|0;a[(c[277219]|0)+q|0]=n;a[(c[277219]|0)+o|0]=n;w=a[1108908]|0;x=c[277219]|0}else{w=s;x=t}}while(0);o=m+4|0;do{if((w&255)>(d[x+o|0]|0)){n=a[r+2|0]|0;if(n<<24>>24==0){z=w;A=x;break}q=e[(c[277225]|0)+((n&255)<<1)>>1]|0;n=c[277228]|0;l=(((q&63454)+(n&-2082)|0)>>>1)+(n&2081&q)|0;if((a[1108928]|0)==0){B=l&65535}else{B=(e[(c[277220]|0)+(l<<1)>>1]|(q^n)&2081)&65535}n=m+5|0;b[(c[277218]|0)+(n<<1)>>1]=B;b[(c[277218]|0)+(o<<1)>>1]=B;q=a[1108909]|0;a[(c[277219]|0)+n|0]=q;a[(c[277219]|0)+o|0]=q;z=a[1108908]|0;A=c[277219]|0}else{z=w;A=x}}while(0);o=m+6|0;do{if((z&255)>(d[A+o|0]|0)){q=a[r+3|0]|0;if(q<<24>>24==0){C=z;D=A;break}n=e[(c[277225]|0)+((q&255)<<1)>>1]|0;q=c[277228]|0;l=(((n&63454)+(q&-2082)|0)>>>1)+(q&2081&n)|0;if((a[1108928]|0)==0){E=l&65535}else{E=(e[(c[277220]|0)+(l<<1)>>1]|(n^q)&2081)&65535}q=m+7|0;b[(c[277218]|0)+(q<<1)>>1]=E;b[(c[277218]|0)+(o<<1)>>1]=E;n=a[1108909]|0;a[(c[277219]|0)+q|0]=n;a[(c[277219]|0)+o|0]=n;C=a[1108908]|0;D=c[277219]|0}else{C=z;D=A}}while(0);o=m+8|0;do{if((C&255)>(d[D+o|0]|0)){n=a[r+4|0]|0;if(n<<24>>24==0){F=C;G=D;break}q=e[(c[277225]|0)+((n&255)<<1)>>1]|0;n=c[277228]|0;l=(((q&63454)+(n&-2082)|0)>>>1)+(n&2081&q)|0;if((a[1108928]|0)==0){H=l&65535}else{H=(e[(c[277220]|0)+(l<<1)>>1]|(q^n)&2081)&65535}n=m+9|0;b[(c[277218]|0)+(n<<1)>>1]=H;b[(c[277218]|0)+(o<<1)>>1]=H;q=a[1108909]|0;a[(c[277219]|0)+n|0]=q;a[(c[277219]|0)+o|0]=q;F=a[1108908]|0;G=c[277219]|0}else{F=C;G=D}}while(0);o=m+10|0;do{if((F&255)>(d[G+o|0]|0)){q=a[r+5|0]|0;if(q<<24>>24==0){I=F;J=G;break}n=e[(c[277225]|0)+((q&255)<<1)>>1]|0;q=c[277228]|0;l=(((n&63454)+(q&-2082)|0)>>>1)+(q&2081&n)|0;if((a[1108928]|0)==0){K=l&65535}else{K=(e[(c[277220]|0)+(l<<1)>>1]|(n^q)&2081)&65535}q=m+11|0;b[(c[277218]|0)+(q<<1)>>1]=K;b[(c[277218]|0)+(o<<1)>>1]=K;n=a[1108909]|0;a[(c[277219]|0)+q|0]=n;a[(c[277219]|0)+o|0]=n;I=a[1108908]|0;J=c[277219]|0}else{I=F;J=G}}while(0);o=m+12|0;do{if((I&255)>(d[J+o|0]|0)){n=a[r+6|0]|0;if(n<<24>>24==0){L=I;M=J;break}q=e[(c[277225]|0)+((n&255)<<1)>>1]|0;n=c[277228]|0;l=(((q&63454)+(n&-2082)|0)>>>1)+(n&2081&q)|0;if((a[1108928]|0)==0){N=l&65535}else{N=(e[(c[277220]|0)+(l<<1)>>1]|(q^n)&2081)&65535}n=m+13|0;b[(c[277218]|0)+(n<<1)>>1]=N;b[(c[277218]|0)+(o<<1)>>1]=N;q=a[1108909]|0;a[(c[277219]|0)+n|0]=q;a[(c[277219]|0)+o|0]=q;L=a[1108908]|0;M=c[277219]|0}else{L=I;M=J}}while(0);o=m+14|0;do{if((L&255)>(d[M+o|0]|0)){q=a[r+7|0]|0;if(q<<24>>24==0){break}n=e[(c[277225]|0)+((q&255)<<1)>>1]|0;q=c[277228]|0;l=(((n&63454)+(q&-2082)|0)>>>1)+(q&2081&n)|0;if((a[1108928]|0)==0){O=l&65535}else{O=(e[(c[277220]|0)+(l<<1)>>1]|(n^q)&2081)&65535}q=m+15|0;b[(c[277218]|0)+(q<<1)>>1]=O;b[(c[277218]|0)+(o<<1)>>1]=O;n=a[1108909]|0;a[(c[277219]|0)+q|0]=n;a[(c[277219]|0)+o|0]=n}}while(0);o=j-1|0;if((o|0)<=0){break}r=r+8|0;j=o;m=(c[277223]|0)+m|0}return}if((f&32768|0)==0){if((i|0)<=0){return}f=p+h|0;m=i;j=g;while(1){r=a[1108908]|0;O=c[277219]|0;do{if((r&255)>(d[O+j|0]|0)){M=a[f+7|0]|0;if(M<<24>>24==0){P=r;Q=O;break}L=e[(c[277225]|0)+((M&255)<<1)>>1]|0;M=c[277228]|0;J=(((L&63454)+(M&-2082)|0)>>>1)+(M&2081&L)|0;if((a[1108928]|0)==0){R=J&65535}else{R=(e[(c[277220]|0)+(J<<1)>>1]|(L^M)&2081)&65535}M=j+1|0;b[(c[277218]|0)+(M<<1)>>1]=R;b[(c[277218]|0)+(j<<1)>>1]=R;L=a[1108909]|0;a[(c[277219]|0)+M|0]=L;a[(c[277219]|0)+j|0]=L;P=a[1108908]|0;Q=c[277219]|0}else{P=r;Q=O}}while(0);O=j+2|0;do{if((P&255)>(d[Q+O|0]|0)){r=a[f+6|0]|0;if(r<<24>>24==0){S=P;T=Q;break}L=e[(c[277225]|0)+((r&255)<<1)>>1]|0;r=c[277228]|0;M=(((L&63454)+(r&-2082)|0)>>>1)+(r&2081&L)|0;if((a[1108928]|0)==0){U=M&65535}else{U=(e[(c[277220]|0)+(M<<1)>>1]|(L^r)&2081)&65535}r=j+3|0;b[(c[277218]|0)+(r<<1)>>1]=U;b[(c[277218]|0)+(O<<1)>>1]=U;L=a[1108909]|0;a[(c[277219]|0)+r|0]=L;a[(c[277219]|0)+O|0]=L;S=a[1108908]|0;T=c[277219]|0}else{S=P;T=Q}}while(0);O=j+4|0;do{if((S&255)>(d[T+O|0]|0)){L=a[f+5|0]|0;if(L<<24>>24==0){V=S;W=T;break}r=e[(c[277225]|0)+((L&255)<<1)>>1]|0;L=c[277228]|0;M=(((r&63454)+(L&-2082)|0)>>>1)+(L&2081&r)|0;if((a[1108928]|0)==0){X=M&65535}else{X=(e[(c[277220]|0)+(M<<1)>>1]|(r^L)&2081)&65535}L=j+5|0;b[(c[277218]|0)+(L<<1)>>1]=X;b[(c[277218]|0)+(O<<1)>>1]=X;r=a[1108909]|0;a[(c[277219]|0)+L|0]=r;a[(c[277219]|0)+O|0]=r;V=a[1108908]|0;W=c[277219]|0}else{V=S;W=T}}while(0);O=j+6|0;do{if((V&255)>(d[W+O|0]|0)){r=a[f+4|0]|0;if(r<<24>>24==0){Y=V;Z=W;break}L=e[(c[277225]|0)+((r&255)<<1)>>1]|0;r=c[277228]|0;M=(((L&63454)+(r&-2082)|0)>>>1)+(r&2081&L)|0;if((a[1108928]|0)==0){_=M&65535}else{_=(e[(c[277220]|0)+(M<<1)>>1]|(L^r)&2081)&65535}r=j+7|0;b[(c[277218]|0)+(r<<1)>>1]=_;b[(c[277218]|0)+(O<<1)>>1]=_;L=a[1108909]|0;a[(c[277219]|0)+r|0]=L;a[(c[277219]|0)+O|0]=L;Y=a[1108908]|0;Z=c[277219]|0}else{Y=V;Z=W}}while(0);O=j+8|0;do{if((Y&255)>(d[Z+O|0]|0)){L=a[f+3|0]|0;if(L<<24>>24==0){$=Y;aa=Z;break}r=e[(c[277225]|0)+((L&255)<<1)>>1]|0;L=c[277228]|0;M=(((r&63454)+(L&-2082)|0)>>>1)+(L&2081&r)|0;if((a[1108928]|0)==0){ab=M&65535}else{ab=(e[(c[277220]|0)+(M<<1)>>1]|(r^L)&2081)&65535}L=j+9|0;b[(c[277218]|0)+(L<<1)>>1]=ab;b[(c[277218]|0)+(O<<1)>>1]=ab;r=a[1108909]|0;a[(c[277219]|0)+L|0]=r;a[(c[277219]|0)+O|0]=r;$=a[1108908]|0;aa=c[277219]|0}else{$=Y;aa=Z}}while(0);O=j+10|0;do{if(($&255)>(d[aa+O|0]|0)){r=a[f+2|0]|0;if(r<<24>>24==0){ac=$;ad=aa;break}L=e[(c[277225]|0)+((r&255)<<1)>>1]|0;r=c[277228]|0;M=(((L&63454)+(r&-2082)|0)>>>1)+(r&2081&L)|0;if((a[1108928]|0)==0){ae=M&65535}else{ae=(e[(c[277220]|0)+(M<<1)>>1]|(L^r)&2081)&65535}r=j+11|0;b[(c[277218]|0)+(r<<1)>>1]=ae;b[(c[277218]|0)+(O<<1)>>1]=ae;L=a[1108909]|0;a[(c[277219]|0)+r|0]=L;a[(c[277219]|0)+O|0]=L;ac=a[1108908]|0;ad=c[277219]|0}else{ac=$;ad=aa}}while(0);O=j+12|0;do{if((ac&255)>(d[ad+O|0]|0)){L=a[f+1|0]|0;if(L<<24>>24==0){af=ac;ag=ad;break}r=e[(c[277225]|0)+((L&255)<<1)>>1]|0;L=c[277228]|0;M=(((r&63454)+(L&-2082)|0)>>>1)+(L&2081&r)|0;if((a[1108928]|0)==0){ah=M&65535}else{ah=(e[(c[277220]|0)+(M<<1)>>1]|(r^L)&2081)&65535}L=j+13|0;b[(c[277218]|0)+(L<<1)>>1]=ah;b[(c[277218]|0)+(O<<1)>>1]=ah;r=a[1108909]|0;a[(c[277219]|0)+L|0]=r;a[(c[277219]|0)+O|0]=r;af=a[1108908]|0;ag=c[277219]|0}else{af=ac;ag=ad}}while(0);O=j+14|0;do{if((af&255)>(d[ag+O|0]|0)){r=a[f]|0;if(r<<24>>24==0){break}L=e[(c[277225]|0)+((r&255)<<1)>>1]|0;r=c[277228]|0;M=(((L&63454)+(r&-2082)|0)>>>1)+(r&2081&L)|0;if((a[1108928]|0)==0){ai=M&65535}else{ai=(e[(c[277220]|0)+(M<<1)>>1]|(L^r)&2081)&65535}r=j+15|0;b[(c[277218]|0)+(r<<1)>>1]=ai;b[(c[277218]|0)+(O<<1)>>1]=ai;L=a[1108909]|0;a[(c[277219]|0)+r|0]=L;a[(c[277219]|0)+O|0]=L}}while(0);O=m-1|0;if((O|0)<=0){break}f=f+8|0;m=O;j=(c[277223]|0)+j|0}return}j=p+(56-h)|0;h=(i|0)>0;if(k){if(h){aj=j;ak=i;al=g}else{return}while(1){k=a[1108908]|0;p=c[277219]|0;do{if((k&255)>(d[p+al|0]|0)){m=a[aj+7|0]|0;if(m<<24>>24==0){am=k;an=p;break}f=e[(c[277225]|0)+((m&255)<<1)>>1]|0;m=c[277228]|0;ai=(((f&63454)+(m&-2082)|0)>>>1)+(m&2081&f)|0;if((a[1108928]|0)==0){ao=ai&65535}else{ao=(e[(c[277220]|0)+(ai<<1)>>1]|(f^m)&2081)&65535}m=al+1|0;b[(c[277218]|0)+(m<<1)>>1]=ao;b[(c[277218]|0)+(al<<1)>>1]=ao;f=a[1108909]|0;a[(c[277219]|0)+m|0]=f;a[(c[277219]|0)+al|0]=f;am=a[1108908]|0;an=c[277219]|0}else{am=k;an=p}}while(0);p=al+2|0;do{if((am&255)>(d[an+p|0]|0)){k=a[aj+6|0]|0;if(k<<24>>24==0){ap=am;aq=an;break}f=e[(c[277225]|0)+((k&255)<<1)>>1]|0;k=c[277228]|0;m=(((f&63454)+(k&-2082)|0)>>>1)+(k&2081&f)|0;if((a[1108928]|0)==0){ar=m&65535}else{ar=(e[(c[277220]|0)+(m<<1)>>1]|(f^k)&2081)&65535}k=al+3|0;b[(c[277218]|0)+(k<<1)>>1]=ar;b[(c[277218]|0)+(p<<1)>>1]=ar;f=a[1108909]|0;a[(c[277219]|0)+k|0]=f;a[(c[277219]|0)+p|0]=f;ap=a[1108908]|0;aq=c[277219]|0}else{ap=am;aq=an}}while(0);p=al+4|0;do{if((ap&255)>(d[aq+p|0]|0)){f=a[aj+5|0]|0;if(f<<24>>24==0){as=ap;at=aq;break}k=e[(c[277225]|0)+((f&255)<<1)>>1]|0;f=c[277228]|0;m=(((k&63454)+(f&-2082)|0)>>>1)+(f&2081&k)|0;if((a[1108928]|0)==0){au=m&65535}else{au=(e[(c[277220]|0)+(m<<1)>>1]|(k^f)&2081)&65535}f=al+5|0;b[(c[277218]|0)+(f<<1)>>1]=au;b[(c[277218]|0)+(p<<1)>>1]=au;k=a[1108909]|0;a[(c[277219]|0)+f|0]=k;a[(c[277219]|0)+p|0]=k;as=a[1108908]|0;at=c[277219]|0}else{as=ap;at=aq}}while(0);p=al+6|0;do{if((as&255)>(d[at+p|0]|0)){k=a[aj+4|0]|0;if(k<<24>>24==0){av=as;aw=at;break}f=e[(c[277225]|0)+((k&255)<<1)>>1]|0;k=c[277228]|0;m=(((f&63454)+(k&-2082)|0)>>>1)+(k&2081&f)|0;if((a[1108928]|0)==0){ax=m&65535}else{ax=(e[(c[277220]|0)+(m<<1)>>1]|(f^k)&2081)&65535}k=al+7|0;b[(c[277218]|0)+(k<<1)>>1]=ax;b[(c[277218]|0)+(p<<1)>>1]=ax;f=a[1108909]|0;a[(c[277219]|0)+k|0]=f;a[(c[277219]|0)+p|0]=f;av=a[1108908]|0;aw=c[277219]|0}else{av=as;aw=at}}while(0);p=al+8|0;do{if((av&255)>(d[aw+p|0]|0)){f=a[aj+3|0]|0;if(f<<24>>24==0){ay=av;az=aw;break}k=e[(c[277225]|0)+((f&255)<<1)>>1]|0;f=c[277228]|0;m=(((k&63454)+(f&-2082)|0)>>>1)+(f&2081&k)|0;if((a[1108928]|0)==0){aA=m&65535}else{aA=(e[(c[277220]|0)+(m<<1)>>1]|(k^f)&2081)&65535}f=al+9|0;b[(c[277218]|0)+(f<<1)>>1]=aA;b[(c[277218]|0)+(p<<1)>>1]=aA;k=a[1108909]|0;a[(c[277219]|0)+f|0]=k;a[(c[277219]|0)+p|0]=k;ay=a[1108908]|0;az=c[277219]|0}else{ay=av;az=aw}}while(0);p=al+10|0;do{if((ay&255)>(d[az+p|0]|0)){k=a[aj+2|0]|0;if(k<<24>>24==0){aB=ay;aC=az;break}f=e[(c[277225]|0)+((k&255)<<1)>>1]|0;k=c[277228]|0;m=(((f&63454)+(k&-2082)|0)>>>1)+(k&2081&f)|0;if((a[1108928]|0)==0){aD=m&65535}else{aD=(e[(c[277220]|0)+(m<<1)>>1]|(f^k)&2081)&65535}k=al+11|0;b[(c[277218]|0)+(k<<1)>>1]=aD;b[(c[277218]|0)+(p<<1)>>1]=aD;f=a[1108909]|0;a[(c[277219]|0)+k|0]=f;a[(c[277219]|0)+p|0]=f;aB=a[1108908]|0;aC=c[277219]|0}else{aB=ay;aC=az}}while(0);p=al+12|0;do{if((aB&255)>(d[aC+p|0]|0)){f=a[aj+1|0]|0;if(f<<24>>24==0){aE=aB;aF=aC;break}k=e[(c[277225]|0)+((f&255)<<1)>>1]|0;f=c[277228]|0;m=(((k&63454)+(f&-2082)|0)>>>1)+(f&2081&k)|0;if((a[1108928]|0)==0){aG=m&65535}else{aG=(e[(c[277220]|0)+(m<<1)>>1]|(k^f)&2081)&65535}f=al+13|0;b[(c[277218]|0)+(f<<1)>>1]=aG;b[(c[277218]|0)+(p<<1)>>1]=aG;k=a[1108909]|0;a[(c[277219]|0)+f|0]=k;a[(c[277219]|0)+p|0]=k;aE=a[1108908]|0;aF=c[277219]|0}else{aE=aB;aF=aC}}while(0);p=al+14|0;do{if((aE&255)>(d[aF+p|0]|0)){k=a[aj]|0;if(k<<24>>24==0){break}f=e[(c[277225]|0)+((k&255)<<1)>>1]|0;k=c[277228]|0;m=(((f&63454)+(k&-2082)|0)>>>1)+(k&2081&f)|0;if((a[1108928]|0)==0){aH=m&65535}else{aH=(e[(c[277220]|0)+(m<<1)>>1]|(f^k)&2081)&65535}k=al+15|0;b[(c[277218]|0)+(k<<1)>>1]=aH;b[(c[277218]|0)+(p<<1)>>1]=aH;f=a[1108909]|0;a[(c[277219]|0)+k|0]=f;a[(c[277219]|0)+p|0]=f}}while(0);p=ak-1|0;if((p|0)<=0){break}aj=aj-8|0;ak=p;al=(c[277223]|0)+al|0}return}else{if(h){aI=j;aJ=i;aK=g}else{return}while(1){g=a[1108908]|0;i=c[277219]|0;do{if((g&255)>(d[i+aK|0]|0)){j=a[aI]|0;if(j<<24>>24==0){aL=g;aM=i;break}h=e[(c[277225]|0)+((j&255)<<1)>>1]|0;j=c[277228]|0;al=(((h&63454)+(j&-2082)|0)>>>1)+(j&2081&h)|0;if((a[1108928]|0)==0){aN=al&65535}else{aN=(e[(c[277220]|0)+(al<<1)>>1]|(h^j)&2081)&65535}j=aK+1|0;b[(c[277218]|0)+(j<<1)>>1]=aN;b[(c[277218]|0)+(aK<<1)>>1]=aN;h=a[1108909]|0;a[(c[277219]|0)+j|0]=h;a[(c[277219]|0)+aK|0]=h;aL=a[1108908]|0;aM=c[277219]|0}else{aL=g;aM=i}}while(0);i=aK+2|0;do{if((aL&255)>(d[aM+i|0]|0)){g=a[aI+1|0]|0;if(g<<24>>24==0){aO=aL;aP=aM;break}h=e[(c[277225]|0)+((g&255)<<1)>>1]|0;g=c[277228]|0;j=(((h&63454)+(g&-2082)|0)>>>1)+(g&2081&h)|0;if((a[1108928]|0)==0){aQ=j&65535}else{aQ=(e[(c[277220]|0)+(j<<1)>>1]|(h^g)&2081)&65535}g=aK+3|0;b[(c[277218]|0)+(g<<1)>>1]=aQ;b[(c[277218]|0)+(i<<1)>>1]=aQ;h=a[1108909]|0;a[(c[277219]|0)+g|0]=h;a[(c[277219]|0)+i|0]=h;aO=a[1108908]|0;aP=c[277219]|0}else{aO=aL;aP=aM}}while(0);i=aK+4|0;do{if((aO&255)>(d[aP+i|0]|0)){h=a[aI+2|0]|0;if(h<<24>>24==0){aR=aO;aS=aP;break}g=e[(c[277225]|0)+((h&255)<<1)>>1]|0;h=c[277228]|0;j=(((g&63454)+(h&-2082)|0)>>>1)+(h&2081&g)|0;if((a[1108928]|0)==0){aT=j&65535}else{aT=(e[(c[277220]|0)+(j<<1)>>1]|(g^h)&2081)&65535}h=aK+5|0;b[(c[277218]|0)+(h<<1)>>1]=aT;b[(c[277218]|0)+(i<<1)>>1]=aT;g=a[1108909]|0;a[(c[277219]|0)+h|0]=g;a[(c[277219]|0)+i|0]=g;aR=a[1108908]|0;aS=c[277219]|0}else{aR=aO;aS=aP}}while(0);i=aK+6|0;do{if((aR&255)>(d[aS+i|0]|0)){g=a[aI+3|0]|0;if(g<<24>>24==0){aU=aR;aV=aS;break}h=e[(c[277225]|0)+((g&255)<<1)>>1]|0;g=c[277228]|0;j=(((h&63454)+(g&-2082)|0)>>>1)+(g&2081&h)|0;if((a[1108928]|0)==0){aW=j&65535}else{aW=(e[(c[277220]|0)+(j<<1)>>1]|(h^g)&2081)&65535}g=aK+7|0;b[(c[277218]|0)+(g<<1)>>1]=aW;b[(c[277218]|0)+(i<<1)>>1]=aW;h=a[1108909]|0;a[(c[277219]|0)+g|0]=h;a[(c[277219]|0)+i|0]=h;aU=a[1108908]|0;aV=c[277219]|0}else{aU=aR;aV=aS}}while(0);i=aK+8|0;do{if((aU&255)>(d[aV+i|0]|0)){h=a[aI+4|0]|0;if(h<<24>>24==0){aX=aU;aY=aV;break}g=e[(c[277225]|0)+((h&255)<<1)>>1]|0;h=c[277228]|0;j=(((g&63454)+(h&-2082)|0)>>>1)+(h&2081&g)|0;if((a[1108928]|0)==0){aZ=j&65535}else{aZ=(e[(c[277220]|0)+(j<<1)>>1]|(g^h)&2081)&65535}h=aK+9|0;b[(c[277218]|0)+(h<<1)>>1]=aZ;b[(c[277218]|0)+(i<<1)>>1]=aZ;g=a[1108909]|0;a[(c[277219]|0)+h|0]=g;a[(c[277219]|0)+i|0]=g;aX=a[1108908]|0;aY=c[277219]|0}else{aX=aU;aY=aV}}while(0);i=aK+10|0;do{if((aX&255)>(d[aY+i|0]|0)){g=a[aI+5|0]|0;if(g<<24>>24==0){a_=aX;a$=aY;break}h=e[(c[277225]|0)+((g&255)<<1)>>1]|0;g=c[277228]|0;j=(((h&63454)+(g&-2082)|0)>>>1)+(g&2081&h)|0;if((a[1108928]|0)==0){a0=j&65535}else{a0=(e[(c[277220]|0)+(j<<1)>>1]|(h^g)&2081)&65535}g=aK+11|0;b[(c[277218]|0)+(g<<1)>>1]=a0;b[(c[277218]|0)+(i<<1)>>1]=a0;h=a[1108909]|0;a[(c[277219]|0)+g|0]=h;a[(c[277219]|0)+i|0]=h;a_=a[1108908]|0;a$=c[277219]|0}else{a_=aX;a$=aY}}while(0);i=aK+12|0;do{if((a_&255)>(d[a$+i|0]|0)){h=a[aI+6|0]|0;if(h<<24>>24==0){a1=a_;a2=a$;break}g=e[(c[277225]|0)+((h&255)<<1)>>1]|0;h=c[277228]|0;j=(((g&63454)+(h&-2082)|0)>>>1)+(h&2081&g)|0;if((a[1108928]|0)==0){a3=j&65535}else{a3=(e[(c[277220]|0)+(j<<1)>>1]|(g^h)&2081)&65535}h=aK+13|0;b[(c[277218]|0)+(h<<1)>>1]=a3;b[(c[277218]|0)+(i<<1)>>1]=a3;g=a[1108909]|0;a[(c[277219]|0)+h|0]=g;a[(c[277219]|0)+i|0]=g;a1=a[1108908]|0;a2=c[277219]|0}else{a1=a_;a2=a$}}while(0);i=aK+14|0;do{if((a1&255)>(d[a2+i|0]|0)){g=a[aI+7|0]|0;if(g<<24>>24==0){break}h=e[(c[277225]|0)+((g&255)<<1)>>1]|0;g=c[277228]|0;j=(((h&63454)+(g&-2082)|0)>>>1)+(g&2081&h)|0;if((a[1108928]|0)==0){a4=j&65535}else{a4=(e[(c[277220]|0)+(j<<1)>>1]|(h^g)&2081)&65535}g=aK+15|0;b[(c[277218]|0)+(g<<1)>>1]=a4;b[(c[277218]|0)+(i<<1)>>1]=a4;h=a[1108909]|0;a[(c[277219]|0)+g|0]=h;a[(c[277219]|0)+i|0]=h}}while(0);i=aJ-1|0;if((i|0)<=0){break}aI=aI-8|0;aJ=i;aK=(c[277223]|0)+aK|0}return}}function Ux(f,g,h,i){f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0,cf=0,cg=0,ch=0,ci=0,cj=0,ck=0,cl=0,cm=0,cn=0,co=0,cp=0,cq=0,cr=0,cs=0,ct=0,cu=0,cv=0,cw=0,cx=0,cy=0,cz=0,cA=0,cB=0,cC=0;j=f&1023;k=c[348606]|0;l=(j<<k)+(c[348604]|0)|0;if((f&256|0)==0){m=l}else{m=(c[348602]|0)+l|0}l=m&65535;m=l>>>(k>>>0);k=(f&16384|0)!=0;n=m<<6;do{if(k){o=(c[348622]|0)+n|0;if((a[(c[348618]|0)+m|0]|0)!=0){p=o;break}q=fi[c[348636]&63](o,l,j)|0;a[(c[348618]|0)+m|0]=q;p=o}else{o=(c[348624]|0)+n|0;if((a[(c[348620]|0)+m|0]|0)!=0){p=o;break}q=fi[c[348638]&63](o,l,j)|0;a[(c[348620]|0)+m|0]=q;p=o}}while(0);if((a[(c[348620]|0)+m|0]|0)==2){return}if((a[1394464]|0)==0){r=1106168+((f>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){m=d[1044485]|0;c[276541]=7080+(m<<5);j=0;do{l=j<<1&2;n=j&2;o=j&4;q=0;do{b[1125528+(j<<9)+(q<<1)>>1]=d[(q>>>1&28|n)+(7080+(m<<5))|0]<<6|d[(q<<2&28|l)+(7080+(m<<5))|0]<<11|d[(q>>>3&24|o)+(7080+(m<<5))|0];q=q+1|0;}while(q>>>0<256);j=j+1|0;}while(j>>>0<8);a[1106089]=0}r=1125528+((f>>>10&7)<<9)|0}c[277226]=r;c[277225]=(a[1108928]|0)!=0?1393712:r;if((f&49152|0)==0){if((i|0)<=0){return}r=p+h|0;j=i;m=g;while(1){q=a[1108908]|0;o=c[277219]|0;do{if((q&255)>(d[o+m|0]|0)){l=a[r]|0;n=l&255;if(l<<24>>24==0){s=q;t=o;break}do{if((a[1108928]|0)==0){l=b[(c[277225]|0)+(n<<1)>>1]|0;u=l&65535;v=u&63454;if((a[(c[277215]|0)+m|0]&32)==0){w=c[277228]|0;x=(e[(c[277220]|0)+((((w&-2082)+v|0)>>>1)+(u&2081&w)<<1)>>1]|(w^u)&2081)&65535;break}else{u=b[(c[277213]|0)+(m<<1)>>1]|0;x=(((u&63454)+v|0)>>>1)+(u&l&2081)&65535;break}}else{l=e[(c[277225]|0)+(n<<1)>>1]|0;u=(a[(c[277215]|0)+m|0]&32)==0;if(u){v=c[277228]|0;y=v;z=v&-2082}else{v=e[(c[277213]|0)+(m<<1)>>1]|0;y=v;z=v&63454}if(u){A=c[277228]|0}else{A=e[(c[277213]|0)+(m<<1)>>1]|0}x=((A^l)&2081|e[(c[277220]|0)+((l&2081&y)+((z+(l&63454)|0)>>>1)<<1)>>1])&65535}}while(0);n=m+1|0;b[(c[277218]|0)+(n<<1)>>1]=x;b[(c[277218]|0)+(m<<1)>>1]=x;l=a[1108909]|0;a[(c[277219]|0)+n|0]=l;a[(c[277219]|0)+m|0]=l;s=a[1108908]|0;t=c[277219]|0}else{s=q;t=o}}while(0);o=m+2|0;do{if((s&255)>(d[t+o|0]|0)){q=a[r+1|0]|0;l=q&255;if(q<<24>>24==0){B=s;C=t;break}do{if((a[1108928]|0)==0){q=b[(c[277225]|0)+(l<<1)>>1]|0;n=q&65535;u=n&63454;if((a[(c[277215]|0)+o|0]&32)==0){v=c[277228]|0;D=(e[(c[277220]|0)+((((v&-2082)+u|0)>>>1)+(n&2081&v)<<1)>>1]|(v^n)&2081)&65535;break}else{n=b[(c[277213]|0)+(o<<1)>>1]|0;D=(((n&63454)+u|0)>>>1)+(n&q&2081)&65535;break}}else{q=e[(c[277225]|0)+(l<<1)>>1]|0;n=(a[(c[277215]|0)+o|0]&32)==0;if(n){u=c[277228]|0;E=u;F=u&-2082}else{u=e[(c[277213]|0)+(o<<1)>>1]|0;E=u;F=u&63454}if(n){G=c[277228]|0}else{G=e[(c[277213]|0)+(o<<1)>>1]|0}D=((G^q)&2081|e[(c[277220]|0)+((q&2081&E)+((F+(q&63454)|0)>>>1)<<1)>>1])&65535}}while(0);l=m+3|0;b[(c[277218]|0)+(l<<1)>>1]=D;b[(c[277218]|0)+(o<<1)>>1]=D;q=a[1108909]|0;a[(c[277219]|0)+l|0]=q;a[(c[277219]|0)+o|0]=q;B=a[1108908]|0;C=c[277219]|0}else{B=s;C=t}}while(0);o=m+4|0;do{if((B&255)>(d[C+o|0]|0)){q=a[r+2|0]|0;l=q&255;if(q<<24>>24==0){H=B;I=C;break}do{if((a[1108928]|0)==0){q=b[(c[277225]|0)+(l<<1)>>1]|0;n=q&65535;u=n&63454;if((a[(c[277215]|0)+o|0]&32)==0){v=c[277228]|0;J=(e[(c[277220]|0)+((((v&-2082)+u|0)>>>1)+(n&2081&v)<<1)>>1]|(v^n)&2081)&65535;break}else{n=b[(c[277213]|0)+(o<<1)>>1]|0;J=(((n&63454)+u|0)>>>1)+(n&q&2081)&65535;break}}else{q=e[(c[277225]|0)+(l<<1)>>1]|0;n=(a[(c[277215]|0)+o|0]&32)==0;if(n){u=c[277228]|0;K=u;L=u&-2082}else{u=e[(c[277213]|0)+(o<<1)>>1]|0;K=u;L=u&63454}if(n){M=c[277228]|0}else{M=e[(c[277213]|0)+(o<<1)>>1]|0}J=((M^q)&2081|e[(c[277220]|0)+((q&2081&K)+((L+(q&63454)|0)>>>1)<<1)>>1])&65535}}while(0);l=m+5|0;b[(c[277218]|0)+(l<<1)>>1]=J;b[(c[277218]|0)+(o<<1)>>1]=J;q=a[1108909]|0;a[(c[277219]|0)+l|0]=q;a[(c[277219]|0)+o|0]=q;H=a[1108908]|0;I=c[277219]|0}else{H=B;I=C}}while(0);o=m+6|0;do{if((H&255)>(d[I+o|0]|0)){q=a[r+3|0]|0;l=q&255;if(q<<24>>24==0){N=H;O=I;break}do{if((a[1108928]|0)==0){q=b[(c[277225]|0)+(l<<1)>>1]|0;n=q&65535;u=n&63454;if((a[(c[277215]|0)+o|0]&32)==0){v=c[277228]|0;P=(e[(c[277220]|0)+((((v&-2082)+u|0)>>>1)+(n&2081&v)<<1)>>1]|(v^n)&2081)&65535;break}else{n=b[(c[277213]|0)+(o<<1)>>1]|0;P=(((n&63454)+u|0)>>>1)+(n&q&2081)&65535;break}}else{q=e[(c[277225]|0)+(l<<1)>>1]|0;n=(a[(c[277215]|0)+o|0]&32)==0;if(n){u=c[277228]|0;Q=u;R=u&-2082}else{u=e[(c[277213]|0)+(o<<1)>>1]|0;Q=u;R=u&63454}if(n){S=c[277228]|0}else{S=e[(c[277213]|0)+(o<<1)>>1]|0}P=((S^q)&2081|e[(c[277220]|0)+((q&2081&Q)+((R+(q&63454)|0)>>>1)<<1)>>1])&65535}}while(0);l=m+7|0;b[(c[277218]|0)+(l<<1)>>1]=P;b[(c[277218]|0)+(o<<1)>>1]=P;q=a[1108909]|0;a[(c[277219]|0)+l|0]=q;a[(c[277219]|0)+o|0]=q;N=a[1108908]|0;O=c[277219]|0}else{N=H;O=I}}while(0);o=m+8|0;do{if((N&255)>(d[O+o|0]|0)){q=a[r+4|0]|0;l=q&255;if(q<<24>>24==0){T=N;U=O;break}do{if((a[1108928]|0)==0){q=b[(c[277225]|0)+(l<<1)>>1]|0;n=q&65535;u=n&63454;if((a[(c[277215]|0)+o|0]&32)==0){v=c[277228]|0;V=(e[(c[277220]|0)+((((v&-2082)+u|0)>>>1)+(n&2081&v)<<1)>>1]|(v^n)&2081)&65535;break}else{n=b[(c[277213]|0)+(o<<1)>>1]|0;V=(((n&63454)+u|0)>>>1)+(n&q&2081)&65535;break}}else{q=e[(c[277225]|0)+(l<<1)>>1]|0;n=(a[(c[277215]|0)+o|0]&32)==0;if(n){u=c[277228]|0;W=u;X=u&-2082}else{u=e[(c[277213]|0)+(o<<1)>>1]|0;W=u;X=u&63454}if(n){Y=c[277228]|0}else{Y=e[(c[277213]|0)+(o<<1)>>1]|0}V=((Y^q)&2081|e[(c[277220]|0)+((q&2081&W)+((X+(q&63454)|0)>>>1)<<1)>>1])&65535}}while(0);l=m+9|0;b[(c[277218]|0)+(l<<1)>>1]=V;b[(c[277218]|0)+(o<<1)>>1]=V;q=a[1108909]|0;a[(c[277219]|0)+l|0]=q;a[(c[277219]|0)+o|0]=q;T=a[1108908]|0;U=c[277219]|0}else{T=N;U=O}}while(0);o=m+10|0;do{if((T&255)>(d[U+o|0]|0)){q=a[r+5|0]|0;l=q&255;if(q<<24>>24==0){Z=T;_=U;break}do{if((a[1108928]|0)==0){q=b[(c[277225]|0)+(l<<1)>>1]|0;n=q&65535;u=n&63454;if((a[(c[277215]|0)+o|0]&32)==0){v=c[277228]|0;$=(e[(c[277220]|0)+((((v&-2082)+u|0)>>>1)+(n&2081&v)<<1)>>1]|(v^n)&2081)&65535;break}else{n=b[(c[277213]|0)+(o<<1)>>1]|0;$=(((n&63454)+u|0)>>>1)+(n&q&2081)&65535;break}}else{q=e[(c[277225]|0)+(l<<1)>>1]|0;n=(a[(c[277215]|0)+o|0]&32)==0;if(n){u=c[277228]|0;aa=u;ab=u&-2082}else{u=e[(c[277213]|0)+(o<<1)>>1]|0;aa=u;ab=u&63454}if(n){ac=c[277228]|0}else{ac=e[(c[277213]|0)+(o<<1)>>1]|0}$=((ac^q)&2081|e[(c[277220]|0)+((q&2081&aa)+((ab+(q&63454)|0)>>>1)<<1)>>1])&65535}}while(0);l=m+11|0;b[(c[277218]|0)+(l<<1)>>1]=$;b[(c[277218]|0)+(o<<1)>>1]=$;q=a[1108909]|0;a[(c[277219]|0)+l|0]=q;a[(c[277219]|0)+o|0]=q;Z=a[1108908]|0;_=c[277219]|0}else{Z=T;_=U}}while(0);o=m+12|0;do{if((Z&255)>(d[_+o|0]|0)){q=a[r+6|0]|0;l=q&255;if(q<<24>>24==0){ad=Z;ae=_;break}do{if((a[1108928]|0)==0){q=b[(c[277225]|0)+(l<<1)>>1]|0;n=q&65535;u=n&63454;if((a[(c[277215]|0)+o|0]&32)==0){v=c[277228]|0;af=(e[(c[277220]|0)+((((v&-2082)+u|0)>>>1)+(n&2081&v)<<1)>>1]|(v^n)&2081)&65535;break}else{n=b[(c[277213]|0)+(o<<1)>>1]|0;af=(((n&63454)+u|0)>>>1)+(n&q&2081)&65535;break}}else{q=e[(c[277225]|0)+(l<<1)>>1]|0;n=(a[(c[277215]|0)+o|0]&32)==0;if(n){u=c[277228]|0;ag=u;ah=u&-2082}else{u=e[(c[277213]|0)+(o<<1)>>1]|0;ag=u;ah=u&63454}if(n){ai=c[277228]|0}else{ai=e[(c[277213]|0)+(o<<1)>>1]|0}af=((ai^q)&2081|e[(c[277220]|0)+((q&2081&ag)+((ah+(q&63454)|0)>>>1)<<1)>>1])&65535}}while(0);l=m+13|0;b[(c[277218]|0)+(l<<1)>>1]=af;b[(c[277218]|0)+(o<<1)>>1]=af;q=a[1108909]|0;a[(c[277219]|0)+l|0]=q;a[(c[277219]|0)+o|0]=q;ad=a[1108908]|0;ae=c[277219]|0}else{ad=Z;ae=_}}while(0);o=m+14|0;do{if((ad&255)>(d[ae+o|0]|0)){q=a[r+7|0]|0;l=q&255;if(q<<24>>24==0){break}do{if((a[1108928]|0)==0){q=b[(c[277225]|0)+(l<<1)>>1]|0;n=q&65535;u=n&63454;if((a[(c[277215]|0)+o|0]&32)==0){v=c[277228]|0;aj=(e[(c[277220]|0)+((((v&-2082)+u|0)>>>1)+(n&2081&v)<<1)>>1]|(v^n)&2081)&65535;break}else{n=b[(c[277213]|0)+(o<<1)>>1]|0;aj=(((n&63454)+u|0)>>>1)+(n&q&2081)&65535;break}}else{q=e[(c[277225]|0)+(l<<1)>>1]|0;n=(a[(c[277215]|0)+o|0]&32)==0;if(n){u=c[277228]|0;ak=u;al=u&-2082}else{u=e[(c[277213]|0)+(o<<1)>>1]|0;ak=u;al=u&63454}if(n){am=c[277228]|0}else{am=e[(c[277213]|0)+(o<<1)>>1]|0}aj=((am^q)&2081|e[(c[277220]|0)+((q&2081&ak)+((al+(q&63454)|0)>>>1)<<1)>>1])&65535}}while(0);l=m+15|0;b[(c[277218]|0)+(l<<1)>>1]=aj;b[(c[277218]|0)+(o<<1)>>1]=aj;q=a[1108909]|0;a[(c[277219]|0)+l|0]=q;a[(c[277219]|0)+o|0]=q}}while(0);o=j-1|0;if((o|0)<=0){break}r=r+8|0;j=o;m=(c[277223]|0)+m|0}return}if((f&32768|0)==0){if((i|0)<=0){return}f=p+h|0;m=i;j=g;while(1){r=a[1108908]|0;aj=c[277219]|0;do{if((r&255)>(d[aj+j|0]|0)){al=a[f+7|0]|0;ak=al&255;if(al<<24>>24==0){an=r;ao=aj;break}do{if((a[1108928]|0)==0){al=b[(c[277225]|0)+(ak<<1)>>1]|0;am=al&65535;ae=am&63454;if((a[(c[277215]|0)+j|0]&32)==0){ad=c[277228]|0;ap=(e[(c[277220]|0)+((((ad&-2082)+ae|0)>>>1)+(am&2081&ad)<<1)>>1]|(ad^am)&2081)&65535;break}else{am=b[(c[277213]|0)+(j<<1)>>1]|0;ap=(((am&63454)+ae|0)>>>1)+(am&al&2081)&65535;break}}else{al=e[(c[277225]|0)+(ak<<1)>>1]|0;am=(a[(c[277215]|0)+j|0]&32)==0;if(am){ae=c[277228]|0;aq=ae;ar=ae&-2082}else{ae=e[(c[277213]|0)+(j<<1)>>1]|0;aq=ae;ar=ae&63454}if(am){as=c[277228]|0}else{as=e[(c[277213]|0)+(j<<1)>>1]|0}ap=((as^al)&2081|e[(c[277220]|0)+((al&2081&aq)+((ar+(al&63454)|0)>>>1)<<1)>>1])&65535}}while(0);ak=j+1|0;b[(c[277218]|0)+(ak<<1)>>1]=ap;b[(c[277218]|0)+(j<<1)>>1]=ap;al=a[1108909]|0;a[(c[277219]|0)+ak|0]=al;a[(c[277219]|0)+j|0]=al;an=a[1108908]|0;ao=c[277219]|0}else{an=r;ao=aj}}while(0);aj=j+2|0;do{if((an&255)>(d[ao+aj|0]|0)){r=a[f+6|0]|0;al=r&255;if(r<<24>>24==0){at=an;au=ao;break}do{if((a[1108928]|0)==0){r=b[(c[277225]|0)+(al<<1)>>1]|0;ak=r&65535;am=ak&63454;if((a[(c[277215]|0)+aj|0]&32)==0){ae=c[277228]|0;av=(e[(c[277220]|0)+((((ae&-2082)+am|0)>>>1)+(ak&2081&ae)<<1)>>1]|(ae^ak)&2081)&65535;break}else{ak=b[(c[277213]|0)+(aj<<1)>>1]|0;av=(((ak&63454)+am|0)>>>1)+(ak&r&2081)&65535;break}}else{r=e[(c[277225]|0)+(al<<1)>>1]|0;ak=(a[(c[277215]|0)+aj|0]&32)==0;if(ak){am=c[277228]|0;aw=am;ax=am&-2082}else{am=e[(c[277213]|0)+(aj<<1)>>1]|0;aw=am;ax=am&63454}if(ak){ay=c[277228]|0}else{ay=e[(c[277213]|0)+(aj<<1)>>1]|0}av=((ay^r)&2081|e[(c[277220]|0)+((r&2081&aw)+((ax+(r&63454)|0)>>>1)<<1)>>1])&65535}}while(0);al=j+3|0;b[(c[277218]|0)+(al<<1)>>1]=av;b[(c[277218]|0)+(aj<<1)>>1]=av;r=a[1108909]|0;a[(c[277219]|0)+al|0]=r;a[(c[277219]|0)+aj|0]=r;at=a[1108908]|0;au=c[277219]|0}else{at=an;au=ao}}while(0);aj=j+4|0;do{if((at&255)>(d[au+aj|0]|0)){r=a[f+5|0]|0;al=r&255;if(r<<24>>24==0){az=at;aA=au;break}do{if((a[1108928]|0)==0){r=b[(c[277225]|0)+(al<<1)>>1]|0;ak=r&65535;am=ak&63454;if((a[(c[277215]|0)+aj|0]&32)==0){ae=c[277228]|0;aB=(e[(c[277220]|0)+((((ae&-2082)+am|0)>>>1)+(ak&2081&ae)<<1)>>1]|(ae^ak)&2081)&65535;break}else{ak=b[(c[277213]|0)+(aj<<1)>>1]|0;aB=(((ak&63454)+am|0)>>>1)+(ak&r&2081)&65535;break}}else{r=e[(c[277225]|0)+(al<<1)>>1]|0;ak=(a[(c[277215]|0)+aj|0]&32)==0;if(ak){am=c[277228]|0;aC=am;aD=am&-2082}else{am=e[(c[277213]|0)+(aj<<1)>>1]|0;aC=am;aD=am&63454}if(ak){aE=c[277228]|0}else{aE=e[(c[277213]|0)+(aj<<1)>>1]|0}aB=((aE^r)&2081|e[(c[277220]|0)+((r&2081&aC)+((aD+(r&63454)|0)>>>1)<<1)>>1])&65535}}while(0);al=j+5|0;b[(c[277218]|0)+(al<<1)>>1]=aB;b[(c[277218]|0)+(aj<<1)>>1]=aB;r=a[1108909]|0;a[(c[277219]|0)+al|0]=r;a[(c[277219]|0)+aj|0]=r;az=a[1108908]|0;aA=c[277219]|0}else{az=at;aA=au}}while(0);aj=j+6|0;do{if((az&255)>(d[aA+aj|0]|0)){r=a[f+4|0]|0;al=r&255;if(r<<24>>24==0){aF=az;aG=aA;break}do{if((a[1108928]|0)==0){r=b[(c[277225]|0)+(al<<1)>>1]|0;ak=r&65535;am=ak&63454;if((a[(c[277215]|0)+aj|0]&32)==0){ae=c[277228]|0;aH=(e[(c[277220]|0)+((((ae&-2082)+am|0)>>>1)+(ak&2081&ae)<<1)>>1]|(ae^ak)&2081)&65535;break}else{ak=b[(c[277213]|0)+(aj<<1)>>1]|0;aH=(((ak&63454)+am|0)>>>1)+(ak&r&2081)&65535;break}}else{r=e[(c[277225]|0)+(al<<1)>>1]|0;ak=(a[(c[277215]|0)+aj|0]&32)==0;if(ak){am=c[277228]|0;aI=am;aJ=am&-2082}else{am=e[(c[277213]|0)+(aj<<1)>>1]|0;aI=am;aJ=am&63454}if(ak){aK=c[277228]|0}else{aK=e[(c[277213]|0)+(aj<<1)>>1]|0}aH=((aK^r)&2081|e[(c[277220]|0)+((r&2081&aI)+((aJ+(r&63454)|0)>>>1)<<1)>>1])&65535}}while(0);al=j+7|0;b[(c[277218]|0)+(al<<1)>>1]=aH;b[(c[277218]|0)+(aj<<1)>>1]=aH;r=a[1108909]|0;a[(c[277219]|0)+al|0]=r;a[(c[277219]|0)+aj|0]=r;aF=a[1108908]|0;aG=c[277219]|0}else{aF=az;aG=aA}}while(0);aj=j+8|0;do{if((aF&255)>(d[aG+aj|0]|0)){r=a[f+3|0]|0;al=r&255;if(r<<24>>24==0){aL=aF;aM=aG;break}do{if((a[1108928]|0)==0){r=b[(c[277225]|0)+(al<<1)>>1]|0;ak=r&65535;am=ak&63454;if((a[(c[277215]|0)+aj|0]&32)==0){ae=c[277228]|0;aN=(e[(c[277220]|0)+((((ae&-2082)+am|0)>>>1)+(ak&2081&ae)<<1)>>1]|(ae^ak)&2081)&65535;break}else{ak=b[(c[277213]|0)+(aj<<1)>>1]|0;aN=(((ak&63454)+am|0)>>>1)+(ak&r&2081)&65535;break}}else{r=e[(c[277225]|0)+(al<<1)>>1]|0;ak=(a[(c[277215]|0)+aj|0]&32)==0;if(ak){am=c[277228]|0;aO=am;aP=am&-2082}else{am=e[(c[277213]|0)+(aj<<1)>>1]|0;aO=am;aP=am&63454}if(ak){aQ=c[277228]|0}else{aQ=e[(c[277213]|0)+(aj<<1)>>1]|0}aN=((aQ^r)&2081|e[(c[277220]|0)+((r&2081&aO)+((aP+(r&63454)|0)>>>1)<<1)>>1])&65535}}while(0);al=j+9|0;b[(c[277218]|0)+(al<<1)>>1]=aN;b[(c[277218]|0)+(aj<<1)>>1]=aN;r=a[1108909]|0;a[(c[277219]|0)+al|0]=r;a[(c[277219]|0)+aj|0]=r;aL=a[1108908]|0;aM=c[277219]|0}else{aL=aF;aM=aG}}while(0);aj=j+10|0;do{if((aL&255)>(d[aM+aj|0]|0)){r=a[f+2|0]|0;al=r&255;if(r<<24>>24==0){aR=aL;aS=aM;break}do{if((a[1108928]|0)==0){r=b[(c[277225]|0)+(al<<1)>>1]|0;ak=r&65535;am=ak&63454;if((a[(c[277215]|0)+aj|0]&32)==0){ae=c[277228]|0;aT=(e[(c[277220]|0)+((((ae&-2082)+am|0)>>>1)+(ak&2081&ae)<<1)>>1]|(ae^ak)&2081)&65535;break}else{ak=b[(c[277213]|0)+(aj<<1)>>1]|0;aT=(((ak&63454)+am|0)>>>1)+(ak&r&2081)&65535;break}}else{r=e[(c[277225]|0)+(al<<1)>>1]|0;ak=(a[(c[277215]|0)+aj|0]&32)==0;if(ak){am=c[277228]|0;aU=am;aV=am&-2082}else{am=e[(c[277213]|0)+(aj<<1)>>1]|0;aU=am;aV=am&63454}if(ak){aW=c[277228]|0}else{aW=e[(c[277213]|0)+(aj<<1)>>1]|0}aT=((aW^r)&2081|e[(c[277220]|0)+((r&2081&aU)+((aV+(r&63454)|0)>>>1)<<1)>>1])&65535}}while(0);al=j+11|0;b[(c[277218]|0)+(al<<1)>>1]=aT;b[(c[277218]|0)+(aj<<1)>>1]=aT;r=a[1108909]|0;a[(c[277219]|0)+al|0]=r;a[(c[277219]|0)+aj|0]=r;aR=a[1108908]|0;aS=c[277219]|0}else{aR=aL;aS=aM}}while(0);aj=j+12|0;do{if((aR&255)>(d[aS+aj|0]|0)){r=a[f+1|0]|0;al=r&255;if(r<<24>>24==0){aX=aR;aY=aS;break}do{if((a[1108928]|0)==0){r=b[(c[277225]|0)+(al<<1)>>1]|0;ak=r&65535;am=ak&63454;if((a[(c[277215]|0)+aj|0]&32)==0){ae=c[277228]|0;aZ=(e[(c[277220]|0)+((((ae&-2082)+am|0)>>>1)+(ak&2081&ae)<<1)>>1]|(ae^ak)&2081)&65535;break}else{ak=b[(c[277213]|0)+(aj<<1)>>1]|0;aZ=(((ak&63454)+am|0)>>>1)+(ak&r&2081)&65535;break}}else{r=e[(c[277225]|0)+(al<<1)>>1]|0;ak=(a[(c[277215]|0)+aj|0]&32)==0;if(ak){am=c[277228]|0;a_=am;a$=am&-2082}else{am=e[(c[277213]|0)+(aj<<1)>>1]|0;a_=am;a$=am&63454}if(ak){a0=c[277228]|0}else{a0=e[(c[277213]|0)+(aj<<1)>>1]|0}aZ=((a0^r)&2081|e[(c[277220]|0)+((r&2081&a_)+((a$+(r&63454)|0)>>>1)<<1)>>1])&65535}}while(0);al=j+13|0;b[(c[277218]|0)+(al<<1)>>1]=aZ;b[(c[277218]|0)+(aj<<1)>>1]=aZ;r=a[1108909]|0;a[(c[277219]|0)+al|0]=r;a[(c[277219]|0)+aj|0]=r;aX=a[1108908]|0;aY=c[277219]|0}else{aX=aR;aY=aS}}while(0);aj=j+14|0;do{if((aX&255)>(d[aY+aj|0]|0)){r=a[f]|0;al=r&255;if(r<<24>>24==0){break}do{if((a[1108928]|0)==0){r=b[(c[277225]|0)+(al<<1)>>1]|0;ak=r&65535;am=ak&63454;if((a[(c[277215]|0)+aj|0]&32)==0){ae=c[277228]|0;a1=(e[(c[277220]|0)+((((ae&-2082)+am|0)>>>1)+(ak&2081&ae)<<1)>>1]|(ae^ak)&2081)&65535;break}else{ak=b[(c[277213]|0)+(aj<<1)>>1]|0;a1=(((ak&63454)+am|0)>>>1)+(ak&r&2081)&65535;break}}else{r=e[(c[277225]|0)+(al<<1)>>1]|0;ak=(a[(c[277215]|0)+aj|0]&32)==0;if(ak){am=c[277228]|0;a2=am;a3=am&-2082}else{am=e[(c[277213]|0)+(aj<<1)>>1]|0;a2=am;a3=am&63454}if(ak){a4=c[277228]|0}else{a4=e[(c[277213]|0)+(aj<<1)>>1]|0}a1=((a4^r)&2081|e[(c[277220]|0)+((r&2081&a2)+((a3+(r&63454)|0)>>>1)<<1)>>1])&65535}}while(0);al=j+15|0;b[(c[277218]|0)+(al<<1)>>1]=a1;b[(c[277218]|0)+(aj<<1)>>1]=a1;r=a[1108909]|0;a[(c[277219]|0)+al|0]=r;a[(c[277219]|0)+aj|0]=r}}while(0);aj=m-1|0;if((aj|0)<=0){break}f=f+8|0;m=aj;j=(c[277223]|0)+j|0}return}j=p+(56-h)|0;h=(i|0)>0;if(k){if(h){a5=j;a6=i;a7=g}else{return}while(1){k=a[1108908]|0;p=c[277219]|0;do{if((k&255)>(d[p+a7|0]|0)){m=a[a5+7|0]|0;f=m&255;if(m<<24>>24==0){a8=k;a9=p;break}do{if((a[1108928]|0)==0){m=b[(c[277225]|0)+(f<<1)>>1]|0;a1=m&65535;a3=a1&63454;if((a[(c[277215]|0)+a7|0]&32)==0){a2=c[277228]|0;ba=(e[(c[277220]|0)+((((a2&-2082)+a3|0)>>>1)+(a1&2081&a2)<<1)>>1]|(a2^a1)&2081)&65535;break}else{a1=b[(c[277213]|0)+(a7<<1)>>1]|0;ba=(((a1&63454)+a3|0)>>>1)+(a1&m&2081)&65535;break}}else{m=e[(c[277225]|0)+(f<<1)>>1]|0;a1=(a[(c[277215]|0)+a7|0]&32)==0;if(a1){a3=c[277228]|0;bb=a3;bc=a3&-2082}else{a3=e[(c[277213]|0)+(a7<<1)>>1]|0;bb=a3;bc=a3&63454}if(a1){bd=c[277228]|0}else{bd=e[(c[277213]|0)+(a7<<1)>>1]|0}ba=((bd^m)&2081|e[(c[277220]|0)+((m&2081&bb)+((bc+(m&63454)|0)>>>1)<<1)>>1])&65535}}while(0);f=a7+1|0;b[(c[277218]|0)+(f<<1)>>1]=ba;b[(c[277218]|0)+(a7<<1)>>1]=ba;m=a[1108909]|0;a[(c[277219]|0)+f|0]=m;a[(c[277219]|0)+a7|0]=m;a8=a[1108908]|0;a9=c[277219]|0}else{a8=k;a9=p}}while(0);p=a7+2|0;do{if((a8&255)>(d[a9+p|0]|0)){k=a[a5+6|0]|0;m=k&255;if(k<<24>>24==0){be=a8;bf=a9;break}do{if((a[1108928]|0)==0){k=b[(c[277225]|0)+(m<<1)>>1]|0;f=k&65535;a1=f&63454;if((a[(c[277215]|0)+p|0]&32)==0){a3=c[277228]|0;bg=(e[(c[277220]|0)+((((a3&-2082)+a1|0)>>>1)+(f&2081&a3)<<1)>>1]|(a3^f)&2081)&65535;break}else{f=b[(c[277213]|0)+(p<<1)>>1]|0;bg=(((f&63454)+a1|0)>>>1)+(f&k&2081)&65535;break}}else{k=e[(c[277225]|0)+(m<<1)>>1]|0;f=(a[(c[277215]|0)+p|0]&32)==0;if(f){a1=c[277228]|0;bh=a1;bi=a1&-2082}else{a1=e[(c[277213]|0)+(p<<1)>>1]|0;bh=a1;bi=a1&63454}if(f){bj=c[277228]|0}else{bj=e[(c[277213]|0)+(p<<1)>>1]|0}bg=((bj^k)&2081|e[(c[277220]|0)+((k&2081&bh)+((bi+(k&63454)|0)>>>1)<<1)>>1])&65535}}while(0);m=a7+3|0;b[(c[277218]|0)+(m<<1)>>1]=bg;b[(c[277218]|0)+(p<<1)>>1]=bg;k=a[1108909]|0;a[(c[277219]|0)+m|0]=k;a[(c[277219]|0)+p|0]=k;be=a[1108908]|0;bf=c[277219]|0}else{be=a8;bf=a9}}while(0);p=a7+4|0;do{if((be&255)>(d[bf+p|0]|0)){k=a[a5+5|0]|0;m=k&255;if(k<<24>>24==0){bk=be;bl=bf;break}do{if((a[1108928]|0)==0){k=b[(c[277225]|0)+(m<<1)>>1]|0;f=k&65535;a1=f&63454;if((a[(c[277215]|0)+p|0]&32)==0){a3=c[277228]|0;bm=(e[(c[277220]|0)+((((a3&-2082)+a1|0)>>>1)+(f&2081&a3)<<1)>>1]|(a3^f)&2081)&65535;break}else{f=b[(c[277213]|0)+(p<<1)>>1]|0;bm=(((f&63454)+a1|0)>>>1)+(f&k&2081)&65535;break}}else{k=e[(c[277225]|0)+(m<<1)>>1]|0;f=(a[(c[277215]|0)+p|0]&32)==0;if(f){a1=c[277228]|0;bn=a1;bo=a1&-2082}else{a1=e[(c[277213]|0)+(p<<1)>>1]|0;bn=a1;bo=a1&63454}if(f){bp=c[277228]|0}else{bp=e[(c[277213]|0)+(p<<1)>>1]|0}bm=((bp^k)&2081|e[(c[277220]|0)+((k&2081&bn)+((bo+(k&63454)|0)>>>1)<<1)>>1])&65535}}while(0);m=a7+5|0;b[(c[277218]|0)+(m<<1)>>1]=bm;b[(c[277218]|0)+(p<<1)>>1]=bm;k=a[1108909]|0;a[(c[277219]|0)+m|0]=k;a[(c[277219]|0)+p|0]=k;bk=a[1108908]|0;bl=c[277219]|0}else{bk=be;bl=bf}}while(0);p=a7+6|0;do{if((bk&255)>(d[bl+p|0]|0)){k=a[a5+4|0]|0;m=k&255;if(k<<24>>24==0){bq=bk;br=bl;break}do{if((a[1108928]|0)==0){k=b[(c[277225]|0)+(m<<1)>>1]|0;f=k&65535;a1=f&63454;if((a[(c[277215]|0)+p|0]&32)==0){a3=c[277228]|0;bs=(e[(c[277220]|0)+((((a3&-2082)+a1|0)>>>1)+(f&2081&a3)<<1)>>1]|(a3^f)&2081)&65535;break}else{f=b[(c[277213]|0)+(p<<1)>>1]|0;bs=(((f&63454)+a1|0)>>>1)+(f&k&2081)&65535;break}}else{k=e[(c[277225]|0)+(m<<1)>>1]|0;f=(a[(c[277215]|0)+p|0]&32)==0;if(f){a1=c[277228]|0;bt=a1;bu=a1&-2082}else{a1=e[(c[277213]|0)+(p<<1)>>1]|0;bt=a1;bu=a1&63454}if(f){bv=c[277228]|0}else{bv=e[(c[277213]|0)+(p<<1)>>1]|0}bs=((bv^k)&2081|e[(c[277220]|0)+((k&2081&bt)+((bu+(k&63454)|0)>>>1)<<1)>>1])&65535}}while(0);m=a7+7|0;b[(c[277218]|0)+(m<<1)>>1]=bs;b[(c[277218]|0)+(p<<1)>>1]=bs;k=a[1108909]|0;a[(c[277219]|0)+m|0]=k;a[(c[277219]|0)+p|0]=k;bq=a[1108908]|0;br=c[277219]|0}else{bq=bk;br=bl}}while(0);p=a7+8|0;do{if((bq&255)>(d[br+p|0]|0)){k=a[a5+3|0]|0;m=k&255;if(k<<24>>24==0){bw=bq;bx=br;break}do{if((a[1108928]|0)==0){k=b[(c[277225]|0)+(m<<1)>>1]|0;f=k&65535;a1=f&63454;if((a[(c[277215]|0)+p|0]&32)==0){a3=c[277228]|0;by=(e[(c[277220]|0)+((((a3&-2082)+a1|0)>>>1)+(f&2081&a3)<<1)>>1]|(a3^f)&2081)&65535;break}else{f=b[(c[277213]|0)+(p<<1)>>1]|0;by=(((f&63454)+a1|0)>>>1)+(f&k&2081)&65535;break}}else{k=e[(c[277225]|0)+(m<<1)>>1]|0;f=(a[(c[277215]|0)+p|0]&32)==0;if(f){a1=c[277228]|0;bz=a1;bA=a1&-2082}else{a1=e[(c[277213]|0)+(p<<1)>>1]|0;bz=a1;bA=a1&63454}if(f){bB=c[277228]|0}else{bB=e[(c[277213]|0)+(p<<1)>>1]|0}by=((bB^k)&2081|e[(c[277220]|0)+((k&2081&bz)+((bA+(k&63454)|0)>>>1)<<1)>>1])&65535}}while(0);m=a7+9|0;b[(c[277218]|0)+(m<<1)>>1]=by;b[(c[277218]|0)+(p<<1)>>1]=by;k=a[1108909]|0;a[(c[277219]|0)+m|0]=k;a[(c[277219]|0)+p|0]=k;bw=a[1108908]|0;bx=c[277219]|0}else{bw=bq;bx=br}}while(0);p=a7+10|0;do{if((bw&255)>(d[bx+p|0]|0)){k=a[a5+2|0]|0;m=k&255;if(k<<24>>24==0){bC=bw;bD=bx;break}do{if((a[1108928]|0)==0){k=b[(c[277225]|0)+(m<<1)>>1]|0;f=k&65535;a1=f&63454;if((a[(c[277215]|0)+p|0]&32)==0){a3=c[277228]|0;bE=(e[(c[277220]|0)+((((a3&-2082)+a1|0)>>>1)+(f&2081&a3)<<1)>>1]|(a3^f)&2081)&65535;break}else{f=b[(c[277213]|0)+(p<<1)>>1]|0;bE=(((f&63454)+a1|0)>>>1)+(f&k&2081)&65535;break}}else{k=e[(c[277225]|0)+(m<<1)>>1]|0;f=(a[(c[277215]|0)+p|0]&32)==0;if(f){a1=c[277228]|0;bF=a1;bG=a1&-2082}else{a1=e[(c[277213]|0)+(p<<1)>>1]|0;bF=a1;bG=a1&63454}if(f){bH=c[277228]|0}else{bH=e[(c[277213]|0)+(p<<1)>>1]|0}bE=((bH^k)&2081|e[(c[277220]|0)+((k&2081&bF)+((bG+(k&63454)|0)>>>1)<<1)>>1])&65535}}while(0);m=a7+11|0;b[(c[277218]|0)+(m<<1)>>1]=bE;b[(c[277218]|0)+(p<<1)>>1]=bE;k=a[1108909]|0;a[(c[277219]|0)+m|0]=k;a[(c[277219]|0)+p|0]=k;bC=a[1108908]|0;bD=c[277219]|0}else{bC=bw;bD=bx}}while(0);p=a7+12|0;do{if((bC&255)>(d[bD+p|0]|0)){k=a[a5+1|0]|0;m=k&255;if(k<<24>>24==0){bI=bC;bJ=bD;break}do{if((a[1108928]|0)==0){k=b[(c[277225]|0)+(m<<1)>>1]|0;f=k&65535;a1=f&63454;if((a[(c[277215]|0)+p|0]&32)==0){a3=c[277228]|0;bK=(e[(c[277220]|0)+((((a3&-2082)+a1|0)>>>1)+(f&2081&a3)<<1)>>1]|(a3^f)&2081)&65535;break}else{f=b[(c[277213]|0)+(p<<1)>>1]|0;bK=(((f&63454)+a1|0)>>>1)+(f&k&2081)&65535;break}}else{k=e[(c[277225]|0)+(m<<1)>>1]|0;f=(a[(c[277215]|0)+p|0]&32)==0;if(f){a1=c[277228]|0;bL=a1;bM=a1&-2082}else{a1=e[(c[277213]|0)+(p<<1)>>1]|0;bL=a1;bM=a1&63454}if(f){bN=c[277228]|0}else{bN=e[(c[277213]|0)+(p<<1)>>1]|0}bK=((bN^k)&2081|e[(c[277220]|0)+((k&2081&bL)+((bM+(k&63454)|0)>>>1)<<1)>>1])&65535}}while(0);m=a7+13|0;b[(c[277218]|0)+(m<<1)>>1]=bK;b[(c[277218]|0)+(p<<1)>>1]=bK;k=a[1108909]|0;a[(c[277219]|0)+m|0]=k;a[(c[277219]|0)+p|0]=k;bI=a[1108908]|0;bJ=c[277219]|0}else{bI=bC;bJ=bD}}while(0);p=a7+14|0;do{if((bI&255)>(d[bJ+p|0]|0)){k=a[a5]|0;m=k&255;if(k<<24>>24==0){break}do{if((a[1108928]|0)==0){k=b[(c[277225]|0)+(m<<1)>>1]|0;f=k&65535;a1=f&63454;if((a[(c[277215]|0)+p|0]&32)==0){a3=c[277228]|0;bO=(e[(c[277220]|0)+((((a3&-2082)+a1|0)>>>1)+(f&2081&a3)<<1)>>1]|(a3^f)&2081)&65535;break}else{f=b[(c[277213]|0)+(p<<1)>>1]|0;bO=(((f&63454)+a1|0)>>>1)+(f&k&2081)&65535;break}}else{k=e[(c[277225]|0)+(m<<1)>>1]|0;f=(a[(c[277215]|0)+p|0]&32)==0;if(f){a1=c[277228]|0;bP=a1;bQ=a1&-2082}else{a1=e[(c[277213]|0)+(p<<1)>>1]|0;bP=a1;bQ=a1&63454}if(f){bR=c[277228]|0}else{bR=e[(c[277213]|0)+(p<<1)>>1]|0}bO=((bR^k)&2081|e[(c[277220]|0)+((k&2081&bP)+((bQ+(k&63454)|0)>>>1)<<1)>>1])&65535}}while(0);m=a7+15|0;b[(c[277218]|0)+(m<<1)>>1]=bO;b[(c[277218]|0)+(p<<1)>>1]=bO;k=a[1108909]|0;a[(c[277219]|0)+m|0]=k;a[(c[277219]|0)+p|0]=k}}while(0);p=a6-1|0;if((p|0)<=0){break}a5=a5-8|0;a6=p;a7=(c[277223]|0)+a7|0}return}else{if(h){bS=j;bT=i;bU=g}else{return}while(1){g=a[1108908]|0;i=c[277219]|0;do{if((g&255)>(d[i+bU|0]|0)){j=a[bS]|0;h=j&255;if(j<<24>>24==0){bV=g;bW=i;break}do{if((a[1108928]|0)==0){j=b[(c[277225]|0)+(h<<1)>>1]|0;a7=j&65535;a6=a7&63454;if((a[(c[277215]|0)+bU|0]&32)==0){a5=c[277228]|0;bX=(e[(c[277220]|0)+((((a5&-2082)+a6|0)>>>1)+(a7&2081&a5)<<1)>>1]|(a5^a7)&2081)&65535;break}else{a7=b[(c[277213]|0)+(bU<<1)>>1]|0;bX=(((a7&63454)+a6|0)>>>1)+(a7&j&2081)&65535;break}}else{j=e[(c[277225]|0)+(h<<1)>>1]|0;a7=(a[(c[277215]|0)+bU|0]&32)==0;if(a7){a6=c[277228]|0;bY=a6;bZ=a6&-2082}else{a6=e[(c[277213]|0)+(bU<<1)>>1]|0;bY=a6;bZ=a6&63454}if(a7){b_=c[277228]|0}else{b_=e[(c[277213]|0)+(bU<<1)>>1]|0}bX=((b_^j)&2081|e[(c[277220]|0)+((j&2081&bY)+((bZ+(j&63454)|0)>>>1)<<1)>>1])&65535}}while(0);h=bU+1|0;b[(c[277218]|0)+(h<<1)>>1]=bX;b[(c[277218]|0)+(bU<<1)>>1]=bX;j=a[1108909]|0;a[(c[277219]|0)+h|0]=j;a[(c[277219]|0)+bU|0]=j;bV=a[1108908]|0;bW=c[277219]|0}else{bV=g;bW=i}}while(0);i=bU+2|0;do{if((bV&255)>(d[bW+i|0]|0)){g=a[bS+1|0]|0;j=g&255;if(g<<24>>24==0){b$=bV;b0=bW;break}do{if((a[1108928]|0)==0){g=b[(c[277225]|0)+(j<<1)>>1]|0;h=g&65535;a7=h&63454;if((a[(c[277215]|0)+i|0]&32)==0){a6=c[277228]|0;b1=(e[(c[277220]|0)+((((a6&-2082)+a7|0)>>>1)+(h&2081&a6)<<1)>>1]|(a6^h)&2081)&65535;break}else{h=b[(c[277213]|0)+(i<<1)>>1]|0;b1=(((h&63454)+a7|0)>>>1)+(h&g&2081)&65535;break}}else{g=e[(c[277225]|0)+(j<<1)>>1]|0;h=(a[(c[277215]|0)+i|0]&32)==0;if(h){a7=c[277228]|0;b2=a7;b3=a7&-2082}else{a7=e[(c[277213]|0)+(i<<1)>>1]|0;b2=a7;b3=a7&63454}if(h){b4=c[277228]|0}else{b4=e[(c[277213]|0)+(i<<1)>>1]|0}b1=((b4^g)&2081|e[(c[277220]|0)+((g&2081&b2)+((b3+(g&63454)|0)>>>1)<<1)>>1])&65535}}while(0);j=bU+3|0;b[(c[277218]|0)+(j<<1)>>1]=b1;b[(c[277218]|0)+(i<<1)>>1]=b1;g=a[1108909]|0;a[(c[277219]|0)+j|0]=g;a[(c[277219]|0)+i|0]=g;b$=a[1108908]|0;b0=c[277219]|0}else{b$=bV;b0=bW}}while(0);i=bU+4|0;do{if((b$&255)>(d[b0+i|0]|0)){g=a[bS+2|0]|0;j=g&255;if(g<<24>>24==0){b5=b$;b6=b0;break}do{if((a[1108928]|0)==0){g=b[(c[277225]|0)+(j<<1)>>1]|0;h=g&65535;a7=h&63454;if((a[(c[277215]|0)+i|0]&32)==0){a6=c[277228]|0;b7=(e[(c[277220]|0)+((((a6&-2082)+a7|0)>>>1)+(h&2081&a6)<<1)>>1]|(a6^h)&2081)&65535;break}else{h=b[(c[277213]|0)+(i<<1)>>1]|0;b7=(((h&63454)+a7|0)>>>1)+(h&g&2081)&65535;break}}else{g=e[(c[277225]|0)+(j<<1)>>1]|0;h=(a[(c[277215]|0)+i|0]&32)==0;if(h){a7=c[277228]|0;b8=a7;b9=a7&-2082}else{a7=e[(c[277213]|0)+(i<<1)>>1]|0;b8=a7;b9=a7&63454}if(h){ca=c[277228]|0}else{ca=e[(c[277213]|0)+(i<<1)>>1]|0}b7=((ca^g)&2081|e[(c[277220]|0)+((g&2081&b8)+((b9+(g&63454)|0)>>>1)<<1)>>1])&65535}}while(0);j=bU+5|0;b[(c[277218]|0)+(j<<1)>>1]=b7;b[(c[277218]|0)+(i<<1)>>1]=b7;g=a[1108909]|0;a[(c[277219]|0)+j|0]=g;a[(c[277219]|0)+i|0]=g;b5=a[1108908]|0;b6=c[277219]|0}else{b5=b$;b6=b0}}while(0);i=bU+6|0;do{if((b5&255)>(d[b6+i|0]|0)){g=a[bS+3|0]|0;j=g&255;if(g<<24>>24==0){cb=b5;cc=b6;break}do{if((a[1108928]|0)==0){g=b[(c[277225]|0)+(j<<1)>>1]|0;h=g&65535;a7=h&63454;if((a[(c[277215]|0)+i|0]&32)==0){a6=c[277228]|0;cd=(e[(c[277220]|0)+((((a6&-2082)+a7|0)>>>1)+(h&2081&a6)<<1)>>1]|(a6^h)&2081)&65535;break}else{h=b[(c[277213]|0)+(i<<1)>>1]|0;cd=(((h&63454)+a7|0)>>>1)+(h&g&2081)&65535;break}}else{g=e[(c[277225]|0)+(j<<1)>>1]|0;h=(a[(c[277215]|0)+i|0]&32)==0;if(h){a7=c[277228]|0;ce=a7;cf=a7&-2082}else{a7=e[(c[277213]|0)+(i<<1)>>1]|0;ce=a7;cf=a7&63454}if(h){cg=c[277228]|0}else{cg=e[(c[277213]|0)+(i<<1)>>1]|0}cd=((cg^g)&2081|e[(c[277220]|0)+((g&2081&ce)+((cf+(g&63454)|0)>>>1)<<1)>>1])&65535}}while(0);j=bU+7|0;b[(c[277218]|0)+(j<<1)>>1]=cd;b[(c[277218]|0)+(i<<1)>>1]=cd;g=a[1108909]|0;a[(c[277219]|0)+j|0]=g;a[(c[277219]|0)+i|0]=g;cb=a[1108908]|0;cc=c[277219]|0}else{cb=b5;cc=b6}}while(0);i=bU+8|0;do{if((cb&255)>(d[cc+i|0]|0)){g=a[bS+4|0]|0;j=g&255;if(g<<24>>24==0){ch=cb;ci=cc;break}do{if((a[1108928]|0)==0){g=b[(c[277225]|0)+(j<<1)>>1]|0;h=g&65535;a7=h&63454;if((a[(c[277215]|0)+i|0]&32)==0){a6=c[277228]|0;cj=(e[(c[277220]|0)+((((a6&-2082)+a7|0)>>>1)+(h&2081&a6)<<1)>>1]|(a6^h)&2081)&65535;break}else{h=b[(c[277213]|0)+(i<<1)>>1]|0;cj=(((h&63454)+a7|0)>>>1)+(h&g&2081)&65535;break}}else{g=e[(c[277225]|0)+(j<<1)>>1]|0;h=(a[(c[277215]|0)+i|0]&32)==0;if(h){a7=c[277228]|0;ck=a7;cl=a7&-2082}else{a7=e[(c[277213]|0)+(i<<1)>>1]|0;ck=a7;cl=a7&63454}if(h){cm=c[277228]|0}else{cm=e[(c[277213]|0)+(i<<1)>>1]|0}cj=((cm^g)&2081|e[(c[277220]|0)+((g&2081&ck)+((cl+(g&63454)|0)>>>1)<<1)>>1])&65535}}while(0);j=bU+9|0;b[(c[277218]|0)+(j<<1)>>1]=cj;b[(c[277218]|0)+(i<<1)>>1]=cj;g=a[1108909]|0;a[(c[277219]|0)+j|0]=g;a[(c[277219]|0)+i|0]=g;ch=a[1108908]|0;ci=c[277219]|0}else{ch=cb;ci=cc}}while(0);i=bU+10|0;do{if((ch&255)>(d[ci+i|0]|0)){g=a[bS+5|0]|0;j=g&255;if(g<<24>>24==0){cn=ch;co=ci;break}do{if((a[1108928]|0)==0){g=b[(c[277225]|0)+(j<<1)>>1]|0;h=g&65535;a7=h&63454;if((a[(c[277215]|0)+i|0]&32)==0){a6=c[277228]|0;cp=(e[(c[277220]|0)+((((a6&-2082)+a7|0)>>>1)+(h&2081&a6)<<1)>>1]|(a6^h)&2081)&65535;break}else{h=b[(c[277213]|0)+(i<<1)>>1]|0;cp=(((h&63454)+a7|0)>>>1)+(h&g&2081)&65535;break}}else{g=e[(c[277225]|0)+(j<<1)>>1]|0;h=(a[(c[277215]|0)+i|0]&32)==0;if(h){a7=c[277228]|0;cq=a7;cr=a7&-2082}else{a7=e[(c[277213]|0)+(i<<1)>>1]|0;cq=a7;cr=a7&63454}if(h){cs=c[277228]|0}else{cs=e[(c[277213]|0)+(i<<1)>>1]|0}cp=((cs^g)&2081|e[(c[277220]|0)+((g&2081&cq)+((cr+(g&63454)|0)>>>1)<<1)>>1])&65535}}while(0);j=bU+11|0;b[(c[277218]|0)+(j<<1)>>1]=cp;b[(c[277218]|0)+(i<<1)>>1]=cp;g=a[1108909]|0;a[(c[277219]|0)+j|0]=g;a[(c[277219]|0)+i|0]=g;cn=a[1108908]|0;co=c[277219]|0}else{cn=ch;co=ci}}while(0);i=bU+12|0;do{if((cn&255)>(d[co+i|0]|0)){g=a[bS+6|0]|0;j=g&255;if(g<<24>>24==0){ct=cn;cu=co;break}do{if((a[1108928]|0)==0){g=b[(c[277225]|0)+(j<<1)>>1]|0;h=g&65535;a7=h&63454;if((a[(c[277215]|0)+i|0]&32)==0){a6=c[277228]|0;cv=(e[(c[277220]|0)+((((a6&-2082)+a7|0)>>>1)+(h&2081&a6)<<1)>>1]|(a6^h)&2081)&65535;break}else{h=b[(c[277213]|0)+(i<<1)>>1]|0;cv=(((h&63454)+a7|0)>>>1)+(h&g&2081)&65535;break}}else{g=e[(c[277225]|0)+(j<<1)>>1]|0;h=(a[(c[277215]|0)+i|0]&32)==0;if(h){a7=c[277228]|0;cw=a7;cx=a7&-2082}else{a7=e[(c[277213]|0)+(i<<1)>>1]|0;cw=a7;cx=a7&63454}if(h){cy=c[277228]|0}else{cy=e[(c[277213]|0)+(i<<1)>>1]|0}cv=((cy^g)&2081|e[(c[277220]|0)+((g&2081&cw)+((cx+(g&63454)|0)>>>1)<<1)>>1])&65535}}while(0);j=bU+13|0;b[(c[277218]|0)+(j<<1)>>1]=cv;b[(c[277218]|0)+(i<<1)>>1]=cv;g=a[1108909]|0;a[(c[277219]|0)+j|0]=g;a[(c[277219]|0)+i|0]=g;ct=a[1108908]|0;cu=c[277219]|0}else{ct=cn;cu=co}}while(0);i=bU+14|0;do{if((ct&255)>(d[cu+i|0]|0)){g=a[bS+7|0]|0;j=g&255;if(g<<24>>24==0){break}do{if((a[1108928]|0)==0){g=b[(c[277225]|0)+(j<<1)>>1]|0;h=g&65535;a7=h&63454;if((a[(c[277215]|0)+i|0]&32)==0){a6=c[277228]|0;cz=(e[(c[277220]|0)+((((a6&-2082)+a7|0)>>>1)+(h&2081&a6)<<1)>>1]|(a6^h)&2081)&65535;break}else{h=b[(c[277213]|0)+(i<<1)>>1]|0;cz=(((h&63454)+a7|0)>>>1)+(h&g&2081)&65535;break}}else{g=e[(c[277225]|0)+(j<<1)>>1]|0;h=(a[(c[277215]|0)+i|0]&32)==0;if(h){a7=c[277228]|0;cA=a7;cB=a7&-2082}else{a7=e[(c[277213]|0)+(i<<1)>>1]|0;cA=a7;cB=a7&63454}if(h){cC=c[277228]|0}else{cC=e[(c[277213]|0)+(i<<1)>>1]|0}cz=((cC^g)&2081|e[(c[277220]|0)+((g&2081&cA)+((cB+(g&63454)|0)>>>1)<<1)>>1])&65535}}while(0);j=bU+15|0;b[(c[277218]|0)+(j<<1)>>1]=cz;b[(c[277218]|0)+(i<<1)>>1]=cz;g=a[1108909]|0;a[(c[277219]|0)+j|0]=g;a[(c[277219]|0)+i|0]=g}}while(0);i=bT-1|0;if((i|0)<=0){break}bS=bS-8|0;bT=i;bU=(c[277223]|0)+bU|0}return}}function Uy(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0;i=e&1023;j=c[348606]|0;k=(i<<j)+(c[348604]|0)|0;if((e&256|0)==0){l=k}else{l=(c[348602]|0)+k|0}k=l&65535;l=k>>>(j>>>0);j=(e&16384|0)!=0;m=l<<6;do{if(j){n=(c[348622]|0)+m|0;if((a[(c[348618]|0)+l|0]|0)!=0){o=n;break}p=fi[c[348636]&63](n,k,i)|0;a[(c[348618]|0)+l|0]=p;o=n}else{n=(c[348624]|0)+m|0;if((a[(c[348620]|0)+l|0]|0)!=0){o=n;break}p=fi[c[348638]&63](n,k,i)|0;a[(c[348620]|0)+l|0]=p;o=n}}while(0);if((a[(c[348620]|0)+l|0]|0)==2){return}if((a[1394464]|0)==0){q=1106168+((e>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){l=d[1044485]|0;c[276541]=7080+(l<<5);i=0;do{k=i<<1&2;m=i&2;n=i&4;p=0;do{b[1125528+(i<<9)+(p<<1)>>1]=d[(p>>>1&28|m)+(7080+(l<<5))|0]<<6|d[(p<<2&28|k)+(7080+(l<<5))|0]<<11|d[(p>>>3&24|n)+(7080+(l<<5))|0];p=p+1|0;}while(p>>>0<256);i=i+1|0;}while(i>>>0<8);a[1106089]=0}q=1125528+((e>>>10&7)<<9)|0}c[277226]=q;c[277225]=(a[1108928]|0)!=0?1393712:q;if((e&49152|0)==0){if((h|0)<=0){return}q=o+g|0;i=h;l=f;while(1){p=a[1108908]|0;n=c[277219]|0;do{if((p&255)>(d[n+l|0]|0)){k=a[q]|0;if(k<<24>>24==0){r=p;s=n;break}m=b[(c[277225]|0)+((k&255)<<1)>>1]|0;if((a[(c[277215]|0)+l|0]&32)==0){t=c[277228]&65535}else{t=b[(c[277213]|0)+(l<<1)>>1]|0}k=m&-2048;u=t&-2048;v=(k&65535)>(u&65535)?k-u&65535:0;u=m&2016;k=t&2016;if((u&65535)>(k&65535)){w=(u-k&65535)+v&65535}else{w=v}v=m&31;m=t&31;if((v&65535)>(m&65535)){x=(v-m&65535)+w&65535}else{x=w}m=l+1|0;b[(c[277218]|0)+(m<<1)>>1]=x;b[(c[277218]|0)+(l<<1)>>1]=x;v=a[1108909]|0;a[(c[277219]|0)+m|0]=v;a[(c[277219]|0)+l|0]=v;r=a[1108908]|0;s=c[277219]|0}else{r=p;s=n}}while(0);n=l+2|0;do{if((r&255)>(d[s+n|0]|0)){p=a[q+1|0]|0;if(p<<24>>24==0){y=r;z=s;break}v=b[(c[277225]|0)+((p&255)<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)==0){A=c[277228]&65535}else{A=b[(c[277213]|0)+(n<<1)>>1]|0}p=v&-2048;m=A&-2048;k=(p&65535)>(m&65535)?p-m&65535:0;m=v&2016;p=A&2016;if((m&65535)>(p&65535)){B=(m-p&65535)+k&65535}else{B=k}k=v&31;v=A&31;if((k&65535)>(v&65535)){C=(k-v&65535)+B&65535}else{C=B}v=l+3|0;b[(c[277218]|0)+(v<<1)>>1]=C;b[(c[277218]|0)+(n<<1)>>1]=C;k=a[1108909]|0;a[(c[277219]|0)+v|0]=k;a[(c[277219]|0)+n|0]=k;y=a[1108908]|0;z=c[277219]|0}else{y=r;z=s}}while(0);n=l+4|0;do{if((y&255)>(d[z+n|0]|0)){k=a[q+2|0]|0;if(k<<24>>24==0){D=y;E=z;break}v=b[(c[277225]|0)+((k&255)<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)==0){F=c[277228]&65535}else{F=b[(c[277213]|0)+(n<<1)>>1]|0}k=v&-2048;p=F&-2048;m=(k&65535)>(p&65535)?k-p&65535:0;p=v&2016;k=F&2016;if((p&65535)>(k&65535)){G=(p-k&65535)+m&65535}else{G=m}m=v&31;v=F&31;if((m&65535)>(v&65535)){H=(m-v&65535)+G&65535}else{H=G}v=l+5|0;b[(c[277218]|0)+(v<<1)>>1]=H;b[(c[277218]|0)+(n<<1)>>1]=H;m=a[1108909]|0;a[(c[277219]|0)+v|0]=m;a[(c[277219]|0)+n|0]=m;D=a[1108908]|0;E=c[277219]|0}else{D=y;E=z}}while(0);n=l+6|0;do{if((D&255)>(d[E+n|0]|0)){m=a[q+3|0]|0;if(m<<24>>24==0){I=D;J=E;break}v=b[(c[277225]|0)+((m&255)<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)==0){K=c[277228]&65535}else{K=b[(c[277213]|0)+(n<<1)>>1]|0}m=v&-2048;k=K&-2048;p=(m&65535)>(k&65535)?m-k&65535:0;k=v&2016;m=K&2016;if((k&65535)>(m&65535)){L=(k-m&65535)+p&65535}else{L=p}p=v&31;v=K&31;if((p&65535)>(v&65535)){M=(p-v&65535)+L&65535}else{M=L}v=l+7|0;b[(c[277218]|0)+(v<<1)>>1]=M;b[(c[277218]|0)+(n<<1)>>1]=M;p=a[1108909]|0;a[(c[277219]|0)+v|0]=p;a[(c[277219]|0)+n|0]=p;I=a[1108908]|0;J=c[277219]|0}else{I=D;J=E}}while(0);n=l+8|0;do{if((I&255)>(d[J+n|0]|0)){p=a[q+4|0]|0;if(p<<24>>24==0){N=I;O=J;break}v=b[(c[277225]|0)+((p&255)<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)==0){P=c[277228]&65535}else{P=b[(c[277213]|0)+(n<<1)>>1]|0}p=v&-2048;m=P&-2048;k=(p&65535)>(m&65535)?p-m&65535:0;m=v&2016;p=P&2016;if((m&65535)>(p&65535)){Q=(m-p&65535)+k&65535}else{Q=k}k=v&31;v=P&31;if((k&65535)>(v&65535)){R=(k-v&65535)+Q&65535}else{R=Q}v=l+9|0;b[(c[277218]|0)+(v<<1)>>1]=R;b[(c[277218]|0)+(n<<1)>>1]=R;k=a[1108909]|0;a[(c[277219]|0)+v|0]=k;a[(c[277219]|0)+n|0]=k;N=a[1108908]|0;O=c[277219]|0}else{N=I;O=J}}while(0);n=l+10|0;do{if((N&255)>(d[O+n|0]|0)){k=a[q+5|0]|0;if(k<<24>>24==0){S=N;T=O;break}v=b[(c[277225]|0)+((k&255)<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)==0){U=c[277228]&65535}else{U=b[(c[277213]|0)+(n<<1)>>1]|0}k=v&-2048;p=U&-2048;m=(k&65535)>(p&65535)?k-p&65535:0;p=v&2016;k=U&2016;if((p&65535)>(k&65535)){V=(p-k&65535)+m&65535}else{V=m}m=v&31;v=U&31;if((m&65535)>(v&65535)){W=(m-v&65535)+V&65535}else{W=V}v=l+11|0;b[(c[277218]|0)+(v<<1)>>1]=W;b[(c[277218]|0)+(n<<1)>>1]=W;m=a[1108909]|0;a[(c[277219]|0)+v|0]=m;a[(c[277219]|0)+n|0]=m;S=a[1108908]|0;T=c[277219]|0}else{S=N;T=O}}while(0);n=l+12|0;do{if((S&255)>(d[T+n|0]|0)){m=a[q+6|0]|0;if(m<<24>>24==0){X=S;Y=T;break}v=b[(c[277225]|0)+((m&255)<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)==0){Z=c[277228]&65535}else{Z=b[(c[277213]|0)+(n<<1)>>1]|0}m=v&-2048;k=Z&-2048;p=(m&65535)>(k&65535)?m-k&65535:0;k=v&2016;m=Z&2016;if((k&65535)>(m&65535)){_=(k-m&65535)+p&65535}else{_=p}p=v&31;v=Z&31;if((p&65535)>(v&65535)){$=(p-v&65535)+_&65535}else{$=_}v=l+13|0;b[(c[277218]|0)+(v<<1)>>1]=$;b[(c[277218]|0)+(n<<1)>>1]=$;p=a[1108909]|0;a[(c[277219]|0)+v|0]=p;a[(c[277219]|0)+n|0]=p;X=a[1108908]|0;Y=c[277219]|0}else{X=S;Y=T}}while(0);n=l+14|0;do{if((X&255)>(d[Y+n|0]|0)){p=a[q+7|0]|0;if(p<<24>>24==0){break}v=b[(c[277225]|0)+((p&255)<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)==0){aa=c[277228]&65535}else{aa=b[(c[277213]|0)+(n<<1)>>1]|0}p=v&-2048;m=aa&-2048;k=(p&65535)>(m&65535)?p-m&65535:0;m=v&2016;p=aa&2016;if((m&65535)>(p&65535)){ab=(m-p&65535)+k&65535}else{ab=k}k=v&31;v=aa&31;if((k&65535)>(v&65535)){ac=(k-v&65535)+ab&65535}else{ac=ab}v=l+15|0;b[(c[277218]|0)+(v<<1)>>1]=ac;b[(c[277218]|0)+(n<<1)>>1]=ac;k=a[1108909]|0;a[(c[277219]|0)+v|0]=k;a[(c[277219]|0)+n|0]=k}}while(0);n=i-1|0;if((n|0)<=0){break}q=q+8|0;i=n;l=(c[277223]|0)+l|0}return}if((e&32768|0)==0){if((h|0)<=0){return}e=o+g|0;l=h;i=f;while(1){q=a[1108908]|0;ac=c[277219]|0;do{if((q&255)>(d[ac+i|0]|0)){ab=a[e+7|0]|0;if(ab<<24>>24==0){ad=q;ae=ac;break}aa=b[(c[277225]|0)+((ab&255)<<1)>>1]|0;if((a[(c[277215]|0)+i|0]&32)==0){af=c[277228]&65535}else{af=b[(c[277213]|0)+(i<<1)>>1]|0}ab=aa&-2048;Y=af&-2048;X=(ab&65535)>(Y&65535)?ab-Y&65535:0;Y=aa&2016;ab=af&2016;if((Y&65535)>(ab&65535)){ag=(Y-ab&65535)+X&65535}else{ag=X}X=aa&31;aa=af&31;if((X&65535)>(aa&65535)){ah=(X-aa&65535)+ag&65535}else{ah=ag}aa=i+1|0;b[(c[277218]|0)+(aa<<1)>>1]=ah;b[(c[277218]|0)+(i<<1)>>1]=ah;X=a[1108909]|0;a[(c[277219]|0)+aa|0]=X;a[(c[277219]|0)+i|0]=X;ad=a[1108908]|0;ae=c[277219]|0}else{ad=q;ae=ac}}while(0);ac=i+2|0;do{if((ad&255)>(d[ae+ac|0]|0)){q=a[e+6|0]|0;if(q<<24>>24==0){ai=ad;aj=ae;break}X=b[(c[277225]|0)+((q&255)<<1)>>1]|0;if((a[(c[277215]|0)+ac|0]&32)==0){ak=c[277228]&65535}else{ak=b[(c[277213]|0)+(ac<<1)>>1]|0}q=X&-2048;aa=ak&-2048;ab=(q&65535)>(aa&65535)?q-aa&65535:0;aa=X&2016;q=ak&2016;if((aa&65535)>(q&65535)){al=(aa-q&65535)+ab&65535}else{al=ab}ab=X&31;X=ak&31;if((ab&65535)>(X&65535)){am=(ab-X&65535)+al&65535}else{am=al}X=i+3|0;b[(c[277218]|0)+(X<<1)>>1]=am;b[(c[277218]|0)+(ac<<1)>>1]=am;ab=a[1108909]|0;a[(c[277219]|0)+X|0]=ab;a[(c[277219]|0)+ac|0]=ab;ai=a[1108908]|0;aj=c[277219]|0}else{ai=ad;aj=ae}}while(0);ac=i+4|0;do{if((ai&255)>(d[aj+ac|0]|0)){ab=a[e+5|0]|0;if(ab<<24>>24==0){an=ai;ao=aj;break}X=b[(c[277225]|0)+((ab&255)<<1)>>1]|0;if((a[(c[277215]|0)+ac|0]&32)==0){ap=c[277228]&65535}else{ap=b[(c[277213]|0)+(ac<<1)>>1]|0}ab=X&-2048;q=ap&-2048;aa=(ab&65535)>(q&65535)?ab-q&65535:0;q=X&2016;ab=ap&2016;if((q&65535)>(ab&65535)){aq=(q-ab&65535)+aa&65535}else{aq=aa}aa=X&31;X=ap&31;if((aa&65535)>(X&65535)){ar=(aa-X&65535)+aq&65535}else{ar=aq}X=i+5|0;b[(c[277218]|0)+(X<<1)>>1]=ar;b[(c[277218]|0)+(ac<<1)>>1]=ar;aa=a[1108909]|0;a[(c[277219]|0)+X|0]=aa;a[(c[277219]|0)+ac|0]=aa;an=a[1108908]|0;ao=c[277219]|0}else{an=ai;ao=aj}}while(0);ac=i+6|0;do{if((an&255)>(d[ao+ac|0]|0)){aa=a[e+4|0]|0;if(aa<<24>>24==0){as=an;at=ao;break}X=b[(c[277225]|0)+((aa&255)<<1)>>1]|0;if((a[(c[277215]|0)+ac|0]&32)==0){au=c[277228]&65535}else{au=b[(c[277213]|0)+(ac<<1)>>1]|0}aa=X&-2048;ab=au&-2048;q=(aa&65535)>(ab&65535)?aa-ab&65535:0;ab=X&2016;aa=au&2016;if((ab&65535)>(aa&65535)){av=(ab-aa&65535)+q&65535}else{av=q}q=X&31;X=au&31;if((q&65535)>(X&65535)){aw=(q-X&65535)+av&65535}else{aw=av}X=i+7|0;b[(c[277218]|0)+(X<<1)>>1]=aw;b[(c[277218]|0)+(ac<<1)>>1]=aw;q=a[1108909]|0;a[(c[277219]|0)+X|0]=q;a[(c[277219]|0)+ac|0]=q;as=a[1108908]|0;at=c[277219]|0}else{as=an;at=ao}}while(0);ac=i+8|0;do{if((as&255)>(d[at+ac|0]|0)){q=a[e+3|0]|0;if(q<<24>>24==0){ax=as;ay=at;break}X=b[(c[277225]|0)+((q&255)<<1)>>1]|0;if((a[(c[277215]|0)+ac|0]&32)==0){az=c[277228]&65535}else{az=b[(c[277213]|0)+(ac<<1)>>1]|0}q=X&-2048;aa=az&-2048;ab=(q&65535)>(aa&65535)?q-aa&65535:0;aa=X&2016;q=az&2016;if((aa&65535)>(q&65535)){aA=(aa-q&65535)+ab&65535}else{aA=ab}ab=X&31;X=az&31;if((ab&65535)>(X&65535)){aB=(ab-X&65535)+aA&65535}else{aB=aA}X=i+9|0;b[(c[277218]|0)+(X<<1)>>1]=aB;b[(c[277218]|0)+(ac<<1)>>1]=aB;ab=a[1108909]|0;a[(c[277219]|0)+X|0]=ab;a[(c[277219]|0)+ac|0]=ab;ax=a[1108908]|0;ay=c[277219]|0}else{ax=as;ay=at}}while(0);ac=i+10|0;do{if((ax&255)>(d[ay+ac|0]|0)){ab=a[e+2|0]|0;if(ab<<24>>24==0){aC=ax;aD=ay;break}X=b[(c[277225]|0)+((ab&255)<<1)>>1]|0;if((a[(c[277215]|0)+ac|0]&32)==0){aE=c[277228]&65535}else{aE=b[(c[277213]|0)+(ac<<1)>>1]|0}ab=X&-2048;q=aE&-2048;aa=(ab&65535)>(q&65535)?ab-q&65535:0;q=X&2016;ab=aE&2016;if((q&65535)>(ab&65535)){aF=(q-ab&65535)+aa&65535}else{aF=aa}aa=X&31;X=aE&31;if((aa&65535)>(X&65535)){aG=(aa-X&65535)+aF&65535}else{aG=aF}X=i+11|0;b[(c[277218]|0)+(X<<1)>>1]=aG;b[(c[277218]|0)+(ac<<1)>>1]=aG;aa=a[1108909]|0;a[(c[277219]|0)+X|0]=aa;a[(c[277219]|0)+ac|0]=aa;aC=a[1108908]|0;aD=c[277219]|0}else{aC=ax;aD=ay}}while(0);ac=i+12|0;do{if((aC&255)>(d[aD+ac|0]|0)){aa=a[e+1|0]|0;if(aa<<24>>24==0){aH=aC;aI=aD;break}X=b[(c[277225]|0)+((aa&255)<<1)>>1]|0;if((a[(c[277215]|0)+ac|0]&32)==0){aJ=c[277228]&65535}else{aJ=b[(c[277213]|0)+(ac<<1)>>1]|0}aa=X&-2048;ab=aJ&-2048;q=(aa&65535)>(ab&65535)?aa-ab&65535:0;ab=X&2016;aa=aJ&2016;if((ab&65535)>(aa&65535)){aK=(ab-aa&65535)+q&65535}else{aK=q}q=X&31;X=aJ&31;if((q&65535)>(X&65535)){aL=(q-X&65535)+aK&65535}else{aL=aK}X=i+13|0;b[(c[277218]|0)+(X<<1)>>1]=aL;b[(c[277218]|0)+(ac<<1)>>1]=aL;q=a[1108909]|0;a[(c[277219]|0)+X|0]=q;a[(c[277219]|0)+ac|0]=q;aH=a[1108908]|0;aI=c[277219]|0}else{aH=aC;aI=aD}}while(0);ac=i+14|0;do{if((aH&255)>(d[aI+ac|0]|0)){q=a[e]|0;if(q<<24>>24==0){break}X=b[(c[277225]|0)+((q&255)<<1)>>1]|0;if((a[(c[277215]|0)+ac|0]&32)==0){aM=c[277228]&65535}else{aM=b[(c[277213]|0)+(ac<<1)>>1]|0}q=X&-2048;aa=aM&-2048;ab=(q&65535)>(aa&65535)?q-aa&65535:0;aa=X&2016;q=aM&2016;if((aa&65535)>(q&65535)){aN=(aa-q&65535)+ab&65535}else{aN=ab}ab=X&31;X=aM&31;if((ab&65535)>(X&65535)){aO=(ab-X&65535)+aN&65535}else{aO=aN}X=i+15|0;b[(c[277218]|0)+(X<<1)>>1]=aO;b[(c[277218]|0)+(ac<<1)>>1]=aO;ab=a[1108909]|0;a[(c[277219]|0)+X|0]=ab;a[(c[277219]|0)+ac|0]=ab}}while(0);ac=l-1|0;if((ac|0)<=0){break}e=e+8|0;l=ac;i=(c[277223]|0)+i|0}return}i=o+(56-g)|0;g=(h|0)>0;if(j){if(g){aP=i;aQ=h;aR=f}else{return}while(1){j=a[1108908]|0;o=c[277219]|0;do{if((j&255)>(d[o+aR|0]|0)){l=a[aP+7|0]|0;if(l<<24>>24==0){aS=j;aT=o;break}e=b[(c[277225]|0)+((l&255)<<1)>>1]|0;if((a[(c[277215]|0)+aR|0]&32)==0){aU=c[277228]&65535}else{aU=b[(c[277213]|0)+(aR<<1)>>1]|0}l=e&-2048;aO=aU&-2048;aN=(l&65535)>(aO&65535)?l-aO&65535:0;aO=e&2016;l=aU&2016;if((aO&65535)>(l&65535)){aV=(aO-l&65535)+aN&65535}else{aV=aN}aN=e&31;e=aU&31;if((aN&65535)>(e&65535)){aW=(aN-e&65535)+aV&65535}else{aW=aV}e=aR+1|0;b[(c[277218]|0)+(e<<1)>>1]=aW;b[(c[277218]|0)+(aR<<1)>>1]=aW;aN=a[1108909]|0;a[(c[277219]|0)+e|0]=aN;a[(c[277219]|0)+aR|0]=aN;aS=a[1108908]|0;aT=c[277219]|0}else{aS=j;aT=o}}while(0);o=aR+2|0;do{if((aS&255)>(d[aT+o|0]|0)){j=a[aP+6|0]|0;if(j<<24>>24==0){aX=aS;aY=aT;break}aN=b[(c[277225]|0)+((j&255)<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){aZ=c[277228]&65535}else{aZ=b[(c[277213]|0)+(o<<1)>>1]|0}j=aN&-2048;e=aZ&-2048;l=(j&65535)>(e&65535)?j-e&65535:0;e=aN&2016;j=aZ&2016;if((e&65535)>(j&65535)){a_=(e-j&65535)+l&65535}else{a_=l}l=aN&31;aN=aZ&31;if((l&65535)>(aN&65535)){a$=(l-aN&65535)+a_&65535}else{a$=a_}aN=aR+3|0;b[(c[277218]|0)+(aN<<1)>>1]=a$;b[(c[277218]|0)+(o<<1)>>1]=a$;l=a[1108909]|0;a[(c[277219]|0)+aN|0]=l;a[(c[277219]|0)+o|0]=l;aX=a[1108908]|0;aY=c[277219]|0}else{aX=aS;aY=aT}}while(0);o=aR+4|0;do{if((aX&255)>(d[aY+o|0]|0)){l=a[aP+5|0]|0;if(l<<24>>24==0){a0=aX;a1=aY;break}aN=b[(c[277225]|0)+((l&255)<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){a2=c[277228]&65535}else{a2=b[(c[277213]|0)+(o<<1)>>1]|0}l=aN&-2048;j=a2&-2048;e=(l&65535)>(j&65535)?l-j&65535:0;j=aN&2016;l=a2&2016;if((j&65535)>(l&65535)){a3=(j-l&65535)+e&65535}else{a3=e}e=aN&31;aN=a2&31;if((e&65535)>(aN&65535)){a4=(e-aN&65535)+a3&65535}else{a4=a3}aN=aR+5|0;b[(c[277218]|0)+(aN<<1)>>1]=a4;b[(c[277218]|0)+(o<<1)>>1]=a4;e=a[1108909]|0;a[(c[277219]|0)+aN|0]=e;a[(c[277219]|0)+o|0]=e;a0=a[1108908]|0;a1=c[277219]|0}else{a0=aX;a1=aY}}while(0);o=aR+6|0;do{if((a0&255)>(d[a1+o|0]|0)){e=a[aP+4|0]|0;if(e<<24>>24==0){a5=a0;a6=a1;break}aN=b[(c[277225]|0)+((e&255)<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){a7=c[277228]&65535}else{a7=b[(c[277213]|0)+(o<<1)>>1]|0}e=aN&-2048;l=a7&-2048;j=(e&65535)>(l&65535)?e-l&65535:0;l=aN&2016;e=a7&2016;if((l&65535)>(e&65535)){a8=(l-e&65535)+j&65535}else{a8=j}j=aN&31;aN=a7&31;if((j&65535)>(aN&65535)){a9=(j-aN&65535)+a8&65535}else{a9=a8}aN=aR+7|0;b[(c[277218]|0)+(aN<<1)>>1]=a9;b[(c[277218]|0)+(o<<1)>>1]=a9;j=a[1108909]|0;a[(c[277219]|0)+aN|0]=j;a[(c[277219]|0)+o|0]=j;a5=a[1108908]|0;a6=c[277219]|0}else{a5=a0;a6=a1}}while(0);o=aR+8|0;do{if((a5&255)>(d[a6+o|0]|0)){j=a[aP+3|0]|0;if(j<<24>>24==0){ba=a5;bb=a6;break}aN=b[(c[277225]|0)+((j&255)<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){bc=c[277228]&65535}else{bc=b[(c[277213]|0)+(o<<1)>>1]|0}j=aN&-2048;e=bc&-2048;l=(j&65535)>(e&65535)?j-e&65535:0;e=aN&2016;j=bc&2016;if((e&65535)>(j&65535)){bd=(e-j&65535)+l&65535}else{bd=l}l=aN&31;aN=bc&31;if((l&65535)>(aN&65535)){be=(l-aN&65535)+bd&65535}else{be=bd}aN=aR+9|0;b[(c[277218]|0)+(aN<<1)>>1]=be;b[(c[277218]|0)+(o<<1)>>1]=be;l=a[1108909]|0;a[(c[277219]|0)+aN|0]=l;a[(c[277219]|0)+o|0]=l;ba=a[1108908]|0;bb=c[277219]|0}else{ba=a5;bb=a6}}while(0);o=aR+10|0;do{if((ba&255)>(d[bb+o|0]|0)){l=a[aP+2|0]|0;if(l<<24>>24==0){bf=ba;bg=bb;break}aN=b[(c[277225]|0)+((l&255)<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){bh=c[277228]&65535}else{bh=b[(c[277213]|0)+(o<<1)>>1]|0}l=aN&-2048;j=bh&-2048;e=(l&65535)>(j&65535)?l-j&65535:0;j=aN&2016;l=bh&2016;if((j&65535)>(l&65535)){bi=(j-l&65535)+e&65535}else{bi=e}e=aN&31;aN=bh&31;if((e&65535)>(aN&65535)){bj=(e-aN&65535)+bi&65535}else{bj=bi}aN=aR+11|0;b[(c[277218]|0)+(aN<<1)>>1]=bj;b[(c[277218]|0)+(o<<1)>>1]=bj;e=a[1108909]|0;a[(c[277219]|0)+aN|0]=e;a[(c[277219]|0)+o|0]=e;bf=a[1108908]|0;bg=c[277219]|0}else{bf=ba;bg=bb}}while(0);o=aR+12|0;do{if((bf&255)>(d[bg+o|0]|0)){e=a[aP+1|0]|0;if(e<<24>>24==0){bk=bf;bl=bg;break}aN=b[(c[277225]|0)+((e&255)<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){bm=c[277228]&65535}else{bm=b[(c[277213]|0)+(o<<1)>>1]|0}e=aN&-2048;l=bm&-2048;j=(e&65535)>(l&65535)?e-l&65535:0;l=aN&2016;e=bm&2016;if((l&65535)>(e&65535)){bn=(l-e&65535)+j&65535}else{bn=j}j=aN&31;aN=bm&31;if((j&65535)>(aN&65535)){bo=(j-aN&65535)+bn&65535}else{bo=bn}aN=aR+13|0;b[(c[277218]|0)+(aN<<1)>>1]=bo;b[(c[277218]|0)+(o<<1)>>1]=bo;j=a[1108909]|0;a[(c[277219]|0)+aN|0]=j;a[(c[277219]|0)+o|0]=j;bk=a[1108908]|0;bl=c[277219]|0}else{bk=bf;bl=bg}}while(0);o=aR+14|0;do{if((bk&255)>(d[bl+o|0]|0)){j=a[aP]|0;if(j<<24>>24==0){break}aN=b[(c[277225]|0)+((j&255)<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){bp=c[277228]&65535}else{bp=b[(c[277213]|0)+(o<<1)>>1]|0}j=aN&-2048;e=bp&-2048;l=(j&65535)>(e&65535)?j-e&65535:0;e=aN&2016;j=bp&2016;if((e&65535)>(j&65535)){bq=(e-j&65535)+l&65535}else{bq=l}l=aN&31;aN=bp&31;if((l&65535)>(aN&65535)){br=(l-aN&65535)+bq&65535}else{br=bq}aN=aR+15|0;b[(c[277218]|0)+(aN<<1)>>1]=br;b[(c[277218]|0)+(o<<1)>>1]=br;l=a[1108909]|0;a[(c[277219]|0)+aN|0]=l;a[(c[277219]|0)+o|0]=l}}while(0);o=aQ-1|0;if((o|0)<=0){break}aP=aP-8|0;aQ=o;aR=(c[277223]|0)+aR|0}return}else{if(g){bs=i;bt=h;bu=f}else{return}while(1){f=a[1108908]|0;h=c[277219]|0;do{if((f&255)>(d[h+bu|0]|0)){i=a[bs]|0;if(i<<24>>24==0){bv=f;bw=h;break}g=b[(c[277225]|0)+((i&255)<<1)>>1]|0;if((a[(c[277215]|0)+bu|0]&32)==0){bx=c[277228]&65535}else{bx=b[(c[277213]|0)+(bu<<1)>>1]|0}i=g&-2048;aR=bx&-2048;aQ=(i&65535)>(aR&65535)?i-aR&65535:0;aR=g&2016;i=bx&2016;if((aR&65535)>(i&65535)){by=(aR-i&65535)+aQ&65535}else{by=aQ}aQ=g&31;g=bx&31;if((aQ&65535)>(g&65535)){bz=(aQ-g&65535)+by&65535}else{bz=by}g=bu+1|0;b[(c[277218]|0)+(g<<1)>>1]=bz;b[(c[277218]|0)+(bu<<1)>>1]=bz;aQ=a[1108909]|0;a[(c[277219]|0)+g|0]=aQ;a[(c[277219]|0)+bu|0]=aQ;bv=a[1108908]|0;bw=c[277219]|0}else{bv=f;bw=h}}while(0);h=bu+2|0;do{if((bv&255)>(d[bw+h|0]|0)){f=a[bs+1|0]|0;if(f<<24>>24==0){bA=bv;bB=bw;break}aQ=b[(c[277225]|0)+((f&255)<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)==0){bC=c[277228]&65535}else{bC=b[(c[277213]|0)+(h<<1)>>1]|0}f=aQ&-2048;g=bC&-2048;i=(f&65535)>(g&65535)?f-g&65535:0;g=aQ&2016;f=bC&2016;if((g&65535)>(f&65535)){bD=(g-f&65535)+i&65535}else{bD=i}i=aQ&31;aQ=bC&31;if((i&65535)>(aQ&65535)){bE=(i-aQ&65535)+bD&65535}else{bE=bD}aQ=bu+3|0;b[(c[277218]|0)+(aQ<<1)>>1]=bE;b[(c[277218]|0)+(h<<1)>>1]=bE;i=a[1108909]|0;a[(c[277219]|0)+aQ|0]=i;a[(c[277219]|0)+h|0]=i;bA=a[1108908]|0;bB=c[277219]|0}else{bA=bv;bB=bw}}while(0);h=bu+4|0;do{if((bA&255)>(d[bB+h|0]|0)){i=a[bs+2|0]|0;if(i<<24>>24==0){bF=bA;bG=bB;break}aQ=b[(c[277225]|0)+((i&255)<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)==0){bH=c[277228]&65535}else{bH=b[(c[277213]|0)+(h<<1)>>1]|0}i=aQ&-2048;f=bH&-2048;g=(i&65535)>(f&65535)?i-f&65535:0;f=aQ&2016;i=bH&2016;if((f&65535)>(i&65535)){bI=(f-i&65535)+g&65535}else{bI=g}g=aQ&31;aQ=bH&31;if((g&65535)>(aQ&65535)){bJ=(g-aQ&65535)+bI&65535}else{bJ=bI}aQ=bu+5|0;b[(c[277218]|0)+(aQ<<1)>>1]=bJ;b[(c[277218]|0)+(h<<1)>>1]=bJ;g=a[1108909]|0;a[(c[277219]|0)+aQ|0]=g;a[(c[277219]|0)+h|0]=g;bF=a[1108908]|0;bG=c[277219]|0}else{bF=bA;bG=bB}}while(0);h=bu+6|0;do{if((bF&255)>(d[bG+h|0]|0)){g=a[bs+3|0]|0;if(g<<24>>24==0){bK=bF;bL=bG;break}aQ=b[(c[277225]|0)+((g&255)<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)==0){bM=c[277228]&65535}else{bM=b[(c[277213]|0)+(h<<1)>>1]|0}g=aQ&-2048;i=bM&-2048;f=(g&65535)>(i&65535)?g-i&65535:0;i=aQ&2016;g=bM&2016;if((i&65535)>(g&65535)){bN=(i-g&65535)+f&65535}else{bN=f}f=aQ&31;aQ=bM&31;if((f&65535)>(aQ&65535)){bO=(f-aQ&65535)+bN&65535}else{bO=bN}aQ=bu+7|0;b[(c[277218]|0)+(aQ<<1)>>1]=bO;b[(c[277218]|0)+(h<<1)>>1]=bO;f=a[1108909]|0;a[(c[277219]|0)+aQ|0]=f;a[(c[277219]|0)+h|0]=f;bK=a[1108908]|0;bL=c[277219]|0}else{bK=bF;bL=bG}}while(0);h=bu+8|0;do{if((bK&255)>(d[bL+h|0]|0)){f=a[bs+4|0]|0;if(f<<24>>24==0){bP=bK;bQ=bL;break}aQ=b[(c[277225]|0)+((f&255)<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)==0){bR=c[277228]&65535}else{bR=b[(c[277213]|0)+(h<<1)>>1]|0}f=aQ&-2048;g=bR&-2048;i=(f&65535)>(g&65535)?f-g&65535:0;g=aQ&2016;f=bR&2016;if((g&65535)>(f&65535)){bS=(g-f&65535)+i&65535}else{bS=i}i=aQ&31;aQ=bR&31;if((i&65535)>(aQ&65535)){bT=(i-aQ&65535)+bS&65535}else{bT=bS}aQ=bu+9|0;b[(c[277218]|0)+(aQ<<1)>>1]=bT;b[(c[277218]|0)+(h<<1)>>1]=bT;i=a[1108909]|0;a[(c[277219]|0)+aQ|0]=i;a[(c[277219]|0)+h|0]=i;bP=a[1108908]|0;bQ=c[277219]|0}else{bP=bK;bQ=bL}}while(0);h=bu+10|0;do{if((bP&255)>(d[bQ+h|0]|0)){i=a[bs+5|0]|0;if(i<<24>>24==0){bU=bP;bV=bQ;break}aQ=b[(c[277225]|0)+((i&255)<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)==0){bW=c[277228]&65535}else{bW=b[(c[277213]|0)+(h<<1)>>1]|0}i=aQ&-2048;f=bW&-2048;g=(i&65535)>(f&65535)?i-f&65535:0;f=aQ&2016;i=bW&2016;if((f&65535)>(i&65535)){bX=(f-i&65535)+g&65535}else{bX=g}g=aQ&31;aQ=bW&31;if((g&65535)>(aQ&65535)){bY=(g-aQ&65535)+bX&65535}else{bY=bX}aQ=bu+11|0;b[(c[277218]|0)+(aQ<<1)>>1]=bY;b[(c[277218]|0)+(h<<1)>>1]=bY;g=a[1108909]|0;a[(c[277219]|0)+aQ|0]=g;a[(c[277219]|0)+h|0]=g;bU=a[1108908]|0;bV=c[277219]|0}else{bU=bP;bV=bQ}}while(0);h=bu+12|0;do{if((bU&255)>(d[bV+h|0]|0)){g=a[bs+6|0]|0;if(g<<24>>24==0){bZ=bU;b_=bV;break}aQ=b[(c[277225]|0)+((g&255)<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)==0){b$=c[277228]&65535}else{b$=b[(c[277213]|0)+(h<<1)>>1]|0}g=aQ&-2048;i=b$&-2048;f=(g&65535)>(i&65535)?g-i&65535:0;i=aQ&2016;g=b$&2016;if((i&65535)>(g&65535)){b0=(i-g&65535)+f&65535}else{b0=f}f=aQ&31;aQ=b$&31;if((f&65535)>(aQ&65535)){b1=(f-aQ&65535)+b0&65535}else{b1=b0}aQ=bu+13|0;b[(c[277218]|0)+(aQ<<1)>>1]=b1;b[(c[277218]|0)+(h<<1)>>1]=b1;f=a[1108909]|0;a[(c[277219]|0)+aQ|0]=f;a[(c[277219]|0)+h|0]=f;bZ=a[1108908]|0;b_=c[277219]|0}else{bZ=bU;b_=bV}}while(0);h=bu+14|0;do{if((bZ&255)>(d[b_+h|0]|0)){f=a[bs+7|0]|0;if(f<<24>>24==0){break}aQ=b[(c[277225]|0)+((f&255)<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)==0){b2=c[277228]&65535}else{b2=b[(c[277213]|0)+(h<<1)>>1]|0}f=aQ&-2048;g=b2&-2048;i=(f&65535)>(g&65535)?f-g&65535:0;g=aQ&2016;f=b2&2016;if((g&65535)>(f&65535)){b3=(g-f&65535)+i&65535}else{b3=i}i=aQ&31;aQ=b2&31;if((i&65535)>(aQ&65535)){b4=(i-aQ&65535)+b3&65535}else{b4=b3}aQ=bu+15|0;b[(c[277218]|0)+(aQ<<1)>>1]=b4;b[(c[277218]|0)+(h<<1)>>1]=b4;i=a[1108909]|0;a[(c[277219]|0)+aQ|0]=i;a[(c[277219]|0)+h|0]=i}}while(0);h=bt-1|0;if((h|0)<=0){break}bs=bs-8|0;bt=h;bu=(c[277223]|0)+bu|0}return}}function Uz(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0;i=e&1023;j=c[348606]|0;k=(i<<j)+(c[348604]|0)|0;if((e&256|0)==0){l=k}else{l=(c[348602]|0)+k|0}k=l&65535;l=k>>>(j>>>0);j=(e&16384|0)!=0;m=l<<6;do{if(j){n=(c[348622]|0)+m|0;if((a[(c[348618]|0)+l|0]|0)!=0){o=n;break}p=fi[c[348636]&63](n,k,i)|0;a[(c[348618]|0)+l|0]=p;o=n}else{n=(c[348624]|0)+m|0;if((a[(c[348620]|0)+l|0]|0)!=0){o=n;break}p=fi[c[348638]&63](n,k,i)|0;a[(c[348620]|0)+l|0]=p;o=n}}while(0);if((a[(c[348620]|0)+l|0]|0)==2){return}if((a[1394464]|0)==0){q=1106168+((e>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){l=d[1044485]|0;c[276541]=7080+(l<<5);i=0;do{k=i<<1&2;m=i&2;n=i&4;p=0;do{b[1125528+(i<<9)+(p<<1)>>1]=d[(p>>>1&28|m)+(7080+(l<<5))|0]<<6|d[(p<<2&28|k)+(7080+(l<<5))|0]<<11|d[(p>>>3&24|n)+(7080+(l<<5))|0];p=p+1|0;}while(p>>>0<256);i=i+1|0;}while(i>>>0<8);a[1106089]=0}q=1125528+((e>>>10&7)<<9)|0}c[277226]=q;c[277225]=(a[1108928]|0)!=0?1393712:q;if((e&49152|0)==0){if((h|0)<=0){return}q=o+g|0;i=h;l=f;while(1){p=a[1108908]|0;n=c[277219]|0;do{if((p&255)>(d[n+l|0]|0)){k=a[q]|0;if(k<<24>>24==0){r=p;s=n;break}m=b[(c[277225]|0)+((k&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){t=b[(c[277221]|0)+(((m&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{k=c[277228]&65535;u=m&-2048;v=k&-2048;w=(u&65535)>(v&65535)?u-v&65535:0;v=m&2016;u=k&2016;if((v&65535)>(u&65535)){x=(v-u&65535)+w&65535}else{x=w}w=m&31;u=k&31;if((w&65535)<=(u&65535)){t=x;break}t=(w-u&65535)+x&65535}}while(0);m=l+1|0;b[(c[277218]|0)+(m<<1)>>1]=t;b[(c[277218]|0)+(l<<1)>>1]=t;u=a[1108909]|0;a[(c[277219]|0)+m|0]=u;a[(c[277219]|0)+l|0]=u;r=a[1108908]|0;s=c[277219]|0}else{r=p;s=n}}while(0);n=l+2|0;do{if((r&255)>(d[s+n|0]|0)){p=a[q+1|0]|0;if(p<<24>>24==0){y=r;z=s;break}u=b[(c[277225]|0)+((p&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){A=b[(c[277221]|0)+(((u&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{p=c[277228]&65535;m=u&-2048;w=p&-2048;k=(m&65535)>(w&65535)?m-w&65535:0;w=u&2016;m=p&2016;if((w&65535)>(m&65535)){B=(w-m&65535)+k&65535}else{B=k}k=u&31;m=p&31;if((k&65535)<=(m&65535)){A=B;break}A=(k-m&65535)+B&65535}}while(0);u=l+3|0;b[(c[277218]|0)+(u<<1)>>1]=A;b[(c[277218]|0)+(n<<1)>>1]=A;m=a[1108909]|0;a[(c[277219]|0)+u|0]=m;a[(c[277219]|0)+n|0]=m;y=a[1108908]|0;z=c[277219]|0}else{y=r;z=s}}while(0);n=l+4|0;do{if((y&255)>(d[z+n|0]|0)){m=a[q+2|0]|0;if(m<<24>>24==0){C=y;D=z;break}u=b[(c[277225]|0)+((m&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){E=b[(c[277221]|0)+(((u&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{m=c[277228]&65535;k=u&-2048;p=m&-2048;w=(k&65535)>(p&65535)?k-p&65535:0;p=u&2016;k=m&2016;if((p&65535)>(k&65535)){F=(p-k&65535)+w&65535}else{F=w}w=u&31;k=m&31;if((w&65535)<=(k&65535)){E=F;break}E=(w-k&65535)+F&65535}}while(0);u=l+5|0;b[(c[277218]|0)+(u<<1)>>1]=E;b[(c[277218]|0)+(n<<1)>>1]=E;k=a[1108909]|0;a[(c[277219]|0)+u|0]=k;a[(c[277219]|0)+n|0]=k;C=a[1108908]|0;D=c[277219]|0}else{C=y;D=z}}while(0);n=l+6|0;do{if((C&255)>(d[D+n|0]|0)){k=a[q+3|0]|0;if(k<<24>>24==0){G=C;H=D;break}u=b[(c[277225]|0)+((k&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){I=b[(c[277221]|0)+(((u&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{k=c[277228]&65535;w=u&-2048;m=k&-2048;p=(w&65535)>(m&65535)?w-m&65535:0;m=u&2016;w=k&2016;if((m&65535)>(w&65535)){J=(m-w&65535)+p&65535}else{J=p}p=u&31;w=k&31;if((p&65535)<=(w&65535)){I=J;break}I=(p-w&65535)+J&65535}}while(0);u=l+7|0;b[(c[277218]|0)+(u<<1)>>1]=I;b[(c[277218]|0)+(n<<1)>>1]=I;w=a[1108909]|0;a[(c[277219]|0)+u|0]=w;a[(c[277219]|0)+n|0]=w;G=a[1108908]|0;H=c[277219]|0}else{G=C;H=D}}while(0);n=l+8|0;do{if((G&255)>(d[H+n|0]|0)){w=a[q+4|0]|0;if(w<<24>>24==0){K=G;L=H;break}u=b[(c[277225]|0)+((w&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){M=b[(c[277221]|0)+(((u&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{w=c[277228]&65535;p=u&-2048;k=w&-2048;m=(p&65535)>(k&65535)?p-k&65535:0;k=u&2016;p=w&2016;if((k&65535)>(p&65535)){N=(k-p&65535)+m&65535}else{N=m}m=u&31;p=w&31;if((m&65535)<=(p&65535)){M=N;break}M=(m-p&65535)+N&65535}}while(0);u=l+9|0;b[(c[277218]|0)+(u<<1)>>1]=M;b[(c[277218]|0)+(n<<1)>>1]=M;p=a[1108909]|0;a[(c[277219]|0)+u|0]=p;a[(c[277219]|0)+n|0]=p;K=a[1108908]|0;L=c[277219]|0}else{K=G;L=H}}while(0);n=l+10|0;do{if((K&255)>(d[L+n|0]|0)){p=a[q+5|0]|0;if(p<<24>>24==0){O=K;P=L;break}u=b[(c[277225]|0)+((p&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){Q=b[(c[277221]|0)+(((u&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{p=c[277228]&65535;m=u&-2048;w=p&-2048;k=(m&65535)>(w&65535)?m-w&65535:0;w=u&2016;m=p&2016;if((w&65535)>(m&65535)){R=(w-m&65535)+k&65535}else{R=k}k=u&31;m=p&31;if((k&65535)<=(m&65535)){Q=R;break}Q=(k-m&65535)+R&65535}}while(0);u=l+11|0;b[(c[277218]|0)+(u<<1)>>1]=Q;b[(c[277218]|0)+(n<<1)>>1]=Q;m=a[1108909]|0;a[(c[277219]|0)+u|0]=m;a[(c[277219]|0)+n|0]=m;O=a[1108908]|0;P=c[277219]|0}else{O=K;P=L}}while(0);n=l+12|0;do{if((O&255)>(d[P+n|0]|0)){m=a[q+6|0]|0;if(m<<24>>24==0){S=O;T=P;break}u=b[(c[277225]|0)+((m&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){U=b[(c[277221]|0)+(((u&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{m=c[277228]&65535;k=u&-2048;p=m&-2048;w=(k&65535)>(p&65535)?k-p&65535:0;p=u&2016;k=m&2016;if((p&65535)>(k&65535)){V=(p-k&65535)+w&65535}else{V=w}w=u&31;k=m&31;if((w&65535)<=(k&65535)){U=V;break}U=(w-k&65535)+V&65535}}while(0);u=l+13|0;b[(c[277218]|0)+(u<<1)>>1]=U;b[(c[277218]|0)+(n<<1)>>1]=U;k=a[1108909]|0;a[(c[277219]|0)+u|0]=k;a[(c[277219]|0)+n|0]=k;S=a[1108908]|0;T=c[277219]|0}else{S=O;T=P}}while(0);n=l+14|0;do{if((S&255)>(d[T+n|0]|0)){k=a[q+7|0]|0;if(k<<24>>24==0){break}u=b[(c[277225]|0)+((k&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){W=b[(c[277221]|0)+(((u&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{k=c[277228]&65535;w=u&-2048;m=k&-2048;p=(w&65535)>(m&65535)?w-m&65535:0;m=u&2016;w=k&2016;if((m&65535)>(w&65535)){X=(m-w&65535)+p&65535}else{X=p}p=u&31;w=k&31;if((p&65535)<=(w&65535)){W=X;break}W=(p-w&65535)+X&65535}}while(0);u=l+15|0;b[(c[277218]|0)+(u<<1)>>1]=W;b[(c[277218]|0)+(n<<1)>>1]=W;w=a[1108909]|0;a[(c[277219]|0)+u|0]=w;a[(c[277219]|0)+n|0]=w}}while(0);n=i-1|0;if((n|0)<=0){break}q=q+8|0;i=n;l=(c[277223]|0)+l|0}return}if((e&32768|0)==0){if((h|0)<=0){return}e=o+g|0;l=h;i=f;while(1){q=a[1108908]|0;W=c[277219]|0;do{if((q&255)>(d[W+i|0]|0)){X=a[e+7|0]|0;if(X<<24>>24==0){Y=q;Z=W;break}T=b[(c[277225]|0)+((X&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){_=b[(c[277221]|0)+(((T&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{X=c[277228]&65535;S=T&-2048;P=X&-2048;O=(S&65535)>(P&65535)?S-P&65535:0;P=T&2016;S=X&2016;if((P&65535)>(S&65535)){$=(P-S&65535)+O&65535}else{$=O}O=T&31;S=X&31;if((O&65535)<=(S&65535)){_=$;break}_=(O-S&65535)+$&65535}}while(0);T=i+1|0;b[(c[277218]|0)+(T<<1)>>1]=_;b[(c[277218]|0)+(i<<1)>>1]=_;S=a[1108909]|0;a[(c[277219]|0)+T|0]=S;a[(c[277219]|0)+i|0]=S;Y=a[1108908]|0;Z=c[277219]|0}else{Y=q;Z=W}}while(0);W=i+2|0;do{if((Y&255)>(d[Z+W|0]|0)){q=a[e+6|0]|0;if(q<<24>>24==0){aa=Y;ab=Z;break}S=b[(c[277225]|0)+((q&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){ac=b[(c[277221]|0)+(((S&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{q=c[277228]&65535;T=S&-2048;O=q&-2048;X=(T&65535)>(O&65535)?T-O&65535:0;O=S&2016;T=q&2016;if((O&65535)>(T&65535)){ad=(O-T&65535)+X&65535}else{ad=X}X=S&31;T=q&31;if((X&65535)<=(T&65535)){ac=ad;break}ac=(X-T&65535)+ad&65535}}while(0);S=i+3|0;b[(c[277218]|0)+(S<<1)>>1]=ac;b[(c[277218]|0)+(W<<1)>>1]=ac;T=a[1108909]|0;a[(c[277219]|0)+S|0]=T;a[(c[277219]|0)+W|0]=T;aa=a[1108908]|0;ab=c[277219]|0}else{aa=Y;ab=Z}}while(0);W=i+4|0;do{if((aa&255)>(d[ab+W|0]|0)){T=a[e+5|0]|0;if(T<<24>>24==0){ae=aa;af=ab;break}S=b[(c[277225]|0)+((T&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){ag=b[(c[277221]|0)+(((S&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{T=c[277228]&65535;X=S&-2048;q=T&-2048;O=(X&65535)>(q&65535)?X-q&65535:0;q=S&2016;X=T&2016;if((q&65535)>(X&65535)){ah=(q-X&65535)+O&65535}else{ah=O}O=S&31;X=T&31;if((O&65535)<=(X&65535)){ag=ah;break}ag=(O-X&65535)+ah&65535}}while(0);S=i+5|0;b[(c[277218]|0)+(S<<1)>>1]=ag;b[(c[277218]|0)+(W<<1)>>1]=ag;X=a[1108909]|0;a[(c[277219]|0)+S|0]=X;a[(c[277219]|0)+W|0]=X;ae=a[1108908]|0;af=c[277219]|0}else{ae=aa;af=ab}}while(0);W=i+6|0;do{if((ae&255)>(d[af+W|0]|0)){X=a[e+4|0]|0;if(X<<24>>24==0){ai=ae;aj=af;break}S=b[(c[277225]|0)+((X&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){ak=b[(c[277221]|0)+(((S&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{X=c[277228]&65535;O=S&-2048;T=X&-2048;q=(O&65535)>(T&65535)?O-T&65535:0;T=S&2016;O=X&2016;if((T&65535)>(O&65535)){al=(T-O&65535)+q&65535}else{al=q}q=S&31;O=X&31;if((q&65535)<=(O&65535)){ak=al;break}ak=(q-O&65535)+al&65535}}while(0);S=i+7|0;b[(c[277218]|0)+(S<<1)>>1]=ak;b[(c[277218]|0)+(W<<1)>>1]=ak;O=a[1108909]|0;a[(c[277219]|0)+S|0]=O;a[(c[277219]|0)+W|0]=O;ai=a[1108908]|0;aj=c[277219]|0}else{ai=ae;aj=af}}while(0);W=i+8|0;do{if((ai&255)>(d[aj+W|0]|0)){O=a[e+3|0]|0;if(O<<24>>24==0){am=ai;an=aj;break}S=b[(c[277225]|0)+((O&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){ao=b[(c[277221]|0)+(((S&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{O=c[277228]&65535;q=S&-2048;X=O&-2048;T=(q&65535)>(X&65535)?q-X&65535:0;X=S&2016;q=O&2016;if((X&65535)>(q&65535)){ap=(X-q&65535)+T&65535}else{ap=T}T=S&31;q=O&31;if((T&65535)<=(q&65535)){ao=ap;break}ao=(T-q&65535)+ap&65535}}while(0);S=i+9|0;b[(c[277218]|0)+(S<<1)>>1]=ao;b[(c[277218]|0)+(W<<1)>>1]=ao;q=a[1108909]|0;a[(c[277219]|0)+S|0]=q;a[(c[277219]|0)+W|0]=q;am=a[1108908]|0;an=c[277219]|0}else{am=ai;an=aj}}while(0);W=i+10|0;do{if((am&255)>(d[an+W|0]|0)){q=a[e+2|0]|0;if(q<<24>>24==0){aq=am;ar=an;break}S=b[(c[277225]|0)+((q&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){as=b[(c[277221]|0)+(((S&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{q=c[277228]&65535;T=S&-2048;O=q&-2048;X=(T&65535)>(O&65535)?T-O&65535:0;O=S&2016;T=q&2016;if((O&65535)>(T&65535)){at=(O-T&65535)+X&65535}else{at=X}X=S&31;T=q&31;if((X&65535)<=(T&65535)){as=at;break}as=(X-T&65535)+at&65535}}while(0);S=i+11|0;b[(c[277218]|0)+(S<<1)>>1]=as;b[(c[277218]|0)+(W<<1)>>1]=as;T=a[1108909]|0;a[(c[277219]|0)+S|0]=T;a[(c[277219]|0)+W|0]=T;aq=a[1108908]|0;ar=c[277219]|0}else{aq=am;ar=an}}while(0);W=i+12|0;do{if((aq&255)>(d[ar+W|0]|0)){T=a[e+1|0]|0;if(T<<24>>24==0){au=aq;av=ar;break}S=b[(c[277225]|0)+((T&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aw=b[(c[277221]|0)+(((S&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{T=c[277228]&65535;X=S&-2048;q=T&-2048;O=(X&65535)>(q&65535)?X-q&65535:0;q=S&2016;X=T&2016;if((q&65535)>(X&65535)){ax=(q-X&65535)+O&65535}else{ax=O}O=S&31;X=T&31;if((O&65535)<=(X&65535)){aw=ax;break}aw=(O-X&65535)+ax&65535}}while(0);S=i+13|0;b[(c[277218]|0)+(S<<1)>>1]=aw;b[(c[277218]|0)+(W<<1)>>1]=aw;X=a[1108909]|0;a[(c[277219]|0)+S|0]=X;a[(c[277219]|0)+W|0]=X;au=a[1108908]|0;av=c[277219]|0}else{au=aq;av=ar}}while(0);W=i+14|0;do{if((au&255)>(d[av+W|0]|0)){X=a[e]|0;if(X<<24>>24==0){break}S=b[(c[277225]|0)+((X&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){ay=b[(c[277221]|0)+(((S&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{X=c[277228]&65535;O=S&-2048;T=X&-2048;q=(O&65535)>(T&65535)?O-T&65535:0;T=S&2016;O=X&2016;if((T&65535)>(O&65535)){az=(T-O&65535)+q&65535}else{az=q}q=S&31;O=X&31;if((q&65535)<=(O&65535)){ay=az;break}ay=(q-O&65535)+az&65535}}while(0);S=i+15|0;b[(c[277218]|0)+(S<<1)>>1]=ay;b[(c[277218]|0)+(W<<1)>>1]=ay;O=a[1108909]|0;a[(c[277219]|0)+S|0]=O;a[(c[277219]|0)+W|0]=O}}while(0);W=l-1|0;if((W|0)<=0){break}e=e+8|0;l=W;i=(c[277223]|0)+i|0}return}i=o+(56-g)|0;g=(h|0)>0;if(j){if(g){aA=i;aB=h;aC=f}else{return}while(1){j=a[1108908]|0;o=c[277219]|0;do{if((j&255)>(d[o+aC|0]|0)){l=a[aA+7|0]|0;if(l<<24>>24==0){aD=j;aE=o;break}e=b[(c[277225]|0)+((l&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aF=b[(c[277221]|0)+(((e&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{l=c[277228]&65535;ay=e&-2048;az=l&-2048;av=(ay&65535)>(az&65535)?ay-az&65535:0;az=e&2016;ay=l&2016;if((az&65535)>(ay&65535)){aG=(az-ay&65535)+av&65535}else{aG=av}av=e&31;ay=l&31;if((av&65535)<=(ay&65535)){aF=aG;break}aF=(av-ay&65535)+aG&65535}}while(0);e=aC+1|0;b[(c[277218]|0)+(e<<1)>>1]=aF;b[(c[277218]|0)+(aC<<1)>>1]=aF;ay=a[1108909]|0;a[(c[277219]|0)+e|0]=ay;a[(c[277219]|0)+aC|0]=ay;aD=a[1108908]|0;aE=c[277219]|0}else{aD=j;aE=o}}while(0);o=aC+2|0;do{if((aD&255)>(d[aE+o|0]|0)){j=a[aA+6|0]|0;if(j<<24>>24==0){aH=aD;aI=aE;break}ay=b[(c[277225]|0)+((j&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aJ=b[(c[277221]|0)+(((ay&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{j=c[277228]&65535;e=ay&-2048;av=j&-2048;l=(e&65535)>(av&65535)?e-av&65535:0;av=ay&2016;e=j&2016;if((av&65535)>(e&65535)){aK=(av-e&65535)+l&65535}else{aK=l}l=ay&31;e=j&31;if((l&65535)<=(e&65535)){aJ=aK;break}aJ=(l-e&65535)+aK&65535}}while(0);ay=aC+3|0;b[(c[277218]|0)+(ay<<1)>>1]=aJ;b[(c[277218]|0)+(o<<1)>>1]=aJ;e=a[1108909]|0;a[(c[277219]|0)+ay|0]=e;a[(c[277219]|0)+o|0]=e;aH=a[1108908]|0;aI=c[277219]|0}else{aH=aD;aI=aE}}while(0);o=aC+4|0;do{if((aH&255)>(d[aI+o|0]|0)){e=a[aA+5|0]|0;if(e<<24>>24==0){aL=aH;aM=aI;break}ay=b[(c[277225]|0)+((e&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aN=b[(c[277221]|0)+(((ay&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{e=c[277228]&65535;l=ay&-2048;j=e&-2048;av=(l&65535)>(j&65535)?l-j&65535:0;j=ay&2016;l=e&2016;if((j&65535)>(l&65535)){aO=(j-l&65535)+av&65535}else{aO=av}av=ay&31;l=e&31;if((av&65535)<=(l&65535)){aN=aO;break}aN=(av-l&65535)+aO&65535}}while(0);ay=aC+5|0;b[(c[277218]|0)+(ay<<1)>>1]=aN;b[(c[277218]|0)+(o<<1)>>1]=aN;l=a[1108909]|0;a[(c[277219]|0)+ay|0]=l;a[(c[277219]|0)+o|0]=l;aL=a[1108908]|0;aM=c[277219]|0}else{aL=aH;aM=aI}}while(0);o=aC+6|0;do{if((aL&255)>(d[aM+o|0]|0)){l=a[aA+4|0]|0;if(l<<24>>24==0){aP=aL;aQ=aM;break}ay=b[(c[277225]|0)+((l&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aR=b[(c[277221]|0)+(((ay&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{l=c[277228]&65535;av=ay&-2048;e=l&-2048;j=(av&65535)>(e&65535)?av-e&65535:0;e=ay&2016;av=l&2016;if((e&65535)>(av&65535)){aS=(e-av&65535)+j&65535}else{aS=j}j=ay&31;av=l&31;if((j&65535)<=(av&65535)){aR=aS;break}aR=(j-av&65535)+aS&65535}}while(0);ay=aC+7|0;b[(c[277218]|0)+(ay<<1)>>1]=aR;b[(c[277218]|0)+(o<<1)>>1]=aR;av=a[1108909]|0;a[(c[277219]|0)+ay|0]=av;a[(c[277219]|0)+o|0]=av;aP=a[1108908]|0;aQ=c[277219]|0}else{aP=aL;aQ=aM}}while(0);o=aC+8|0;do{if((aP&255)>(d[aQ+o|0]|0)){av=a[aA+3|0]|0;if(av<<24>>24==0){aT=aP;aU=aQ;break}ay=b[(c[277225]|0)+((av&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aV=b[(c[277221]|0)+(((ay&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{av=c[277228]&65535;j=ay&-2048;l=av&-2048;e=(j&65535)>(l&65535)?j-l&65535:0;l=ay&2016;j=av&2016;if((l&65535)>(j&65535)){aW=(l-j&65535)+e&65535}else{aW=e}e=ay&31;j=av&31;if((e&65535)<=(j&65535)){aV=aW;break}aV=(e-j&65535)+aW&65535}}while(0);ay=aC+9|0;b[(c[277218]|0)+(ay<<1)>>1]=aV;b[(c[277218]|0)+(o<<1)>>1]=aV;j=a[1108909]|0;a[(c[277219]|0)+ay|0]=j;a[(c[277219]|0)+o|0]=j;aT=a[1108908]|0;aU=c[277219]|0}else{aT=aP;aU=aQ}}while(0);o=aC+10|0;do{if((aT&255)>(d[aU+o|0]|0)){j=a[aA+2|0]|0;if(j<<24>>24==0){aX=aT;aY=aU;break}ay=b[(c[277225]|0)+((j&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aZ=b[(c[277221]|0)+(((ay&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{j=c[277228]&65535;e=ay&-2048;av=j&-2048;l=(e&65535)>(av&65535)?e-av&65535:0;av=ay&2016;e=j&2016;if((av&65535)>(e&65535)){a_=(av-e&65535)+l&65535}else{a_=l}l=ay&31;e=j&31;if((l&65535)<=(e&65535)){aZ=a_;break}aZ=(l-e&65535)+a_&65535}}while(0);ay=aC+11|0;b[(c[277218]|0)+(ay<<1)>>1]=aZ;b[(c[277218]|0)+(o<<1)>>1]=aZ;e=a[1108909]|0;a[(c[277219]|0)+ay|0]=e;a[(c[277219]|0)+o|0]=e;aX=a[1108908]|0;aY=c[277219]|0}else{aX=aT;aY=aU}}while(0);o=aC+12|0;do{if((aX&255)>(d[aY+o|0]|0)){e=a[aA+1|0]|0;if(e<<24>>24==0){a$=aX;a0=aY;break}ay=b[(c[277225]|0)+((e&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){a1=b[(c[277221]|0)+(((ay&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{e=c[277228]&65535;l=ay&-2048;j=e&-2048;av=(l&65535)>(j&65535)?l-j&65535:0;j=ay&2016;l=e&2016;if((j&65535)>(l&65535)){a2=(j-l&65535)+av&65535}else{a2=av}av=ay&31;l=e&31;if((av&65535)<=(l&65535)){a1=a2;break}a1=(av-l&65535)+a2&65535}}while(0);ay=aC+13|0;b[(c[277218]|0)+(ay<<1)>>1]=a1;b[(c[277218]|0)+(o<<1)>>1]=a1;l=a[1108909]|0;a[(c[277219]|0)+ay|0]=l;a[(c[277219]|0)+o|0]=l;a$=a[1108908]|0;a0=c[277219]|0}else{a$=aX;a0=aY}}while(0);o=aC+14|0;do{if((a$&255)>(d[a0+o|0]|0)){l=a[aA]|0;if(l<<24>>24==0){break}ay=b[(c[277225]|0)+((l&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){a3=b[(c[277221]|0)+(((ay&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{l=c[277228]&65535;av=ay&-2048;e=l&-2048;j=(av&65535)>(e&65535)?av-e&65535:0;e=ay&2016;av=l&2016;if((e&65535)>(av&65535)){a4=(e-av&65535)+j&65535}else{a4=j}j=ay&31;av=l&31;if((j&65535)<=(av&65535)){a3=a4;break}a3=(j-av&65535)+a4&65535}}while(0);ay=aC+15|0;b[(c[277218]|0)+(ay<<1)>>1]=a3;b[(c[277218]|0)+(o<<1)>>1]=a3;av=a[1108909]|0;a[(c[277219]|0)+ay|0]=av;a[(c[277219]|0)+o|0]=av}}while(0);o=aB-1|0;if((o|0)<=0){break}aA=aA-8|0;aB=o;aC=(c[277223]|0)+aC|0}return}else{if(g){a5=i;a6=h;a7=f}else{return}while(1){f=a[1108908]|0;h=c[277219]|0;do{if((f&255)>(d[h+a7|0]|0)){i=a[a5]|0;if(i<<24>>24==0){a8=f;a9=h;break}g=b[(c[277225]|0)+((i&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){ba=b[(c[277221]|0)+(((g&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{i=c[277228]&65535;aC=g&-2048;aB=i&-2048;aA=(aC&65535)>(aB&65535)?aC-aB&65535:0;aB=g&2016;aC=i&2016;if((aB&65535)>(aC&65535)){bb=(aB-aC&65535)+aA&65535}else{bb=aA}aA=g&31;aC=i&31;if((aA&65535)<=(aC&65535)){ba=bb;break}ba=(aA-aC&65535)+bb&65535}}while(0);g=a7+1|0;b[(c[277218]|0)+(g<<1)>>1]=ba;b[(c[277218]|0)+(a7<<1)>>1]=ba;aC=a[1108909]|0;a[(c[277219]|0)+g|0]=aC;a[(c[277219]|0)+a7|0]=aC;a8=a[1108908]|0;a9=c[277219]|0}else{a8=f;a9=h}}while(0);h=a7+2|0;do{if((a8&255)>(d[a9+h|0]|0)){f=a[a5+1|0]|0;if(f<<24>>24==0){bc=a8;bd=a9;break}aC=b[(c[277225]|0)+((f&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){be=b[(c[277221]|0)+(((aC&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{f=c[277228]&65535;g=aC&-2048;aA=f&-2048;i=(g&65535)>(aA&65535)?g-aA&65535:0;aA=aC&2016;g=f&2016;if((aA&65535)>(g&65535)){bf=(aA-g&65535)+i&65535}else{bf=i}i=aC&31;g=f&31;if((i&65535)<=(g&65535)){be=bf;break}be=(i-g&65535)+bf&65535}}while(0);aC=a7+3|0;b[(c[277218]|0)+(aC<<1)>>1]=be;b[(c[277218]|0)+(h<<1)>>1]=be;g=a[1108909]|0;a[(c[277219]|0)+aC|0]=g;a[(c[277219]|0)+h|0]=g;bc=a[1108908]|0;bd=c[277219]|0}else{bc=a8;bd=a9}}while(0);h=a7+4|0;do{if((bc&255)>(d[bd+h|0]|0)){g=a[a5+2|0]|0;if(g<<24>>24==0){bg=bc;bh=bd;break}aC=b[(c[277225]|0)+((g&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){bi=b[(c[277221]|0)+(((aC&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{g=c[277228]&65535;i=aC&-2048;f=g&-2048;aA=(i&65535)>(f&65535)?i-f&65535:0;f=aC&2016;i=g&2016;if((f&65535)>(i&65535)){bj=(f-i&65535)+aA&65535}else{bj=aA}aA=aC&31;i=g&31;if((aA&65535)<=(i&65535)){bi=bj;break}bi=(aA-i&65535)+bj&65535}}while(0);aC=a7+5|0;b[(c[277218]|0)+(aC<<1)>>1]=bi;b[(c[277218]|0)+(h<<1)>>1]=bi;i=a[1108909]|0;a[(c[277219]|0)+aC|0]=i;a[(c[277219]|0)+h|0]=i;bg=a[1108908]|0;bh=c[277219]|0}else{bg=bc;bh=bd}}while(0);h=a7+6|0;do{if((bg&255)>(d[bh+h|0]|0)){i=a[a5+3|0]|0;if(i<<24>>24==0){bk=bg;bl=bh;break}aC=b[(c[277225]|0)+((i&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){bm=b[(c[277221]|0)+(((aC&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{i=c[277228]&65535;aA=aC&-2048;g=i&-2048;f=(aA&65535)>(g&65535)?aA-g&65535:0;g=aC&2016;aA=i&2016;if((g&65535)>(aA&65535)){bn=(g-aA&65535)+f&65535}else{bn=f}f=aC&31;aA=i&31;if((f&65535)<=(aA&65535)){bm=bn;break}bm=(f-aA&65535)+bn&65535}}while(0);aC=a7+7|0;b[(c[277218]|0)+(aC<<1)>>1]=bm;b[(c[277218]|0)+(h<<1)>>1]=bm;aA=a[1108909]|0;a[(c[277219]|0)+aC|0]=aA;a[(c[277219]|0)+h|0]=aA;bk=a[1108908]|0;bl=c[277219]|0}else{bk=bg;bl=bh}}while(0);h=a7+8|0;do{if((bk&255)>(d[bl+h|0]|0)){aA=a[a5+4|0]|0;if(aA<<24>>24==0){bo=bk;bp=bl;break}aC=b[(c[277225]|0)+((aA&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){bq=b[(c[277221]|0)+(((aC&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{aA=c[277228]&65535;f=aC&-2048;i=aA&-2048;g=(f&65535)>(i&65535)?f-i&65535:0;i=aC&2016;f=aA&2016;if((i&65535)>(f&65535)){br=(i-f&65535)+g&65535}else{br=g}g=aC&31;f=aA&31;if((g&65535)<=(f&65535)){bq=br;break}bq=(g-f&65535)+br&65535}}while(0);aC=a7+9|0;b[(c[277218]|0)+(aC<<1)>>1]=bq;b[(c[277218]|0)+(h<<1)>>1]=bq;f=a[1108909]|0;a[(c[277219]|0)+aC|0]=f;a[(c[277219]|0)+h|0]=f;bo=a[1108908]|0;bp=c[277219]|0}else{bo=bk;bp=bl}}while(0);h=a7+10|0;do{if((bo&255)>(d[bp+h|0]|0)){f=a[a5+5|0]|0;if(f<<24>>24==0){bs=bo;bt=bp;break}aC=b[(c[277225]|0)+((f&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){bu=b[(c[277221]|0)+(((aC&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{f=c[277228]&65535;g=aC&-2048;aA=f&-2048;i=(g&65535)>(aA&65535)?g-aA&65535:0;aA=aC&2016;g=f&2016;if((aA&65535)>(g&65535)){bv=(aA-g&65535)+i&65535}else{bv=i}i=aC&31;g=f&31;if((i&65535)<=(g&65535)){bu=bv;break}bu=(i-g&65535)+bv&65535}}while(0);aC=a7+11|0;b[(c[277218]|0)+(aC<<1)>>1]=bu;b[(c[277218]|0)+(h<<1)>>1]=bu;g=a[1108909]|0;a[(c[277219]|0)+aC|0]=g;a[(c[277219]|0)+h|0]=g;bs=a[1108908]|0;bt=c[277219]|0}else{bs=bo;bt=bp}}while(0);h=a7+12|0;do{if((bs&255)>(d[bt+h|0]|0)){g=a[a5+6|0]|0;if(g<<24>>24==0){bw=bs;bx=bt;break}aC=b[(c[277225]|0)+((g&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){by=b[(c[277221]|0)+(((aC&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{g=c[277228]&65535;i=aC&-2048;f=g&-2048;aA=(i&65535)>(f&65535)?i-f&65535:0;f=aC&2016;i=g&2016;if((f&65535)>(i&65535)){bz=(f-i&65535)+aA&65535}else{bz=aA}aA=aC&31;i=g&31;if((aA&65535)<=(i&65535)){by=bz;break}by=(aA-i&65535)+bz&65535}}while(0);aC=a7+13|0;b[(c[277218]|0)+(aC<<1)>>1]=by;b[(c[277218]|0)+(h<<1)>>1]=by;i=a[1108909]|0;a[(c[277219]|0)+aC|0]=i;a[(c[277219]|0)+h|0]=i;bw=a[1108908]|0;bx=c[277219]|0}else{bw=bs;bx=bt}}while(0);h=a7+14|0;do{if((bw&255)>(d[bx+h|0]|0)){i=a[a5+7|0]|0;if(i<<24>>24==0){break}aC=b[(c[277225]|0)+((i&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){bA=b[(c[277221]|0)+(((aC&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{i=c[277228]&65535;aA=aC&-2048;g=i&-2048;f=(aA&65535)>(g&65535)?aA-g&65535:0;g=aC&2016;aA=i&2016;if((g&65535)>(aA&65535)){bB=(g-aA&65535)+f&65535}else{bB=f}f=aC&31;aA=i&31;if((f&65535)<=(aA&65535)){bA=bB;break}bA=(f-aA&65535)+bB&65535}}while(0);aC=a7+15|0;b[(c[277218]|0)+(aC<<1)>>1]=bA;b[(c[277218]|0)+(h<<1)>>1]=bA;aA=a[1108909]|0;a[(c[277219]|0)+aC|0]=aA;a[(c[277219]|0)+h|0]=aA}}while(0);h=a6-1|0;if((h|0)<=0){break}a5=a5-8|0;a6=h;a7=(c[277223]|0)+a7|0}return}}
function VF(f,g,h,i,j,k){f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0;l=f&1023;m=c[348606]|0;n=(l<<m)+(c[348604]|0)|0;if((f&256|0)==0){o=n}else{o=(c[348602]|0)+n|0}n=o&65535;o=n>>>(m>>>0);m=(f&16384|0)!=0;p=o<<6;do{if(m){q=(c[348622]|0)+p|0;if((a[(c[348618]|0)+o|0]|0)!=0){r=q;break}s=fi[c[348636]&63](q,n,l)|0;a[(c[348618]|0)+o|0]=s;r=q}else{q=(c[348624]|0)+p|0;if((a[(c[348620]|0)+o|0]|0)!=0){r=q;break}s=fi[c[348638]&63](q,n,l)|0;a[(c[348620]|0)+o|0]=s;r=q}}while(0);if((a[(c[348620]|0)+o|0]|0)==2){return}if((a[1394464]|0)==0){t=1106168+((f>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){o=d[1044485]|0;c[276541]=7080+(o<<5);l=0;do{n=l<<1&2;p=l&2;q=l&4;s=0;do{b[1125528+(l<<9)+(s<<1)>>1]=d[(s>>>1&28|p)+(7080+(o<<5))|0]<<6|d[(s<<2&28|n)+(7080+(o<<5))|0]<<11|d[(s>>>3&24|q)+(7080+(o<<5))|0];s=s+1|0;}while(s>>>0<256);l=l+1|0;}while(l>>>0<8);a[1106089]=0}t=1125528+((f>>>10&7)<<9)|0}c[277226]=t;c[277225]=(a[1108928]|0)!=0?1393712:t;if((f&49152|0)==0){if((k|0)<=0){return}t=i&255;l=t-1&255;o=l<<24>>24==0;s=r+j|0;q=k;n=g;while(1){switch(h|0){case 5:{u=t;v=9365;break};case 7:{v=9389;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+n|0]|0)){p=a[s]|0;if(p<<24>>24==0){break}w=b[(c[277225]|0)+((p&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){x=b[(c[277221]|0)+(((w&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{p=c[277228]&65535;y=w&-2048;z=p&-2048;A=(y&65535)>(z&65535)?y-z&65535:0;z=w&2016;y=p&2016;if((z&65535)>(y&65535)){B=(z-y&65535)+A&65535}else{B=A}A=w&31;y=p&31;if((A&65535)<=(y&65535)){x=B;break}x=(A-y&65535)+B&65535}}while(0);b[(c[277218]|0)+(n<<1)>>1]=x;if((a[1108928]|0)==0){C=b[(c[277221]|0)+(((e[(c[277213]|0)+(n+2<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{C=0}w=n+1|0;b[(c[277218]|0)+(w<<1)>>1]=C;y=a[1108909]|0;a[(c[277219]|0)+w|0]=y;a[(c[277219]|0)+n|0]=y}}while(0);if(!o){D=l;v=9317}break};case 1:{D=t;v=9317;break};case 2:{E=t;v=9329;break};case 4:{F=t;v=9353;break};case 3:{G=t;v=9341;break};case 6:{H=t;v=9377;break};default:{}}if((v|0)==9317){v=0;y=n+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+y|0]|0)){w=a[s+1|0]|0;if(w<<24>>24==0){break}A=b[(c[277225]|0)+((w&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){I=b[(c[277221]|0)+(((A&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{w=c[277228]&65535;p=A&-2048;z=w&-2048;J=(p&65535)>(z&65535)?p-z&65535:0;z=A&2016;p=w&2016;if((z&65535)>(p&65535)){K=(z-p&65535)+J&65535}else{K=J}J=A&31;p=w&31;if((J&65535)<=(p&65535)){I=K;break}I=(J-p&65535)+K&65535}}while(0);b[(c[277218]|0)+(y<<1)>>1]=I;if((a[1108928]|0)==0){L=b[(c[277221]|0)+(((e[(c[277213]|0)+(n+4<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{L=0}A=n+3|0;b[(c[277218]|0)+(A<<1)>>1]=L;p=a[1108909]|0;a[(c[277219]|0)+A|0]=p;a[(c[277219]|0)+y|0]=p}}while(0);y=D-1&255;if(y<<24>>24!=0){E=y;v=9329}}if((v|0)==9329){v=0;y=n+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+y|0]|0)){p=a[s+2|0]|0;if(p<<24>>24==0){break}A=b[(c[277225]|0)+((p&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){M=b[(c[277221]|0)+(((A&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{p=c[277228]&65535;J=A&-2048;w=p&-2048;z=(J&65535)>(w&65535)?J-w&65535:0;w=A&2016;J=p&2016;if((w&65535)>(J&65535)){N=(w-J&65535)+z&65535}else{N=z}z=A&31;J=p&31;if((z&65535)<=(J&65535)){M=N;break}M=(z-J&65535)+N&65535}}while(0);b[(c[277218]|0)+(y<<1)>>1]=M;if((a[1108928]|0)==0){O=b[(c[277221]|0)+(((e[(c[277213]|0)+(n+6<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{O=0}A=n+5|0;b[(c[277218]|0)+(A<<1)>>1]=O;J=a[1108909]|0;a[(c[277219]|0)+A|0]=J;a[(c[277219]|0)+y|0]=J}}while(0);y=E-1&255;if(y<<24>>24!=0){G=y;v=9341}}if((v|0)==9341){v=0;y=n+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+y|0]|0)){J=a[s+3|0]|0;if(J<<24>>24==0){break}A=b[(c[277225]|0)+((J&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){P=b[(c[277221]|0)+(((A&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{J=c[277228]&65535;z=A&-2048;p=J&-2048;w=(z&65535)>(p&65535)?z-p&65535:0;p=A&2016;z=J&2016;if((p&65535)>(z&65535)){Q=(p-z&65535)+w&65535}else{Q=w}w=A&31;z=J&31;if((w&65535)<=(z&65535)){P=Q;break}P=(w-z&65535)+Q&65535}}while(0);b[(c[277218]|0)+(y<<1)>>1]=P;if((a[1108928]|0)==0){R=b[(c[277221]|0)+(((e[(c[277213]|0)+(n+8<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{R=0}A=n+7|0;b[(c[277218]|0)+(A<<1)>>1]=R;z=a[1108909]|0;a[(c[277219]|0)+A|0]=z;a[(c[277219]|0)+y|0]=z}}while(0);y=G-1&255;if(y<<24>>24!=0){F=y;v=9353}}if((v|0)==9353){v=0;y=n+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+y|0]|0)){z=a[s+4|0]|0;if(z<<24>>24==0){break}A=b[(c[277225]|0)+((z&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){S=b[(c[277221]|0)+(((A&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{z=c[277228]&65535;w=A&-2048;J=z&-2048;p=(w&65535)>(J&65535)?w-J&65535:0;J=A&2016;w=z&2016;if((J&65535)>(w&65535)){T=(J-w&65535)+p&65535}else{T=p}p=A&31;w=z&31;if((p&65535)<=(w&65535)){S=T;break}S=(p-w&65535)+T&65535}}while(0);b[(c[277218]|0)+(y<<1)>>1]=S;if((a[1108928]|0)==0){U=b[(c[277221]|0)+(((e[(c[277213]|0)+(n+10<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{U=0}A=n+9|0;b[(c[277218]|0)+(A<<1)>>1]=U;w=a[1108909]|0;a[(c[277219]|0)+A|0]=w;a[(c[277219]|0)+y|0]=w}}while(0);y=F-1&255;if(y<<24>>24!=0){u=y;v=9365}}if((v|0)==9365){v=0;y=n+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+y|0]|0)){w=a[s+5|0]|0;if(w<<24>>24==0){break}A=b[(c[277225]|0)+((w&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){V=b[(c[277221]|0)+(((A&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{w=c[277228]&65535;p=A&-2048;z=w&-2048;J=(p&65535)>(z&65535)?p-z&65535:0;z=A&2016;p=w&2016;if((z&65535)>(p&65535)){W=(z-p&65535)+J&65535}else{W=J}J=A&31;p=w&31;if((J&65535)<=(p&65535)){V=W;break}V=(J-p&65535)+W&65535}}while(0);b[(c[277218]|0)+(y<<1)>>1]=V;if((a[1108928]|0)==0){X=b[(c[277221]|0)+(((e[(c[277213]|0)+(n+12<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{X=0}A=n+11|0;b[(c[277218]|0)+(A<<1)>>1]=X;p=a[1108909]|0;a[(c[277219]|0)+A|0]=p;a[(c[277219]|0)+y|0]=p}}while(0);y=u-1&255;if(y<<24>>24!=0){H=y;v=9377}}if((v|0)==9377){v=0;y=n+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+y|0]|0)){p=a[s+6|0]|0;if(p<<24>>24==0){break}A=b[(c[277225]|0)+((p&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){Y=b[(c[277221]|0)+(((A&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{p=c[277228]&65535;J=A&-2048;w=p&-2048;z=(J&65535)>(w&65535)?J-w&65535:0;w=A&2016;J=p&2016;if((w&65535)>(J&65535)){Z=(w-J&65535)+z&65535}else{Z=z}z=A&31;J=p&31;if((z&65535)<=(J&65535)){Y=Z;break}Y=(z-J&65535)+Z&65535}}while(0);b[(c[277218]|0)+(y<<1)>>1]=Y;if((a[1108928]|0)==0){_=b[(c[277221]|0)+(((e[(c[277213]|0)+(n+14<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{_=0}A=n+13|0;b[(c[277218]|0)+(A<<1)>>1]=_;J=a[1108909]|0;a[(c[277219]|0)+A|0]=J;a[(c[277219]|0)+y|0]=J}}while(0);if(H<<24>>24!=1){v=9389}}do{if((v|0)==9389){v=0;y=n+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+y|0]|0)){break}J=a[s+7|0]|0;if(J<<24>>24==0){break}A=b[(c[277225]|0)+((J&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){$=b[(c[277221]|0)+(((A&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{J=c[277228]&65535;z=A&-2048;p=J&-2048;w=(z&65535)>(p&65535)?z-p&65535:0;p=A&2016;z=J&2016;if((p&65535)>(z&65535)){aa=(p-z&65535)+w&65535}else{aa=w}w=A&31;z=J&31;if((w&65535)<=(z&65535)){$=aa;break}$=(w-z&65535)+aa&65535}}while(0);b[(c[277218]|0)+(y<<1)>>1]=$;if((a[1108928]|0)==0){ab=b[(c[277221]|0)+(((e[(c[277213]|0)+(n+16<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{ab=0}A=n+15|0;b[(c[277218]|0)+(A<<1)>>1]=ab;z=a[1108909]|0;a[(c[277219]|0)+A|0]=z;a[(c[277219]|0)+y|0]=z}}while(0);z=q-1|0;if((z|0)>0){s=s+8|0;q=z;n=(c[277223]|0)+n|0}else{break}}return}if((f&32768|0)==0){if((k|0)<=0){return}f=i&255;n=f-1&255;q=n<<24>>24==0;s=r+j|0;ab=k;$=g;while(1){switch(h|0){case 1:{ac=f;v=9417;break};case 5:{ad=f;v=9465;break};case 6:{ae=f;v=9477;break};case 7:{v=9489;break};case 2:{af=f;v=9429;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+$|0]|0)){aa=a[s+7|0]|0;if(aa<<24>>24==0){break}H=b[(c[277225]|0)+((aa&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){ag=b[(c[277221]|0)+(((H&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{aa=c[277228]&65535;_=H&-2048;Y=aa&-2048;Z=(_&65535)>(Y&65535)?_-Y&65535:0;Y=H&2016;_=aa&2016;if((Y&65535)>(_&65535)){ah=(Y-_&65535)+Z&65535}else{ah=Z}Z=H&31;_=aa&31;if((Z&65535)<=(_&65535)){ag=ah;break}ag=(Z-_&65535)+ah&65535}}while(0);b[(c[277218]|0)+($<<1)>>1]=ag;if((a[1108928]|0)==0){ai=b[(c[277221]|0)+(((e[(c[277213]|0)+($+2<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{ai=0}H=$+1|0;b[(c[277218]|0)+(H<<1)>>1]=ai;y=a[1108909]|0;a[(c[277219]|0)+H|0]=y;a[(c[277219]|0)+$|0]=y}}while(0);if(!q){ac=n;v=9417}break};case 3:{aj=f;v=9441;break};case 4:{ak=f;v=9453;break};default:{}}if((v|0)==9417){v=0;y=$+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+y|0]|0)){H=a[s+6|0]|0;if(H<<24>>24==0){break}_=b[(c[277225]|0)+((H&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){al=b[(c[277221]|0)+(((_&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{H=c[277228]&65535;Z=_&-2048;aa=H&-2048;Y=(Z&65535)>(aa&65535)?Z-aa&65535:0;aa=_&2016;Z=H&2016;if((aa&65535)>(Z&65535)){am=(aa-Z&65535)+Y&65535}else{am=Y}Y=_&31;Z=H&31;if((Y&65535)<=(Z&65535)){al=am;break}al=(Y-Z&65535)+am&65535}}while(0);b[(c[277218]|0)+(y<<1)>>1]=al;if((a[1108928]|0)==0){an=b[(c[277221]|0)+(((e[(c[277213]|0)+($+4<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{an=0}_=$+3|0;b[(c[277218]|0)+(_<<1)>>1]=an;Z=a[1108909]|0;a[(c[277219]|0)+_|0]=Z;a[(c[277219]|0)+y|0]=Z}}while(0);y=ac-1&255;if(y<<24>>24!=0){af=y;v=9429}}if((v|0)==9429){v=0;y=$+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+y|0]|0)){Z=a[s+5|0]|0;if(Z<<24>>24==0){break}_=b[(c[277225]|0)+((Z&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){ao=b[(c[277221]|0)+(((_&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{Z=c[277228]&65535;Y=_&-2048;H=Z&-2048;aa=(Y&65535)>(H&65535)?Y-H&65535:0;H=_&2016;Y=Z&2016;if((H&65535)>(Y&65535)){ap=(H-Y&65535)+aa&65535}else{ap=aa}aa=_&31;Y=Z&31;if((aa&65535)<=(Y&65535)){ao=ap;break}ao=(aa-Y&65535)+ap&65535}}while(0);b[(c[277218]|0)+(y<<1)>>1]=ao;if((a[1108928]|0)==0){aq=b[(c[277221]|0)+(((e[(c[277213]|0)+($+6<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{aq=0}_=$+5|0;b[(c[277218]|0)+(_<<1)>>1]=aq;Y=a[1108909]|0;a[(c[277219]|0)+_|0]=Y;a[(c[277219]|0)+y|0]=Y}}while(0);y=af-1&255;if(y<<24>>24!=0){aj=y;v=9441}}if((v|0)==9441){v=0;y=$+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+y|0]|0)){Y=a[s+4|0]|0;if(Y<<24>>24==0){break}_=b[(c[277225]|0)+((Y&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){ar=b[(c[277221]|0)+(((_&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{Y=c[277228]&65535;aa=_&-2048;Z=Y&-2048;H=(aa&65535)>(Z&65535)?aa-Z&65535:0;Z=_&2016;aa=Y&2016;if((Z&65535)>(aa&65535)){as=(Z-aa&65535)+H&65535}else{as=H}H=_&31;aa=Y&31;if((H&65535)<=(aa&65535)){ar=as;break}ar=(H-aa&65535)+as&65535}}while(0);b[(c[277218]|0)+(y<<1)>>1]=ar;if((a[1108928]|0)==0){at=b[(c[277221]|0)+(((e[(c[277213]|0)+($+8<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{at=0}_=$+7|0;b[(c[277218]|0)+(_<<1)>>1]=at;aa=a[1108909]|0;a[(c[277219]|0)+_|0]=aa;a[(c[277219]|0)+y|0]=aa}}while(0);y=aj-1&255;if(y<<24>>24!=0){ak=y;v=9453}}if((v|0)==9453){v=0;y=$+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+y|0]|0)){aa=a[s+3|0]|0;if(aa<<24>>24==0){break}_=b[(c[277225]|0)+((aa&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){au=b[(c[277221]|0)+(((_&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{aa=c[277228]&65535;H=_&-2048;Y=aa&-2048;Z=(H&65535)>(Y&65535)?H-Y&65535:0;Y=_&2016;H=aa&2016;if((Y&65535)>(H&65535)){av=(Y-H&65535)+Z&65535}else{av=Z}Z=_&31;H=aa&31;if((Z&65535)<=(H&65535)){au=av;break}au=(Z-H&65535)+av&65535}}while(0);b[(c[277218]|0)+(y<<1)>>1]=au;if((a[1108928]|0)==0){aw=b[(c[277221]|0)+(((e[(c[277213]|0)+($+10<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{aw=0}_=$+9|0;b[(c[277218]|0)+(_<<1)>>1]=aw;H=a[1108909]|0;a[(c[277219]|0)+_|0]=H;a[(c[277219]|0)+y|0]=H}}while(0);y=ak-1&255;if(y<<24>>24!=0){ad=y;v=9465}}if((v|0)==9465){v=0;y=$+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+y|0]|0)){H=a[s+2|0]|0;if(H<<24>>24==0){break}_=b[(c[277225]|0)+((H&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){ax=b[(c[277221]|0)+(((_&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{H=c[277228]&65535;Z=_&-2048;aa=H&-2048;Y=(Z&65535)>(aa&65535)?Z-aa&65535:0;aa=_&2016;Z=H&2016;if((aa&65535)>(Z&65535)){ay=(aa-Z&65535)+Y&65535}else{ay=Y}Y=_&31;Z=H&31;if((Y&65535)<=(Z&65535)){ax=ay;break}ax=(Y-Z&65535)+ay&65535}}while(0);b[(c[277218]|0)+(y<<1)>>1]=ax;if((a[1108928]|0)==0){az=b[(c[277221]|0)+(((e[(c[277213]|0)+($+12<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{az=0}_=$+11|0;b[(c[277218]|0)+(_<<1)>>1]=az;Z=a[1108909]|0;a[(c[277219]|0)+_|0]=Z;a[(c[277219]|0)+y|0]=Z}}while(0);y=ad-1&255;if(y<<24>>24!=0){ae=y;v=9477}}if((v|0)==9477){v=0;y=$+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+y|0]|0)){Z=a[s+1|0]|0;if(Z<<24>>24==0){break}_=b[(c[277225]|0)+((Z&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aA=b[(c[277221]|0)+(((_&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{Z=c[277228]&65535;Y=_&-2048;H=Z&-2048;aa=(Y&65535)>(H&65535)?Y-H&65535:0;H=_&2016;Y=Z&2016;if((H&65535)>(Y&65535)){aB=(H-Y&65535)+aa&65535}else{aB=aa}aa=_&31;Y=Z&31;if((aa&65535)<=(Y&65535)){aA=aB;break}aA=(aa-Y&65535)+aB&65535}}while(0);b[(c[277218]|0)+(y<<1)>>1]=aA;if((a[1108928]|0)==0){aC=b[(c[277221]|0)+(((e[(c[277213]|0)+($+14<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{aC=0}_=$+13|0;b[(c[277218]|0)+(_<<1)>>1]=aC;Y=a[1108909]|0;a[(c[277219]|0)+_|0]=Y;a[(c[277219]|0)+y|0]=Y}}while(0);if(ae<<24>>24!=1){v=9489}}do{if((v|0)==9489){v=0;y=$+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+y|0]|0)){break}Y=a[s]|0;if(Y<<24>>24==0){break}_=b[(c[277225]|0)+((Y&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aD=b[(c[277221]|0)+(((_&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{Y=c[277228]&65535;aa=_&-2048;Z=Y&-2048;H=(aa&65535)>(Z&65535)?aa-Z&65535:0;Z=_&2016;aa=Y&2016;if((Z&65535)>(aa&65535)){aE=(Z-aa&65535)+H&65535}else{aE=H}H=_&31;aa=Y&31;if((H&65535)<=(aa&65535)){aD=aE;break}aD=(H-aa&65535)+aE&65535}}while(0);b[(c[277218]|0)+(y<<1)>>1]=aD;if((a[1108928]|0)==0){aF=b[(c[277221]|0)+(((e[(c[277213]|0)+($+16<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{aF=0}_=$+15|0;b[(c[277218]|0)+(_<<1)>>1]=aF;aa=a[1108909]|0;a[(c[277219]|0)+_|0]=aa;a[(c[277219]|0)+y|0]=aa}}while(0);aa=ab-1|0;if((aa|0)>0){s=s+8|0;ab=aa;$=(c[277223]|0)+$|0}else{break}}return}$=r+(56-j)|0;j=(k|0)>0;if(m){if(!j){return}m=i&255;r=m-1&255;ab=r<<24>>24==0;s=$;aF=k;aD=g;while(1){switch(h|0){case 1:{aG=m;v=9616;break};case 4:{aH=m;v=9652;break};case 5:{aI=m;v=9664;break};case 3:{aJ=m;v=9640;break};case 2:{aK=m;v=9628;break};case 7:{v=9688;break};case 6:{aL=m;v=9676;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+aD|0]|0)){aE=a[s+7|0]|0;if(aE<<24>>24==0){break}ae=b[(c[277225]|0)+((aE&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aM=b[(c[277221]|0)+(((ae&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{aE=c[277228]&65535;aC=ae&-2048;aA=aE&-2048;aB=(aC&65535)>(aA&65535)?aC-aA&65535:0;aA=ae&2016;aC=aE&2016;if((aA&65535)>(aC&65535)){aN=(aA-aC&65535)+aB&65535}else{aN=aB}aB=ae&31;aC=aE&31;if((aB&65535)<=(aC&65535)){aM=aN;break}aM=(aB-aC&65535)+aN&65535}}while(0);b[(c[277218]|0)+(aD<<1)>>1]=aM;if((a[1108928]|0)==0){aO=b[(c[277221]|0)+(((e[(c[277213]|0)+(aD+2<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{aO=0}ae=aD+1|0;b[(c[277218]|0)+(ae<<1)>>1]=aO;y=a[1108909]|0;a[(c[277219]|0)+ae|0]=y;a[(c[277219]|0)+aD|0]=y}}while(0);if(!ab){aG=r;v=9616}break};default:{}}if((v|0)==9616){v=0;y=aD+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+y|0]|0)){ae=a[s+6|0]|0;if(ae<<24>>24==0){break}aC=b[(c[277225]|0)+((ae&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aP=b[(c[277221]|0)+(((aC&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{ae=c[277228]&65535;aB=aC&-2048;aE=ae&-2048;aA=(aB&65535)>(aE&65535)?aB-aE&65535:0;aE=aC&2016;aB=ae&2016;if((aE&65535)>(aB&65535)){aQ=(aE-aB&65535)+aA&65535}else{aQ=aA}aA=aC&31;aB=ae&31;if((aA&65535)<=(aB&65535)){aP=aQ;break}aP=(aA-aB&65535)+aQ&65535}}while(0);b[(c[277218]|0)+(y<<1)>>1]=aP;if((a[1108928]|0)==0){aR=b[(c[277221]|0)+(((e[(c[277213]|0)+(aD+4<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{aR=0}aC=aD+3|0;b[(c[277218]|0)+(aC<<1)>>1]=aR;aB=a[1108909]|0;a[(c[277219]|0)+aC|0]=aB;a[(c[277219]|0)+y|0]=aB}}while(0);y=aG-1&255;if(y<<24>>24!=0){aK=y;v=9628}}if((v|0)==9628){v=0;y=aD+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+y|0]|0)){aB=a[s+5|0]|0;if(aB<<24>>24==0){break}aC=b[(c[277225]|0)+((aB&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aS=b[(c[277221]|0)+(((aC&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{aB=c[277228]&65535;aA=aC&-2048;ae=aB&-2048;aE=(aA&65535)>(ae&65535)?aA-ae&65535:0;ae=aC&2016;aA=aB&2016;if((ae&65535)>(aA&65535)){aT=(ae-aA&65535)+aE&65535}else{aT=aE}aE=aC&31;aA=aB&31;if((aE&65535)<=(aA&65535)){aS=aT;break}aS=(aE-aA&65535)+aT&65535}}while(0);b[(c[277218]|0)+(y<<1)>>1]=aS;if((a[1108928]|0)==0){aU=b[(c[277221]|0)+(((e[(c[277213]|0)+(aD+6<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{aU=0}aC=aD+5|0;b[(c[277218]|0)+(aC<<1)>>1]=aU;aA=a[1108909]|0;a[(c[277219]|0)+aC|0]=aA;a[(c[277219]|0)+y|0]=aA}}while(0);y=aK-1&255;if(y<<24>>24!=0){aJ=y;v=9640}}if((v|0)==9640){v=0;y=aD+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+y|0]|0)){aA=a[s+4|0]|0;if(aA<<24>>24==0){break}aC=b[(c[277225]|0)+((aA&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aV=b[(c[277221]|0)+(((aC&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{aA=c[277228]&65535;aE=aC&-2048;aB=aA&-2048;ae=(aE&65535)>(aB&65535)?aE-aB&65535:0;aB=aC&2016;aE=aA&2016;if((aB&65535)>(aE&65535)){aW=(aB-aE&65535)+ae&65535}else{aW=ae}ae=aC&31;aE=aA&31;if((ae&65535)<=(aE&65535)){aV=aW;break}aV=(ae-aE&65535)+aW&65535}}while(0);b[(c[277218]|0)+(y<<1)>>1]=aV;if((a[1108928]|0)==0){aX=b[(c[277221]|0)+(((e[(c[277213]|0)+(aD+8<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{aX=0}aC=aD+7|0;b[(c[277218]|0)+(aC<<1)>>1]=aX;aE=a[1108909]|0;a[(c[277219]|0)+aC|0]=aE;a[(c[277219]|0)+y|0]=aE}}while(0);y=aJ-1&255;if(y<<24>>24!=0){aH=y;v=9652}}if((v|0)==9652){v=0;y=aD+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+y|0]|0)){aE=a[s+3|0]|0;if(aE<<24>>24==0){break}aC=b[(c[277225]|0)+((aE&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aY=b[(c[277221]|0)+(((aC&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{aE=c[277228]&65535;ae=aC&-2048;aA=aE&-2048;aB=(ae&65535)>(aA&65535)?ae-aA&65535:0;aA=aC&2016;ae=aE&2016;if((aA&65535)>(ae&65535)){aZ=(aA-ae&65535)+aB&65535}else{aZ=aB}aB=aC&31;ae=aE&31;if((aB&65535)<=(ae&65535)){aY=aZ;break}aY=(aB-ae&65535)+aZ&65535}}while(0);b[(c[277218]|0)+(y<<1)>>1]=aY;if((a[1108928]|0)==0){a_=b[(c[277221]|0)+(((e[(c[277213]|0)+(aD+10<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{a_=0}aC=aD+9|0;b[(c[277218]|0)+(aC<<1)>>1]=a_;ae=a[1108909]|0;a[(c[277219]|0)+aC|0]=ae;a[(c[277219]|0)+y|0]=ae}}while(0);y=aH-1&255;if(y<<24>>24!=0){aI=y;v=9664}}if((v|0)==9664){v=0;y=aD+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+y|0]|0)){ae=a[s+2|0]|0;if(ae<<24>>24==0){break}aC=b[(c[277225]|0)+((ae&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){a$=b[(c[277221]|0)+(((aC&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{ae=c[277228]&65535;aB=aC&-2048;aE=ae&-2048;aA=(aB&65535)>(aE&65535)?aB-aE&65535:0;aE=aC&2016;aB=ae&2016;if((aE&65535)>(aB&65535)){a0=(aE-aB&65535)+aA&65535}else{a0=aA}aA=aC&31;aB=ae&31;if((aA&65535)<=(aB&65535)){a$=a0;break}a$=(aA-aB&65535)+a0&65535}}while(0);b[(c[277218]|0)+(y<<1)>>1]=a$;if((a[1108928]|0)==0){a1=b[(c[277221]|0)+(((e[(c[277213]|0)+(aD+12<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{a1=0}aC=aD+11|0;b[(c[277218]|0)+(aC<<1)>>1]=a1;aB=a[1108909]|0;a[(c[277219]|0)+aC|0]=aB;a[(c[277219]|0)+y|0]=aB}}while(0);y=aI-1&255;if(y<<24>>24!=0){aL=y;v=9676}}if((v|0)==9676){v=0;y=aD+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+y|0]|0)){aB=a[s+1|0]|0;if(aB<<24>>24==0){break}aC=b[(c[277225]|0)+((aB&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){a2=b[(c[277221]|0)+(((aC&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{aB=c[277228]&65535;aA=aC&-2048;ae=aB&-2048;aE=(aA&65535)>(ae&65535)?aA-ae&65535:0;ae=aC&2016;aA=aB&2016;if((ae&65535)>(aA&65535)){a3=(ae-aA&65535)+aE&65535}else{a3=aE}aE=aC&31;aA=aB&31;if((aE&65535)<=(aA&65535)){a2=a3;break}a2=(aE-aA&65535)+a3&65535}}while(0);b[(c[277218]|0)+(y<<1)>>1]=a2;if((a[1108928]|0)==0){a4=b[(c[277221]|0)+(((e[(c[277213]|0)+(aD+14<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{a4=0}aC=aD+13|0;b[(c[277218]|0)+(aC<<1)>>1]=a4;aA=a[1108909]|0;a[(c[277219]|0)+aC|0]=aA;a[(c[277219]|0)+y|0]=aA}}while(0);if(aL<<24>>24!=1){v=9688}}do{if((v|0)==9688){v=0;y=aD+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+y|0]|0)){break}aA=a[s]|0;if(aA<<24>>24==0){break}aC=b[(c[277225]|0)+((aA&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){a5=b[(c[277221]|0)+(((aC&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{aA=c[277228]&65535;aE=aC&-2048;aB=aA&-2048;ae=(aE&65535)>(aB&65535)?aE-aB&65535:0;aB=aC&2016;aE=aA&2016;if((aB&65535)>(aE&65535)){a6=(aB-aE&65535)+ae&65535}else{a6=ae}ae=aC&31;aE=aA&31;if((ae&65535)<=(aE&65535)){a5=a6;break}a5=(ae-aE&65535)+a6&65535}}while(0);b[(c[277218]|0)+(y<<1)>>1]=a5;if((a[1108928]|0)==0){a7=b[(c[277221]|0)+(((e[(c[277213]|0)+(aD+16<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{a7=0}aC=aD+15|0;b[(c[277218]|0)+(aC<<1)>>1]=a7;aE=a[1108909]|0;a[(c[277219]|0)+aC|0]=aE;a[(c[277219]|0)+y|0]=aE}}while(0);aE=aF-1|0;if((aE|0)>0){s=s-8|0;aF=aE;aD=(c[277223]|0)+aD|0}else{break}}return}else{if(!j){return}j=i&255;i=j-1&255;aD=i<<24>>24==0;aF=$;$=k;k=g;while(1){switch(h|0){case 3:{a8=j;v=9543;break};case 5:{a9=j;v=9567;break};case 6:{ba=j;v=9579;break};case 4:{bb=j;v=9555;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+k|0]|0)){g=a[aF]|0;if(g<<24>>24==0){break}s=b[(c[277225]|0)+((g&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){bc=b[(c[277221]|0)+(((s&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{g=c[277228]&65535;a7=s&-2048;a5=g&-2048;a6=(a7&65535)>(a5&65535)?a7-a5&65535:0;a5=s&2016;a7=g&2016;if((a5&65535)>(a7&65535)){bd=(a5-a7&65535)+a6&65535}else{bd=a6}a6=s&31;a7=g&31;if((a6&65535)<=(a7&65535)){bc=bd;break}bc=(a6-a7&65535)+bd&65535}}while(0);b[(c[277218]|0)+(k<<1)>>1]=bc;if((a[1108928]|0)==0){be=b[(c[277221]|0)+(((e[(c[277213]|0)+(k+2<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{be=0}s=k+1|0;b[(c[277218]|0)+(s<<1)>>1]=be;y=a[1108909]|0;a[(c[277219]|0)+s|0]=y;a[(c[277219]|0)+k|0]=y}}while(0);if(!aD){bf=i;v=9519}break};case 1:{bf=j;v=9519;break};case 2:{bg=j;v=9531;break};case 7:{v=9591;break};default:{}}if((v|0)==9519){v=0;y=k+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+y|0]|0)){s=a[aF+1|0]|0;if(s<<24>>24==0){break}a7=b[(c[277225]|0)+((s&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){bh=b[(c[277221]|0)+(((a7&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{s=c[277228]&65535;a6=a7&-2048;g=s&-2048;a5=(a6&65535)>(g&65535)?a6-g&65535:0;g=a7&2016;a6=s&2016;if((g&65535)>(a6&65535)){bi=(g-a6&65535)+a5&65535}else{bi=a5}a5=a7&31;a6=s&31;if((a5&65535)<=(a6&65535)){bh=bi;break}bh=(a5-a6&65535)+bi&65535}}while(0);b[(c[277218]|0)+(y<<1)>>1]=bh;if((a[1108928]|0)==0){bj=b[(c[277221]|0)+(((e[(c[277213]|0)+(k+4<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{bj=0}a7=k+3|0;b[(c[277218]|0)+(a7<<1)>>1]=bj;a6=a[1108909]|0;a[(c[277219]|0)+a7|0]=a6;a[(c[277219]|0)+y|0]=a6}}while(0);y=bf-1&255;if(y<<24>>24!=0){bg=y;v=9531}}if((v|0)==9531){v=0;y=k+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+y|0]|0)){a6=a[aF+2|0]|0;if(a6<<24>>24==0){break}a7=b[(c[277225]|0)+((a6&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){bk=b[(c[277221]|0)+(((a7&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{a6=c[277228]&65535;a5=a7&-2048;s=a6&-2048;g=(a5&65535)>(s&65535)?a5-s&65535:0;s=a7&2016;a5=a6&2016;if((s&65535)>(a5&65535)){bl=(s-a5&65535)+g&65535}else{bl=g}g=a7&31;a5=a6&31;if((g&65535)<=(a5&65535)){bk=bl;break}bk=(g-a5&65535)+bl&65535}}while(0);b[(c[277218]|0)+(y<<1)>>1]=bk;if((a[1108928]|0)==0){bm=b[(c[277221]|0)+(((e[(c[277213]|0)+(k+6<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{bm=0}a7=k+5|0;b[(c[277218]|0)+(a7<<1)>>1]=bm;a5=a[1108909]|0;a[(c[277219]|0)+a7|0]=a5;a[(c[277219]|0)+y|0]=a5}}while(0);y=bg-1&255;if(y<<24>>24!=0){a8=y;v=9543}}if((v|0)==9543){v=0;y=k+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+y|0]|0)){a5=a[aF+3|0]|0;if(a5<<24>>24==0){break}a7=b[(c[277225]|0)+((a5&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){bn=b[(c[277221]|0)+(((a7&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{a5=c[277228]&65535;g=a7&-2048;a6=a5&-2048;s=(g&65535)>(a6&65535)?g-a6&65535:0;a6=a7&2016;g=a5&2016;if((a6&65535)>(g&65535)){bo=(a6-g&65535)+s&65535}else{bo=s}s=a7&31;g=a5&31;if((s&65535)<=(g&65535)){bn=bo;break}bn=(s-g&65535)+bo&65535}}while(0);b[(c[277218]|0)+(y<<1)>>1]=bn;if((a[1108928]|0)==0){bp=b[(c[277221]|0)+(((e[(c[277213]|0)+(k+8<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{bp=0}a7=k+7|0;b[(c[277218]|0)+(a7<<1)>>1]=bp;g=a[1108909]|0;a[(c[277219]|0)+a7|0]=g;a[(c[277219]|0)+y|0]=g}}while(0);y=a8-1&255;if(y<<24>>24!=0){bb=y;v=9555}}if((v|0)==9555){v=0;y=k+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+y|0]|0)){g=a[aF+4|0]|0;if(g<<24>>24==0){break}a7=b[(c[277225]|0)+((g&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){bq=b[(c[277221]|0)+(((a7&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{g=c[277228]&65535;s=a7&-2048;a5=g&-2048;a6=(s&65535)>(a5&65535)?s-a5&65535:0;a5=a7&2016;s=g&2016;if((a5&65535)>(s&65535)){br=(a5-s&65535)+a6&65535}else{br=a6}a6=a7&31;s=g&31;if((a6&65535)<=(s&65535)){bq=br;break}bq=(a6-s&65535)+br&65535}}while(0);b[(c[277218]|0)+(y<<1)>>1]=bq;if((a[1108928]|0)==0){bs=b[(c[277221]|0)+(((e[(c[277213]|0)+(k+10<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{bs=0}a7=k+9|0;b[(c[277218]|0)+(a7<<1)>>1]=bs;s=a[1108909]|0;a[(c[277219]|0)+a7|0]=s;a[(c[277219]|0)+y|0]=s}}while(0);y=bb-1&255;if(y<<24>>24!=0){a9=y;v=9567}}if((v|0)==9567){v=0;y=k+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+y|0]|0)){s=a[aF+5|0]|0;if(s<<24>>24==0){break}a7=b[(c[277225]|0)+((s&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){bt=b[(c[277221]|0)+(((a7&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{s=c[277228]&65535;a6=a7&-2048;g=s&-2048;a5=(a6&65535)>(g&65535)?a6-g&65535:0;g=a7&2016;a6=s&2016;if((g&65535)>(a6&65535)){bu=(g-a6&65535)+a5&65535}else{bu=a5}a5=a7&31;a6=s&31;if((a5&65535)<=(a6&65535)){bt=bu;break}bt=(a5-a6&65535)+bu&65535}}while(0);b[(c[277218]|0)+(y<<1)>>1]=bt;if((a[1108928]|0)==0){bv=b[(c[277221]|0)+(((e[(c[277213]|0)+(k+12<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{bv=0}a7=k+11|0;b[(c[277218]|0)+(a7<<1)>>1]=bv;a6=a[1108909]|0;a[(c[277219]|0)+a7|0]=a6;a[(c[277219]|0)+y|0]=a6}}while(0);y=a9-1&255;if(y<<24>>24!=0){ba=y;v=9579}}if((v|0)==9579){v=0;y=k+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+y|0]|0)){a6=a[aF+6|0]|0;if(a6<<24>>24==0){break}a7=b[(c[277225]|0)+((a6&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){bw=b[(c[277221]|0)+(((a7&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{a6=c[277228]&65535;a5=a7&-2048;s=a6&-2048;g=(a5&65535)>(s&65535)?a5-s&65535:0;s=a7&2016;a5=a6&2016;if((s&65535)>(a5&65535)){bx=(s-a5&65535)+g&65535}else{bx=g}g=a7&31;a5=a6&31;if((g&65535)<=(a5&65535)){bw=bx;break}bw=(g-a5&65535)+bx&65535}}while(0);b[(c[277218]|0)+(y<<1)>>1]=bw;if((a[1108928]|0)==0){by=b[(c[277221]|0)+(((e[(c[277213]|0)+(k+14<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{by=0}a7=k+13|0;b[(c[277218]|0)+(a7<<1)>>1]=by;a5=a[1108909]|0;a[(c[277219]|0)+a7|0]=a5;a[(c[277219]|0)+y|0]=a5}}while(0);if(ba<<24>>24!=1){v=9591}}do{if((v|0)==9591){v=0;y=k+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+y|0]|0)){break}a5=a[aF+7|0]|0;if(a5<<24>>24==0){break}a7=b[(c[277225]|0)+((a5&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){bz=b[(c[277221]|0)+(((a7&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{a5=c[277228]&65535;g=a7&-2048;a6=a5&-2048;s=(g&65535)>(a6&65535)?g-a6&65535:0;a6=a7&2016;g=a5&2016;if((a6&65535)>(g&65535)){bA=(a6-g&65535)+s&65535}else{bA=s}s=a7&31;g=a5&31;if((s&65535)<=(g&65535)){bz=bA;break}bz=(s-g&65535)+bA&65535}}while(0);b[(c[277218]|0)+(y<<1)>>1]=bz;if((a[1108928]|0)==0){bB=b[(c[277221]|0)+(((e[(c[277213]|0)+(k+16<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{bB=0}a7=k+15|0;b[(c[277218]|0)+(a7<<1)>>1]=bB;g=a[1108909]|0;a[(c[277219]|0)+a7|0]=g;a[(c[277219]|0)+y|0]=g}}while(0);g=$-1|0;if((g|0)>0){aF=aF-8|0;$=g;k=(c[277223]|0)+k|0}else{break}}return}}function VG(e,f,g,h,i,j){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0,cf=0,cg=0,ch=0,ci=0,cj=0,ck=0,cl=0,cm=0,cn=0,co=0,cp=0,cq=0,cr=0,cs=0,ct=0,cu=0,cv=0,cw=0,cx=0,cy=0,cz=0,cA=0,cB=0,cC=0,cD=0,cE=0,cF=0,cG=0,cH=0,cI=0,cJ=0,cK=0,cL=0,cM=0,cN=0,cO=0,cP=0,cQ=0,cR=0,cS=0,cT=0,cU=0,cV=0,cW=0,cX=0,cY=0,cZ=0,c_=0,c$=0,c0=0,c1=0,c2=0,c3=0,c4=0,c5=0;k=e&1023;l=c[348606]|0;m=(k<<l)+(c[348604]|0)|0;if((e&256|0)==0){n=m}else{n=(c[348602]|0)+m|0}m=n&65535;n=m>>>(l>>>0);l=(e&16384|0)!=0;o=n<<6;do{if(l){p=(c[348622]|0)+o|0;if((a[(c[348618]|0)+n|0]|0)!=0){q=p;break}r=fi[c[348636]&63](p,m,k)|0;a[(c[348618]|0)+n|0]=r;q=p}else{p=(c[348624]|0)+o|0;if((a[(c[348620]|0)+n|0]|0)!=0){q=p;break}r=fi[c[348638]&63](p,m,k)|0;a[(c[348620]|0)+n|0]=r;q=p}}while(0);if((a[(c[348620]|0)+n|0]|0)==2){return}if((a[1394464]|0)==0){s=1106168+((e>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){n=d[1044485]|0;c[276541]=7080+(n<<5);k=0;do{m=k<<1&2;o=k&2;p=k&4;r=0;do{b[1125528+(k<<9)+(r<<1)>>1]=d[(r>>>1&28|o)+(7080+(n<<5))|0]<<6|d[(r<<2&28|m)+(7080+(n<<5))|0]<<11|d[(r>>>3&24|p)+(7080+(n<<5))|0];r=r+1|0;}while(r>>>0<256);k=k+1|0;}while(k>>>0<8);a[1106089]=0}s=1125528+((e>>>10&7)<<9)|0}c[277226]=s;c[277225]=(a[1108928]|0)!=0?1393712:s;if((e&49152|0)==0){if((j|0)<=0){return}s=h&255;k=s-1&255;n=k<<24>>24==0;r=q+i|0;p=j;m=f;while(1){switch(g|0){case 7:{t=9906;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+m|0]|0)){o=a[r]|0;u=o&255;if(o<<24>>24==0){break}do{if((a[1108928]|0)==0){o=b[(c[277225]|0)+(u<<1)>>1]|0;if((a[(c[277215]|0)+m|0]&32)!=0){v=b[(c[277221]|0)+((o&65535|67616)-(b[(c[277213]|0)+(m<<1)>>1]&63454)>>1<<1)>>1]|0;break}w=c[277228]&65535;x=o&-2048;y=w&-2048;z=(x&65535)>(y&65535)?x-y&65535:0;y=o&2016;x=w&2016;if((y&65535)>(x&65535)){A=(y-x&65535)+z&65535}else{A=z}z=o&31;o=w&31;if((z&65535)<=(o&65535)){v=A;break}v=(z-o&65535)+A&65535}else{o=b[(c[277225]|0)+(u<<1)>>1]|0;if((a[(c[277215]|0)+m|0]&32)==0){B=c[277228]&65535}else{B=b[(c[277213]|0)+(m<<1)>>1]|0}z=o&-2048;w=B&-2048;x=(z&65535)>(w&65535)?z-w&65535:0;w=o&2016;z=B&2016;if((w&65535)>(z&65535)){C=(w-z&65535)+x&65535}else{C=x}x=o&31;o=B&31;if((x&65535)<=(o&65535)){v=C;break}v=(x-o&65535)+C&65535}}while(0);b[(c[277218]|0)+(m<<1)>>1]=v;do{if((a[1108928]|0)==0){o=b[(c[277213]|0)+(m+2<<1)>>1]|0;if((a[(c[277215]|0)+m|0]&32)!=0){D=b[(c[277221]|0)+((o&65535|67616)-(b[(c[277226]|0)+(u<<1)>>1]&63454)>>1<<1)>>1]|0;break}x=c[277228]&65535;z=o&-2048;w=x&-2048;y=(z&65535)>(w&65535)?z-w&65535:0;w=o&2016;z=x&2016;if((w&65535)>(z&65535)){E=(w-z&65535)+y&65535}else{E=y}y=o&31;o=x&31;if((y&65535)<=(o&65535)){D=E;break}D=(y-o&65535)+E&65535}else{D=0}}while(0);u=m+1|0;b[(c[277218]|0)+(u<<1)>>1]=D;o=a[1108909]|0;a[(c[277219]|0)+u|0]=o;a[(c[277219]|0)+m|0]=o}}while(0);if(!n){F=k;t=9756}break};case 1:{F=s;t=9756;break};case 2:{G=s;t=9781;break};case 3:{H=s;t=9806;break};case 6:{I=s;t=9881;break};case 5:{J=s;t=9856;break};case 4:{K=s;t=9831;break};default:{}}if((t|0)==9756){t=0;o=m+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){u=a[r+1|0]|0;y=u&255;if(u<<24>>24==0){break}do{if((a[1108928]|0)==0){u=b[(c[277225]|0)+(y<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){L=b[(c[277221]|0)+((u&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}x=c[277228]&65535;z=u&-2048;w=x&-2048;M=(z&65535)>(w&65535)?z-w&65535:0;w=u&2016;z=x&2016;if((w&65535)>(z&65535)){N=(w-z&65535)+M&65535}else{N=M}M=u&31;u=x&31;if((M&65535)<=(u&65535)){L=N;break}L=(M-u&65535)+N&65535}else{u=b[(c[277225]|0)+(y<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){O=c[277228]&65535}else{O=b[(c[277213]|0)+(o<<1)>>1]|0}M=u&-2048;x=O&-2048;z=(M&65535)>(x&65535)?M-x&65535:0;x=u&2016;M=O&2016;if((x&65535)>(M&65535)){P=(x-M&65535)+z&65535}else{P=z}z=u&31;u=O&31;if((z&65535)<=(u&65535)){L=P;break}L=(z-u&65535)+P&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=L;do{if((a[1108928]|0)==0){u=b[(c[277213]|0)+(m+4<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){Q=b[(c[277221]|0)+((u&65535|67616)-(b[(c[277226]|0)+(y<<1)>>1]&63454)>>1<<1)>>1]|0;break}z=c[277228]&65535;M=u&-2048;x=z&-2048;w=(M&65535)>(x&65535)?M-x&65535:0;x=u&2016;M=z&2016;if((x&65535)>(M&65535)){R=(x-M&65535)+w&65535}else{R=w}w=u&31;u=z&31;if((w&65535)<=(u&65535)){Q=R;break}Q=(w-u&65535)+R&65535}else{Q=0}}while(0);y=m+3|0;b[(c[277218]|0)+(y<<1)>>1]=Q;u=a[1108909]|0;a[(c[277219]|0)+y|0]=u;a[(c[277219]|0)+o|0]=u}}while(0);o=F-1&255;if(o<<24>>24!=0){G=o;t=9781}}if((t|0)==9781){t=0;o=m+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){u=a[r+2|0]|0;y=u&255;if(u<<24>>24==0){break}do{if((a[1108928]|0)==0){u=b[(c[277225]|0)+(y<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){S=b[(c[277221]|0)+((u&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}w=c[277228]&65535;z=u&-2048;M=w&-2048;x=(z&65535)>(M&65535)?z-M&65535:0;M=u&2016;z=w&2016;if((M&65535)>(z&65535)){T=(M-z&65535)+x&65535}else{T=x}x=u&31;u=w&31;if((x&65535)<=(u&65535)){S=T;break}S=(x-u&65535)+T&65535}else{u=b[(c[277225]|0)+(y<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){U=c[277228]&65535}else{U=b[(c[277213]|0)+(o<<1)>>1]|0}x=u&-2048;w=U&-2048;z=(x&65535)>(w&65535)?x-w&65535:0;w=u&2016;x=U&2016;if((w&65535)>(x&65535)){V=(w-x&65535)+z&65535}else{V=z}z=u&31;u=U&31;if((z&65535)<=(u&65535)){S=V;break}S=(z-u&65535)+V&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=S;do{if((a[1108928]|0)==0){u=b[(c[277213]|0)+(m+6<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){W=b[(c[277221]|0)+((u&65535|67616)-(b[(c[277226]|0)+(y<<1)>>1]&63454)>>1<<1)>>1]|0;break}z=c[277228]&65535;x=u&-2048;w=z&-2048;M=(x&65535)>(w&65535)?x-w&65535:0;w=u&2016;x=z&2016;if((w&65535)>(x&65535)){X=(w-x&65535)+M&65535}else{X=M}M=u&31;u=z&31;if((M&65535)<=(u&65535)){W=X;break}W=(M-u&65535)+X&65535}else{W=0}}while(0);y=m+5|0;b[(c[277218]|0)+(y<<1)>>1]=W;u=a[1108909]|0;a[(c[277219]|0)+y|0]=u;a[(c[277219]|0)+o|0]=u}}while(0);o=G-1&255;if(o<<24>>24!=0){H=o;t=9806}}if((t|0)==9806){t=0;o=m+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){u=a[r+3|0]|0;y=u&255;if(u<<24>>24==0){break}do{if((a[1108928]|0)==0){u=b[(c[277225]|0)+(y<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){Y=b[(c[277221]|0)+((u&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}M=c[277228]&65535;z=u&-2048;x=M&-2048;w=(z&65535)>(x&65535)?z-x&65535:0;x=u&2016;z=M&2016;if((x&65535)>(z&65535)){Z=(x-z&65535)+w&65535}else{Z=w}w=u&31;u=M&31;if((w&65535)<=(u&65535)){Y=Z;break}Y=(w-u&65535)+Z&65535}else{u=b[(c[277225]|0)+(y<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){_=c[277228]&65535}else{_=b[(c[277213]|0)+(o<<1)>>1]|0}w=u&-2048;M=_&-2048;z=(w&65535)>(M&65535)?w-M&65535:0;M=u&2016;w=_&2016;if((M&65535)>(w&65535)){$=(M-w&65535)+z&65535}else{$=z}z=u&31;u=_&31;if((z&65535)<=(u&65535)){Y=$;break}Y=(z-u&65535)+$&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=Y;do{if((a[1108928]|0)==0){u=b[(c[277213]|0)+(m+8<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){aa=b[(c[277221]|0)+((u&65535|67616)-(b[(c[277226]|0)+(y<<1)>>1]&63454)>>1<<1)>>1]|0;break}z=c[277228]&65535;w=u&-2048;M=z&-2048;x=(w&65535)>(M&65535)?w-M&65535:0;M=u&2016;w=z&2016;if((M&65535)>(w&65535)){ab=(M-w&65535)+x&65535}else{ab=x}x=u&31;u=z&31;if((x&65535)<=(u&65535)){aa=ab;break}aa=(x-u&65535)+ab&65535}else{aa=0}}while(0);y=m+7|0;b[(c[277218]|0)+(y<<1)>>1]=aa;u=a[1108909]|0;a[(c[277219]|0)+y|0]=u;a[(c[277219]|0)+o|0]=u}}while(0);o=H-1&255;if(o<<24>>24!=0){K=o;t=9831}}if((t|0)==9831){t=0;o=m+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){u=a[r+4|0]|0;y=u&255;if(u<<24>>24==0){break}do{if((a[1108928]|0)==0){u=b[(c[277225]|0)+(y<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){ac=b[(c[277221]|0)+((u&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}x=c[277228]&65535;z=u&-2048;w=x&-2048;M=(z&65535)>(w&65535)?z-w&65535:0;w=u&2016;z=x&2016;if((w&65535)>(z&65535)){ad=(w-z&65535)+M&65535}else{ad=M}M=u&31;u=x&31;if((M&65535)<=(u&65535)){ac=ad;break}ac=(M-u&65535)+ad&65535}else{u=b[(c[277225]|0)+(y<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){ae=c[277228]&65535}else{ae=b[(c[277213]|0)+(o<<1)>>1]|0}M=u&-2048;x=ae&-2048;z=(M&65535)>(x&65535)?M-x&65535:0;x=u&2016;M=ae&2016;if((x&65535)>(M&65535)){af=(x-M&65535)+z&65535}else{af=z}z=u&31;u=ae&31;if((z&65535)<=(u&65535)){ac=af;break}ac=(z-u&65535)+af&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=ac;do{if((a[1108928]|0)==0){u=b[(c[277213]|0)+(m+10<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){ag=b[(c[277221]|0)+((u&65535|67616)-(b[(c[277226]|0)+(y<<1)>>1]&63454)>>1<<1)>>1]|0;break}z=c[277228]&65535;M=u&-2048;x=z&-2048;w=(M&65535)>(x&65535)?M-x&65535:0;x=u&2016;M=z&2016;if((x&65535)>(M&65535)){ah=(x-M&65535)+w&65535}else{ah=w}w=u&31;u=z&31;if((w&65535)<=(u&65535)){ag=ah;break}ag=(w-u&65535)+ah&65535}else{ag=0}}while(0);y=m+9|0;b[(c[277218]|0)+(y<<1)>>1]=ag;u=a[1108909]|0;a[(c[277219]|0)+y|0]=u;a[(c[277219]|0)+o|0]=u}}while(0);o=K-1&255;if(o<<24>>24!=0){J=o;t=9856}}if((t|0)==9856){t=0;o=m+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){u=a[r+5|0]|0;y=u&255;if(u<<24>>24==0){break}do{if((a[1108928]|0)==0){u=b[(c[277225]|0)+(y<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){ai=b[(c[277221]|0)+((u&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}w=c[277228]&65535;z=u&-2048;M=w&-2048;x=(z&65535)>(M&65535)?z-M&65535:0;M=u&2016;z=w&2016;if((M&65535)>(z&65535)){aj=(M-z&65535)+x&65535}else{aj=x}x=u&31;u=w&31;if((x&65535)<=(u&65535)){ai=aj;break}ai=(x-u&65535)+aj&65535}else{u=b[(c[277225]|0)+(y<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){ak=c[277228]&65535}else{ak=b[(c[277213]|0)+(o<<1)>>1]|0}x=u&-2048;w=ak&-2048;z=(x&65535)>(w&65535)?x-w&65535:0;w=u&2016;x=ak&2016;if((w&65535)>(x&65535)){al=(w-x&65535)+z&65535}else{al=z}z=u&31;u=ak&31;if((z&65535)<=(u&65535)){ai=al;break}ai=(z-u&65535)+al&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=ai;do{if((a[1108928]|0)==0){u=b[(c[277213]|0)+(m+12<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){am=b[(c[277221]|0)+((u&65535|67616)-(b[(c[277226]|0)+(y<<1)>>1]&63454)>>1<<1)>>1]|0;break}z=c[277228]&65535;x=u&-2048;w=z&-2048;M=(x&65535)>(w&65535)?x-w&65535:0;w=u&2016;x=z&2016;if((w&65535)>(x&65535)){an=(w-x&65535)+M&65535}else{an=M}M=u&31;u=z&31;if((M&65535)<=(u&65535)){am=an;break}am=(M-u&65535)+an&65535}else{am=0}}while(0);y=m+11|0;b[(c[277218]|0)+(y<<1)>>1]=am;u=a[1108909]|0;a[(c[277219]|0)+y|0]=u;a[(c[277219]|0)+o|0]=u}}while(0);o=J-1&255;if(o<<24>>24!=0){I=o;t=9881}}if((t|0)==9881){t=0;o=m+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){u=a[r+6|0]|0;y=u&255;if(u<<24>>24==0){break}do{if((a[1108928]|0)==0){u=b[(c[277225]|0)+(y<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){ao=b[(c[277221]|0)+((u&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}M=c[277228]&65535;z=u&-2048;x=M&-2048;w=(z&65535)>(x&65535)?z-x&65535:0;x=u&2016;z=M&2016;if((x&65535)>(z&65535)){ap=(x-z&65535)+w&65535}else{ap=w}w=u&31;u=M&31;if((w&65535)<=(u&65535)){ao=ap;break}ao=(w-u&65535)+ap&65535}else{u=b[(c[277225]|0)+(y<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){aq=c[277228]&65535}else{aq=b[(c[277213]|0)+(o<<1)>>1]|0}w=u&-2048;M=aq&-2048;z=(w&65535)>(M&65535)?w-M&65535:0;M=u&2016;w=aq&2016;if((M&65535)>(w&65535)){ar=(M-w&65535)+z&65535}else{ar=z}z=u&31;u=aq&31;if((z&65535)<=(u&65535)){ao=ar;break}ao=(z-u&65535)+ar&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=ao;do{if((a[1108928]|0)==0){u=b[(c[277213]|0)+(m+14<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){as=b[(c[277221]|0)+((u&65535|67616)-(b[(c[277226]|0)+(y<<1)>>1]&63454)>>1<<1)>>1]|0;break}z=c[277228]&65535;w=u&-2048;M=z&-2048;x=(w&65535)>(M&65535)?w-M&65535:0;M=u&2016;w=z&2016;if((M&65535)>(w&65535)){at=(M-w&65535)+x&65535}else{at=x}x=u&31;u=z&31;if((x&65535)<=(u&65535)){as=at;break}as=(x-u&65535)+at&65535}else{as=0}}while(0);y=m+13|0;b[(c[277218]|0)+(y<<1)>>1]=as;u=a[1108909]|0;a[(c[277219]|0)+y|0]=u;a[(c[277219]|0)+o|0]=u}}while(0);if(I<<24>>24!=1){t=9906}}do{if((t|0)==9906){t=0;o=m+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+o|0]|0)){break}u=a[r+7|0]|0;y=u&255;if(u<<24>>24==0){break}do{if((a[1108928]|0)==0){u=b[(c[277225]|0)+(y<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){au=b[(c[277221]|0)+((u&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}x=c[277228]&65535;z=u&-2048;w=x&-2048;M=(z&65535)>(w&65535)?z-w&65535:0;w=u&2016;z=x&2016;if((w&65535)>(z&65535)){av=(w-z&65535)+M&65535}else{av=M}M=u&31;u=x&31;if((M&65535)<=(u&65535)){au=av;break}au=(M-u&65535)+av&65535}else{u=b[(c[277225]|0)+(y<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){aw=c[277228]&65535}else{aw=b[(c[277213]|0)+(o<<1)>>1]|0}M=u&-2048;x=aw&-2048;z=(M&65535)>(x&65535)?M-x&65535:0;x=u&2016;M=aw&2016;if((x&65535)>(M&65535)){ax=(x-M&65535)+z&65535}else{ax=z}z=u&31;u=aw&31;if((z&65535)<=(u&65535)){au=ax;break}au=(z-u&65535)+ax&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=au;do{if((a[1108928]|0)==0){u=b[(c[277213]|0)+(m+16<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){ay=b[(c[277221]|0)+((u&65535|67616)-(b[(c[277226]|0)+(y<<1)>>1]&63454)>>1<<1)>>1]|0;break}z=c[277228]&65535;M=u&-2048;x=z&-2048;w=(M&65535)>(x&65535)?M-x&65535:0;x=u&2016;M=z&2016;if((x&65535)>(M&65535)){az=(x-M&65535)+w&65535}else{az=w}w=u&31;u=z&31;if((w&65535)<=(u&65535)){ay=az;break}ay=(w-u&65535)+az&65535}else{ay=0}}while(0);y=m+15|0;b[(c[277218]|0)+(y<<1)>>1]=ay;u=a[1108909]|0;a[(c[277219]|0)+y|0]=u;a[(c[277219]|0)+o|0]=u}}while(0);u=p-1|0;if((u|0)>0){r=r+8|0;p=u;m=(c[277223]|0)+m|0}else{break}}return}if((e&32768|0)==0){if((j|0)<=0){return}e=h&255;m=e-1&255;p=m<<24>>24==0;r=q+i|0;ay=j;az=f;while(1){switch(g|0){case 4:{aA=e;t=10035;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+az|0]|0)){au=a[r+7|0]|0;ax=au&255;if(au<<24>>24==0){break}do{if((a[1108928]|0)==0){au=b[(c[277225]|0)+(ax<<1)>>1]|0;if((a[(c[277215]|0)+az|0]&32)!=0){aB=b[(c[277221]|0)+((au&65535|67616)-(b[(c[277213]|0)+(az<<1)>>1]&63454)>>1<<1)>>1]|0;break}aw=c[277228]&65535;av=au&-2048;I=aw&-2048;as=(av&65535)>(I&65535)?av-I&65535:0;I=au&2016;av=aw&2016;if((I&65535)>(av&65535)){aC=(I-av&65535)+as&65535}else{aC=as}as=au&31;au=aw&31;if((as&65535)<=(au&65535)){aB=aC;break}aB=(as-au&65535)+aC&65535}else{au=b[(c[277225]|0)+(ax<<1)>>1]|0;if((a[(c[277215]|0)+az|0]&32)==0){aD=c[277228]&65535}else{aD=b[(c[277213]|0)+(az<<1)>>1]|0}as=au&-2048;aw=aD&-2048;av=(as&65535)>(aw&65535)?as-aw&65535:0;aw=au&2016;as=aD&2016;if((aw&65535)>(as&65535)){aE=(aw-as&65535)+av&65535}else{aE=av}av=au&31;au=aD&31;if((av&65535)<=(au&65535)){aB=aE;break}aB=(av-au&65535)+aE&65535}}while(0);b[(c[277218]|0)+(az<<1)>>1]=aB;do{if((a[1108928]|0)==0){o=b[(c[277213]|0)+(az+2<<1)>>1]|0;if((a[(c[277215]|0)+az|0]&32)!=0){aF=b[(c[277221]|0)+((o&65535|67616)-(b[(c[277226]|0)+(ax<<1)>>1]&63454)>>1<<1)>>1]|0;break}au=c[277228]&65535;av=o&-2048;as=au&-2048;aw=(av&65535)>(as&65535)?av-as&65535:0;as=o&2016;av=au&2016;if((as&65535)>(av&65535)){aG=(as-av&65535)+aw&65535}else{aG=aw}aw=o&31;o=au&31;if((aw&65535)<=(o&65535)){aF=aG;break}aF=(aw-o&65535)+aG&65535}else{aF=0}}while(0);ax=az+1|0;b[(c[277218]|0)+(ax<<1)>>1]=aF;o=a[1108909]|0;a[(c[277219]|0)+ax|0]=o;a[(c[277219]|0)+az|0]=o}}while(0);if(!p){aH=m;t=9960}break};case 6:{aI=e;t=10085;break};case 5:{aJ=e;t=10060;break};case 2:{aK=e;t=9985;break};case 3:{aL=e;t=10010;break};case 7:{t=10110;break};case 1:{aH=e;t=9960;break};default:{}}if((t|0)==9960){t=0;o=az+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){ax=a[r+6|0]|0;aw=ax&255;if(ax<<24>>24==0){break}do{if((a[1108928]|0)==0){ax=b[(c[277225]|0)+(aw<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){aM=b[(c[277221]|0)+((ax&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}au=c[277228]&65535;av=ax&-2048;as=au&-2048;I=(av&65535)>(as&65535)?av-as&65535:0;as=ax&2016;av=au&2016;if((as&65535)>(av&65535)){aN=(as-av&65535)+I&65535}else{aN=I}I=ax&31;ax=au&31;if((I&65535)<=(ax&65535)){aM=aN;break}aM=(I-ax&65535)+aN&65535}else{ax=b[(c[277225]|0)+(aw<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){aO=c[277228]&65535}else{aO=b[(c[277213]|0)+(o<<1)>>1]|0}I=ax&-2048;au=aO&-2048;av=(I&65535)>(au&65535)?I-au&65535:0;au=ax&2016;I=aO&2016;if((au&65535)>(I&65535)){aP=(au-I&65535)+av&65535}else{aP=av}av=ax&31;ax=aO&31;if((av&65535)<=(ax&65535)){aM=aP;break}aM=(av-ax&65535)+aP&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=aM;do{if((a[1108928]|0)==0){ax=b[(c[277213]|0)+(az+4<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){aQ=b[(c[277221]|0)+((ax&65535|67616)-(b[(c[277226]|0)+(aw<<1)>>1]&63454)>>1<<1)>>1]|0;break}av=c[277228]&65535;I=ax&-2048;au=av&-2048;as=(I&65535)>(au&65535)?I-au&65535:0;au=ax&2016;I=av&2016;if((au&65535)>(I&65535)){aR=(au-I&65535)+as&65535}else{aR=as}as=ax&31;ax=av&31;if((as&65535)<=(ax&65535)){aQ=aR;break}aQ=(as-ax&65535)+aR&65535}else{aQ=0}}while(0);aw=az+3|0;b[(c[277218]|0)+(aw<<1)>>1]=aQ;ax=a[1108909]|0;a[(c[277219]|0)+aw|0]=ax;a[(c[277219]|0)+o|0]=ax}}while(0);o=aH-1&255;if(o<<24>>24!=0){aK=o;t=9985}}if((t|0)==9985){t=0;o=az+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){ax=a[r+5|0]|0;aw=ax&255;if(ax<<24>>24==0){break}do{if((a[1108928]|0)==0){ax=b[(c[277225]|0)+(aw<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){aS=b[(c[277221]|0)+((ax&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}as=c[277228]&65535;av=ax&-2048;I=as&-2048;au=(av&65535)>(I&65535)?av-I&65535:0;I=ax&2016;av=as&2016;if((I&65535)>(av&65535)){aT=(I-av&65535)+au&65535}else{aT=au}au=ax&31;ax=as&31;if((au&65535)<=(ax&65535)){aS=aT;break}aS=(au-ax&65535)+aT&65535}else{ax=b[(c[277225]|0)+(aw<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){aU=c[277228]&65535}else{aU=b[(c[277213]|0)+(o<<1)>>1]|0}au=ax&-2048;as=aU&-2048;av=(au&65535)>(as&65535)?au-as&65535:0;as=ax&2016;au=aU&2016;if((as&65535)>(au&65535)){aV=(as-au&65535)+av&65535}else{aV=av}av=ax&31;ax=aU&31;if((av&65535)<=(ax&65535)){aS=aV;break}aS=(av-ax&65535)+aV&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=aS;do{if((a[1108928]|0)==0){ax=b[(c[277213]|0)+(az+6<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){aW=b[(c[277221]|0)+((ax&65535|67616)-(b[(c[277226]|0)+(aw<<1)>>1]&63454)>>1<<1)>>1]|0;break}av=c[277228]&65535;au=ax&-2048;as=av&-2048;I=(au&65535)>(as&65535)?au-as&65535:0;as=ax&2016;au=av&2016;if((as&65535)>(au&65535)){aX=(as-au&65535)+I&65535}else{aX=I}I=ax&31;ax=av&31;if((I&65535)<=(ax&65535)){aW=aX;break}aW=(I-ax&65535)+aX&65535}else{aW=0}}while(0);aw=az+5|0;b[(c[277218]|0)+(aw<<1)>>1]=aW;ax=a[1108909]|0;a[(c[277219]|0)+aw|0]=ax;a[(c[277219]|0)+o|0]=ax}}while(0);o=aK-1&255;if(o<<24>>24!=0){aL=o;t=10010}}if((t|0)==10010){t=0;o=az+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){ax=a[r+4|0]|0;aw=ax&255;if(ax<<24>>24==0){break}do{if((a[1108928]|0)==0){ax=b[(c[277225]|0)+(aw<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){aY=b[(c[277221]|0)+((ax&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}I=c[277228]&65535;av=ax&-2048;au=I&-2048;as=(av&65535)>(au&65535)?av-au&65535:0;au=ax&2016;av=I&2016;if((au&65535)>(av&65535)){aZ=(au-av&65535)+as&65535}else{aZ=as}as=ax&31;ax=I&31;if((as&65535)<=(ax&65535)){aY=aZ;break}aY=(as-ax&65535)+aZ&65535}else{ax=b[(c[277225]|0)+(aw<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){a_=c[277228]&65535}else{a_=b[(c[277213]|0)+(o<<1)>>1]|0}as=ax&-2048;I=a_&-2048;av=(as&65535)>(I&65535)?as-I&65535:0;I=ax&2016;as=a_&2016;if((I&65535)>(as&65535)){a$=(I-as&65535)+av&65535}else{a$=av}av=ax&31;ax=a_&31;if((av&65535)<=(ax&65535)){aY=a$;break}aY=(av-ax&65535)+a$&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=aY;do{if((a[1108928]|0)==0){ax=b[(c[277213]|0)+(az+8<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){a0=b[(c[277221]|0)+((ax&65535|67616)-(b[(c[277226]|0)+(aw<<1)>>1]&63454)>>1<<1)>>1]|0;break}av=c[277228]&65535;as=ax&-2048;I=av&-2048;au=(as&65535)>(I&65535)?as-I&65535:0;I=ax&2016;as=av&2016;if((I&65535)>(as&65535)){a1=(I-as&65535)+au&65535}else{a1=au}au=ax&31;ax=av&31;if((au&65535)<=(ax&65535)){a0=a1;break}a0=(au-ax&65535)+a1&65535}else{a0=0}}while(0);aw=az+7|0;b[(c[277218]|0)+(aw<<1)>>1]=a0;ax=a[1108909]|0;a[(c[277219]|0)+aw|0]=ax;a[(c[277219]|0)+o|0]=ax}}while(0);o=aL-1&255;if(o<<24>>24!=0){aA=o;t=10035}}if((t|0)==10035){t=0;o=az+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){ax=a[r+3|0]|0;aw=ax&255;if(ax<<24>>24==0){break}do{if((a[1108928]|0)==0){ax=b[(c[277225]|0)+(aw<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){a2=b[(c[277221]|0)+((ax&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}au=c[277228]&65535;av=ax&-2048;as=au&-2048;I=(av&65535)>(as&65535)?av-as&65535:0;as=ax&2016;av=au&2016;if((as&65535)>(av&65535)){a3=(as-av&65535)+I&65535}else{a3=I}I=ax&31;ax=au&31;if((I&65535)<=(ax&65535)){a2=a3;break}a2=(I-ax&65535)+a3&65535}else{ax=b[(c[277225]|0)+(aw<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){a4=c[277228]&65535}else{a4=b[(c[277213]|0)+(o<<1)>>1]|0}I=ax&-2048;au=a4&-2048;av=(I&65535)>(au&65535)?I-au&65535:0;au=ax&2016;I=a4&2016;if((au&65535)>(I&65535)){a5=(au-I&65535)+av&65535}else{a5=av}av=ax&31;ax=a4&31;if((av&65535)<=(ax&65535)){a2=a5;break}a2=(av-ax&65535)+a5&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=a2;do{if((a[1108928]|0)==0){ax=b[(c[277213]|0)+(az+10<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){a6=b[(c[277221]|0)+((ax&65535|67616)-(b[(c[277226]|0)+(aw<<1)>>1]&63454)>>1<<1)>>1]|0;break}av=c[277228]&65535;I=ax&-2048;au=av&-2048;as=(I&65535)>(au&65535)?I-au&65535:0;au=ax&2016;I=av&2016;if((au&65535)>(I&65535)){a7=(au-I&65535)+as&65535}else{a7=as}as=ax&31;ax=av&31;if((as&65535)<=(ax&65535)){a6=a7;break}a6=(as-ax&65535)+a7&65535}else{a6=0}}while(0);aw=az+9|0;b[(c[277218]|0)+(aw<<1)>>1]=a6;ax=a[1108909]|0;a[(c[277219]|0)+aw|0]=ax;a[(c[277219]|0)+o|0]=ax}}while(0);o=aA-1&255;if(o<<24>>24!=0){aJ=o;t=10060}}if((t|0)==10060){t=0;o=az+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){ax=a[r+2|0]|0;aw=ax&255;if(ax<<24>>24==0){break}do{if((a[1108928]|0)==0){ax=b[(c[277225]|0)+(aw<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){a8=b[(c[277221]|0)+((ax&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}as=c[277228]&65535;av=ax&-2048;I=as&-2048;au=(av&65535)>(I&65535)?av-I&65535:0;I=ax&2016;av=as&2016;if((I&65535)>(av&65535)){a9=(I-av&65535)+au&65535}else{a9=au}au=ax&31;ax=as&31;if((au&65535)<=(ax&65535)){a8=a9;break}a8=(au-ax&65535)+a9&65535}else{ax=b[(c[277225]|0)+(aw<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){ba=c[277228]&65535}else{ba=b[(c[277213]|0)+(o<<1)>>1]|0}au=ax&-2048;as=ba&-2048;av=(au&65535)>(as&65535)?au-as&65535:0;as=ax&2016;au=ba&2016;if((as&65535)>(au&65535)){bb=(as-au&65535)+av&65535}else{bb=av}av=ax&31;ax=ba&31;if((av&65535)<=(ax&65535)){a8=bb;break}a8=(av-ax&65535)+bb&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=a8;do{if((a[1108928]|0)==0){ax=b[(c[277213]|0)+(az+12<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){bc=b[(c[277221]|0)+((ax&65535|67616)-(b[(c[277226]|0)+(aw<<1)>>1]&63454)>>1<<1)>>1]|0;break}av=c[277228]&65535;au=ax&-2048;as=av&-2048;I=(au&65535)>(as&65535)?au-as&65535:0;as=ax&2016;au=av&2016;if((as&65535)>(au&65535)){bd=(as-au&65535)+I&65535}else{bd=I}I=ax&31;ax=av&31;if((I&65535)<=(ax&65535)){bc=bd;break}bc=(I-ax&65535)+bd&65535}else{bc=0}}while(0);aw=az+11|0;b[(c[277218]|0)+(aw<<1)>>1]=bc;ax=a[1108909]|0;a[(c[277219]|0)+aw|0]=ax;a[(c[277219]|0)+o|0]=ax}}while(0);o=aJ-1&255;if(o<<24>>24!=0){aI=o;t=10085}}if((t|0)==10085){t=0;o=az+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){ax=a[r+1|0]|0;aw=ax&255;if(ax<<24>>24==0){break}do{if((a[1108928]|0)==0){ax=b[(c[277225]|0)+(aw<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){be=b[(c[277221]|0)+((ax&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}I=c[277228]&65535;av=ax&-2048;au=I&-2048;as=(av&65535)>(au&65535)?av-au&65535:0;au=ax&2016;av=I&2016;if((au&65535)>(av&65535)){bf=(au-av&65535)+as&65535}else{bf=as}as=ax&31;ax=I&31;if((as&65535)<=(ax&65535)){be=bf;break}be=(as-ax&65535)+bf&65535}else{ax=b[(c[277225]|0)+(aw<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){bg=c[277228]&65535}else{bg=b[(c[277213]|0)+(o<<1)>>1]|0}as=ax&-2048;I=bg&-2048;av=(as&65535)>(I&65535)?as-I&65535:0;I=ax&2016;as=bg&2016;if((I&65535)>(as&65535)){bh=(I-as&65535)+av&65535}else{bh=av}av=ax&31;ax=bg&31;if((av&65535)<=(ax&65535)){be=bh;break}be=(av-ax&65535)+bh&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=be;do{if((a[1108928]|0)==0){ax=b[(c[277213]|0)+(az+14<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){bi=b[(c[277221]|0)+((ax&65535|67616)-(b[(c[277226]|0)+(aw<<1)>>1]&63454)>>1<<1)>>1]|0;break}av=c[277228]&65535;as=ax&-2048;I=av&-2048;au=(as&65535)>(I&65535)?as-I&65535:0;I=ax&2016;as=av&2016;if((I&65535)>(as&65535)){bj=(I-as&65535)+au&65535}else{bj=au}au=ax&31;ax=av&31;if((au&65535)<=(ax&65535)){bi=bj;break}bi=(au-ax&65535)+bj&65535}else{bi=0}}while(0);aw=az+13|0;b[(c[277218]|0)+(aw<<1)>>1]=bi;ax=a[1108909]|0;a[(c[277219]|0)+aw|0]=ax;a[(c[277219]|0)+o|0]=ax}}while(0);if(aI<<24>>24!=1){t=10110}}do{if((t|0)==10110){t=0;o=az+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+o|0]|0)){break}ax=a[r]|0;aw=ax&255;if(ax<<24>>24==0){break}do{if((a[1108928]|0)==0){ax=b[(c[277225]|0)+(aw<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){bk=b[(c[277221]|0)+((ax&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}au=c[277228]&65535;av=ax&-2048;as=au&-2048;I=(av&65535)>(as&65535)?av-as&65535:0;as=ax&2016;av=au&2016;if((as&65535)>(av&65535)){bl=(as-av&65535)+I&65535}else{bl=I}I=ax&31;ax=au&31;if((I&65535)<=(ax&65535)){bk=bl;break}bk=(I-ax&65535)+bl&65535}else{ax=b[(c[277225]|0)+(aw<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){bm=c[277228]&65535}else{bm=b[(c[277213]|0)+(o<<1)>>1]|0}I=ax&-2048;au=bm&-2048;av=(I&65535)>(au&65535)?I-au&65535:0;au=ax&2016;I=bm&2016;if((au&65535)>(I&65535)){bn=(au-I&65535)+av&65535}else{bn=av}av=ax&31;ax=bm&31;if((av&65535)<=(ax&65535)){bk=bn;break}bk=(av-ax&65535)+bn&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=bk;do{if((a[1108928]|0)==0){ax=b[(c[277213]|0)+(az+16<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){bo=b[(c[277221]|0)+((ax&65535|67616)-(b[(c[277226]|0)+(aw<<1)>>1]&63454)>>1<<1)>>1]|0;break}av=c[277228]&65535;I=ax&-2048;au=av&-2048;as=(I&65535)>(au&65535)?I-au&65535:0;au=ax&2016;I=av&2016;if((au&65535)>(I&65535)){bp=(au-I&65535)+as&65535}else{bp=as}as=ax&31;ax=av&31;if((as&65535)<=(ax&65535)){bo=bp;break}bo=(as-ax&65535)+bp&65535}else{bo=0}}while(0);aw=az+15|0;b[(c[277218]|0)+(aw<<1)>>1]=bo;ax=a[1108909]|0;a[(c[277219]|0)+aw|0]=ax;a[(c[277219]|0)+o|0]=ax}}while(0);ax=ay-1|0;if((ax|0)>0){r=r+8|0;ay=ax;az=(c[277223]|0)+az|0}else{break}}return}az=q+(56-i)|0;i=(j|0)>0;if(l){if(!i){return}l=h&255;q=l-1&255;ay=q<<24>>24==0;r=az;bo=j;bp=f;while(1){switch(g|0){case 2:{bq=l;t=10392;break};case 6:{br=l;t=10492;break};case 1:{bs=l;t=10367;break};case 4:{bt=l;t=10442;break};case 3:{bu=l;t=10417;break};case 7:{t=10517;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+bp|0]|0)){bk=a[r+7|0]|0;bn=bk&255;if(bk<<24>>24==0){break}do{if((a[1108928]|0)==0){bk=b[(c[277225]|0)+(bn<<1)>>1]|0;if((a[(c[277215]|0)+bp|0]&32)!=0){bv=b[(c[277221]|0)+((bk&65535|67616)-(b[(c[277213]|0)+(bp<<1)>>1]&63454)>>1<<1)>>1]|0;break}bm=c[277228]&65535;bl=bk&-2048;aI=bm&-2048;bi=(bl&65535)>(aI&65535)?bl-aI&65535:0;aI=bk&2016;bl=bm&2016;if((aI&65535)>(bl&65535)){bw=(aI-bl&65535)+bi&65535}else{bw=bi}bi=bk&31;bk=bm&31;if((bi&65535)<=(bk&65535)){bv=bw;break}bv=(bi-bk&65535)+bw&65535}else{bk=b[(c[277225]|0)+(bn<<1)>>1]|0;if((a[(c[277215]|0)+bp|0]&32)==0){bx=c[277228]&65535}else{bx=b[(c[277213]|0)+(bp<<1)>>1]|0}bi=bk&-2048;bm=bx&-2048;bl=(bi&65535)>(bm&65535)?bi-bm&65535:0;bm=bk&2016;bi=bx&2016;if((bm&65535)>(bi&65535)){by=(bm-bi&65535)+bl&65535}else{by=bl}bl=bk&31;bk=bx&31;if((bl&65535)<=(bk&65535)){bv=by;break}bv=(bl-bk&65535)+by&65535}}while(0);b[(c[277218]|0)+(bp<<1)>>1]=bv;do{if((a[1108928]|0)==0){o=b[(c[277213]|0)+(bp+2<<1)>>1]|0;if((a[(c[277215]|0)+bp|0]&32)!=0){bz=b[(c[277221]|0)+((o&65535|67616)-(b[(c[277226]|0)+(bn<<1)>>1]&63454)>>1<<1)>>1]|0;break}bk=c[277228]&65535;bl=o&-2048;bi=bk&-2048;bm=(bl&65535)>(bi&65535)?bl-bi&65535:0;bi=o&2016;bl=bk&2016;if((bi&65535)>(bl&65535)){bA=(bi-bl&65535)+bm&65535}else{bA=bm}bm=o&31;o=bk&31;if((bm&65535)<=(o&65535)){bz=bA;break}bz=(bm-o&65535)+bA&65535}else{bz=0}}while(0);bn=bp+1|0;b[(c[277218]|0)+(bn<<1)>>1]=bz;o=a[1108909]|0;a[(c[277219]|0)+bn|0]=o;a[(c[277219]|0)+bp|0]=o}}while(0);if(!ay){bs=q;t=10367}break};case 5:{bB=l;t=10467;break};default:{}}if((t|0)==10367){t=0;o=bp+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){bn=a[r+6|0]|0;bm=bn&255;if(bn<<24>>24==0){break}do{if((a[1108928]|0)==0){bn=b[(c[277225]|0)+(bm<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){bC=b[(c[277221]|0)+((bn&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}bk=c[277228]&65535;bl=bn&-2048;bi=bk&-2048;aI=(bl&65535)>(bi&65535)?bl-bi&65535:0;bi=bn&2016;bl=bk&2016;if((bi&65535)>(bl&65535)){bD=(bi-bl&65535)+aI&65535}else{bD=aI}aI=bn&31;bn=bk&31;if((aI&65535)<=(bn&65535)){bC=bD;break}bC=(aI-bn&65535)+bD&65535}else{bn=b[(c[277225]|0)+(bm<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){bE=c[277228]&65535}else{bE=b[(c[277213]|0)+(o<<1)>>1]|0}aI=bn&-2048;bk=bE&-2048;bl=(aI&65535)>(bk&65535)?aI-bk&65535:0;bk=bn&2016;aI=bE&2016;if((bk&65535)>(aI&65535)){bF=(bk-aI&65535)+bl&65535}else{bF=bl}bl=bn&31;bn=bE&31;if((bl&65535)<=(bn&65535)){bC=bF;break}bC=(bl-bn&65535)+bF&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=bC;do{if((a[1108928]|0)==0){bn=b[(c[277213]|0)+(bp+4<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){bG=b[(c[277221]|0)+((bn&65535|67616)-(b[(c[277226]|0)+(bm<<1)>>1]&63454)>>1<<1)>>1]|0;break}bl=c[277228]&65535;aI=bn&-2048;bk=bl&-2048;bi=(aI&65535)>(bk&65535)?aI-bk&65535:0;bk=bn&2016;aI=bl&2016;if((bk&65535)>(aI&65535)){bH=(bk-aI&65535)+bi&65535}else{bH=bi}bi=bn&31;bn=bl&31;if((bi&65535)<=(bn&65535)){bG=bH;break}bG=(bi-bn&65535)+bH&65535}else{bG=0}}while(0);bm=bp+3|0;b[(c[277218]|0)+(bm<<1)>>1]=bG;bn=a[1108909]|0;a[(c[277219]|0)+bm|0]=bn;a[(c[277219]|0)+o|0]=bn}}while(0);o=bs-1&255;if(o<<24>>24!=0){bq=o;t=10392}}if((t|0)==10392){t=0;o=bp+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){bn=a[r+5|0]|0;bm=bn&255;if(bn<<24>>24==0){break}do{if((a[1108928]|0)==0){bn=b[(c[277225]|0)+(bm<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){bI=b[(c[277221]|0)+((bn&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}bi=c[277228]&65535;bl=bn&-2048;aI=bi&-2048;bk=(bl&65535)>(aI&65535)?bl-aI&65535:0;aI=bn&2016;bl=bi&2016;if((aI&65535)>(bl&65535)){bJ=(aI-bl&65535)+bk&65535}else{bJ=bk}bk=bn&31;bn=bi&31;if((bk&65535)<=(bn&65535)){bI=bJ;break}bI=(bk-bn&65535)+bJ&65535}else{bn=b[(c[277225]|0)+(bm<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){bK=c[277228]&65535}else{bK=b[(c[277213]|0)+(o<<1)>>1]|0}bk=bn&-2048;bi=bK&-2048;bl=(bk&65535)>(bi&65535)?bk-bi&65535:0;bi=bn&2016;bk=bK&2016;if((bi&65535)>(bk&65535)){bL=(bi-bk&65535)+bl&65535}else{bL=bl}bl=bn&31;bn=bK&31;if((bl&65535)<=(bn&65535)){bI=bL;break}bI=(bl-bn&65535)+bL&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=bI;do{if((a[1108928]|0)==0){bn=b[(c[277213]|0)+(bp+6<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){bM=b[(c[277221]|0)+((bn&65535|67616)-(b[(c[277226]|0)+(bm<<1)>>1]&63454)>>1<<1)>>1]|0;break}bl=c[277228]&65535;bk=bn&-2048;bi=bl&-2048;aI=(bk&65535)>(bi&65535)?bk-bi&65535:0;bi=bn&2016;bk=bl&2016;if((bi&65535)>(bk&65535)){bN=(bi-bk&65535)+aI&65535}else{bN=aI}aI=bn&31;bn=bl&31;if((aI&65535)<=(bn&65535)){bM=bN;break}bM=(aI-bn&65535)+bN&65535}else{bM=0}}while(0);bm=bp+5|0;b[(c[277218]|0)+(bm<<1)>>1]=bM;bn=a[1108909]|0;a[(c[277219]|0)+bm|0]=bn;a[(c[277219]|0)+o|0]=bn}}while(0);o=bq-1&255;if(o<<24>>24!=0){bu=o;t=10417}}if((t|0)==10417){t=0;o=bp+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){bn=a[r+4|0]|0;bm=bn&255;if(bn<<24>>24==0){break}do{if((a[1108928]|0)==0){bn=b[(c[277225]|0)+(bm<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){bO=b[(c[277221]|0)+((bn&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}aI=c[277228]&65535;bl=bn&-2048;bk=aI&-2048;bi=(bl&65535)>(bk&65535)?bl-bk&65535:0;bk=bn&2016;bl=aI&2016;if((bk&65535)>(bl&65535)){bP=(bk-bl&65535)+bi&65535}else{bP=bi}bi=bn&31;bn=aI&31;if((bi&65535)<=(bn&65535)){bO=bP;break}bO=(bi-bn&65535)+bP&65535}else{bn=b[(c[277225]|0)+(bm<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){bQ=c[277228]&65535}else{bQ=b[(c[277213]|0)+(o<<1)>>1]|0}bi=bn&-2048;aI=bQ&-2048;bl=(bi&65535)>(aI&65535)?bi-aI&65535:0;aI=bn&2016;bi=bQ&2016;if((aI&65535)>(bi&65535)){bR=(aI-bi&65535)+bl&65535}else{bR=bl}bl=bn&31;bn=bQ&31;if((bl&65535)<=(bn&65535)){bO=bR;break}bO=(bl-bn&65535)+bR&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=bO;do{if((a[1108928]|0)==0){bn=b[(c[277213]|0)+(bp+8<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){bS=b[(c[277221]|0)+((bn&65535|67616)-(b[(c[277226]|0)+(bm<<1)>>1]&63454)>>1<<1)>>1]|0;break}bl=c[277228]&65535;bi=bn&-2048;aI=bl&-2048;bk=(bi&65535)>(aI&65535)?bi-aI&65535:0;aI=bn&2016;bi=bl&2016;if((aI&65535)>(bi&65535)){bT=(aI-bi&65535)+bk&65535}else{bT=bk}bk=bn&31;bn=bl&31;if((bk&65535)<=(bn&65535)){bS=bT;break}bS=(bk-bn&65535)+bT&65535}else{bS=0}}while(0);bm=bp+7|0;b[(c[277218]|0)+(bm<<1)>>1]=bS;bn=a[1108909]|0;a[(c[277219]|0)+bm|0]=bn;a[(c[277219]|0)+o|0]=bn}}while(0);o=bu-1&255;if(o<<24>>24!=0){bt=o;t=10442}}if((t|0)==10442){t=0;o=bp+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){bn=a[r+3|0]|0;bm=bn&255;if(bn<<24>>24==0){break}do{if((a[1108928]|0)==0){bn=b[(c[277225]|0)+(bm<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){bU=b[(c[277221]|0)+((bn&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}bk=c[277228]&65535;bl=bn&-2048;bi=bk&-2048;aI=(bl&65535)>(bi&65535)?bl-bi&65535:0;bi=bn&2016;bl=bk&2016;if((bi&65535)>(bl&65535)){bV=(bi-bl&65535)+aI&65535}else{bV=aI}aI=bn&31;bn=bk&31;if((aI&65535)<=(bn&65535)){bU=bV;break}bU=(aI-bn&65535)+bV&65535}else{bn=b[(c[277225]|0)+(bm<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){bW=c[277228]&65535}else{bW=b[(c[277213]|0)+(o<<1)>>1]|0}aI=bn&-2048;bk=bW&-2048;bl=(aI&65535)>(bk&65535)?aI-bk&65535:0;bk=bn&2016;aI=bW&2016;if((bk&65535)>(aI&65535)){bX=(bk-aI&65535)+bl&65535}else{bX=bl}bl=bn&31;bn=bW&31;if((bl&65535)<=(bn&65535)){bU=bX;break}bU=(bl-bn&65535)+bX&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=bU;do{if((a[1108928]|0)==0){bn=b[(c[277213]|0)+(bp+10<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){bY=b[(c[277221]|0)+((bn&65535|67616)-(b[(c[277226]|0)+(bm<<1)>>1]&63454)>>1<<1)>>1]|0;break}bl=c[277228]&65535;aI=bn&-2048;bk=bl&-2048;bi=(aI&65535)>(bk&65535)?aI-bk&65535:0;bk=bn&2016;aI=bl&2016;if((bk&65535)>(aI&65535)){bZ=(bk-aI&65535)+bi&65535}else{bZ=bi}bi=bn&31;bn=bl&31;if((bi&65535)<=(bn&65535)){bY=bZ;break}bY=(bi-bn&65535)+bZ&65535}else{bY=0}}while(0);bm=bp+9|0;b[(c[277218]|0)+(bm<<1)>>1]=bY;bn=a[1108909]|0;a[(c[277219]|0)+bm|0]=bn;a[(c[277219]|0)+o|0]=bn}}while(0);o=bt-1&255;if(o<<24>>24!=0){bB=o;t=10467}}if((t|0)==10467){t=0;o=bp+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){bn=a[r+2|0]|0;bm=bn&255;if(bn<<24>>24==0){break}do{if((a[1108928]|0)==0){bn=b[(c[277225]|0)+(bm<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){b_=b[(c[277221]|0)+((bn&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}bi=c[277228]&65535;bl=bn&-2048;aI=bi&-2048;bk=(bl&65535)>(aI&65535)?bl-aI&65535:0;aI=bn&2016;bl=bi&2016;if((aI&65535)>(bl&65535)){b$=(aI-bl&65535)+bk&65535}else{b$=bk}bk=bn&31;bn=bi&31;if((bk&65535)<=(bn&65535)){b_=b$;break}b_=(bk-bn&65535)+b$&65535}else{bn=b[(c[277225]|0)+(bm<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){b0=c[277228]&65535}else{b0=b[(c[277213]|0)+(o<<1)>>1]|0}bk=bn&-2048;bi=b0&-2048;bl=(bk&65535)>(bi&65535)?bk-bi&65535:0;bi=bn&2016;bk=b0&2016;if((bi&65535)>(bk&65535)){b1=(bi-bk&65535)+bl&65535}else{b1=bl}bl=bn&31;bn=b0&31;if((bl&65535)<=(bn&65535)){b_=b1;break}b_=(bl-bn&65535)+b1&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=b_;do{if((a[1108928]|0)==0){bn=b[(c[277213]|0)+(bp+12<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){b2=b[(c[277221]|0)+((bn&65535|67616)-(b[(c[277226]|0)+(bm<<1)>>1]&63454)>>1<<1)>>1]|0;break}bl=c[277228]&65535;bk=bn&-2048;bi=bl&-2048;aI=(bk&65535)>(bi&65535)?bk-bi&65535:0;bi=bn&2016;bk=bl&2016;if((bi&65535)>(bk&65535)){b3=(bi-bk&65535)+aI&65535}else{b3=aI}aI=bn&31;bn=bl&31;if((aI&65535)<=(bn&65535)){b2=b3;break}b2=(aI-bn&65535)+b3&65535}else{b2=0}}while(0);bm=bp+11|0;b[(c[277218]|0)+(bm<<1)>>1]=b2;bn=a[1108909]|0;a[(c[277219]|0)+bm|0]=bn;a[(c[277219]|0)+o|0]=bn}}while(0);o=bB-1&255;if(o<<24>>24!=0){br=o;t=10492}}if((t|0)==10492){t=0;o=bp+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){bn=a[r+1|0]|0;bm=bn&255;if(bn<<24>>24==0){break}do{if((a[1108928]|0)==0){bn=b[(c[277225]|0)+(bm<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){b4=b[(c[277221]|0)+((bn&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}aI=c[277228]&65535;bl=bn&-2048;bk=aI&-2048;bi=(bl&65535)>(bk&65535)?bl-bk&65535:0;bk=bn&2016;bl=aI&2016;if((bk&65535)>(bl&65535)){b5=(bk-bl&65535)+bi&65535}else{b5=bi}bi=bn&31;bn=aI&31;if((bi&65535)<=(bn&65535)){b4=b5;break}b4=(bi-bn&65535)+b5&65535}else{bn=b[(c[277225]|0)+(bm<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){b6=c[277228]&65535}else{b6=b[(c[277213]|0)+(o<<1)>>1]|0}bi=bn&-2048;aI=b6&-2048;bl=(bi&65535)>(aI&65535)?bi-aI&65535:0;aI=bn&2016;bi=b6&2016;if((aI&65535)>(bi&65535)){b7=(aI-bi&65535)+bl&65535}else{b7=bl}bl=bn&31;bn=b6&31;if((bl&65535)<=(bn&65535)){b4=b7;break}b4=(bl-bn&65535)+b7&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=b4;do{if((a[1108928]|0)==0){bn=b[(c[277213]|0)+(bp+14<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){b8=b[(c[277221]|0)+((bn&65535|67616)-(b[(c[277226]|0)+(bm<<1)>>1]&63454)>>1<<1)>>1]|0;break}bl=c[277228]&65535;bi=bn&-2048;aI=bl&-2048;bk=(bi&65535)>(aI&65535)?bi-aI&65535:0;aI=bn&2016;bi=bl&2016;if((aI&65535)>(bi&65535)){b9=(aI-bi&65535)+bk&65535}else{b9=bk}bk=bn&31;bn=bl&31;if((bk&65535)<=(bn&65535)){b8=b9;break}b8=(bk-bn&65535)+b9&65535}else{b8=0}}while(0);bm=bp+13|0;b[(c[277218]|0)+(bm<<1)>>1]=b8;bn=a[1108909]|0;a[(c[277219]|0)+bm|0]=bn;a[(c[277219]|0)+o|0]=bn}}while(0);if(br<<24>>24!=1){t=10517}}do{if((t|0)==10517){t=0;o=bp+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+o|0]|0)){break}bn=a[r]|0;bm=bn&255;if(bn<<24>>24==0){break}do{if((a[1108928]|0)==0){bn=b[(c[277225]|0)+(bm<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){ca=b[(c[277221]|0)+((bn&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}bk=c[277228]&65535;bl=bn&-2048;bi=bk&-2048;aI=(bl&65535)>(bi&65535)?bl-bi&65535:0;bi=bn&2016;bl=bk&2016;if((bi&65535)>(bl&65535)){cb=(bi-bl&65535)+aI&65535}else{cb=aI}aI=bn&31;bn=bk&31;if((aI&65535)<=(bn&65535)){ca=cb;break}ca=(aI-bn&65535)+cb&65535}else{bn=b[(c[277225]|0)+(bm<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){cc=c[277228]&65535}else{cc=b[(c[277213]|0)+(o<<1)>>1]|0}aI=bn&-2048;bk=cc&-2048;bl=(aI&65535)>(bk&65535)?aI-bk&65535:0;bk=bn&2016;aI=cc&2016;if((bk&65535)>(aI&65535)){cd=(bk-aI&65535)+bl&65535}else{cd=bl}bl=bn&31;bn=cc&31;if((bl&65535)<=(bn&65535)){ca=cd;break}ca=(bl-bn&65535)+cd&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=ca;do{if((a[1108928]|0)==0){bn=b[(c[277213]|0)+(bp+16<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){ce=b[(c[277221]|0)+((bn&65535|67616)-(b[(c[277226]|0)+(bm<<1)>>1]&63454)>>1<<1)>>1]|0;break}bl=c[277228]&65535;aI=bn&-2048;bk=bl&-2048;bi=(aI&65535)>(bk&65535)?aI-bk&65535:0;bk=bn&2016;aI=bl&2016;if((bk&65535)>(aI&65535)){cf=(bk-aI&65535)+bi&65535}else{cf=bi}bi=bn&31;bn=bl&31;if((bi&65535)<=(bn&65535)){ce=cf;break}ce=(bi-bn&65535)+cf&65535}else{ce=0}}while(0);bm=bp+15|0;b[(c[277218]|0)+(bm<<1)>>1]=ce;bn=a[1108909]|0;a[(c[277219]|0)+bm|0]=bn;a[(c[277219]|0)+o|0]=bn}}while(0);bn=bo-1|0;if((bn|0)>0){r=r-8|0;bo=bn;bp=(c[277223]|0)+bp|0}else{break}}return}else{if(!i){return}i=h&255;h=i-1&255;bp=h<<24>>24==0;bo=az;az=j;j=f;while(1){switch(g|0){case 5:{cg=i;t=10266;break};case 2:{ch=i;t=10191;break};case 1:{ci=i;t=10166;break};case 7:{t=10316;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+j|0]|0)){f=a[bo]|0;r=f&255;if(f<<24>>24==0){break}do{if((a[1108928]|0)==0){f=b[(c[277225]|0)+(r<<1)>>1]|0;if((a[(c[277215]|0)+j|0]&32)!=0){cj=b[(c[277221]|0)+((f&65535|67616)-(b[(c[277213]|0)+(j<<1)>>1]&63454)>>1<<1)>>1]|0;break}ce=c[277228]&65535;cf=f&-2048;ca=ce&-2048;cd=(cf&65535)>(ca&65535)?cf-ca&65535:0;ca=f&2016;cf=ce&2016;if((ca&65535)>(cf&65535)){ck=(ca-cf&65535)+cd&65535}else{ck=cd}cd=f&31;f=ce&31;if((cd&65535)<=(f&65535)){cj=ck;break}cj=(cd-f&65535)+ck&65535}else{f=b[(c[277225]|0)+(r<<1)>>1]|0;if((a[(c[277215]|0)+j|0]&32)==0){cl=c[277228]&65535}else{cl=b[(c[277213]|0)+(j<<1)>>1]|0}cd=f&-2048;ce=cl&-2048;cf=(cd&65535)>(ce&65535)?cd-ce&65535:0;ce=f&2016;cd=cl&2016;if((ce&65535)>(cd&65535)){cm=(ce-cd&65535)+cf&65535}else{cm=cf}cf=f&31;f=cl&31;if((cf&65535)<=(f&65535)){cj=cm;break}cj=(cf-f&65535)+cm&65535}}while(0);b[(c[277218]|0)+(j<<1)>>1]=cj;do{if((a[1108928]|0)==0){o=b[(c[277213]|0)+(j+2<<1)>>1]|0;if((a[(c[277215]|0)+j|0]&32)!=0){cn=b[(c[277221]|0)+((o&65535|67616)-(b[(c[277226]|0)+(r<<1)>>1]&63454)>>1<<1)>>1]|0;break}f=c[277228]&65535;cf=o&-2048;cd=f&-2048;ce=(cf&65535)>(cd&65535)?cf-cd&65535:0;cd=o&2016;cf=f&2016;if((cd&65535)>(cf&65535)){co=(cd-cf&65535)+ce&65535}else{co=ce}ce=o&31;o=f&31;if((ce&65535)<=(o&65535)){cn=co;break}cn=(ce-o&65535)+co&65535}else{cn=0}}while(0);r=j+1|0;b[(c[277218]|0)+(r<<1)>>1]=cn;o=a[1108909]|0;a[(c[277219]|0)+r|0]=o;a[(c[277219]|0)+j|0]=o}}while(0);if(!bp){ci=h;t=10166}break};case 3:{cp=i;t=10216;break};case 6:{cq=i;t=10291;break};case 4:{cr=i;t=10241;break};default:{}}if((t|0)==10166){t=0;o=j+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){r=a[bo+1|0]|0;ce=r&255;if(r<<24>>24==0){break}do{if((a[1108928]|0)==0){r=b[(c[277225]|0)+(ce<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){cs=b[(c[277221]|0)+((r&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}f=c[277228]&65535;cf=r&-2048;cd=f&-2048;ca=(cf&65535)>(cd&65535)?cf-cd&65535:0;cd=r&2016;cf=f&2016;if((cd&65535)>(cf&65535)){ct=(cd-cf&65535)+ca&65535}else{ct=ca}ca=r&31;r=f&31;if((ca&65535)<=(r&65535)){cs=ct;break}cs=(ca-r&65535)+ct&65535}else{r=b[(c[277225]|0)+(ce<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){cu=c[277228]&65535}else{cu=b[(c[277213]|0)+(o<<1)>>1]|0}ca=r&-2048;f=cu&-2048;cf=(ca&65535)>(f&65535)?ca-f&65535:0;f=r&2016;ca=cu&2016;if((f&65535)>(ca&65535)){cv=(f-ca&65535)+cf&65535}else{cv=cf}cf=r&31;r=cu&31;if((cf&65535)<=(r&65535)){cs=cv;break}cs=(cf-r&65535)+cv&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=cs;do{if((a[1108928]|0)==0){r=b[(c[277213]|0)+(j+4<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){cw=b[(c[277221]|0)+((r&65535|67616)-(b[(c[277226]|0)+(ce<<1)>>1]&63454)>>1<<1)>>1]|0;break}cf=c[277228]&65535;ca=r&-2048;f=cf&-2048;cd=(ca&65535)>(f&65535)?ca-f&65535:0;f=r&2016;ca=cf&2016;if((f&65535)>(ca&65535)){cx=(f-ca&65535)+cd&65535}else{cx=cd}cd=r&31;r=cf&31;if((cd&65535)<=(r&65535)){cw=cx;break}cw=(cd-r&65535)+cx&65535}else{cw=0}}while(0);ce=j+3|0;b[(c[277218]|0)+(ce<<1)>>1]=cw;r=a[1108909]|0;a[(c[277219]|0)+ce|0]=r;a[(c[277219]|0)+o|0]=r}}while(0);o=ci-1&255;if(o<<24>>24!=0){ch=o;t=10191}}if((t|0)==10191){t=0;o=j+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){r=a[bo+2|0]|0;ce=r&255;if(r<<24>>24==0){break}do{if((a[1108928]|0)==0){r=b[(c[277225]|0)+(ce<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){cy=b[(c[277221]|0)+((r&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}cd=c[277228]&65535;cf=r&-2048;ca=cd&-2048;f=(cf&65535)>(ca&65535)?cf-ca&65535:0;ca=r&2016;cf=cd&2016;if((ca&65535)>(cf&65535)){cz=(ca-cf&65535)+f&65535}else{cz=f}f=r&31;r=cd&31;if((f&65535)<=(r&65535)){cy=cz;break}cy=(f-r&65535)+cz&65535}else{r=b[(c[277225]|0)+(ce<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){cA=c[277228]&65535}else{cA=b[(c[277213]|0)+(o<<1)>>1]|0}f=r&-2048;cd=cA&-2048;cf=(f&65535)>(cd&65535)?f-cd&65535:0;cd=r&2016;f=cA&2016;if((cd&65535)>(f&65535)){cB=(cd-f&65535)+cf&65535}else{cB=cf}cf=r&31;r=cA&31;if((cf&65535)<=(r&65535)){cy=cB;break}cy=(cf-r&65535)+cB&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=cy;do{if((a[1108928]|0)==0){r=b[(c[277213]|0)+(j+6<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){cC=b[(c[277221]|0)+((r&65535|67616)-(b[(c[277226]|0)+(ce<<1)>>1]&63454)>>1<<1)>>1]|0;break}cf=c[277228]&65535;f=r&-2048;cd=cf&-2048;ca=(f&65535)>(cd&65535)?f-cd&65535:0;cd=r&2016;f=cf&2016;if((cd&65535)>(f&65535)){cD=(cd-f&65535)+ca&65535}else{cD=ca}ca=r&31;r=cf&31;if((ca&65535)<=(r&65535)){cC=cD;break}cC=(ca-r&65535)+cD&65535}else{cC=0}}while(0);ce=j+5|0;b[(c[277218]|0)+(ce<<1)>>1]=cC;r=a[1108909]|0;a[(c[277219]|0)+ce|0]=r;a[(c[277219]|0)+o|0]=r}}while(0);o=ch-1&255;if(o<<24>>24!=0){cp=o;t=10216}}if((t|0)==10216){t=0;o=j+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){r=a[bo+3|0]|0;ce=r&255;if(r<<24>>24==0){break}do{if((a[1108928]|0)==0){r=b[(c[277225]|0)+(ce<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){cE=b[(c[277221]|0)+((r&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}ca=c[277228]&65535;cf=r&-2048;f=ca&-2048;cd=(cf&65535)>(f&65535)?cf-f&65535:0;f=r&2016;cf=ca&2016;if((f&65535)>(cf&65535)){cF=(f-cf&65535)+cd&65535}else{cF=cd}cd=r&31;r=ca&31;if((cd&65535)<=(r&65535)){cE=cF;break}cE=(cd-r&65535)+cF&65535}else{r=b[(c[277225]|0)+(ce<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){cG=c[277228]&65535}else{cG=b[(c[277213]|0)+(o<<1)>>1]|0}cd=r&-2048;ca=cG&-2048;cf=(cd&65535)>(ca&65535)?cd-ca&65535:0;ca=r&2016;cd=cG&2016;if((ca&65535)>(cd&65535)){cH=(ca-cd&65535)+cf&65535}else{cH=cf}cf=r&31;r=cG&31;if((cf&65535)<=(r&65535)){cE=cH;break}cE=(cf-r&65535)+cH&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=cE;do{if((a[1108928]|0)==0){r=b[(c[277213]|0)+(j+8<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){cI=b[(c[277221]|0)+((r&65535|67616)-(b[(c[277226]|0)+(ce<<1)>>1]&63454)>>1<<1)>>1]|0;break}cf=c[277228]&65535;cd=r&-2048;ca=cf&-2048;f=(cd&65535)>(ca&65535)?cd-ca&65535:0;ca=r&2016;cd=cf&2016;if((ca&65535)>(cd&65535)){cJ=(ca-cd&65535)+f&65535}else{cJ=f}f=r&31;r=cf&31;if((f&65535)<=(r&65535)){cI=cJ;break}cI=(f-r&65535)+cJ&65535}else{cI=0}}while(0);ce=j+7|0;b[(c[277218]|0)+(ce<<1)>>1]=cI;r=a[1108909]|0;a[(c[277219]|0)+ce|0]=r;a[(c[277219]|0)+o|0]=r}}while(0);o=cp-1&255;if(o<<24>>24!=0){cr=o;t=10241}}if((t|0)==10241){t=0;o=j+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){r=a[bo+4|0]|0;ce=r&255;if(r<<24>>24==0){break}do{if((a[1108928]|0)==0){r=b[(c[277225]|0)+(ce<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){cK=b[(c[277221]|0)+((r&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}f=c[277228]&65535;cf=r&-2048;cd=f&-2048;ca=(cf&65535)>(cd&65535)?cf-cd&65535:0;cd=r&2016;cf=f&2016;if((cd&65535)>(cf&65535)){cL=(cd-cf&65535)+ca&65535}else{cL=ca}ca=r&31;r=f&31;if((ca&65535)<=(r&65535)){cK=cL;break}cK=(ca-r&65535)+cL&65535}else{r=b[(c[277225]|0)+(ce<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){cM=c[277228]&65535}else{cM=b[(c[277213]|0)+(o<<1)>>1]|0}ca=r&-2048;f=cM&-2048;cf=(ca&65535)>(f&65535)?ca-f&65535:0;f=r&2016;ca=cM&2016;if((f&65535)>(ca&65535)){cN=(f-ca&65535)+cf&65535}else{cN=cf}cf=r&31;r=cM&31;if((cf&65535)<=(r&65535)){cK=cN;break}cK=(cf-r&65535)+cN&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=cK;do{if((a[1108928]|0)==0){r=b[(c[277213]|0)+(j+10<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){cO=b[(c[277221]|0)+((r&65535|67616)-(b[(c[277226]|0)+(ce<<1)>>1]&63454)>>1<<1)>>1]|0;break}cf=c[277228]&65535;ca=r&-2048;f=cf&-2048;cd=(ca&65535)>(f&65535)?ca-f&65535:0;f=r&2016;ca=cf&2016;if((f&65535)>(ca&65535)){cP=(f-ca&65535)+cd&65535}else{cP=cd}cd=r&31;r=cf&31;if((cd&65535)<=(r&65535)){cO=cP;break}cO=(cd-r&65535)+cP&65535}else{cO=0}}while(0);ce=j+9|0;b[(c[277218]|0)+(ce<<1)>>1]=cO;r=a[1108909]|0;a[(c[277219]|0)+ce|0]=r;a[(c[277219]|0)+o|0]=r}}while(0);o=cr-1&255;if(o<<24>>24!=0){cg=o;t=10266}}if((t|0)==10266){t=0;o=j+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){r=a[bo+5|0]|0;ce=r&255;if(r<<24>>24==0){break}do{if((a[1108928]|0)==0){r=b[(c[277225]|0)+(ce<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){cQ=b[(c[277221]|0)+((r&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}cd=c[277228]&65535;cf=r&-2048;ca=cd&-2048;f=(cf&65535)>(ca&65535)?cf-ca&65535:0;ca=r&2016;cf=cd&2016;if((ca&65535)>(cf&65535)){cR=(ca-cf&65535)+f&65535}else{cR=f}f=r&31;r=cd&31;if((f&65535)<=(r&65535)){cQ=cR;break}cQ=(f-r&65535)+cR&65535}else{r=b[(c[277225]|0)+(ce<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){cS=c[277228]&65535}else{cS=b[(c[277213]|0)+(o<<1)>>1]|0}f=r&-2048;cd=cS&-2048;cf=(f&65535)>(cd&65535)?f-cd&65535:0;cd=r&2016;f=cS&2016;if((cd&65535)>(f&65535)){cT=(cd-f&65535)+cf&65535}else{cT=cf}cf=r&31;r=cS&31;if((cf&65535)<=(r&65535)){cQ=cT;break}cQ=(cf-r&65535)+cT&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=cQ;do{if((a[1108928]|0)==0){r=b[(c[277213]|0)+(j+12<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){cU=b[(c[277221]|0)+((r&65535|67616)-(b[(c[277226]|0)+(ce<<1)>>1]&63454)>>1<<1)>>1]|0;break}cf=c[277228]&65535;f=r&-2048;cd=cf&-2048;ca=(f&65535)>(cd&65535)?f-cd&65535:0;cd=r&2016;f=cf&2016;if((cd&65535)>(f&65535)){cV=(cd-f&65535)+ca&65535}else{cV=ca}ca=r&31;r=cf&31;if((ca&65535)<=(r&65535)){cU=cV;break}cU=(ca-r&65535)+cV&65535}else{cU=0}}while(0);ce=j+11|0;b[(c[277218]|0)+(ce<<1)>>1]=cU;r=a[1108909]|0;a[(c[277219]|0)+ce|0]=r;a[(c[277219]|0)+o|0]=r}}while(0);o=cg-1&255;if(o<<24>>24!=0){cq=o;t=10291}}if((t|0)==10291){t=0;o=j+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){r=a[bo+6|0]|0;ce=r&255;if(r<<24>>24==0){break}do{if((a[1108928]|0)==0){r=b[(c[277225]|0)+(ce<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){cW=b[(c[277221]|0)+((r&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}ca=c[277228]&65535;cf=r&-2048;f=ca&-2048;cd=(cf&65535)>(f&65535)?cf-f&65535:0;f=r&2016;cf=ca&2016;if((f&65535)>(cf&65535)){cX=(f-cf&65535)+cd&65535}else{cX=cd}cd=r&31;r=ca&31;if((cd&65535)<=(r&65535)){cW=cX;break}cW=(cd-r&65535)+cX&65535}else{r=b[(c[277225]|0)+(ce<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){cY=c[277228]&65535}else{cY=b[(c[277213]|0)+(o<<1)>>1]|0}cd=r&-2048;ca=cY&-2048;cf=(cd&65535)>(ca&65535)?cd-ca&65535:0;ca=r&2016;cd=cY&2016;if((ca&65535)>(cd&65535)){cZ=(ca-cd&65535)+cf&65535}else{cZ=cf}cf=r&31;r=cY&31;if((cf&65535)<=(r&65535)){cW=cZ;break}cW=(cf-r&65535)+cZ&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=cW;do{if((a[1108928]|0)==0){r=b[(c[277213]|0)+(j+14<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){c_=b[(c[277221]|0)+((r&65535|67616)-(b[(c[277226]|0)+(ce<<1)>>1]&63454)>>1<<1)>>1]|0;break}cf=c[277228]&65535;cd=r&-2048;ca=cf&-2048;f=(cd&65535)>(ca&65535)?cd-ca&65535:0;ca=r&2016;cd=cf&2016;if((ca&65535)>(cd&65535)){c$=(ca-cd&65535)+f&65535}else{c$=f}f=r&31;r=cf&31;if((f&65535)<=(r&65535)){c_=c$;break}c_=(f-r&65535)+c$&65535}else{c_=0}}while(0);ce=j+13|0;b[(c[277218]|0)+(ce<<1)>>1]=c_;r=a[1108909]|0;a[(c[277219]|0)+ce|0]=r;a[(c[277219]|0)+o|0]=r}}while(0);if(cq<<24>>24!=1){t=10316}}do{if((t|0)==10316){t=0;o=j+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+o|0]|0)){break}r=a[bo+7|0]|0;ce=r&255;if(r<<24>>24==0){break}do{if((a[1108928]|0)==0){r=b[(c[277225]|0)+(ce<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){c0=b[(c[277221]|0)+((r&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}f=c[277228]&65535;cf=r&-2048;cd=f&-2048;ca=(cf&65535)>(cd&65535)?cf-cd&65535:0;cd=r&2016;cf=f&2016;if((cd&65535)>(cf&65535)){c1=(cd-cf&65535)+ca&65535}else{c1=ca}ca=r&31;r=f&31;if((ca&65535)<=(r&65535)){c0=c1;break}c0=(ca-r&65535)+c1&65535}else{r=b[(c[277225]|0)+(ce<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){c2=c[277228]&65535}else{c2=b[(c[277213]|0)+(o<<1)>>1]|0}ca=r&-2048;f=c2&-2048;cf=(ca&65535)>(f&65535)?ca-f&65535:0;f=r&2016;ca=c2&2016;if((f&65535)>(ca&65535)){c3=(f-ca&65535)+cf&65535}else{c3=cf}cf=r&31;r=c2&31;if((cf&65535)<=(r&65535)){c0=c3;break}c0=(cf-r&65535)+c3&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=c0;do{if((a[1108928]|0)==0){r=b[(c[277213]|0)+(j+16<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){c4=b[(c[277221]|0)+((r&65535|67616)-(b[(c[277226]|0)+(ce<<1)>>1]&63454)>>1<<1)>>1]|0;break}cf=c[277228]&65535;ca=r&-2048;f=cf&-2048;cd=(ca&65535)>(f&65535)?ca-f&65535:0;f=r&2016;ca=cf&2016;if((f&65535)>(ca&65535)){c5=(f-ca&65535)+cd&65535}else{c5=cd}cd=r&31;r=cf&31;if((cd&65535)<=(r&65535)){c4=c5;break}c4=(cd-r&65535)+c5&65535}else{c4=0}}while(0);ce=j+15|0;b[(c[277218]|0)+(ce<<1)>>1]=c4;r=a[1108909]|0;a[(c[277219]|0)+ce|0]=r;a[(c[277219]|0)+o|0]=r}}while(0);r=az-1|0;if((r|0)>0){bo=bo-8|0;az=r;j=(c[277223]|0)+j|0}else{break}}return}}function VH(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0;i=e&1023;j=c[348606]|0;k=(i<<j)+(c[348604]|0)|0;if((e&256|0)==0){l=k}else{l=(c[348602]|0)+k|0}k=l&65535;l=k>>>(j>>>0);j=(e&16384|0)!=0;m=l<<6;do{if(j){n=(c[348622]|0)+m|0;if((a[(c[348618]|0)+l|0]|0)!=0){o=n;break}p=fi[c[348636]&63](n,k,i)|0;a[(c[348618]|0)+l|0]=p;o=n}else{n=(c[348624]|0)+m|0;if((a[(c[348620]|0)+l|0]|0)!=0){o=n;break}p=fi[c[348638]&63](n,k,i)|0;a[(c[348620]|0)+l|0]=p;o=n}}while(0);if((a[(c[348620]|0)+l|0]|0)==2){return}if((a[1394464]|0)==0){q=1106168+((e>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){l=d[1044485]|0;c[276541]=7080+(l<<5);i=0;do{k=i<<1&2;m=i&2;n=i&4;p=0;do{b[1125528+(i<<9)+(p<<1)>>1]=d[(p>>>1&28|m)+(7080+(l<<5))|0]<<6|d[(p<<2&28|k)+(7080+(l<<5))|0]<<11|d[(p>>>3&24|n)+(7080+(l<<5))|0];p=p+1|0;}while(p>>>0<256);i=i+1|0;}while(i>>>0<8);a[1106089]=0}q=1125528+((e>>>10&7)<<9)|0}c[277226]=q;c[277225]=(a[1108928]|0)!=0?1393712:q;if((e&49152|0)==0){if((h|0)<=0){return}q=o+g|0;i=h;l=f;while(1){p=a[1108908]|0;n=c[277219]|0;do{if((p&255)>(d[n+l|0]|0)){k=a[q]|0;if(k<<24>>24==0){r=p;s=n;break}b[(c[277218]|0)+(l<<1)>>1]=b[(c[277225]|0)+((k&255)<<1)>>1]|0;if((a[1108928]|0)==0){t=b[(c[277213]|0)+(l+2<<1)>>1]|0}else{t=0}k=l+1|0;b[(c[277218]|0)+(k<<1)>>1]=t;m=a[1108909]|0;a[(c[277219]|0)+k|0]=m;a[(c[277219]|0)+l|0]=m;r=a[1108908]|0;s=c[277219]|0}else{r=p;s=n}}while(0);n=l+2|0;do{if((r&255)>(d[s+n|0]|0)){p=a[q+1|0]|0;if(p<<24>>24==0){u=r;v=s;break}b[(c[277218]|0)+(n<<1)>>1]=b[(c[277225]|0)+((p&255)<<1)>>1]|0;if((a[1108928]|0)==0){w=b[(c[277213]|0)+(l+4<<1)>>1]|0}else{w=0}p=l+3|0;b[(c[277218]|0)+(p<<1)>>1]=w;m=a[1108909]|0;a[(c[277219]|0)+p|0]=m;a[(c[277219]|0)+n|0]=m;u=a[1108908]|0;v=c[277219]|0}else{u=r;v=s}}while(0);n=l+4|0;do{if((u&255)>(d[v+n|0]|0)){m=a[q+2|0]|0;if(m<<24>>24==0){x=u;y=v;break}b[(c[277218]|0)+(n<<1)>>1]=b[(c[277225]|0)+((m&255)<<1)>>1]|0;if((a[1108928]|0)==0){z=b[(c[277213]|0)+(l+6<<1)>>1]|0}else{z=0}m=l+5|0;b[(c[277218]|0)+(m<<1)>>1]=z;p=a[1108909]|0;a[(c[277219]|0)+m|0]=p;a[(c[277219]|0)+n|0]=p;x=a[1108908]|0;y=c[277219]|0}else{x=u;y=v}}while(0);n=l+6|0;do{if((x&255)>(d[y+n|0]|0)){p=a[q+3|0]|0;if(p<<24>>24==0){A=x;B=y;break}b[(c[277218]|0)+(n<<1)>>1]=b[(c[277225]|0)+((p&255)<<1)>>1]|0;if((a[1108928]|0)==0){C=b[(c[277213]|0)+(l+8<<1)>>1]|0}else{C=0}p=l+7|0;b[(c[277218]|0)+(p<<1)>>1]=C;m=a[1108909]|0;a[(c[277219]|0)+p|0]=m;a[(c[277219]|0)+n|0]=m;A=a[1108908]|0;B=c[277219]|0}else{A=x;B=y}}while(0);n=l+8|0;do{if((A&255)>(d[B+n|0]|0)){m=a[q+4|0]|0;if(m<<24>>24==0){D=A;E=B;break}b[(c[277218]|0)+(n<<1)>>1]=b[(c[277225]|0)+((m&255)<<1)>>1]|0;if((a[1108928]|0)==0){F=b[(c[277213]|0)+(l+10<<1)>>1]|0}else{F=0}m=l+9|0;b[(c[277218]|0)+(m<<1)>>1]=F;p=a[1108909]|0;a[(c[277219]|0)+m|0]=p;a[(c[277219]|0)+n|0]=p;D=a[1108908]|0;E=c[277219]|0}else{D=A;E=B}}while(0);n=l+10|0;do{if((D&255)>(d[E+n|0]|0)){p=a[q+5|0]|0;if(p<<24>>24==0){G=D;H=E;break}b[(c[277218]|0)+(n<<1)>>1]=b[(c[277225]|0)+((p&255)<<1)>>1]|0;if((a[1108928]|0)==0){I=b[(c[277213]|0)+(l+12<<1)>>1]|0}else{I=0}p=l+11|0;b[(c[277218]|0)+(p<<1)>>1]=I;m=a[1108909]|0;a[(c[277219]|0)+p|0]=m;a[(c[277219]|0)+n|0]=m;G=a[1108908]|0;H=c[277219]|0}else{G=D;H=E}}while(0);n=l+12|0;do{if((G&255)>(d[H+n|0]|0)){m=a[q+6|0]|0;if(m<<24>>24==0){J=G;K=H;break}b[(c[277218]|0)+(n<<1)>>1]=b[(c[277225]|0)+((m&255)<<1)>>1]|0;if((a[1108928]|0)==0){L=b[(c[277213]|0)+(l+14<<1)>>1]|0}else{L=0}m=l+13|0;b[(c[277218]|0)+(m<<1)>>1]=L;p=a[1108909]|0;a[(c[277219]|0)+m|0]=p;a[(c[277219]|0)+n|0]=p;J=a[1108908]|0;K=c[277219]|0}else{J=G;K=H}}while(0);n=l+14|0;do{if((J&255)>(d[K+n|0]|0)){p=a[q+7|0]|0;if(p<<24>>24==0){break}b[(c[277218]|0)+(n<<1)>>1]=b[(c[277225]|0)+((p&255)<<1)>>1]|0;if((a[1108928]|0)==0){M=b[(c[277213]|0)+(l+16<<1)>>1]|0}else{M=0}p=l+15|0;b[(c[277218]|0)+(p<<1)>>1]=M;m=a[1108909]|0;a[(c[277219]|0)+p|0]=m;a[(c[277219]|0)+n|0]=m}}while(0);n=i-1|0;if((n|0)<=0){break}q=q+8|0;i=n;l=(c[277223]|0)+l|0}return}if((e&32768|0)==0){if((h|0)<=0){return}e=o+g|0;l=h;i=f;while(1){q=a[1108908]|0;M=c[277219]|0;do{if((q&255)>(d[M+i|0]|0)){K=a[e+7|0]|0;if(K<<24>>24==0){N=q;O=M;break}b[(c[277218]|0)+(i<<1)>>1]=b[(c[277225]|0)+((K&255)<<1)>>1]|0;if((a[1108928]|0)==0){P=b[(c[277213]|0)+(i+2<<1)>>1]|0}else{P=0}K=i+1|0;b[(c[277218]|0)+(K<<1)>>1]=P;J=a[1108909]|0;a[(c[277219]|0)+K|0]=J;a[(c[277219]|0)+i|0]=J;N=a[1108908]|0;O=c[277219]|0}else{N=q;O=M}}while(0);M=i+2|0;do{if((N&255)>(d[O+M|0]|0)){q=a[e+6|0]|0;if(q<<24>>24==0){Q=N;R=O;break}b[(c[277218]|0)+(M<<1)>>1]=b[(c[277225]|0)+((q&255)<<1)>>1]|0;if((a[1108928]|0)==0){S=b[(c[277213]|0)+(i+4<<1)>>1]|0}else{S=0}q=i+3|0;b[(c[277218]|0)+(q<<1)>>1]=S;J=a[1108909]|0;a[(c[277219]|0)+q|0]=J;a[(c[277219]|0)+M|0]=J;Q=a[1108908]|0;R=c[277219]|0}else{Q=N;R=O}}while(0);M=i+4|0;do{if((Q&255)>(d[R+M|0]|0)){J=a[e+5|0]|0;if(J<<24>>24==0){T=Q;U=R;break}b[(c[277218]|0)+(M<<1)>>1]=b[(c[277225]|0)+((J&255)<<1)>>1]|0;if((a[1108928]|0)==0){V=b[(c[277213]|0)+(i+6<<1)>>1]|0}else{V=0}J=i+5|0;b[(c[277218]|0)+(J<<1)>>1]=V;q=a[1108909]|0;a[(c[277219]|0)+J|0]=q;a[(c[277219]|0)+M|0]=q;T=a[1108908]|0;U=c[277219]|0}else{T=Q;U=R}}while(0);M=i+6|0;do{if((T&255)>(d[U+M|0]|0)){q=a[e+4|0]|0;if(q<<24>>24==0){W=T;X=U;break}b[(c[277218]|0)+(M<<1)>>1]=b[(c[277225]|0)+((q&255)<<1)>>1]|0;if((a[1108928]|0)==0){Y=b[(c[277213]|0)+(i+8<<1)>>1]|0}else{Y=0}q=i+7|0;b[(c[277218]|0)+(q<<1)>>1]=Y;J=a[1108909]|0;a[(c[277219]|0)+q|0]=J;a[(c[277219]|0)+M|0]=J;W=a[1108908]|0;X=c[277219]|0}else{W=T;X=U}}while(0);M=i+8|0;do{if((W&255)>(d[X+M|0]|0)){J=a[e+3|0]|0;if(J<<24>>24==0){Z=W;_=X;break}b[(c[277218]|0)+(M<<1)>>1]=b[(c[277225]|0)+((J&255)<<1)>>1]|0;if((a[1108928]|0)==0){$=b[(c[277213]|0)+(i+10<<1)>>1]|0}else{$=0}J=i+9|0;b[(c[277218]|0)+(J<<1)>>1]=$;q=a[1108909]|0;a[(c[277219]|0)+J|0]=q;a[(c[277219]|0)+M|0]=q;Z=a[1108908]|0;_=c[277219]|0}else{Z=W;_=X}}while(0);M=i+10|0;do{if((Z&255)>(d[_+M|0]|0)){q=a[e+2|0]|0;if(q<<24>>24==0){aa=Z;ab=_;break}b[(c[277218]|0)+(M<<1)>>1]=b[(c[277225]|0)+((q&255)<<1)>>1]|0;if((a[1108928]|0)==0){ac=b[(c[277213]|0)+(i+12<<1)>>1]|0}else{ac=0}q=i+11|0;b[(c[277218]|0)+(q<<1)>>1]=ac;J=a[1108909]|0;a[(c[277219]|0)+q|0]=J;a[(c[277219]|0)+M|0]=J;aa=a[1108908]|0;ab=c[277219]|0}else{aa=Z;ab=_}}while(0);M=i+12|0;do{if((aa&255)>(d[ab+M|0]|0)){J=a[e+1|0]|0;if(J<<24>>24==0){ad=aa;ae=ab;break}b[(c[277218]|0)+(M<<1)>>1]=b[(c[277225]|0)+((J&255)<<1)>>1]|0;if((a[1108928]|0)==0){af=b[(c[277213]|0)+(i+14<<1)>>1]|0}else{af=0}J=i+13|0;b[(c[277218]|0)+(J<<1)>>1]=af;q=a[1108909]|0;a[(c[277219]|0)+J|0]=q;a[(c[277219]|0)+M|0]=q;ad=a[1108908]|0;ae=c[277219]|0}else{ad=aa;ae=ab}}while(0);M=i+14|0;do{if((ad&255)>(d[ae+M|0]|0)){q=a[e]|0;if(q<<24>>24==0){break}b[(c[277218]|0)+(M<<1)>>1]=b[(c[277225]|0)+((q&255)<<1)>>1]|0;if((a[1108928]|0)==0){ag=b[(c[277213]|0)+(i+16<<1)>>1]|0}else{ag=0}q=i+15|0;b[(c[277218]|0)+(q<<1)>>1]=ag;J=a[1108909]|0;a[(c[277219]|0)+q|0]=J;a[(c[277219]|0)+M|0]=J}}while(0);M=l-1|0;if((M|0)<=0){break}e=e+8|0;l=M;i=(c[277223]|0)+i|0}return}i=o+(56-g)|0;g=(h|0)>0;if(j){if(g){ah=i;ai=h;aj=f}else{return}while(1){j=a[1108908]|0;o=c[277219]|0;do{if((j&255)>(d[o+aj|0]|0)){l=a[ah+7|0]|0;if(l<<24>>24==0){ak=j;al=o;break}b[(c[277218]|0)+(aj<<1)>>1]=b[(c[277225]|0)+((l&255)<<1)>>1]|0;if((a[1108928]|0)==0){am=b[(c[277213]|0)+(aj+2<<1)>>1]|0}else{am=0}l=aj+1|0;b[(c[277218]|0)+(l<<1)>>1]=am;e=a[1108909]|0;a[(c[277219]|0)+l|0]=e;a[(c[277219]|0)+aj|0]=e;ak=a[1108908]|0;al=c[277219]|0}else{ak=j;al=o}}while(0);o=aj+2|0;do{if((ak&255)>(d[al+o|0]|0)){j=a[ah+6|0]|0;if(j<<24>>24==0){an=ak;ao=al;break}b[(c[277218]|0)+(o<<1)>>1]=b[(c[277225]|0)+((j&255)<<1)>>1]|0;if((a[1108928]|0)==0){ap=b[(c[277213]|0)+(aj+4<<1)>>1]|0}else{ap=0}j=aj+3|0;b[(c[277218]|0)+(j<<1)>>1]=ap;e=a[1108909]|0;a[(c[277219]|0)+j|0]=e;a[(c[277219]|0)+o|0]=e;an=a[1108908]|0;ao=c[277219]|0}else{an=ak;ao=al}}while(0);o=aj+4|0;do{if((an&255)>(d[ao+o|0]|0)){e=a[ah+5|0]|0;if(e<<24>>24==0){aq=an;ar=ao;break}b[(c[277218]|0)+(o<<1)>>1]=b[(c[277225]|0)+((e&255)<<1)>>1]|0;if((a[1108928]|0)==0){as=b[(c[277213]|0)+(aj+6<<1)>>1]|0}else{as=0}e=aj+5|0;b[(c[277218]|0)+(e<<1)>>1]=as;j=a[1108909]|0;a[(c[277219]|0)+e|0]=j;a[(c[277219]|0)+o|0]=j;aq=a[1108908]|0;ar=c[277219]|0}else{aq=an;ar=ao}}while(0);o=aj+6|0;do{if((aq&255)>(d[ar+o|0]|0)){j=a[ah+4|0]|0;if(j<<24>>24==0){at=aq;au=ar;break}b[(c[277218]|0)+(o<<1)>>1]=b[(c[277225]|0)+((j&255)<<1)>>1]|0;if((a[1108928]|0)==0){av=b[(c[277213]|0)+(aj+8<<1)>>1]|0}else{av=0}j=aj+7|0;b[(c[277218]|0)+(j<<1)>>1]=av;e=a[1108909]|0;a[(c[277219]|0)+j|0]=e;a[(c[277219]|0)+o|0]=e;at=a[1108908]|0;au=c[277219]|0}else{at=aq;au=ar}}while(0);o=aj+8|0;do{if((at&255)>(d[au+o|0]|0)){e=a[ah+3|0]|0;if(e<<24>>24==0){aw=at;ax=au;break}b[(c[277218]|0)+(o<<1)>>1]=b[(c[277225]|0)+((e&255)<<1)>>1]|0;if((a[1108928]|0)==0){ay=b[(c[277213]|0)+(aj+10<<1)>>1]|0}else{ay=0}e=aj+9|0;b[(c[277218]|0)+(e<<1)>>1]=ay;j=a[1108909]|0;a[(c[277219]|0)+e|0]=j;a[(c[277219]|0)+o|0]=j;aw=a[1108908]|0;ax=c[277219]|0}else{aw=at;ax=au}}while(0);o=aj+10|0;do{if((aw&255)>(d[ax+o|0]|0)){j=a[ah+2|0]|0;if(j<<24>>24==0){az=aw;aA=ax;break}b[(c[277218]|0)+(o<<1)>>1]=b[(c[277225]|0)+((j&255)<<1)>>1]|0;if((a[1108928]|0)==0){aB=b[(c[277213]|0)+(aj+12<<1)>>1]|0}else{aB=0}j=aj+11|0;b[(c[277218]|0)+(j<<1)>>1]=aB;e=a[1108909]|0;a[(c[277219]|0)+j|0]=e;a[(c[277219]|0)+o|0]=e;az=a[1108908]|0;aA=c[277219]|0}else{az=aw;aA=ax}}while(0);o=aj+12|0;do{if((az&255)>(d[aA+o|0]|0)){e=a[ah+1|0]|0;if(e<<24>>24==0){aC=az;aD=aA;break}b[(c[277218]|0)+(o<<1)>>1]=b[(c[277225]|0)+((e&255)<<1)>>1]|0;if((a[1108928]|0)==0){aE=b[(c[277213]|0)+(aj+14<<1)>>1]|0}else{aE=0}e=aj+13|0;b[(c[277218]|0)+(e<<1)>>1]=aE;j=a[1108909]|0;a[(c[277219]|0)+e|0]=j;a[(c[277219]|0)+o|0]=j;aC=a[1108908]|0;aD=c[277219]|0}else{aC=az;aD=aA}}while(0);o=aj+14|0;do{if((aC&255)>(d[aD+o|0]|0)){j=a[ah]|0;if(j<<24>>24==0){break}b[(c[277218]|0)+(o<<1)>>1]=b[(c[277225]|0)+((j&255)<<1)>>1]|0;if((a[1108928]|0)==0){aF=b[(c[277213]|0)+(aj+16<<1)>>1]|0}else{aF=0}j=aj+15|0;b[(c[277218]|0)+(j<<1)>>1]=aF;e=a[1108909]|0;a[(c[277219]|0)+j|0]=e;a[(c[277219]|0)+o|0]=e}}while(0);o=ai-1|0;if((o|0)<=0){break}ah=ah-8|0;ai=o;aj=(c[277223]|0)+aj|0}return}else{if(g){aG=i;aH=h;aI=f}else{return}while(1){f=a[1108908]|0;h=c[277219]|0;do{if((f&255)>(d[h+aI|0]|0)){i=a[aG]|0;if(i<<24>>24==0){aJ=f;aK=h;break}b[(c[277218]|0)+(aI<<1)>>1]=b[(c[277225]|0)+((i&255)<<1)>>1]|0;if((a[1108928]|0)==0){aL=b[(c[277213]|0)+(aI+2<<1)>>1]|0}else{aL=0}i=aI+1|0;b[(c[277218]|0)+(i<<1)>>1]=aL;g=a[1108909]|0;a[(c[277219]|0)+i|0]=g;a[(c[277219]|0)+aI|0]=g;aJ=a[1108908]|0;aK=c[277219]|0}else{aJ=f;aK=h}}while(0);h=aI+2|0;do{if((aJ&255)>(d[aK+h|0]|0)){f=a[aG+1|0]|0;if(f<<24>>24==0){aM=aJ;aN=aK;break}b[(c[277218]|0)+(h<<1)>>1]=b[(c[277225]|0)+((f&255)<<1)>>1]|0;if((a[1108928]|0)==0){aO=b[(c[277213]|0)+(aI+4<<1)>>1]|0}else{aO=0}f=aI+3|0;b[(c[277218]|0)+(f<<1)>>1]=aO;g=a[1108909]|0;a[(c[277219]|0)+f|0]=g;a[(c[277219]|0)+h|0]=g;aM=a[1108908]|0;aN=c[277219]|0}else{aM=aJ;aN=aK}}while(0);h=aI+4|0;do{if((aM&255)>(d[aN+h|0]|0)){g=a[aG+2|0]|0;if(g<<24>>24==0){aP=aM;aQ=aN;break}b[(c[277218]|0)+(h<<1)>>1]=b[(c[277225]|0)+((g&255)<<1)>>1]|0;if((a[1108928]|0)==0){aR=b[(c[277213]|0)+(aI+6<<1)>>1]|0}else{aR=0}g=aI+5|0;b[(c[277218]|0)+(g<<1)>>1]=aR;f=a[1108909]|0;a[(c[277219]|0)+g|0]=f;a[(c[277219]|0)+h|0]=f;aP=a[1108908]|0;aQ=c[277219]|0}else{aP=aM;aQ=aN}}while(0);h=aI+6|0;do{if((aP&255)>(d[aQ+h|0]|0)){f=a[aG+3|0]|0;if(f<<24>>24==0){aS=aP;aT=aQ;break}b[(c[277218]|0)+(h<<1)>>1]=b[(c[277225]|0)+((f&255)<<1)>>1]|0;if((a[1108928]|0)==0){aU=b[(c[277213]|0)+(aI+8<<1)>>1]|0}else{aU=0}f=aI+7|0;b[(c[277218]|0)+(f<<1)>>1]=aU;g=a[1108909]|0;a[(c[277219]|0)+f|0]=g;a[(c[277219]|0)+h|0]=g;aS=a[1108908]|0;aT=c[277219]|0}else{aS=aP;aT=aQ}}while(0);h=aI+8|0;do{if((aS&255)>(d[aT+h|0]|0)){g=a[aG+4|0]|0;if(g<<24>>24==0){aV=aS;aW=aT;break}b[(c[277218]|0)+(h<<1)>>1]=b[(c[277225]|0)+((g&255)<<1)>>1]|0;if((a[1108928]|0)==0){aX=b[(c[277213]|0)+(aI+10<<1)>>1]|0}else{aX=0}g=aI+9|0;b[(c[277218]|0)+(g<<1)>>1]=aX;f=a[1108909]|0;a[(c[277219]|0)+g|0]=f;a[(c[277219]|0)+h|0]=f;aV=a[1108908]|0;aW=c[277219]|0}else{aV=aS;aW=aT}}while(0);h=aI+10|0;do{if((aV&255)>(d[aW+h|0]|0)){f=a[aG+5|0]|0;if(f<<24>>24==0){aY=aV;aZ=aW;break}b[(c[277218]|0)+(h<<1)>>1]=b[(c[277225]|0)+((f&255)<<1)>>1]|0;if((a[1108928]|0)==0){a_=b[(c[277213]|0)+(aI+12<<1)>>1]|0}else{a_=0}f=aI+11|0;b[(c[277218]|0)+(f<<1)>>1]=a_;g=a[1108909]|0;a[(c[277219]|0)+f|0]=g;a[(c[277219]|0)+h|0]=g;aY=a[1108908]|0;aZ=c[277219]|0}else{aY=aV;aZ=aW}}while(0);h=aI+12|0;do{if((aY&255)>(d[aZ+h|0]|0)){g=a[aG+6|0]|0;if(g<<24>>24==0){a$=aY;a0=aZ;break}b[(c[277218]|0)+(h<<1)>>1]=b[(c[277225]|0)+((g&255)<<1)>>1]|0;if((a[1108928]|0)==0){a1=b[(c[277213]|0)+(aI+14<<1)>>1]|0}else{a1=0}g=aI+13|0;b[(c[277218]|0)+(g<<1)>>1]=a1;f=a[1108909]|0;a[(c[277219]|0)+g|0]=f;a[(c[277219]|0)+h|0]=f;a$=a[1108908]|0;a0=c[277219]|0}else{a$=aY;a0=aZ}}while(0);h=aI+14|0;do{if((a$&255)>(d[a0+h|0]|0)){f=a[aG+7|0]|0;if(f<<24>>24==0){break}b[(c[277218]|0)+(h<<1)>>1]=b[(c[277225]|0)+((f&255)<<1)>>1]|0;if((a[1108928]|0)==0){a2=b[(c[277213]|0)+(aI+16<<1)>>1]|0}else{a2=0}f=aI+15|0;b[(c[277218]|0)+(f<<1)>>1]=a2;g=a[1108909]|0;a[(c[277219]|0)+f|0]=g;a[(c[277219]|0)+h|0]=g}}while(0);h=aH-1|0;if((h|0)<=0){break}aG=aG-8|0;aH=h;aI=(c[277223]|0)+aI|0}return}}function VI(f,g,h,i){f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0,cf=0,cg=0,ch=0,ci=0,cj=0,ck=0,cl=0,cm=0,cn=0,co=0,cp=0,cq=0,cr=0,cs=0,ct=0,cu=0,cv=0,cw=0,cx=0,cy=0,cz=0,cA=0,cB=0,cC=0,cD=0,cE=0,cF=0,cG=0,cH=0,cI=0,cJ=0,cK=0,cL=0,cM=0,cN=0,cO=0,cP=0,cQ=0,cR=0,cS=0,cT=0,cU=0,cV=0,cW=0,cX=0,cY=0,cZ=0,c_=0,c$=0,c0=0,c1=0,c2=0,c3=0,c4=0,c5=0,c6=0,c7=0,c8=0,c9=0,da=0,db=0,dc=0,dd=0,de=0,df=0,dg=0,dh=0,di=0,dj=0,dk=0,dl=0,dm=0,dn=0,dp=0,dq=0,dr=0,ds=0,dt=0,du=0,dv=0,dw=0,dx=0,dy=0,dz=0,dA=0,dB=0,dC=0,dD=0,dE=0,dF=0,dG=0,dH=0,dI=0,dJ=0,dK=0,dL=0,dM=0,dN=0,dO=0,dP=0,dQ=0,dR=0,dS=0,dT=0,dU=0,dV=0,dW=0,dX=0,dY=0,dZ=0,d_=0,d$=0,d0=0,d1=0,d2=0,d3=0,d4=0,d5=0,d6=0,d7=0,d8=0,d9=0,ea=0,eb=0,ec=0,ed=0,ee=0,ef=0,eg=0,eh=0,ei=0,ej=0,ek=0,el=0,em=0,en=0,eo=0,ep=0,eq=0,er=0,es=0,et=0,eu=0,ev=0,ew=0,ex=0,ey=0,ez=0,eA=0,eB=0,eC=0,eD=0,eE=0,eF=0,eG=0,eH=0,eI=0,eJ=0,eK=0,eL=0,eM=0,eN=0,eO=0,eP=0,eQ=0,eR=0,eS=0,eT=0,eU=0,eV=0,eW=0,eX=0,eY=0,eZ=0,e_=0,e$=0,e0=0,e1=0,e2=0,e3=0,e4=0,e5=0,e6=0;j=f&1023;k=c[348606]|0;l=(j<<k)+(c[348604]|0)|0;if((f&256|0)==0){m=l}else{m=(c[348602]|0)+l|0}l=m&65535;m=l>>>(k>>>0);k=(f&16384|0)!=0;n=m<<6;do{if(k){o=(c[348622]|0)+n|0;if((a[(c[348618]|0)+m|0]|0)!=0){p=o;break}q=fi[c[348636]&63](o,l,j)|0;a[(c[348618]|0)+m|0]=q;p=o}else{o=(c[348624]|0)+n|0;if((a[(c[348620]|0)+m|0]|0)!=0){p=o;break}q=fi[c[348638]&63](o,l,j)|0;a[(c[348620]|0)+m|0]=q;p=o}}while(0);if((a[(c[348620]|0)+m|0]|0)==2){return}if((a[1394464]|0)==0){r=1106168+((f>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){m=d[1044485]|0;c[276541]=7080+(m<<5);j=0;do{l=j<<1&2;n=j&2;o=j&4;q=0;do{b[1125528+(j<<9)+(q<<1)>>1]=d[(q>>>1&28|n)+(7080+(m<<5))|0]<<6|d[(q<<2&28|l)+(7080+(m<<5))|0]<<11|d[(q>>>3&24|o)+(7080+(m<<5))|0];q=q+1|0;}while(q>>>0<256);j=j+1|0;}while(j>>>0<8);a[1106089]=0}r=1125528+((f>>>10&7)<<9)|0}c[277226]=r;c[277225]=(a[1108928]|0)!=0?1393712:r;if((f&49152|0)==0){if((i|0)<=0){return}r=p+h|0;j=i;m=g;while(1){q=a[1108908]|0;o=c[277219]|0;do{if((q&255)>(d[o+m|0]|0)){l=a[r]|0;n=l&255;if(l<<24>>24==0){s=q;t=o;break}l=e[(c[277225]|0)+(n<<1)>>1]|0;u=(a[(c[277215]|0)+m|0]&32)==0;if(u){v=c[277228]|0;w=v;x=v&-2082}else{v=e[(c[277213]|0)+(m<<1)>>1]|0;w=v;x=v&63454}if(u){y=c[277228]|0}else{y=e[(c[277213]|0)+(m<<1)>>1]|0}b[(c[277218]|0)+(m<<1)>>1]=((y^l)&2081|e[(c[277220]|0)+((l&2081&w)+((x+(l&63454)|0)>>>1)<<1)>>1])&65535;l=(a[1108928]|0)==0;if(l){z=b[(c[277213]|0)+(m+2<<1)>>1]&63454}else{z=0}u=(a[(c[277215]|0)+m|0]&32)==0;if(u){A=c[277228]|0}else{A=e[(c[277226]|0)+(n<<1)>>1]|0}if(l){B=b[(c[277213]|0)+(m+2<<1)>>1]&2081}else{B=0}if(u){C=c[277228]|0}else{C=e[(c[277226]|0)+(n<<1)>>1]|0}if(l){D=e[(c[277213]|0)+(m+2<<1)>>1]|0}else{D=0}if(u){E=c[277228]|0}else{E=e[(c[277226]|0)+(n<<1)>>1]|0}n=m+1|0;b[(c[277218]|0)+(n<<1)>>1]=((E^D)&2081|e[(c[277220]|0)+((C&B)+(((A&-2082)+z|0)>>>1)<<1)>>1])&65535;u=a[1108909]|0;a[(c[277219]|0)+n|0]=u;a[(c[277219]|0)+m|0]=u;s=a[1108908]|0;t=c[277219]|0}else{s=q;t=o}}while(0);o=m+2|0;do{if((s&255)>(d[t+o|0]|0)){q=a[r+1|0]|0;u=q&255;if(q<<24>>24==0){F=s;G=t;break}q=e[(c[277225]|0)+(u<<1)>>1]|0;n=(a[(c[277215]|0)+o|0]&32)==0;if(n){l=c[277228]|0;H=l;I=l&-2082}else{l=e[(c[277213]|0)+(o<<1)>>1]|0;H=l;I=l&63454}if(n){J=c[277228]|0}else{J=e[(c[277213]|0)+(o<<1)>>1]|0}b[(c[277218]|0)+(o<<1)>>1]=((J^q)&2081|e[(c[277220]|0)+((q&2081&H)+((I+(q&63454)|0)>>>1)<<1)>>1])&65535;q=(a[1108928]|0)==0;if(q){K=b[(c[277213]|0)+(m+4<<1)>>1]&63454}else{K=0}n=(a[(c[277215]|0)+o|0]&32)==0;if(n){L=c[277228]|0}else{L=e[(c[277226]|0)+(u<<1)>>1]|0}if(q){M=b[(c[277213]|0)+(m+4<<1)>>1]&2081}else{M=0}if(n){N=c[277228]|0}else{N=e[(c[277226]|0)+(u<<1)>>1]|0}if(q){O=e[(c[277213]|0)+(m+4<<1)>>1]|0}else{O=0}if(n){P=c[277228]|0}else{P=e[(c[277226]|0)+(u<<1)>>1]|0}u=m+3|0;b[(c[277218]|0)+(u<<1)>>1]=((P^O)&2081|e[(c[277220]|0)+((N&M)+(((L&-2082)+K|0)>>>1)<<1)>>1])&65535;n=a[1108909]|0;a[(c[277219]|0)+u|0]=n;a[(c[277219]|0)+o|0]=n;F=a[1108908]|0;G=c[277219]|0}else{F=s;G=t}}while(0);o=m+4|0;do{if((F&255)>(d[G+o|0]|0)){n=a[r+2|0]|0;u=n&255;if(n<<24>>24==0){Q=F;R=G;break}n=e[(c[277225]|0)+(u<<1)>>1]|0;q=(a[(c[277215]|0)+o|0]&32)==0;if(q){l=c[277228]|0;S=l;T=l&-2082}else{l=e[(c[277213]|0)+(o<<1)>>1]|0;S=l;T=l&63454}if(q){U=c[277228]|0}else{U=e[(c[277213]|0)+(o<<1)>>1]|0}b[(c[277218]|0)+(o<<1)>>1]=((U^n)&2081|e[(c[277220]|0)+((n&2081&S)+((T+(n&63454)|0)>>>1)<<1)>>1])&65535;n=(a[1108928]|0)==0;if(n){V=b[(c[277213]|0)+(m+6<<1)>>1]&63454}else{V=0}q=(a[(c[277215]|0)+o|0]&32)==0;if(q){W=c[277228]|0}else{W=e[(c[277226]|0)+(u<<1)>>1]|0}if(n){X=b[(c[277213]|0)+(m+6<<1)>>1]&2081}else{X=0}if(q){Y=c[277228]|0}else{Y=e[(c[277226]|0)+(u<<1)>>1]|0}if(n){Z=e[(c[277213]|0)+(m+6<<1)>>1]|0}else{Z=0}if(q){_=c[277228]|0}else{_=e[(c[277226]|0)+(u<<1)>>1]|0}u=m+5|0;b[(c[277218]|0)+(u<<1)>>1]=((_^Z)&2081|e[(c[277220]|0)+((Y&X)+(((W&-2082)+V|0)>>>1)<<1)>>1])&65535;q=a[1108909]|0;a[(c[277219]|0)+u|0]=q;a[(c[277219]|0)+o|0]=q;Q=a[1108908]|0;R=c[277219]|0}else{Q=F;R=G}}while(0);o=m+6|0;do{if((Q&255)>(d[R+o|0]|0)){q=a[r+3|0]|0;u=q&255;if(q<<24>>24==0){$=Q;aa=R;break}q=e[(c[277225]|0)+(u<<1)>>1]|0;n=(a[(c[277215]|0)+o|0]&32)==0;if(n){l=c[277228]|0;ab=l;ac=l&-2082}else{l=e[(c[277213]|0)+(o<<1)>>1]|0;ab=l;ac=l&63454}if(n){ad=c[277228]|0}else{ad=e[(c[277213]|0)+(o<<1)>>1]|0}b[(c[277218]|0)+(o<<1)>>1]=((ad^q)&2081|e[(c[277220]|0)+((q&2081&ab)+((ac+(q&63454)|0)>>>1)<<1)>>1])&65535;q=(a[1108928]|0)==0;if(q){ae=b[(c[277213]|0)+(m+8<<1)>>1]&63454}else{ae=0}n=(a[(c[277215]|0)+o|0]&32)==0;if(n){af=c[277228]|0}else{af=e[(c[277226]|0)+(u<<1)>>1]|0}if(q){ag=b[(c[277213]|0)+(m+8<<1)>>1]&2081}else{ag=0}if(n){ah=c[277228]|0}else{ah=e[(c[277226]|0)+(u<<1)>>1]|0}if(q){ai=e[(c[277213]|0)+(m+8<<1)>>1]|0}else{ai=0}if(n){aj=c[277228]|0}else{aj=e[(c[277226]|0)+(u<<1)>>1]|0}u=m+7|0;b[(c[277218]|0)+(u<<1)>>1]=((aj^ai)&2081|e[(c[277220]|0)+((ah&ag)+(((af&-2082)+ae|0)>>>1)<<1)>>1])&65535;n=a[1108909]|0;a[(c[277219]|0)+u|0]=n;a[(c[277219]|0)+o|0]=n;$=a[1108908]|0;aa=c[277219]|0}else{$=Q;aa=R}}while(0);o=m+8|0;do{if(($&255)>(d[aa+o|0]|0)){n=a[r+4|0]|0;u=n&255;if(n<<24>>24==0){ak=$;al=aa;break}n=e[(c[277225]|0)+(u<<1)>>1]|0;q=(a[(c[277215]|0)+o|0]&32)==0;if(q){l=c[277228]|0;am=l;an=l&-2082}else{l=e[(c[277213]|0)+(o<<1)>>1]|0;am=l;an=l&63454}if(q){ao=c[277228]|0}else{ao=e[(c[277213]|0)+(o<<1)>>1]|0}b[(c[277218]|0)+(o<<1)>>1]=((ao^n)&2081|e[(c[277220]|0)+((n&2081&am)+((an+(n&63454)|0)>>>1)<<1)>>1])&65535;n=(a[1108928]|0)==0;if(n){ap=b[(c[277213]|0)+(m+10<<1)>>1]&63454}else{ap=0}q=(a[(c[277215]|0)+o|0]&32)==0;if(q){aq=c[277228]|0}else{aq=e[(c[277226]|0)+(u<<1)>>1]|0}if(n){ar=b[(c[277213]|0)+(m+10<<1)>>1]&2081}else{ar=0}if(q){as=c[277228]|0}else{as=e[(c[277226]|0)+(u<<1)>>1]|0}if(n){at=e[(c[277213]|0)+(m+10<<1)>>1]|0}else{at=0}if(q){au=c[277228]|0}else{au=e[(c[277226]|0)+(u<<1)>>1]|0}u=m+9|0;b[(c[277218]|0)+(u<<1)>>1]=((au^at)&2081|e[(c[277220]|0)+((as&ar)+(((aq&-2082)+ap|0)>>>1)<<1)>>1])&65535;q=a[1108909]|0;a[(c[277219]|0)+u|0]=q;a[(c[277219]|0)+o|0]=q;ak=a[1108908]|0;al=c[277219]|0}else{ak=$;al=aa}}while(0);o=m+10|0;do{if((ak&255)>(d[al+o|0]|0)){q=a[r+5|0]|0;u=q&255;if(q<<24>>24==0){av=ak;aw=al;break}q=e[(c[277225]|0)+(u<<1)>>1]|0;n=(a[(c[277215]|0)+o|0]&32)==0;if(n){l=c[277228]|0;ax=l;ay=l&-2082}else{l=e[(c[277213]|0)+(o<<1)>>1]|0;ax=l;ay=l&63454}if(n){az=c[277228]|0}else{az=e[(c[277213]|0)+(o<<1)>>1]|0}b[(c[277218]|0)+(o<<1)>>1]=((az^q)&2081|e[(c[277220]|0)+((q&2081&ax)+((ay+(q&63454)|0)>>>1)<<1)>>1])&65535;q=(a[1108928]|0)==0;if(q){aA=b[(c[277213]|0)+(m+12<<1)>>1]&63454}else{aA=0}n=(a[(c[277215]|0)+o|0]&32)==0;if(n){aB=c[277228]|0}else{aB=e[(c[277226]|0)+(u<<1)>>1]|0}if(q){aC=b[(c[277213]|0)+(m+12<<1)>>1]&2081}else{aC=0}if(n){aD=c[277228]|0}else{aD=e[(c[277226]|0)+(u<<1)>>1]|0}if(q){aE=e[(c[277213]|0)+(m+12<<1)>>1]|0}else{aE=0}if(n){aF=c[277228]|0}else{aF=e[(c[277226]|0)+(u<<1)>>1]|0}u=m+11|0;b[(c[277218]|0)+(u<<1)>>1]=((aF^aE)&2081|e[(c[277220]|0)+((aD&aC)+(((aB&-2082)+aA|0)>>>1)<<1)>>1])&65535;n=a[1108909]|0;a[(c[277219]|0)+u|0]=n;a[(c[277219]|0)+o|0]=n;av=a[1108908]|0;aw=c[277219]|0}else{av=ak;aw=al}}while(0);o=m+12|0;do{if((av&255)>(d[aw+o|0]|0)){n=a[r+6|0]|0;u=n&255;if(n<<24>>24==0){aG=av;aH=aw;break}n=e[(c[277225]|0)+(u<<1)>>1]|0;q=(a[(c[277215]|0)+o|0]&32)==0;if(q){l=c[277228]|0;aI=l;aJ=l&-2082}else{l=e[(c[277213]|0)+(o<<1)>>1]|0;aI=l;aJ=l&63454}if(q){aK=c[277228]|0}else{aK=e[(c[277213]|0)+(o<<1)>>1]|0}b[(c[277218]|0)+(o<<1)>>1]=((aK^n)&2081|e[(c[277220]|0)+((n&2081&aI)+((aJ+(n&63454)|0)>>>1)<<1)>>1])&65535;n=(a[1108928]|0)==0;if(n){aL=b[(c[277213]|0)+(m+14<<1)>>1]&63454}else{aL=0}q=(a[(c[277215]|0)+o|0]&32)==0;if(q){aM=c[277228]|0}else{aM=e[(c[277226]|0)+(u<<1)>>1]|0}if(n){aN=b[(c[277213]|0)+(m+14<<1)>>1]&2081}else{aN=0}if(q){aO=c[277228]|0}else{aO=e[(c[277226]|0)+(u<<1)>>1]|0}if(n){aP=e[(c[277213]|0)+(m+14<<1)>>1]|0}else{aP=0}if(q){aQ=c[277228]|0}else{aQ=e[(c[277226]|0)+(u<<1)>>1]|0}u=m+13|0;b[(c[277218]|0)+(u<<1)>>1]=((aQ^aP)&2081|e[(c[277220]|0)+((aO&aN)+(((aM&-2082)+aL|0)>>>1)<<1)>>1])&65535;q=a[1108909]|0;a[(c[277219]|0)+u|0]=q;a[(c[277219]|0)+o|0]=q;aG=a[1108908]|0;aH=c[277219]|0}else{aG=av;aH=aw}}while(0);o=m+14|0;do{if((aG&255)>(d[aH+o|0]|0)){q=a[r+7|0]|0;u=q&255;if(q<<24>>24==0){break}q=e[(c[277225]|0)+(u<<1)>>1]|0;n=(a[(c[277215]|0)+o|0]&32)==0;if(n){l=c[277228]|0;aR=l;aS=l&-2082}else{l=e[(c[277213]|0)+(o<<1)>>1]|0;aR=l;aS=l&63454}if(n){aT=c[277228]|0}else{aT=e[(c[277213]|0)+(o<<1)>>1]|0}b[(c[277218]|0)+(o<<1)>>1]=((aT^q)&2081|e[(c[277220]|0)+((q&2081&aR)+((aS+(q&63454)|0)>>>1)<<1)>>1])&65535;q=(a[1108928]|0)==0;if(q){aU=b[(c[277213]|0)+(m+16<<1)>>1]&63454}else{aU=0}n=(a[(c[277215]|0)+o|0]&32)==0;if(n){aV=c[277228]|0}else{aV=e[(c[277226]|0)+(u<<1)>>1]|0}if(q){aW=b[(c[277213]|0)+(m+16<<1)>>1]&2081}else{aW=0}if(n){aX=c[277228]|0}else{aX=e[(c[277226]|0)+(u<<1)>>1]|0}if(q){aY=e[(c[277213]|0)+(m+16<<1)>>1]|0}else{aY=0}if(n){aZ=c[277228]|0}else{aZ=e[(c[277226]|0)+(u<<1)>>1]|0}u=m+15|0;b[(c[277218]|0)+(u<<1)>>1]=((aZ^aY)&2081|e[(c[277220]|0)+((aX&aW)+(((aV&-2082)+aU|0)>>>1)<<1)>>1])&65535;n=a[1108909]|0;a[(c[277219]|0)+u|0]=n;a[(c[277219]|0)+o|0]=n}}while(0);o=j-1|0;if((o|0)<=0){break}r=r+8|0;j=o;m=(c[277223]|0)+m|0}return}if((f&32768|0)==0){if((i|0)<=0){return}f=p+h|0;m=i;j=g;while(1){r=a[1108908]|0;aU=c[277219]|0;do{if((r&255)>(d[aU+j|0]|0)){aV=a[f+7|0]|0;aW=aV&255;if(aV<<24>>24==0){a_=r;a$=aU;break}aV=e[(c[277225]|0)+(aW<<1)>>1]|0;aX=(a[(c[277215]|0)+j|0]&32)==0;if(aX){aY=c[277228]|0;a0=aY;a1=aY&-2082}else{aY=e[(c[277213]|0)+(j<<1)>>1]|0;a0=aY;a1=aY&63454}if(aX){a2=c[277228]|0}else{a2=e[(c[277213]|0)+(j<<1)>>1]|0}b[(c[277218]|0)+(j<<1)>>1]=((a2^aV)&2081|e[(c[277220]|0)+((aV&2081&a0)+((a1+(aV&63454)|0)>>>1)<<1)>>1])&65535;aV=(a[1108928]|0)==0;if(aV){a3=b[(c[277213]|0)+(j+2<<1)>>1]&63454}else{a3=0}aX=(a[(c[277215]|0)+j|0]&32)==0;if(aX){a4=c[277228]|0}else{a4=e[(c[277226]|0)+(aW<<1)>>1]|0}if(aV){a5=b[(c[277213]|0)+(j+2<<1)>>1]&2081}else{a5=0}if(aX){a6=c[277228]|0}else{a6=e[(c[277226]|0)+(aW<<1)>>1]|0}if(aV){a7=e[(c[277213]|0)+(j+2<<1)>>1]|0}else{a7=0}if(aX){a8=c[277228]|0}else{a8=e[(c[277226]|0)+(aW<<1)>>1]|0}aW=j+1|0;b[(c[277218]|0)+(aW<<1)>>1]=((a8^a7)&2081|e[(c[277220]|0)+((a6&a5)+(((a4&-2082)+a3|0)>>>1)<<1)>>1])&65535;aX=a[1108909]|0;a[(c[277219]|0)+aW|0]=aX;a[(c[277219]|0)+j|0]=aX;a_=a[1108908]|0;a$=c[277219]|0}else{a_=r;a$=aU}}while(0);aU=j+2|0;do{if((a_&255)>(d[a$+aU|0]|0)){r=a[f+6|0]|0;aX=r&255;if(r<<24>>24==0){a9=a_;ba=a$;break}r=e[(c[277225]|0)+(aX<<1)>>1]|0;aW=(a[(c[277215]|0)+aU|0]&32)==0;if(aW){aV=c[277228]|0;bb=aV;bc=aV&-2082}else{aV=e[(c[277213]|0)+(aU<<1)>>1]|0;bb=aV;bc=aV&63454}if(aW){bd=c[277228]|0}else{bd=e[(c[277213]|0)+(aU<<1)>>1]|0}b[(c[277218]|0)+(aU<<1)>>1]=((bd^r)&2081|e[(c[277220]|0)+((r&2081&bb)+((bc+(r&63454)|0)>>>1)<<1)>>1])&65535;r=(a[1108928]|0)==0;if(r){be=b[(c[277213]|0)+(j+4<<1)>>1]&63454}else{be=0}aW=(a[(c[277215]|0)+aU|0]&32)==0;if(aW){bf=c[277228]|0}else{bf=e[(c[277226]|0)+(aX<<1)>>1]|0}if(r){bg=b[(c[277213]|0)+(j+4<<1)>>1]&2081}else{bg=0}if(aW){bh=c[277228]|0}else{bh=e[(c[277226]|0)+(aX<<1)>>1]|0}if(r){bi=e[(c[277213]|0)+(j+4<<1)>>1]|0}else{bi=0}if(aW){bj=c[277228]|0}else{bj=e[(c[277226]|0)+(aX<<1)>>1]|0}aX=j+3|0;b[(c[277218]|0)+(aX<<1)>>1]=((bj^bi)&2081|e[(c[277220]|0)+((bh&bg)+(((bf&-2082)+be|0)>>>1)<<1)>>1])&65535;aW=a[1108909]|0;a[(c[277219]|0)+aX|0]=aW;a[(c[277219]|0)+aU|0]=aW;a9=a[1108908]|0;ba=c[277219]|0}else{a9=a_;ba=a$}}while(0);aU=j+4|0;do{if((a9&255)>(d[ba+aU|0]|0)){aW=a[f+5|0]|0;aX=aW&255;if(aW<<24>>24==0){bk=a9;bl=ba;break}aW=e[(c[277225]|0)+(aX<<1)>>1]|0;r=(a[(c[277215]|0)+aU|0]&32)==0;if(r){aV=c[277228]|0;bm=aV;bn=aV&-2082}else{aV=e[(c[277213]|0)+(aU<<1)>>1]|0;bm=aV;bn=aV&63454}if(r){bo=c[277228]|0}else{bo=e[(c[277213]|0)+(aU<<1)>>1]|0}b[(c[277218]|0)+(aU<<1)>>1]=((bo^aW)&2081|e[(c[277220]|0)+((aW&2081&bm)+((bn+(aW&63454)|0)>>>1)<<1)>>1])&65535;aW=(a[1108928]|0)==0;if(aW){bp=b[(c[277213]|0)+(j+6<<1)>>1]&63454}else{bp=0}r=(a[(c[277215]|0)+aU|0]&32)==0;if(r){bq=c[277228]|0}else{bq=e[(c[277226]|0)+(aX<<1)>>1]|0}if(aW){br=b[(c[277213]|0)+(j+6<<1)>>1]&2081}else{br=0}if(r){bs=c[277228]|0}else{bs=e[(c[277226]|0)+(aX<<1)>>1]|0}if(aW){bt=e[(c[277213]|0)+(j+6<<1)>>1]|0}else{bt=0}if(r){bu=c[277228]|0}else{bu=e[(c[277226]|0)+(aX<<1)>>1]|0}aX=j+5|0;b[(c[277218]|0)+(aX<<1)>>1]=((bu^bt)&2081|e[(c[277220]|0)+((bs&br)+(((bq&-2082)+bp|0)>>>1)<<1)>>1])&65535;r=a[1108909]|0;a[(c[277219]|0)+aX|0]=r;a[(c[277219]|0)+aU|0]=r;bk=a[1108908]|0;bl=c[277219]|0}else{bk=a9;bl=ba}}while(0);aU=j+6|0;do{if((bk&255)>(d[bl+aU|0]|0)){r=a[f+4|0]|0;aX=r&255;if(r<<24>>24==0){bv=bk;bw=bl;break}r=e[(c[277225]|0)+(aX<<1)>>1]|0;aW=(a[(c[277215]|0)+aU|0]&32)==0;if(aW){aV=c[277228]|0;bx=aV;by=aV&-2082}else{aV=e[(c[277213]|0)+(aU<<1)>>1]|0;bx=aV;by=aV&63454}if(aW){bz=c[277228]|0}else{bz=e[(c[277213]|0)+(aU<<1)>>1]|0}b[(c[277218]|0)+(aU<<1)>>1]=((bz^r)&2081|e[(c[277220]|0)+((r&2081&bx)+((by+(r&63454)|0)>>>1)<<1)>>1])&65535;r=(a[1108928]|0)==0;if(r){bA=b[(c[277213]|0)+(j+8<<1)>>1]&63454}else{bA=0}aW=(a[(c[277215]|0)+aU|0]&32)==0;if(aW){bB=c[277228]|0}else{bB=e[(c[277226]|0)+(aX<<1)>>1]|0}if(r){bC=b[(c[277213]|0)+(j+8<<1)>>1]&2081}else{bC=0}if(aW){bD=c[277228]|0}else{bD=e[(c[277226]|0)+(aX<<1)>>1]|0}if(r){bE=e[(c[277213]|0)+(j+8<<1)>>1]|0}else{bE=0}if(aW){bF=c[277228]|0}else{bF=e[(c[277226]|0)+(aX<<1)>>1]|0}aX=j+7|0;b[(c[277218]|0)+(aX<<1)>>1]=((bF^bE)&2081|e[(c[277220]|0)+((bD&bC)+(((bB&-2082)+bA|0)>>>1)<<1)>>1])&65535;aW=a[1108909]|0;a[(c[277219]|0)+aX|0]=aW;a[(c[277219]|0)+aU|0]=aW;bv=a[1108908]|0;bw=c[277219]|0}else{bv=bk;bw=bl}}while(0);aU=j+8|0;do{if((bv&255)>(d[bw+aU|0]|0)){aW=a[f+3|0]|0;aX=aW&255;if(aW<<24>>24==0){bG=bv;bH=bw;break}aW=e[(c[277225]|0)+(aX<<1)>>1]|0;r=(a[(c[277215]|0)+aU|0]&32)==0;if(r){aV=c[277228]|0;bI=aV;bJ=aV&-2082}else{aV=e[(c[277213]|0)+(aU<<1)>>1]|0;bI=aV;bJ=aV&63454}if(r){bK=c[277228]|0}else{bK=e[(c[277213]|0)+(aU<<1)>>1]|0}b[(c[277218]|0)+(aU<<1)>>1]=((bK^aW)&2081|e[(c[277220]|0)+((aW&2081&bI)+((bJ+(aW&63454)|0)>>>1)<<1)>>1])&65535;aW=(a[1108928]|0)==0;if(aW){bL=b[(c[277213]|0)+(j+10<<1)>>1]&63454}else{bL=0}r=(a[(c[277215]|0)+aU|0]&32)==0;if(r){bM=c[277228]|0}else{bM=e[(c[277226]|0)+(aX<<1)>>1]|0}if(aW){bN=b[(c[277213]|0)+(j+10<<1)>>1]&2081}else{bN=0}if(r){bO=c[277228]|0}else{bO=e[(c[277226]|0)+(aX<<1)>>1]|0}if(aW){bP=e[(c[277213]|0)+(j+10<<1)>>1]|0}else{bP=0}if(r){bQ=c[277228]|0}else{bQ=e[(c[277226]|0)+(aX<<1)>>1]|0}aX=j+9|0;b[(c[277218]|0)+(aX<<1)>>1]=((bQ^bP)&2081|e[(c[277220]|0)+((bO&bN)+(((bM&-2082)+bL|0)>>>1)<<1)>>1])&65535;r=a[1108909]|0;a[(c[277219]|0)+aX|0]=r;a[(c[277219]|0)+aU|0]=r;bG=a[1108908]|0;bH=c[277219]|0}else{bG=bv;bH=bw}}while(0);aU=j+10|0;do{if((bG&255)>(d[bH+aU|0]|0)){r=a[f+2|0]|0;aX=r&255;if(r<<24>>24==0){bR=bG;bS=bH;break}r=e[(c[277225]|0)+(aX<<1)>>1]|0;aW=(a[(c[277215]|0)+aU|0]&32)==0;if(aW){aV=c[277228]|0;bT=aV;bU=aV&-2082}else{aV=e[(c[277213]|0)+(aU<<1)>>1]|0;bT=aV;bU=aV&63454}if(aW){bV=c[277228]|0}else{bV=e[(c[277213]|0)+(aU<<1)>>1]|0}b[(c[277218]|0)+(aU<<1)>>1]=((bV^r)&2081|e[(c[277220]|0)+((r&2081&bT)+((bU+(r&63454)|0)>>>1)<<1)>>1])&65535;r=(a[1108928]|0)==0;if(r){bW=b[(c[277213]|0)+(j+12<<1)>>1]&63454}else{bW=0}aW=(a[(c[277215]|0)+aU|0]&32)==0;if(aW){bX=c[277228]|0}else{bX=e[(c[277226]|0)+(aX<<1)>>1]|0}if(r){bY=b[(c[277213]|0)+(j+12<<1)>>1]&2081}else{bY=0}if(aW){bZ=c[277228]|0}else{bZ=e[(c[277226]|0)+(aX<<1)>>1]|0}if(r){b_=e[(c[277213]|0)+(j+12<<1)>>1]|0}else{b_=0}if(aW){b$=c[277228]|0}else{b$=e[(c[277226]|0)+(aX<<1)>>1]|0}aX=j+11|0;b[(c[277218]|0)+(aX<<1)>>1]=((b$^b_)&2081|e[(c[277220]|0)+((bZ&bY)+(((bX&-2082)+bW|0)>>>1)<<1)>>1])&65535;aW=a[1108909]|0;a[(c[277219]|0)+aX|0]=aW;a[(c[277219]|0)+aU|0]=aW;bR=a[1108908]|0;bS=c[277219]|0}else{bR=bG;bS=bH}}while(0);aU=j+12|0;do{if((bR&255)>(d[bS+aU|0]|0)){aW=a[f+1|0]|0;aX=aW&255;if(aW<<24>>24==0){b0=bR;b1=bS;break}aW=e[(c[277225]|0)+(aX<<1)>>1]|0;r=(a[(c[277215]|0)+aU|0]&32)==0;if(r){aV=c[277228]|0;b2=aV;b3=aV&-2082}else{aV=e[(c[277213]|0)+(aU<<1)>>1]|0;b2=aV;b3=aV&63454}if(r){b4=c[277228]|0}else{b4=e[(c[277213]|0)+(aU<<1)>>1]|0}b[(c[277218]|0)+(aU<<1)>>1]=((b4^aW)&2081|e[(c[277220]|0)+((aW&2081&b2)+((b3+(aW&63454)|0)>>>1)<<1)>>1])&65535;aW=(a[1108928]|0)==0;if(aW){b5=b[(c[277213]|0)+(j+14<<1)>>1]&63454}else{b5=0}r=(a[(c[277215]|0)+aU|0]&32)==0;if(r){b6=c[277228]|0}else{b6=e[(c[277226]|0)+(aX<<1)>>1]|0}if(aW){b7=b[(c[277213]|0)+(j+14<<1)>>1]&2081}else{b7=0}if(r){b8=c[277228]|0}else{b8=e[(c[277226]|0)+(aX<<1)>>1]|0}if(aW){b9=e[(c[277213]|0)+(j+14<<1)>>1]|0}else{b9=0}if(r){ca=c[277228]|0}else{ca=e[(c[277226]|0)+(aX<<1)>>1]|0}aX=j+13|0;b[(c[277218]|0)+(aX<<1)>>1]=((ca^b9)&2081|e[(c[277220]|0)+((b8&b7)+(((b6&-2082)+b5|0)>>>1)<<1)>>1])&65535;r=a[1108909]|0;a[(c[277219]|0)+aX|0]=r;a[(c[277219]|0)+aU|0]=r;b0=a[1108908]|0;b1=c[277219]|0}else{b0=bR;b1=bS}}while(0);aU=j+14|0;do{if((b0&255)>(d[b1+aU|0]|0)){r=a[f]|0;aX=r&255;if(r<<24>>24==0){break}r=e[(c[277225]|0)+(aX<<1)>>1]|0;aW=(a[(c[277215]|0)+aU|0]&32)==0;if(aW){aV=c[277228]|0;cb=aV;cc=aV&-2082}else{aV=e[(c[277213]|0)+(aU<<1)>>1]|0;cb=aV;cc=aV&63454}if(aW){cd=c[277228]|0}else{cd=e[(c[277213]|0)+(aU<<1)>>1]|0}b[(c[277218]|0)+(aU<<1)>>1]=((cd^r)&2081|e[(c[277220]|0)+((r&2081&cb)+((cc+(r&63454)|0)>>>1)<<1)>>1])&65535;r=(a[1108928]|0)==0;if(r){ce=b[(c[277213]|0)+(j+16<<1)>>1]&63454}else{ce=0}aW=(a[(c[277215]|0)+aU|0]&32)==0;if(aW){cf=c[277228]|0}else{cf=e[(c[277226]|0)+(aX<<1)>>1]|0}if(r){cg=b[(c[277213]|0)+(j+16<<1)>>1]&2081}else{cg=0}if(aW){ch=c[277228]|0}else{ch=e[(c[277226]|0)+(aX<<1)>>1]|0}if(r){ci=e[(c[277213]|0)+(j+16<<1)>>1]|0}else{ci=0}if(aW){cj=c[277228]|0}else{cj=e[(c[277226]|0)+(aX<<1)>>1]|0}aX=j+15|0;b[(c[277218]|0)+(aX<<1)>>1]=((cj^ci)&2081|e[(c[277220]|0)+((ch&cg)+(((cf&-2082)+ce|0)>>>1)<<1)>>1])&65535;aW=a[1108909]|0;a[(c[277219]|0)+aX|0]=aW;a[(c[277219]|0)+aU|0]=aW}}while(0);aU=m-1|0;if((aU|0)<=0){break}f=f+8|0;m=aU;j=(c[277223]|0)+j|0}return}j=p+(56-h)|0;h=(i|0)>0;if(k){if(h){ck=j;cl=i;cm=g}else{return}while(1){k=a[1108908]|0;p=c[277219]|0;do{if((k&255)>(d[p+cm|0]|0)){m=a[ck+7|0]|0;f=m&255;if(m<<24>>24==0){cn=k;co=p;break}m=e[(c[277225]|0)+(f<<1)>>1]|0;ce=(a[(c[277215]|0)+cm|0]&32)==0;if(ce){cf=c[277228]|0;cp=cf;cq=cf&-2082}else{cf=e[(c[277213]|0)+(cm<<1)>>1]|0;cp=cf;cq=cf&63454}if(ce){cr=c[277228]|0}else{cr=e[(c[277213]|0)+(cm<<1)>>1]|0}b[(c[277218]|0)+(cm<<1)>>1]=((cr^m)&2081|e[(c[277220]|0)+((m&2081&cp)+((cq+(m&63454)|0)>>>1)<<1)>>1])&65535;m=(a[1108928]|0)==0;if(m){cs=b[(c[277213]|0)+(cm+2<<1)>>1]&63454}else{cs=0}ce=(a[(c[277215]|0)+cm|0]&32)==0;if(ce){ct=c[277228]|0}else{ct=e[(c[277226]|0)+(f<<1)>>1]|0}if(m){cu=b[(c[277213]|0)+(cm+2<<1)>>1]&2081}else{cu=0}if(ce){cv=c[277228]|0}else{cv=e[(c[277226]|0)+(f<<1)>>1]|0}if(m){cw=e[(c[277213]|0)+(cm+2<<1)>>1]|0}else{cw=0}if(ce){cx=c[277228]|0}else{cx=e[(c[277226]|0)+(f<<1)>>1]|0}f=cm+1|0;b[(c[277218]|0)+(f<<1)>>1]=((cx^cw)&2081|e[(c[277220]|0)+((cv&cu)+(((ct&-2082)+cs|0)>>>1)<<1)>>1])&65535;ce=a[1108909]|0;a[(c[277219]|0)+f|0]=ce;a[(c[277219]|0)+cm|0]=ce;cn=a[1108908]|0;co=c[277219]|0}else{cn=k;co=p}}while(0);p=cm+2|0;do{if((cn&255)>(d[co+p|0]|0)){k=a[ck+6|0]|0;ce=k&255;if(k<<24>>24==0){cy=cn;cz=co;break}k=e[(c[277225]|0)+(ce<<1)>>1]|0;f=(a[(c[277215]|0)+p|0]&32)==0;if(f){m=c[277228]|0;cA=m;cB=m&-2082}else{m=e[(c[277213]|0)+(p<<1)>>1]|0;cA=m;cB=m&63454}if(f){cC=c[277228]|0}else{cC=e[(c[277213]|0)+(p<<1)>>1]|0}b[(c[277218]|0)+(p<<1)>>1]=((cC^k)&2081|e[(c[277220]|0)+((k&2081&cA)+((cB+(k&63454)|0)>>>1)<<1)>>1])&65535;k=(a[1108928]|0)==0;if(k){cD=b[(c[277213]|0)+(cm+4<<1)>>1]&63454}else{cD=0}f=(a[(c[277215]|0)+p|0]&32)==0;if(f){cE=c[277228]|0}else{cE=e[(c[277226]|0)+(ce<<1)>>1]|0}if(k){cF=b[(c[277213]|0)+(cm+4<<1)>>1]&2081}else{cF=0}if(f){cG=c[277228]|0}else{cG=e[(c[277226]|0)+(ce<<1)>>1]|0}if(k){cH=e[(c[277213]|0)+(cm+4<<1)>>1]|0}else{cH=0}if(f){cI=c[277228]|0}else{cI=e[(c[277226]|0)+(ce<<1)>>1]|0}ce=cm+3|0;b[(c[277218]|0)+(ce<<1)>>1]=((cI^cH)&2081|e[(c[277220]|0)+((cG&cF)+(((cE&-2082)+cD|0)>>>1)<<1)>>1])&65535;f=a[1108909]|0;a[(c[277219]|0)+ce|0]=f;a[(c[277219]|0)+p|0]=f;cy=a[1108908]|0;cz=c[277219]|0}else{cy=cn;cz=co}}while(0);p=cm+4|0;do{if((cy&255)>(d[cz+p|0]|0)){f=a[ck+5|0]|0;ce=f&255;if(f<<24>>24==0){cJ=cy;cK=cz;break}f=e[(c[277225]|0)+(ce<<1)>>1]|0;k=(a[(c[277215]|0)+p|0]&32)==0;if(k){m=c[277228]|0;cL=m;cM=m&-2082}else{m=e[(c[277213]|0)+(p<<1)>>1]|0;cL=m;cM=m&63454}if(k){cN=c[277228]|0}else{cN=e[(c[277213]|0)+(p<<1)>>1]|0}b[(c[277218]|0)+(p<<1)>>1]=((cN^f)&2081|e[(c[277220]|0)+((f&2081&cL)+((cM+(f&63454)|0)>>>1)<<1)>>1])&65535;f=(a[1108928]|0)==0;if(f){cO=b[(c[277213]|0)+(cm+6<<1)>>1]&63454}else{cO=0}k=(a[(c[277215]|0)+p|0]&32)==0;if(k){cP=c[277228]|0}else{cP=e[(c[277226]|0)+(ce<<1)>>1]|0}if(f){cQ=b[(c[277213]|0)+(cm+6<<1)>>1]&2081}else{cQ=0}if(k){cR=c[277228]|0}else{cR=e[(c[277226]|0)+(ce<<1)>>1]|0}if(f){cS=e[(c[277213]|0)+(cm+6<<1)>>1]|0}else{cS=0}if(k){cT=c[277228]|0}else{cT=e[(c[277226]|0)+(ce<<1)>>1]|0}ce=cm+5|0;b[(c[277218]|0)+(ce<<1)>>1]=((cT^cS)&2081|e[(c[277220]|0)+((cR&cQ)+(((cP&-2082)+cO|0)>>>1)<<1)>>1])&65535;k=a[1108909]|0;a[(c[277219]|0)+ce|0]=k;a[(c[277219]|0)+p|0]=k;cJ=a[1108908]|0;cK=c[277219]|0}else{cJ=cy;cK=cz}}while(0);p=cm+6|0;do{if((cJ&255)>(d[cK+p|0]|0)){k=a[ck+4|0]|0;ce=k&255;if(k<<24>>24==0){cU=cJ;cV=cK;break}k=e[(c[277225]|0)+(ce<<1)>>1]|0;f=(a[(c[277215]|0)+p|0]&32)==0;if(f){m=c[277228]|0;cW=m;cX=m&-2082}else{m=e[(c[277213]|0)+(p<<1)>>1]|0;cW=m;cX=m&63454}if(f){cY=c[277228]|0}else{cY=e[(c[277213]|0)+(p<<1)>>1]|0}b[(c[277218]|0)+(p<<1)>>1]=((cY^k)&2081|e[(c[277220]|0)+((k&2081&cW)+((cX+(k&63454)|0)>>>1)<<1)>>1])&65535;k=(a[1108928]|0)==0;if(k){cZ=b[(c[277213]|0)+(cm+8<<1)>>1]&63454}else{cZ=0}f=(a[(c[277215]|0)+p|0]&32)==0;if(f){c_=c[277228]|0}else{c_=e[(c[277226]|0)+(ce<<1)>>1]|0}if(k){c$=b[(c[277213]|0)+(cm+8<<1)>>1]&2081}else{c$=0}if(f){c0=c[277228]|0}else{c0=e[(c[277226]|0)+(ce<<1)>>1]|0}if(k){c1=e[(c[277213]|0)+(cm+8<<1)>>1]|0}else{c1=0}if(f){c2=c[277228]|0}else{c2=e[(c[277226]|0)+(ce<<1)>>1]|0}ce=cm+7|0;b[(c[277218]|0)+(ce<<1)>>1]=((c2^c1)&2081|e[(c[277220]|0)+((c0&c$)+(((c_&-2082)+cZ|0)>>>1)<<1)>>1])&65535;f=a[1108909]|0;a[(c[277219]|0)+ce|0]=f;a[(c[277219]|0)+p|0]=f;cU=a[1108908]|0;cV=c[277219]|0}else{cU=cJ;cV=cK}}while(0);p=cm+8|0;do{if((cU&255)>(d[cV+p|0]|0)){f=a[ck+3|0]|0;ce=f&255;if(f<<24>>24==0){c3=cU;c4=cV;break}f=e[(c[277225]|0)+(ce<<1)>>1]|0;k=(a[(c[277215]|0)+p|0]&32)==0;if(k){m=c[277228]|0;c5=m;c6=m&-2082}else{m=e[(c[277213]|0)+(p<<1)>>1]|0;c5=m;c6=m&63454}if(k){c7=c[277228]|0}else{c7=e[(c[277213]|0)+(p<<1)>>1]|0}b[(c[277218]|0)+(p<<1)>>1]=((c7^f)&2081|e[(c[277220]|0)+((f&2081&c5)+((c6+(f&63454)|0)>>>1)<<1)>>1])&65535;f=(a[1108928]|0)==0;if(f){c8=b[(c[277213]|0)+(cm+10<<1)>>1]&63454}else{c8=0}k=(a[(c[277215]|0)+p|0]&32)==0;if(k){c9=c[277228]|0}else{c9=e[(c[277226]|0)+(ce<<1)>>1]|0}if(f){da=b[(c[277213]|0)+(cm+10<<1)>>1]&2081}else{da=0}if(k){db=c[277228]|0}else{db=e[(c[277226]|0)+(ce<<1)>>1]|0}if(f){dc=e[(c[277213]|0)+(cm+10<<1)>>1]|0}else{dc=0}if(k){dd=c[277228]|0}else{dd=e[(c[277226]|0)+(ce<<1)>>1]|0}ce=cm+9|0;b[(c[277218]|0)+(ce<<1)>>1]=((dd^dc)&2081|e[(c[277220]|0)+((db&da)+(((c9&-2082)+c8|0)>>>1)<<1)>>1])&65535;k=a[1108909]|0;a[(c[277219]|0)+ce|0]=k;a[(c[277219]|0)+p|0]=k;c3=a[1108908]|0;c4=c[277219]|0}else{c3=cU;c4=cV}}while(0);p=cm+10|0;do{if((c3&255)>(d[c4+p|0]|0)){k=a[ck+2|0]|0;ce=k&255;if(k<<24>>24==0){de=c3;df=c4;break}k=e[(c[277225]|0)+(ce<<1)>>1]|0;f=(a[(c[277215]|0)+p|0]&32)==0;if(f){m=c[277228]|0;dg=m;dh=m&-2082}else{m=e[(c[277213]|0)+(p<<1)>>1]|0;dg=m;dh=m&63454}if(f){di=c[277228]|0}else{di=e[(c[277213]|0)+(p<<1)>>1]|0}b[(c[277218]|0)+(p<<1)>>1]=((di^k)&2081|e[(c[277220]|0)+((k&2081&dg)+((dh+(k&63454)|0)>>>1)<<1)>>1])&65535;k=(a[1108928]|0)==0;if(k){dj=b[(c[277213]|0)+(cm+12<<1)>>1]&63454}else{dj=0}f=(a[(c[277215]|0)+p|0]&32)==0;if(f){dk=c[277228]|0}else{dk=e[(c[277226]|0)+(ce<<1)>>1]|0}if(k){dl=b[(c[277213]|0)+(cm+12<<1)>>1]&2081}else{dl=0}if(f){dm=c[277228]|0}else{dm=e[(c[277226]|0)+(ce<<1)>>1]|0}if(k){dn=e[(c[277213]|0)+(cm+12<<1)>>1]|0}else{dn=0}if(f){dp=c[277228]|0}else{dp=e[(c[277226]|0)+(ce<<1)>>1]|0}ce=cm+11|0;b[(c[277218]|0)+(ce<<1)>>1]=((dp^dn)&2081|e[(c[277220]|0)+((dm&dl)+(((dk&-2082)+dj|0)>>>1)<<1)>>1])&65535;f=a[1108909]|0;a[(c[277219]|0)+ce|0]=f;a[(c[277219]|0)+p|0]=f;de=a[1108908]|0;df=c[277219]|0}else{de=c3;df=c4}}while(0);p=cm+12|0;do{if((de&255)>(d[df+p|0]|0)){f=a[ck+1|0]|0;ce=f&255;if(f<<24>>24==0){dq=de;dr=df;break}f=e[(c[277225]|0)+(ce<<1)>>1]|0;k=(a[(c[277215]|0)+p|0]&32)==0;if(k){m=c[277228]|0;ds=m;dt=m&-2082}else{m=e[(c[277213]|0)+(p<<1)>>1]|0;ds=m;dt=m&63454}if(k){du=c[277228]|0}else{du=e[(c[277213]|0)+(p<<1)>>1]|0}b[(c[277218]|0)+(p<<1)>>1]=((du^f)&2081|e[(c[277220]|0)+((f&2081&ds)+((dt+(f&63454)|0)>>>1)<<1)>>1])&65535;f=(a[1108928]|0)==0;if(f){dv=b[(c[277213]|0)+(cm+14<<1)>>1]&63454}else{dv=0}k=(a[(c[277215]|0)+p|0]&32)==0;if(k){dw=c[277228]|0}else{dw=e[(c[277226]|0)+(ce<<1)>>1]|0}if(f){dx=b[(c[277213]|0)+(cm+14<<1)>>1]&2081}else{dx=0}if(k){dy=c[277228]|0}else{dy=e[(c[277226]|0)+(ce<<1)>>1]|0}if(f){dz=e[(c[277213]|0)+(cm+14<<1)>>1]|0}else{dz=0}if(k){dA=c[277228]|0}else{dA=e[(c[277226]|0)+(ce<<1)>>1]|0}ce=cm+13|0;b[(c[277218]|0)+(ce<<1)>>1]=((dA^dz)&2081|e[(c[277220]|0)+((dy&dx)+(((dw&-2082)+dv|0)>>>1)<<1)>>1])&65535;k=a[1108909]|0;a[(c[277219]|0)+ce|0]=k;a[(c[277219]|0)+p|0]=k;dq=a[1108908]|0;dr=c[277219]|0}else{dq=de;dr=df}}while(0);p=cm+14|0;do{if((dq&255)>(d[dr+p|0]|0)){k=a[ck]|0;ce=k&255;if(k<<24>>24==0){break}k=e[(c[277225]|0)+(ce<<1)>>1]|0;f=(a[(c[277215]|0)+p|0]&32)==0;if(f){m=c[277228]|0;dB=m;dC=m&-2082}else{m=e[(c[277213]|0)+(p<<1)>>1]|0;dB=m;dC=m&63454}if(f){dD=c[277228]|0}else{dD=e[(c[277213]|0)+(p<<1)>>1]|0}b[(c[277218]|0)+(p<<1)>>1]=((dD^k)&2081|e[(c[277220]|0)+((k&2081&dB)+((dC+(k&63454)|0)>>>1)<<1)>>1])&65535;k=(a[1108928]|0)==0;if(k){dE=b[(c[277213]|0)+(cm+16<<1)>>1]&63454}else{dE=0}f=(a[(c[277215]|0)+p|0]&32)==0;if(f){dF=c[277228]|0}else{dF=e[(c[277226]|0)+(ce<<1)>>1]|0}if(k){dG=b[(c[277213]|0)+(cm+16<<1)>>1]&2081}else{dG=0}if(f){dH=c[277228]|0}else{dH=e[(c[277226]|0)+(ce<<1)>>1]|0}if(k){dI=e[(c[277213]|0)+(cm+16<<1)>>1]|0}else{dI=0}if(f){dJ=c[277228]|0}else{dJ=e[(c[277226]|0)+(ce<<1)>>1]|0}ce=cm+15|0;b[(c[277218]|0)+(ce<<1)>>1]=((dJ^dI)&2081|e[(c[277220]|0)+((dH&dG)+(((dF&-2082)+dE|0)>>>1)<<1)>>1])&65535;f=a[1108909]|0;a[(c[277219]|0)+ce|0]=f;a[(c[277219]|0)+p|0]=f}}while(0);p=cl-1|0;if((p|0)<=0){break}ck=ck-8|0;cl=p;cm=(c[277223]|0)+cm|0}return}else{if(h){dK=j;dL=i;dM=g}else{return}while(1){g=a[1108908]|0;i=c[277219]|0;do{if((g&255)>(d[i+dM|0]|0)){j=a[dK]|0;h=j&255;if(j<<24>>24==0){dN=g;dO=i;break}j=e[(c[277225]|0)+(h<<1)>>1]|0;cm=(a[(c[277215]|0)+dM|0]&32)==0;if(cm){cl=c[277228]|0;dP=cl;dQ=cl&-2082}else{cl=e[(c[277213]|0)+(dM<<1)>>1]|0;dP=cl;dQ=cl&63454}if(cm){dR=c[277228]|0}else{dR=e[(c[277213]|0)+(dM<<1)>>1]|0}b[(c[277218]|0)+(dM<<1)>>1]=((dR^j)&2081|e[(c[277220]|0)+((j&2081&dP)+((dQ+(j&63454)|0)>>>1)<<1)>>1])&65535;j=(a[1108928]|0)==0;if(j){dS=b[(c[277213]|0)+(dM+2<<1)>>1]&63454}else{dS=0}cm=(a[(c[277215]|0)+dM|0]&32)==0;if(cm){dT=c[277228]|0}else{dT=e[(c[277226]|0)+(h<<1)>>1]|0}if(j){dU=b[(c[277213]|0)+(dM+2<<1)>>1]&2081}else{dU=0}if(cm){dV=c[277228]|0}else{dV=e[(c[277226]|0)+(h<<1)>>1]|0}if(j){dW=e[(c[277213]|0)+(dM+2<<1)>>1]|0}else{dW=0}if(cm){dX=c[277228]|0}else{dX=e[(c[277226]|0)+(h<<1)>>1]|0}h=dM+1|0;b[(c[277218]|0)+(h<<1)>>1]=((dX^dW)&2081|e[(c[277220]|0)+((dV&dU)+(((dT&-2082)+dS|0)>>>1)<<1)>>1])&65535;cm=a[1108909]|0;a[(c[277219]|0)+h|0]=cm;a[(c[277219]|0)+dM|0]=cm;dN=a[1108908]|0;dO=c[277219]|0}else{dN=g;dO=i}}while(0);i=dM+2|0;do{if((dN&255)>(d[dO+i|0]|0)){g=a[dK+1|0]|0;cm=g&255;if(g<<24>>24==0){dY=dN;dZ=dO;break}g=e[(c[277225]|0)+(cm<<1)>>1]|0;h=(a[(c[277215]|0)+i|0]&32)==0;if(h){j=c[277228]|0;d_=j;d$=j&-2082}else{j=e[(c[277213]|0)+(i<<1)>>1]|0;d_=j;d$=j&63454}if(h){d0=c[277228]|0}else{d0=e[(c[277213]|0)+(i<<1)>>1]|0}b[(c[277218]|0)+(i<<1)>>1]=((d0^g)&2081|e[(c[277220]|0)+((g&2081&d_)+((d$+(g&63454)|0)>>>1)<<1)>>1])&65535;g=(a[1108928]|0)==0;if(g){d1=b[(c[277213]|0)+(dM+4<<1)>>1]&63454}else{d1=0}h=(a[(c[277215]|0)+i|0]&32)==0;if(h){d2=c[277228]|0}else{d2=e[(c[277226]|0)+(cm<<1)>>1]|0}if(g){d3=b[(c[277213]|0)+(dM+4<<1)>>1]&2081}else{d3=0}if(h){d4=c[277228]|0}else{d4=e[(c[277226]|0)+(cm<<1)>>1]|0}if(g){d5=e[(c[277213]|0)+(dM+4<<1)>>1]|0}else{d5=0}if(h){d6=c[277228]|0}else{d6=e[(c[277226]|0)+(cm<<1)>>1]|0}cm=dM+3|0;b[(c[277218]|0)+(cm<<1)>>1]=((d6^d5)&2081|e[(c[277220]|0)+((d4&d3)+(((d2&-2082)+d1|0)>>>1)<<1)>>1])&65535;h=a[1108909]|0;a[(c[277219]|0)+cm|0]=h;a[(c[277219]|0)+i|0]=h;dY=a[1108908]|0;dZ=c[277219]|0}else{dY=dN;dZ=dO}}while(0);i=dM+4|0;do{if((dY&255)>(d[dZ+i|0]|0)){h=a[dK+2|0]|0;cm=h&255;if(h<<24>>24==0){d7=dY;d8=dZ;break}h=e[(c[277225]|0)+(cm<<1)>>1]|0;g=(a[(c[277215]|0)+i|0]&32)==0;if(g){j=c[277228]|0;d9=j;ea=j&-2082}else{j=e[(c[277213]|0)+(i<<1)>>1]|0;d9=j;ea=j&63454}if(g){eb=c[277228]|0}else{eb=e[(c[277213]|0)+(i<<1)>>1]|0}b[(c[277218]|0)+(i<<1)>>1]=((eb^h)&2081|e[(c[277220]|0)+((h&2081&d9)+((ea+(h&63454)|0)>>>1)<<1)>>1])&65535;h=(a[1108928]|0)==0;if(h){ec=b[(c[277213]|0)+(dM+6<<1)>>1]&63454}else{ec=0}g=(a[(c[277215]|0)+i|0]&32)==0;if(g){ed=c[277228]|0}else{ed=e[(c[277226]|0)+(cm<<1)>>1]|0}if(h){ee=b[(c[277213]|0)+(dM+6<<1)>>1]&2081}else{ee=0}if(g){ef=c[277228]|0}else{ef=e[(c[277226]|0)+(cm<<1)>>1]|0}if(h){eg=e[(c[277213]|0)+(dM+6<<1)>>1]|0}else{eg=0}if(g){eh=c[277228]|0}else{eh=e[(c[277226]|0)+(cm<<1)>>1]|0}cm=dM+5|0;b[(c[277218]|0)+(cm<<1)>>1]=((eh^eg)&2081|e[(c[277220]|0)+((ef&ee)+(((ed&-2082)+ec|0)>>>1)<<1)>>1])&65535;g=a[1108909]|0;a[(c[277219]|0)+cm|0]=g;a[(c[277219]|0)+i|0]=g;d7=a[1108908]|0;d8=c[277219]|0}else{d7=dY;d8=dZ}}while(0);i=dM+6|0;do{if((d7&255)>(d[d8+i|0]|0)){g=a[dK+3|0]|0;cm=g&255;if(g<<24>>24==0){ei=d7;ej=d8;break}g=e[(c[277225]|0)+(cm<<1)>>1]|0;h=(a[(c[277215]|0)+i|0]&32)==0;if(h){j=c[277228]|0;ek=j;el=j&-2082}else{j=e[(c[277213]|0)+(i<<1)>>1]|0;ek=j;el=j&63454}if(h){em=c[277228]|0}else{em=e[(c[277213]|0)+(i<<1)>>1]|0}b[(c[277218]|0)+(i<<1)>>1]=((em^g)&2081|e[(c[277220]|0)+((g&2081&ek)+((el+(g&63454)|0)>>>1)<<1)>>1])&65535;g=(a[1108928]|0)==0;if(g){en=b[(c[277213]|0)+(dM+8<<1)>>1]&63454}else{en=0}h=(a[(c[277215]|0)+i|0]&32)==0;if(h){eo=c[277228]|0}else{eo=e[(c[277226]|0)+(cm<<1)>>1]|0}if(g){ep=b[(c[277213]|0)+(dM+8<<1)>>1]&2081}else{ep=0}if(h){eq=c[277228]|0}else{eq=e[(c[277226]|0)+(cm<<1)>>1]|0}if(g){er=e[(c[277213]|0)+(dM+8<<1)>>1]|0}else{er=0}if(h){es=c[277228]|0}else{es=e[(c[277226]|0)+(cm<<1)>>1]|0}cm=dM+7|0;b[(c[277218]|0)+(cm<<1)>>1]=((es^er)&2081|e[(c[277220]|0)+((eq&ep)+(((eo&-2082)+en|0)>>>1)<<1)>>1])&65535;h=a[1108909]|0;a[(c[277219]|0)+cm|0]=h;a[(c[277219]|0)+i|0]=h;ei=a[1108908]|0;ej=c[277219]|0}else{ei=d7;ej=d8}}while(0);i=dM+8|0;do{if((ei&255)>(d[ej+i|0]|0)){h=a[dK+4|0]|0;cm=h&255;if(h<<24>>24==0){et=ei;eu=ej;break}h=e[(c[277225]|0)+(cm<<1)>>1]|0;g=(a[(c[277215]|0)+i|0]&32)==0;if(g){j=c[277228]|0;ev=j;ew=j&-2082}else{j=e[(c[277213]|0)+(i<<1)>>1]|0;ev=j;ew=j&63454}if(g){ex=c[277228]|0}else{ex=e[(c[277213]|0)+(i<<1)>>1]|0}b[(c[277218]|0)+(i<<1)>>1]=((ex^h)&2081|e[(c[277220]|0)+((h&2081&ev)+((ew+(h&63454)|0)>>>1)<<1)>>1])&65535;h=(a[1108928]|0)==0;if(h){ey=b[(c[277213]|0)+(dM+10<<1)>>1]&63454}else{ey=0}g=(a[(c[277215]|0)+i|0]&32)==0;if(g){ez=c[277228]|0}else{ez=e[(c[277226]|0)+(cm<<1)>>1]|0}if(h){eA=b[(c[277213]|0)+(dM+10<<1)>>1]&2081}else{eA=0}if(g){eB=c[277228]|0}else{eB=e[(c[277226]|0)+(cm<<1)>>1]|0}if(h){eC=e[(c[277213]|0)+(dM+10<<1)>>1]|0}else{eC=0}if(g){eD=c[277228]|0}else{eD=e[(c[277226]|0)+(cm<<1)>>1]|0}cm=dM+9|0;b[(c[277218]|0)+(cm<<1)>>1]=((eD^eC)&2081|e[(c[277220]|0)+((eB&eA)+(((ez&-2082)+ey|0)>>>1)<<1)>>1])&65535;g=a[1108909]|0;a[(c[277219]|0)+cm|0]=g;a[(c[277219]|0)+i|0]=g;et=a[1108908]|0;eu=c[277219]|0}else{et=ei;eu=ej}}while(0);i=dM+10|0;do{if((et&255)>(d[eu+i|0]|0)){g=a[dK+5|0]|0;cm=g&255;if(g<<24>>24==0){eE=et;eF=eu;break}g=e[(c[277225]|0)+(cm<<1)>>1]|0;h=(a[(c[277215]|0)+i|0]&32)==0;if(h){j=c[277228]|0;eG=j;eH=j&-2082}else{j=e[(c[277213]|0)+(i<<1)>>1]|0;eG=j;eH=j&63454}if(h){eI=c[277228]|0}else{eI=e[(c[277213]|0)+(i<<1)>>1]|0}b[(c[277218]|0)+(i<<1)>>1]=((eI^g)&2081|e[(c[277220]|0)+((g&2081&eG)+((eH+(g&63454)|0)>>>1)<<1)>>1])&65535;g=(a[1108928]|0)==0;if(g){eJ=b[(c[277213]|0)+(dM+12<<1)>>1]&63454}else{eJ=0}h=(a[(c[277215]|0)+i|0]&32)==0;if(h){eK=c[277228]|0}else{eK=e[(c[277226]|0)+(cm<<1)>>1]|0}if(g){eL=b[(c[277213]|0)+(dM+12<<1)>>1]&2081}else{eL=0}if(h){eM=c[277228]|0}else{eM=e[(c[277226]|0)+(cm<<1)>>1]|0}if(g){eN=e[(c[277213]|0)+(dM+12<<1)>>1]|0}else{eN=0}if(h){eO=c[277228]|0}else{eO=e[(c[277226]|0)+(cm<<1)>>1]|0}cm=dM+11|0;b[(c[277218]|0)+(cm<<1)>>1]=((eO^eN)&2081|e[(c[277220]|0)+((eM&eL)+(((eK&-2082)+eJ|0)>>>1)<<1)>>1])&65535;h=a[1108909]|0;a[(c[277219]|0)+cm|0]=h;a[(c[277219]|0)+i|0]=h;eE=a[1108908]|0;eF=c[277219]|0}else{eE=et;eF=eu}}while(0);i=dM+12|0;do{if((eE&255)>(d[eF+i|0]|0)){h=a[dK+6|0]|0;cm=h&255;if(h<<24>>24==0){eP=eE;eQ=eF;break}h=e[(c[277225]|0)+(cm<<1)>>1]|0;g=(a[(c[277215]|0)+i|0]&32)==0;if(g){j=c[277228]|0;eR=j;eS=j&-2082}else{j=e[(c[277213]|0)+(i<<1)>>1]|0;eR=j;eS=j&63454}if(g){eT=c[277228]|0}else{eT=e[(c[277213]|0)+(i<<1)>>1]|0}b[(c[277218]|0)+(i<<1)>>1]=((eT^h)&2081|e[(c[277220]|0)+((h&2081&eR)+((eS+(h&63454)|0)>>>1)<<1)>>1])&65535;h=(a[1108928]|0)==0;if(h){eU=b[(c[277213]|0)+(dM+14<<1)>>1]&63454}else{eU=0}g=(a[(c[277215]|0)+i|0]&32)==0;if(g){eV=c[277228]|0}else{eV=e[(c[277226]|0)+(cm<<1)>>1]|0}if(h){eW=b[(c[277213]|0)+(dM+14<<1)>>1]&2081}else{eW=0}if(g){eX=c[277228]|0}else{eX=e[(c[277226]|0)+(cm<<1)>>1]|0}if(h){eY=e[(c[277213]|0)+(dM+14<<1)>>1]|0}else{eY=0}if(g){eZ=c[277228]|0}else{eZ=e[(c[277226]|0)+(cm<<1)>>1]|0}cm=dM+13|0;b[(c[277218]|0)+(cm<<1)>>1]=((eZ^eY)&2081|e[(c[277220]|0)+((eX&eW)+(((eV&-2082)+eU|0)>>>1)<<1)>>1])&65535;g=a[1108909]|0;a[(c[277219]|0)+cm|0]=g;a[(c[277219]|0)+i|0]=g;eP=a[1108908]|0;eQ=c[277219]|0}else{eP=eE;eQ=eF}}while(0);i=dM+14|0;do{if((eP&255)>(d[eQ+i|0]|0)){g=a[dK+7|0]|0;cm=g&255;if(g<<24>>24==0){break}g=e[(c[277225]|0)+(cm<<1)>>1]|0;h=(a[(c[277215]|0)+i|0]&32)==0;if(h){j=c[277228]|0;e_=j;e$=j&-2082}else{j=e[(c[277213]|0)+(i<<1)>>1]|0;e_=j;e$=j&63454}if(h){e0=c[277228]|0}else{e0=e[(c[277213]|0)+(i<<1)>>1]|0}b[(c[277218]|0)+(i<<1)>>1]=((e0^g)&2081|e[(c[277220]|0)+((g&2081&e_)+((e$+(g&63454)|0)>>>1)<<1)>>1])&65535;g=(a[1108928]|0)==0;if(g){e1=b[(c[277213]|0)+(dM+16<<1)>>1]&63454}else{e1=0}h=(a[(c[277215]|0)+i|0]&32)==0;if(h){e2=c[277228]|0}else{e2=e[(c[277226]|0)+(cm<<1)>>1]|0}if(g){e3=b[(c[277213]|0)+(dM+16<<1)>>1]&2081}else{e3=0}if(h){e4=c[277228]|0}else{e4=e[(c[277226]|0)+(cm<<1)>>1]|0}if(g){e5=e[(c[277213]|0)+(dM+16<<1)>>1]|0}else{e5=0}if(h){e6=c[277228]|0}else{e6=e[(c[277226]|0)+(cm<<1)>>1]|0}cm=dM+15|0;b[(c[277218]|0)+(cm<<1)>>1]=((e6^e5)&2081|e[(c[277220]|0)+((e4&e3)+(((e2&-2082)+e1|0)>>>1)<<1)>>1])&65535;h=a[1108909]|0;a[(c[277219]|0)+cm|0]=h;a[(c[277219]|0)+i|0]=h}}while(0);i=dL-1|0;if((i|0)<=0){break}dK=dK-8|0;dL=i;dM=(c[277223]|0)+dM|0}return}}function VJ(f,g,h,i){f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0;j=f&1023;k=c[348606]|0;l=(j<<k)+(c[348604]|0)|0;if((f&256|0)==0){m=l}else{m=(c[348602]|0)+l|0}l=m&65535;m=l>>>(k>>>0);k=(f&16384|0)!=0;n=m<<6;do{if(k){o=(c[348622]|0)+n|0;if((a[(c[348618]|0)+m|0]|0)!=0){p=o;break}q=fi[c[348636]&63](o,l,j)|0;a[(c[348618]|0)+m|0]=q;p=o}else{o=(c[348624]|0)+n|0;if((a[(c[348620]|0)+m|0]|0)!=0){p=o;break}q=fi[c[348638]&63](o,l,j)|0;a[(c[348620]|0)+m|0]=q;p=o}}while(0);if((a[(c[348620]|0)+m|0]|0)==2){return}if((a[1394464]|0)==0){r=1106168+((f>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){m=d[1044485]|0;c[276541]=7080+(m<<5);j=0;do{l=j<<1&2;n=j&2;o=j&4;q=0;do{b[1125528+(j<<9)+(q<<1)>>1]=d[(q>>>1&28|n)+(7080+(m<<5))|0]<<6|d[(q<<2&28|l)+(7080+(m<<5))|0]<<11|d[(q>>>3&24|o)+(7080+(m<<5))|0];q=q+1|0;}while(q>>>0<256);j=j+1|0;}while(j>>>0<8);a[1106089]=0}r=1125528+((f>>>10&7)<<9)|0}c[277226]=r;c[277225]=(a[1108928]|0)!=0?1393712:r;if((f&49152|0)==0){if((i|0)<=0){return}r=p+h|0;j=i;m=g;while(1){q=a[1108908]|0;o=c[277219]|0;do{if((q&255)>(d[o+m|0]|0)){l=a[r]|0;if(l<<24>>24==0){s=q;t=o;break}n=e[(c[277225]|0)+((l&255)<<1)>>1]|0;l=c[277228]|0;u=(((n&63454)+(l&-2082)|0)>>>1)+(l&2081&n)|0;if((a[1108928]|0)==0){v=u&65535}else{v=(e[(c[277220]|0)+(u<<1)>>1]|(n^l)&2081)&65535}b[(c[277218]|0)+(m<<1)>>1]=v;if((a[1108928]|0)==0){l=e[(c[277213]|0)+(m+2<<1)>>1]|0;n=c[277228]|0;w=(((l&63454)+(n&128990)|0)>>>1)+(n&2081&l)|0}else{l=c[277228]|0;w=e[(c[277220]|0)+((l>>>1&2147482607)<<1)>>1]|l&2081}l=m+1|0;b[(c[277218]|0)+(l<<1)>>1]=w&65535;n=a[1108909]|0;a[(c[277219]|0)+l|0]=n;a[(c[277219]|0)+m|0]=n;s=a[1108908]|0;t=c[277219]|0}else{s=q;t=o}}while(0);o=m+2|0;do{if((s&255)>(d[t+o|0]|0)){q=a[r+1|0]|0;if(q<<24>>24==0){x=s;y=t;break}n=e[(c[277225]|0)+((q&255)<<1)>>1]|0;q=c[277228]|0;l=(((n&63454)+(q&-2082)|0)>>>1)+(q&2081&n)|0;if((a[1108928]|0)==0){z=l&65535}else{z=(e[(c[277220]|0)+(l<<1)>>1]|(n^q)&2081)&65535}b[(c[277218]|0)+(o<<1)>>1]=z;if((a[1108928]|0)==0){q=e[(c[277213]|0)+(m+4<<1)>>1]|0;n=c[277228]|0;A=(((q&63454)+(n&128990)|0)>>>1)+(n&2081&q)|0}else{q=c[277228]|0;A=e[(c[277220]|0)+((q>>>1&2147482607)<<1)>>1]|q&2081}q=m+3|0;b[(c[277218]|0)+(q<<1)>>1]=A&65535;n=a[1108909]|0;a[(c[277219]|0)+q|0]=n;a[(c[277219]|0)+o|0]=n;x=a[1108908]|0;y=c[277219]|0}else{x=s;y=t}}while(0);o=m+4|0;do{if((x&255)>(d[y+o|0]|0)){n=a[r+2|0]|0;if(n<<24>>24==0){B=x;C=y;break}q=e[(c[277225]|0)+((n&255)<<1)>>1]|0;n=c[277228]|0;l=(((q&63454)+(n&-2082)|0)>>>1)+(n&2081&q)|0;if((a[1108928]|0)==0){D=l&65535}else{D=(e[(c[277220]|0)+(l<<1)>>1]|(q^n)&2081)&65535}b[(c[277218]|0)+(o<<1)>>1]=D;if((a[1108928]|0)==0){n=e[(c[277213]|0)+(m+6<<1)>>1]|0;q=c[277228]|0;E=(((n&63454)+(q&128990)|0)>>>1)+(q&2081&n)|0}else{n=c[277228]|0;E=e[(c[277220]|0)+((n>>>1&2147482607)<<1)>>1]|n&2081}n=m+5|0;b[(c[277218]|0)+(n<<1)>>1]=E&65535;q=a[1108909]|0;a[(c[277219]|0)+n|0]=q;a[(c[277219]|0)+o|0]=q;B=a[1108908]|0;C=c[277219]|0}else{B=x;C=y}}while(0);o=m+6|0;do{if((B&255)>(d[C+o|0]|0)){q=a[r+3|0]|0;if(q<<24>>24==0){F=B;G=C;break}n=e[(c[277225]|0)+((q&255)<<1)>>1]|0;q=c[277228]|0;l=(((n&63454)+(q&-2082)|0)>>>1)+(q&2081&n)|0;if((a[1108928]|0)==0){H=l&65535}else{H=(e[(c[277220]|0)+(l<<1)>>1]|(n^q)&2081)&65535}b[(c[277218]|0)+(o<<1)>>1]=H;if((a[1108928]|0)==0){q=e[(c[277213]|0)+(m+8<<1)>>1]|0;n=c[277228]|0;I=(((q&63454)+(n&128990)|0)>>>1)+(n&2081&q)|0}else{q=c[277228]|0;I=e[(c[277220]|0)+((q>>>1&2147482607)<<1)>>1]|q&2081}q=m+7|0;b[(c[277218]|0)+(q<<1)>>1]=I&65535;n=a[1108909]|0;a[(c[277219]|0)+q|0]=n;a[(c[277219]|0)+o|0]=n;F=a[1108908]|0;G=c[277219]|0}else{F=B;G=C}}while(0);o=m+8|0;do{if((F&255)>(d[G+o|0]|0)){n=a[r+4|0]|0;if(n<<24>>24==0){J=F;K=G;break}q=e[(c[277225]|0)+((n&255)<<1)>>1]|0;n=c[277228]|0;l=(((q&63454)+(n&-2082)|0)>>>1)+(n&2081&q)|0;if((a[1108928]|0)==0){L=l&65535}else{L=(e[(c[277220]|0)+(l<<1)>>1]|(q^n)&2081)&65535}b[(c[277218]|0)+(o<<1)>>1]=L;if((a[1108928]|0)==0){n=e[(c[277213]|0)+(m+10<<1)>>1]|0;q=c[277228]|0;M=(((n&63454)+(q&128990)|0)>>>1)+(q&2081&n)|0}else{n=c[277228]|0;M=e[(c[277220]|0)+((n>>>1&2147482607)<<1)>>1]|n&2081}n=m+9|0;b[(c[277218]|0)+(n<<1)>>1]=M&65535;q=a[1108909]|0;a[(c[277219]|0)+n|0]=q;a[(c[277219]|0)+o|0]=q;J=a[1108908]|0;K=c[277219]|0}else{J=F;K=G}}while(0);o=m+10|0;do{if((J&255)>(d[K+o|0]|0)){q=a[r+5|0]|0;if(q<<24>>24==0){N=J;O=K;break}n=e[(c[277225]|0)+((q&255)<<1)>>1]|0;q=c[277228]|0;l=(((n&63454)+(q&-2082)|0)>>>1)+(q&2081&n)|0;if((a[1108928]|0)==0){P=l&65535}else{P=(e[(c[277220]|0)+(l<<1)>>1]|(n^q)&2081)&65535}b[(c[277218]|0)+(o<<1)>>1]=P;if((a[1108928]|0)==0){q=e[(c[277213]|0)+(m+12<<1)>>1]|0;n=c[277228]|0;Q=(((q&63454)+(n&128990)|0)>>>1)+(n&2081&q)|0}else{q=c[277228]|0;Q=e[(c[277220]|0)+((q>>>1&2147482607)<<1)>>1]|q&2081}q=m+11|0;b[(c[277218]|0)+(q<<1)>>1]=Q&65535;n=a[1108909]|0;a[(c[277219]|0)+q|0]=n;a[(c[277219]|0)+o|0]=n;N=a[1108908]|0;O=c[277219]|0}else{N=J;O=K}}while(0);o=m+12|0;do{if((N&255)>(d[O+o|0]|0)){n=a[r+6|0]|0;if(n<<24>>24==0){R=N;S=O;break}q=e[(c[277225]|0)+((n&255)<<1)>>1]|0;n=c[277228]|0;l=(((q&63454)+(n&-2082)|0)>>>1)+(n&2081&q)|0;if((a[1108928]|0)==0){T=l&65535}else{T=(e[(c[277220]|0)+(l<<1)>>1]|(q^n)&2081)&65535}b[(c[277218]|0)+(o<<1)>>1]=T;if((a[1108928]|0)==0){n=e[(c[277213]|0)+(m+14<<1)>>1]|0;q=c[277228]|0;U=(((n&63454)+(q&128990)|0)>>>1)+(q&2081&n)|0}else{n=c[277228]|0;U=e[(c[277220]|0)+((n>>>1&2147482607)<<1)>>1]|n&2081}n=m+13|0;b[(c[277218]|0)+(n<<1)>>1]=U&65535;q=a[1108909]|0;a[(c[277219]|0)+n|0]=q;a[(c[277219]|0)+o|0]=q;R=a[1108908]|0;S=c[277219]|0}else{R=N;S=O}}while(0);o=m+14|0;do{if((R&255)>(d[S+o|0]|0)){q=a[r+7|0]|0;if(q<<24>>24==0){break}n=e[(c[277225]|0)+((q&255)<<1)>>1]|0;q=c[277228]|0;l=(((n&63454)+(q&-2082)|0)>>>1)+(q&2081&n)|0;if((a[1108928]|0)==0){V=l&65535}else{V=(e[(c[277220]|0)+(l<<1)>>1]|(n^q)&2081)&65535}b[(c[277218]|0)+(o<<1)>>1]=V;if((a[1108928]|0)==0){q=e[(c[277213]|0)+(m+16<<1)>>1]|0;n=c[277228]|0;W=(((q&63454)+(n&128990)|0)>>>1)+(n&2081&q)|0}else{q=c[277228]|0;W=e[(c[277220]|0)+((q>>>1&2147482607)<<1)>>1]|q&2081}q=m+15|0;b[(c[277218]|0)+(q<<1)>>1]=W&65535;n=a[1108909]|0;a[(c[277219]|0)+q|0]=n;a[(c[277219]|0)+o|0]=n}}while(0);o=j-1|0;if((o|0)<=0){break}r=r+8|0;j=o;m=(c[277223]|0)+m|0}return}if((f&32768|0)==0){if((i|0)<=0){return}f=p+h|0;m=i;j=g;while(1){r=a[1108908]|0;W=c[277219]|0;do{if((r&255)>(d[W+j|0]|0)){V=a[f+7|0]|0;if(V<<24>>24==0){X=r;Y=W;break}S=e[(c[277225]|0)+((V&255)<<1)>>1]|0;V=c[277228]|0;R=(((S&63454)+(V&-2082)|0)>>>1)+(V&2081&S)|0;if((a[1108928]|0)==0){Z=R&65535}else{Z=(e[(c[277220]|0)+(R<<1)>>1]|(S^V)&2081)&65535}b[(c[277218]|0)+(j<<1)>>1]=Z;if((a[1108928]|0)==0){V=e[(c[277213]|0)+(j+2<<1)>>1]|0;S=c[277228]|0;_=(((V&63454)+(S&128990)|0)>>>1)+(S&2081&V)|0}else{V=c[277228]|0;_=e[(c[277220]|0)+((V>>>1&2147482607)<<1)>>1]|V&2081}V=j+1|0;b[(c[277218]|0)+(V<<1)>>1]=_&65535;S=a[1108909]|0;a[(c[277219]|0)+V|0]=S;a[(c[277219]|0)+j|0]=S;X=a[1108908]|0;Y=c[277219]|0}else{X=r;Y=W}}while(0);W=j+2|0;do{if((X&255)>(d[Y+W|0]|0)){r=a[f+6|0]|0;if(r<<24>>24==0){$=X;aa=Y;break}S=e[(c[277225]|0)+((r&255)<<1)>>1]|0;r=c[277228]|0;V=(((S&63454)+(r&-2082)|0)>>>1)+(r&2081&S)|0;if((a[1108928]|0)==0){ab=V&65535}else{ab=(e[(c[277220]|0)+(V<<1)>>1]|(S^r)&2081)&65535}b[(c[277218]|0)+(W<<1)>>1]=ab;if((a[1108928]|0)==0){r=e[(c[277213]|0)+(j+4<<1)>>1]|0;S=c[277228]|0;ac=(((r&63454)+(S&128990)|0)>>>1)+(S&2081&r)|0}else{r=c[277228]|0;ac=e[(c[277220]|0)+((r>>>1&2147482607)<<1)>>1]|r&2081}r=j+3|0;b[(c[277218]|0)+(r<<1)>>1]=ac&65535;S=a[1108909]|0;a[(c[277219]|0)+r|0]=S;a[(c[277219]|0)+W|0]=S;$=a[1108908]|0;aa=c[277219]|0}else{$=X;aa=Y}}while(0);W=j+4|0;do{if(($&255)>(d[aa+W|0]|0)){S=a[f+5|0]|0;if(S<<24>>24==0){ad=$;ae=aa;break}r=e[(c[277225]|0)+((S&255)<<1)>>1]|0;S=c[277228]|0;V=(((r&63454)+(S&-2082)|0)>>>1)+(S&2081&r)|0;if((a[1108928]|0)==0){af=V&65535}else{af=(e[(c[277220]|0)+(V<<1)>>1]|(r^S)&2081)&65535}b[(c[277218]|0)+(W<<1)>>1]=af;if((a[1108928]|0)==0){S=e[(c[277213]|0)+(j+6<<1)>>1]|0;r=c[277228]|0;ag=(((S&63454)+(r&128990)|0)>>>1)+(r&2081&S)|0}else{S=c[277228]|0;ag=e[(c[277220]|0)+((S>>>1&2147482607)<<1)>>1]|S&2081}S=j+5|0;b[(c[277218]|0)+(S<<1)>>1]=ag&65535;r=a[1108909]|0;a[(c[277219]|0)+S|0]=r;a[(c[277219]|0)+W|0]=r;ad=a[1108908]|0;ae=c[277219]|0}else{ad=$;ae=aa}}while(0);W=j+6|0;do{if((ad&255)>(d[ae+W|0]|0)){r=a[f+4|0]|0;if(r<<24>>24==0){ah=ad;ai=ae;break}S=e[(c[277225]|0)+((r&255)<<1)>>1]|0;r=c[277228]|0;V=(((S&63454)+(r&-2082)|0)>>>1)+(r&2081&S)|0;if((a[1108928]|0)==0){aj=V&65535}else{aj=(e[(c[277220]|0)+(V<<1)>>1]|(S^r)&2081)&65535}b[(c[277218]|0)+(W<<1)>>1]=aj;if((a[1108928]|0)==0){r=e[(c[277213]|0)+(j+8<<1)>>1]|0;S=c[277228]|0;ak=(((r&63454)+(S&128990)|0)>>>1)+(S&2081&r)|0}else{r=c[277228]|0;ak=e[(c[277220]|0)+((r>>>1&2147482607)<<1)>>1]|r&2081}r=j+7|0;b[(c[277218]|0)+(r<<1)>>1]=ak&65535;S=a[1108909]|0;a[(c[277219]|0)+r|0]=S;a[(c[277219]|0)+W|0]=S;ah=a[1108908]|0;ai=c[277219]|0}else{ah=ad;ai=ae}}while(0);W=j+8|0;do{if((ah&255)>(d[ai+W|0]|0)){S=a[f+3|0]|0;if(S<<24>>24==0){al=ah;am=ai;break}r=e[(c[277225]|0)+((S&255)<<1)>>1]|0;S=c[277228]|0;V=(((r&63454)+(S&-2082)|0)>>>1)+(S&2081&r)|0;if((a[1108928]|0)==0){an=V&65535}else{an=(e[(c[277220]|0)+(V<<1)>>1]|(r^S)&2081)&65535}b[(c[277218]|0)+(W<<1)>>1]=an;if((a[1108928]|0)==0){S=e[(c[277213]|0)+(j+10<<1)>>1]|0;r=c[277228]|0;ao=(((S&63454)+(r&128990)|0)>>>1)+(r&2081&S)|0}else{S=c[277228]|0;ao=e[(c[277220]|0)+((S>>>1&2147482607)<<1)>>1]|S&2081}S=j+9|0;b[(c[277218]|0)+(S<<1)>>1]=ao&65535;r=a[1108909]|0;a[(c[277219]|0)+S|0]=r;a[(c[277219]|0)+W|0]=r;al=a[1108908]|0;am=c[277219]|0}else{al=ah;am=ai}}while(0);W=j+10|0;do{if((al&255)>(d[am+W|0]|0)){r=a[f+2|0]|0;if(r<<24>>24==0){ap=al;aq=am;break}S=e[(c[277225]|0)+((r&255)<<1)>>1]|0;r=c[277228]|0;V=(((S&63454)+(r&-2082)|0)>>>1)+(r&2081&S)|0;if((a[1108928]|0)==0){ar=V&65535}else{ar=(e[(c[277220]|0)+(V<<1)>>1]|(S^r)&2081)&65535}b[(c[277218]|0)+(W<<1)>>1]=ar;if((a[1108928]|0)==0){r=e[(c[277213]|0)+(j+12<<1)>>1]|0;S=c[277228]|0;as=(((r&63454)+(S&128990)|0)>>>1)+(S&2081&r)|0}else{r=c[277228]|0;as=e[(c[277220]|0)+((r>>>1&2147482607)<<1)>>1]|r&2081}r=j+11|0;b[(c[277218]|0)+(r<<1)>>1]=as&65535;S=a[1108909]|0;a[(c[277219]|0)+r|0]=S;a[(c[277219]|0)+W|0]=S;ap=a[1108908]|0;aq=c[277219]|0}else{ap=al;aq=am}}while(0);W=j+12|0;do{if((ap&255)>(d[aq+W|0]|0)){S=a[f+1|0]|0;if(S<<24>>24==0){at=ap;au=aq;break}r=e[(c[277225]|0)+((S&255)<<1)>>1]|0;S=c[277228]|0;V=(((r&63454)+(S&-2082)|0)>>>1)+(S&2081&r)|0;if((a[1108928]|0)==0){av=V&65535}else{av=(e[(c[277220]|0)+(V<<1)>>1]|(r^S)&2081)&65535}b[(c[277218]|0)+(W<<1)>>1]=av;if((a[1108928]|0)==0){S=e[(c[277213]|0)+(j+14<<1)>>1]|0;r=c[277228]|0;aw=(((S&63454)+(r&128990)|0)>>>1)+(r&2081&S)|0}else{S=c[277228]|0;aw=e[(c[277220]|0)+((S>>>1&2147482607)<<1)>>1]|S&2081}S=j+13|0;b[(c[277218]|0)+(S<<1)>>1]=aw&65535;r=a[1108909]|0;a[(c[277219]|0)+S|0]=r;a[(c[277219]|0)+W|0]=r;at=a[1108908]|0;au=c[277219]|0}else{at=ap;au=aq}}while(0);W=j+14|0;do{if((at&255)>(d[au+W|0]|0)){r=a[f]|0;if(r<<24>>24==0){break}S=e[(c[277225]|0)+((r&255)<<1)>>1]|0;r=c[277228]|0;V=(((S&63454)+(r&-2082)|0)>>>1)+(r&2081&S)|0;if((a[1108928]|0)==0){ax=V&65535}else{ax=(e[(c[277220]|0)+(V<<1)>>1]|(S^r)&2081)&65535}b[(c[277218]|0)+(W<<1)>>1]=ax;if((a[1108928]|0)==0){r=e[(c[277213]|0)+(j+16<<1)>>1]|0;S=c[277228]|0;ay=(((r&63454)+(S&128990)|0)>>>1)+(S&2081&r)|0}else{r=c[277228]|0;ay=e[(c[277220]|0)+((r>>>1&2147482607)<<1)>>1]|r&2081}r=j+15|0;b[(c[277218]|0)+(r<<1)>>1]=ay&65535;S=a[1108909]|0;a[(c[277219]|0)+r|0]=S;a[(c[277219]|0)+W|0]=S}}while(0);W=m-1|0;if((W|0)<=0){break}f=f+8|0;m=W;j=(c[277223]|0)+j|0}return}j=p+(56-h)|0;h=(i|0)>0;if(k){if(h){az=j;aA=i;aB=g}else{return}while(1){k=a[1108908]|0;p=c[277219]|0;do{if((k&255)>(d[p+aB|0]|0)){m=a[az+7|0]|0;if(m<<24>>24==0){aC=k;aD=p;break}f=e[(c[277225]|0)+((m&255)<<1)>>1]|0;m=c[277228]|0;ay=(((f&63454)+(m&-2082)|0)>>>1)+(m&2081&f)|0;if((a[1108928]|0)==0){aE=ay&65535}else{aE=(e[(c[277220]|0)+(ay<<1)>>1]|(f^m)&2081)&65535}b[(c[277218]|0)+(aB<<1)>>1]=aE;if((a[1108928]|0)==0){m=e[(c[277213]|0)+(aB+2<<1)>>1]|0;f=c[277228]|0;aF=(((m&63454)+(f&128990)|0)>>>1)+(f&2081&m)|0}else{m=c[277228]|0;aF=e[(c[277220]|0)+((m>>>1&2147482607)<<1)>>1]|m&2081}m=aB+1|0;b[(c[277218]|0)+(m<<1)>>1]=aF&65535;f=a[1108909]|0;a[(c[277219]|0)+m|0]=f;a[(c[277219]|0)+aB|0]=f;aC=a[1108908]|0;aD=c[277219]|0}else{aC=k;aD=p}}while(0);p=aB+2|0;do{if((aC&255)>(d[aD+p|0]|0)){k=a[az+6|0]|0;if(k<<24>>24==0){aG=aC;aH=aD;break}f=e[(c[277225]|0)+((k&255)<<1)>>1]|0;k=c[277228]|0;m=(((f&63454)+(k&-2082)|0)>>>1)+(k&2081&f)|0;if((a[1108928]|0)==0){aI=m&65535}else{aI=(e[(c[277220]|0)+(m<<1)>>1]|(f^k)&2081)&65535}b[(c[277218]|0)+(p<<1)>>1]=aI;if((a[1108928]|0)==0){k=e[(c[277213]|0)+(aB+4<<1)>>1]|0;f=c[277228]|0;aJ=(((k&63454)+(f&128990)|0)>>>1)+(f&2081&k)|0}else{k=c[277228]|0;aJ=e[(c[277220]|0)+((k>>>1&2147482607)<<1)>>1]|k&2081}k=aB+3|0;b[(c[277218]|0)+(k<<1)>>1]=aJ&65535;f=a[1108909]|0;a[(c[277219]|0)+k|0]=f;a[(c[277219]|0)+p|0]=f;aG=a[1108908]|0;aH=c[277219]|0}else{aG=aC;aH=aD}}while(0);p=aB+4|0;do{if((aG&255)>(d[aH+p|0]|0)){f=a[az+5|0]|0;if(f<<24>>24==0){aK=aG;aL=aH;break}k=e[(c[277225]|0)+((f&255)<<1)>>1]|0;f=c[277228]|0;m=(((k&63454)+(f&-2082)|0)>>>1)+(f&2081&k)|0;if((a[1108928]|0)==0){aM=m&65535}else{aM=(e[(c[277220]|0)+(m<<1)>>1]|(k^f)&2081)&65535}b[(c[277218]|0)+(p<<1)>>1]=aM;if((a[1108928]|0)==0){f=e[(c[277213]|0)+(aB+6<<1)>>1]|0;k=c[277228]|0;aN=(((f&63454)+(k&128990)|0)>>>1)+(k&2081&f)|0}else{f=c[277228]|0;aN=e[(c[277220]|0)+((f>>>1&2147482607)<<1)>>1]|f&2081}f=aB+5|0;b[(c[277218]|0)+(f<<1)>>1]=aN&65535;k=a[1108909]|0;a[(c[277219]|0)+f|0]=k;a[(c[277219]|0)+p|0]=k;aK=a[1108908]|0;aL=c[277219]|0}else{aK=aG;aL=aH}}while(0);p=aB+6|0;do{if((aK&255)>(d[aL+p|0]|0)){k=a[az+4|0]|0;if(k<<24>>24==0){aO=aK;aP=aL;break}f=e[(c[277225]|0)+((k&255)<<1)>>1]|0;k=c[277228]|0;m=(((f&63454)+(k&-2082)|0)>>>1)+(k&2081&f)|0;if((a[1108928]|0)==0){aQ=m&65535}else{aQ=(e[(c[277220]|0)+(m<<1)>>1]|(f^k)&2081)&65535}b[(c[277218]|0)+(p<<1)>>1]=aQ;if((a[1108928]|0)==0){k=e[(c[277213]|0)+(aB+8<<1)>>1]|0;f=c[277228]|0;aR=(((k&63454)+(f&128990)|0)>>>1)+(f&2081&k)|0}else{k=c[277228]|0;aR=e[(c[277220]|0)+((k>>>1&2147482607)<<1)>>1]|k&2081}k=aB+7|0;b[(c[277218]|0)+(k<<1)>>1]=aR&65535;f=a[1108909]|0;a[(c[277219]|0)+k|0]=f;a[(c[277219]|0)+p|0]=f;aO=a[1108908]|0;aP=c[277219]|0}else{aO=aK;aP=aL}}while(0);p=aB+8|0;do{if((aO&255)>(d[aP+p|0]|0)){f=a[az+3|0]|0;if(f<<24>>24==0){aS=aO;aT=aP;break}k=e[(c[277225]|0)+((f&255)<<1)>>1]|0;f=c[277228]|0;m=(((k&63454)+(f&-2082)|0)>>>1)+(f&2081&k)|0;if((a[1108928]|0)==0){aU=m&65535}else{aU=(e[(c[277220]|0)+(m<<1)>>1]|(k^f)&2081)&65535}b[(c[277218]|0)+(p<<1)>>1]=aU;if((a[1108928]|0)==0){f=e[(c[277213]|0)+(aB+10<<1)>>1]|0;k=c[277228]|0;aV=(((f&63454)+(k&128990)|0)>>>1)+(k&2081&f)|0}else{f=c[277228]|0;aV=e[(c[277220]|0)+((f>>>1&2147482607)<<1)>>1]|f&2081}f=aB+9|0;b[(c[277218]|0)+(f<<1)>>1]=aV&65535;k=a[1108909]|0;a[(c[277219]|0)+f|0]=k;a[(c[277219]|0)+p|0]=k;aS=a[1108908]|0;aT=c[277219]|0}else{aS=aO;aT=aP}}while(0);p=aB+10|0;do{if((aS&255)>(d[aT+p|0]|0)){k=a[az+2|0]|0;if(k<<24>>24==0){aW=aS;aX=aT;break}f=e[(c[277225]|0)+((k&255)<<1)>>1]|0;k=c[277228]|0;m=(((f&63454)+(k&-2082)|0)>>>1)+(k&2081&f)|0;if((a[1108928]|0)==0){aY=m&65535}else{aY=(e[(c[277220]|0)+(m<<1)>>1]|(f^k)&2081)&65535}b[(c[277218]|0)+(p<<1)>>1]=aY;if((a[1108928]|0)==0){k=e[(c[277213]|0)+(aB+12<<1)>>1]|0;f=c[277228]|0;aZ=(((k&63454)+(f&128990)|0)>>>1)+(f&2081&k)|0}else{k=c[277228]|0;aZ=e[(c[277220]|0)+((k>>>1&2147482607)<<1)>>1]|k&2081}k=aB+11|0;b[(c[277218]|0)+(k<<1)>>1]=aZ&65535;f=a[1108909]|0;a[(c[277219]|0)+k|0]=f;a[(c[277219]|0)+p|0]=f;aW=a[1108908]|0;aX=c[277219]|0}else{aW=aS;aX=aT}}while(0);p=aB+12|0;do{if((aW&255)>(d[aX+p|0]|0)){f=a[az+1|0]|0;if(f<<24>>24==0){a_=aW;a$=aX;break}k=e[(c[277225]|0)+((f&255)<<1)>>1]|0;f=c[277228]|0;m=(((k&63454)+(f&-2082)|0)>>>1)+(f&2081&k)|0;if((a[1108928]|0)==0){a0=m&65535}else{a0=(e[(c[277220]|0)+(m<<1)>>1]|(k^f)&2081)&65535}b[(c[277218]|0)+(p<<1)>>1]=a0;if((a[1108928]|0)==0){f=e[(c[277213]|0)+(aB+14<<1)>>1]|0;k=c[277228]|0;a1=(((f&63454)+(k&128990)|0)>>>1)+(k&2081&f)|0}else{f=c[277228]|0;a1=e[(c[277220]|0)+((f>>>1&2147482607)<<1)>>1]|f&2081}f=aB+13|0;b[(c[277218]|0)+(f<<1)>>1]=a1&65535;k=a[1108909]|0;a[(c[277219]|0)+f|0]=k;a[(c[277219]|0)+p|0]=k;a_=a[1108908]|0;a$=c[277219]|0}else{a_=aW;a$=aX}}while(0);p=aB+14|0;do{if((a_&255)>(d[a$+p|0]|0)){k=a[az]|0;if(k<<24>>24==0){break}f=e[(c[277225]|0)+((k&255)<<1)>>1]|0;k=c[277228]|0;m=(((f&63454)+(k&-2082)|0)>>>1)+(k&2081&f)|0;if((a[1108928]|0)==0){a2=m&65535}else{a2=(e[(c[277220]|0)+(m<<1)>>1]|(f^k)&2081)&65535}b[(c[277218]|0)+(p<<1)>>1]=a2;if((a[1108928]|0)==0){k=e[(c[277213]|0)+(aB+16<<1)>>1]|0;f=c[277228]|0;a3=(((k&63454)+(f&128990)|0)>>>1)+(f&2081&k)|0}else{k=c[277228]|0;a3=e[(c[277220]|0)+((k>>>1&2147482607)<<1)>>1]|k&2081}k=aB+15|0;b[(c[277218]|0)+(k<<1)>>1]=a3&65535;f=a[1108909]|0;a[(c[277219]|0)+k|0]=f;a[(c[277219]|0)+p|0]=f}}while(0);p=aA-1|0;if((p|0)<=0){break}az=az-8|0;aA=p;aB=(c[277223]|0)+aB|0}return}else{if(h){a4=j;a5=i;a6=g}else{return}while(1){g=a[1108908]|0;i=c[277219]|0;do{if((g&255)>(d[i+a6|0]|0)){j=a[a4]|0;if(j<<24>>24==0){a7=g;a8=i;break}h=e[(c[277225]|0)+((j&255)<<1)>>1]|0;j=c[277228]|0;aB=(((h&63454)+(j&-2082)|0)>>>1)+(j&2081&h)|0;if((a[1108928]|0)==0){a9=aB&65535}else{a9=(e[(c[277220]|0)+(aB<<1)>>1]|(h^j)&2081)&65535}b[(c[277218]|0)+(a6<<1)>>1]=a9;if((a[1108928]|0)==0){j=e[(c[277213]|0)+(a6+2<<1)>>1]|0;h=c[277228]|0;ba=(((j&63454)+(h&128990)|0)>>>1)+(h&2081&j)|0}else{j=c[277228]|0;ba=e[(c[277220]|0)+((j>>>1&2147482607)<<1)>>1]|j&2081}j=a6+1|0;b[(c[277218]|0)+(j<<1)>>1]=ba&65535;h=a[1108909]|0;a[(c[277219]|0)+j|0]=h;a[(c[277219]|0)+a6|0]=h;a7=a[1108908]|0;a8=c[277219]|0}else{a7=g;a8=i}}while(0);i=a6+2|0;do{if((a7&255)>(d[a8+i|0]|0)){g=a[a4+1|0]|0;if(g<<24>>24==0){bb=a7;bc=a8;break}h=e[(c[277225]|0)+((g&255)<<1)>>1]|0;g=c[277228]|0;j=(((h&63454)+(g&-2082)|0)>>>1)+(g&2081&h)|0;if((a[1108928]|0)==0){bd=j&65535}else{bd=(e[(c[277220]|0)+(j<<1)>>1]|(h^g)&2081)&65535}b[(c[277218]|0)+(i<<1)>>1]=bd;if((a[1108928]|0)==0){g=e[(c[277213]|0)+(a6+4<<1)>>1]|0;h=c[277228]|0;be=(((g&63454)+(h&128990)|0)>>>1)+(h&2081&g)|0}else{g=c[277228]|0;be=e[(c[277220]|0)+((g>>>1&2147482607)<<1)>>1]|g&2081}g=a6+3|0;b[(c[277218]|0)+(g<<1)>>1]=be&65535;h=a[1108909]|0;a[(c[277219]|0)+g|0]=h;a[(c[277219]|0)+i|0]=h;bb=a[1108908]|0;bc=c[277219]|0}else{bb=a7;bc=a8}}while(0);i=a6+4|0;do{if((bb&255)>(d[bc+i|0]|0)){h=a[a4+2|0]|0;if(h<<24>>24==0){bf=bb;bg=bc;break}g=e[(c[277225]|0)+((h&255)<<1)>>1]|0;h=c[277228]|0;j=(((g&63454)+(h&-2082)|0)>>>1)+(h&2081&g)|0;if((a[1108928]|0)==0){bh=j&65535}else{bh=(e[(c[277220]|0)+(j<<1)>>1]|(g^h)&2081)&65535}b[(c[277218]|0)+(i<<1)>>1]=bh;if((a[1108928]|0)==0){h=e[(c[277213]|0)+(a6+6<<1)>>1]|0;g=c[277228]|0;bi=(((h&63454)+(g&128990)|0)>>>1)+(g&2081&h)|0}else{h=c[277228]|0;bi=e[(c[277220]|0)+((h>>>1&2147482607)<<1)>>1]|h&2081}h=a6+5|0;b[(c[277218]|0)+(h<<1)>>1]=bi&65535;g=a[1108909]|0;a[(c[277219]|0)+h|0]=g;a[(c[277219]|0)+i|0]=g;bf=a[1108908]|0;bg=c[277219]|0}else{bf=bb;bg=bc}}while(0);i=a6+6|0;do{if((bf&255)>(d[bg+i|0]|0)){g=a[a4+3|0]|0;if(g<<24>>24==0){bj=bf;bk=bg;break}h=e[(c[277225]|0)+((g&255)<<1)>>1]|0;g=c[277228]|0;j=(((h&63454)+(g&-2082)|0)>>>1)+(g&2081&h)|0;if((a[1108928]|0)==0){bl=j&65535}else{bl=(e[(c[277220]|0)+(j<<1)>>1]|(h^g)&2081)&65535}b[(c[277218]|0)+(i<<1)>>1]=bl;if((a[1108928]|0)==0){g=e[(c[277213]|0)+(a6+8<<1)>>1]|0;h=c[277228]|0;bm=(((g&63454)+(h&128990)|0)>>>1)+(h&2081&g)|0}else{g=c[277228]|0;bm=e[(c[277220]|0)+((g>>>1&2147482607)<<1)>>1]|g&2081}g=a6+7|0;b[(c[277218]|0)+(g<<1)>>1]=bm&65535;h=a[1108909]|0;a[(c[277219]|0)+g|0]=h;a[(c[277219]|0)+i|0]=h;bj=a[1108908]|0;bk=c[277219]|0}else{bj=bf;bk=bg}}while(0);i=a6+8|0;do{if((bj&255)>(d[bk+i|0]|0)){h=a[a4+4|0]|0;if(h<<24>>24==0){bn=bj;bo=bk;break}g=e[(c[277225]|0)+((h&255)<<1)>>1]|0;h=c[277228]|0;j=(((g&63454)+(h&-2082)|0)>>>1)+(h&2081&g)|0;if((a[1108928]|0)==0){bp=j&65535}else{bp=(e[(c[277220]|0)+(j<<1)>>1]|(g^h)&2081)&65535}b[(c[277218]|0)+(i<<1)>>1]=bp;if((a[1108928]|0)==0){h=e[(c[277213]|0)+(a6+10<<1)>>1]|0;g=c[277228]|0;bq=(((h&63454)+(g&128990)|0)>>>1)+(g&2081&h)|0}else{h=c[277228]|0;bq=e[(c[277220]|0)+((h>>>1&2147482607)<<1)>>1]|h&2081}h=a6+9|0;b[(c[277218]|0)+(h<<1)>>1]=bq&65535;g=a[1108909]|0;a[(c[277219]|0)+h|0]=g;a[(c[277219]|0)+i|0]=g;bn=a[1108908]|0;bo=c[277219]|0}else{bn=bj;bo=bk}}while(0);i=a6+10|0;do{if((bn&255)>(d[bo+i|0]|0)){g=a[a4+5|0]|0;if(g<<24>>24==0){br=bn;bs=bo;break}h=e[(c[277225]|0)+((g&255)<<1)>>1]|0;g=c[277228]|0;j=(((h&63454)+(g&-2082)|0)>>>1)+(g&2081&h)|0;if((a[1108928]|0)==0){bt=j&65535}else{bt=(e[(c[277220]|0)+(j<<1)>>1]|(h^g)&2081)&65535}b[(c[277218]|0)+(i<<1)>>1]=bt;if((a[1108928]|0)==0){g=e[(c[277213]|0)+(a6+12<<1)>>1]|0;h=c[277228]|0;bu=(((g&63454)+(h&128990)|0)>>>1)+(h&2081&g)|0}else{g=c[277228]|0;bu=e[(c[277220]|0)+((g>>>1&2147482607)<<1)>>1]|g&2081}g=a6+11|0;b[(c[277218]|0)+(g<<1)>>1]=bu&65535;h=a[1108909]|0;a[(c[277219]|0)+g|0]=h;a[(c[277219]|0)+i|0]=h;br=a[1108908]|0;bs=c[277219]|0}else{br=bn;bs=bo}}while(0);i=a6+12|0;do{if((br&255)>(d[bs+i|0]|0)){h=a[a4+6|0]|0;if(h<<24>>24==0){bv=br;bw=bs;break}g=e[(c[277225]|0)+((h&255)<<1)>>1]|0;h=c[277228]|0;j=(((g&63454)+(h&-2082)|0)>>>1)+(h&2081&g)|0;if((a[1108928]|0)==0){bx=j&65535}else{bx=(e[(c[277220]|0)+(j<<1)>>1]|(g^h)&2081)&65535}b[(c[277218]|0)+(i<<1)>>1]=bx;if((a[1108928]|0)==0){h=e[(c[277213]|0)+(a6+14<<1)>>1]|0;g=c[277228]|0;by=(((h&63454)+(g&128990)|0)>>>1)+(g&2081&h)|0}else{h=c[277228]|0;by=e[(c[277220]|0)+((h>>>1&2147482607)<<1)>>1]|h&2081}h=a6+13|0;b[(c[277218]|0)+(h<<1)>>1]=by&65535;g=a[1108909]|0;a[(c[277219]|0)+h|0]=g;a[(c[277219]|0)+i|0]=g;bv=a[1108908]|0;bw=c[277219]|0}else{bv=br;bw=bs}}while(0);i=a6+14|0;do{if((bv&255)>(d[bw+i|0]|0)){g=a[a4+7|0]|0;if(g<<24>>24==0){break}h=e[(c[277225]|0)+((g&255)<<1)>>1]|0;g=c[277228]|0;j=(((h&63454)+(g&-2082)|0)>>>1)+(g&2081&h)|0;if((a[1108928]|0)==0){bz=j&65535}else{bz=(e[(c[277220]|0)+(j<<1)>>1]|(h^g)&2081)&65535}b[(c[277218]|0)+(i<<1)>>1]=bz;if((a[1108928]|0)==0){g=e[(c[277213]|0)+(a6+16<<1)>>1]|0;h=c[277228]|0;bA=(((g&63454)+(h&128990)|0)>>>1)+(h&2081&g)|0}else{g=c[277228]|0;bA=e[(c[277220]|0)+((g>>>1&2147482607)<<1)>>1]|g&2081}g=a6+15|0;b[(c[277218]|0)+(g<<1)>>1]=bA&65535;h=a[1108909]|0;a[(c[277219]|0)+g|0]=h;a[(c[277219]|0)+i|0]=h}}while(0);i=a5-1|0;if((i|0)<=0){break}a4=a4-8|0;a5=i;a6=(c[277223]|0)+a6|0}return}}function VK(f,g,h,i){f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0,cf=0,cg=0,ch=0,ci=0,cj=0,ck=0,cl=0,cm=0,cn=0,co=0,cp=0,cq=0,cr=0,cs=0,ct=0,cu=0,cv=0,cw=0,cx=0,cy=0,cz=0,cA=0,cB=0,cC=0,cD=0,cE=0,cF=0,cG=0,cH=0,cI=0,cJ=0,cK=0,cL=0,cM=0,cN=0,cO=0,cP=0,cQ=0,cR=0,cS=0,cT=0,cU=0,cV=0,cW=0,cX=0,cY=0,cZ=0,c_=0,c$=0,c0=0,c1=0,c2=0,c3=0,c4=0,c5=0,c6=0,c7=0,c8=0,c9=0,da=0,db=0,dc=0,dd=0,de=0,df=0,dg=0,dh=0,di=0,dj=0,dk=0,dl=0,dm=0,dn=0,dp=0,dq=0,dr=0,ds=0,dt=0,du=0,dv=0,dw=0,dx=0,dy=0,dz=0,dA=0,dB=0,dC=0,dD=0,dE=0,dF=0,dG=0,dH=0,dI=0,dJ=0,dK=0,dL=0,dM=0,dN=0,dO=0,dP=0,dQ=0,dR=0,dS=0,dT=0,dU=0,dV=0,dW=0,dX=0,dY=0,dZ=0,d_=0,d$=0,d0=0,d1=0,d2=0,d3=0,d4=0,d5=0,d6=0,d7=0;j=f&1023;k=c[348606]|0;l=(j<<k)+(c[348604]|0)|0;if((f&256|0)==0){m=l}else{m=(c[348602]|0)+l|0}l=m&65535;m=l>>>(k>>>0);k=(f&16384|0)!=0;n=m<<6;do{if(k){o=(c[348622]|0)+n|0;if((a[(c[348618]|0)+m|0]|0)!=0){p=o;break}q=fi[c[348636]&63](o,l,j)|0;a[(c[348618]|0)+m|0]=q;p=o}else{o=(c[348624]|0)+n|0;if((a[(c[348620]|0)+m|0]|0)!=0){p=o;break}q=fi[c[348638]&63](o,l,j)|0;a[(c[348620]|0)+m|0]=q;p=o}}while(0);if((a[(c[348620]|0)+m|0]|0)==2){return}if((a[1394464]|0)==0){r=1106168+((f>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){m=d[1044485]|0;c[276541]=7080+(m<<5);j=0;do{l=j<<1&2;n=j&2;o=j&4;q=0;do{b[1125528+(j<<9)+(q<<1)>>1]=d[(q>>>1&28|n)+(7080+(m<<5))|0]<<6|d[(q<<2&28|l)+(7080+(m<<5))|0]<<11|d[(q>>>3&24|o)+(7080+(m<<5))|0];q=q+1|0;}while(q>>>0<256);j=j+1|0;}while(j>>>0<8);a[1106089]=0}r=1125528+((f>>>10&7)<<9)|0}c[277226]=r;c[277225]=(a[1108928]|0)!=0?1393712:r;if((f&49152|0)==0){if((i|0)<=0){return}r=p+h|0;j=i;m=g;while(1){q=a[1108908]|0;o=c[277219]|0;do{if((q&255)>(d[o+m|0]|0)){l=a[r]|0;n=l&255;if(l<<24>>24==0){s=q;t=o;break}do{if((a[1108928]|0)==0){l=b[(c[277225]|0)+(n<<1)>>1]|0;u=l&65535;v=u&63454;if((a[(c[277215]|0)+m|0]&32)==0){w=c[277228]|0;x=(e[(c[277220]|0)+((((w&-2082)+v|0)>>>1)+(u&2081&w)<<1)>>1]|(w^u)&2081)&65535;break}else{u=b[(c[277213]|0)+(m<<1)>>1]|0;x=(((u&63454)+v|0)>>>1)+(u&l&2081)&65535;break}}else{l=e[(c[277225]|0)+(n<<1)>>1]|0;u=(a[(c[277215]|0)+m|0]&32)==0;if(u){v=c[277228]|0;y=v;z=v&-2082}else{v=e[(c[277213]|0)+(m<<1)>>1]|0;y=v;z=v&63454}if(u){A=c[277228]|0}else{A=e[(c[277213]|0)+(m<<1)>>1]|0}x=((A^l)&2081|e[(c[277220]|0)+((l&2081&y)+((z+(l&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(m<<1)>>1]=x;l=(a[(c[277215]|0)+m|0]&32)==0;do{if((a[1108928]|0)==0){u=e[(c[277213]|0)+(m+2<<1)>>1]|0;v=u&63454;if(l){w=c[277228]|0;B=(e[(c[277220]|0)+((((w&-2082)+v|0)>>>1)+(u&2081&w)<<1)>>1]|(w^u)&2081)&65535;break}else{w=e[(c[277226]|0)+(n<<1)>>1]|0;B=(((w&63454)+v|0)>>>1)+(u&2081&w)&65535;break}}else{if(l){w=c[277228]|0;C=w;D=(c[277220]|0)+((w>>>1&2147482607)<<1)|0}else{w=e[(c[277226]|0)+(n<<1)>>1]|0;C=w;D=(c[277220]|0)+((w>>>1&31727)<<1)|0}B=(e[D>>1]|C&2081)&65535}}while(0);n=m+1|0;b[(c[277218]|0)+(n<<1)>>1]=B;l=a[1108909]|0;a[(c[277219]|0)+n|0]=l;a[(c[277219]|0)+m|0]=l;s=a[1108908]|0;t=c[277219]|0}else{s=q;t=o}}while(0);o=m+2|0;do{if((s&255)>(d[t+o|0]|0)){q=a[r+1|0]|0;l=q&255;if(q<<24>>24==0){E=s;F=t;break}do{if((a[1108928]|0)==0){q=b[(c[277225]|0)+(l<<1)>>1]|0;n=q&65535;w=n&63454;if((a[(c[277215]|0)+o|0]&32)==0){u=c[277228]|0;G=(e[(c[277220]|0)+((((u&-2082)+w|0)>>>1)+(n&2081&u)<<1)>>1]|(u^n)&2081)&65535;break}else{n=b[(c[277213]|0)+(o<<1)>>1]|0;G=(((n&63454)+w|0)>>>1)+(n&q&2081)&65535;break}}else{q=e[(c[277225]|0)+(l<<1)>>1]|0;n=(a[(c[277215]|0)+o|0]&32)==0;if(n){w=c[277228]|0;H=w;I=w&-2082}else{w=e[(c[277213]|0)+(o<<1)>>1]|0;H=w;I=w&63454}if(n){J=c[277228]|0}else{J=e[(c[277213]|0)+(o<<1)>>1]|0}G=((J^q)&2081|e[(c[277220]|0)+((q&2081&H)+((I+(q&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=G;q=(a[(c[277215]|0)+o|0]&32)==0;do{if((a[1108928]|0)==0){n=e[(c[277213]|0)+(m+4<<1)>>1]|0;w=n&63454;if(q){u=c[277228]|0;K=(e[(c[277220]|0)+((((u&-2082)+w|0)>>>1)+(n&2081&u)<<1)>>1]|(u^n)&2081)&65535;break}else{u=e[(c[277226]|0)+(l<<1)>>1]|0;K=(((u&63454)+w|0)>>>1)+(n&2081&u)&65535;break}}else{if(q){u=c[277228]|0;L=u;M=(c[277220]|0)+((u>>>1&2147482607)<<1)|0}else{u=e[(c[277226]|0)+(l<<1)>>1]|0;L=u;M=(c[277220]|0)+((u>>>1&31727)<<1)|0}K=(e[M>>1]|L&2081)&65535}}while(0);l=m+3|0;b[(c[277218]|0)+(l<<1)>>1]=K;q=a[1108909]|0;a[(c[277219]|0)+l|0]=q;a[(c[277219]|0)+o|0]=q;E=a[1108908]|0;F=c[277219]|0}else{E=s;F=t}}while(0);o=m+4|0;do{if((E&255)>(d[F+o|0]|0)){q=a[r+2|0]|0;l=q&255;if(q<<24>>24==0){N=E;O=F;break}do{if((a[1108928]|0)==0){q=b[(c[277225]|0)+(l<<1)>>1]|0;u=q&65535;n=u&63454;if((a[(c[277215]|0)+o|0]&32)==0){w=c[277228]|0;P=(e[(c[277220]|0)+((((w&-2082)+n|0)>>>1)+(u&2081&w)<<1)>>1]|(w^u)&2081)&65535;break}else{u=b[(c[277213]|0)+(o<<1)>>1]|0;P=(((u&63454)+n|0)>>>1)+(u&q&2081)&65535;break}}else{q=e[(c[277225]|0)+(l<<1)>>1]|0;u=(a[(c[277215]|0)+o|0]&32)==0;if(u){n=c[277228]|0;Q=n;R=n&-2082}else{n=e[(c[277213]|0)+(o<<1)>>1]|0;Q=n;R=n&63454}if(u){S=c[277228]|0}else{S=e[(c[277213]|0)+(o<<1)>>1]|0}P=((S^q)&2081|e[(c[277220]|0)+((q&2081&Q)+((R+(q&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=P;q=(a[(c[277215]|0)+o|0]&32)==0;do{if((a[1108928]|0)==0){u=e[(c[277213]|0)+(m+6<<1)>>1]|0;n=u&63454;if(q){w=c[277228]|0;T=(e[(c[277220]|0)+((((w&-2082)+n|0)>>>1)+(u&2081&w)<<1)>>1]|(w^u)&2081)&65535;break}else{w=e[(c[277226]|0)+(l<<1)>>1]|0;T=(((w&63454)+n|0)>>>1)+(u&2081&w)&65535;break}}else{if(q){w=c[277228]|0;U=w;V=(c[277220]|0)+((w>>>1&2147482607)<<1)|0}else{w=e[(c[277226]|0)+(l<<1)>>1]|0;U=w;V=(c[277220]|0)+((w>>>1&31727)<<1)|0}T=(e[V>>1]|U&2081)&65535}}while(0);l=m+5|0;b[(c[277218]|0)+(l<<1)>>1]=T;q=a[1108909]|0;a[(c[277219]|0)+l|0]=q;a[(c[277219]|0)+o|0]=q;N=a[1108908]|0;O=c[277219]|0}else{N=E;O=F}}while(0);o=m+6|0;do{if((N&255)>(d[O+o|0]|0)){q=a[r+3|0]|0;l=q&255;if(q<<24>>24==0){W=N;X=O;break}do{if((a[1108928]|0)==0){q=b[(c[277225]|0)+(l<<1)>>1]|0;w=q&65535;u=w&63454;if((a[(c[277215]|0)+o|0]&32)==0){n=c[277228]|0;Y=(e[(c[277220]|0)+((((n&-2082)+u|0)>>>1)+(w&2081&n)<<1)>>1]|(n^w)&2081)&65535;break}else{w=b[(c[277213]|0)+(o<<1)>>1]|0;Y=(((w&63454)+u|0)>>>1)+(w&q&2081)&65535;break}}else{q=e[(c[277225]|0)+(l<<1)>>1]|0;w=(a[(c[277215]|0)+o|0]&32)==0;if(w){u=c[277228]|0;Z=u;_=u&-2082}else{u=e[(c[277213]|0)+(o<<1)>>1]|0;Z=u;_=u&63454}if(w){$=c[277228]|0}else{$=e[(c[277213]|0)+(o<<1)>>1]|0}Y=(($^q)&2081|e[(c[277220]|0)+((q&2081&Z)+((_+(q&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=Y;q=(a[(c[277215]|0)+o|0]&32)==0;do{if((a[1108928]|0)==0){w=e[(c[277213]|0)+(m+8<<1)>>1]|0;u=w&63454;if(q){n=c[277228]|0;aa=(e[(c[277220]|0)+((((n&-2082)+u|0)>>>1)+(w&2081&n)<<1)>>1]|(n^w)&2081)&65535;break}else{n=e[(c[277226]|0)+(l<<1)>>1]|0;aa=(((n&63454)+u|0)>>>1)+(w&2081&n)&65535;break}}else{if(q){n=c[277228]|0;ab=n;ac=(c[277220]|0)+((n>>>1&2147482607)<<1)|0}else{n=e[(c[277226]|0)+(l<<1)>>1]|0;ab=n;ac=(c[277220]|0)+((n>>>1&31727)<<1)|0}aa=(e[ac>>1]|ab&2081)&65535}}while(0);l=m+7|0;b[(c[277218]|0)+(l<<1)>>1]=aa;q=a[1108909]|0;a[(c[277219]|0)+l|0]=q;a[(c[277219]|0)+o|0]=q;W=a[1108908]|0;X=c[277219]|0}else{W=N;X=O}}while(0);o=m+8|0;do{if((W&255)>(d[X+o|0]|0)){q=a[r+4|0]|0;l=q&255;if(q<<24>>24==0){ad=W;ae=X;break}do{if((a[1108928]|0)==0){q=b[(c[277225]|0)+(l<<1)>>1]|0;n=q&65535;w=n&63454;if((a[(c[277215]|0)+o|0]&32)==0){u=c[277228]|0;af=(e[(c[277220]|0)+((((u&-2082)+w|0)>>>1)+(n&2081&u)<<1)>>1]|(u^n)&2081)&65535;break}else{n=b[(c[277213]|0)+(o<<1)>>1]|0;af=(((n&63454)+w|0)>>>1)+(n&q&2081)&65535;break}}else{q=e[(c[277225]|0)+(l<<1)>>1]|0;n=(a[(c[277215]|0)+o|0]&32)==0;if(n){w=c[277228]|0;ag=w;ah=w&-2082}else{w=e[(c[277213]|0)+(o<<1)>>1]|0;ag=w;ah=w&63454}if(n){ai=c[277228]|0}else{ai=e[(c[277213]|0)+(o<<1)>>1]|0}af=((ai^q)&2081|e[(c[277220]|0)+((q&2081&ag)+((ah+(q&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=af;q=(a[(c[277215]|0)+o|0]&32)==0;do{if((a[1108928]|0)==0){n=e[(c[277213]|0)+(m+10<<1)>>1]|0;w=n&63454;if(q){u=c[277228]|0;aj=(e[(c[277220]|0)+((((u&-2082)+w|0)>>>1)+(n&2081&u)<<1)>>1]|(u^n)&2081)&65535;break}else{u=e[(c[277226]|0)+(l<<1)>>1]|0;aj=(((u&63454)+w|0)>>>1)+(n&2081&u)&65535;break}}else{if(q){u=c[277228]|0;ak=u;al=(c[277220]|0)+((u>>>1&2147482607)<<1)|0}else{u=e[(c[277226]|0)+(l<<1)>>1]|0;ak=u;al=(c[277220]|0)+((u>>>1&31727)<<1)|0}aj=(e[al>>1]|ak&2081)&65535}}while(0);l=m+9|0;b[(c[277218]|0)+(l<<1)>>1]=aj;q=a[1108909]|0;a[(c[277219]|0)+l|0]=q;a[(c[277219]|0)+o|0]=q;ad=a[1108908]|0;ae=c[277219]|0}else{ad=W;ae=X}}while(0);o=m+10|0;do{if((ad&255)>(d[ae+o|0]|0)){q=a[r+5|0]|0;l=q&255;if(q<<24>>24==0){am=ad;an=ae;break}do{if((a[1108928]|0)==0){q=b[(c[277225]|0)+(l<<1)>>1]|0;u=q&65535;n=u&63454;if((a[(c[277215]|0)+o|0]&32)==0){w=c[277228]|0;ao=(e[(c[277220]|0)+((((w&-2082)+n|0)>>>1)+(u&2081&w)<<1)>>1]|(w^u)&2081)&65535;break}else{u=b[(c[277213]|0)+(o<<1)>>1]|0;ao=(((u&63454)+n|0)>>>1)+(u&q&2081)&65535;break}}else{q=e[(c[277225]|0)+(l<<1)>>1]|0;u=(a[(c[277215]|0)+o|0]&32)==0;if(u){n=c[277228]|0;ap=n;aq=n&-2082}else{n=e[(c[277213]|0)+(o<<1)>>1]|0;ap=n;aq=n&63454}if(u){ar=c[277228]|0}else{ar=e[(c[277213]|0)+(o<<1)>>1]|0}ao=((ar^q)&2081|e[(c[277220]|0)+((q&2081&ap)+((aq+(q&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=ao;q=(a[(c[277215]|0)+o|0]&32)==0;do{if((a[1108928]|0)==0){u=e[(c[277213]|0)+(m+12<<1)>>1]|0;n=u&63454;if(q){w=c[277228]|0;as=(e[(c[277220]|0)+((((w&-2082)+n|0)>>>1)+(u&2081&w)<<1)>>1]|(w^u)&2081)&65535;break}else{w=e[(c[277226]|0)+(l<<1)>>1]|0;as=(((w&63454)+n|0)>>>1)+(u&2081&w)&65535;break}}else{if(q){w=c[277228]|0;at=w;au=(c[277220]|0)+((w>>>1&2147482607)<<1)|0}else{w=e[(c[277226]|0)+(l<<1)>>1]|0;at=w;au=(c[277220]|0)+((w>>>1&31727)<<1)|0}as=(e[au>>1]|at&2081)&65535}}while(0);l=m+11|0;b[(c[277218]|0)+(l<<1)>>1]=as;q=a[1108909]|0;a[(c[277219]|0)+l|0]=q;a[(c[277219]|0)+o|0]=q;am=a[1108908]|0;an=c[277219]|0}else{am=ad;an=ae}}while(0);o=m+12|0;do{if((am&255)>(d[an+o|0]|0)){q=a[r+6|0]|0;l=q&255;if(q<<24>>24==0){av=am;aw=an;break}do{if((a[1108928]|0)==0){q=b[(c[277225]|0)+(l<<1)>>1]|0;w=q&65535;u=w&63454;if((a[(c[277215]|0)+o|0]&32)==0){n=c[277228]|0;ax=(e[(c[277220]|0)+((((n&-2082)+u|0)>>>1)+(w&2081&n)<<1)>>1]|(n^w)&2081)&65535;break}else{w=b[(c[277213]|0)+(o<<1)>>1]|0;ax=(((w&63454)+u|0)>>>1)+(w&q&2081)&65535;break}}else{q=e[(c[277225]|0)+(l<<1)>>1]|0;w=(a[(c[277215]|0)+o|0]&32)==0;if(w){u=c[277228]|0;ay=u;az=u&-2082}else{u=e[(c[277213]|0)+(o<<1)>>1]|0;ay=u;az=u&63454}if(w){aA=c[277228]|0}else{aA=e[(c[277213]|0)+(o<<1)>>1]|0}ax=((aA^q)&2081|e[(c[277220]|0)+((q&2081&ay)+((az+(q&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=ax;q=(a[(c[277215]|0)+o|0]&32)==0;do{if((a[1108928]|0)==0){w=e[(c[277213]|0)+(m+14<<1)>>1]|0;u=w&63454;if(q){n=c[277228]|0;aB=(e[(c[277220]|0)+((((n&-2082)+u|0)>>>1)+(w&2081&n)<<1)>>1]|(n^w)&2081)&65535;break}else{n=e[(c[277226]|0)+(l<<1)>>1]|0;aB=(((n&63454)+u|0)>>>1)+(w&2081&n)&65535;break}}else{if(q){n=c[277228]|0;aC=n;aD=(c[277220]|0)+((n>>>1&2147482607)<<1)|0}else{n=e[(c[277226]|0)+(l<<1)>>1]|0;aC=n;aD=(c[277220]|0)+((n>>>1&31727)<<1)|0}aB=(e[aD>>1]|aC&2081)&65535}}while(0);l=m+13|0;b[(c[277218]|0)+(l<<1)>>1]=aB;q=a[1108909]|0;a[(c[277219]|0)+l|0]=q;a[(c[277219]|0)+o|0]=q;av=a[1108908]|0;aw=c[277219]|0}else{av=am;aw=an}}while(0);o=m+14|0;do{if((av&255)>(d[aw+o|0]|0)){q=a[r+7|0]|0;l=q&255;if(q<<24>>24==0){break}do{if((a[1108928]|0)==0){q=b[(c[277225]|0)+(l<<1)>>1]|0;n=q&65535;w=n&63454;if((a[(c[277215]|0)+o|0]&32)==0){u=c[277228]|0;aE=(e[(c[277220]|0)+((((u&-2082)+w|0)>>>1)+(n&2081&u)<<1)>>1]|(u^n)&2081)&65535;break}else{n=b[(c[277213]|0)+(o<<1)>>1]|0;aE=(((n&63454)+w|0)>>>1)+(n&q&2081)&65535;break}}else{q=e[(c[277225]|0)+(l<<1)>>1]|0;n=(a[(c[277215]|0)+o|0]&32)==0;if(n){w=c[277228]|0;aF=w;aG=w&-2082}else{w=e[(c[277213]|0)+(o<<1)>>1]|0;aF=w;aG=w&63454}if(n){aH=c[277228]|0}else{aH=e[(c[277213]|0)+(o<<1)>>1]|0}aE=((aH^q)&2081|e[(c[277220]|0)+((q&2081&aF)+((aG+(q&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=aE;q=(a[(c[277215]|0)+o|0]&32)==0;do{if((a[1108928]|0)==0){n=e[(c[277213]|0)+(m+16<<1)>>1]|0;w=n&63454;if(q){u=c[277228]|0;aI=(e[(c[277220]|0)+((((u&-2082)+w|0)>>>1)+(n&2081&u)<<1)>>1]|(u^n)&2081)&65535;break}else{u=e[(c[277226]|0)+(l<<1)>>1]|0;aI=(((u&63454)+w|0)>>>1)+(n&2081&u)&65535;break}}else{if(q){u=c[277228]|0;aJ=u;aK=(c[277220]|0)+((u>>>1&2147482607)<<1)|0}else{u=e[(c[277226]|0)+(l<<1)>>1]|0;aJ=u;aK=(c[277220]|0)+((u>>>1&31727)<<1)|0}aI=(e[aK>>1]|aJ&2081)&65535}}while(0);l=m+15|0;b[(c[277218]|0)+(l<<1)>>1]=aI;q=a[1108909]|0;a[(c[277219]|0)+l|0]=q;a[(c[277219]|0)+o|0]=q}}while(0);o=j-1|0;if((o|0)<=0){break}r=r+8|0;j=o;m=(c[277223]|0)+m|0}return}if((f&32768|0)==0){if((i|0)<=0){return}f=p+h|0;m=i;j=g;while(1){r=a[1108908]|0;aI=c[277219]|0;do{if((r&255)>(d[aI+j|0]|0)){aJ=a[f+7|0]|0;aK=aJ&255;if(aJ<<24>>24==0){aL=r;aM=aI;break}do{if((a[1108928]|0)==0){aJ=b[(c[277225]|0)+(aK<<1)>>1]|0;aE=aJ&65535;aG=aE&63454;if((a[(c[277215]|0)+j|0]&32)==0){aF=c[277228]|0;aN=(e[(c[277220]|0)+((((aF&-2082)+aG|0)>>>1)+(aE&2081&aF)<<1)>>1]|(aF^aE)&2081)&65535;break}else{aE=b[(c[277213]|0)+(j<<1)>>1]|0;aN=(((aE&63454)+aG|0)>>>1)+(aE&aJ&2081)&65535;break}}else{aJ=e[(c[277225]|0)+(aK<<1)>>1]|0;aE=(a[(c[277215]|0)+j|0]&32)==0;if(aE){aG=c[277228]|0;aO=aG;aP=aG&-2082}else{aG=e[(c[277213]|0)+(j<<1)>>1]|0;aO=aG;aP=aG&63454}if(aE){aQ=c[277228]|0}else{aQ=e[(c[277213]|0)+(j<<1)>>1]|0}aN=((aQ^aJ)&2081|e[(c[277220]|0)+((aJ&2081&aO)+((aP+(aJ&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(j<<1)>>1]=aN;aJ=(a[(c[277215]|0)+j|0]&32)==0;do{if((a[1108928]|0)==0){aE=e[(c[277213]|0)+(j+2<<1)>>1]|0;aG=aE&63454;if(aJ){aF=c[277228]|0;aR=(e[(c[277220]|0)+((((aF&-2082)+aG|0)>>>1)+(aE&2081&aF)<<1)>>1]|(aF^aE)&2081)&65535;break}else{aF=e[(c[277226]|0)+(aK<<1)>>1]|0;aR=(((aF&63454)+aG|0)>>>1)+(aE&2081&aF)&65535;break}}else{if(aJ){aF=c[277228]|0;aS=aF;aT=(c[277220]|0)+((aF>>>1&2147482607)<<1)|0}else{aF=e[(c[277226]|0)+(aK<<1)>>1]|0;aS=aF;aT=(c[277220]|0)+((aF>>>1&31727)<<1)|0}aR=(e[aT>>1]|aS&2081)&65535}}while(0);aK=j+1|0;b[(c[277218]|0)+(aK<<1)>>1]=aR;aJ=a[1108909]|0;a[(c[277219]|0)+aK|0]=aJ;a[(c[277219]|0)+j|0]=aJ;aL=a[1108908]|0;aM=c[277219]|0}else{aL=r;aM=aI}}while(0);aI=j+2|0;do{if((aL&255)>(d[aM+aI|0]|0)){r=a[f+6|0]|0;aJ=r&255;if(r<<24>>24==0){aU=aL;aV=aM;break}do{if((a[1108928]|0)==0){r=b[(c[277225]|0)+(aJ<<1)>>1]|0;aK=r&65535;aF=aK&63454;if((a[(c[277215]|0)+aI|0]&32)==0){aE=c[277228]|0;aW=(e[(c[277220]|0)+((((aE&-2082)+aF|0)>>>1)+(aK&2081&aE)<<1)>>1]|(aE^aK)&2081)&65535;break}else{aK=b[(c[277213]|0)+(aI<<1)>>1]|0;aW=(((aK&63454)+aF|0)>>>1)+(aK&r&2081)&65535;break}}else{r=e[(c[277225]|0)+(aJ<<1)>>1]|0;aK=(a[(c[277215]|0)+aI|0]&32)==0;if(aK){aF=c[277228]|0;aX=aF;aY=aF&-2082}else{aF=e[(c[277213]|0)+(aI<<1)>>1]|0;aX=aF;aY=aF&63454}if(aK){aZ=c[277228]|0}else{aZ=e[(c[277213]|0)+(aI<<1)>>1]|0}aW=((aZ^r)&2081|e[(c[277220]|0)+((r&2081&aX)+((aY+(r&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(aI<<1)>>1]=aW;r=(a[(c[277215]|0)+aI|0]&32)==0;do{if((a[1108928]|0)==0){aK=e[(c[277213]|0)+(j+4<<1)>>1]|0;aF=aK&63454;if(r){aE=c[277228]|0;a_=(e[(c[277220]|0)+((((aE&-2082)+aF|0)>>>1)+(aK&2081&aE)<<1)>>1]|(aE^aK)&2081)&65535;break}else{aE=e[(c[277226]|0)+(aJ<<1)>>1]|0;a_=(((aE&63454)+aF|0)>>>1)+(aK&2081&aE)&65535;break}}else{if(r){aE=c[277228]|0;a$=aE;a0=(c[277220]|0)+((aE>>>1&2147482607)<<1)|0}else{aE=e[(c[277226]|0)+(aJ<<1)>>1]|0;a$=aE;a0=(c[277220]|0)+((aE>>>1&31727)<<1)|0}a_=(e[a0>>1]|a$&2081)&65535}}while(0);aJ=j+3|0;b[(c[277218]|0)+(aJ<<1)>>1]=a_;r=a[1108909]|0;a[(c[277219]|0)+aJ|0]=r;a[(c[277219]|0)+aI|0]=r;aU=a[1108908]|0;aV=c[277219]|0}else{aU=aL;aV=aM}}while(0);aI=j+4|0;do{if((aU&255)>(d[aV+aI|0]|0)){r=a[f+5|0]|0;aJ=r&255;if(r<<24>>24==0){a1=aU;a2=aV;break}do{if((a[1108928]|0)==0){r=b[(c[277225]|0)+(aJ<<1)>>1]|0;aE=r&65535;aK=aE&63454;if((a[(c[277215]|0)+aI|0]&32)==0){aF=c[277228]|0;a3=(e[(c[277220]|0)+((((aF&-2082)+aK|0)>>>1)+(aE&2081&aF)<<1)>>1]|(aF^aE)&2081)&65535;break}else{aE=b[(c[277213]|0)+(aI<<1)>>1]|0;a3=(((aE&63454)+aK|0)>>>1)+(aE&r&2081)&65535;break}}else{r=e[(c[277225]|0)+(aJ<<1)>>1]|0;aE=(a[(c[277215]|0)+aI|0]&32)==0;if(aE){aK=c[277228]|0;a4=aK;a5=aK&-2082}else{aK=e[(c[277213]|0)+(aI<<1)>>1]|0;a4=aK;a5=aK&63454}if(aE){a6=c[277228]|0}else{a6=e[(c[277213]|0)+(aI<<1)>>1]|0}a3=((a6^r)&2081|e[(c[277220]|0)+((r&2081&a4)+((a5+(r&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(aI<<1)>>1]=a3;r=(a[(c[277215]|0)+aI|0]&32)==0;do{if((a[1108928]|0)==0){aE=e[(c[277213]|0)+(j+6<<1)>>1]|0;aK=aE&63454;if(r){aF=c[277228]|0;a7=(e[(c[277220]|0)+((((aF&-2082)+aK|0)>>>1)+(aE&2081&aF)<<1)>>1]|(aF^aE)&2081)&65535;break}else{aF=e[(c[277226]|0)+(aJ<<1)>>1]|0;a7=(((aF&63454)+aK|0)>>>1)+(aE&2081&aF)&65535;break}}else{if(r){aF=c[277228]|0;a8=aF;a9=(c[277220]|0)+((aF>>>1&2147482607)<<1)|0}else{aF=e[(c[277226]|0)+(aJ<<1)>>1]|0;a8=aF;a9=(c[277220]|0)+((aF>>>1&31727)<<1)|0}a7=(e[a9>>1]|a8&2081)&65535}}while(0);aJ=j+5|0;b[(c[277218]|0)+(aJ<<1)>>1]=a7;r=a[1108909]|0;a[(c[277219]|0)+aJ|0]=r;a[(c[277219]|0)+aI|0]=r;a1=a[1108908]|0;a2=c[277219]|0}else{a1=aU;a2=aV}}while(0);aI=j+6|0;do{if((a1&255)>(d[a2+aI|0]|0)){r=a[f+4|0]|0;aJ=r&255;if(r<<24>>24==0){ba=a1;bb=a2;break}do{if((a[1108928]|0)==0){r=b[(c[277225]|0)+(aJ<<1)>>1]|0;aF=r&65535;aE=aF&63454;if((a[(c[277215]|0)+aI|0]&32)==0){aK=c[277228]|0;bc=(e[(c[277220]|0)+((((aK&-2082)+aE|0)>>>1)+(aF&2081&aK)<<1)>>1]|(aK^aF)&2081)&65535;break}else{aF=b[(c[277213]|0)+(aI<<1)>>1]|0;bc=(((aF&63454)+aE|0)>>>1)+(aF&r&2081)&65535;break}}else{r=e[(c[277225]|0)+(aJ<<1)>>1]|0;aF=(a[(c[277215]|0)+aI|0]&32)==0;if(aF){aE=c[277228]|0;bd=aE;be=aE&-2082}else{aE=e[(c[277213]|0)+(aI<<1)>>1]|0;bd=aE;be=aE&63454}if(aF){bf=c[277228]|0}else{bf=e[(c[277213]|0)+(aI<<1)>>1]|0}bc=((bf^r)&2081|e[(c[277220]|0)+((r&2081&bd)+((be+(r&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(aI<<1)>>1]=bc;r=(a[(c[277215]|0)+aI|0]&32)==0;do{if((a[1108928]|0)==0){aF=e[(c[277213]|0)+(j+8<<1)>>1]|0;aE=aF&63454;if(r){aK=c[277228]|0;bg=(e[(c[277220]|0)+((((aK&-2082)+aE|0)>>>1)+(aF&2081&aK)<<1)>>1]|(aK^aF)&2081)&65535;break}else{aK=e[(c[277226]|0)+(aJ<<1)>>1]|0;bg=(((aK&63454)+aE|0)>>>1)+(aF&2081&aK)&65535;break}}else{if(r){aK=c[277228]|0;bh=aK;bi=(c[277220]|0)+((aK>>>1&2147482607)<<1)|0}else{aK=e[(c[277226]|0)+(aJ<<1)>>1]|0;bh=aK;bi=(c[277220]|0)+((aK>>>1&31727)<<1)|0}bg=(e[bi>>1]|bh&2081)&65535}}while(0);aJ=j+7|0;b[(c[277218]|0)+(aJ<<1)>>1]=bg;r=a[1108909]|0;a[(c[277219]|0)+aJ|0]=r;a[(c[277219]|0)+aI|0]=r;ba=a[1108908]|0;bb=c[277219]|0}else{ba=a1;bb=a2}}while(0);aI=j+8|0;do{if((ba&255)>(d[bb+aI|0]|0)){r=a[f+3|0]|0;aJ=r&255;if(r<<24>>24==0){bj=ba;bk=bb;break}do{if((a[1108928]|0)==0){r=b[(c[277225]|0)+(aJ<<1)>>1]|0;aK=r&65535;aF=aK&63454;if((a[(c[277215]|0)+aI|0]&32)==0){aE=c[277228]|0;bl=(e[(c[277220]|0)+((((aE&-2082)+aF|0)>>>1)+(aK&2081&aE)<<1)>>1]|(aE^aK)&2081)&65535;break}else{aK=b[(c[277213]|0)+(aI<<1)>>1]|0;bl=(((aK&63454)+aF|0)>>>1)+(aK&r&2081)&65535;break}}else{r=e[(c[277225]|0)+(aJ<<1)>>1]|0;aK=(a[(c[277215]|0)+aI|0]&32)==0;if(aK){aF=c[277228]|0;bm=aF;bn=aF&-2082}else{aF=e[(c[277213]|0)+(aI<<1)>>1]|0;bm=aF;bn=aF&63454}if(aK){bo=c[277228]|0}else{bo=e[(c[277213]|0)+(aI<<1)>>1]|0}bl=((bo^r)&2081|e[(c[277220]|0)+((r&2081&bm)+((bn+(r&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(aI<<1)>>1]=bl;r=(a[(c[277215]|0)+aI|0]&32)==0;do{if((a[1108928]|0)==0){aK=e[(c[277213]|0)+(j+10<<1)>>1]|0;aF=aK&63454;if(r){aE=c[277228]|0;bp=(e[(c[277220]|0)+((((aE&-2082)+aF|0)>>>1)+(aK&2081&aE)<<1)>>1]|(aE^aK)&2081)&65535;break}else{aE=e[(c[277226]|0)+(aJ<<1)>>1]|0;bp=(((aE&63454)+aF|0)>>>1)+(aK&2081&aE)&65535;break}}else{if(r){aE=c[277228]|0;bq=aE;br=(c[277220]|0)+((aE>>>1&2147482607)<<1)|0}else{aE=e[(c[277226]|0)+(aJ<<1)>>1]|0;bq=aE;br=(c[277220]|0)+((aE>>>1&31727)<<1)|0}bp=(e[br>>1]|bq&2081)&65535}}while(0);aJ=j+9|0;b[(c[277218]|0)+(aJ<<1)>>1]=bp;r=a[1108909]|0;a[(c[277219]|0)+aJ|0]=r;a[(c[277219]|0)+aI|0]=r;bj=a[1108908]|0;bk=c[277219]|0}else{bj=ba;bk=bb}}while(0);aI=j+10|0;do{if((bj&255)>(d[bk+aI|0]|0)){r=a[f+2|0]|0;aJ=r&255;if(r<<24>>24==0){bs=bj;bt=bk;break}do{if((a[1108928]|0)==0){r=b[(c[277225]|0)+(aJ<<1)>>1]|0;aE=r&65535;aK=aE&63454;if((a[(c[277215]|0)+aI|0]&32)==0){aF=c[277228]|0;bu=(e[(c[277220]|0)+((((aF&-2082)+aK|0)>>>1)+(aE&2081&aF)<<1)>>1]|(aF^aE)&2081)&65535;break}else{aE=b[(c[277213]|0)+(aI<<1)>>1]|0;bu=(((aE&63454)+aK|0)>>>1)+(aE&r&2081)&65535;break}}else{r=e[(c[277225]|0)+(aJ<<1)>>1]|0;aE=(a[(c[277215]|0)+aI|0]&32)==0;if(aE){aK=c[277228]|0;bv=aK;bw=aK&-2082}else{aK=e[(c[277213]|0)+(aI<<1)>>1]|0;bv=aK;bw=aK&63454}if(aE){bx=c[277228]|0}else{bx=e[(c[277213]|0)+(aI<<1)>>1]|0}bu=((bx^r)&2081|e[(c[277220]|0)+((r&2081&bv)+((bw+(r&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(aI<<1)>>1]=bu;r=(a[(c[277215]|0)+aI|0]&32)==0;do{if((a[1108928]|0)==0){aE=e[(c[277213]|0)+(j+12<<1)>>1]|0;aK=aE&63454;if(r){aF=c[277228]|0;by=(e[(c[277220]|0)+((((aF&-2082)+aK|0)>>>1)+(aE&2081&aF)<<1)>>1]|(aF^aE)&2081)&65535;break}else{aF=e[(c[277226]|0)+(aJ<<1)>>1]|0;by=(((aF&63454)+aK|0)>>>1)+(aE&2081&aF)&65535;break}}else{if(r){aF=c[277228]|0;bz=aF;bA=(c[277220]|0)+((aF>>>1&2147482607)<<1)|0}else{aF=e[(c[277226]|0)+(aJ<<1)>>1]|0;bz=aF;bA=(c[277220]|0)+((aF>>>1&31727)<<1)|0}by=(e[bA>>1]|bz&2081)&65535}}while(0);aJ=j+11|0;b[(c[277218]|0)+(aJ<<1)>>1]=by;r=a[1108909]|0;a[(c[277219]|0)+aJ|0]=r;a[(c[277219]|0)+aI|0]=r;bs=a[1108908]|0;bt=c[277219]|0}else{bs=bj;bt=bk}}while(0);aI=j+12|0;do{if((bs&255)>(d[bt+aI|0]|0)){r=a[f+1|0]|0;aJ=r&255;if(r<<24>>24==0){bB=bs;bC=bt;break}do{if((a[1108928]|0)==0){r=b[(c[277225]|0)+(aJ<<1)>>1]|0;aF=r&65535;aE=aF&63454;if((a[(c[277215]|0)+aI|0]&32)==0){aK=c[277228]|0;bD=(e[(c[277220]|0)+((((aK&-2082)+aE|0)>>>1)+(aF&2081&aK)<<1)>>1]|(aK^aF)&2081)&65535;break}else{aF=b[(c[277213]|0)+(aI<<1)>>1]|0;bD=(((aF&63454)+aE|0)>>>1)+(aF&r&2081)&65535;break}}else{r=e[(c[277225]|0)+(aJ<<1)>>1]|0;aF=(a[(c[277215]|0)+aI|0]&32)==0;if(aF){aE=c[277228]|0;bE=aE;bF=aE&-2082}else{aE=e[(c[277213]|0)+(aI<<1)>>1]|0;bE=aE;bF=aE&63454}if(aF){bG=c[277228]|0}else{bG=e[(c[277213]|0)+(aI<<1)>>1]|0}bD=((bG^r)&2081|e[(c[277220]|0)+((r&2081&bE)+((bF+(r&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(aI<<1)>>1]=bD;r=(a[(c[277215]|0)+aI|0]&32)==0;do{if((a[1108928]|0)==0){aF=e[(c[277213]|0)+(j+14<<1)>>1]|0;aE=aF&63454;if(r){aK=c[277228]|0;bH=(e[(c[277220]|0)+((((aK&-2082)+aE|0)>>>1)+(aF&2081&aK)<<1)>>1]|(aK^aF)&2081)&65535;break}else{aK=e[(c[277226]|0)+(aJ<<1)>>1]|0;bH=(((aK&63454)+aE|0)>>>1)+(aF&2081&aK)&65535;break}}else{if(r){aK=c[277228]|0;bI=aK;bJ=(c[277220]|0)+((aK>>>1&2147482607)<<1)|0}else{aK=e[(c[277226]|0)+(aJ<<1)>>1]|0;bI=aK;bJ=(c[277220]|0)+((aK>>>1&31727)<<1)|0}bH=(e[bJ>>1]|bI&2081)&65535}}while(0);aJ=j+13|0;b[(c[277218]|0)+(aJ<<1)>>1]=bH;r=a[1108909]|0;a[(c[277219]|0)+aJ|0]=r;a[(c[277219]|0)+aI|0]=r;bB=a[1108908]|0;bC=c[277219]|0}else{bB=bs;bC=bt}}while(0);aI=j+14|0;do{if((bB&255)>(d[bC+aI|0]|0)){r=a[f]|0;aJ=r&255;if(r<<24>>24==0){break}do{if((a[1108928]|0)==0){r=b[(c[277225]|0)+(aJ<<1)>>1]|0;aK=r&65535;aF=aK&63454;if((a[(c[277215]|0)+aI|0]&32)==0){aE=c[277228]|0;bK=(e[(c[277220]|0)+((((aE&-2082)+aF|0)>>>1)+(aK&2081&aE)<<1)>>1]|(aE^aK)&2081)&65535;break}else{aK=b[(c[277213]|0)+(aI<<1)>>1]|0;bK=(((aK&63454)+aF|0)>>>1)+(aK&r&2081)&65535;break}}else{r=e[(c[277225]|0)+(aJ<<1)>>1]|0;aK=(a[(c[277215]|0)+aI|0]&32)==0;if(aK){aF=c[277228]|0;bL=aF;bM=aF&-2082}else{aF=e[(c[277213]|0)+(aI<<1)>>1]|0;bL=aF;bM=aF&63454}if(aK){bN=c[277228]|0}else{bN=e[(c[277213]|0)+(aI<<1)>>1]|0}bK=((bN^r)&2081|e[(c[277220]|0)+((r&2081&bL)+((bM+(r&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(aI<<1)>>1]=bK;r=(a[(c[277215]|0)+aI|0]&32)==0;do{if((a[1108928]|0)==0){aK=e[(c[277213]|0)+(j+16<<1)>>1]|0;aF=aK&63454;if(r){aE=c[277228]|0;bO=(e[(c[277220]|0)+((((aE&-2082)+aF|0)>>>1)+(aK&2081&aE)<<1)>>1]|(aE^aK)&2081)&65535;break}else{aE=e[(c[277226]|0)+(aJ<<1)>>1]|0;bO=(((aE&63454)+aF|0)>>>1)+(aK&2081&aE)&65535;break}}else{if(r){aE=c[277228]|0;bP=aE;bQ=(c[277220]|0)+((aE>>>1&2147482607)<<1)|0}else{aE=e[(c[277226]|0)+(aJ<<1)>>1]|0;bP=aE;bQ=(c[277220]|0)+((aE>>>1&31727)<<1)|0}bO=(e[bQ>>1]|bP&2081)&65535}}while(0);aJ=j+15|0;b[(c[277218]|0)+(aJ<<1)>>1]=bO;r=a[1108909]|0;a[(c[277219]|0)+aJ|0]=r;a[(c[277219]|0)+aI|0]=r}}while(0);aI=m-1|0;if((aI|0)<=0){break}f=f+8|0;m=aI;j=(c[277223]|0)+j|0}return}j=p+(56-h)|0;h=(i|0)>0;if(k){if(h){bR=j;bS=i;bT=g}else{return}while(1){k=a[1108908]|0;p=c[277219]|0;do{if((k&255)>(d[p+bT|0]|0)){m=a[bR+7|0]|0;f=m&255;if(m<<24>>24==0){bU=k;bV=p;break}do{if((a[1108928]|0)==0){m=b[(c[277225]|0)+(f<<1)>>1]|0;bO=m&65535;bP=bO&63454;if((a[(c[277215]|0)+bT|0]&32)==0){bQ=c[277228]|0;bW=(e[(c[277220]|0)+((((bQ&-2082)+bP|0)>>>1)+(bO&2081&bQ)<<1)>>1]|(bQ^bO)&2081)&65535;break}else{bO=b[(c[277213]|0)+(bT<<1)>>1]|0;bW=(((bO&63454)+bP|0)>>>1)+(bO&m&2081)&65535;break}}else{m=e[(c[277225]|0)+(f<<1)>>1]|0;bO=(a[(c[277215]|0)+bT|0]&32)==0;if(bO){bP=c[277228]|0;bX=bP;bY=bP&-2082}else{bP=e[(c[277213]|0)+(bT<<1)>>1]|0;bX=bP;bY=bP&63454}if(bO){bZ=c[277228]|0}else{bZ=e[(c[277213]|0)+(bT<<1)>>1]|0}bW=((bZ^m)&2081|e[(c[277220]|0)+((m&2081&bX)+((bY+(m&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(bT<<1)>>1]=bW;m=(a[(c[277215]|0)+bT|0]&32)==0;do{if((a[1108928]|0)==0){bO=e[(c[277213]|0)+(bT+2<<1)>>1]|0;bP=bO&63454;if(m){bQ=c[277228]|0;b_=(e[(c[277220]|0)+((((bQ&-2082)+bP|0)>>>1)+(bO&2081&bQ)<<1)>>1]|(bQ^bO)&2081)&65535;break}else{bQ=e[(c[277226]|0)+(f<<1)>>1]|0;b_=(((bQ&63454)+bP|0)>>>1)+(bO&2081&bQ)&65535;break}}else{if(m){bQ=c[277228]|0;b$=bQ;b0=(c[277220]|0)+((bQ>>>1&2147482607)<<1)|0}else{bQ=e[(c[277226]|0)+(f<<1)>>1]|0;b$=bQ;b0=(c[277220]|0)+((bQ>>>1&31727)<<1)|0}b_=(e[b0>>1]|b$&2081)&65535}}while(0);f=bT+1|0;b[(c[277218]|0)+(f<<1)>>1]=b_;m=a[1108909]|0;a[(c[277219]|0)+f|0]=m;a[(c[277219]|0)+bT|0]=m;bU=a[1108908]|0;bV=c[277219]|0}else{bU=k;bV=p}}while(0);p=bT+2|0;do{if((bU&255)>(d[bV+p|0]|0)){k=a[bR+6|0]|0;m=k&255;if(k<<24>>24==0){b1=bU;b2=bV;break}do{if((a[1108928]|0)==0){k=b[(c[277225]|0)+(m<<1)>>1]|0;f=k&65535;bQ=f&63454;if((a[(c[277215]|0)+p|0]&32)==0){bO=c[277228]|0;b3=(e[(c[277220]|0)+((((bO&-2082)+bQ|0)>>>1)+(f&2081&bO)<<1)>>1]|(bO^f)&2081)&65535;break}else{f=b[(c[277213]|0)+(p<<1)>>1]|0;b3=(((f&63454)+bQ|0)>>>1)+(f&k&2081)&65535;break}}else{k=e[(c[277225]|0)+(m<<1)>>1]|0;f=(a[(c[277215]|0)+p|0]&32)==0;if(f){bQ=c[277228]|0;b4=bQ;b5=bQ&-2082}else{bQ=e[(c[277213]|0)+(p<<1)>>1]|0;b4=bQ;b5=bQ&63454}if(f){b6=c[277228]|0}else{b6=e[(c[277213]|0)+(p<<1)>>1]|0}b3=((b6^k)&2081|e[(c[277220]|0)+((k&2081&b4)+((b5+(k&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=b3;k=(a[(c[277215]|0)+p|0]&32)==0;do{if((a[1108928]|0)==0){f=e[(c[277213]|0)+(bT+4<<1)>>1]|0;bQ=f&63454;if(k){bO=c[277228]|0;b7=(e[(c[277220]|0)+((((bO&-2082)+bQ|0)>>>1)+(f&2081&bO)<<1)>>1]|(bO^f)&2081)&65535;break}else{bO=e[(c[277226]|0)+(m<<1)>>1]|0;b7=(((bO&63454)+bQ|0)>>>1)+(f&2081&bO)&65535;break}}else{if(k){bO=c[277228]|0;b8=bO;b9=(c[277220]|0)+((bO>>>1&2147482607)<<1)|0}else{bO=e[(c[277226]|0)+(m<<1)>>1]|0;b8=bO;b9=(c[277220]|0)+((bO>>>1&31727)<<1)|0}b7=(e[b9>>1]|b8&2081)&65535}}while(0);m=bT+3|0;b[(c[277218]|0)+(m<<1)>>1]=b7;k=a[1108909]|0;a[(c[277219]|0)+m|0]=k;a[(c[277219]|0)+p|0]=k;b1=a[1108908]|0;b2=c[277219]|0}else{b1=bU;b2=bV}}while(0);p=bT+4|0;do{if((b1&255)>(d[b2+p|0]|0)){k=a[bR+5|0]|0;m=k&255;if(k<<24>>24==0){ca=b1;cb=b2;break}do{if((a[1108928]|0)==0){k=b[(c[277225]|0)+(m<<1)>>1]|0;bO=k&65535;f=bO&63454;if((a[(c[277215]|0)+p|0]&32)==0){bQ=c[277228]|0;cc=(e[(c[277220]|0)+((((bQ&-2082)+f|0)>>>1)+(bO&2081&bQ)<<1)>>1]|(bQ^bO)&2081)&65535;break}else{bO=b[(c[277213]|0)+(p<<1)>>1]|0;cc=(((bO&63454)+f|0)>>>1)+(bO&k&2081)&65535;break}}else{k=e[(c[277225]|0)+(m<<1)>>1]|0;bO=(a[(c[277215]|0)+p|0]&32)==0;if(bO){f=c[277228]|0;cd=f;ce=f&-2082}else{f=e[(c[277213]|0)+(p<<1)>>1]|0;cd=f;ce=f&63454}if(bO){cf=c[277228]|0}else{cf=e[(c[277213]|0)+(p<<1)>>1]|0}cc=((cf^k)&2081|e[(c[277220]|0)+((k&2081&cd)+((ce+(k&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=cc;k=(a[(c[277215]|0)+p|0]&32)==0;do{if((a[1108928]|0)==0){bO=e[(c[277213]|0)+(bT+6<<1)>>1]|0;f=bO&63454;if(k){bQ=c[277228]|0;cg=(e[(c[277220]|0)+((((bQ&-2082)+f|0)>>>1)+(bO&2081&bQ)<<1)>>1]|(bQ^bO)&2081)&65535;break}else{bQ=e[(c[277226]|0)+(m<<1)>>1]|0;cg=(((bQ&63454)+f|0)>>>1)+(bO&2081&bQ)&65535;break}}else{if(k){bQ=c[277228]|0;ch=bQ;ci=(c[277220]|0)+((bQ>>>1&2147482607)<<1)|0}else{bQ=e[(c[277226]|0)+(m<<1)>>1]|0;ch=bQ;ci=(c[277220]|0)+((bQ>>>1&31727)<<1)|0}cg=(e[ci>>1]|ch&2081)&65535}}while(0);m=bT+5|0;b[(c[277218]|0)+(m<<1)>>1]=cg;k=a[1108909]|0;a[(c[277219]|0)+m|0]=k;a[(c[277219]|0)+p|0]=k;ca=a[1108908]|0;cb=c[277219]|0}else{ca=b1;cb=b2}}while(0);p=bT+6|0;do{if((ca&255)>(d[cb+p|0]|0)){k=a[bR+4|0]|0;m=k&255;if(k<<24>>24==0){cj=ca;ck=cb;break}do{if((a[1108928]|0)==0){k=b[(c[277225]|0)+(m<<1)>>1]|0;bQ=k&65535;bO=bQ&63454;if((a[(c[277215]|0)+p|0]&32)==0){f=c[277228]|0;cl=(e[(c[277220]|0)+((((f&-2082)+bO|0)>>>1)+(bQ&2081&f)<<1)>>1]|(f^bQ)&2081)&65535;break}else{bQ=b[(c[277213]|0)+(p<<1)>>1]|0;cl=(((bQ&63454)+bO|0)>>>1)+(bQ&k&2081)&65535;break}}else{k=e[(c[277225]|0)+(m<<1)>>1]|0;bQ=(a[(c[277215]|0)+p|0]&32)==0;if(bQ){bO=c[277228]|0;cm=bO;cn=bO&-2082}else{bO=e[(c[277213]|0)+(p<<1)>>1]|0;cm=bO;cn=bO&63454}if(bQ){co=c[277228]|0}else{co=e[(c[277213]|0)+(p<<1)>>1]|0}cl=((co^k)&2081|e[(c[277220]|0)+((k&2081&cm)+((cn+(k&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=cl;k=(a[(c[277215]|0)+p|0]&32)==0;do{if((a[1108928]|0)==0){bQ=e[(c[277213]|0)+(bT+8<<1)>>1]|0;bO=bQ&63454;if(k){f=c[277228]|0;cp=(e[(c[277220]|0)+((((f&-2082)+bO|0)>>>1)+(bQ&2081&f)<<1)>>1]|(f^bQ)&2081)&65535;break}else{f=e[(c[277226]|0)+(m<<1)>>1]|0;cp=(((f&63454)+bO|0)>>>1)+(bQ&2081&f)&65535;break}}else{if(k){f=c[277228]|0;cq=f;cr=(c[277220]|0)+((f>>>1&2147482607)<<1)|0}else{f=e[(c[277226]|0)+(m<<1)>>1]|0;cq=f;cr=(c[277220]|0)+((f>>>1&31727)<<1)|0}cp=(e[cr>>1]|cq&2081)&65535}}while(0);m=bT+7|0;b[(c[277218]|0)+(m<<1)>>1]=cp;k=a[1108909]|0;a[(c[277219]|0)+m|0]=k;a[(c[277219]|0)+p|0]=k;cj=a[1108908]|0;ck=c[277219]|0}else{cj=ca;ck=cb}}while(0);p=bT+8|0;do{if((cj&255)>(d[ck+p|0]|0)){k=a[bR+3|0]|0;m=k&255;if(k<<24>>24==0){cs=cj;ct=ck;break}do{if((a[1108928]|0)==0){k=b[(c[277225]|0)+(m<<1)>>1]|0;f=k&65535;bQ=f&63454;if((a[(c[277215]|0)+p|0]&32)==0){bO=c[277228]|0;cu=(e[(c[277220]|0)+((((bO&-2082)+bQ|0)>>>1)+(f&2081&bO)<<1)>>1]|(bO^f)&2081)&65535;break}else{f=b[(c[277213]|0)+(p<<1)>>1]|0;cu=(((f&63454)+bQ|0)>>>1)+(f&k&2081)&65535;break}}else{k=e[(c[277225]|0)+(m<<1)>>1]|0;f=(a[(c[277215]|0)+p|0]&32)==0;if(f){bQ=c[277228]|0;cv=bQ;cw=bQ&-2082}else{bQ=e[(c[277213]|0)+(p<<1)>>1]|0;cv=bQ;cw=bQ&63454}if(f){cx=c[277228]|0}else{cx=e[(c[277213]|0)+(p<<1)>>1]|0}cu=((cx^k)&2081|e[(c[277220]|0)+((k&2081&cv)+((cw+(k&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=cu;k=(a[(c[277215]|0)+p|0]&32)==0;do{if((a[1108928]|0)==0){f=e[(c[277213]|0)+(bT+10<<1)>>1]|0;bQ=f&63454;if(k){bO=c[277228]|0;cy=(e[(c[277220]|0)+((((bO&-2082)+bQ|0)>>>1)+(f&2081&bO)<<1)>>1]|(bO^f)&2081)&65535;break}else{bO=e[(c[277226]|0)+(m<<1)>>1]|0;cy=(((bO&63454)+bQ|0)>>>1)+(f&2081&bO)&65535;break}}else{if(k){bO=c[277228]|0;cz=bO;cA=(c[277220]|0)+((bO>>>1&2147482607)<<1)|0}else{bO=e[(c[277226]|0)+(m<<1)>>1]|0;cz=bO;cA=(c[277220]|0)+((bO>>>1&31727)<<1)|0}cy=(e[cA>>1]|cz&2081)&65535}}while(0);m=bT+9|0;b[(c[277218]|0)+(m<<1)>>1]=cy;k=a[1108909]|0;a[(c[277219]|0)+m|0]=k;a[(c[277219]|0)+p|0]=k;cs=a[1108908]|0;ct=c[277219]|0}else{cs=cj;ct=ck}}while(0);p=bT+10|0;do{if((cs&255)>(d[ct+p|0]|0)){k=a[bR+2|0]|0;m=k&255;if(k<<24>>24==0){cB=cs;cC=ct;break}do{if((a[1108928]|0)==0){k=b[(c[277225]|0)+(m<<1)>>1]|0;bO=k&65535;f=bO&63454;if((a[(c[277215]|0)+p|0]&32)==0){bQ=c[277228]|0;cD=(e[(c[277220]|0)+((((bQ&-2082)+f|0)>>>1)+(bO&2081&bQ)<<1)>>1]|(bQ^bO)&2081)&65535;break}else{bO=b[(c[277213]|0)+(p<<1)>>1]|0;cD=(((bO&63454)+f|0)>>>1)+(bO&k&2081)&65535;break}}else{k=e[(c[277225]|0)+(m<<1)>>1]|0;bO=(a[(c[277215]|0)+p|0]&32)==0;if(bO){f=c[277228]|0;cE=f;cF=f&-2082}else{f=e[(c[277213]|0)+(p<<1)>>1]|0;cE=f;cF=f&63454}if(bO){cG=c[277228]|0}else{cG=e[(c[277213]|0)+(p<<1)>>1]|0}cD=((cG^k)&2081|e[(c[277220]|0)+((k&2081&cE)+((cF+(k&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=cD;k=(a[(c[277215]|0)+p|0]&32)==0;do{if((a[1108928]|0)==0){bO=e[(c[277213]|0)+(bT+12<<1)>>1]|0;f=bO&63454;if(k){bQ=c[277228]|0;cH=(e[(c[277220]|0)+((((bQ&-2082)+f|0)>>>1)+(bO&2081&bQ)<<1)>>1]|(bQ^bO)&2081)&65535;break}else{bQ=e[(c[277226]|0)+(m<<1)>>1]|0;cH=(((bQ&63454)+f|0)>>>1)+(bO&2081&bQ)&65535;break}}else{if(k){bQ=c[277228]|0;cI=bQ;cJ=(c[277220]|0)+((bQ>>>1&2147482607)<<1)|0}else{bQ=e[(c[277226]|0)+(m<<1)>>1]|0;cI=bQ;cJ=(c[277220]|0)+((bQ>>>1&31727)<<1)|0}cH=(e[cJ>>1]|cI&2081)&65535}}while(0);m=bT+11|0;b[(c[277218]|0)+(m<<1)>>1]=cH;k=a[1108909]|0;a[(c[277219]|0)+m|0]=k;a[(c[277219]|0)+p|0]=k;cB=a[1108908]|0;cC=c[277219]|0}else{cB=cs;cC=ct}}while(0);p=bT+12|0;do{if((cB&255)>(d[cC+p|0]|0)){k=a[bR+1|0]|0;m=k&255;if(k<<24>>24==0){cK=cB;cL=cC;break}do{if((a[1108928]|0)==0){k=b[(c[277225]|0)+(m<<1)>>1]|0;bQ=k&65535;bO=bQ&63454;if((a[(c[277215]|0)+p|0]&32)==0){f=c[277228]|0;cM=(e[(c[277220]|0)+((((f&-2082)+bO|0)>>>1)+(bQ&2081&f)<<1)>>1]|(f^bQ)&2081)&65535;break}else{bQ=b[(c[277213]|0)+(p<<1)>>1]|0;cM=(((bQ&63454)+bO|0)>>>1)+(bQ&k&2081)&65535;break}}else{k=e[(c[277225]|0)+(m<<1)>>1]|0;bQ=(a[(c[277215]|0)+p|0]&32)==0;if(bQ){bO=c[277228]|0;cN=bO;cO=bO&-2082}else{bO=e[(c[277213]|0)+(p<<1)>>1]|0;cN=bO;cO=bO&63454}if(bQ){cP=c[277228]|0}else{cP=e[(c[277213]|0)+(p<<1)>>1]|0}cM=((cP^k)&2081|e[(c[277220]|0)+((k&2081&cN)+((cO+(k&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=cM;k=(a[(c[277215]|0)+p|0]&32)==0;do{if((a[1108928]|0)==0){bQ=e[(c[277213]|0)+(bT+14<<1)>>1]|0;bO=bQ&63454;if(k){f=c[277228]|0;cQ=(e[(c[277220]|0)+((((f&-2082)+bO|0)>>>1)+(bQ&2081&f)<<1)>>1]|(f^bQ)&2081)&65535;break}else{f=e[(c[277226]|0)+(m<<1)>>1]|0;cQ=(((f&63454)+bO|0)>>>1)+(bQ&2081&f)&65535;break}}else{if(k){f=c[277228]|0;cR=f;cS=(c[277220]|0)+((f>>>1&2147482607)<<1)|0}else{f=e[(c[277226]|0)+(m<<1)>>1]|0;cR=f;cS=(c[277220]|0)+((f>>>1&31727)<<1)|0}cQ=(e[cS>>1]|cR&2081)&65535}}while(0);m=bT+13|0;b[(c[277218]|0)+(m<<1)>>1]=cQ;k=a[1108909]|0;a[(c[277219]|0)+m|0]=k;a[(c[277219]|0)+p|0]=k;cK=a[1108908]|0;cL=c[277219]|0}else{cK=cB;cL=cC}}while(0);p=bT+14|0;do{if((cK&255)>(d[cL+p|0]|0)){k=a[bR]|0;m=k&255;if(k<<24>>24==0){break}do{if((a[1108928]|0)==0){k=b[(c[277225]|0)+(m<<1)>>1]|0;f=k&65535;bQ=f&63454;if((a[(c[277215]|0)+p|0]&32)==0){bO=c[277228]|0;cT=(e[(c[277220]|0)+((((bO&-2082)+bQ|0)>>>1)+(f&2081&bO)<<1)>>1]|(bO^f)&2081)&65535;break}else{f=b[(c[277213]|0)+(p<<1)>>1]|0;cT=(((f&63454)+bQ|0)>>>1)+(f&k&2081)&65535;break}}else{k=e[(c[277225]|0)+(m<<1)>>1]|0;f=(a[(c[277215]|0)+p|0]&32)==0;if(f){bQ=c[277228]|0;cU=bQ;cV=bQ&-2082}else{bQ=e[(c[277213]|0)+(p<<1)>>1]|0;cU=bQ;cV=bQ&63454}if(f){cW=c[277228]|0}else{cW=e[(c[277213]|0)+(p<<1)>>1]|0}cT=((cW^k)&2081|e[(c[277220]|0)+((k&2081&cU)+((cV+(k&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=cT;k=(a[(c[277215]|0)+p|0]&32)==0;do{if((a[1108928]|0)==0){f=e[(c[277213]|0)+(bT+16<<1)>>1]|0;bQ=f&63454;if(k){bO=c[277228]|0;cX=(e[(c[277220]|0)+((((bO&-2082)+bQ|0)>>>1)+(f&2081&bO)<<1)>>1]|(bO^f)&2081)&65535;break}else{bO=e[(c[277226]|0)+(m<<1)>>1]|0;cX=(((bO&63454)+bQ|0)>>>1)+(f&2081&bO)&65535;break}}else{if(k){bO=c[277228]|0;cY=bO;cZ=(c[277220]|0)+((bO>>>1&2147482607)<<1)|0}else{bO=e[(c[277226]|0)+(m<<1)>>1]|0;cY=bO;cZ=(c[277220]|0)+((bO>>>1&31727)<<1)|0}cX=(e[cZ>>1]|cY&2081)&65535}}while(0);m=bT+15|0;b[(c[277218]|0)+(m<<1)>>1]=cX;k=a[1108909]|0;a[(c[277219]|0)+m|0]=k;a[(c[277219]|0)+p|0]=k}}while(0);p=bS-1|0;if((p|0)<=0){break}bR=bR-8|0;bS=p;bT=(c[277223]|0)+bT|0}return}else{if(h){c_=j;c$=i;c0=g}else{return}while(1){g=a[1108908]|0;i=c[277219]|0;do{if((g&255)>(d[i+c0|0]|0)){j=a[c_]|0;h=j&255;if(j<<24>>24==0){c1=g;c2=i;break}do{if((a[1108928]|0)==0){j=b[(c[277225]|0)+(h<<1)>>1]|0;bT=j&65535;bS=bT&63454;if((a[(c[277215]|0)+c0|0]&32)==0){bR=c[277228]|0;c3=(e[(c[277220]|0)+((((bR&-2082)+bS|0)>>>1)+(bT&2081&bR)<<1)>>1]|(bR^bT)&2081)&65535;break}else{bT=b[(c[277213]|0)+(c0<<1)>>1]|0;c3=(((bT&63454)+bS|0)>>>1)+(bT&j&2081)&65535;break}}else{j=e[(c[277225]|0)+(h<<1)>>1]|0;bT=(a[(c[277215]|0)+c0|0]&32)==0;if(bT){bS=c[277228]|0;c4=bS;c5=bS&-2082}else{bS=e[(c[277213]|0)+(c0<<1)>>1]|0;c4=bS;c5=bS&63454}if(bT){c6=c[277228]|0}else{c6=e[(c[277213]|0)+(c0<<1)>>1]|0}c3=((c6^j)&2081|e[(c[277220]|0)+((j&2081&c4)+((c5+(j&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(c0<<1)>>1]=c3;j=(a[(c[277215]|0)+c0|0]&32)==0;do{if((a[1108928]|0)==0){bT=e[(c[277213]|0)+(c0+2<<1)>>1]|0;bS=bT&63454;if(j){bR=c[277228]|0;c7=(e[(c[277220]|0)+((((bR&-2082)+bS|0)>>>1)+(bT&2081&bR)<<1)>>1]|(bR^bT)&2081)&65535;break}else{bR=e[(c[277226]|0)+(h<<1)>>1]|0;c7=(((bR&63454)+bS|0)>>>1)+(bT&2081&bR)&65535;break}}else{if(j){bR=c[277228]|0;c8=bR;c9=(c[277220]|0)+((bR>>>1&2147482607)<<1)|0}else{bR=e[(c[277226]|0)+(h<<1)>>1]|0;c8=bR;c9=(c[277220]|0)+((bR>>>1&31727)<<1)|0}c7=(e[c9>>1]|c8&2081)&65535}}while(0);h=c0+1|0;b[(c[277218]|0)+(h<<1)>>1]=c7;j=a[1108909]|0;a[(c[277219]|0)+h|0]=j;a[(c[277219]|0)+c0|0]=j;c1=a[1108908]|0;c2=c[277219]|0}else{c1=g;c2=i}}while(0);i=c0+2|0;do{if((c1&255)>(d[c2+i|0]|0)){g=a[c_+1|0]|0;j=g&255;if(g<<24>>24==0){da=c1;db=c2;break}do{if((a[1108928]|0)==0){g=b[(c[277225]|0)+(j<<1)>>1]|0;h=g&65535;bR=h&63454;if((a[(c[277215]|0)+i|0]&32)==0){bT=c[277228]|0;dc=(e[(c[277220]|0)+((((bT&-2082)+bR|0)>>>1)+(h&2081&bT)<<1)>>1]|(bT^h)&2081)&65535;break}else{h=b[(c[277213]|0)+(i<<1)>>1]|0;dc=(((h&63454)+bR|0)>>>1)+(h&g&2081)&65535;break}}else{g=e[(c[277225]|0)+(j<<1)>>1]|0;h=(a[(c[277215]|0)+i|0]&32)==0;if(h){bR=c[277228]|0;dd=bR;de=bR&-2082}else{bR=e[(c[277213]|0)+(i<<1)>>1]|0;dd=bR;de=bR&63454}if(h){df=c[277228]|0}else{df=e[(c[277213]|0)+(i<<1)>>1]|0}dc=((df^g)&2081|e[(c[277220]|0)+((g&2081&dd)+((de+(g&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(i<<1)>>1]=dc;g=(a[(c[277215]|0)+i|0]&32)==0;do{if((a[1108928]|0)==0){h=e[(c[277213]|0)+(c0+4<<1)>>1]|0;bR=h&63454;if(g){bT=c[277228]|0;dg=(e[(c[277220]|0)+((((bT&-2082)+bR|0)>>>1)+(h&2081&bT)<<1)>>1]|(bT^h)&2081)&65535;break}else{bT=e[(c[277226]|0)+(j<<1)>>1]|0;dg=(((bT&63454)+bR|0)>>>1)+(h&2081&bT)&65535;break}}else{if(g){bT=c[277228]|0;dh=bT;di=(c[277220]|0)+((bT>>>1&2147482607)<<1)|0}else{bT=e[(c[277226]|0)+(j<<1)>>1]|0;dh=bT;di=(c[277220]|0)+((bT>>>1&31727)<<1)|0}dg=(e[di>>1]|dh&2081)&65535}}while(0);j=c0+3|0;b[(c[277218]|0)+(j<<1)>>1]=dg;g=a[1108909]|0;a[(c[277219]|0)+j|0]=g;a[(c[277219]|0)+i|0]=g;da=a[1108908]|0;db=c[277219]|0}else{da=c1;db=c2}}while(0);i=c0+4|0;do{if((da&255)>(d[db+i|0]|0)){g=a[c_+2|0]|0;j=g&255;if(g<<24>>24==0){dj=da;dk=db;break}do{if((a[1108928]|0)==0){g=b[(c[277225]|0)+(j<<1)>>1]|0;bT=g&65535;h=bT&63454;if((a[(c[277215]|0)+i|0]&32)==0){bR=c[277228]|0;dl=(e[(c[277220]|0)+((((bR&-2082)+h|0)>>>1)+(bT&2081&bR)<<1)>>1]|(bR^bT)&2081)&65535;break}else{bT=b[(c[277213]|0)+(i<<1)>>1]|0;dl=(((bT&63454)+h|0)>>>1)+(bT&g&2081)&65535;break}}else{g=e[(c[277225]|0)+(j<<1)>>1]|0;bT=(a[(c[277215]|0)+i|0]&32)==0;if(bT){h=c[277228]|0;dm=h;dn=h&-2082}else{h=e[(c[277213]|0)+(i<<1)>>1]|0;dm=h;dn=h&63454}if(bT){dp=c[277228]|0}else{dp=e[(c[277213]|0)+(i<<1)>>1]|0}dl=((dp^g)&2081|e[(c[277220]|0)+((g&2081&dm)+((dn+(g&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(i<<1)>>1]=dl;g=(a[(c[277215]|0)+i|0]&32)==0;do{if((a[1108928]|0)==0){bT=e[(c[277213]|0)+(c0+6<<1)>>1]|0;h=bT&63454;if(g){bR=c[277228]|0;dq=(e[(c[277220]|0)+((((bR&-2082)+h|0)>>>1)+(bT&2081&bR)<<1)>>1]|(bR^bT)&2081)&65535;break}else{bR=e[(c[277226]|0)+(j<<1)>>1]|0;dq=(((bR&63454)+h|0)>>>1)+(bT&2081&bR)&65535;break}}else{if(g){bR=c[277228]|0;dr=bR;ds=(c[277220]|0)+((bR>>>1&2147482607)<<1)|0}else{bR=e[(c[277226]|0)+(j<<1)>>1]|0;dr=bR;ds=(c[277220]|0)+((bR>>>1&31727)<<1)|0}dq=(e[ds>>1]|dr&2081)&65535}}while(0);j=c0+5|0;b[(c[277218]|0)+(j<<1)>>1]=dq;g=a[1108909]|0;a[(c[277219]|0)+j|0]=g;a[(c[277219]|0)+i|0]=g;dj=a[1108908]|0;dk=c[277219]|0}else{dj=da;dk=db}}while(0);i=c0+6|0;do{if((dj&255)>(d[dk+i|0]|0)){g=a[c_+3|0]|0;j=g&255;if(g<<24>>24==0){dt=dj;du=dk;break}do{if((a[1108928]|0)==0){g=b[(c[277225]|0)+(j<<1)>>1]|0;bR=g&65535;bT=bR&63454;if((a[(c[277215]|0)+i|0]&32)==0){h=c[277228]|0;dv=(e[(c[277220]|0)+((((h&-2082)+bT|0)>>>1)+(bR&2081&h)<<1)>>1]|(h^bR)&2081)&65535;break}else{bR=b[(c[277213]|0)+(i<<1)>>1]|0;dv=(((bR&63454)+bT|0)>>>1)+(bR&g&2081)&65535;break}}else{g=e[(c[277225]|0)+(j<<1)>>1]|0;bR=(a[(c[277215]|0)+i|0]&32)==0;if(bR){bT=c[277228]|0;dw=bT;dx=bT&-2082}else{bT=e[(c[277213]|0)+(i<<1)>>1]|0;dw=bT;dx=bT&63454}if(bR){dy=c[277228]|0}else{dy=e[(c[277213]|0)+(i<<1)>>1]|0}dv=((dy^g)&2081|e[(c[277220]|0)+((g&2081&dw)+((dx+(g&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(i<<1)>>1]=dv;g=(a[(c[277215]|0)+i|0]&32)==0;do{if((a[1108928]|0)==0){bR=e[(c[277213]|0)+(c0+8<<1)>>1]|0;bT=bR&63454;if(g){h=c[277228]|0;dz=(e[(c[277220]|0)+((((h&-2082)+bT|0)>>>1)+(bR&2081&h)<<1)>>1]|(h^bR)&2081)&65535;break}else{h=e[(c[277226]|0)+(j<<1)>>1]|0;dz=(((h&63454)+bT|0)>>>1)+(bR&2081&h)&65535;break}}else{if(g){h=c[277228]|0;dA=h;dB=(c[277220]|0)+((h>>>1&2147482607)<<1)|0}else{h=e[(c[277226]|0)+(j<<1)>>1]|0;dA=h;dB=(c[277220]|0)+((h>>>1&31727)<<1)|0}dz=(e[dB>>1]|dA&2081)&65535}}while(0);j=c0+7|0;b[(c[277218]|0)+(j<<1)>>1]=dz;g=a[1108909]|0;a[(c[277219]|0)+j|0]=g;a[(c[277219]|0)+i|0]=g;dt=a[1108908]|0;du=c[277219]|0}else{dt=dj;du=dk}}while(0);i=c0+8|0;do{if((dt&255)>(d[du+i|0]|0)){g=a[c_+4|0]|0;j=g&255;if(g<<24>>24==0){dC=dt;dD=du;break}do{if((a[1108928]|0)==0){g=b[(c[277225]|0)+(j<<1)>>1]|0;h=g&65535;bR=h&63454;if((a[(c[277215]|0)+i|0]&32)==0){bT=c[277228]|0;dE=(e[(c[277220]|0)+((((bT&-2082)+bR|0)>>>1)+(h&2081&bT)<<1)>>1]|(bT^h)&2081)&65535;break}else{h=b[(c[277213]|0)+(i<<1)>>1]|0;dE=(((h&63454)+bR|0)>>>1)+(h&g&2081)&65535;break}}else{g=e[(c[277225]|0)+(j<<1)>>1]|0;h=(a[(c[277215]|0)+i|0]&32)==0;if(h){bR=c[277228]|0;dF=bR;dG=bR&-2082}else{bR=e[(c[277213]|0)+(i<<1)>>1]|0;dF=bR;dG=bR&63454}if(h){dH=c[277228]|0}else{dH=e[(c[277213]|0)+(i<<1)>>1]|0}dE=((dH^g)&2081|e[(c[277220]|0)+((g&2081&dF)+((dG+(g&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(i<<1)>>1]=dE;g=(a[(c[277215]|0)+i|0]&32)==0;do{if((a[1108928]|0)==0){h=e[(c[277213]|0)+(c0+10<<1)>>1]|0;bR=h&63454;if(g){bT=c[277228]|0;dI=(e[(c[277220]|0)+((((bT&-2082)+bR|0)>>>1)+(h&2081&bT)<<1)>>1]|(bT^h)&2081)&65535;break}else{bT=e[(c[277226]|0)+(j<<1)>>1]|0;dI=(((bT&63454)+bR|0)>>>1)+(h&2081&bT)&65535;break}}else{if(g){bT=c[277228]|0;dJ=bT;dK=(c[277220]|0)+((bT>>>1&2147482607)<<1)|0}else{bT=e[(c[277226]|0)+(j<<1)>>1]|0;dJ=bT;dK=(c[277220]|0)+((bT>>>1&31727)<<1)|0}dI=(e[dK>>1]|dJ&2081)&65535}}while(0);j=c0+9|0;b[(c[277218]|0)+(j<<1)>>1]=dI;g=a[1108909]|0;a[(c[277219]|0)+j|0]=g;a[(c[277219]|0)+i|0]=g;dC=a[1108908]|0;dD=c[277219]|0}else{dC=dt;dD=du}}while(0);i=c0+10|0;do{if((dC&255)>(d[dD+i|0]|0)){g=a[c_+5|0]|0;j=g&255;if(g<<24>>24==0){dL=dC;dM=dD;break}do{if((a[1108928]|0)==0){g=b[(c[277225]|0)+(j<<1)>>1]|0;bT=g&65535;h=bT&63454;if((a[(c[277215]|0)+i|0]&32)==0){bR=c[277228]|0;dN=(e[(c[277220]|0)+((((bR&-2082)+h|0)>>>1)+(bT&2081&bR)<<1)>>1]|(bR^bT)&2081)&65535;break}else{bT=b[(c[277213]|0)+(i<<1)>>1]|0;dN=(((bT&63454)+h|0)>>>1)+(bT&g&2081)&65535;break}}else{g=e[(c[277225]|0)+(j<<1)>>1]|0;bT=(a[(c[277215]|0)+i|0]&32)==0;if(bT){h=c[277228]|0;dO=h;dP=h&-2082}else{h=e[(c[277213]|0)+(i<<1)>>1]|0;dO=h;dP=h&63454}if(bT){dQ=c[277228]|0}else{dQ=e[(c[277213]|0)+(i<<1)>>1]|0}dN=((dQ^g)&2081|e[(c[277220]|0)+((g&2081&dO)+((dP+(g&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(i<<1)>>1]=dN;g=(a[(c[277215]|0)+i|0]&32)==0;do{if((a[1108928]|0)==0){bT=e[(c[277213]|0)+(c0+12<<1)>>1]|0;h=bT&63454;if(g){bR=c[277228]|0;dR=(e[(c[277220]|0)+((((bR&-2082)+h|0)>>>1)+(bT&2081&bR)<<1)>>1]|(bR^bT)&2081)&65535;break}else{bR=e[(c[277226]|0)+(j<<1)>>1]|0;dR=(((bR&63454)+h|0)>>>1)+(bT&2081&bR)&65535;break}}else{if(g){bR=c[277228]|0;dS=bR;dT=(c[277220]|0)+((bR>>>1&2147482607)<<1)|0}else{bR=e[(c[277226]|0)+(j<<1)>>1]|0;dS=bR;dT=(c[277220]|0)+((bR>>>1&31727)<<1)|0}dR=(e[dT>>1]|dS&2081)&65535}}while(0);j=c0+11|0;b[(c[277218]|0)+(j<<1)>>1]=dR;g=a[1108909]|0;a[(c[277219]|0)+j|0]=g;a[(c[277219]|0)+i|0]=g;dL=a[1108908]|0;dM=c[277219]|0}else{dL=dC;dM=dD}}while(0);i=c0+12|0;do{if((dL&255)>(d[dM+i|0]|0)){g=a[c_+6|0]|0;j=g&255;if(g<<24>>24==0){dU=dL;dV=dM;break}do{if((a[1108928]|0)==0){g=b[(c[277225]|0)+(j<<1)>>1]|0;bR=g&65535;bT=bR&63454;if((a[(c[277215]|0)+i|0]&32)==0){h=c[277228]|0;dW=(e[(c[277220]|0)+((((h&-2082)+bT|0)>>>1)+(bR&2081&h)<<1)>>1]|(h^bR)&2081)&65535;break}else{bR=b[(c[277213]|0)+(i<<1)>>1]|0;dW=(((bR&63454)+bT|0)>>>1)+(bR&g&2081)&65535;break}}else{g=e[(c[277225]|0)+(j<<1)>>1]|0;bR=(a[(c[277215]|0)+i|0]&32)==0;if(bR){bT=c[277228]|0;dX=bT;dY=bT&-2082}else{bT=e[(c[277213]|0)+(i<<1)>>1]|0;dX=bT;dY=bT&63454}if(bR){dZ=c[277228]|0}else{dZ=e[(c[277213]|0)+(i<<1)>>1]|0}dW=((dZ^g)&2081|e[(c[277220]|0)+((g&2081&dX)+((dY+(g&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(i<<1)>>1]=dW;g=(a[(c[277215]|0)+i|0]&32)==0;do{if((a[1108928]|0)==0){bR=e[(c[277213]|0)+(c0+14<<1)>>1]|0;bT=bR&63454;if(g){h=c[277228]|0;d_=(e[(c[277220]|0)+((((h&-2082)+bT|0)>>>1)+(bR&2081&h)<<1)>>1]|(h^bR)&2081)&65535;break}else{h=e[(c[277226]|0)+(j<<1)>>1]|0;d_=(((h&63454)+bT|0)>>>1)+(bR&2081&h)&65535;break}}else{if(g){h=c[277228]|0;d$=h;d0=(c[277220]|0)+((h>>>1&2147482607)<<1)|0}else{h=e[(c[277226]|0)+(j<<1)>>1]|0;d$=h;d0=(c[277220]|0)+((h>>>1&31727)<<1)|0}d_=(e[d0>>1]|d$&2081)&65535}}while(0);j=c0+13|0;b[(c[277218]|0)+(j<<1)>>1]=d_;g=a[1108909]|0;a[(c[277219]|0)+j|0]=g;a[(c[277219]|0)+i|0]=g;dU=a[1108908]|0;dV=c[277219]|0}else{dU=dL;dV=dM}}while(0);i=c0+14|0;do{if((dU&255)>(d[dV+i|0]|0)){g=a[c_+7|0]|0;j=g&255;if(g<<24>>24==0){break}do{if((a[1108928]|0)==0){g=b[(c[277225]|0)+(j<<1)>>1]|0;h=g&65535;bR=h&63454;if((a[(c[277215]|0)+i|0]&32)==0){bT=c[277228]|0;d1=(e[(c[277220]|0)+((((bT&-2082)+bR|0)>>>1)+(h&2081&bT)<<1)>>1]|(bT^h)&2081)&65535;break}else{h=b[(c[277213]|0)+(i<<1)>>1]|0;d1=(((h&63454)+bR|0)>>>1)+(h&g&2081)&65535;break}}else{g=e[(c[277225]|0)+(j<<1)>>1]|0;h=(a[(c[277215]|0)+i|0]&32)==0;if(h){bR=c[277228]|0;d2=bR;d3=bR&-2082}else{bR=e[(c[277213]|0)+(i<<1)>>1]|0;d2=bR;d3=bR&63454}if(h){d4=c[277228]|0}else{d4=e[(c[277213]|0)+(i<<1)>>1]|0}d1=((d4^g)&2081|e[(c[277220]|0)+((g&2081&d2)+((d3+(g&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(i<<1)>>1]=d1;g=(a[(c[277215]|0)+i|0]&32)==0;do{if((a[1108928]|0)==0){h=e[(c[277213]|0)+(c0+16<<1)>>1]|0;bR=h&63454;if(g){bT=c[277228]|0;d5=(e[(c[277220]|0)+((((bT&-2082)+bR|0)>>>1)+(h&2081&bT)<<1)>>1]|(bT^h)&2081)&65535;break}else{bT=e[(c[277226]|0)+(j<<1)>>1]|0;d5=(((bT&63454)+bR|0)>>>1)+(h&2081&bT)&65535;break}}else{if(g){bT=c[277228]|0;d6=bT;d7=(c[277220]|0)+((bT>>>1&2147482607)<<1)|0}else{bT=e[(c[277226]|0)+(j<<1)>>1]|0;d6=bT;d7=(c[277220]|0)+((bT>>>1&31727)<<1)|0}d5=(e[d7>>1]|d6&2081)&65535}}while(0);j=c0+15|0;b[(c[277218]|0)+(j<<1)>>1]=d5;g=a[1108909]|0;a[(c[277219]|0)+j|0]=g;a[(c[277219]|0)+i|0]=g}}while(0);i=c$-1|0;if((i|0)<=0){break}c_=c_-8|0;c$=i;c0=(c[277223]|0)+c0|0}return}}function VL(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0,cf=0,cg=0,ch=0,ci=0,cj=0,ck=0,cl=0,cm=0,cn=0,co=0,cp=0,cq=0,cr=0,cs=0,ct=0,cu=0,cv=0,cw=0,cx=0,cy=0,cz=0,cA=0,cB=0,cC=0,cD=0,cE=0,cF=0,cG=0,cH=0,cI=0,cJ=0,cK=0,cL=0,cM=0,cN=0,cO=0,cP=0,cQ=0,cR=0,cS=0,cT=0,cU=0,cV=0,cW=0,cX=0,cY=0,cZ=0,c_=0,c$=0,c0=0,c1=0,c2=0,c3=0,c4=0,c5=0,c6=0,c7=0,c8=0,c9=0,da=0,db=0,dc=0,dd=0,de=0,df=0,dg=0,dh=0,di=0,dj=0,dk=0,dl=0,dm=0,dn=0,dp=0,dq=0,dr=0,ds=0,dt=0,du=0,dv=0,dw=0,dx=0,dy=0,dz=0,dA=0,dB=0,dC=0,dD=0,dE=0,dF=0,dG=0,dH=0,dI=0,dJ=0,dK=0,dL=0,dM=0,dN=0,dO=0,dP=0,dQ=0,dR=0,dS=0,dT=0,dU=0,dV=0,dW=0,dX=0,dY=0,dZ=0,d_=0,d$=0,d0=0,d1=0,d2=0,d3=0,d4=0,d5=0,d6=0;i=e&1023;j=c[348606]|0;k=(i<<j)+(c[348604]|0)|0;if((e&256|0)==0){l=k}else{l=(c[348602]|0)+k|0}k=l&65535;l=k>>>(j>>>0);j=(e&16384|0)!=0;m=l<<6;do{if(j){n=(c[348622]|0)+m|0;if((a[(c[348618]|0)+l|0]|0)!=0){o=n;break}p=fi[c[348636]&63](n,k,i)|0;a[(c[348618]|0)+l|0]=p;o=n}else{n=(c[348624]|0)+m|0;if((a[(c[348620]|0)+l|0]|0)!=0){o=n;break}p=fi[c[348638]&63](n,k,i)|0;a[(c[348620]|0)+l|0]=p;o=n}}while(0);if((a[(c[348620]|0)+l|0]|0)==2){return}if((a[1394464]|0)==0){q=1106168+((e>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){l=d[1044485]|0;c[276541]=7080+(l<<5);i=0;do{k=i<<1&2;m=i&2;n=i&4;p=0;do{b[1125528+(i<<9)+(p<<1)>>1]=d[(p>>>1&28|m)+(7080+(l<<5))|0]<<6|d[(p<<2&28|k)+(7080+(l<<5))|0]<<11|d[(p>>>3&24|n)+(7080+(l<<5))|0];p=p+1|0;}while(p>>>0<256);i=i+1|0;}while(i>>>0<8);a[1106089]=0}q=1125528+((e>>>10&7)<<9)|0}c[277226]=q;c[277225]=(a[1108928]|0)!=0?1393712:q;if((e&49152|0)==0){if((h|0)<=0){return}q=o+g|0;i=h;l=f;while(1){p=a[1108908]|0;n=c[277219]|0;do{if((p&255)>(d[n+l|0]|0)){k=a[q]|0;m=k&255;if(k<<24>>24==0){r=p;s=n;break}k=b[(c[277225]|0)+(m<<1)>>1]|0;if((a[(c[277215]|0)+l|0]&32)==0){t=c[277228]&65535}else{t=b[(c[277213]|0)+(l<<1)>>1]|0}u=k&-2048;v=t&-2048;w=(u&65535)>(v&65535)?u-v&65535:0;v=k&2016;u=t&2016;if((v&65535)>(u&65535)){x=(v-u&65535)+w&65535}else{x=w}w=k&31;k=t&31;if((w&65535)>(k&65535)){y=(w-k&65535)+x&65535}else{y=x}b[(c[277218]|0)+(l<<1)>>1]=y;if((a[1108928]|0)==0){z=b[(c[277213]|0)+(l+2<<1)>>1]|0}else{z=0}if((a[(c[277215]|0)+l|0]&32)==0){A=c[277228]&65535}else{A=b[(c[277226]|0)+(m<<1)>>1]|0}m=z&-2048;k=A&-2048;w=(m&65535)>(k&65535)?m-k&65535:0;k=z&2016;m=A&2016;if((k&65535)>(m&65535)){B=(k-m&65535)+w&65535}else{B=w}w=z&31;m=A&31;if((w&65535)>(m&65535)){C=(w-m&65535)+B&65535}else{C=B}m=l+1|0;b[(c[277218]|0)+(m<<1)>>1]=C;w=a[1108909]|0;a[(c[277219]|0)+m|0]=w;a[(c[277219]|0)+l|0]=w;r=a[1108908]|0;s=c[277219]|0}else{r=p;s=n}}while(0);n=l+2|0;do{if((r&255)>(d[s+n|0]|0)){p=a[q+1|0]|0;w=p&255;if(p<<24>>24==0){D=r;E=s;break}p=b[(c[277225]|0)+(w<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)==0){F=c[277228]&65535}else{F=b[(c[277213]|0)+(n<<1)>>1]|0}m=p&-2048;k=F&-2048;u=(m&65535)>(k&65535)?m-k&65535:0;k=p&2016;m=F&2016;if((k&65535)>(m&65535)){G=(k-m&65535)+u&65535}else{G=u}u=p&31;p=F&31;if((u&65535)>(p&65535)){H=(u-p&65535)+G&65535}else{H=G}b[(c[277218]|0)+(n<<1)>>1]=H;if((a[1108928]|0)==0){I=b[(c[277213]|0)+(l+4<<1)>>1]|0}else{I=0}if((a[(c[277215]|0)+n|0]&32)==0){J=c[277228]&65535}else{J=b[(c[277226]|0)+(w<<1)>>1]|0}w=I&-2048;p=J&-2048;u=(w&65535)>(p&65535)?w-p&65535:0;p=I&2016;w=J&2016;if((p&65535)>(w&65535)){K=(p-w&65535)+u&65535}else{K=u}u=I&31;w=J&31;if((u&65535)>(w&65535)){L=(u-w&65535)+K&65535}else{L=K}w=l+3|0;b[(c[277218]|0)+(w<<1)>>1]=L;u=a[1108909]|0;a[(c[277219]|0)+w|0]=u;a[(c[277219]|0)+n|0]=u;D=a[1108908]|0;E=c[277219]|0}else{D=r;E=s}}while(0);n=l+4|0;do{if((D&255)>(d[E+n|0]|0)){u=a[q+2|0]|0;w=u&255;if(u<<24>>24==0){M=D;N=E;break}u=b[(c[277225]|0)+(w<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)==0){O=c[277228]&65535}else{O=b[(c[277213]|0)+(n<<1)>>1]|0}p=u&-2048;m=O&-2048;k=(p&65535)>(m&65535)?p-m&65535:0;m=u&2016;p=O&2016;if((m&65535)>(p&65535)){P=(m-p&65535)+k&65535}else{P=k}k=u&31;u=O&31;if((k&65535)>(u&65535)){Q=(k-u&65535)+P&65535}else{Q=P}b[(c[277218]|0)+(n<<1)>>1]=Q;if((a[1108928]|0)==0){R=b[(c[277213]|0)+(l+6<<1)>>1]|0}else{R=0}if((a[(c[277215]|0)+n|0]&32)==0){S=c[277228]&65535}else{S=b[(c[277226]|0)+(w<<1)>>1]|0}w=R&-2048;u=S&-2048;k=(w&65535)>(u&65535)?w-u&65535:0;u=R&2016;w=S&2016;if((u&65535)>(w&65535)){T=(u-w&65535)+k&65535}else{T=k}k=R&31;w=S&31;if((k&65535)>(w&65535)){U=(k-w&65535)+T&65535}else{U=T}w=l+5|0;b[(c[277218]|0)+(w<<1)>>1]=U;k=a[1108909]|0;a[(c[277219]|0)+w|0]=k;a[(c[277219]|0)+n|0]=k;M=a[1108908]|0;N=c[277219]|0}else{M=D;N=E}}while(0);n=l+6|0;do{if((M&255)>(d[N+n|0]|0)){k=a[q+3|0]|0;w=k&255;if(k<<24>>24==0){V=M;W=N;break}k=b[(c[277225]|0)+(w<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)==0){X=c[277228]&65535}else{X=b[(c[277213]|0)+(n<<1)>>1]|0}u=k&-2048;p=X&-2048;m=(u&65535)>(p&65535)?u-p&65535:0;p=k&2016;u=X&2016;if((p&65535)>(u&65535)){Y=(p-u&65535)+m&65535}else{Y=m}m=k&31;k=X&31;if((m&65535)>(k&65535)){Z=(m-k&65535)+Y&65535}else{Z=Y}b[(c[277218]|0)+(n<<1)>>1]=Z;if((a[1108928]|0)==0){_=b[(c[277213]|0)+(l+8<<1)>>1]|0}else{_=0}if((a[(c[277215]|0)+n|0]&32)==0){$=c[277228]&65535}else{$=b[(c[277226]|0)+(w<<1)>>1]|0}w=_&-2048;k=$&-2048;m=(w&65535)>(k&65535)?w-k&65535:0;k=_&2016;w=$&2016;if((k&65535)>(w&65535)){aa=(k-w&65535)+m&65535}else{aa=m}m=_&31;w=$&31;if((m&65535)>(w&65535)){ab=(m-w&65535)+aa&65535}else{ab=aa}w=l+7|0;b[(c[277218]|0)+(w<<1)>>1]=ab;m=a[1108909]|0;a[(c[277219]|0)+w|0]=m;a[(c[277219]|0)+n|0]=m;V=a[1108908]|0;W=c[277219]|0}else{V=M;W=N}}while(0);n=l+8|0;do{if((V&255)>(d[W+n|0]|0)){m=a[q+4|0]|0;w=m&255;if(m<<24>>24==0){ac=V;ad=W;break}m=b[(c[277225]|0)+(w<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)==0){ae=c[277228]&65535}else{ae=b[(c[277213]|0)+(n<<1)>>1]|0}k=m&-2048;u=ae&-2048;p=(k&65535)>(u&65535)?k-u&65535:0;u=m&2016;k=ae&2016;if((u&65535)>(k&65535)){af=(u-k&65535)+p&65535}else{af=p}p=m&31;m=ae&31;if((p&65535)>(m&65535)){ag=(p-m&65535)+af&65535}else{ag=af}b[(c[277218]|0)+(n<<1)>>1]=ag;if((a[1108928]|0)==0){ah=b[(c[277213]|0)+(l+10<<1)>>1]|0}else{ah=0}if((a[(c[277215]|0)+n|0]&32)==0){ai=c[277228]&65535}else{ai=b[(c[277226]|0)+(w<<1)>>1]|0}w=ah&-2048;m=ai&-2048;p=(w&65535)>(m&65535)?w-m&65535:0;m=ah&2016;w=ai&2016;if((m&65535)>(w&65535)){aj=(m-w&65535)+p&65535}else{aj=p}p=ah&31;w=ai&31;if((p&65535)>(w&65535)){ak=(p-w&65535)+aj&65535}else{ak=aj}w=l+9|0;b[(c[277218]|0)+(w<<1)>>1]=ak;p=a[1108909]|0;a[(c[277219]|0)+w|0]=p;a[(c[277219]|0)+n|0]=p;ac=a[1108908]|0;ad=c[277219]|0}else{ac=V;ad=W}}while(0);n=l+10|0;do{if((ac&255)>(d[ad+n|0]|0)){p=a[q+5|0]|0;w=p&255;if(p<<24>>24==0){al=ac;am=ad;break}p=b[(c[277225]|0)+(w<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)==0){an=c[277228]&65535}else{an=b[(c[277213]|0)+(n<<1)>>1]|0}m=p&-2048;k=an&-2048;u=(m&65535)>(k&65535)?m-k&65535:0;k=p&2016;m=an&2016;if((k&65535)>(m&65535)){ao=(k-m&65535)+u&65535}else{ao=u}u=p&31;p=an&31;if((u&65535)>(p&65535)){ap=(u-p&65535)+ao&65535}else{ap=ao}b[(c[277218]|0)+(n<<1)>>1]=ap;if((a[1108928]|0)==0){aq=b[(c[277213]|0)+(l+12<<1)>>1]|0}else{aq=0}if((a[(c[277215]|0)+n|0]&32)==0){ar=c[277228]&65535}else{ar=b[(c[277226]|0)+(w<<1)>>1]|0}w=aq&-2048;p=ar&-2048;u=(w&65535)>(p&65535)?w-p&65535:0;p=aq&2016;w=ar&2016;if((p&65535)>(w&65535)){as=(p-w&65535)+u&65535}else{as=u}u=aq&31;w=ar&31;if((u&65535)>(w&65535)){at=(u-w&65535)+as&65535}else{at=as}w=l+11|0;b[(c[277218]|0)+(w<<1)>>1]=at;u=a[1108909]|0;a[(c[277219]|0)+w|0]=u;a[(c[277219]|0)+n|0]=u;al=a[1108908]|0;am=c[277219]|0}else{al=ac;am=ad}}while(0);n=l+12|0;do{if((al&255)>(d[am+n|0]|0)){u=a[q+6|0]|0;w=u&255;if(u<<24>>24==0){au=al;av=am;break}u=b[(c[277225]|0)+(w<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)==0){aw=c[277228]&65535}else{aw=b[(c[277213]|0)+(n<<1)>>1]|0}p=u&-2048;m=aw&-2048;k=(p&65535)>(m&65535)?p-m&65535:0;m=u&2016;p=aw&2016;if((m&65535)>(p&65535)){ax=(m-p&65535)+k&65535}else{ax=k}k=u&31;u=aw&31;if((k&65535)>(u&65535)){ay=(k-u&65535)+ax&65535}else{ay=ax}b[(c[277218]|0)+(n<<1)>>1]=ay;if((a[1108928]|0)==0){az=b[(c[277213]|0)+(l+14<<1)>>1]|0}else{az=0}if((a[(c[277215]|0)+n|0]&32)==0){aA=c[277228]&65535}else{aA=b[(c[277226]|0)+(w<<1)>>1]|0}w=az&-2048;u=aA&-2048;k=(w&65535)>(u&65535)?w-u&65535:0;u=az&2016;w=aA&2016;if((u&65535)>(w&65535)){aB=(u-w&65535)+k&65535}else{aB=k}k=az&31;w=aA&31;if((k&65535)>(w&65535)){aC=(k-w&65535)+aB&65535}else{aC=aB}w=l+13|0;b[(c[277218]|0)+(w<<1)>>1]=aC;k=a[1108909]|0;a[(c[277219]|0)+w|0]=k;a[(c[277219]|0)+n|0]=k;au=a[1108908]|0;av=c[277219]|0}else{au=al;av=am}}while(0);n=l+14|0;do{if((au&255)>(d[av+n|0]|0)){k=a[q+7|0]|0;w=k&255;if(k<<24>>24==0){break}k=b[(c[277225]|0)+(w<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)==0){aD=c[277228]&65535}else{aD=b[(c[277213]|0)+(n<<1)>>1]|0}u=k&-2048;p=aD&-2048;m=(u&65535)>(p&65535)?u-p&65535:0;p=k&2016;u=aD&2016;if((p&65535)>(u&65535)){aE=(p-u&65535)+m&65535}else{aE=m}m=k&31;k=aD&31;if((m&65535)>(k&65535)){aF=(m-k&65535)+aE&65535}else{aF=aE}b[(c[277218]|0)+(n<<1)>>1]=aF;if((a[1108928]|0)==0){aG=b[(c[277213]|0)+(l+16<<1)>>1]|0}else{aG=0}if((a[(c[277215]|0)+n|0]&32)==0){aH=c[277228]&65535}else{aH=b[(c[277226]|0)+(w<<1)>>1]|0}w=aG&-2048;k=aH&-2048;m=(w&65535)>(k&65535)?w-k&65535:0;k=aG&2016;w=aH&2016;if((k&65535)>(w&65535)){aI=(k-w&65535)+m&65535}else{aI=m}m=aG&31;w=aH&31;if((m&65535)>(w&65535)){aJ=(m-w&65535)+aI&65535}else{aJ=aI}w=l+15|0;b[(c[277218]|0)+(w<<1)>>1]=aJ;m=a[1108909]|0;a[(c[277219]|0)+w|0]=m;a[(c[277219]|0)+n|0]=m}}while(0);n=i-1|0;if((n|0)<=0){break}q=q+8|0;i=n;l=(c[277223]|0)+l|0}return}if((e&32768|0)==0){if((h|0)<=0){return}e=o+g|0;l=h;i=f;while(1){q=a[1108908]|0;aJ=c[277219]|0;do{if((q&255)>(d[aJ+i|0]|0)){aI=a[e+7|0]|0;aH=aI&255;if(aI<<24>>24==0){aK=q;aL=aJ;break}aI=b[(c[277225]|0)+(aH<<1)>>1]|0;if((a[(c[277215]|0)+i|0]&32)==0){aM=c[277228]&65535}else{aM=b[(c[277213]|0)+(i<<1)>>1]|0}aG=aI&-2048;aF=aM&-2048;aE=(aG&65535)>(aF&65535)?aG-aF&65535:0;aF=aI&2016;aG=aM&2016;if((aF&65535)>(aG&65535)){aN=(aF-aG&65535)+aE&65535}else{aN=aE}aE=aI&31;aI=aM&31;if((aE&65535)>(aI&65535)){aO=(aE-aI&65535)+aN&65535}else{aO=aN}b[(c[277218]|0)+(i<<1)>>1]=aO;if((a[1108928]|0)==0){aP=b[(c[277213]|0)+(i+2<<1)>>1]|0}else{aP=0}if((a[(c[277215]|0)+i|0]&32)==0){aQ=c[277228]&65535}else{aQ=b[(c[277226]|0)+(aH<<1)>>1]|0}aH=aP&-2048;aI=aQ&-2048;aE=(aH&65535)>(aI&65535)?aH-aI&65535:0;aI=aP&2016;aH=aQ&2016;if((aI&65535)>(aH&65535)){aR=(aI-aH&65535)+aE&65535}else{aR=aE}aE=aP&31;aH=aQ&31;if((aE&65535)>(aH&65535)){aS=(aE-aH&65535)+aR&65535}else{aS=aR}aH=i+1|0;b[(c[277218]|0)+(aH<<1)>>1]=aS;aE=a[1108909]|0;a[(c[277219]|0)+aH|0]=aE;a[(c[277219]|0)+i|0]=aE;aK=a[1108908]|0;aL=c[277219]|0}else{aK=q;aL=aJ}}while(0);aJ=i+2|0;do{if((aK&255)>(d[aL+aJ|0]|0)){q=a[e+6|0]|0;aE=q&255;if(q<<24>>24==0){aT=aK;aU=aL;break}q=b[(c[277225]|0)+(aE<<1)>>1]|0;if((a[(c[277215]|0)+aJ|0]&32)==0){aV=c[277228]&65535}else{aV=b[(c[277213]|0)+(aJ<<1)>>1]|0}aH=q&-2048;aI=aV&-2048;aG=(aH&65535)>(aI&65535)?aH-aI&65535:0;aI=q&2016;aH=aV&2016;if((aI&65535)>(aH&65535)){aW=(aI-aH&65535)+aG&65535}else{aW=aG}aG=q&31;q=aV&31;if((aG&65535)>(q&65535)){aX=(aG-q&65535)+aW&65535}else{aX=aW}b[(c[277218]|0)+(aJ<<1)>>1]=aX;if((a[1108928]|0)==0){aY=b[(c[277213]|0)+(i+4<<1)>>1]|0}else{aY=0}if((a[(c[277215]|0)+aJ|0]&32)==0){aZ=c[277228]&65535}else{aZ=b[(c[277226]|0)+(aE<<1)>>1]|0}aE=aY&-2048;q=aZ&-2048;aG=(aE&65535)>(q&65535)?aE-q&65535:0;q=aY&2016;aE=aZ&2016;if((q&65535)>(aE&65535)){a_=(q-aE&65535)+aG&65535}else{a_=aG}aG=aY&31;aE=aZ&31;if((aG&65535)>(aE&65535)){a$=(aG-aE&65535)+a_&65535}else{a$=a_}aE=i+3|0;b[(c[277218]|0)+(aE<<1)>>1]=a$;aG=a[1108909]|0;a[(c[277219]|0)+aE|0]=aG;a[(c[277219]|0)+aJ|0]=aG;aT=a[1108908]|0;aU=c[277219]|0}else{aT=aK;aU=aL}}while(0);aJ=i+4|0;do{if((aT&255)>(d[aU+aJ|0]|0)){aG=a[e+5|0]|0;aE=aG&255;if(aG<<24>>24==0){a0=aT;a1=aU;break}aG=b[(c[277225]|0)+(aE<<1)>>1]|0;if((a[(c[277215]|0)+aJ|0]&32)==0){a2=c[277228]&65535}else{a2=b[(c[277213]|0)+(aJ<<1)>>1]|0}q=aG&-2048;aH=a2&-2048;aI=(q&65535)>(aH&65535)?q-aH&65535:0;aH=aG&2016;q=a2&2016;if((aH&65535)>(q&65535)){a3=(aH-q&65535)+aI&65535}else{a3=aI}aI=aG&31;aG=a2&31;if((aI&65535)>(aG&65535)){a4=(aI-aG&65535)+a3&65535}else{a4=a3}b[(c[277218]|0)+(aJ<<1)>>1]=a4;if((a[1108928]|0)==0){a5=b[(c[277213]|0)+(i+6<<1)>>1]|0}else{a5=0}if((a[(c[277215]|0)+aJ|0]&32)==0){a6=c[277228]&65535}else{a6=b[(c[277226]|0)+(aE<<1)>>1]|0}aE=a5&-2048;aG=a6&-2048;aI=(aE&65535)>(aG&65535)?aE-aG&65535:0;aG=a5&2016;aE=a6&2016;if((aG&65535)>(aE&65535)){a7=(aG-aE&65535)+aI&65535}else{a7=aI}aI=a5&31;aE=a6&31;if((aI&65535)>(aE&65535)){a8=(aI-aE&65535)+a7&65535}else{a8=a7}aE=i+5|0;b[(c[277218]|0)+(aE<<1)>>1]=a8;aI=a[1108909]|0;a[(c[277219]|0)+aE|0]=aI;a[(c[277219]|0)+aJ|0]=aI;a0=a[1108908]|0;a1=c[277219]|0}else{a0=aT;a1=aU}}while(0);aJ=i+6|0;do{if((a0&255)>(d[a1+aJ|0]|0)){aI=a[e+4|0]|0;aE=aI&255;if(aI<<24>>24==0){a9=a0;ba=a1;break}aI=b[(c[277225]|0)+(aE<<1)>>1]|0;if((a[(c[277215]|0)+aJ|0]&32)==0){bb=c[277228]&65535}else{bb=b[(c[277213]|0)+(aJ<<1)>>1]|0}aG=aI&-2048;q=bb&-2048;aH=(aG&65535)>(q&65535)?aG-q&65535:0;q=aI&2016;aG=bb&2016;if((q&65535)>(aG&65535)){bc=(q-aG&65535)+aH&65535}else{bc=aH}aH=aI&31;aI=bb&31;if((aH&65535)>(aI&65535)){bd=(aH-aI&65535)+bc&65535}else{bd=bc}b[(c[277218]|0)+(aJ<<1)>>1]=bd;if((a[1108928]|0)==0){be=b[(c[277213]|0)+(i+8<<1)>>1]|0}else{be=0}if((a[(c[277215]|0)+aJ|0]&32)==0){bf=c[277228]&65535}else{bf=b[(c[277226]|0)+(aE<<1)>>1]|0}aE=be&-2048;aI=bf&-2048;aH=(aE&65535)>(aI&65535)?aE-aI&65535:0;aI=be&2016;aE=bf&2016;if((aI&65535)>(aE&65535)){bg=(aI-aE&65535)+aH&65535}else{bg=aH}aH=be&31;aE=bf&31;if((aH&65535)>(aE&65535)){bh=(aH-aE&65535)+bg&65535}else{bh=bg}aE=i+7|0;b[(c[277218]|0)+(aE<<1)>>1]=bh;aH=a[1108909]|0;a[(c[277219]|0)+aE|0]=aH;a[(c[277219]|0)+aJ|0]=aH;a9=a[1108908]|0;ba=c[277219]|0}else{a9=a0;ba=a1}}while(0);aJ=i+8|0;do{if((a9&255)>(d[ba+aJ|0]|0)){aH=a[e+3|0]|0;aE=aH&255;if(aH<<24>>24==0){bi=a9;bj=ba;break}aH=b[(c[277225]|0)+(aE<<1)>>1]|0;if((a[(c[277215]|0)+aJ|0]&32)==0){bk=c[277228]&65535}else{bk=b[(c[277213]|0)+(aJ<<1)>>1]|0}aI=aH&-2048;aG=bk&-2048;q=(aI&65535)>(aG&65535)?aI-aG&65535:0;aG=aH&2016;aI=bk&2016;if((aG&65535)>(aI&65535)){bl=(aG-aI&65535)+q&65535}else{bl=q}q=aH&31;aH=bk&31;if((q&65535)>(aH&65535)){bm=(q-aH&65535)+bl&65535}else{bm=bl}b[(c[277218]|0)+(aJ<<1)>>1]=bm;if((a[1108928]|0)==0){bn=b[(c[277213]|0)+(i+10<<1)>>1]|0}else{bn=0}if((a[(c[277215]|0)+aJ|0]&32)==0){bo=c[277228]&65535}else{bo=b[(c[277226]|0)+(aE<<1)>>1]|0}aE=bn&-2048;aH=bo&-2048;q=(aE&65535)>(aH&65535)?aE-aH&65535:0;aH=bn&2016;aE=bo&2016;if((aH&65535)>(aE&65535)){bp=(aH-aE&65535)+q&65535}else{bp=q}q=bn&31;aE=bo&31;if((q&65535)>(aE&65535)){bq=(q-aE&65535)+bp&65535}else{bq=bp}aE=i+9|0;b[(c[277218]|0)+(aE<<1)>>1]=bq;q=a[1108909]|0;a[(c[277219]|0)+aE|0]=q;a[(c[277219]|0)+aJ|0]=q;bi=a[1108908]|0;bj=c[277219]|0}else{bi=a9;bj=ba}}while(0);aJ=i+10|0;do{if((bi&255)>(d[bj+aJ|0]|0)){q=a[e+2|0]|0;aE=q&255;if(q<<24>>24==0){br=bi;bs=bj;break}q=b[(c[277225]|0)+(aE<<1)>>1]|0;if((a[(c[277215]|0)+aJ|0]&32)==0){bt=c[277228]&65535}else{bt=b[(c[277213]|0)+(aJ<<1)>>1]|0}aH=q&-2048;aI=bt&-2048;aG=(aH&65535)>(aI&65535)?aH-aI&65535:0;aI=q&2016;aH=bt&2016;if((aI&65535)>(aH&65535)){bu=(aI-aH&65535)+aG&65535}else{bu=aG}aG=q&31;q=bt&31;if((aG&65535)>(q&65535)){bv=(aG-q&65535)+bu&65535}else{bv=bu}b[(c[277218]|0)+(aJ<<1)>>1]=bv;if((a[1108928]|0)==0){bw=b[(c[277213]|0)+(i+12<<1)>>1]|0}else{bw=0}if((a[(c[277215]|0)+aJ|0]&32)==0){bx=c[277228]&65535}else{bx=b[(c[277226]|0)+(aE<<1)>>1]|0}aE=bw&-2048;q=bx&-2048;aG=(aE&65535)>(q&65535)?aE-q&65535:0;q=bw&2016;aE=bx&2016;if((q&65535)>(aE&65535)){by=(q-aE&65535)+aG&65535}else{by=aG}aG=bw&31;aE=bx&31;if((aG&65535)>(aE&65535)){bz=(aG-aE&65535)+by&65535}else{bz=by}aE=i+11|0;b[(c[277218]|0)+(aE<<1)>>1]=bz;aG=a[1108909]|0;a[(c[277219]|0)+aE|0]=aG;a[(c[277219]|0)+aJ|0]=aG;br=a[1108908]|0;bs=c[277219]|0}else{br=bi;bs=bj}}while(0);aJ=i+12|0;do{if((br&255)>(d[bs+aJ|0]|0)){aG=a[e+1|0]|0;aE=aG&255;if(aG<<24>>24==0){bA=br;bB=bs;break}aG=b[(c[277225]|0)+(aE<<1)>>1]|0;if((a[(c[277215]|0)+aJ|0]&32)==0){bC=c[277228]&65535}else{bC=b[(c[277213]|0)+(aJ<<1)>>1]|0}q=aG&-2048;aH=bC&-2048;aI=(q&65535)>(aH&65535)?q-aH&65535:0;aH=aG&2016;q=bC&2016;if((aH&65535)>(q&65535)){bD=(aH-q&65535)+aI&65535}else{bD=aI}aI=aG&31;aG=bC&31;if((aI&65535)>(aG&65535)){bE=(aI-aG&65535)+bD&65535}else{bE=bD}b[(c[277218]|0)+(aJ<<1)>>1]=bE;if((a[1108928]|0)==0){bF=b[(c[277213]|0)+(i+14<<1)>>1]|0}else{bF=0}if((a[(c[277215]|0)+aJ|0]&32)==0){bG=c[277228]&65535}else{bG=b[(c[277226]|0)+(aE<<1)>>1]|0}aE=bF&-2048;aG=bG&-2048;aI=(aE&65535)>(aG&65535)?aE-aG&65535:0;aG=bF&2016;aE=bG&2016;if((aG&65535)>(aE&65535)){bH=(aG-aE&65535)+aI&65535}else{bH=aI}aI=bF&31;aE=bG&31;if((aI&65535)>(aE&65535)){bI=(aI-aE&65535)+bH&65535}else{bI=bH}aE=i+13|0;b[(c[277218]|0)+(aE<<1)>>1]=bI;aI=a[1108909]|0;a[(c[277219]|0)+aE|0]=aI;a[(c[277219]|0)+aJ|0]=aI;bA=a[1108908]|0;bB=c[277219]|0}else{bA=br;bB=bs}}while(0);aJ=i+14|0;do{if((bA&255)>(d[bB+aJ|0]|0)){aI=a[e]|0;aE=aI&255;if(aI<<24>>24==0){break}aI=b[(c[277225]|0)+(aE<<1)>>1]|0;if((a[(c[277215]|0)+aJ|0]&32)==0){bJ=c[277228]&65535}else{bJ=b[(c[277213]|0)+(aJ<<1)>>1]|0}aG=aI&-2048;q=bJ&-2048;aH=(aG&65535)>(q&65535)?aG-q&65535:0;q=aI&2016;aG=bJ&2016;if((q&65535)>(aG&65535)){bK=(q-aG&65535)+aH&65535}else{bK=aH}aH=aI&31;aI=bJ&31;if((aH&65535)>(aI&65535)){bL=(aH-aI&65535)+bK&65535}else{bL=bK}b[(c[277218]|0)+(aJ<<1)>>1]=bL;if((a[1108928]|0)==0){bM=b[(c[277213]|0)+(i+16<<1)>>1]|0}else{bM=0}if((a[(c[277215]|0)+aJ|0]&32)==0){bN=c[277228]&65535}else{bN=b[(c[277226]|0)+(aE<<1)>>1]|0}aE=bM&-2048;aI=bN&-2048;aH=(aE&65535)>(aI&65535)?aE-aI&65535:0;aI=bM&2016;aE=bN&2016;if((aI&65535)>(aE&65535)){bO=(aI-aE&65535)+aH&65535}else{bO=aH}aH=bM&31;aE=bN&31;if((aH&65535)>(aE&65535)){bP=(aH-aE&65535)+bO&65535}else{bP=bO}aE=i+15|0;b[(c[277218]|0)+(aE<<1)>>1]=bP;aH=a[1108909]|0;a[(c[277219]|0)+aE|0]=aH;a[(c[277219]|0)+aJ|0]=aH}}while(0);aJ=l-1|0;if((aJ|0)<=0){break}e=e+8|0;l=aJ;i=(c[277223]|0)+i|0}return}i=o+(56-g)|0;g=(h|0)>0;if(j){if(g){bQ=i;bR=h;bS=f}else{return}while(1){j=a[1108908]|0;o=c[277219]|0;do{if((j&255)>(d[o+bS|0]|0)){l=a[bQ+7|0]|0;e=l&255;if(l<<24>>24==0){bT=j;bU=o;break}l=b[(c[277225]|0)+(e<<1)>>1]|0;if((a[(c[277215]|0)+bS|0]&32)==0){bV=c[277228]&65535}else{bV=b[(c[277213]|0)+(bS<<1)>>1]|0}bP=l&-2048;bO=bV&-2048;bN=(bP&65535)>(bO&65535)?bP-bO&65535:0;bO=l&2016;bP=bV&2016;if((bO&65535)>(bP&65535)){bW=(bO-bP&65535)+bN&65535}else{bW=bN}bN=l&31;l=bV&31;if((bN&65535)>(l&65535)){bX=(bN-l&65535)+bW&65535}else{bX=bW}b[(c[277218]|0)+(bS<<1)>>1]=bX;if((a[1108928]|0)==0){bY=b[(c[277213]|0)+(bS+2<<1)>>1]|0}else{bY=0}if((a[(c[277215]|0)+bS|0]&32)==0){bZ=c[277228]&65535}else{bZ=b[(c[277226]|0)+(e<<1)>>1]|0}e=bY&-2048;l=bZ&-2048;bN=(e&65535)>(l&65535)?e-l&65535:0;l=bY&2016;e=bZ&2016;if((l&65535)>(e&65535)){b_=(l-e&65535)+bN&65535}else{b_=bN}bN=bY&31;e=bZ&31;if((bN&65535)>(e&65535)){b$=(bN-e&65535)+b_&65535}else{b$=b_}e=bS+1|0;b[(c[277218]|0)+(e<<1)>>1]=b$;bN=a[1108909]|0;a[(c[277219]|0)+e|0]=bN;a[(c[277219]|0)+bS|0]=bN;bT=a[1108908]|0;bU=c[277219]|0}else{bT=j;bU=o}}while(0);o=bS+2|0;do{if((bT&255)>(d[bU+o|0]|0)){j=a[bQ+6|0]|0;bN=j&255;if(j<<24>>24==0){b0=bT;b1=bU;break}j=b[(c[277225]|0)+(bN<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){b2=c[277228]&65535}else{b2=b[(c[277213]|0)+(o<<1)>>1]|0}e=j&-2048;l=b2&-2048;bP=(e&65535)>(l&65535)?e-l&65535:0;l=j&2016;e=b2&2016;if((l&65535)>(e&65535)){b3=(l-e&65535)+bP&65535}else{b3=bP}bP=j&31;j=b2&31;if((bP&65535)>(j&65535)){b4=(bP-j&65535)+b3&65535}else{b4=b3}b[(c[277218]|0)+(o<<1)>>1]=b4;if((a[1108928]|0)==0){b5=b[(c[277213]|0)+(bS+4<<1)>>1]|0}else{b5=0}if((a[(c[277215]|0)+o|0]&32)==0){b6=c[277228]&65535}else{b6=b[(c[277226]|0)+(bN<<1)>>1]|0}bN=b5&-2048;j=b6&-2048;bP=(bN&65535)>(j&65535)?bN-j&65535:0;j=b5&2016;bN=b6&2016;if((j&65535)>(bN&65535)){b7=(j-bN&65535)+bP&65535}else{b7=bP}bP=b5&31;bN=b6&31;if((bP&65535)>(bN&65535)){b8=(bP-bN&65535)+b7&65535}else{b8=b7}bN=bS+3|0;b[(c[277218]|0)+(bN<<1)>>1]=b8;bP=a[1108909]|0;a[(c[277219]|0)+bN|0]=bP;a[(c[277219]|0)+o|0]=bP;b0=a[1108908]|0;b1=c[277219]|0}else{b0=bT;b1=bU}}while(0);o=bS+4|0;do{if((b0&255)>(d[b1+o|0]|0)){bP=a[bQ+5|0]|0;bN=bP&255;if(bP<<24>>24==0){b9=b0;ca=b1;break}bP=b[(c[277225]|0)+(bN<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){cb=c[277228]&65535}else{cb=b[(c[277213]|0)+(o<<1)>>1]|0}j=bP&-2048;e=cb&-2048;l=(j&65535)>(e&65535)?j-e&65535:0;e=bP&2016;j=cb&2016;if((e&65535)>(j&65535)){cc=(e-j&65535)+l&65535}else{cc=l}l=bP&31;bP=cb&31;if((l&65535)>(bP&65535)){cd=(l-bP&65535)+cc&65535}else{cd=cc}b[(c[277218]|0)+(o<<1)>>1]=cd;if((a[1108928]|0)==0){ce=b[(c[277213]|0)+(bS+6<<1)>>1]|0}else{ce=0}if((a[(c[277215]|0)+o|0]&32)==0){cf=c[277228]&65535}else{cf=b[(c[277226]|0)+(bN<<1)>>1]|0}bN=ce&-2048;bP=cf&-2048;l=(bN&65535)>(bP&65535)?bN-bP&65535:0;bP=ce&2016;bN=cf&2016;if((bP&65535)>(bN&65535)){cg=(bP-bN&65535)+l&65535}else{cg=l}l=ce&31;bN=cf&31;if((l&65535)>(bN&65535)){ch=(l-bN&65535)+cg&65535}else{ch=cg}bN=bS+5|0;b[(c[277218]|0)+(bN<<1)>>1]=ch;l=a[1108909]|0;a[(c[277219]|0)+bN|0]=l;a[(c[277219]|0)+o|0]=l;b9=a[1108908]|0;ca=c[277219]|0}else{b9=b0;ca=b1}}while(0);o=bS+6|0;do{if((b9&255)>(d[ca+o|0]|0)){l=a[bQ+4|0]|0;bN=l&255;if(l<<24>>24==0){ci=b9;cj=ca;break}l=b[(c[277225]|0)+(bN<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){ck=c[277228]&65535}else{ck=b[(c[277213]|0)+(o<<1)>>1]|0}bP=l&-2048;j=ck&-2048;e=(bP&65535)>(j&65535)?bP-j&65535:0;j=l&2016;bP=ck&2016;if((j&65535)>(bP&65535)){cl=(j-bP&65535)+e&65535}else{cl=e}e=l&31;l=ck&31;if((e&65535)>(l&65535)){cm=(e-l&65535)+cl&65535}else{cm=cl}b[(c[277218]|0)+(o<<1)>>1]=cm;if((a[1108928]|0)==0){cn=b[(c[277213]|0)+(bS+8<<1)>>1]|0}else{cn=0}if((a[(c[277215]|0)+o|0]&32)==0){co=c[277228]&65535}else{co=b[(c[277226]|0)+(bN<<1)>>1]|0}bN=cn&-2048;l=co&-2048;e=(bN&65535)>(l&65535)?bN-l&65535:0;l=cn&2016;bN=co&2016;if((l&65535)>(bN&65535)){cp=(l-bN&65535)+e&65535}else{cp=e}e=cn&31;bN=co&31;if((e&65535)>(bN&65535)){cq=(e-bN&65535)+cp&65535}else{cq=cp}bN=bS+7|0;b[(c[277218]|0)+(bN<<1)>>1]=cq;e=a[1108909]|0;a[(c[277219]|0)+bN|0]=e;a[(c[277219]|0)+o|0]=e;ci=a[1108908]|0;cj=c[277219]|0}else{ci=b9;cj=ca}}while(0);o=bS+8|0;do{if((ci&255)>(d[cj+o|0]|0)){e=a[bQ+3|0]|0;bN=e&255;if(e<<24>>24==0){cr=ci;cs=cj;break}e=b[(c[277225]|0)+(bN<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){ct=c[277228]&65535}else{ct=b[(c[277213]|0)+(o<<1)>>1]|0}l=e&-2048;bP=ct&-2048;j=(l&65535)>(bP&65535)?l-bP&65535:0;bP=e&2016;l=ct&2016;if((bP&65535)>(l&65535)){cu=(bP-l&65535)+j&65535}else{cu=j}j=e&31;e=ct&31;if((j&65535)>(e&65535)){cv=(j-e&65535)+cu&65535}else{cv=cu}b[(c[277218]|0)+(o<<1)>>1]=cv;if((a[1108928]|0)==0){cw=b[(c[277213]|0)+(bS+10<<1)>>1]|0}else{cw=0}if((a[(c[277215]|0)+o|0]&32)==0){cx=c[277228]&65535}else{cx=b[(c[277226]|0)+(bN<<1)>>1]|0}bN=cw&-2048;e=cx&-2048;j=(bN&65535)>(e&65535)?bN-e&65535:0;e=cw&2016;bN=cx&2016;if((e&65535)>(bN&65535)){cy=(e-bN&65535)+j&65535}else{cy=j}j=cw&31;bN=cx&31;if((j&65535)>(bN&65535)){cz=(j-bN&65535)+cy&65535}else{cz=cy}bN=bS+9|0;b[(c[277218]|0)+(bN<<1)>>1]=cz;j=a[1108909]|0;a[(c[277219]|0)+bN|0]=j;a[(c[277219]|0)+o|0]=j;cr=a[1108908]|0;cs=c[277219]|0}else{cr=ci;cs=cj}}while(0);o=bS+10|0;do{if((cr&255)>(d[cs+o|0]|0)){j=a[bQ+2|0]|0;bN=j&255;if(j<<24>>24==0){cA=cr;cB=cs;break}j=b[(c[277225]|0)+(bN<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){cC=c[277228]&65535}else{cC=b[(c[277213]|0)+(o<<1)>>1]|0}e=j&-2048;l=cC&-2048;bP=(e&65535)>(l&65535)?e-l&65535:0;l=j&2016;e=cC&2016;if((l&65535)>(e&65535)){cD=(l-e&65535)+bP&65535}else{cD=bP}bP=j&31;j=cC&31;if((bP&65535)>(j&65535)){cE=(bP-j&65535)+cD&65535}else{cE=cD}b[(c[277218]|0)+(o<<1)>>1]=cE;if((a[1108928]|0)==0){cF=b[(c[277213]|0)+(bS+12<<1)>>1]|0}else{cF=0}if((a[(c[277215]|0)+o|0]&32)==0){cG=c[277228]&65535}else{cG=b[(c[277226]|0)+(bN<<1)>>1]|0}bN=cF&-2048;j=cG&-2048;bP=(bN&65535)>(j&65535)?bN-j&65535:0;j=cF&2016;bN=cG&2016;if((j&65535)>(bN&65535)){cH=(j-bN&65535)+bP&65535}else{cH=bP}bP=cF&31;bN=cG&31;if((bP&65535)>(bN&65535)){cI=(bP-bN&65535)+cH&65535}else{cI=cH}bN=bS+11|0;b[(c[277218]|0)+(bN<<1)>>1]=cI;bP=a[1108909]|0;a[(c[277219]|0)+bN|0]=bP;a[(c[277219]|0)+o|0]=bP;cA=a[1108908]|0;cB=c[277219]|0}else{cA=cr;cB=cs}}while(0);o=bS+12|0;do{if((cA&255)>(d[cB+o|0]|0)){bP=a[bQ+1|0]|0;bN=bP&255;if(bP<<24>>24==0){cJ=cA;cK=cB;break}bP=b[(c[277225]|0)+(bN<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){cL=c[277228]&65535}else{cL=b[(c[277213]|0)+(o<<1)>>1]|0}j=bP&-2048;e=cL&-2048;l=(j&65535)>(e&65535)?j-e&65535:0;e=bP&2016;j=cL&2016;if((e&65535)>(j&65535)){cM=(e-j&65535)+l&65535}else{cM=l}l=bP&31;bP=cL&31;if((l&65535)>(bP&65535)){cN=(l-bP&65535)+cM&65535}else{cN=cM}b[(c[277218]|0)+(o<<1)>>1]=cN;if((a[1108928]|0)==0){cO=b[(c[277213]|0)+(bS+14<<1)>>1]|0}else{cO=0}if((a[(c[277215]|0)+o|0]&32)==0){cP=c[277228]&65535}else{cP=b[(c[277226]|0)+(bN<<1)>>1]|0}bN=cO&-2048;bP=cP&-2048;l=(bN&65535)>(bP&65535)?bN-bP&65535:0;bP=cO&2016;bN=cP&2016;if((bP&65535)>(bN&65535)){cQ=(bP-bN&65535)+l&65535}else{cQ=l}l=cO&31;bN=cP&31;if((l&65535)>(bN&65535)){cR=(l-bN&65535)+cQ&65535}else{cR=cQ}bN=bS+13|0;b[(c[277218]|0)+(bN<<1)>>1]=cR;l=a[1108909]|0;a[(c[277219]|0)+bN|0]=l;a[(c[277219]|0)+o|0]=l;cJ=a[1108908]|0;cK=c[277219]|0}else{cJ=cA;cK=cB}}while(0);o=bS+14|0;do{if((cJ&255)>(d[cK+o|0]|0)){l=a[bQ]|0;bN=l&255;if(l<<24>>24==0){break}l=b[(c[277225]|0)+(bN<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){cS=c[277228]&65535}else{cS=b[(c[277213]|0)+(o<<1)>>1]|0}bP=l&-2048;j=cS&-2048;e=(bP&65535)>(j&65535)?bP-j&65535:0;j=l&2016;bP=cS&2016;if((j&65535)>(bP&65535)){cT=(j-bP&65535)+e&65535}else{cT=e}e=l&31;l=cS&31;if((e&65535)>(l&65535)){cU=(e-l&65535)+cT&65535}else{cU=cT}b[(c[277218]|0)+(o<<1)>>1]=cU;if((a[1108928]|0)==0){cV=b[(c[277213]|0)+(bS+16<<1)>>1]|0}else{cV=0}if((a[(c[277215]|0)+o|0]&32)==0){cW=c[277228]&65535}else{cW=b[(c[277226]|0)+(bN<<1)>>1]|0}bN=cV&-2048;l=cW&-2048;e=(bN&65535)>(l&65535)?bN-l&65535:0;l=cV&2016;bN=cW&2016;if((l&65535)>(bN&65535)){cX=(l-bN&65535)+e&65535}else{cX=e}e=cV&31;bN=cW&31;if((e&65535)>(bN&65535)){cY=(e-bN&65535)+cX&65535}else{cY=cX}bN=bS+15|0;b[(c[277218]|0)+(bN<<1)>>1]=cY;e=a[1108909]|0;a[(c[277219]|0)+bN|0]=e;a[(c[277219]|0)+o|0]=e}}while(0);o=bR-1|0;if((o|0)<=0){break}bQ=bQ-8|0;bR=o;bS=(c[277223]|0)+bS|0}return}else{if(g){cZ=i;c_=h;c$=f}else{return}while(1){f=a[1108908]|0;h=c[277219]|0;do{if((f&255)>(d[h+c$|0]|0)){i=a[cZ]|0;g=i&255;if(i<<24>>24==0){c0=f;c1=h;break}i=b[(c[277225]|0)+(g<<1)>>1]|0;if((a[(c[277215]|0)+c$|0]&32)==0){c2=c[277228]&65535}else{c2=b[(c[277213]|0)+(c$<<1)>>1]|0}bS=i&-2048;bR=c2&-2048;bQ=(bS&65535)>(bR&65535)?bS-bR&65535:0;bR=i&2016;bS=c2&2016;if((bR&65535)>(bS&65535)){c3=(bR-bS&65535)+bQ&65535}else{c3=bQ}bQ=i&31;i=c2&31;if((bQ&65535)>(i&65535)){c4=(bQ-i&65535)+c3&65535}else{c4=c3}b[(c[277218]|0)+(c$<<1)>>1]=c4;if((a[1108928]|0)==0){c5=b[(c[277213]|0)+(c$+2<<1)>>1]|0}else{c5=0}if((a[(c[277215]|0)+c$|0]&32)==0){c6=c[277228]&65535}else{c6=b[(c[277226]|0)+(g<<1)>>1]|0}g=c5&-2048;i=c6&-2048;bQ=(g&65535)>(i&65535)?g-i&65535:0;i=c5&2016;g=c6&2016;if((i&65535)>(g&65535)){c7=(i-g&65535)+bQ&65535}else{c7=bQ}bQ=c5&31;g=c6&31;if((bQ&65535)>(g&65535)){c8=(bQ-g&65535)+c7&65535}else{c8=c7}g=c$+1|0;b[(c[277218]|0)+(g<<1)>>1]=c8;bQ=a[1108909]|0;a[(c[277219]|0)+g|0]=bQ;a[(c[277219]|0)+c$|0]=bQ;c0=a[1108908]|0;c1=c[277219]|0}else{c0=f;c1=h}}while(0);h=c$+2|0;do{if((c0&255)>(d[c1+h|0]|0)){f=a[cZ+1|0]|0;bQ=f&255;if(f<<24>>24==0){c9=c0;da=c1;break}f=b[(c[277225]|0)+(bQ<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)==0){db=c[277228]&65535}else{db=b[(c[277213]|0)+(h<<1)>>1]|0}g=f&-2048;i=db&-2048;bS=(g&65535)>(i&65535)?g-i&65535:0;i=f&2016;g=db&2016;if((i&65535)>(g&65535)){dc=(i-g&65535)+bS&65535}else{dc=bS}bS=f&31;f=db&31;if((bS&65535)>(f&65535)){dd=(bS-f&65535)+dc&65535}else{dd=dc}b[(c[277218]|0)+(h<<1)>>1]=dd;if((a[1108928]|0)==0){de=b[(c[277213]|0)+(c$+4<<1)>>1]|0}else{de=0}if((a[(c[277215]|0)+h|0]&32)==0){df=c[277228]&65535}else{df=b[(c[277226]|0)+(bQ<<1)>>1]|0}bQ=de&-2048;f=df&-2048;bS=(bQ&65535)>(f&65535)?bQ-f&65535:0;f=de&2016;bQ=df&2016;if((f&65535)>(bQ&65535)){dg=(f-bQ&65535)+bS&65535}else{dg=bS}bS=de&31;bQ=df&31;if((bS&65535)>(bQ&65535)){dh=(bS-bQ&65535)+dg&65535}else{dh=dg}bQ=c$+3|0;b[(c[277218]|0)+(bQ<<1)>>1]=dh;bS=a[1108909]|0;a[(c[277219]|0)+bQ|0]=bS;a[(c[277219]|0)+h|0]=bS;c9=a[1108908]|0;da=c[277219]|0}else{c9=c0;da=c1}}while(0);h=c$+4|0;do{if((c9&255)>(d[da+h|0]|0)){bS=a[cZ+2|0]|0;bQ=bS&255;if(bS<<24>>24==0){di=c9;dj=da;break}bS=b[(c[277225]|0)+(bQ<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)==0){dk=c[277228]&65535}else{dk=b[(c[277213]|0)+(h<<1)>>1]|0}f=bS&-2048;g=dk&-2048;i=(f&65535)>(g&65535)?f-g&65535:0;g=bS&2016;f=dk&2016;if((g&65535)>(f&65535)){dl=(g-f&65535)+i&65535}else{dl=i}i=bS&31;bS=dk&31;if((i&65535)>(bS&65535)){dm=(i-bS&65535)+dl&65535}else{dm=dl}b[(c[277218]|0)+(h<<1)>>1]=dm;if((a[1108928]|0)==0){dn=b[(c[277213]|0)+(c$+6<<1)>>1]|0}else{dn=0}if((a[(c[277215]|0)+h|0]&32)==0){dp=c[277228]&65535}else{dp=b[(c[277226]|0)+(bQ<<1)>>1]|0}bQ=dn&-2048;bS=dp&-2048;i=(bQ&65535)>(bS&65535)?bQ-bS&65535:0;bS=dn&2016;bQ=dp&2016;if((bS&65535)>(bQ&65535)){dq=(bS-bQ&65535)+i&65535}else{dq=i}i=dn&31;bQ=dp&31;if((i&65535)>(bQ&65535)){dr=(i-bQ&65535)+dq&65535}else{dr=dq}bQ=c$+5|0;b[(c[277218]|0)+(bQ<<1)>>1]=dr;i=a[1108909]|0;a[(c[277219]|0)+bQ|0]=i;a[(c[277219]|0)+h|0]=i;di=a[1108908]|0;dj=c[277219]|0}else{di=c9;dj=da}}while(0);h=c$+6|0;do{if((di&255)>(d[dj+h|0]|0)){i=a[cZ+3|0]|0;bQ=i&255;if(i<<24>>24==0){ds=di;dt=dj;break}i=b[(c[277225]|0)+(bQ<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)==0){du=c[277228]&65535}else{du=b[(c[277213]|0)+(h<<1)>>1]|0}bS=i&-2048;f=du&-2048;g=(bS&65535)>(f&65535)?bS-f&65535:0;f=i&2016;bS=du&2016;if((f&65535)>(bS&65535)){dv=(f-bS&65535)+g&65535}else{dv=g}g=i&31;i=du&31;if((g&65535)>(i&65535)){dw=(g-i&65535)+dv&65535}else{dw=dv}b[(c[277218]|0)+(h<<1)>>1]=dw;if((a[1108928]|0)==0){dx=b[(c[277213]|0)+(c$+8<<1)>>1]|0}else{dx=0}if((a[(c[277215]|0)+h|0]&32)==0){dy=c[277228]&65535}else{dy=b[(c[277226]|0)+(bQ<<1)>>1]|0}bQ=dx&-2048;i=dy&-2048;g=(bQ&65535)>(i&65535)?bQ-i&65535:0;i=dx&2016;bQ=dy&2016;if((i&65535)>(bQ&65535)){dz=(i-bQ&65535)+g&65535}else{dz=g}g=dx&31;bQ=dy&31;if((g&65535)>(bQ&65535)){dA=(g-bQ&65535)+dz&65535}else{dA=dz}bQ=c$+7|0;b[(c[277218]|0)+(bQ<<1)>>1]=dA;g=a[1108909]|0;a[(c[277219]|0)+bQ|0]=g;a[(c[277219]|0)+h|0]=g;ds=a[1108908]|0;dt=c[277219]|0}else{ds=di;dt=dj}}while(0);h=c$+8|0;do{if((ds&255)>(d[dt+h|0]|0)){g=a[cZ+4|0]|0;bQ=g&255;if(g<<24>>24==0){dB=ds;dC=dt;break}g=b[(c[277225]|0)+(bQ<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)==0){dD=c[277228]&65535}else{dD=b[(c[277213]|0)+(h<<1)>>1]|0}i=g&-2048;bS=dD&-2048;f=(i&65535)>(bS&65535)?i-bS&65535:0;bS=g&2016;i=dD&2016;if((bS&65535)>(i&65535)){dE=(bS-i&65535)+f&65535}else{dE=f}f=g&31;g=dD&31;if((f&65535)>(g&65535)){dF=(f-g&65535)+dE&65535}else{dF=dE}b[(c[277218]|0)+(h<<1)>>1]=dF;if((a[1108928]|0)==0){dG=b[(c[277213]|0)+(c$+10<<1)>>1]|0}else{dG=0}if((a[(c[277215]|0)+h|0]&32)==0){dH=c[277228]&65535}else{dH=b[(c[277226]|0)+(bQ<<1)>>1]|0}bQ=dG&-2048;g=dH&-2048;f=(bQ&65535)>(g&65535)?bQ-g&65535:0;g=dG&2016;bQ=dH&2016;if((g&65535)>(bQ&65535)){dI=(g-bQ&65535)+f&65535}else{dI=f}f=dG&31;bQ=dH&31;if((f&65535)>(bQ&65535)){dJ=(f-bQ&65535)+dI&65535}else{dJ=dI}bQ=c$+9|0;b[(c[277218]|0)+(bQ<<1)>>1]=dJ;f=a[1108909]|0;a[(c[277219]|0)+bQ|0]=f;a[(c[277219]|0)+h|0]=f;dB=a[1108908]|0;dC=c[277219]|0}else{dB=ds;dC=dt}}while(0);h=c$+10|0;do{if((dB&255)>(d[dC+h|0]|0)){f=a[cZ+5|0]|0;bQ=f&255;if(f<<24>>24==0){dK=dB;dL=dC;break}f=b[(c[277225]|0)+(bQ<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)==0){dM=c[277228]&65535}else{dM=b[(c[277213]|0)+(h<<1)>>1]|0}g=f&-2048;i=dM&-2048;bS=(g&65535)>(i&65535)?g-i&65535:0;i=f&2016;g=dM&2016;if((i&65535)>(g&65535)){dN=(i-g&65535)+bS&65535}else{dN=bS}bS=f&31;f=dM&31;if((bS&65535)>(f&65535)){dO=(bS-f&65535)+dN&65535}else{dO=dN}b[(c[277218]|0)+(h<<1)>>1]=dO;if((a[1108928]|0)==0){dP=b[(c[277213]|0)+(c$+12<<1)>>1]|0}else{dP=0}if((a[(c[277215]|0)+h|0]&32)==0){dQ=c[277228]&65535}else{dQ=b[(c[277226]|0)+(bQ<<1)>>1]|0}bQ=dP&-2048;f=dQ&-2048;bS=(bQ&65535)>(f&65535)?bQ-f&65535:0;f=dP&2016;bQ=dQ&2016;if((f&65535)>(bQ&65535)){dR=(f-bQ&65535)+bS&65535}else{dR=bS}bS=dP&31;bQ=dQ&31;if((bS&65535)>(bQ&65535)){dS=(bS-bQ&65535)+dR&65535}else{dS=dR}bQ=c$+11|0;b[(c[277218]|0)+(bQ<<1)>>1]=dS;bS=a[1108909]|0;a[(c[277219]|0)+bQ|0]=bS;a[(c[277219]|0)+h|0]=bS;dK=a[1108908]|0;dL=c[277219]|0}else{dK=dB;dL=dC}}while(0);h=c$+12|0;do{if((dK&255)>(d[dL+h|0]|0)){bS=a[cZ+6|0]|0;bQ=bS&255;if(bS<<24>>24==0){dT=dK;dU=dL;break}bS=b[(c[277225]|0)+(bQ<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)==0){dV=c[277228]&65535}else{dV=b[(c[277213]|0)+(h<<1)>>1]|0}f=bS&-2048;g=dV&-2048;i=(f&65535)>(g&65535)?f-g&65535:0;g=bS&2016;f=dV&2016;if((g&65535)>(f&65535)){dW=(g-f&65535)+i&65535}else{dW=i}i=bS&31;bS=dV&31;if((i&65535)>(bS&65535)){dX=(i-bS&65535)+dW&65535}else{dX=dW}b[(c[277218]|0)+(h<<1)>>1]=dX;if((a[1108928]|0)==0){dY=b[(c[277213]|0)+(c$+14<<1)>>1]|0}else{dY=0}if((a[(c[277215]|0)+h|0]&32)==0){dZ=c[277228]&65535}else{dZ=b[(c[277226]|0)+(bQ<<1)>>1]|0}bQ=dY&-2048;bS=dZ&-2048;i=(bQ&65535)>(bS&65535)?bQ-bS&65535:0;bS=dY&2016;bQ=dZ&2016;if((bS&65535)>(bQ&65535)){d_=(bS-bQ&65535)+i&65535}else{d_=i}i=dY&31;bQ=dZ&31;if((i&65535)>(bQ&65535)){d$=(i-bQ&65535)+d_&65535}else{d$=d_}bQ=c$+13|0;b[(c[277218]|0)+(bQ<<1)>>1]=d$;i=a[1108909]|0;a[(c[277219]|0)+bQ|0]=i;a[(c[277219]|0)+h|0]=i;dT=a[1108908]|0;dU=c[277219]|0}else{dT=dK;dU=dL}}while(0);h=c$+14|0;do{if((dT&255)>(d[dU+h|0]|0)){i=a[cZ+7|0]|0;bQ=i&255;if(i<<24>>24==0){break}i=b[(c[277225]|0)+(bQ<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)==0){d0=c[277228]&65535}else{d0=b[(c[277213]|0)+(h<<1)>>1]|0}bS=i&-2048;f=d0&-2048;g=(bS&65535)>(f&65535)?bS-f&65535:0;f=i&2016;bS=d0&2016;if((f&65535)>(bS&65535)){d1=(f-bS&65535)+g&65535}else{d1=g}g=i&31;i=d0&31;if((g&65535)>(i&65535)){d2=(g-i&65535)+d1&65535}else{d2=d1}b[(c[277218]|0)+(h<<1)>>1]=d2;if((a[1108928]|0)==0){d3=b[(c[277213]|0)+(c$+16<<1)>>1]|0}else{d3=0}if((a[(c[277215]|0)+h|0]&32)==0){d4=c[277228]&65535}else{d4=b[(c[277226]|0)+(bQ<<1)>>1]|0}bQ=d3&-2048;i=d4&-2048;g=(bQ&65535)>(i&65535)?bQ-i&65535:0;i=d3&2016;bQ=d4&2016;if((i&65535)>(bQ&65535)){d5=(i-bQ&65535)+g&65535}else{d5=g}g=d3&31;bQ=d4&31;if((g&65535)>(bQ&65535)){d6=(g-bQ&65535)+d5&65535}else{d6=d5}bQ=c$+15|0;b[(c[277218]|0)+(bQ<<1)>>1]=d6;g=a[1108909]|0;a[(c[277219]|0)+bQ|0]=g;a[(c[277219]|0)+h|0]=g}}while(0);h=c_-1|0;if((h|0)<=0){break}cZ=cZ-8|0;c_=h;c$=(c[277223]|0)+c$|0}return}}function VM(f,g,h,i){f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0;j=f&1023;k=c[348606]|0;l=(j<<k)+(c[348604]|0)|0;if((f&256|0)==0){m=l}else{m=(c[348602]|0)+l|0}l=m&65535;m=l>>>(k>>>0);k=(f&16384|0)!=0;n=m<<6;do{if(k){o=(c[348622]|0)+n|0;if((a[(c[348618]|0)+m|0]|0)!=0){p=o;break}q=fi[c[348636]&63](o,l,j)|0;a[(c[348618]|0)+m|0]=q;p=o}else{o=(c[348624]|0)+n|0;if((a[(c[348620]|0)+m|0]|0)!=0){p=o;break}q=fi[c[348638]&63](o,l,j)|0;a[(c[348620]|0)+m|0]=q;p=o}}while(0);if((a[(c[348620]|0)+m|0]|0)==2){return}if((a[1394464]|0)==0){r=1106168+((f>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){m=d[1044485]|0;c[276541]=7080+(m<<5);j=0;do{l=j<<1&2;n=j&2;o=j&4;q=0;do{b[1125528+(j<<9)+(q<<1)>>1]=d[(q>>>1&28|n)+(7080+(m<<5))|0]<<6|d[(q<<2&28|l)+(7080+(m<<5))|0]<<11|d[(q>>>3&24|o)+(7080+(m<<5))|0];q=q+1|0;}while(q>>>0<256);j=j+1|0;}while(j>>>0<8);a[1106089]=0}r=1125528+((f>>>10&7)<<9)|0}c[277226]=r;c[277225]=(a[1108928]|0)!=0?1393712:r;if((f&49152|0)==0){if((i|0)<=0){return}r=p+h|0;j=i;m=g;while(1){q=a[1108908]|0;o=c[277219]|0;do{if((q&255)>(d[o+m|0]|0)){l=a[r]|0;if(l<<24>>24==0){s=q;t=o;break}n=b[(c[277225]|0)+((l&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){u=b[(c[277221]|0)+(((n&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{l=c[277228]&65535;v=n&-2048;w=l&-2048;x=(v&65535)>(w&65535)?v-w&65535:0;w=n&2016;v=l&2016;if((w&65535)>(v&65535)){y=(w-v&65535)+x&65535}else{y=x}x=n&31;v=l&31;if((x&65535)<=(v&65535)){u=y;break}u=(x-v&65535)+y&65535}}while(0);b[(c[277218]|0)+(m<<1)>>1]=u;if((a[1108928]|0)==0){z=b[(c[277221]|0)+(((e[(c[277213]|0)+(m+2<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{z=0}n=m+1|0;b[(c[277218]|0)+(n<<1)>>1]=z;v=a[1108909]|0;a[(c[277219]|0)+n|0]=v;a[(c[277219]|0)+m|0]=v;s=a[1108908]|0;t=c[277219]|0}else{s=q;t=o}}while(0);o=m+2|0;do{if((s&255)>(d[t+o|0]|0)){q=a[r+1|0]|0;if(q<<24>>24==0){A=s;B=t;break}v=b[(c[277225]|0)+((q&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){C=b[(c[277221]|0)+(((v&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{q=c[277228]&65535;n=v&-2048;x=q&-2048;l=(n&65535)>(x&65535)?n-x&65535:0;x=v&2016;n=q&2016;if((x&65535)>(n&65535)){D=(x-n&65535)+l&65535}else{D=l}l=v&31;n=q&31;if((l&65535)<=(n&65535)){C=D;break}C=(l-n&65535)+D&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=C;if((a[1108928]|0)==0){E=b[(c[277221]|0)+(((e[(c[277213]|0)+(m+4<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{E=0}v=m+3|0;b[(c[277218]|0)+(v<<1)>>1]=E;n=a[1108909]|0;a[(c[277219]|0)+v|0]=n;a[(c[277219]|0)+o|0]=n;A=a[1108908]|0;B=c[277219]|0}else{A=s;B=t}}while(0);o=m+4|0;do{if((A&255)>(d[B+o|0]|0)){n=a[r+2|0]|0;if(n<<24>>24==0){F=A;G=B;break}v=b[(c[277225]|0)+((n&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){H=b[(c[277221]|0)+(((v&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{n=c[277228]&65535;l=v&-2048;q=n&-2048;x=(l&65535)>(q&65535)?l-q&65535:0;q=v&2016;l=n&2016;if((q&65535)>(l&65535)){I=(q-l&65535)+x&65535}else{I=x}x=v&31;l=n&31;if((x&65535)<=(l&65535)){H=I;break}H=(x-l&65535)+I&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=H;if((a[1108928]|0)==0){J=b[(c[277221]|0)+(((e[(c[277213]|0)+(m+6<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{J=0}v=m+5|0;b[(c[277218]|0)+(v<<1)>>1]=J;l=a[1108909]|0;a[(c[277219]|0)+v|0]=l;a[(c[277219]|0)+o|0]=l;F=a[1108908]|0;G=c[277219]|0}else{F=A;G=B}}while(0);o=m+6|0;do{if((F&255)>(d[G+o|0]|0)){l=a[r+3|0]|0;if(l<<24>>24==0){K=F;L=G;break}v=b[(c[277225]|0)+((l&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){M=b[(c[277221]|0)+(((v&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{l=c[277228]&65535;x=v&-2048;n=l&-2048;q=(x&65535)>(n&65535)?x-n&65535:0;n=v&2016;x=l&2016;if((n&65535)>(x&65535)){N=(n-x&65535)+q&65535}else{N=q}q=v&31;x=l&31;if((q&65535)<=(x&65535)){M=N;break}M=(q-x&65535)+N&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=M;if((a[1108928]|0)==0){O=b[(c[277221]|0)+(((e[(c[277213]|0)+(m+8<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{O=0}v=m+7|0;b[(c[277218]|0)+(v<<1)>>1]=O;x=a[1108909]|0;a[(c[277219]|0)+v|0]=x;a[(c[277219]|0)+o|0]=x;K=a[1108908]|0;L=c[277219]|0}else{K=F;L=G}}while(0);o=m+8|0;do{if((K&255)>(d[L+o|0]|0)){x=a[r+4|0]|0;if(x<<24>>24==0){P=K;Q=L;break}v=b[(c[277225]|0)+((x&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){R=b[(c[277221]|0)+(((v&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{x=c[277228]&65535;q=v&-2048;l=x&-2048;n=(q&65535)>(l&65535)?q-l&65535:0;l=v&2016;q=x&2016;if((l&65535)>(q&65535)){S=(l-q&65535)+n&65535}else{S=n}n=v&31;q=x&31;if((n&65535)<=(q&65535)){R=S;break}R=(n-q&65535)+S&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=R;if((a[1108928]|0)==0){T=b[(c[277221]|0)+(((e[(c[277213]|0)+(m+10<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{T=0}v=m+9|0;b[(c[277218]|0)+(v<<1)>>1]=T;q=a[1108909]|0;a[(c[277219]|0)+v|0]=q;a[(c[277219]|0)+o|0]=q;P=a[1108908]|0;Q=c[277219]|0}else{P=K;Q=L}}while(0);o=m+10|0;do{if((P&255)>(d[Q+o|0]|0)){q=a[r+5|0]|0;if(q<<24>>24==0){U=P;V=Q;break}v=b[(c[277225]|0)+((q&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){W=b[(c[277221]|0)+(((v&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{q=c[277228]&65535;n=v&-2048;x=q&-2048;l=(n&65535)>(x&65535)?n-x&65535:0;x=v&2016;n=q&2016;if((x&65535)>(n&65535)){X=(x-n&65535)+l&65535}else{X=l}l=v&31;n=q&31;if((l&65535)<=(n&65535)){W=X;break}W=(l-n&65535)+X&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=W;if((a[1108928]|0)==0){Y=b[(c[277221]|0)+(((e[(c[277213]|0)+(m+12<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{Y=0}v=m+11|0;b[(c[277218]|0)+(v<<1)>>1]=Y;n=a[1108909]|0;a[(c[277219]|0)+v|0]=n;a[(c[277219]|0)+o|0]=n;U=a[1108908]|0;V=c[277219]|0}else{U=P;V=Q}}while(0);o=m+12|0;do{if((U&255)>(d[V+o|0]|0)){n=a[r+6|0]|0;if(n<<24>>24==0){Z=U;_=V;break}v=b[(c[277225]|0)+((n&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){$=b[(c[277221]|0)+(((v&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{n=c[277228]&65535;l=v&-2048;q=n&-2048;x=(l&65535)>(q&65535)?l-q&65535:0;q=v&2016;l=n&2016;if((q&65535)>(l&65535)){aa=(q-l&65535)+x&65535}else{aa=x}x=v&31;l=n&31;if((x&65535)<=(l&65535)){$=aa;break}$=(x-l&65535)+aa&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=$;if((a[1108928]|0)==0){ab=b[(c[277221]|0)+(((e[(c[277213]|0)+(m+14<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{ab=0}v=m+13|0;b[(c[277218]|0)+(v<<1)>>1]=ab;l=a[1108909]|0;a[(c[277219]|0)+v|0]=l;a[(c[277219]|0)+o|0]=l;Z=a[1108908]|0;_=c[277219]|0}else{Z=U;_=V}}while(0);o=m+14|0;do{if((Z&255)>(d[_+o|0]|0)){l=a[r+7|0]|0;if(l<<24>>24==0){break}v=b[(c[277225]|0)+((l&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){ac=b[(c[277221]|0)+(((v&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{l=c[277228]&65535;x=v&-2048;n=l&-2048;q=(x&65535)>(n&65535)?x-n&65535:0;n=v&2016;x=l&2016;if((n&65535)>(x&65535)){ad=(n-x&65535)+q&65535}else{ad=q}q=v&31;x=l&31;if((q&65535)<=(x&65535)){ac=ad;break}ac=(q-x&65535)+ad&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=ac;if((a[1108928]|0)==0){ae=b[(c[277221]|0)+(((e[(c[277213]|0)+(m+16<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{ae=0}v=m+15|0;b[(c[277218]|0)+(v<<1)>>1]=ae;x=a[1108909]|0;a[(c[277219]|0)+v|0]=x;a[(c[277219]|0)+o|0]=x}}while(0);o=j-1|0;if((o|0)<=0){break}r=r+8|0;j=o;m=(c[277223]|0)+m|0}return}if((f&32768|0)==0){if((i|0)<=0){return}f=p+h|0;m=i;j=g;while(1){r=a[1108908]|0;ae=c[277219]|0;do{if((r&255)>(d[ae+j|0]|0)){ac=a[f+7|0]|0;if(ac<<24>>24==0){af=r;ag=ae;break}ad=b[(c[277225]|0)+((ac&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){ah=b[(c[277221]|0)+(((ad&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{ac=c[277228]&65535;_=ad&-2048;Z=ac&-2048;V=(_&65535)>(Z&65535)?_-Z&65535:0;Z=ad&2016;_=ac&2016;if((Z&65535)>(_&65535)){ai=(Z-_&65535)+V&65535}else{ai=V}V=ad&31;_=ac&31;if((V&65535)<=(_&65535)){ah=ai;break}ah=(V-_&65535)+ai&65535}}while(0);b[(c[277218]|0)+(j<<1)>>1]=ah;if((a[1108928]|0)==0){aj=b[(c[277221]|0)+(((e[(c[277213]|0)+(j+2<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{aj=0}ad=j+1|0;b[(c[277218]|0)+(ad<<1)>>1]=aj;_=a[1108909]|0;a[(c[277219]|0)+ad|0]=_;a[(c[277219]|0)+j|0]=_;af=a[1108908]|0;ag=c[277219]|0}else{af=r;ag=ae}}while(0);ae=j+2|0;do{if((af&255)>(d[ag+ae|0]|0)){r=a[f+6|0]|0;if(r<<24>>24==0){ak=af;al=ag;break}_=b[(c[277225]|0)+((r&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){am=b[(c[277221]|0)+(((_&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{r=c[277228]&65535;ad=_&-2048;V=r&-2048;ac=(ad&65535)>(V&65535)?ad-V&65535:0;V=_&2016;ad=r&2016;if((V&65535)>(ad&65535)){an=(V-ad&65535)+ac&65535}else{an=ac}ac=_&31;ad=r&31;if((ac&65535)<=(ad&65535)){am=an;break}am=(ac-ad&65535)+an&65535}}while(0);b[(c[277218]|0)+(ae<<1)>>1]=am;if((a[1108928]|0)==0){ao=b[(c[277221]|0)+(((e[(c[277213]|0)+(j+4<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{ao=0}_=j+3|0;b[(c[277218]|0)+(_<<1)>>1]=ao;ad=a[1108909]|0;a[(c[277219]|0)+_|0]=ad;a[(c[277219]|0)+ae|0]=ad;ak=a[1108908]|0;al=c[277219]|0}else{ak=af;al=ag}}while(0);ae=j+4|0;do{if((ak&255)>(d[al+ae|0]|0)){ad=a[f+5|0]|0;if(ad<<24>>24==0){ap=ak;aq=al;break}_=b[(c[277225]|0)+((ad&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){ar=b[(c[277221]|0)+(((_&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{ad=c[277228]&65535;ac=_&-2048;r=ad&-2048;V=(ac&65535)>(r&65535)?ac-r&65535:0;r=_&2016;ac=ad&2016;if((r&65535)>(ac&65535)){as=(r-ac&65535)+V&65535}else{as=V}V=_&31;ac=ad&31;if((V&65535)<=(ac&65535)){ar=as;break}ar=(V-ac&65535)+as&65535}}while(0);b[(c[277218]|0)+(ae<<1)>>1]=ar;if((a[1108928]|0)==0){at=b[(c[277221]|0)+(((e[(c[277213]|0)+(j+6<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{at=0}_=j+5|0;b[(c[277218]|0)+(_<<1)>>1]=at;ac=a[1108909]|0;a[(c[277219]|0)+_|0]=ac;a[(c[277219]|0)+ae|0]=ac;ap=a[1108908]|0;aq=c[277219]|0}else{ap=ak;aq=al}}while(0);ae=j+6|0;do{if((ap&255)>(d[aq+ae|0]|0)){ac=a[f+4|0]|0;if(ac<<24>>24==0){au=ap;av=aq;break}_=b[(c[277225]|0)+((ac&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aw=b[(c[277221]|0)+(((_&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{ac=c[277228]&65535;V=_&-2048;ad=ac&-2048;r=(V&65535)>(ad&65535)?V-ad&65535:0;ad=_&2016;V=ac&2016;if((ad&65535)>(V&65535)){ax=(ad-V&65535)+r&65535}else{ax=r}r=_&31;V=ac&31;if((r&65535)<=(V&65535)){aw=ax;break}aw=(r-V&65535)+ax&65535}}while(0);b[(c[277218]|0)+(ae<<1)>>1]=aw;if((a[1108928]|0)==0){ay=b[(c[277221]|0)+(((e[(c[277213]|0)+(j+8<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{ay=0}_=j+7|0;b[(c[277218]|0)+(_<<1)>>1]=ay;V=a[1108909]|0;a[(c[277219]|0)+_|0]=V;a[(c[277219]|0)+ae|0]=V;au=a[1108908]|0;av=c[277219]|0}else{au=ap;av=aq}}while(0);ae=j+8|0;do{if((au&255)>(d[av+ae|0]|0)){V=a[f+3|0]|0;if(V<<24>>24==0){az=au;aA=av;break}_=b[(c[277225]|0)+((V&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aB=b[(c[277221]|0)+(((_&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{V=c[277228]&65535;r=_&-2048;ac=V&-2048;ad=(r&65535)>(ac&65535)?r-ac&65535:0;ac=_&2016;r=V&2016;if((ac&65535)>(r&65535)){aC=(ac-r&65535)+ad&65535}else{aC=ad}ad=_&31;r=V&31;if((ad&65535)<=(r&65535)){aB=aC;break}aB=(ad-r&65535)+aC&65535}}while(0);b[(c[277218]|0)+(ae<<1)>>1]=aB;if((a[1108928]|0)==0){aD=b[(c[277221]|0)+(((e[(c[277213]|0)+(j+10<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{aD=0}_=j+9|0;b[(c[277218]|0)+(_<<1)>>1]=aD;r=a[1108909]|0;a[(c[277219]|0)+_|0]=r;a[(c[277219]|0)+ae|0]=r;az=a[1108908]|0;aA=c[277219]|0}else{az=au;aA=av}}while(0);ae=j+10|0;do{if((az&255)>(d[aA+ae|0]|0)){r=a[f+2|0]|0;if(r<<24>>24==0){aE=az;aF=aA;break}_=b[(c[277225]|0)+((r&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aG=b[(c[277221]|0)+(((_&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{r=c[277228]&65535;ad=_&-2048;V=r&-2048;ac=(ad&65535)>(V&65535)?ad-V&65535:0;V=_&2016;ad=r&2016;if((V&65535)>(ad&65535)){aH=(V-ad&65535)+ac&65535}else{aH=ac}ac=_&31;ad=r&31;if((ac&65535)<=(ad&65535)){aG=aH;break}aG=(ac-ad&65535)+aH&65535}}while(0);b[(c[277218]|0)+(ae<<1)>>1]=aG;if((a[1108928]|0)==0){aI=b[(c[277221]|0)+(((e[(c[277213]|0)+(j+12<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{aI=0}_=j+11|0;b[(c[277218]|0)+(_<<1)>>1]=aI;ad=a[1108909]|0;a[(c[277219]|0)+_|0]=ad;a[(c[277219]|0)+ae|0]=ad;aE=a[1108908]|0;aF=c[277219]|0}else{aE=az;aF=aA}}while(0);ae=j+12|0;do{if((aE&255)>(d[aF+ae|0]|0)){ad=a[f+1|0]|0;if(ad<<24>>24==0){aJ=aE;aK=aF;break}_=b[(c[277225]|0)+((ad&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aL=b[(c[277221]|0)+(((_&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{ad=c[277228]&65535;ac=_&-2048;r=ad&-2048;V=(ac&65535)>(r&65535)?ac-r&65535:0;r=_&2016;ac=ad&2016;if((r&65535)>(ac&65535)){aM=(r-ac&65535)+V&65535}else{aM=V}V=_&31;ac=ad&31;if((V&65535)<=(ac&65535)){aL=aM;break}aL=(V-ac&65535)+aM&65535}}while(0);b[(c[277218]|0)+(ae<<1)>>1]=aL;if((a[1108928]|0)==0){aN=b[(c[277221]|0)+(((e[(c[277213]|0)+(j+14<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{aN=0}_=j+13|0;b[(c[277218]|0)+(_<<1)>>1]=aN;ac=a[1108909]|0;a[(c[277219]|0)+_|0]=ac;a[(c[277219]|0)+ae|0]=ac;aJ=a[1108908]|0;aK=c[277219]|0}else{aJ=aE;aK=aF}}while(0);ae=j+14|0;do{if((aJ&255)>(d[aK+ae|0]|0)){ac=a[f]|0;if(ac<<24>>24==0){break}_=b[(c[277225]|0)+((ac&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aO=b[(c[277221]|0)+(((_&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{ac=c[277228]&65535;V=_&-2048;ad=ac&-2048;r=(V&65535)>(ad&65535)?V-ad&65535:0;ad=_&2016;V=ac&2016;if((ad&65535)>(V&65535)){aP=(ad-V&65535)+r&65535}else{aP=r}r=_&31;V=ac&31;if((r&65535)<=(V&65535)){aO=aP;break}aO=(r-V&65535)+aP&65535}}while(0);b[(c[277218]|0)+(ae<<1)>>1]=aO;if((a[1108928]|0)==0){aQ=b[(c[277221]|0)+(((e[(c[277213]|0)+(j+16<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{aQ=0}_=j+15|0;b[(c[277218]|0)+(_<<1)>>1]=aQ;V=a[1108909]|0;a[(c[277219]|0)+_|0]=V;a[(c[277219]|0)+ae|0]=V}}while(0);ae=m-1|0;if((ae|0)<=0){break}f=f+8|0;m=ae;j=(c[277223]|0)+j|0}return}j=p+(56-h)|0;h=(i|0)>0;if(k){if(h){aR=j;aS=i;aT=g}else{return}while(1){k=a[1108908]|0;p=c[277219]|0;do{if((k&255)>(d[p+aT|0]|0)){m=a[aR+7|0]|0;if(m<<24>>24==0){aU=k;aV=p;break}f=b[(c[277225]|0)+((m&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aW=b[(c[277221]|0)+(((f&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{m=c[277228]&65535;aQ=f&-2048;aO=m&-2048;aP=(aQ&65535)>(aO&65535)?aQ-aO&65535:0;aO=f&2016;aQ=m&2016;if((aO&65535)>(aQ&65535)){aX=(aO-aQ&65535)+aP&65535}else{aX=aP}aP=f&31;aQ=m&31;if((aP&65535)<=(aQ&65535)){aW=aX;break}aW=(aP-aQ&65535)+aX&65535}}while(0);b[(c[277218]|0)+(aT<<1)>>1]=aW;if((a[1108928]|0)==0){aY=b[(c[277221]|0)+(((e[(c[277213]|0)+(aT+2<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{aY=0}f=aT+1|0;b[(c[277218]|0)+(f<<1)>>1]=aY;aQ=a[1108909]|0;a[(c[277219]|0)+f|0]=aQ;a[(c[277219]|0)+aT|0]=aQ;aU=a[1108908]|0;aV=c[277219]|0}else{aU=k;aV=p}}while(0);p=aT+2|0;do{if((aU&255)>(d[aV+p|0]|0)){k=a[aR+6|0]|0;if(k<<24>>24==0){aZ=aU;a_=aV;break}aQ=b[(c[277225]|0)+((k&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){a$=b[(c[277221]|0)+(((aQ&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{k=c[277228]&65535;f=aQ&-2048;aP=k&-2048;m=(f&65535)>(aP&65535)?f-aP&65535:0;aP=aQ&2016;f=k&2016;if((aP&65535)>(f&65535)){a0=(aP-f&65535)+m&65535}else{a0=m}m=aQ&31;f=k&31;if((m&65535)<=(f&65535)){a$=a0;break}a$=(m-f&65535)+a0&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=a$;if((a[1108928]|0)==0){a1=b[(c[277221]|0)+(((e[(c[277213]|0)+(aT+4<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{a1=0}aQ=aT+3|0;b[(c[277218]|0)+(aQ<<1)>>1]=a1;f=a[1108909]|0;a[(c[277219]|0)+aQ|0]=f;a[(c[277219]|0)+p|0]=f;aZ=a[1108908]|0;a_=c[277219]|0}else{aZ=aU;a_=aV}}while(0);p=aT+4|0;do{if((aZ&255)>(d[a_+p|0]|0)){f=a[aR+5|0]|0;if(f<<24>>24==0){a2=aZ;a3=a_;break}aQ=b[(c[277225]|0)+((f&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){a4=b[(c[277221]|0)+(((aQ&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{f=c[277228]&65535;m=aQ&-2048;k=f&-2048;aP=(m&65535)>(k&65535)?m-k&65535:0;k=aQ&2016;m=f&2016;if((k&65535)>(m&65535)){a5=(k-m&65535)+aP&65535}else{a5=aP}aP=aQ&31;m=f&31;if((aP&65535)<=(m&65535)){a4=a5;break}a4=(aP-m&65535)+a5&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=a4;if((a[1108928]|0)==0){a6=b[(c[277221]|0)+(((e[(c[277213]|0)+(aT+6<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{a6=0}aQ=aT+5|0;b[(c[277218]|0)+(aQ<<1)>>1]=a6;m=a[1108909]|0;a[(c[277219]|0)+aQ|0]=m;a[(c[277219]|0)+p|0]=m;a2=a[1108908]|0;a3=c[277219]|0}else{a2=aZ;a3=a_}}while(0);p=aT+6|0;do{if((a2&255)>(d[a3+p|0]|0)){m=a[aR+4|0]|0;if(m<<24>>24==0){a7=a2;a8=a3;break}aQ=b[(c[277225]|0)+((m&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){a9=b[(c[277221]|0)+(((aQ&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{m=c[277228]&65535;aP=aQ&-2048;f=m&-2048;k=(aP&65535)>(f&65535)?aP-f&65535:0;f=aQ&2016;aP=m&2016;if((f&65535)>(aP&65535)){ba=(f-aP&65535)+k&65535}else{ba=k}k=aQ&31;aP=m&31;if((k&65535)<=(aP&65535)){a9=ba;break}a9=(k-aP&65535)+ba&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=a9;if((a[1108928]|0)==0){bb=b[(c[277221]|0)+(((e[(c[277213]|0)+(aT+8<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{bb=0}aQ=aT+7|0;b[(c[277218]|0)+(aQ<<1)>>1]=bb;aP=a[1108909]|0;a[(c[277219]|0)+aQ|0]=aP;a[(c[277219]|0)+p|0]=aP;a7=a[1108908]|0;a8=c[277219]|0}else{a7=a2;a8=a3}}while(0);p=aT+8|0;do{if((a7&255)>(d[a8+p|0]|0)){aP=a[aR+3|0]|0;if(aP<<24>>24==0){bc=a7;bd=a8;break}aQ=b[(c[277225]|0)+((aP&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){be=b[(c[277221]|0)+(((aQ&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{aP=c[277228]&65535;k=aQ&-2048;m=aP&-2048;f=(k&65535)>(m&65535)?k-m&65535:0;m=aQ&2016;k=aP&2016;if((m&65535)>(k&65535)){bf=(m-k&65535)+f&65535}else{bf=f}f=aQ&31;k=aP&31;if((f&65535)<=(k&65535)){be=bf;break}be=(f-k&65535)+bf&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=be;if((a[1108928]|0)==0){bg=b[(c[277221]|0)+(((e[(c[277213]|0)+(aT+10<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{bg=0}aQ=aT+9|0;b[(c[277218]|0)+(aQ<<1)>>1]=bg;k=a[1108909]|0;a[(c[277219]|0)+aQ|0]=k;a[(c[277219]|0)+p|0]=k;bc=a[1108908]|0;bd=c[277219]|0}else{bc=a7;bd=a8}}while(0);p=aT+10|0;do{if((bc&255)>(d[bd+p|0]|0)){k=a[aR+2|0]|0;if(k<<24>>24==0){bh=bc;bi=bd;break}aQ=b[(c[277225]|0)+((k&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){bj=b[(c[277221]|0)+(((aQ&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{k=c[277228]&65535;f=aQ&-2048;aP=k&-2048;m=(f&65535)>(aP&65535)?f-aP&65535:0;aP=aQ&2016;f=k&2016;if((aP&65535)>(f&65535)){bk=(aP-f&65535)+m&65535}else{bk=m}m=aQ&31;f=k&31;if((m&65535)<=(f&65535)){bj=bk;break}bj=(m-f&65535)+bk&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=bj;if((a[1108928]|0)==0){bl=b[(c[277221]|0)+(((e[(c[277213]|0)+(aT+12<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{bl=0}aQ=aT+11|0;b[(c[277218]|0)+(aQ<<1)>>1]=bl;f=a[1108909]|0;a[(c[277219]|0)+aQ|0]=f;a[(c[277219]|0)+p|0]=f;bh=a[1108908]|0;bi=c[277219]|0}else{bh=bc;bi=bd}}while(0);p=aT+12|0;do{if((bh&255)>(d[bi+p|0]|0)){f=a[aR+1|0]|0;if(f<<24>>24==0){bm=bh;bn=bi;break}aQ=b[(c[277225]|0)+((f&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){bo=b[(c[277221]|0)+(((aQ&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{f=c[277228]&65535;m=aQ&-2048;k=f&-2048;aP=(m&65535)>(k&65535)?m-k&65535:0;k=aQ&2016;m=f&2016;if((k&65535)>(m&65535)){bp=(k-m&65535)+aP&65535}else{bp=aP}aP=aQ&31;m=f&31;if((aP&65535)<=(m&65535)){bo=bp;break}bo=(aP-m&65535)+bp&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=bo;if((a[1108928]|0)==0){bq=b[(c[277221]|0)+(((e[(c[277213]|0)+(aT+14<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{bq=0}aQ=aT+13|0;b[(c[277218]|0)+(aQ<<1)>>1]=bq;m=a[1108909]|0;a[(c[277219]|0)+aQ|0]=m;a[(c[277219]|0)+p|0]=m;bm=a[1108908]|0;bn=c[277219]|0}else{bm=bh;bn=bi}}while(0);p=aT+14|0;do{if((bm&255)>(d[bn+p|0]|0)){m=a[aR]|0;if(m<<24>>24==0){break}aQ=b[(c[277225]|0)+((m&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){br=b[(c[277221]|0)+(((aQ&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{m=c[277228]&65535;aP=aQ&-2048;f=m&-2048;k=(aP&65535)>(f&65535)?aP-f&65535:0;f=aQ&2016;aP=m&2016;if((f&65535)>(aP&65535)){bs=(f-aP&65535)+k&65535}else{bs=k}k=aQ&31;aP=m&31;if((k&65535)<=(aP&65535)){br=bs;break}br=(k-aP&65535)+bs&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=br;if((a[1108928]|0)==0){bt=b[(c[277221]|0)+(((e[(c[277213]|0)+(aT+16<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{bt=0}aQ=aT+15|0;b[(c[277218]|0)+(aQ<<1)>>1]=bt;aP=a[1108909]|0;a[(c[277219]|0)+aQ|0]=aP;a[(c[277219]|0)+p|0]=aP}}while(0);p=aS-1|0;if((p|0)<=0){break}aR=aR-8|0;aS=p;aT=(c[277223]|0)+aT|0}return}else{if(h){bu=j;bv=i;bw=g}else{return}while(1){g=a[1108908]|0;i=c[277219]|0;do{if((g&255)>(d[i+bw|0]|0)){j=a[bu]|0;if(j<<24>>24==0){bx=g;by=i;break}h=b[(c[277225]|0)+((j&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){bz=b[(c[277221]|0)+(((h&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{j=c[277228]&65535;aT=h&-2048;aS=j&-2048;aR=(aT&65535)>(aS&65535)?aT-aS&65535:0;aS=h&2016;aT=j&2016;if((aS&65535)>(aT&65535)){bA=(aS-aT&65535)+aR&65535}else{bA=aR}aR=h&31;aT=j&31;if((aR&65535)<=(aT&65535)){bz=bA;break}bz=(aR-aT&65535)+bA&65535}}while(0);b[(c[277218]|0)+(bw<<1)>>1]=bz;if((a[1108928]|0)==0){bB=b[(c[277221]|0)+(((e[(c[277213]|0)+(bw+2<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{bB=0}h=bw+1|0;b[(c[277218]|0)+(h<<1)>>1]=bB;aT=a[1108909]|0;a[(c[277219]|0)+h|0]=aT;a[(c[277219]|0)+bw|0]=aT;bx=a[1108908]|0;by=c[277219]|0}else{bx=g;by=i}}while(0);i=bw+2|0;do{if((bx&255)>(d[by+i|0]|0)){g=a[bu+1|0]|0;if(g<<24>>24==0){bC=bx;bD=by;break}aT=b[(c[277225]|0)+((g&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){bE=b[(c[277221]|0)+(((aT&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{g=c[277228]&65535;h=aT&-2048;aR=g&-2048;j=(h&65535)>(aR&65535)?h-aR&65535:0;aR=aT&2016;h=g&2016;if((aR&65535)>(h&65535)){bF=(aR-h&65535)+j&65535}else{bF=j}j=aT&31;h=g&31;if((j&65535)<=(h&65535)){bE=bF;break}bE=(j-h&65535)+bF&65535}}while(0);b[(c[277218]|0)+(i<<1)>>1]=bE;if((a[1108928]|0)==0){bG=b[(c[277221]|0)+(((e[(c[277213]|0)+(bw+4<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{bG=0}aT=bw+3|0;b[(c[277218]|0)+(aT<<1)>>1]=bG;h=a[1108909]|0;a[(c[277219]|0)+aT|0]=h;a[(c[277219]|0)+i|0]=h;bC=a[1108908]|0;bD=c[277219]|0}else{bC=bx;bD=by}}while(0);i=bw+4|0;do{if((bC&255)>(d[bD+i|0]|0)){h=a[bu+2|0]|0;if(h<<24>>24==0){bH=bC;bI=bD;break}aT=b[(c[277225]|0)+((h&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){bJ=b[(c[277221]|0)+(((aT&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{h=c[277228]&65535;j=aT&-2048;g=h&-2048;aR=(j&65535)>(g&65535)?j-g&65535:0;g=aT&2016;j=h&2016;if((g&65535)>(j&65535)){bK=(g-j&65535)+aR&65535}else{bK=aR}aR=aT&31;j=h&31;if((aR&65535)<=(j&65535)){bJ=bK;break}bJ=(aR-j&65535)+bK&65535}}while(0);b[(c[277218]|0)+(i<<1)>>1]=bJ;if((a[1108928]|0)==0){bL=b[(c[277221]|0)+(((e[(c[277213]|0)+(bw+6<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{bL=0}aT=bw+5|0;b[(c[277218]|0)+(aT<<1)>>1]=bL;j=a[1108909]|0;a[(c[277219]|0)+aT|0]=j;a[(c[277219]|0)+i|0]=j;bH=a[1108908]|0;bI=c[277219]|0}else{bH=bC;bI=bD}}while(0);i=bw+6|0;do{if((bH&255)>(d[bI+i|0]|0)){j=a[bu+3|0]|0;if(j<<24>>24==0){bM=bH;bN=bI;break}aT=b[(c[277225]|0)+((j&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){bO=b[(c[277221]|0)+(((aT&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{j=c[277228]&65535;aR=aT&-2048;h=j&-2048;g=(aR&65535)>(h&65535)?aR-h&65535:0;h=aT&2016;aR=j&2016;if((h&65535)>(aR&65535)){bP=(h-aR&65535)+g&65535}else{bP=g}g=aT&31;aR=j&31;if((g&65535)<=(aR&65535)){bO=bP;break}bO=(g-aR&65535)+bP&65535}}while(0);b[(c[277218]|0)+(i<<1)>>1]=bO;if((a[1108928]|0)==0){bQ=b[(c[277221]|0)+(((e[(c[277213]|0)+(bw+8<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{bQ=0}aT=bw+7|0;b[(c[277218]|0)+(aT<<1)>>1]=bQ;aR=a[1108909]|0;a[(c[277219]|0)+aT|0]=aR;a[(c[277219]|0)+i|0]=aR;bM=a[1108908]|0;bN=c[277219]|0}else{bM=bH;bN=bI}}while(0);i=bw+8|0;do{if((bM&255)>(d[bN+i|0]|0)){aR=a[bu+4|0]|0;if(aR<<24>>24==0){bR=bM;bS=bN;break}aT=b[(c[277225]|0)+((aR&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){bT=b[(c[277221]|0)+(((aT&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{aR=c[277228]&65535;g=aT&-2048;j=aR&-2048;h=(g&65535)>(j&65535)?g-j&65535:0;j=aT&2016;g=aR&2016;if((j&65535)>(g&65535)){bU=(j-g&65535)+h&65535}else{bU=h}h=aT&31;g=aR&31;if((h&65535)<=(g&65535)){bT=bU;break}bT=(h-g&65535)+bU&65535}}while(0);b[(c[277218]|0)+(i<<1)>>1]=bT;if((a[1108928]|0)==0){bV=b[(c[277221]|0)+(((e[(c[277213]|0)+(bw+10<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{bV=0}aT=bw+9|0;b[(c[277218]|0)+(aT<<1)>>1]=bV;g=a[1108909]|0;a[(c[277219]|0)+aT|0]=g;a[(c[277219]|0)+i|0]=g;bR=a[1108908]|0;bS=c[277219]|0}else{bR=bM;bS=bN}}while(0);i=bw+10|0;do{if((bR&255)>(d[bS+i|0]|0)){g=a[bu+5|0]|0;if(g<<24>>24==0){bW=bR;bX=bS;break}aT=b[(c[277225]|0)+((g&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){bY=b[(c[277221]|0)+(((aT&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{g=c[277228]&65535;h=aT&-2048;aR=g&-2048;j=(h&65535)>(aR&65535)?h-aR&65535:0;aR=aT&2016;h=g&2016;if((aR&65535)>(h&65535)){bZ=(aR-h&65535)+j&65535}else{bZ=j}j=aT&31;h=g&31;if((j&65535)<=(h&65535)){bY=bZ;break}bY=(j-h&65535)+bZ&65535}}while(0);b[(c[277218]|0)+(i<<1)>>1]=bY;if((a[1108928]|0)==0){b_=b[(c[277221]|0)+(((e[(c[277213]|0)+(bw+12<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{b_=0}aT=bw+11|0;b[(c[277218]|0)+(aT<<1)>>1]=b_;h=a[1108909]|0;a[(c[277219]|0)+aT|0]=h;a[(c[277219]|0)+i|0]=h;bW=a[1108908]|0;bX=c[277219]|0}else{bW=bR;bX=bS}}while(0);i=bw+12|0;do{if((bW&255)>(d[bX+i|0]|0)){h=a[bu+6|0]|0;if(h<<24>>24==0){b$=bW;b0=bX;break}aT=b[(c[277225]|0)+((h&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){b1=b[(c[277221]|0)+(((aT&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{h=c[277228]&65535;j=aT&-2048;g=h&-2048;aR=(j&65535)>(g&65535)?j-g&65535:0;g=aT&2016;j=h&2016;if((g&65535)>(j&65535)){b2=(g-j&65535)+aR&65535}else{b2=aR}aR=aT&31;j=h&31;if((aR&65535)<=(j&65535)){b1=b2;break}b1=(aR-j&65535)+b2&65535}}while(0);b[(c[277218]|0)+(i<<1)>>1]=b1;if((a[1108928]|0)==0){b3=b[(c[277221]|0)+(((e[(c[277213]|0)+(bw+14<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{b3=0}aT=bw+13|0;b[(c[277218]|0)+(aT<<1)>>1]=b3;j=a[1108909]|0;a[(c[277219]|0)+aT|0]=j;a[(c[277219]|0)+i|0]=j;b$=a[1108908]|0;b0=c[277219]|0}else{b$=bW;b0=bX}}while(0);i=bw+14|0;do{if((b$&255)>(d[b0+i|0]|0)){j=a[bu+7|0]|0;if(j<<24>>24==0){break}aT=b[(c[277225]|0)+((j&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){b4=b[(c[277221]|0)+(((aT&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{j=c[277228]&65535;aR=aT&-2048;h=j&-2048;g=(aR&65535)>(h&65535)?aR-h&65535:0;h=aT&2016;aR=j&2016;if((h&65535)>(aR&65535)){b5=(h-aR&65535)+g&65535}else{b5=g}g=aT&31;aR=j&31;if((g&65535)<=(aR&65535)){b4=b5;break}b4=(g-aR&65535)+b5&65535}}while(0);b[(c[277218]|0)+(i<<1)>>1]=b4;if((a[1108928]|0)==0){b6=b[(c[277221]|0)+(((e[(c[277213]|0)+(bw+16<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{b6=0}aT=bw+15|0;b[(c[277218]|0)+(aT<<1)>>1]=b6;aR=a[1108909]|0;a[(c[277219]|0)+aT|0]=aR;a[(c[277219]|0)+i|0]=aR}}while(0);i=bv-1|0;if((i|0)<=0){break}bu=bu-8|0;bv=i;bw=(c[277223]|0)+bw|0}return}}function VN(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0,cf=0,cg=0,ch=0,ci=0,cj=0,ck=0,cl=0,cm=0,cn=0,co=0,cp=0,cq=0,cr=0,cs=0,ct=0,cu=0,cv=0,cw=0,cx=0,cy=0,cz=0,cA=0,cB=0,cC=0,cD=0,cE=0,cF=0,cG=0,cH=0,cI=0,cJ=0,cK=0,cL=0,cM=0,cN=0,cO=0,cP=0,cQ=0,cR=0,cS=0,cT=0,cU=0,cV=0,cW=0,cX=0,cY=0,cZ=0,c_=0,c$=0,c0=0,c1=0,c2=0,c3=0,c4=0,c5=0,c6=0,c7=0,c8=0,c9=0,da=0,db=0,dc=0,dd=0,de=0,df=0,dg=0,dh=0,di=0,dj=0,dk=0,dl=0,dm=0,dn=0,dp=0,dq=0,dr=0,ds=0,dt=0,du=0,dv=0,dw=0,dx=0,dy=0,dz=0,dA=0,dB=0,dC=0,dD=0;i=e&1023;j=c[348606]|0;k=(i<<j)+(c[348604]|0)|0;if((e&256|0)==0){l=k}else{l=(c[348602]|0)+k|0}k=l&65535;l=k>>>(j>>>0);j=(e&16384|0)!=0;m=l<<6;do{if(j){n=(c[348622]|0)+m|0;if((a[(c[348618]|0)+l|0]|0)!=0){o=n;break}p=fi[c[348636]&63](n,k,i)|0;a[(c[348618]|0)+l|0]=p;o=n}else{n=(c[348624]|0)+m|0;if((a[(c[348620]|0)+l|0]|0)!=0){o=n;break}p=fi[c[348638]&63](n,k,i)|0;a[(c[348620]|0)+l|0]=p;o=n}}while(0);if((a[(c[348620]|0)+l|0]|0)==2){return}if((a[1394464]|0)==0){q=1106168+((e>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){l=d[1044485]|0;c[276541]=7080+(l<<5);i=0;do{k=i<<1&2;m=i&2;n=i&4;p=0;do{b[1125528+(i<<9)+(p<<1)>>1]=d[(p>>>1&28|m)+(7080+(l<<5))|0]<<6|d[(p<<2&28|k)+(7080+(l<<5))|0]<<11|d[(p>>>3&24|n)+(7080+(l<<5))|0];p=p+1|0;}while(p>>>0<256);i=i+1|0;}while(i>>>0<8);a[1106089]=0}q=1125528+((e>>>10&7)<<9)|0}c[277226]=q;c[277225]=(a[1108928]|0)!=0?1393712:q;if((e&49152|0)==0){if((h|0)<=0){return}q=o+g|0;i=h;l=f;while(1){p=a[1108908]|0;n=c[277219]|0;do{if((p&255)>(d[n+l|0]|0)){k=a[q]|0;m=k&255;if(k<<24>>24==0){r=p;s=n;break}do{if((a[1108928]|0)==0){k=b[(c[277225]|0)+(m<<1)>>1]|0;if((a[(c[277215]|0)+l|0]&32)!=0){t=b[(c[277221]|0)+((k&65535|67616)-(b[(c[277213]|0)+(l<<1)>>1]&63454)>>1<<1)>>1]|0;break}u=c[277228]&65535;v=k&-2048;w=u&-2048;x=(v&65535)>(w&65535)?v-w&65535:0;w=k&2016;v=u&2016;if((w&65535)>(v&65535)){y=(w-v&65535)+x&65535}else{y=x}x=k&31;k=u&31;if((x&65535)<=(k&65535)){t=y;break}t=(x-k&65535)+y&65535}else{k=b[(c[277225]|0)+(m<<1)>>1]|0;if((a[(c[277215]|0)+l|0]&32)==0){z=c[277228]&65535}else{z=b[(c[277213]|0)+(l<<1)>>1]|0}x=k&-2048;u=z&-2048;v=(x&65535)>(u&65535)?x-u&65535:0;u=k&2016;x=z&2016;if((u&65535)>(x&65535)){A=(u-x&65535)+v&65535}else{A=v}v=k&31;k=z&31;if((v&65535)<=(k&65535)){t=A;break}t=(v-k&65535)+A&65535}}while(0);b[(c[277218]|0)+(l<<1)>>1]=t;do{if((a[1108928]|0)==0){k=b[(c[277213]|0)+(l+2<<1)>>1]|0;if((a[(c[277215]|0)+l|0]&32)!=0){B=b[(c[277221]|0)+((k&65535|67616)-(b[(c[277226]|0)+(m<<1)>>1]&63454)>>1<<1)>>1]|0;break}v=c[277228]&65535;x=k&-2048;u=v&-2048;w=(x&65535)>(u&65535)?x-u&65535:0;u=k&2016;x=v&2016;if((u&65535)>(x&65535)){C=(u-x&65535)+w&65535}else{C=w}w=k&31;k=v&31;if((w&65535)<=(k&65535)){B=C;break}B=(w-k&65535)+C&65535}else{B=0}}while(0);m=l+1|0;b[(c[277218]|0)+(m<<1)>>1]=B;k=a[1108909]|0;a[(c[277219]|0)+m|0]=k;a[(c[277219]|0)+l|0]=k;r=a[1108908]|0;s=c[277219]|0}else{r=p;s=n}}while(0);n=l+2|0;do{if((r&255)>(d[s+n|0]|0)){p=a[q+1|0]|0;k=p&255;if(p<<24>>24==0){D=r;E=s;break}do{if((a[1108928]|0)==0){p=b[(c[277225]|0)+(k<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)!=0){F=b[(c[277221]|0)+((p&65535|67616)-(b[(c[277213]|0)+(n<<1)>>1]&63454)>>1<<1)>>1]|0;break}m=c[277228]&65535;w=p&-2048;v=m&-2048;x=(w&65535)>(v&65535)?w-v&65535:0;v=p&2016;w=m&2016;if((v&65535)>(w&65535)){G=(v-w&65535)+x&65535}else{G=x}x=p&31;p=m&31;if((x&65535)<=(p&65535)){F=G;break}F=(x-p&65535)+G&65535}else{p=b[(c[277225]|0)+(k<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)==0){H=c[277228]&65535}else{H=b[(c[277213]|0)+(n<<1)>>1]|0}x=p&-2048;m=H&-2048;w=(x&65535)>(m&65535)?x-m&65535:0;m=p&2016;x=H&2016;if((m&65535)>(x&65535)){I=(m-x&65535)+w&65535}else{I=w}w=p&31;p=H&31;if((w&65535)<=(p&65535)){F=I;break}F=(w-p&65535)+I&65535}}while(0);b[(c[277218]|0)+(n<<1)>>1]=F;do{if((a[1108928]|0)==0){p=b[(c[277213]|0)+(l+4<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)!=0){J=b[(c[277221]|0)+((p&65535|67616)-(b[(c[277226]|0)+(k<<1)>>1]&63454)>>1<<1)>>1]|0;break}w=c[277228]&65535;x=p&-2048;m=w&-2048;v=(x&65535)>(m&65535)?x-m&65535:0;m=p&2016;x=w&2016;if((m&65535)>(x&65535)){K=(m-x&65535)+v&65535}else{K=v}v=p&31;p=w&31;if((v&65535)<=(p&65535)){J=K;break}J=(v-p&65535)+K&65535}else{J=0}}while(0);k=l+3|0;b[(c[277218]|0)+(k<<1)>>1]=J;p=a[1108909]|0;a[(c[277219]|0)+k|0]=p;a[(c[277219]|0)+n|0]=p;D=a[1108908]|0;E=c[277219]|0}else{D=r;E=s}}while(0);n=l+4|0;do{if((D&255)>(d[E+n|0]|0)){p=a[q+2|0]|0;k=p&255;if(p<<24>>24==0){L=D;M=E;break}do{if((a[1108928]|0)==0){p=b[(c[277225]|0)+(k<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)!=0){N=b[(c[277221]|0)+((p&65535|67616)-(b[(c[277213]|0)+(n<<1)>>1]&63454)>>1<<1)>>1]|0;break}v=c[277228]&65535;w=p&-2048;x=v&-2048;m=(w&65535)>(x&65535)?w-x&65535:0;x=p&2016;w=v&2016;if((x&65535)>(w&65535)){O=(x-w&65535)+m&65535}else{O=m}m=p&31;p=v&31;if((m&65535)<=(p&65535)){N=O;break}N=(m-p&65535)+O&65535}else{p=b[(c[277225]|0)+(k<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)==0){P=c[277228]&65535}else{P=b[(c[277213]|0)+(n<<1)>>1]|0}m=p&-2048;v=P&-2048;w=(m&65535)>(v&65535)?m-v&65535:0;v=p&2016;m=P&2016;if((v&65535)>(m&65535)){Q=(v-m&65535)+w&65535}else{Q=w}w=p&31;p=P&31;if((w&65535)<=(p&65535)){N=Q;break}N=(w-p&65535)+Q&65535}}while(0);b[(c[277218]|0)+(n<<1)>>1]=N;do{if((a[1108928]|0)==0){p=b[(c[277213]|0)+(l+6<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)!=0){R=b[(c[277221]|0)+((p&65535|67616)-(b[(c[277226]|0)+(k<<1)>>1]&63454)>>1<<1)>>1]|0;break}w=c[277228]&65535;m=p&-2048;v=w&-2048;x=(m&65535)>(v&65535)?m-v&65535:0;v=p&2016;m=w&2016;if((v&65535)>(m&65535)){S=(v-m&65535)+x&65535}else{S=x}x=p&31;p=w&31;if((x&65535)<=(p&65535)){R=S;break}R=(x-p&65535)+S&65535}else{R=0}}while(0);k=l+5|0;b[(c[277218]|0)+(k<<1)>>1]=R;p=a[1108909]|0;a[(c[277219]|0)+k|0]=p;a[(c[277219]|0)+n|0]=p;L=a[1108908]|0;M=c[277219]|0}else{L=D;M=E}}while(0);n=l+6|0;do{if((L&255)>(d[M+n|0]|0)){p=a[q+3|0]|0;k=p&255;if(p<<24>>24==0){T=L;U=M;break}do{if((a[1108928]|0)==0){p=b[(c[277225]|0)+(k<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)!=0){V=b[(c[277221]|0)+((p&65535|67616)-(b[(c[277213]|0)+(n<<1)>>1]&63454)>>1<<1)>>1]|0;break}x=c[277228]&65535;w=p&-2048;m=x&-2048;v=(w&65535)>(m&65535)?w-m&65535:0;m=p&2016;w=x&2016;if((m&65535)>(w&65535)){W=(m-w&65535)+v&65535}else{W=v}v=p&31;p=x&31;if((v&65535)<=(p&65535)){V=W;break}V=(v-p&65535)+W&65535}else{p=b[(c[277225]|0)+(k<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)==0){X=c[277228]&65535}else{X=b[(c[277213]|0)+(n<<1)>>1]|0}v=p&-2048;x=X&-2048;w=(v&65535)>(x&65535)?v-x&65535:0;x=p&2016;v=X&2016;if((x&65535)>(v&65535)){Y=(x-v&65535)+w&65535}else{Y=w}w=p&31;p=X&31;if((w&65535)<=(p&65535)){V=Y;break}V=(w-p&65535)+Y&65535}}while(0);b[(c[277218]|0)+(n<<1)>>1]=V;do{if((a[1108928]|0)==0){p=b[(c[277213]|0)+(l+8<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)!=0){Z=b[(c[277221]|0)+((p&65535|67616)-(b[(c[277226]|0)+(k<<1)>>1]&63454)>>1<<1)>>1]|0;break}w=c[277228]&65535;v=p&-2048;x=w&-2048;m=(v&65535)>(x&65535)?v-x&65535:0;x=p&2016;v=w&2016;if((x&65535)>(v&65535)){_=(x-v&65535)+m&65535}else{_=m}m=p&31;p=w&31;if((m&65535)<=(p&65535)){Z=_;break}Z=(m-p&65535)+_&65535}else{Z=0}}while(0);k=l+7|0;b[(c[277218]|0)+(k<<1)>>1]=Z;p=a[1108909]|0;a[(c[277219]|0)+k|0]=p;a[(c[277219]|0)+n|0]=p;T=a[1108908]|0;U=c[277219]|0}else{T=L;U=M}}while(0);n=l+8|0;do{if((T&255)>(d[U+n|0]|0)){p=a[q+4|0]|0;k=p&255;if(p<<24>>24==0){$=T;aa=U;break}do{if((a[1108928]|0)==0){p=b[(c[277225]|0)+(k<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)!=0){ab=b[(c[277221]|0)+((p&65535|67616)-(b[(c[277213]|0)+(n<<1)>>1]&63454)>>1<<1)>>1]|0;break}m=c[277228]&65535;w=p&-2048;v=m&-2048;x=(w&65535)>(v&65535)?w-v&65535:0;v=p&2016;w=m&2016;if((v&65535)>(w&65535)){ac=(v-w&65535)+x&65535}else{ac=x}x=p&31;p=m&31;if((x&65535)<=(p&65535)){ab=ac;break}ab=(x-p&65535)+ac&65535}else{p=b[(c[277225]|0)+(k<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)==0){ad=c[277228]&65535}else{ad=b[(c[277213]|0)+(n<<1)>>1]|0}x=p&-2048;m=ad&-2048;w=(x&65535)>(m&65535)?x-m&65535:0;m=p&2016;x=ad&2016;if((m&65535)>(x&65535)){ae=(m-x&65535)+w&65535}else{ae=w}w=p&31;p=ad&31;if((w&65535)<=(p&65535)){ab=ae;break}ab=(w-p&65535)+ae&65535}}while(0);b[(c[277218]|0)+(n<<1)>>1]=ab;do{if((a[1108928]|0)==0){p=b[(c[277213]|0)+(l+10<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)!=0){af=b[(c[277221]|0)+((p&65535|67616)-(b[(c[277226]|0)+(k<<1)>>1]&63454)>>1<<1)>>1]|0;break}w=c[277228]&65535;x=p&-2048;m=w&-2048;v=(x&65535)>(m&65535)?x-m&65535:0;m=p&2016;x=w&2016;if((m&65535)>(x&65535)){ag=(m-x&65535)+v&65535}else{ag=v}v=p&31;p=w&31;if((v&65535)<=(p&65535)){af=ag;break}af=(v-p&65535)+ag&65535}else{af=0}}while(0);k=l+9|0;b[(c[277218]|0)+(k<<1)>>1]=af;p=a[1108909]|0;a[(c[277219]|0)+k|0]=p;a[(c[277219]|0)+n|0]=p;$=a[1108908]|0;aa=c[277219]|0}else{$=T;aa=U}}while(0);n=l+10|0;do{if(($&255)>(d[aa+n|0]|0)){p=a[q+5|0]|0;k=p&255;if(p<<24>>24==0){ah=$;ai=aa;break}do{if((a[1108928]|0)==0){p=b[(c[277225]|0)+(k<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)!=0){aj=b[(c[277221]|0)+((p&65535|67616)-(b[(c[277213]|0)+(n<<1)>>1]&63454)>>1<<1)>>1]|0;break}v=c[277228]&65535;w=p&-2048;x=v&-2048;m=(w&65535)>(x&65535)?w-x&65535:0;x=p&2016;w=v&2016;if((x&65535)>(w&65535)){ak=(x-w&65535)+m&65535}else{ak=m}m=p&31;p=v&31;if((m&65535)<=(p&65535)){aj=ak;break}aj=(m-p&65535)+ak&65535}else{p=b[(c[277225]|0)+(k<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)==0){al=c[277228]&65535}else{al=b[(c[277213]|0)+(n<<1)>>1]|0}m=p&-2048;v=al&-2048;w=(m&65535)>(v&65535)?m-v&65535:0;v=p&2016;m=al&2016;if((v&65535)>(m&65535)){am=(v-m&65535)+w&65535}else{am=w}w=p&31;p=al&31;if((w&65535)<=(p&65535)){aj=am;break}aj=(w-p&65535)+am&65535}}while(0);b[(c[277218]|0)+(n<<1)>>1]=aj;do{if((a[1108928]|0)==0){p=b[(c[277213]|0)+(l+12<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)!=0){an=b[(c[277221]|0)+((p&65535|67616)-(b[(c[277226]|0)+(k<<1)>>1]&63454)>>1<<1)>>1]|0;break}w=c[277228]&65535;m=p&-2048;v=w&-2048;x=(m&65535)>(v&65535)?m-v&65535:0;v=p&2016;m=w&2016;if((v&65535)>(m&65535)){ao=(v-m&65535)+x&65535}else{ao=x}x=p&31;p=w&31;if((x&65535)<=(p&65535)){an=ao;break}an=(x-p&65535)+ao&65535}else{an=0}}while(0);k=l+11|0;b[(c[277218]|0)+(k<<1)>>1]=an;p=a[1108909]|0;a[(c[277219]|0)+k|0]=p;a[(c[277219]|0)+n|0]=p;ah=a[1108908]|0;ai=c[277219]|0}else{ah=$;ai=aa}}while(0);n=l+12|0;do{if((ah&255)>(d[ai+n|0]|0)){p=a[q+6|0]|0;k=p&255;if(p<<24>>24==0){ap=ah;aq=ai;break}do{if((a[1108928]|0)==0){p=b[(c[277225]|0)+(k<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)!=0){ar=b[(c[277221]|0)+((p&65535|67616)-(b[(c[277213]|0)+(n<<1)>>1]&63454)>>1<<1)>>1]|0;break}x=c[277228]&65535;w=p&-2048;m=x&-2048;v=(w&65535)>(m&65535)?w-m&65535:0;m=p&2016;w=x&2016;if((m&65535)>(w&65535)){as=(m-w&65535)+v&65535}else{as=v}v=p&31;p=x&31;if((v&65535)<=(p&65535)){ar=as;break}ar=(v-p&65535)+as&65535}else{p=b[(c[277225]|0)+(k<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)==0){at=c[277228]&65535}else{at=b[(c[277213]|0)+(n<<1)>>1]|0}v=p&-2048;x=at&-2048;w=(v&65535)>(x&65535)?v-x&65535:0;x=p&2016;v=at&2016;if((x&65535)>(v&65535)){au=(x-v&65535)+w&65535}else{au=w}w=p&31;p=at&31;if((w&65535)<=(p&65535)){ar=au;break}ar=(w-p&65535)+au&65535}}while(0);b[(c[277218]|0)+(n<<1)>>1]=ar;do{if((a[1108928]|0)==0){p=b[(c[277213]|0)+(l+14<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)!=0){av=b[(c[277221]|0)+((p&65535|67616)-(b[(c[277226]|0)+(k<<1)>>1]&63454)>>1<<1)>>1]|0;break}w=c[277228]&65535;v=p&-2048;x=w&-2048;m=(v&65535)>(x&65535)?v-x&65535:0;x=p&2016;v=w&2016;if((x&65535)>(v&65535)){aw=(x-v&65535)+m&65535}else{aw=m}m=p&31;p=w&31;if((m&65535)<=(p&65535)){av=aw;break}av=(m-p&65535)+aw&65535}else{av=0}}while(0);k=l+13|0;b[(c[277218]|0)+(k<<1)>>1]=av;p=a[1108909]|0;a[(c[277219]|0)+k|0]=p;a[(c[277219]|0)+n|0]=p;ap=a[1108908]|0;aq=c[277219]|0}else{ap=ah;aq=ai}}while(0);n=l+14|0;do{if((ap&255)>(d[aq+n|0]|0)){p=a[q+7|0]|0;k=p&255;if(p<<24>>24==0){break}do{if((a[1108928]|0)==0){p=b[(c[277225]|0)+(k<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)!=0){ax=b[(c[277221]|0)+((p&65535|67616)-(b[(c[277213]|0)+(n<<1)>>1]&63454)>>1<<1)>>1]|0;break}m=c[277228]&65535;w=p&-2048;v=m&-2048;x=(w&65535)>(v&65535)?w-v&65535:0;v=p&2016;w=m&2016;if((v&65535)>(w&65535)){ay=(v-w&65535)+x&65535}else{ay=x}x=p&31;p=m&31;if((x&65535)<=(p&65535)){ax=ay;break}ax=(x-p&65535)+ay&65535}else{p=b[(c[277225]|0)+(k<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)==0){az=c[277228]&65535}else{az=b[(c[277213]|0)+(n<<1)>>1]|0}x=p&-2048;m=az&-2048;w=(x&65535)>(m&65535)?x-m&65535:0;m=p&2016;x=az&2016;if((m&65535)>(x&65535)){aA=(m-x&65535)+w&65535}else{aA=w}w=p&31;p=az&31;if((w&65535)<=(p&65535)){ax=aA;break}ax=(w-p&65535)+aA&65535}}while(0);b[(c[277218]|0)+(n<<1)>>1]=ax;do{if((a[1108928]|0)==0){p=b[(c[277213]|0)+(l+16<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)!=0){aB=b[(c[277221]|0)+((p&65535|67616)-(b[(c[277226]|0)+(k<<1)>>1]&63454)>>1<<1)>>1]|0;break}w=c[277228]&65535;x=p&-2048;m=w&-2048;v=(x&65535)>(m&65535)?x-m&65535:0;m=p&2016;x=w&2016;if((m&65535)>(x&65535)){aC=(m-x&65535)+v&65535}else{aC=v}v=p&31;p=w&31;if((v&65535)<=(p&65535)){aB=aC;break}aB=(v-p&65535)+aC&65535}else{aB=0}}while(0);k=l+15|0;b[(c[277218]|0)+(k<<1)>>1]=aB;p=a[1108909]|0;a[(c[277219]|0)+k|0]=p;a[(c[277219]|0)+n|0]=p}}while(0);n=i-1|0;if((n|0)<=0){break}q=q+8|0;i=n;l=(c[277223]|0)+l|0}return}if((e&32768|0)==0){if((h|0)<=0){return}e=o+g|0;l=h;i=f;while(1){q=a[1108908]|0;aB=c[277219]|0;do{if((q&255)>(d[aB+i|0]|0)){aC=a[e+7|0]|0;ax=aC&255;if(aC<<24>>24==0){aD=q;aE=aB;break}do{if((a[1108928]|0)==0){aC=b[(c[277225]|0)+(ax<<1)>>1]|0;if((a[(c[277215]|0)+i|0]&32)!=0){aF=b[(c[277221]|0)+((aC&65535|67616)-(b[(c[277213]|0)+(i<<1)>>1]&63454)>>1<<1)>>1]|0;break}aA=c[277228]&65535;az=aC&-2048;ay=aA&-2048;aq=(az&65535)>(ay&65535)?az-ay&65535:0;ay=aC&2016;az=aA&2016;if((ay&65535)>(az&65535)){aG=(ay-az&65535)+aq&65535}else{aG=aq}aq=aC&31;aC=aA&31;if((aq&65535)<=(aC&65535)){aF=aG;break}aF=(aq-aC&65535)+aG&65535}else{aC=b[(c[277225]|0)+(ax<<1)>>1]|0;if((a[(c[277215]|0)+i|0]&32)==0){aH=c[277228]&65535}else{aH=b[(c[277213]|0)+(i<<1)>>1]|0}aq=aC&-2048;aA=aH&-2048;az=(aq&65535)>(aA&65535)?aq-aA&65535:0;aA=aC&2016;aq=aH&2016;if((aA&65535)>(aq&65535)){aI=(aA-aq&65535)+az&65535}else{aI=az}az=aC&31;aC=aH&31;if((az&65535)<=(aC&65535)){aF=aI;break}aF=(az-aC&65535)+aI&65535}}while(0);b[(c[277218]|0)+(i<<1)>>1]=aF;do{if((a[1108928]|0)==0){aC=b[(c[277213]|0)+(i+2<<1)>>1]|0;if((a[(c[277215]|0)+i|0]&32)!=0){aJ=b[(c[277221]|0)+((aC&65535|67616)-(b[(c[277226]|0)+(ax<<1)>>1]&63454)>>1<<1)>>1]|0;break}az=c[277228]&65535;aq=aC&-2048;aA=az&-2048;ay=(aq&65535)>(aA&65535)?aq-aA&65535:0;aA=aC&2016;aq=az&2016;if((aA&65535)>(aq&65535)){aK=(aA-aq&65535)+ay&65535}else{aK=ay}ay=aC&31;aC=az&31;if((ay&65535)<=(aC&65535)){aJ=aK;break}aJ=(ay-aC&65535)+aK&65535}else{aJ=0}}while(0);ax=i+1|0;b[(c[277218]|0)+(ax<<1)>>1]=aJ;aC=a[1108909]|0;a[(c[277219]|0)+ax|0]=aC;a[(c[277219]|0)+i|0]=aC;aD=a[1108908]|0;aE=c[277219]|0}else{aD=q;aE=aB}}while(0);aB=i+2|0;do{if((aD&255)>(d[aE+aB|0]|0)){q=a[e+6|0]|0;aC=q&255;if(q<<24>>24==0){aL=aD;aM=aE;break}do{if((a[1108928]|0)==0){q=b[(c[277225]|0)+(aC<<1)>>1]|0;if((a[(c[277215]|0)+aB|0]&32)!=0){aN=b[(c[277221]|0)+((q&65535|67616)-(b[(c[277213]|0)+(aB<<1)>>1]&63454)>>1<<1)>>1]|0;break}ax=c[277228]&65535;ay=q&-2048;az=ax&-2048;aq=(ay&65535)>(az&65535)?ay-az&65535:0;az=q&2016;ay=ax&2016;if((az&65535)>(ay&65535)){aO=(az-ay&65535)+aq&65535}else{aO=aq}aq=q&31;q=ax&31;if((aq&65535)<=(q&65535)){aN=aO;break}aN=(aq-q&65535)+aO&65535}else{q=b[(c[277225]|0)+(aC<<1)>>1]|0;if((a[(c[277215]|0)+aB|0]&32)==0){aP=c[277228]&65535}else{aP=b[(c[277213]|0)+(aB<<1)>>1]|0}aq=q&-2048;ax=aP&-2048;ay=(aq&65535)>(ax&65535)?aq-ax&65535:0;ax=q&2016;aq=aP&2016;if((ax&65535)>(aq&65535)){aQ=(ax-aq&65535)+ay&65535}else{aQ=ay}ay=q&31;q=aP&31;if((ay&65535)<=(q&65535)){aN=aQ;break}aN=(ay-q&65535)+aQ&65535}}while(0);b[(c[277218]|0)+(aB<<1)>>1]=aN;do{if((a[1108928]|0)==0){q=b[(c[277213]|0)+(i+4<<1)>>1]|0;if((a[(c[277215]|0)+aB|0]&32)!=0){aR=b[(c[277221]|0)+((q&65535|67616)-(b[(c[277226]|0)+(aC<<1)>>1]&63454)>>1<<1)>>1]|0;break}ay=c[277228]&65535;aq=q&-2048;ax=ay&-2048;az=(aq&65535)>(ax&65535)?aq-ax&65535:0;ax=q&2016;aq=ay&2016;if((ax&65535)>(aq&65535)){aS=(ax-aq&65535)+az&65535}else{aS=az}az=q&31;q=ay&31;if((az&65535)<=(q&65535)){aR=aS;break}aR=(az-q&65535)+aS&65535}else{aR=0}}while(0);aC=i+3|0;b[(c[277218]|0)+(aC<<1)>>1]=aR;q=a[1108909]|0;a[(c[277219]|0)+aC|0]=q;a[(c[277219]|0)+aB|0]=q;aL=a[1108908]|0;aM=c[277219]|0}else{aL=aD;aM=aE}}while(0);aB=i+4|0;do{if((aL&255)>(d[aM+aB|0]|0)){q=a[e+5|0]|0;aC=q&255;if(q<<24>>24==0){aT=aL;aU=aM;break}do{if((a[1108928]|0)==0){q=b[(c[277225]|0)+(aC<<1)>>1]|0;if((a[(c[277215]|0)+aB|0]&32)!=0){aV=b[(c[277221]|0)+((q&65535|67616)-(b[(c[277213]|0)+(aB<<1)>>1]&63454)>>1<<1)>>1]|0;break}az=c[277228]&65535;ay=q&-2048;aq=az&-2048;ax=(ay&65535)>(aq&65535)?ay-aq&65535:0;aq=q&2016;ay=az&2016;if((aq&65535)>(ay&65535)){aW=(aq-ay&65535)+ax&65535}else{aW=ax}ax=q&31;q=az&31;if((ax&65535)<=(q&65535)){aV=aW;break}aV=(ax-q&65535)+aW&65535}else{q=b[(c[277225]|0)+(aC<<1)>>1]|0;if((a[(c[277215]|0)+aB|0]&32)==0){aX=c[277228]&65535}else{aX=b[(c[277213]|0)+(aB<<1)>>1]|0}ax=q&-2048;az=aX&-2048;ay=(ax&65535)>(az&65535)?ax-az&65535:0;az=q&2016;ax=aX&2016;if((az&65535)>(ax&65535)){aY=(az-ax&65535)+ay&65535}else{aY=ay}ay=q&31;q=aX&31;if((ay&65535)<=(q&65535)){aV=aY;break}aV=(ay-q&65535)+aY&65535}}while(0);b[(c[277218]|0)+(aB<<1)>>1]=aV;do{if((a[1108928]|0)==0){q=b[(c[277213]|0)+(i+6<<1)>>1]|0;if((a[(c[277215]|0)+aB|0]&32)!=0){aZ=b[(c[277221]|0)+((q&65535|67616)-(b[(c[277226]|0)+(aC<<1)>>1]&63454)>>1<<1)>>1]|0;break}ay=c[277228]&65535;ax=q&-2048;az=ay&-2048;aq=(ax&65535)>(az&65535)?ax-az&65535:0;az=q&2016;ax=ay&2016;if((az&65535)>(ax&65535)){a_=(az-ax&65535)+aq&65535}else{a_=aq}aq=q&31;q=ay&31;if((aq&65535)<=(q&65535)){aZ=a_;break}aZ=(aq-q&65535)+a_&65535}else{aZ=0}}while(0);aC=i+5|0;b[(c[277218]|0)+(aC<<1)>>1]=aZ;q=a[1108909]|0;a[(c[277219]|0)+aC|0]=q;a[(c[277219]|0)+aB|0]=q;aT=a[1108908]|0;aU=c[277219]|0}else{aT=aL;aU=aM}}while(0);aB=i+6|0;do{if((aT&255)>(d[aU+aB|0]|0)){q=a[e+4|0]|0;aC=q&255;if(q<<24>>24==0){a$=aT;a0=aU;break}do{if((a[1108928]|0)==0){q=b[(c[277225]|0)+(aC<<1)>>1]|0;if((a[(c[277215]|0)+aB|0]&32)!=0){a1=b[(c[277221]|0)+((q&65535|67616)-(b[(c[277213]|0)+(aB<<1)>>1]&63454)>>1<<1)>>1]|0;break}aq=c[277228]&65535;ay=q&-2048;ax=aq&-2048;az=(ay&65535)>(ax&65535)?ay-ax&65535:0;ax=q&2016;ay=aq&2016;if((ax&65535)>(ay&65535)){a2=(ax-ay&65535)+az&65535}else{a2=az}az=q&31;q=aq&31;if((az&65535)<=(q&65535)){a1=a2;break}a1=(az-q&65535)+a2&65535}else{q=b[(c[277225]|0)+(aC<<1)>>1]|0;if((a[(c[277215]|0)+aB|0]&32)==0){a3=c[277228]&65535}else{a3=b[(c[277213]|0)+(aB<<1)>>1]|0}az=q&-2048;aq=a3&-2048;ay=(az&65535)>(aq&65535)?az-aq&65535:0;aq=q&2016;az=a3&2016;if((aq&65535)>(az&65535)){a4=(aq-az&65535)+ay&65535}else{a4=ay}ay=q&31;q=a3&31;if((ay&65535)<=(q&65535)){a1=a4;break}a1=(ay-q&65535)+a4&65535}}while(0);b[(c[277218]|0)+(aB<<1)>>1]=a1;do{if((a[1108928]|0)==0){q=b[(c[277213]|0)+(i+8<<1)>>1]|0;if((a[(c[277215]|0)+aB|0]&32)!=0){a5=b[(c[277221]|0)+((q&65535|67616)-(b[(c[277226]|0)+(aC<<1)>>1]&63454)>>1<<1)>>1]|0;break}ay=c[277228]&65535;az=q&-2048;aq=ay&-2048;ax=(az&65535)>(aq&65535)?az-aq&65535:0;aq=q&2016;az=ay&2016;if((aq&65535)>(az&65535)){a6=(aq-az&65535)+ax&65535}else{a6=ax}ax=q&31;q=ay&31;if((ax&65535)<=(q&65535)){a5=a6;break}a5=(ax-q&65535)+a6&65535}else{a5=0}}while(0);aC=i+7|0;b[(c[277218]|0)+(aC<<1)>>1]=a5;q=a[1108909]|0;a[(c[277219]|0)+aC|0]=q;a[(c[277219]|0)+aB|0]=q;a$=a[1108908]|0;a0=c[277219]|0}else{a$=aT;a0=aU}}while(0);aB=i+8|0;do{if((a$&255)>(d[a0+aB|0]|0)){q=a[e+3|0]|0;aC=q&255;if(q<<24>>24==0){a7=a$;a8=a0;break}do{if((a[1108928]|0)==0){q=b[(c[277225]|0)+(aC<<1)>>1]|0;if((a[(c[277215]|0)+aB|0]&32)!=0){a9=b[(c[277221]|0)+((q&65535|67616)-(b[(c[277213]|0)+(aB<<1)>>1]&63454)>>1<<1)>>1]|0;break}ax=c[277228]&65535;ay=q&-2048;az=ax&-2048;aq=(ay&65535)>(az&65535)?ay-az&65535:0;az=q&2016;ay=ax&2016;if((az&65535)>(ay&65535)){ba=(az-ay&65535)+aq&65535}else{ba=aq}aq=q&31;q=ax&31;if((aq&65535)<=(q&65535)){a9=ba;break}a9=(aq-q&65535)+ba&65535}else{q=b[(c[277225]|0)+(aC<<1)>>1]|0;if((a[(c[277215]|0)+aB|0]&32)==0){bb=c[277228]&65535}else{bb=b[(c[277213]|0)+(aB<<1)>>1]|0}aq=q&-2048;ax=bb&-2048;ay=(aq&65535)>(ax&65535)?aq-ax&65535:0;ax=q&2016;aq=bb&2016;if((ax&65535)>(aq&65535)){bc=(ax-aq&65535)+ay&65535}else{bc=ay}ay=q&31;q=bb&31;if((ay&65535)<=(q&65535)){a9=bc;break}a9=(ay-q&65535)+bc&65535}}while(0);b[(c[277218]|0)+(aB<<1)>>1]=a9;do{if((a[1108928]|0)==0){q=b[(c[277213]|0)+(i+10<<1)>>1]|0;if((a[(c[277215]|0)+aB|0]&32)!=0){bd=b[(c[277221]|0)+((q&65535|67616)-(b[(c[277226]|0)+(aC<<1)>>1]&63454)>>1<<1)>>1]|0;break}ay=c[277228]&65535;aq=q&-2048;ax=ay&-2048;az=(aq&65535)>(ax&65535)?aq-ax&65535:0;ax=q&2016;aq=ay&2016;if((ax&65535)>(aq&65535)){be=(ax-aq&65535)+az&65535}else{be=az}az=q&31;q=ay&31;if((az&65535)<=(q&65535)){bd=be;break}bd=(az-q&65535)+be&65535}else{bd=0}}while(0);aC=i+9|0;b[(c[277218]|0)+(aC<<1)>>1]=bd;q=a[1108909]|0;a[(c[277219]|0)+aC|0]=q;a[(c[277219]|0)+aB|0]=q;a7=a[1108908]|0;a8=c[277219]|0}else{a7=a$;a8=a0}}while(0);aB=i+10|0;do{if((a7&255)>(d[a8+aB|0]|0)){q=a[e+2|0]|0;aC=q&255;if(q<<24>>24==0){bf=a7;bg=a8;break}do{if((a[1108928]|0)==0){q=b[(c[277225]|0)+(aC<<1)>>1]|0;if((a[(c[277215]|0)+aB|0]&32)!=0){bh=b[(c[277221]|0)+((q&65535|67616)-(b[(c[277213]|0)+(aB<<1)>>1]&63454)>>1<<1)>>1]|0;break}az=c[277228]&65535;ay=q&-2048;aq=az&-2048;ax=(ay&65535)>(aq&65535)?ay-aq&65535:0;aq=q&2016;ay=az&2016;if((aq&65535)>(ay&65535)){bi=(aq-ay&65535)+ax&65535}else{bi=ax}ax=q&31;q=az&31;if((ax&65535)<=(q&65535)){bh=bi;break}bh=(ax-q&65535)+bi&65535}else{q=b[(c[277225]|0)+(aC<<1)>>1]|0;if((a[(c[277215]|0)+aB|0]&32)==0){bj=c[277228]&65535}else{bj=b[(c[277213]|0)+(aB<<1)>>1]|0}ax=q&-2048;az=bj&-2048;ay=(ax&65535)>(az&65535)?ax-az&65535:0;az=q&2016;ax=bj&2016;if((az&65535)>(ax&65535)){bk=(az-ax&65535)+ay&65535}else{bk=ay}ay=q&31;q=bj&31;if((ay&65535)<=(q&65535)){bh=bk;break}bh=(ay-q&65535)+bk&65535}}while(0);b[(c[277218]|0)+(aB<<1)>>1]=bh;do{if((a[1108928]|0)==0){q=b[(c[277213]|0)+(i+12<<1)>>1]|0;if((a[(c[277215]|0)+aB|0]&32)!=0){bl=b[(c[277221]|0)+((q&65535|67616)-(b[(c[277226]|0)+(aC<<1)>>1]&63454)>>1<<1)>>1]|0;break}ay=c[277228]&65535;ax=q&-2048;az=ay&-2048;aq=(ax&65535)>(az&65535)?ax-az&65535:0;az=q&2016;ax=ay&2016;if((az&65535)>(ax&65535)){bm=(az-ax&65535)+aq&65535}else{bm=aq}aq=q&31;q=ay&31;if((aq&65535)<=(q&65535)){bl=bm;break}bl=(aq-q&65535)+bm&65535}else{bl=0}}while(0);aC=i+11|0;b[(c[277218]|0)+(aC<<1)>>1]=bl;q=a[1108909]|0;a[(c[277219]|0)+aC|0]=q;a[(c[277219]|0)+aB|0]=q;bf=a[1108908]|0;bg=c[277219]|0}else{bf=a7;bg=a8}}while(0);aB=i+12|0;do{if((bf&255)>(d[bg+aB|0]|0)){q=a[e+1|0]|0;aC=q&255;if(q<<24>>24==0){bn=bf;bo=bg;break}do{if((a[1108928]|0)==0){q=b[(c[277225]|0)+(aC<<1)>>1]|0;if((a[(c[277215]|0)+aB|0]&32)!=0){bp=b[(c[277221]|0)+((q&65535|67616)-(b[(c[277213]|0)+(aB<<1)>>1]&63454)>>1<<1)>>1]|0;break}aq=c[277228]&65535;ay=q&-2048;ax=aq&-2048;az=(ay&65535)>(ax&65535)?ay-ax&65535:0;ax=q&2016;ay=aq&2016;if((ax&65535)>(ay&65535)){bq=(ax-ay&65535)+az&65535}else{bq=az}az=q&31;q=aq&31;if((az&65535)<=(q&65535)){bp=bq;break}bp=(az-q&65535)+bq&65535}else{q=b[(c[277225]|0)+(aC<<1)>>1]|0;if((a[(c[277215]|0)+aB|0]&32)==0){br=c[277228]&65535}else{br=b[(c[277213]|0)+(aB<<1)>>1]|0}az=q&-2048;aq=br&-2048;ay=(az&65535)>(aq&65535)?az-aq&65535:0;aq=q&2016;az=br&2016;if((aq&65535)>(az&65535)){bs=(aq-az&65535)+ay&65535}else{bs=ay}ay=q&31;q=br&31;if((ay&65535)<=(q&65535)){bp=bs;break}bp=(ay-q&65535)+bs&65535}}while(0);b[(c[277218]|0)+(aB<<1)>>1]=bp;do{if((a[1108928]|0)==0){q=b[(c[277213]|0)+(i+14<<1)>>1]|0;if((a[(c[277215]|0)+aB|0]&32)!=0){bt=b[(c[277221]|0)+((q&65535|67616)-(b[(c[277226]|0)+(aC<<1)>>1]&63454)>>1<<1)>>1]|0;break}ay=c[277228]&65535;az=q&-2048;aq=ay&-2048;ax=(az&65535)>(aq&65535)?az-aq&65535:0;aq=q&2016;az=ay&2016;if((aq&65535)>(az&65535)){bu=(aq-az&65535)+ax&65535}else{bu=ax}ax=q&31;q=ay&31;if((ax&65535)<=(q&65535)){bt=bu;break}bt=(ax-q&65535)+bu&65535}else{bt=0}}while(0);aC=i+13|0;b[(c[277218]|0)+(aC<<1)>>1]=bt;q=a[1108909]|0;a[(c[277219]|0)+aC|0]=q;a[(c[277219]|0)+aB|0]=q;bn=a[1108908]|0;bo=c[277219]|0}else{bn=bf;bo=bg}}while(0);aB=i+14|0;do{if((bn&255)>(d[bo+aB|0]|0)){q=a[e]|0;aC=q&255;if(q<<24>>24==0){break}do{if((a[1108928]|0)==0){q=b[(c[277225]|0)+(aC<<1)>>1]|0;if((a[(c[277215]|0)+aB|0]&32)!=0){bv=b[(c[277221]|0)+((q&65535|67616)-(b[(c[277213]|0)+(aB<<1)>>1]&63454)>>1<<1)>>1]|0;break}ax=c[277228]&65535;ay=q&-2048;az=ax&-2048;aq=(ay&65535)>(az&65535)?ay-az&65535:0;az=q&2016;ay=ax&2016;if((az&65535)>(ay&65535)){bw=(az-ay&65535)+aq&65535}else{bw=aq}aq=q&31;q=ax&31;if((aq&65535)<=(q&65535)){bv=bw;break}bv=(aq-q&65535)+bw&65535}else{q=b[(c[277225]|0)+(aC<<1)>>1]|0;if((a[(c[277215]|0)+aB|0]&32)==0){bx=c[277228]&65535}else{bx=b[(c[277213]|0)+(aB<<1)>>1]|0}aq=q&-2048;ax=bx&-2048;ay=(aq&65535)>(ax&65535)?aq-ax&65535:0;ax=q&2016;aq=bx&2016;if((ax&65535)>(aq&65535)){by=(ax-aq&65535)+ay&65535}else{by=ay}ay=q&31;q=bx&31;if((ay&65535)<=(q&65535)){bv=by;break}bv=(ay-q&65535)+by&65535}}while(0);b[(c[277218]|0)+(aB<<1)>>1]=bv;do{if((a[1108928]|0)==0){q=b[(c[277213]|0)+(i+16<<1)>>1]|0;if((a[(c[277215]|0)+aB|0]&32)!=0){bz=b[(c[277221]|0)+((q&65535|67616)-(b[(c[277226]|0)+(aC<<1)>>1]&63454)>>1<<1)>>1]|0;break}ay=c[277228]&65535;aq=q&-2048;ax=ay&-2048;az=(aq&65535)>(ax&65535)?aq-ax&65535:0;ax=q&2016;aq=ay&2016;if((ax&65535)>(aq&65535)){bA=(ax-aq&65535)+az&65535}else{bA=az}az=q&31;q=ay&31;if((az&65535)<=(q&65535)){bz=bA;break}bz=(az-q&65535)+bA&65535}else{bz=0}}while(0);aC=i+15|0;b[(c[277218]|0)+(aC<<1)>>1]=bz;q=a[1108909]|0;a[(c[277219]|0)+aC|0]=q;a[(c[277219]|0)+aB|0]=q}}while(0);aB=l-1|0;if((aB|0)<=0){break}e=e+8|0;l=aB;i=(c[277223]|0)+i|0}return}i=o+(56-g)|0;g=(h|0)>0;if(j){if(g){bB=i;bC=h;bD=f}else{return}while(1){j=a[1108908]|0;o=c[277219]|0;do{if((j&255)>(d[o+bD|0]|0)){l=a[bB+7|0]|0;e=l&255;if(l<<24>>24==0){bE=j;bF=o;break}do{if((a[1108928]|0)==0){l=b[(c[277225]|0)+(e<<1)>>1]|0;if((a[(c[277215]|0)+bD|0]&32)!=0){bG=b[(c[277221]|0)+((l&65535|67616)-(b[(c[277213]|0)+(bD<<1)>>1]&63454)>>1<<1)>>1]|0;break}bz=c[277228]&65535;bA=l&-2048;bv=bz&-2048;by=(bA&65535)>(bv&65535)?bA-bv&65535:0;bv=l&2016;bA=bz&2016;if((bv&65535)>(bA&65535)){bH=(bv-bA&65535)+by&65535}else{bH=by}by=l&31;l=bz&31;if((by&65535)<=(l&65535)){bG=bH;break}bG=(by-l&65535)+bH&65535}else{l=b[(c[277225]|0)+(e<<1)>>1]|0;if((a[(c[277215]|0)+bD|0]&32)==0){bI=c[277228]&65535}else{bI=b[(c[277213]|0)+(bD<<1)>>1]|0}by=l&-2048;bz=bI&-2048;bA=(by&65535)>(bz&65535)?by-bz&65535:0;bz=l&2016;by=bI&2016;if((bz&65535)>(by&65535)){bJ=(bz-by&65535)+bA&65535}else{bJ=bA}bA=l&31;l=bI&31;if((bA&65535)<=(l&65535)){bG=bJ;break}bG=(bA-l&65535)+bJ&65535}}while(0);b[(c[277218]|0)+(bD<<1)>>1]=bG;do{if((a[1108928]|0)==0){l=b[(c[277213]|0)+(bD+2<<1)>>1]|0;if((a[(c[277215]|0)+bD|0]&32)!=0){bK=b[(c[277221]|0)+((l&65535|67616)-(b[(c[277226]|0)+(e<<1)>>1]&63454)>>1<<1)>>1]|0;break}bA=c[277228]&65535;by=l&-2048;bz=bA&-2048;bv=(by&65535)>(bz&65535)?by-bz&65535:0;bz=l&2016;by=bA&2016;if((bz&65535)>(by&65535)){bL=(bz-by&65535)+bv&65535}else{bL=bv}bv=l&31;l=bA&31;if((bv&65535)<=(l&65535)){bK=bL;break}bK=(bv-l&65535)+bL&65535}else{bK=0}}while(0);e=bD+1|0;b[(c[277218]|0)+(e<<1)>>1]=bK;l=a[1108909]|0;a[(c[277219]|0)+e|0]=l;a[(c[277219]|0)+bD|0]=l;bE=a[1108908]|0;bF=c[277219]|0}else{bE=j;bF=o}}while(0);o=bD+2|0;do{if((bE&255)>(d[bF+o|0]|0)){j=a[bB+6|0]|0;l=j&255;if(j<<24>>24==0){bM=bE;bN=bF;break}do{if((a[1108928]|0)==0){j=b[(c[277225]|0)+(l<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){bO=b[(c[277221]|0)+((j&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}e=c[277228]&65535;bv=j&-2048;bA=e&-2048;by=(bv&65535)>(bA&65535)?bv-bA&65535:0;bA=j&2016;bv=e&2016;if((bA&65535)>(bv&65535)){bP=(bA-bv&65535)+by&65535}else{bP=by}by=j&31;j=e&31;if((by&65535)<=(j&65535)){bO=bP;break}bO=(by-j&65535)+bP&65535}else{j=b[(c[277225]|0)+(l<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){bQ=c[277228]&65535}else{bQ=b[(c[277213]|0)+(o<<1)>>1]|0}by=j&-2048;e=bQ&-2048;bv=(by&65535)>(e&65535)?by-e&65535:0;e=j&2016;by=bQ&2016;if((e&65535)>(by&65535)){bR=(e-by&65535)+bv&65535}else{bR=bv}bv=j&31;j=bQ&31;if((bv&65535)<=(j&65535)){bO=bR;break}bO=(bv-j&65535)+bR&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=bO;do{if((a[1108928]|0)==0){j=b[(c[277213]|0)+(bD+4<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){bS=b[(c[277221]|0)+((j&65535|67616)-(b[(c[277226]|0)+(l<<1)>>1]&63454)>>1<<1)>>1]|0;break}bv=c[277228]&65535;by=j&-2048;e=bv&-2048;bA=(by&65535)>(e&65535)?by-e&65535:0;e=j&2016;by=bv&2016;if((e&65535)>(by&65535)){bT=(e-by&65535)+bA&65535}else{bT=bA}bA=j&31;j=bv&31;if((bA&65535)<=(j&65535)){bS=bT;break}bS=(bA-j&65535)+bT&65535}else{bS=0}}while(0);l=bD+3|0;b[(c[277218]|0)+(l<<1)>>1]=bS;j=a[1108909]|0;a[(c[277219]|0)+l|0]=j;a[(c[277219]|0)+o|0]=j;bM=a[1108908]|0;bN=c[277219]|0}else{bM=bE;bN=bF}}while(0);o=bD+4|0;do{if((bM&255)>(d[bN+o|0]|0)){j=a[bB+5|0]|0;l=j&255;if(j<<24>>24==0){bU=bM;bV=bN;break}do{if((a[1108928]|0)==0){j=b[(c[277225]|0)+(l<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){bW=b[(c[277221]|0)+((j&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}bA=c[277228]&65535;bv=j&-2048;by=bA&-2048;e=(bv&65535)>(by&65535)?bv-by&65535:0;by=j&2016;bv=bA&2016;if((by&65535)>(bv&65535)){bX=(by-bv&65535)+e&65535}else{bX=e}e=j&31;j=bA&31;if((e&65535)<=(j&65535)){bW=bX;break}bW=(e-j&65535)+bX&65535}else{j=b[(c[277225]|0)+(l<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){bY=c[277228]&65535}else{bY=b[(c[277213]|0)+(o<<1)>>1]|0}e=j&-2048;bA=bY&-2048;bv=(e&65535)>(bA&65535)?e-bA&65535:0;bA=j&2016;e=bY&2016;if((bA&65535)>(e&65535)){bZ=(bA-e&65535)+bv&65535}else{bZ=bv}bv=j&31;j=bY&31;if((bv&65535)<=(j&65535)){bW=bZ;break}bW=(bv-j&65535)+bZ&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=bW;do{if((a[1108928]|0)==0){j=b[(c[277213]|0)+(bD+6<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){b_=b[(c[277221]|0)+((j&65535|67616)-(b[(c[277226]|0)+(l<<1)>>1]&63454)>>1<<1)>>1]|0;break}bv=c[277228]&65535;e=j&-2048;bA=bv&-2048;by=(e&65535)>(bA&65535)?e-bA&65535:0;bA=j&2016;e=bv&2016;if((bA&65535)>(e&65535)){b$=(bA-e&65535)+by&65535}else{b$=by}by=j&31;j=bv&31;if((by&65535)<=(j&65535)){b_=b$;break}b_=(by-j&65535)+b$&65535}else{b_=0}}while(0);l=bD+5|0;b[(c[277218]|0)+(l<<1)>>1]=b_;j=a[1108909]|0;a[(c[277219]|0)+l|0]=j;a[(c[277219]|0)+o|0]=j;bU=a[1108908]|0;bV=c[277219]|0}else{bU=bM;bV=bN}}while(0);o=bD+6|0;do{if((bU&255)>(d[bV+o|0]|0)){j=a[bB+4|0]|0;l=j&255;if(j<<24>>24==0){b0=bU;b1=bV;break}do{if((a[1108928]|0)==0){j=b[(c[277225]|0)+(l<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){b2=b[(c[277221]|0)+((j&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}by=c[277228]&65535;bv=j&-2048;e=by&-2048;bA=(bv&65535)>(e&65535)?bv-e&65535:0;e=j&2016;bv=by&2016;if((e&65535)>(bv&65535)){b3=(e-bv&65535)+bA&65535}else{b3=bA}bA=j&31;j=by&31;if((bA&65535)<=(j&65535)){b2=b3;break}b2=(bA-j&65535)+b3&65535}else{j=b[(c[277225]|0)+(l<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){b4=c[277228]&65535}else{b4=b[(c[277213]|0)+(o<<1)>>1]|0}bA=j&-2048;by=b4&-2048;bv=(bA&65535)>(by&65535)?bA-by&65535:0;by=j&2016;bA=b4&2016;if((by&65535)>(bA&65535)){b5=(by-bA&65535)+bv&65535}else{b5=bv}bv=j&31;j=b4&31;if((bv&65535)<=(j&65535)){b2=b5;break}b2=(bv-j&65535)+b5&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=b2;do{if((a[1108928]|0)==0){j=b[(c[277213]|0)+(bD+8<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){b6=b[(c[277221]|0)+((j&65535|67616)-(b[(c[277226]|0)+(l<<1)>>1]&63454)>>1<<1)>>1]|0;break}bv=c[277228]&65535;bA=j&-2048;by=bv&-2048;e=(bA&65535)>(by&65535)?bA-by&65535:0;by=j&2016;bA=bv&2016;if((by&65535)>(bA&65535)){b7=(by-bA&65535)+e&65535}else{b7=e}e=j&31;j=bv&31;if((e&65535)<=(j&65535)){b6=b7;break}b6=(e-j&65535)+b7&65535}else{b6=0}}while(0);l=bD+7|0;b[(c[277218]|0)+(l<<1)>>1]=b6;j=a[1108909]|0;a[(c[277219]|0)+l|0]=j;a[(c[277219]|0)+o|0]=j;b0=a[1108908]|0;b1=c[277219]|0}else{b0=bU;b1=bV}}while(0);o=bD+8|0;do{if((b0&255)>(d[b1+o|0]|0)){j=a[bB+3|0]|0;l=j&255;if(j<<24>>24==0){b8=b0;b9=b1;break}do{if((a[1108928]|0)==0){j=b[(c[277225]|0)+(l<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){ca=b[(c[277221]|0)+((j&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}e=c[277228]&65535;bv=j&-2048;bA=e&-2048;by=(bv&65535)>(bA&65535)?bv-bA&65535:0;bA=j&2016;bv=e&2016;if((bA&65535)>(bv&65535)){cb=(bA-bv&65535)+by&65535}else{cb=by}by=j&31;j=e&31;if((by&65535)<=(j&65535)){ca=cb;break}ca=(by-j&65535)+cb&65535}else{j=b[(c[277225]|0)+(l<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){cc=c[277228]&65535}else{cc=b[(c[277213]|0)+(o<<1)>>1]|0}by=j&-2048;e=cc&-2048;bv=(by&65535)>(e&65535)?by-e&65535:0;e=j&2016;by=cc&2016;if((e&65535)>(by&65535)){cd=(e-by&65535)+bv&65535}else{cd=bv}bv=j&31;j=cc&31;if((bv&65535)<=(j&65535)){ca=cd;break}ca=(bv-j&65535)+cd&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=ca;do{if((a[1108928]|0)==0){j=b[(c[277213]|0)+(bD+10<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){ce=b[(c[277221]|0)+((j&65535|67616)-(b[(c[277226]|0)+(l<<1)>>1]&63454)>>1<<1)>>1]|0;break}bv=c[277228]&65535;by=j&-2048;e=bv&-2048;bA=(by&65535)>(e&65535)?by-e&65535:0;e=j&2016;by=bv&2016;if((e&65535)>(by&65535)){cf=(e-by&65535)+bA&65535}else{cf=bA}bA=j&31;j=bv&31;if((bA&65535)<=(j&65535)){ce=cf;break}ce=(bA-j&65535)+cf&65535}else{ce=0}}while(0);l=bD+9|0;b[(c[277218]|0)+(l<<1)>>1]=ce;j=a[1108909]|0;a[(c[277219]|0)+l|0]=j;a[(c[277219]|0)+o|0]=j;b8=a[1108908]|0;b9=c[277219]|0}else{b8=b0;b9=b1}}while(0);o=bD+10|0;do{if((b8&255)>(d[b9+o|0]|0)){j=a[bB+2|0]|0;l=j&255;if(j<<24>>24==0){cg=b8;ch=b9;break}do{if((a[1108928]|0)==0){j=b[(c[277225]|0)+(l<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){ci=b[(c[277221]|0)+((j&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}bA=c[277228]&65535;bv=j&-2048;by=bA&-2048;e=(bv&65535)>(by&65535)?bv-by&65535:0;by=j&2016;bv=bA&2016;if((by&65535)>(bv&65535)){cj=(by-bv&65535)+e&65535}else{cj=e}e=j&31;j=bA&31;if((e&65535)<=(j&65535)){ci=cj;break}ci=(e-j&65535)+cj&65535}else{j=b[(c[277225]|0)+(l<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){ck=c[277228]&65535}else{ck=b[(c[277213]|0)+(o<<1)>>1]|0}e=j&-2048;bA=ck&-2048;bv=(e&65535)>(bA&65535)?e-bA&65535:0;bA=j&2016;e=ck&2016;if((bA&65535)>(e&65535)){cl=(bA-e&65535)+bv&65535}else{cl=bv}bv=j&31;j=ck&31;if((bv&65535)<=(j&65535)){ci=cl;break}ci=(bv-j&65535)+cl&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=ci;do{if((a[1108928]|0)==0){j=b[(c[277213]|0)+(bD+12<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){cm=b[(c[277221]|0)+((j&65535|67616)-(b[(c[277226]|0)+(l<<1)>>1]&63454)>>1<<1)>>1]|0;break}bv=c[277228]&65535;e=j&-2048;bA=bv&-2048;by=(e&65535)>(bA&65535)?e-bA&65535:0;bA=j&2016;e=bv&2016;if((bA&65535)>(e&65535)){cn=(bA-e&65535)+by&65535}else{cn=by}by=j&31;j=bv&31;if((by&65535)<=(j&65535)){cm=cn;break}cm=(by-j&65535)+cn&65535}else{cm=0}}while(0);l=bD+11|0;b[(c[277218]|0)+(l<<1)>>1]=cm;j=a[1108909]|0;a[(c[277219]|0)+l|0]=j;a[(c[277219]|0)+o|0]=j;cg=a[1108908]|0;ch=c[277219]|0}else{cg=b8;ch=b9}}while(0);o=bD+12|0;do{if((cg&255)>(d[ch+o|0]|0)){j=a[bB+1|0]|0;l=j&255;if(j<<24>>24==0){co=cg;cp=ch;break}do{if((a[1108928]|0)==0){j=b[(c[277225]|0)+(l<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){cq=b[(c[277221]|0)+((j&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}by=c[277228]&65535;bv=j&-2048;e=by&-2048;bA=(bv&65535)>(e&65535)?bv-e&65535:0;e=j&2016;bv=by&2016;if((e&65535)>(bv&65535)){cr=(e-bv&65535)+bA&65535}else{cr=bA}bA=j&31;j=by&31;if((bA&65535)<=(j&65535)){cq=cr;break}cq=(bA-j&65535)+cr&65535}else{j=b[(c[277225]|0)+(l<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){cs=c[277228]&65535}else{cs=b[(c[277213]|0)+(o<<1)>>1]|0}bA=j&-2048;by=cs&-2048;bv=(bA&65535)>(by&65535)?bA-by&65535:0;by=j&2016;bA=cs&2016;if((by&65535)>(bA&65535)){ct=(by-bA&65535)+bv&65535}else{ct=bv}bv=j&31;j=cs&31;if((bv&65535)<=(j&65535)){cq=ct;break}cq=(bv-j&65535)+ct&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=cq;do{if((a[1108928]|0)==0){j=b[(c[277213]|0)+(bD+14<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){cu=b[(c[277221]|0)+((j&65535|67616)-(b[(c[277226]|0)+(l<<1)>>1]&63454)>>1<<1)>>1]|0;break}bv=c[277228]&65535;bA=j&-2048;by=bv&-2048;e=(bA&65535)>(by&65535)?bA-by&65535:0;by=j&2016;bA=bv&2016;if((by&65535)>(bA&65535)){cv=(by-bA&65535)+e&65535}else{cv=e}e=j&31;j=bv&31;if((e&65535)<=(j&65535)){cu=cv;break}cu=(e-j&65535)+cv&65535}else{cu=0}}while(0);l=bD+13|0;b[(c[277218]|0)+(l<<1)>>1]=cu;j=a[1108909]|0;a[(c[277219]|0)+l|0]=j;a[(c[277219]|0)+o|0]=j;co=a[1108908]|0;cp=c[277219]|0}else{co=cg;cp=ch}}while(0);o=bD+14|0;do{if((co&255)>(d[cp+o|0]|0)){j=a[bB]|0;l=j&255;if(j<<24>>24==0){break}do{if((a[1108928]|0)==0){j=b[(c[277225]|0)+(l<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){cw=b[(c[277221]|0)+((j&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}e=c[277228]&65535;bv=j&-2048;bA=e&-2048;by=(bv&65535)>(bA&65535)?bv-bA&65535:0;bA=j&2016;bv=e&2016;if((bA&65535)>(bv&65535)){cx=(bA-bv&65535)+by&65535}else{cx=by}by=j&31;j=e&31;if((by&65535)<=(j&65535)){cw=cx;break}cw=(by-j&65535)+cx&65535}else{j=b[(c[277225]|0)+(l<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){cy=c[277228]&65535}else{cy=b[(c[277213]|0)+(o<<1)>>1]|0}by=j&-2048;e=cy&-2048;bv=(by&65535)>(e&65535)?by-e&65535:0;e=j&2016;by=cy&2016;if((e&65535)>(by&65535)){cz=(e-by&65535)+bv&65535}else{cz=bv}bv=j&31;j=cy&31;if((bv&65535)<=(j&65535)){cw=cz;break}cw=(bv-j&65535)+cz&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=cw;do{if((a[1108928]|0)==0){j=b[(c[277213]|0)+(bD+16<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){cA=b[(c[277221]|0)+((j&65535|67616)-(b[(c[277226]|0)+(l<<1)>>1]&63454)>>1<<1)>>1]|0;break}bv=c[277228]&65535;by=j&-2048;e=bv&-2048;bA=(by&65535)>(e&65535)?by-e&65535:0;e=j&2016;by=bv&2016;if((e&65535)>(by&65535)){cB=(e-by&65535)+bA&65535}else{cB=bA}bA=j&31;j=bv&31;if((bA&65535)<=(j&65535)){cA=cB;break}cA=(bA-j&65535)+cB&65535}else{cA=0}}while(0);l=bD+15|0;b[(c[277218]|0)+(l<<1)>>1]=cA;j=a[1108909]|0;a[(c[277219]|0)+l|0]=j;a[(c[277219]|0)+o|0]=j}}while(0);o=bC-1|0;if((o|0)<=0){break}bB=bB-8|0;bC=o;bD=(c[277223]|0)+bD|0}return}else{if(g){cC=i;cD=h;cE=f}else{return}while(1){f=a[1108908]|0;h=c[277219]|0;do{if((f&255)>(d[h+cE|0]|0)){i=a[cC]|0;g=i&255;if(i<<24>>24==0){cF=f;cG=h;break}do{if((a[1108928]|0)==0){i=b[(c[277225]|0)+(g<<1)>>1]|0;if((a[(c[277215]|0)+cE|0]&32)!=0){cH=b[(c[277221]|0)+((i&65535|67616)-(b[(c[277213]|0)+(cE<<1)>>1]&63454)>>1<<1)>>1]|0;break}bD=c[277228]&65535;bC=i&-2048;bB=bD&-2048;cA=(bC&65535)>(bB&65535)?bC-bB&65535:0;bB=i&2016;bC=bD&2016;if((bB&65535)>(bC&65535)){cI=(bB-bC&65535)+cA&65535}else{cI=cA}cA=i&31;i=bD&31;if((cA&65535)<=(i&65535)){cH=cI;break}cH=(cA-i&65535)+cI&65535}else{i=b[(c[277225]|0)+(g<<1)>>1]|0;if((a[(c[277215]|0)+cE|0]&32)==0){cJ=c[277228]&65535}else{cJ=b[(c[277213]|0)+(cE<<1)>>1]|0}cA=i&-2048;bD=cJ&-2048;bC=(cA&65535)>(bD&65535)?cA-bD&65535:0;bD=i&2016;cA=cJ&2016;if((bD&65535)>(cA&65535)){cK=(bD-cA&65535)+bC&65535}else{cK=bC}bC=i&31;i=cJ&31;if((bC&65535)<=(i&65535)){cH=cK;break}cH=(bC-i&65535)+cK&65535}}while(0);b[(c[277218]|0)+(cE<<1)>>1]=cH;do{if((a[1108928]|0)==0){i=b[(c[277213]|0)+(cE+2<<1)>>1]|0;if((a[(c[277215]|0)+cE|0]&32)!=0){cL=b[(c[277221]|0)+((i&65535|67616)-(b[(c[277226]|0)+(g<<1)>>1]&63454)>>1<<1)>>1]|0;break}bC=c[277228]&65535;cA=i&-2048;bD=bC&-2048;bB=(cA&65535)>(bD&65535)?cA-bD&65535:0;bD=i&2016;cA=bC&2016;if((bD&65535)>(cA&65535)){cM=(bD-cA&65535)+bB&65535}else{cM=bB}bB=i&31;i=bC&31;if((bB&65535)<=(i&65535)){cL=cM;break}cL=(bB-i&65535)+cM&65535}else{cL=0}}while(0);g=cE+1|0;b[(c[277218]|0)+(g<<1)>>1]=cL;i=a[1108909]|0;a[(c[277219]|0)+g|0]=i;a[(c[277219]|0)+cE|0]=i;cF=a[1108908]|0;cG=c[277219]|0}else{cF=f;cG=h}}while(0);h=cE+2|0;do{if((cF&255)>(d[cG+h|0]|0)){f=a[cC+1|0]|0;i=f&255;if(f<<24>>24==0){cN=cF;cO=cG;break}do{if((a[1108928]|0)==0){f=b[(c[277225]|0)+(i<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)!=0){cP=b[(c[277221]|0)+((f&65535|67616)-(b[(c[277213]|0)+(h<<1)>>1]&63454)>>1<<1)>>1]|0;break}g=c[277228]&65535;bB=f&-2048;bC=g&-2048;cA=(bB&65535)>(bC&65535)?bB-bC&65535:0;bC=f&2016;bB=g&2016;if((bC&65535)>(bB&65535)){cQ=(bC-bB&65535)+cA&65535}else{cQ=cA}cA=f&31;f=g&31;if((cA&65535)<=(f&65535)){cP=cQ;break}cP=(cA-f&65535)+cQ&65535}else{f=b[(c[277225]|0)+(i<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)==0){cR=c[277228]&65535}else{cR=b[(c[277213]|0)+(h<<1)>>1]|0}cA=f&-2048;g=cR&-2048;bB=(cA&65535)>(g&65535)?cA-g&65535:0;g=f&2016;cA=cR&2016;if((g&65535)>(cA&65535)){cS=(g-cA&65535)+bB&65535}else{cS=bB}bB=f&31;f=cR&31;if((bB&65535)<=(f&65535)){cP=cS;break}cP=(bB-f&65535)+cS&65535}}while(0);b[(c[277218]|0)+(h<<1)>>1]=cP;do{if((a[1108928]|0)==0){f=b[(c[277213]|0)+(cE+4<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)!=0){cT=b[(c[277221]|0)+((f&65535|67616)-(b[(c[277226]|0)+(i<<1)>>1]&63454)>>1<<1)>>1]|0;break}bB=c[277228]&65535;cA=f&-2048;g=bB&-2048;bC=(cA&65535)>(g&65535)?cA-g&65535:0;g=f&2016;cA=bB&2016;if((g&65535)>(cA&65535)){cU=(g-cA&65535)+bC&65535}else{cU=bC}bC=f&31;f=bB&31;if((bC&65535)<=(f&65535)){cT=cU;break}cT=(bC-f&65535)+cU&65535}else{cT=0}}while(0);i=cE+3|0;b[(c[277218]|0)+(i<<1)>>1]=cT;f=a[1108909]|0;a[(c[277219]|0)+i|0]=f;a[(c[277219]|0)+h|0]=f;cN=a[1108908]|0;cO=c[277219]|0}else{cN=cF;cO=cG}}while(0);h=cE+4|0;do{if((cN&255)>(d[cO+h|0]|0)){f=a[cC+2|0]|0;i=f&255;if(f<<24>>24==0){cV=cN;cW=cO;break}do{if((a[1108928]|0)==0){f=b[(c[277225]|0)+(i<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)!=0){cX=b[(c[277221]|0)+((f&65535|67616)-(b[(c[277213]|0)+(h<<1)>>1]&63454)>>1<<1)>>1]|0;break}bC=c[277228]&65535;bB=f&-2048;cA=bC&-2048;g=(bB&65535)>(cA&65535)?bB-cA&65535:0;cA=f&2016;bB=bC&2016;if((cA&65535)>(bB&65535)){cY=(cA-bB&65535)+g&65535}else{cY=g}g=f&31;f=bC&31;if((g&65535)<=(f&65535)){cX=cY;break}cX=(g-f&65535)+cY&65535}else{f=b[(c[277225]|0)+(i<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)==0){cZ=c[277228]&65535}else{cZ=b[(c[277213]|0)+(h<<1)>>1]|0}g=f&-2048;bC=cZ&-2048;bB=(g&65535)>(bC&65535)?g-bC&65535:0;bC=f&2016;g=cZ&2016;if((bC&65535)>(g&65535)){c_=(bC-g&65535)+bB&65535}else{c_=bB}bB=f&31;f=cZ&31;if((bB&65535)<=(f&65535)){cX=c_;break}cX=(bB-f&65535)+c_&65535}}while(0);b[(c[277218]|0)+(h<<1)>>1]=cX;do{if((a[1108928]|0)==0){f=b[(c[277213]|0)+(cE+6<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)!=0){c$=b[(c[277221]|0)+((f&65535|67616)-(b[(c[277226]|0)+(i<<1)>>1]&63454)>>1<<1)>>1]|0;break}bB=c[277228]&65535;g=f&-2048;bC=bB&-2048;cA=(g&65535)>(bC&65535)?g-bC&65535:0;bC=f&2016;g=bB&2016;if((bC&65535)>(g&65535)){c0=(bC-g&65535)+cA&65535}else{c0=cA}cA=f&31;f=bB&31;if((cA&65535)<=(f&65535)){c$=c0;break}c$=(cA-f&65535)+c0&65535}else{c$=0}}while(0);i=cE+5|0;b[(c[277218]|0)+(i<<1)>>1]=c$;f=a[1108909]|0;a[(c[277219]|0)+i|0]=f;a[(c[277219]|0)+h|0]=f;cV=a[1108908]|0;cW=c[277219]|0}else{cV=cN;cW=cO}}while(0);h=cE+6|0;do{if((cV&255)>(d[cW+h|0]|0)){f=a[cC+3|0]|0;i=f&255;if(f<<24>>24==0){c1=cV;c2=cW;break}do{if((a[1108928]|0)==0){f=b[(c[277225]|0)+(i<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)!=0){c3=b[(c[277221]|0)+((f&65535|67616)-(b[(c[277213]|0)+(h<<1)>>1]&63454)>>1<<1)>>1]|0;break}cA=c[277228]&65535;bB=f&-2048;g=cA&-2048;bC=(bB&65535)>(g&65535)?bB-g&65535:0;g=f&2016;bB=cA&2016;if((g&65535)>(bB&65535)){c4=(g-bB&65535)+bC&65535}else{c4=bC}bC=f&31;f=cA&31;if((bC&65535)<=(f&65535)){c3=c4;break}c3=(bC-f&65535)+c4&65535}else{f=b[(c[277225]|0)+(i<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)==0){c5=c[277228]&65535}else{c5=b[(c[277213]|0)+(h<<1)>>1]|0}bC=f&-2048;cA=c5&-2048;bB=(bC&65535)>(cA&65535)?bC-cA&65535:0;cA=f&2016;bC=c5&2016;if((cA&65535)>(bC&65535)){c6=(cA-bC&65535)+bB&65535}else{c6=bB}bB=f&31;f=c5&31;if((bB&65535)<=(f&65535)){c3=c6;break}c3=(bB-f&65535)+c6&65535}}while(0);b[(c[277218]|0)+(h<<1)>>1]=c3;do{if((a[1108928]|0)==0){f=b[(c[277213]|0)+(cE+8<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)!=0){c7=b[(c[277221]|0)+((f&65535|67616)-(b[(c[277226]|0)+(i<<1)>>1]&63454)>>1<<1)>>1]|0;break}bB=c[277228]&65535;bC=f&-2048;cA=bB&-2048;g=(bC&65535)>(cA&65535)?bC-cA&65535:0;cA=f&2016;bC=bB&2016;if((cA&65535)>(bC&65535)){c8=(cA-bC&65535)+g&65535}else{c8=g}g=f&31;f=bB&31;if((g&65535)<=(f&65535)){c7=c8;break}c7=(g-f&65535)+c8&65535}else{c7=0}}while(0);i=cE+7|0;b[(c[277218]|0)+(i<<1)>>1]=c7;f=a[1108909]|0;a[(c[277219]|0)+i|0]=f;a[(c[277219]|0)+h|0]=f;c1=a[1108908]|0;c2=c[277219]|0}else{c1=cV;c2=cW}}while(0);h=cE+8|0;do{if((c1&255)>(d[c2+h|0]|0)){f=a[cC+4|0]|0;i=f&255;if(f<<24>>24==0){c9=c1;da=c2;break}do{if((a[1108928]|0)==0){f=b[(c[277225]|0)+(i<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)!=0){db=b[(c[277221]|0)+((f&65535|67616)-(b[(c[277213]|0)+(h<<1)>>1]&63454)>>1<<1)>>1]|0;break}g=c[277228]&65535;bB=f&-2048;bC=g&-2048;cA=(bB&65535)>(bC&65535)?bB-bC&65535:0;bC=f&2016;bB=g&2016;if((bC&65535)>(bB&65535)){dc=(bC-bB&65535)+cA&65535}else{dc=cA}cA=f&31;f=g&31;if((cA&65535)<=(f&65535)){db=dc;break}db=(cA-f&65535)+dc&65535}else{f=b[(c[277225]|0)+(i<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)==0){dd=c[277228]&65535}else{dd=b[(c[277213]|0)+(h<<1)>>1]|0}cA=f&-2048;g=dd&-2048;bB=(cA&65535)>(g&65535)?cA-g&65535:0;g=f&2016;cA=dd&2016;if((g&65535)>(cA&65535)){de=(g-cA&65535)+bB&65535}else{de=bB}bB=f&31;f=dd&31;if((bB&65535)<=(f&65535)){db=de;break}db=(bB-f&65535)+de&65535}}while(0);b[(c[277218]|0)+(h<<1)>>1]=db;do{if((a[1108928]|0)==0){f=b[(c[277213]|0)+(cE+10<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)!=0){df=b[(c[277221]|0)+((f&65535|67616)-(b[(c[277226]|0)+(i<<1)>>1]&63454)>>1<<1)>>1]|0;break}bB=c[277228]&65535;cA=f&-2048;g=bB&-2048;bC=(cA&65535)>(g&65535)?cA-g&65535:0;g=f&2016;cA=bB&2016;if((g&65535)>(cA&65535)){dg=(g-cA&65535)+bC&65535}else{dg=bC}bC=f&31;f=bB&31;if((bC&65535)<=(f&65535)){df=dg;break}df=(bC-f&65535)+dg&65535}else{df=0}}while(0);i=cE+9|0;b[(c[277218]|0)+(i<<1)>>1]=df;f=a[1108909]|0;a[(c[277219]|0)+i|0]=f;a[(c[277219]|0)+h|0]=f;c9=a[1108908]|0;da=c[277219]|0}else{c9=c1;da=c2}}while(0);h=cE+10|0;do{if((c9&255)>(d[da+h|0]|0)){f=a[cC+5|0]|0;i=f&255;if(f<<24>>24==0){dh=c9;di=da;break}do{if((a[1108928]|0)==0){f=b[(c[277225]|0)+(i<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)!=0){dj=b[(c[277221]|0)+((f&65535|67616)-(b[(c[277213]|0)+(h<<1)>>1]&63454)>>1<<1)>>1]|0;break}bC=c[277228]&65535;bB=f&-2048;cA=bC&-2048;g=(bB&65535)>(cA&65535)?bB-cA&65535:0;cA=f&2016;bB=bC&2016;if((cA&65535)>(bB&65535)){dk=(cA-bB&65535)+g&65535}else{dk=g}g=f&31;f=bC&31;if((g&65535)<=(f&65535)){dj=dk;break}dj=(g-f&65535)+dk&65535}else{f=b[(c[277225]|0)+(i<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)==0){dl=c[277228]&65535}else{dl=b[(c[277213]|0)+(h<<1)>>1]|0}g=f&-2048;bC=dl&-2048;bB=(g&65535)>(bC&65535)?g-bC&65535:0;bC=f&2016;g=dl&2016;if((bC&65535)>(g&65535)){dm=(bC-g&65535)+bB&65535}else{dm=bB}bB=f&31;f=dl&31;if((bB&65535)<=(f&65535)){dj=dm;break}dj=(bB-f&65535)+dm&65535}}while(0);b[(c[277218]|0)+(h<<1)>>1]=dj;do{if((a[1108928]|0)==0){f=b[(c[277213]|0)+(cE+12<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)!=0){dn=b[(c[277221]|0)+((f&65535|67616)-(b[(c[277226]|0)+(i<<1)>>1]&63454)>>1<<1)>>1]|0;break}bB=c[277228]&65535;g=f&-2048;bC=bB&-2048;cA=(g&65535)>(bC&65535)?g-bC&65535:0;bC=f&2016;g=bB&2016;if((bC&65535)>(g&65535)){dp=(bC-g&65535)+cA&65535}else{dp=cA}cA=f&31;f=bB&31;if((cA&65535)<=(f&65535)){dn=dp;break}dn=(cA-f&65535)+dp&65535}else{dn=0}}while(0);i=cE+11|0;b[(c[277218]|0)+(i<<1)>>1]=dn;f=a[1108909]|0;a[(c[277219]|0)+i|0]=f;a[(c[277219]|0)+h|0]=f;dh=a[1108908]|0;di=c[277219]|0}else{dh=c9;di=da}}while(0);h=cE+12|0;do{if((dh&255)>(d[di+h|0]|0)){f=a[cC+6|0]|0;i=f&255;if(f<<24>>24==0){dq=dh;dr=di;break}do{if((a[1108928]|0)==0){f=b[(c[277225]|0)+(i<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)!=0){ds=b[(c[277221]|0)+((f&65535|67616)-(b[(c[277213]|0)+(h<<1)>>1]&63454)>>1<<1)>>1]|0;break}cA=c[277228]&65535;bB=f&-2048;g=cA&-2048;bC=(bB&65535)>(g&65535)?bB-g&65535:0;g=f&2016;bB=cA&2016;if((g&65535)>(bB&65535)){dt=(g-bB&65535)+bC&65535}else{dt=bC}bC=f&31;f=cA&31;if((bC&65535)<=(f&65535)){ds=dt;break}ds=(bC-f&65535)+dt&65535}else{f=b[(c[277225]|0)+(i<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)==0){du=c[277228]&65535}else{du=b[(c[277213]|0)+(h<<1)>>1]|0}bC=f&-2048;cA=du&-2048;bB=(bC&65535)>(cA&65535)?bC-cA&65535:0;cA=f&2016;bC=du&2016;if((cA&65535)>(bC&65535)){dv=(cA-bC&65535)+bB&65535}else{dv=bB}bB=f&31;f=du&31;if((bB&65535)<=(f&65535)){ds=dv;break}ds=(bB-f&65535)+dv&65535}}while(0);b[(c[277218]|0)+(h<<1)>>1]=ds;do{if((a[1108928]|0)==0){f=b[(c[277213]|0)+(cE+14<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)!=0){dw=b[(c[277221]|0)+((f&65535|67616)-(b[(c[277226]|0)+(i<<1)>>1]&63454)>>1<<1)>>1]|0;break}bB=c[277228]&65535;bC=f&-2048;cA=bB&-2048;g=(bC&65535)>(cA&65535)?bC-cA&65535:0;cA=f&2016;bC=bB&2016;if((cA&65535)>(bC&65535)){dx=(cA-bC&65535)+g&65535}else{dx=g}g=f&31;f=bB&31;if((g&65535)<=(f&65535)){dw=dx;break}dw=(g-f&65535)+dx&65535}else{dw=0}}while(0);i=cE+13|0;b[(c[277218]|0)+(i<<1)>>1]=dw;f=a[1108909]|0;a[(c[277219]|0)+i|0]=f;a[(c[277219]|0)+h|0]=f;dq=a[1108908]|0;dr=c[277219]|0}else{dq=dh;dr=di}}while(0);h=cE+14|0;do{if((dq&255)>(d[dr+h|0]|0)){f=a[cC+7|0]|0;i=f&255;if(f<<24>>24==0){break}do{if((a[1108928]|0)==0){f=b[(c[277225]|0)+(i<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)!=0){dy=b[(c[277221]|0)+((f&65535|67616)-(b[(c[277213]|0)+(h<<1)>>1]&63454)>>1<<1)>>1]|0;break}g=c[277228]&65535;bB=f&-2048;bC=g&-2048;cA=(bB&65535)>(bC&65535)?bB-bC&65535:0;bC=f&2016;bB=g&2016;if((bC&65535)>(bB&65535)){dz=(bC-bB&65535)+cA&65535}else{dz=cA}cA=f&31;f=g&31;if((cA&65535)<=(f&65535)){dy=dz;break}dy=(cA-f&65535)+dz&65535}else{f=b[(c[277225]|0)+(i<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)==0){dA=c[277228]&65535}else{dA=b[(c[277213]|0)+(h<<1)>>1]|0}cA=f&-2048;g=dA&-2048;bB=(cA&65535)>(g&65535)?cA-g&65535:0;g=f&2016;cA=dA&2016;if((g&65535)>(cA&65535)){dB=(g-cA&65535)+bB&65535}else{dB=bB}bB=f&31;f=dA&31;if((bB&65535)<=(f&65535)){dy=dB;break}dy=(bB-f&65535)+dB&65535}}while(0);b[(c[277218]|0)+(h<<1)>>1]=dy;do{if((a[1108928]|0)==0){f=b[(c[277213]|0)+(cE+16<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)!=0){dC=b[(c[277221]|0)+((f&65535|67616)-(b[(c[277226]|0)+(i<<1)>>1]&63454)>>1<<1)>>1]|0;break}bB=c[277228]&65535;cA=f&-2048;g=bB&-2048;bC=(cA&65535)>(g&65535)?cA-g&65535:0;g=f&2016;cA=bB&2016;if((g&65535)>(cA&65535)){dD=(g-cA&65535)+bC&65535}else{dD=bC}bC=f&31;f=bB&31;if((bC&65535)<=(f&65535)){dC=dD;break}dC=(bC-f&65535)+dD&65535}else{dC=0}}while(0);i=cE+15|0;b[(c[277218]|0)+(i<<1)>>1]=dC;f=a[1108909]|0;a[(c[277219]|0)+i|0]=f;a[(c[277219]|0)+h|0]=f}}while(0);h=cD-1|0;if((h|0)<=0){break}cC=cC-8|0;cD=h;cE=(c[277223]|0)+cE|0}return}}function VO(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;i=c[263194]|0;c[277226]=1106168;c[277225]=(a[1108928]|0)!=0?1393712:1106168;j=c[277230]|0;if(j>>>0>(c[277231]|0)>>>0){return}k=f>>>0<g>>>0;l=g-1|0;m=ab(c[277223]|0,j)|0;n=j;o=1097960+(j<<4)|0;while(1){j=e[o+12>>1]<<19>>19;p=e[o+8>>1]<<19;q=e[o+10>>1]<<19;r=n+1|0;s=(e[o+14>>1]<<19>>19)-(q>>19)|0;t=(s&8192|0)!=0?s|-1024:s&1023;s=b[o+2>>1]|0;u=((a[1044414]|0)==0?r:r^255)&255;v=(ab(u,s)|0)&-64;w=v+(p>>11)+((ab(t,s)|0)&-64)|0;s=b[o+6>>1]|0;v=(ab(s,u)|0)&-64;u=v+(q>>11)+((ab(t,s)|0)&-64)|0;s=b[o>>1]|0;if((a[1044413]|0)==0){t=b[o+4>>1]|0;x=s;y=t<<16>>16;z=f;A=t}else{t=b[o+4>>1]|0;x=-s|0;y=-(t<<16>>16)|0;z=l;A=t}t=j-(p>>19)|0;p=(t&8192|0)!=0?t|-1024:t&1023;t=ab(z,s)|0;j=t+((ab(s,p)|0)&-64)|0;s=A<<16>>16;t=ab(s,z)|0;q=((ab(s,p)|0)&-64)+t|0;L1668:do{if((a[1044415]|0)==0){if(k){B=q;C=j;D=f}else{break}while(1){t=C+w|0;p=(B+u|0)>>>8;s=a[i+(t>>>8<<1&14|p<<4&112|d[(c[263194]|0)+(p<<5&32512|t>>>10&254)|0]<<7|1)|0]|0;t=((s&255)>>>4&8|3)+h|0;p=(D<<1)+m|0;do{if((t|0)>(d[(c[277219]|0)+p|0]|0)){v=s&127;if(v<<24>>24==0){break}b[(c[277218]|0)+(p<<1)>>1]=b[(c[277225]|0)+((v&255)<<1)>>1]|0;if((a[1108928]|0)==0){E=b[(c[277213]|0)+(p+2<<1)>>1]|0}else{E=0}v=p+1|0;b[(c[277218]|0)+(v<<1)>>1]=E;F=t&255;a[(c[277219]|0)+v|0]=F;a[(c[277219]|0)+p|0]=F}}while(0);p=D+1|0;if(p>>>0>=g>>>0){break L1668}B=B+y|0;C=C+x|0;D=p}}else{if(k){G=q;H=j;I=f}else{break}while(1){p=H+w|0;t=p>>8;s=G+u>>8;do{if((s|t)>>>0<1024){J=s<<4&112|t<<1&14|d[(c[263194]|0)+((s<<5&-256)+(p>>10&-2))|0]<<7;K=1228}else{if((a[1044415]|0)!=3){break}J=s<<4&112|t<<1&14;K=1228}}while(0);do{if((K|0)==1228){K=0;t=a[i+(J|1)|0]|0;s=((t&255)>>>4&8|3)+h|0;p=(I<<1)+m|0;if((s|0)<=(d[(c[277219]|0)+p|0]|0)){break}F=t&127;if(F<<24>>24==0){break}b[(c[277218]|0)+(p<<1)>>1]=b[(c[277225]|0)+((F&255)<<1)>>1]|0;if((a[1108928]|0)==0){L=b[(c[277213]|0)+(p+2<<1)>>1]|0}else{L=0}F=p+1|0;b[(c[277218]|0)+(F<<1)>>1]=L;t=s&255;a[(c[277219]|0)+F|0]=t;a[(c[277219]|0)+p|0]=t}}while(0);t=I+1|0;if(t>>>0<g>>>0){G=G+y|0;H=H+x|0;I=t}else{break}}}}while(0);if(r>>>0>(c[277231]|0)>>>0){break}m=(c[277223]|0)+m|0;n=r;o=o+16|0}return}function VP(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ac=0;i=c[263194]|0;c[277226]=1106168;c[277225]=(a[1108928]|0)!=0?1393712:1106168;j=c[277230]|0;if(j>>>0>(c[277231]|0)>>>0){return}k=f>>>0<g>>>0;l=g-1|0;m=ab(c[277223]|0,j)|0;n=j;o=1097960+(j<<4)|0;while(1){j=e[o+12>>1]<<19>>19;p=e[o+8>>1]<<19;q=e[o+10>>1]<<19;r=n+1|0;s=(e[o+14>>1]<<19>>19)-(q>>19)|0;t=(s&8192|0)!=0?s|-1024:s&1023;s=b[o+2>>1]|0;u=((a[1044414]|0)==0?r:r^255)&255;v=(ab(u,s)|0)&-64;w=v+(p>>11)+((ab(t,s)|0)&-64)|0;s=b[o+6>>1]|0;v=(ab(s,u)|0)&-64;u=v+(q>>11)+((ab(t,s)|0)&-64)|0;s=b[o>>1]|0;if((a[1044413]|0)==0){t=b[o+4>>1]|0;x=s;y=t<<16>>16;z=f;A=t}else{t=b[o+4>>1]|0;x=-s|0;y=-(t<<16>>16)|0;z=l;A=t}t=j-(p>>19)|0;p=(t&8192|0)!=0?t|-1024:t&1023;t=ab(z,s)|0;j=t+((ab(s,p)|0)&-64)|0;s=A<<16>>16;t=ab(s,z)|0;q=((ab(s,p)|0)&-64)+t|0;L1708:do{if((a[1044415]|0)==0){if(k){B=q;C=j;D=f}else{break}while(1){t=C+w|0;p=(B+u|0)>>>8;s=a[i+(t>>>8<<1&14|p<<4&112|d[(c[263194]|0)+(p<<5&32512|t>>>10&254)|0]<<7|1)|0]|0;t=((s&255)>>>4&8|3)+h|0;p=(D<<1)+m|0;do{if((t|0)>(d[(c[277219]|0)+p|0]|0)){v=s&127;E=v&255;if(v<<24>>24==0){break}v=e[(c[277225]|0)+(E<<1)>>1]|0;F=(a[(c[277215]|0)+p|0]&32)==0;if(F){G=c[277228]|0;H=G;I=G&-2082}else{G=e[(c[277213]|0)+(p<<1)>>1]|0;H=G;I=G&63454}if(F){J=c[277228]|0}else{J=e[(c[277213]|0)+(p<<1)>>1]|0}b[(c[277218]|0)+(p<<1)>>1]=((J^v)&2081|e[(c[277220]|0)+((v&2081&H)+((I+(v&63454)|0)>>>1)<<1)>>1])&65535;v=(a[1108928]|0)==0;if(v){K=b[(c[277213]|0)+(p+2<<1)>>1]&63454}else{K=0}F=(a[(c[277215]|0)+p|0]&32)==0;if(F){L=c[277228]|0}else{L=e[(c[277226]|0)+(E<<1)>>1]|0}if(v){M=b[(c[277213]|0)+(p+2<<1)>>1]&2081}else{M=0}if(F){N=c[277228]|0}else{N=e[(c[277226]|0)+(E<<1)>>1]|0}if(v){O=e[(c[277213]|0)+(p+2<<1)>>1]|0}else{O=0}if(F){P=c[277228]|0}else{P=e[(c[277226]|0)+(E<<1)>>1]|0}E=p+1|0;b[(c[277218]|0)+(E<<1)>>1]=((P^O)&2081|e[(c[277220]|0)+((N&M)+(((L&-2082)+K|0)>>>1)<<1)>>1])&65535;F=t&255;a[(c[277219]|0)+E|0]=F;a[(c[277219]|0)+p|0]=F}}while(0);p=D+1|0;if(p>>>0>=g>>>0){break L1708}B=B+y|0;C=C+x|0;D=p}}else{if(k){Q=q;R=j;S=f}else{break}while(1){p=R+w|0;t=p>>8;s=Q+u>>8;do{if((s|t)>>>0<1024){T=s<<4&112|t<<1&14|d[(c[263194]|0)+((s<<5&-256)+(p>>10&-2))|0]<<7;U=1277}else{if((a[1044415]|0)!=3){break}T=s<<4&112|t<<1&14;U=1277}}while(0);do{if((U|0)==1277){U=0;t=a[i+(T|1)|0]|0;s=((t&255)>>>4&8|3)+h|0;p=(S<<1)+m|0;if((s|0)<=(d[(c[277219]|0)+p|0]|0)){break}F=t&127;t=F&255;if(F<<24>>24==0){break}F=e[(c[277225]|0)+(t<<1)>>1]|0;E=(a[(c[277215]|0)+p|0]&32)==0;if(E){v=c[277228]|0;V=v;W=v&-2082}else{v=e[(c[277213]|0)+(p<<1)>>1]|0;V=v;W=v&63454}if(E){X=c[277228]|0}else{X=e[(c[277213]|0)+(p<<1)>>1]|0}b[(c[277218]|0)+(p<<1)>>1]=((X^F)&2081|e[(c[277220]|0)+((F&2081&V)+((W+(F&63454)|0)>>>1)<<1)>>1])&65535;F=(a[1108928]|0)==0;if(F){Y=b[(c[277213]|0)+(p+2<<1)>>1]&63454}else{Y=0}E=(a[(c[277215]|0)+p|0]&32)==0;if(E){Z=c[277228]|0}else{Z=e[(c[277226]|0)+(t<<1)>>1]|0}if(F){_=b[(c[277213]|0)+(p+2<<1)>>1]&2081}else{_=0}if(E){$=c[277228]|0}else{$=e[(c[277226]|0)+(t<<1)>>1]|0}if(F){aa=e[(c[277213]|0)+(p+2<<1)>>1]|0}else{aa=0}if(E){ac=c[277228]|0}else{ac=e[(c[277226]|0)+(t<<1)>>1]|0}t=p+1|0;b[(c[277218]|0)+(t<<1)>>1]=((ac^aa)&2081|e[(c[277220]|0)+(($&_)+(((Z&-2082)+Y|0)>>>1)<<1)>>1])&65535;E=s&255;a[(c[277219]|0)+t|0]=E;a[(c[277219]|0)+p|0]=E}}while(0);E=S+1|0;if(E>>>0<g>>>0){Q=Q+y|0;R=R+x|0;S=E}else{break}}}}while(0);if(r>>>0>(c[277231]|0)>>>0){break}m=(c[277223]|0)+m|0;n=r;o=o+16|0}return}function VQ(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;i=c[263194]|0;c[277226]=1106168;c[277225]=(a[1108928]|0)!=0?1393712:1106168;j=c[277230]|0;if(j>>>0>(c[277231]|0)>>>0){return}k=f>>>0<g>>>0;l=g-1|0;m=ab(c[277223]|0,j)|0;n=j;o=1097960+(j<<4)|0;while(1){j=e[o+12>>1]<<19>>19;p=e[o+8>>1]<<19;q=e[o+10>>1]<<19;r=n+1|0;s=(e[o+14>>1]<<19>>19)-(q>>19)|0;t=(s&8192|0)!=0?s|-1024:s&1023;s=b[o+2>>1]|0;u=((a[1044414]|0)==0?r:r^255)&255;v=(ab(u,s)|0)&-64;w=v+(p>>11)+((ab(t,s)|0)&-64)|0;s=b[o+6>>1]|0;v=(ab(s,u)|0)&-64;u=v+(q>>11)+((ab(t,s)|0)&-64)|0;s=b[o>>1]|0;if((a[1044413]|0)==0){t=b[o+4>>1]|0;x=s;y=t<<16>>16;z=f;A=t}else{t=b[o+4>>1]|0;x=-s|0;y=-(t<<16>>16)|0;z=l;A=t}t=j-(p>>19)|0;p=(t&8192|0)!=0?t|-1024:t&1023;t=ab(z,s)|0;j=t+((ab(s,p)|0)&-64)|0;s=A<<16>>16;t=ab(s,z)|0;q=((ab(s,p)|0)&-64)+t|0;L1800:do{if((a[1044415]|0)==0){if(k){B=q;C=j;D=f}else{break}while(1){t=C+w|0;p=(B+u|0)>>>8;s=a[i+(t>>>8<<1&14|p<<4&112|d[(c[263194]|0)+(p<<5&32512|t>>>10&254)|0]<<7|1)|0]|0;t=((s&255)>>>4&8|3)+h|0;p=(D<<1)+m|0;do{if((t|0)>(d[(c[277219]|0)+p|0]|0)){v=s&127;if(v<<24>>24==0){break}E=e[(c[277225]|0)+((v&255)<<1)>>1]|0;v=c[277228]|0;F=(((E&63454)+(v&-2082)|0)>>>1)+(v&2081&E)|0;if((a[1108928]|0)==0){G=F&65535}else{G=(e[(c[277220]|0)+(F<<1)>>1]|(E^v)&2081)&65535}b[(c[277218]|0)+(p<<1)>>1]=G;if((a[1108928]|0)==0){v=e[(c[277213]|0)+(p+2<<1)>>1]|0;E=c[277228]|0;H=(((v&63454)+(E&128990)|0)>>>1)+(E&2081&v)|0}else{v=c[277228]|0;H=e[(c[277220]|0)+((v>>>1&2147482607)<<1)>>1]|v&2081}v=p+1|0;b[(c[277218]|0)+(v<<1)>>1]=H&65535;E=t&255;a[(c[277219]|0)+v|0]=E;a[(c[277219]|0)+p|0]=E}}while(0);p=D+1|0;if(p>>>0>=g>>>0){break L1800}B=B+y|0;C=C+x|0;D=p}}else{if(k){I=q;J=j;K=f}else{break}while(1){p=J+w|0;t=p>>8;s=I+u>>8;do{if((s|t)>>>0<1024){L=s<<4&112|t<<1&14|d[(c[263194]|0)+((s<<5&-256)+(p>>10&-2))|0]<<7;M=1329}else{if((a[1044415]|0)!=3){break}L=s<<4&112|t<<1&14;M=1329}}while(0);do{if((M|0)==1329){M=0;t=a[i+(L|1)|0]|0;s=((t&255)>>>4&8|3)+h|0;p=(K<<1)+m|0;if((s|0)<=(d[(c[277219]|0)+p|0]|0)){break}E=t&127;if(E<<24>>24==0){break}t=e[(c[277225]|0)+((E&255)<<1)>>1]|0;E=c[277228]|0;v=(((t&63454)+(E&-2082)|0)>>>1)+(E&2081&t)|0;if((a[1108928]|0)==0){N=v&65535}else{N=(e[(c[277220]|0)+(v<<1)>>1]|(t^E)&2081)&65535}b[(c[277218]|0)+(p<<1)>>1]=N;if((a[1108928]|0)==0){E=e[(c[277213]|0)+(p+2<<1)>>1]|0;t=c[277228]|0;O=(((E&63454)+(t&128990)|0)>>>1)+(t&2081&E)|0}else{E=c[277228]|0;O=e[(c[277220]|0)+((E>>>1&2147482607)<<1)>>1]|E&2081}E=p+1|0;b[(c[277218]|0)+(E<<1)>>1]=O&65535;t=s&255;a[(c[277219]|0)+E|0]=t;a[(c[277219]|0)+p|0]=t}}while(0);t=K+1|0;if(t>>>0<g>>>0){I=I+y|0;J=J+x|0;K=t}else{break}}}}while(0);if(r>>>0>(c[277231]|0)>>>0){break}m=(c[277223]|0)+m|0;n=r;o=o+16|0}return}function VR(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;i=c[263194]|0;c[277226]=1106168;c[277225]=(a[1108928]|0)!=0?1393712:1106168;j=c[277230]|0;if(j>>>0>(c[277231]|0)>>>0){return}k=f>>>0<g>>>0;l=g-1|0;m=ab(c[277223]|0,j)|0;n=j;o=1097960+(j<<4)|0;while(1){j=e[o+12>>1]<<19>>19;p=e[o+8>>1]<<19;q=e[o+10>>1]<<19;r=n+1|0;s=(e[o+14>>1]<<19>>19)-(q>>19)|0;t=(s&8192|0)!=0?s|-1024:s&1023;s=b[o+2>>1]|0;u=((a[1044414]|0)==0?r:r^255)&255;v=(ab(u,s)|0)&-64;w=v+(p>>11)+((ab(t,s)|0)&-64)|0;s=b[o+6>>1]|0;v=(ab(s,u)|0)&-64;u=v+(q>>11)+((ab(t,s)|0)&-64)|0;s=b[o>>1]|0;if((a[1044413]|0)==0){t=b[o+4>>1]|0;x=s;y=t<<16>>16;z=f;A=t}else{t=b[o+4>>1]|0;x=-s|0;y=-(t<<16>>16)|0;z=l;A=t}t=j-(p>>19)|0;p=(t&8192|0)!=0?t|-1024:t&1023;t=ab(z,s)|0;j=t+((ab(s,p)|0)&-64)|0;s=A<<16>>16;t=ab(s,z)|0;q=((ab(s,p)|0)&-64)+t|0;L1848:do{if((a[1044415]|0)==0){if(k){B=q;C=j;D=f}else{break}while(1){t=C+w|0;p=(B+u|0)>>>8;s=a[i+(t>>>8<<1&14|p<<4&112|d[(c[263194]|0)+(p<<5&32512|t>>>10&254)|0]<<7|1)|0]|0;t=((s&255)>>>4&8|3)+h|0;p=(D<<1)+m|0;do{if((t|0)>(d[(c[277219]|0)+p|0]|0)){v=s&127;E=v&255;if(v<<24>>24==0){break}do{if((a[1108928]|0)==0){v=b[(c[277225]|0)+(E<<1)>>1]|0;F=v&65535;G=F&63454;if((a[(c[277215]|0)+p|0]&32)==0){H=c[277228]|0;I=(e[(c[277220]|0)+((((H&-2082)+G|0)>>>1)+(F&2081&H)<<1)>>1]|(H^F)&2081)&65535;break}else{F=b[(c[277213]|0)+(p<<1)>>1]|0;I=(((F&63454)+G|0)>>>1)+(F&v&2081)&65535;break}}else{v=e[(c[277225]|0)+(E<<1)>>1]|0;F=(a[(c[277215]|0)+p|0]&32)==0;if(F){G=c[277228]|0;J=G;K=G&-2082}else{G=e[(c[277213]|0)+(p<<1)>>1]|0;J=G;K=G&63454}if(F){L=c[277228]|0}else{L=e[(c[277213]|0)+(p<<1)>>1]|0}I=((L^v)&2081|e[(c[277220]|0)+((v&2081&J)+((K+(v&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=I;v=(a[(c[277215]|0)+p|0]&32)==0;do{if((a[1108928]|0)==0){F=e[(c[277213]|0)+(p+2<<1)>>1]|0;G=F&63454;if(v){H=c[277228]|0;M=(e[(c[277220]|0)+((((H&-2082)+G|0)>>>1)+(F&2081&H)<<1)>>1]|(H^F)&2081)&65535;break}else{H=e[(c[277226]|0)+(E<<1)>>1]|0;M=(((H&63454)+G|0)>>>1)+(F&2081&H)&65535;break}}else{if(v){H=c[277228]|0;N=H;O=(c[277220]|0)+((H>>>1&2147482607)<<1)|0}else{H=e[(c[277226]|0)+(E<<1)>>1]|0;N=H;O=(c[277220]|0)+((H>>>1&31727)<<1)|0}M=(e[O>>1]|N&2081)&65535}}while(0);E=p+1|0;b[(c[277218]|0)+(E<<1)>>1]=M;v=t&255;a[(c[277219]|0)+E|0]=v;a[(c[277219]|0)+p|0]=v}}while(0);p=D+1|0;if(p>>>0>=g>>>0){break L1848}B=B+y|0;C=C+x|0;D=p}}else{if(k){P=q;Q=j;R=f}else{break}while(1){p=Q+w|0;t=p>>8;s=P+u>>8;do{if((s|t)>>>0<1024){S=s<<4&112|t<<1&14|d[(c[263194]|0)+((s<<5&-256)+(p>>10&-2))|0]<<7;T=1379}else{if((a[1044415]|0)!=3){break}S=s<<4&112|t<<1&14;T=1379}}while(0);do{if((T|0)==1379){T=0;t=a[i+(S|1)|0]|0;s=((t&255)>>>4&8|3)+h|0;p=(R<<1)+m|0;if((s|0)<=(d[(c[277219]|0)+p|0]|0)){break}v=t&127;t=v&255;if(v<<24>>24==0){break}do{if((a[1108928]|0)==0){v=b[(c[277225]|0)+(t<<1)>>1]|0;E=v&65535;H=E&63454;if((a[(c[277215]|0)+p|0]&32)==0){F=c[277228]|0;U=(e[(c[277220]|0)+((((F&-2082)+H|0)>>>1)+(E&2081&F)<<1)>>1]|(F^E)&2081)&65535;break}else{E=b[(c[277213]|0)+(p<<1)>>1]|0;U=(((E&63454)+H|0)>>>1)+(E&v&2081)&65535;break}}else{v=e[(c[277225]|0)+(t<<1)>>1]|0;E=(a[(c[277215]|0)+p|0]&32)==0;if(E){H=c[277228]|0;V=H;W=H&-2082}else{H=e[(c[277213]|0)+(p<<1)>>1]|0;V=H;W=H&63454}if(E){X=c[277228]|0}else{X=e[(c[277213]|0)+(p<<1)>>1]|0}U=((X^v)&2081|e[(c[277220]|0)+((v&2081&V)+((W+(v&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=U;v=(a[(c[277215]|0)+p|0]&32)==0;do{if((a[1108928]|0)==0){E=e[(c[277213]|0)+(p+2<<1)>>1]|0;H=E&63454;if(v){F=c[277228]|0;Y=(e[(c[277220]|0)+((((F&-2082)+H|0)>>>1)+(E&2081&F)<<1)>>1]|(F^E)&2081)&65535;break}else{F=e[(c[277226]|0)+(t<<1)>>1]|0;Y=(((F&63454)+H|0)>>>1)+(E&2081&F)&65535;break}}else{if(v){F=c[277228]|0;Z=F;_=(c[277220]|0)+((F>>>1&2147482607)<<1)|0}else{F=e[(c[277226]|0)+(t<<1)>>1]|0;Z=F;_=(c[277220]|0)+((F>>>1&31727)<<1)|0}Y=(e[_>>1]|Z&2081)&65535}}while(0);t=p+1|0;b[(c[277218]|0)+(t<<1)>>1]=Y;v=s&255;a[(c[277219]|0)+t|0]=v;a[(c[277219]|0)+p|0]=v}}while(0);v=R+1|0;if(v>>>0<g>>>0){P=P+y|0;Q=Q+x|0;R=v}else{break}}}}while(0);if(r>>>0>(c[277231]|0)>>>0){break}m=(c[277223]|0)+m|0;n=r;o=o+16|0}return}function VS(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;i=c[263194]|0;c[277226]=1106168;c[277225]=(a[1108928]|0)!=0?1393712:1106168;j=c[277230]|0;if(j>>>0>(c[277231]|0)>>>0){return}k=f>>>0<g>>>0;l=g-1|0;m=ab(c[277223]|0,j)|0;n=j;o=1097960+(j<<4)|0;while(1){j=e[o+12>>1]<<19>>19;p=e[o+8>>1]<<19;q=e[o+10>>1]<<19;r=n+1|0;s=(e[o+14>>1]<<19>>19)-(q>>19)|0;t=(s&8192|0)!=0?s|-1024:s&1023;s=b[o+2>>1]|0;u=((a[1044414]|0)==0?r:r^255)&255;v=(ab(u,s)|0)&-64;w=v+(p>>11)+((ab(t,s)|0)&-64)|0;s=b[o+6>>1]|0;v=(ab(s,u)|0)&-64;u=v+(q>>11)+((ab(t,s)|0)&-64)|0;s=b[o>>1]|0;if((a[1044413]|0)==0){t=b[o+4>>1]|0;x=s;y=t<<16>>16;z=f;A=t}else{t=b[o+4>>1]|0;x=-s|0;y=-(t<<16>>16)|0;z=l;A=t}t=j-(p>>19)|0;p=(t&8192|0)!=0?t|-1024:t&1023;t=ab(z,s)|0;j=t+((ab(s,p)|0)&-64)|0;s=A<<16>>16;t=ab(s,z)|0;q=((ab(s,p)|0)&-64)+t|0;L1934:do{if((a[1044415]|0)==0){if(k){B=q;C=j;D=f}else{break}while(1){t=C+w|0;p=(B+u|0)>>>8;s=a[i+(t>>>8<<1&14|p<<4&112|d[(c[263194]|0)+(p<<5&32512|t>>>10&254)|0]<<7|1)|0]|0;t=((s&255)>>>4&8|3)+h|0;p=(D<<1)+m|0;do{if((t|0)>(d[(c[277219]|0)+p|0]|0)){v=s&127;E=v&255;if(v<<24>>24==0){break}v=b[(c[277225]|0)+(E<<1)>>1]|0;if((a[(c[277215]|0)+p|0]&32)==0){F=c[277228]&65535}else{F=b[(c[277213]|0)+(p<<1)>>1]|0}G=v&-2048;H=F&-2048;I=(G&65535)>(H&65535)?G-H&65535:0;H=v&2016;G=F&2016;if((H&65535)>(G&65535)){J=(H-G&65535)+I&65535}else{J=I}I=v&31;v=F&31;if((I&65535)>(v&65535)){K=(I-v&65535)+J&65535}else{K=J}b[(c[277218]|0)+(p<<1)>>1]=K;if((a[1108928]|0)==0){L=b[(c[277213]|0)+(p+2<<1)>>1]|0}else{L=0}if((a[(c[277215]|0)+p|0]&32)==0){M=c[277228]&65535}else{M=b[(c[277226]|0)+(E<<1)>>1]|0}E=L&-2048;v=M&-2048;I=(E&65535)>(v&65535)?E-v&65535:0;v=L&2016;E=M&2016;if((v&65535)>(E&65535)){N=(v-E&65535)+I&65535}else{N=I}I=L&31;E=M&31;if((I&65535)>(E&65535)){O=(I-E&65535)+N&65535}else{O=N}E=p+1|0;b[(c[277218]|0)+(E<<1)>>1]=O;I=t&255;a[(c[277219]|0)+E|0]=I;a[(c[277219]|0)+p|0]=I}}while(0);p=D+1|0;if(p>>>0>=g>>>0){break L1934}B=B+y|0;C=C+x|0;D=p}}else{if(k){P=q;Q=j;R=f}else{break}while(1){p=Q+w|0;t=p>>8;s=P+u>>8;do{if((s|t)>>>0<1024){S=s<<4&112|t<<1&14|d[(c[263194]|0)+((s<<5&-256)+(p>>10&-2))|0]<<7;T=1440}else{if((a[1044415]|0)!=3){break}S=s<<4&112|t<<1&14;T=1440}}while(0);do{if((T|0)==1440){T=0;t=a[i+(S|1)|0]|0;s=((t&255)>>>4&8|3)+h|0;p=(R<<1)+m|0;if((s|0)<=(d[(c[277219]|0)+p|0]|0)){break}I=t&127;t=I&255;if(I<<24>>24==0){break}I=b[(c[277225]|0)+(t<<1)>>1]|0;if((a[(c[277215]|0)+p|0]&32)==0){U=c[277228]&65535}else{U=b[(c[277213]|0)+(p<<1)>>1]|0}E=I&-2048;v=U&-2048;G=(E&65535)>(v&65535)?E-v&65535:0;v=I&2016;E=U&2016;if((v&65535)>(E&65535)){V=(v-E&65535)+G&65535}else{V=G}G=I&31;I=U&31;if((G&65535)>(I&65535)){W=(G-I&65535)+V&65535}else{W=V}b[(c[277218]|0)+(p<<1)>>1]=W;if((a[1108928]|0)==0){X=b[(c[277213]|0)+(p+2<<1)>>1]|0}else{X=0}if((a[(c[277215]|0)+p|0]&32)==0){Y=c[277228]&65535}else{Y=b[(c[277226]|0)+(t<<1)>>1]|0}t=X&-2048;I=Y&-2048;G=(t&65535)>(I&65535)?t-I&65535:0;I=X&2016;t=Y&2016;if((I&65535)>(t&65535)){Z=(I-t&65535)+G&65535}else{Z=G}G=X&31;t=Y&31;if((G&65535)>(t&65535)){_=(G-t&65535)+Z&65535}else{_=Z}t=p+1|0;b[(c[277218]|0)+(t<<1)>>1]=_;G=s&255;a[(c[277219]|0)+t|0]=G;a[(c[277219]|0)+p|0]=G}}while(0);G=R+1|0;if(G>>>0<g>>>0){P=P+y|0;Q=Q+x|0;R=G}else{break}}}}while(0);if(r>>>0>(c[277231]|0)>>>0){break}m=(c[277223]|0)+m|0;n=r;o=o+16|0}return}function VT(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;i=c[263194]|0;c[277226]=1106168;c[277225]=(a[1108928]|0)!=0?1393712:1106168;j=c[277230]|0;if(j>>>0>(c[277231]|0)>>>0){return}k=f>>>0<g>>>0;l=g-1|0;m=ab(c[277223]|0,j)|0;n=j;o=1097960+(j<<4)|0;while(1){j=e[o+12>>1]<<19>>19;p=e[o+8>>1]<<19;q=e[o+10>>1]<<19;r=n+1|0;s=(e[o+14>>1]<<19>>19)-(q>>19)|0;t=(s&8192|0)!=0?s|-1024:s&1023;s=b[o+2>>1]|0;u=((a[1044414]|0)==0?r:r^255)&255;v=(ab(u,s)|0)&-64;w=v+(p>>11)+((ab(t,s)|0)&-64)|0;s=b[o+6>>1]|0;v=(ab(s,u)|0)&-64;u=v+(q>>11)+((ab(t,s)|0)&-64)|0;s=b[o>>1]|0;if((a[1044413]|0)==0){t=b[o+4>>1]|0;x=s;y=t<<16>>16;z=f;A=t}else{t=b[o+4>>1]|0;x=-s|0;y=-(t<<16>>16)|0;z=l;A=t}t=j-(p>>19)|0;p=(t&8192|0)!=0?t|-1024:t&1023;t=ab(z,s)|0;j=t+((ab(s,p)|0)&-64)|0;s=A<<16>>16;t=ab(s,z)|0;q=((ab(s,p)|0)&-64)+t|0;L2014:do{if((a[1044415]|0)==0){if(k){B=q;C=j;D=f}else{break}while(1){t=C+w|0;p=(B+u|0)>>>8;s=a[i+(t>>>8<<1&14|p<<4&112|d[(c[263194]|0)+(p<<5&32512|t>>>10&254)|0]<<7|1)|0]|0;t=((s&255)>>>4&8|3)+h|0;p=(D<<1)+m|0;do{if((t|0)>(d[(c[277219]|0)+p|0]|0)){v=s&127;if(v<<24>>24==0){break}E=b[(c[277225]|0)+((v&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){F=b[(c[277221]|0)+(((E&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{v=c[277228]&65535;G=E&-2048;H=v&-2048;I=(G&65535)>(H&65535)?G-H&65535:0;H=E&2016;G=v&2016;if((H&65535)>(G&65535)){J=(H-G&65535)+I&65535}else{J=I}I=E&31;G=v&31;if((I&65535)<=(G&65535)){F=J;break}F=(I-G&65535)+J&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=F;if((a[1108928]|0)==0){K=b[(c[277221]|0)+(((e[(c[277213]|0)+(p+2<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{K=0}E=p+1|0;b[(c[277218]|0)+(E<<1)>>1]=K;G=t&255;a[(c[277219]|0)+E|0]=G;a[(c[277219]|0)+p|0]=G}}while(0);p=D+1|0;if(p>>>0>=g>>>0){break L2014}B=B+y|0;C=C+x|0;D=p}}else{if(k){L=q;M=j;N=f}else{break}while(1){p=M+w|0;t=p>>8;s=L+u>>8;do{if((s|t)>>>0<1024){O=s<<4&112|t<<1&14|d[(c[263194]|0)+((s<<5&-256)+(p>>10&-2))|0]<<7;P=1490}else{if((a[1044415]|0)!=3){break}O=s<<4&112|t<<1&14;P=1490}}while(0);do{if((P|0)==1490){P=0;t=a[i+(O|1)|0]|0;s=((t&255)>>>4&8|3)+h|0;p=(N<<1)+m|0;if((s|0)<=(d[(c[277219]|0)+p|0]|0)){break}G=t&127;if(G<<24>>24==0){break}t=b[(c[277225]|0)+((G&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){Q=b[(c[277221]|0)+(((t&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{G=c[277228]&65535;E=t&-2048;I=G&-2048;v=(E&65535)>(I&65535)?E-I&65535:0;I=t&2016;E=G&2016;if((I&65535)>(E&65535)){R=(I-E&65535)+v&65535}else{R=v}v=t&31;E=G&31;if((v&65535)<=(E&65535)){Q=R;break}Q=(v-E&65535)+R&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=Q;if((a[1108928]|0)==0){S=b[(c[277221]|0)+(((e[(c[277213]|0)+(p+2<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{S=0}t=p+1|0;b[(c[277218]|0)+(t<<1)>>1]=S;E=s&255;a[(c[277219]|0)+t|0]=E;a[(c[277219]|0)+p|0]=E}}while(0);E=N+1|0;if(E>>>0<g>>>0){L=L+y|0;M=M+x|0;N=E}else{break}}}}while(0);if(r>>>0>(c[277231]|0)>>>0){break}m=(c[277223]|0)+m|0;n=r;o=o+16|0}return}function VU(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;i=c[263194]|0;c[277226]=1106168;c[277225]=(a[1108928]|0)!=0?1393712:1106168;j=c[277230]|0;if(j>>>0>(c[277231]|0)>>>0){return}k=f>>>0<g>>>0;l=g-1|0;m=ab(c[277223]|0,j)|0;n=j;o=1097960+(j<<4)|0;while(1){j=e[o+12>>1]<<19>>19;p=e[o+8>>1]<<19;q=e[o+10>>1]<<19;r=n+1|0;s=(e[o+14>>1]<<19>>19)-(q>>19)|0;t=(s&8192|0)!=0?s|-1024:s&1023;s=b[o+2>>1]|0;u=((a[1044414]|0)==0?r:r^255)&255;v=(ab(u,s)|0)&-64;w=v+(p>>11)+((ab(t,s)|0)&-64)|0;s=b[o+6>>1]|0;v=(ab(s,u)|0)&-64;u=v+(q>>11)+((ab(t,s)|0)&-64)|0;s=b[o>>1]|0;if((a[1044413]|0)==0){t=b[o+4>>1]|0;x=s;y=t<<16>>16;z=f;A=t}else{t=b[o+4>>1]|0;x=-s|0;y=-(t<<16>>16)|0;z=l;A=t}t=j-(p>>19)|0;p=(t&8192|0)!=0?t|-1024:t&1023;t=ab(z,s)|0;j=t+((ab(s,p)|0)&-64)|0;s=A<<16>>16;t=ab(s,z)|0;q=((ab(s,p)|0)&-64)+t|0;L2070:do{if((a[1044415]|0)==0){if(k){B=q;C=j;D=f}else{break}while(1){t=C+w|0;p=(B+u|0)>>>8;s=a[i+(t>>>8<<1&14|p<<4&112|d[(c[263194]|0)+(p<<5&32512|t>>>10&254)|0]<<7|1)|0]|0;t=((s&255)>>>4&8|3)+h|0;p=(D<<1)+m|0;do{if((t|0)>(d[(c[277219]|0)+p|0]|0)){v=s&127;E=v&255;if(v<<24>>24==0){break}do{if((a[1108928]|0)==0){v=b[(c[277225]|0)+(E<<1)>>1]|0;if((a[(c[277215]|0)+p|0]&32)!=0){F=b[(c[277221]|0)+((v&65535|67616)-(b[(c[277213]|0)+(p<<1)>>1]&63454)>>1<<1)>>1]|0;break}G=c[277228]&65535;H=v&-2048;I=G&-2048;J=(H&65535)>(I&65535)?H-I&65535:0;I=v&2016;H=G&2016;if((I&65535)>(H&65535)){K=(I-H&65535)+J&65535}else{K=J}J=v&31;v=G&31;if((J&65535)<=(v&65535)){F=K;break}F=(J-v&65535)+K&65535}else{v=b[(c[277225]|0)+(E<<1)>>1]|0;if((a[(c[277215]|0)+p|0]&32)==0){L=c[277228]&65535}else{L=b[(c[277213]|0)+(p<<1)>>1]|0}J=v&-2048;G=L&-2048;H=(J&65535)>(G&65535)?J-G&65535:0;G=v&2016;J=L&2016;if((G&65535)>(J&65535)){M=(G-J&65535)+H&65535}else{M=H}H=v&31;v=L&31;if((H&65535)<=(v&65535)){F=M;break}F=(H-v&65535)+M&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=F;do{if((a[1108928]|0)==0){v=b[(c[277213]|0)+(p+2<<1)>>1]|0;if((a[(c[277215]|0)+p|0]&32)!=0){N=b[(c[277221]|0)+((v&65535|67616)-(b[(c[277226]|0)+(E<<1)>>1]&63454)>>1<<1)>>1]|0;break}H=c[277228]&65535;J=v&-2048;G=H&-2048;I=(J&65535)>(G&65535)?J-G&65535:0;G=v&2016;J=H&2016;if((G&65535)>(J&65535)){O=(G-J&65535)+I&65535}else{O=I}I=v&31;v=H&31;if((I&65535)<=(v&65535)){N=O;break}N=(I-v&65535)+O&65535}else{N=0}}while(0);E=p+1|0;b[(c[277218]|0)+(E<<1)>>1]=N;v=t&255;a[(c[277219]|0)+E|0]=v;a[(c[277219]|0)+p|0]=v}}while(0);p=D+1|0;if(p>>>0>=g>>>0){break L2070}B=B+y|0;C=C+x|0;D=p}}else{if(k){P=q;Q=j;R=f}else{break}while(1){p=Q+w|0;t=p>>8;s=P+u>>8;do{if((s|t)>>>0<1024){S=s<<4&112|t<<1&14|d[(c[263194]|0)+((s<<5&-256)+(p>>10&-2))|0]<<7;T=1545}else{if((a[1044415]|0)!=3){break}S=s<<4&112|t<<1&14;T=1545}}while(0);do{if((T|0)==1545){T=0;t=a[i+(S|1)|0]|0;s=((t&255)>>>4&8|3)+h|0;p=(R<<1)+m|0;if((s|0)<=(d[(c[277219]|0)+p|0]|0)){break}v=t&127;t=v&255;if(v<<24>>24==0){break}do{if((a[1108928]|0)==0){v=b[(c[277225]|0)+(t<<1)>>1]|0;if((a[(c[277215]|0)+p|0]&32)!=0){U=b[(c[277221]|0)+((v&65535|67616)-(b[(c[277213]|0)+(p<<1)>>1]&63454)>>1<<1)>>1]|0;break}E=c[277228]&65535;I=v&-2048;H=E&-2048;J=(I&65535)>(H&65535)?I-H&65535:0;H=v&2016;I=E&2016;if((H&65535)>(I&65535)){V=(H-I&65535)+J&65535}else{V=J}J=v&31;v=E&31;if((J&65535)<=(v&65535)){U=V;break}U=(J-v&65535)+V&65535}else{v=b[(c[277225]|0)+(t<<1)>>1]|0;if((a[(c[277215]|0)+p|0]&32)==0){W=c[277228]&65535}else{W=b[(c[277213]|0)+(p<<1)>>1]|0}J=v&-2048;E=W&-2048;I=(J&65535)>(E&65535)?J-E&65535:0;E=v&2016;J=W&2016;if((E&65535)>(J&65535)){X=(E-J&65535)+I&65535}else{X=I}I=v&31;v=W&31;if((I&65535)<=(v&65535)){U=X;break}U=(I-v&65535)+X&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=U;do{if((a[1108928]|0)==0){v=b[(c[277213]|0)+(p+2<<1)>>1]|0;if((a[(c[277215]|0)+p|0]&32)!=0){Y=b[(c[277221]|0)+((v&65535|67616)-(b[(c[277226]|0)+(t<<1)>>1]&63454)>>1<<1)>>1]|0;break}I=c[277228]&65535;J=v&-2048;E=I&-2048;H=(J&65535)>(E&65535)?J-E&65535:0;E=v&2016;J=I&2016;if((E&65535)>(J&65535)){Z=(E-J&65535)+H&65535}else{Z=H}H=v&31;v=I&31;if((H&65535)<=(v&65535)){Y=Z;break}Y=(H-v&65535)+Z&65535}else{Y=0}}while(0);t=p+1|0;b[(c[277218]|0)+(t<<1)>>1]=Y;v=s&255;a[(c[277219]|0)+t|0]=v;a[(c[277219]|0)+p|0]=v}}while(0);v=R+1|0;if(v>>>0<g>>>0){P=P+y|0;Q=Q+x|0;R=v}else{break}}}}while(0);if(r>>>0>(c[277231]|0)>>>0){break}m=(c[277223]|0)+m|0;n=r;o=o+16|0}return}function VV(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0;i=c[263194]|0;c[277226]=1106168;c[277225]=(a[1108928]|0)!=0?1393712:1106168;j=c[277230]|0;if((a[1044434]|0)==0){k=j;l=1;m=0}else{n=d[1044432]|0;o=((j-(d[1044433]|0)|0)>>>0)%(n>>>0)|0;k=j-o|0;l=n;m=o}if((a[1044435]|0)==0){p=f;q=g;r=1}else{o=d[1044432]|0;n=g-1+o|0;p=f-((f|0)%(o|0)|0)|0;q=n-((n|0)%(o|0)|0)|0;r=o}o=c[277231]|0;if(k>>>0>o>>>0){return}n=(p|0)<(q|0);j=r&255;s=q-1|0;t=r-1|0;r=m;m=l;l=ab(c[277223]|0,k)|0;u=k;v=1097960+(k<<4)|0;k=o;while(1){if((m+u|0)>>>0>k>>>0){w=k+1-u|0}else{w=m}o=e[v+12>>1]<<19>>19;x=e[v+8>>1]<<19;y=e[v+10>>1]<<19;z=u+1|0;A=(e[v+14>>1]<<19>>19)-(y>>19)|0;B=(A&8192|0)!=0?A|-1024:A&1023;A=b[v+2>>1]|0;C=((a[1044414]|0)==0?z:z^255)&255;z=(ab(C,A)|0)&-64;D=z+(x>>11)+((ab(B,A)|0)&-64)|0;A=b[v+6>>1]|0;z=(ab(A,C)|0)&-64;C=z+(y>>11)+((ab(B,A)|0)&-64)|0;A=b[v>>1]|0;if((a[1044413]|0)==0){B=b[v+4>>1]|0;E=A;F=B<<16>>16;G=p;H=B}else{B=b[v+4>>1]|0;E=-A|0;F=-(B<<16>>16)|0;G=s;H=B}B=o-(x>>19)|0;x=(B&8192|0)!=0?B|-1024:B&1023;B=ab(G,A)|0;o=B+((ab(A,x)|0)&-64)|0;A=H<<16>>16;B=ab(A,G)|0;y=((ab(A,x)|0)&-64)+B|0;do{if((a[1044415]|0)==0){if(!n){break}B=(r|0)>=(w|0);x=o;A=y;z=1;I=p;while(1){J=z-1&255;do{if(J<<24>>24==0){K=x+D|0;L=(A+C|0)>>>8;M=a[i+(L<<4&112|K>>>8<<1&14|d[(c[263194]|0)+(L<<5&32512|K>>>10&254)|0]<<7|1)|0]|0;K=M&127;if(K<<24>>24==0|B){N=j;break}L=t+I|0;O=(L|0)<(I|0);P=(M<<24>>24<0?11:3)+h|0;M=K&255;K=P&255;Q=r;while(1){if(!O){R=L;do{S=(R<<1)+l|0;T=(ab(c[277223]|0,Q)|0)+S|0;if((R|0)>=(f|0)&(P|0)>(d[(c[277219]|0)+T|0]|0)&(R|0)<(g|0)){b[(c[277218]|0)+(T<<1)>>1]=b[(c[277225]|0)+(M<<1)>>1]|0;T=(a[1108928]|0)==0;U=ab(c[277223]|0,Q)|0;if(T){V=b[(c[277213]|0)+(S+2+U<<1)>>1]|0}else{V=0}T=S+1|0;b[(c[277218]|0)+(U+T<<1)>>1]=V;U=(ab(c[277223]|0,Q)|0)+T|0;a[(c[277219]|0)+U|0]=K;U=(ab(c[277223]|0,Q)|0)+S|0;a[(c[277219]|0)+U|0]=K}R=R-1|0;}while((R|0)>=(I|0))}R=Q+1|0;if((R|0)<(w|0)){Q=R}else{N=j;break}}}else{N=J}}while(0);J=I+1|0;if((J|0)<(q|0)){x=x+E|0;A=A+F|0;z=N;I=J}else{break}}}else{if(!n){break}I=(r|0)>=(w|0);z=o;A=y;x=1;B=p;while(1){J=x-1&255;do{if(J<<24>>24==0){Q=z+D|0;K=Q>>8;M=A+C>>8;if((K|M)>>>0<1024){W=K<<1&14|M<<4&112|d[(c[263194]|0)+((M<<5&-256)+(Q>>10&-2))|0]<<7}else{if((a[1044415]|0)!=3){X=j;break}W=K<<1&14|M<<4&112}M=a[i+(W|1)|0]|0;K=M&127;if(K<<24>>24==0|I){X=j;break}Q=t+B|0;P=(Q|0)<(B|0);L=(M<<24>>24<0?11:3)+h|0;M=K&255;K=L&255;O=r;while(1){if(!P){R=Q;do{U=(R<<1)+l|0;S=(ab(c[277223]|0,O)|0)+U|0;if((R|0)>=(f|0)&(L|0)>(d[(c[277219]|0)+S|0]|0)&(R|0)<(g|0)){b[(c[277218]|0)+(S<<1)>>1]=b[(c[277225]|0)+(M<<1)>>1]|0;S=(a[1108928]|0)==0;T=ab(c[277223]|0,O)|0;if(S){Y=b[(c[277213]|0)+(U+2+T<<1)>>1]|0}else{Y=0}S=U+1|0;b[(c[277218]|0)+(T+S<<1)>>1]=Y;T=(ab(c[277223]|0,O)|0)+S|0;a[(c[277219]|0)+T|0]=K;T=(ab(c[277223]|0,O)|0)+U|0;a[(c[277219]|0)+T|0]=K}R=R-1|0;}while((R|0)>=(B|0))}R=O+1|0;if((R|0)<(w|0)){O=R}else{X=j;break}}}else{X=J}}while(0);J=B+1|0;if((J|0)<(q|0)){z=z+E|0;A=A+F|0;x=X;B=J}else{break}}}}while(0);C=w+u|0;D=(ab(c[277223]|0,w)|0)+l|0;y=c[277231]|0;if(C>>>0>y>>>0){break}else{r=0;m=w;l=D;u=C;v=v+(w<<4)|0;k=y}}return}
function Wy(e,f,g,h,i,j){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0,cf=0,cg=0,ch=0,ci=0,cj=0,ck=0,cl=0,cm=0,cn=0,co=0,cp=0,cq=0,cr=0,cs=0,ct=0,cu=0,cv=0,cw=0,cx=0,cy=0,cz=0,cA=0,cB=0,cC=0,cD=0,cE=0,cF=0,cG=0,cH=0,cI=0,cJ=0,cK=0,cL=0,cM=0,cN=0,cO=0,cP=0,cQ=0,cR=0,cS=0,cT=0,cU=0,cV=0,cW=0,cX=0,cY=0,cZ=0,c_=0,c$=0,c0=0,c1=0,c2=0,c3=0,c4=0,c5=0;k=e&1023;l=c[348606]|0;m=(k<<l)+(c[348604]|0)|0;if((e&256|0)==0){n=m}else{n=(c[348602]|0)+m|0}m=n&65535;n=m>>>(l>>>0);l=(e&16384|0)!=0;o=n<<6;do{if(l){p=(c[348622]|0)+o|0;if((a[(c[348618]|0)+n|0]|0)!=0){q=p;break}r=fi[c[348636]&63](p,m,k)|0;a[(c[348618]|0)+n|0]=r;q=p}else{p=(c[348624]|0)+o|0;if((a[(c[348620]|0)+n|0]|0)!=0){q=p;break}r=fi[c[348638]&63](p,m,k)|0;a[(c[348620]|0)+n|0]=r;q=p}}while(0);if((a[(c[348620]|0)+n|0]|0)==2){return}if((a[1394464]|0)==0){s=1106168+((e>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){n=d[1044485]|0;c[276541]=7080+(n<<5);k=0;do{m=k<<1&2;o=k&2;p=k&4;r=0;do{b[1125528+(k<<9)+(r<<1)>>1]=d[(r>>>1&28|o)+(7080+(n<<5))|0]<<6|d[(r<<2&28|m)+(7080+(n<<5))|0]<<11|d[(r>>>3&24|p)+(7080+(n<<5))|0];r=r+1|0;}while(r>>>0<256);k=k+1|0;}while(k>>>0<8);a[1106089]=0}s=1125528+((e>>>10&7)<<9)|0}c[277226]=s;c[277225]=(a[1108928]|0)!=0?1393712:s;if((e&49152|0)==0){if((j|0)<=0){return}s=h&255;k=s-1&255;n=k<<24>>24==0;r=q+((d[1394504]|0)+(i<<1))|0;p=j;m=f;while(1){switch(g|0){case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+m|0]|0)){o=a[r]|0;t=o&255;if(o<<24>>24==0){break}do{if((a[1108928]|0)==0){o=b[(c[277225]|0)+(t<<1)>>1]|0;if((a[(c[277215]|0)+m|0]&32)!=0){u=b[(c[277221]|0)+((o&65535|67616)-(b[(c[277213]|0)+(m<<1)>>1]&63454)>>1<<1)>>1]|0;break}v=c[277228]&65535;w=o&-2048;x=v&-2048;y=(w&65535)>(x&65535)?w-x&65535:0;x=o&2016;w=v&2016;if((x&65535)>(w&65535)){z=(x-w&65535)+y&65535}else{z=y}y=o&31;o=v&31;if((y&65535)<=(o&65535)){u=z;break}u=(y-o&65535)+z&65535}else{o=b[(c[277225]|0)+(t<<1)>>1]|0;if((a[(c[277215]|0)+m|0]&32)==0){A=c[277228]&65535}else{A=b[(c[277213]|0)+(m<<1)>>1]|0}y=o&-2048;v=A&-2048;w=(y&65535)>(v&65535)?y-v&65535:0;v=o&2016;y=A&2016;if((v&65535)>(y&65535)){B=(v-y&65535)+w&65535}else{B=w}w=o&31;o=A&31;if((w&65535)<=(o&65535)){u=B;break}u=(w-o&65535)+B&65535}}while(0);b[(c[277218]|0)+(m<<1)>>1]=u;do{if((a[1108928]|0)==0){o=b[(c[277213]|0)+(m+2<<1)>>1]|0;if((a[(c[277215]|0)+m|0]&32)!=0){C=b[(c[277221]|0)+((o&65535|67616)-(b[(c[277226]|0)+(t<<1)>>1]&63454)>>1<<1)>>1]|0;break}w=c[277228]&65535;y=o&-2048;v=w&-2048;x=(y&65535)>(v&65535)?y-v&65535:0;v=o&2016;y=w&2016;if((v&65535)>(y&65535)){D=(v-y&65535)+x&65535}else{D=x}x=o&31;o=w&31;if((x&65535)<=(o&65535)){C=D;break}C=(x-o&65535)+D&65535}else{C=0}}while(0);t=m+1|0;b[(c[277218]|0)+(t<<1)>>1]=C;o=a[1108909]|0;a[(c[277219]|0)+t|0]=o;a[(c[277219]|0)+m|0]=o}}while(0);if(!n){E=k;F=6776}break};case 1:{E=s;F=6776;break};case 2:{G=s;F=6801;break};case 3:{H=s;F=6826;break};case 5:{I=s;F=6876;break};case 4:{J=s;F=6851;break};case 7:{F=6926;break};case 6:{K=s;F=6901;break};default:{}}if((F|0)==6776){F=0;o=m+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){t=a[r+1|0]|0;x=t&255;if(t<<24>>24==0){break}do{if((a[1108928]|0)==0){t=b[(c[277225]|0)+(x<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){L=b[(c[277221]|0)+((t&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}w=c[277228]&65535;y=t&-2048;v=w&-2048;M=(y&65535)>(v&65535)?y-v&65535:0;v=t&2016;y=w&2016;if((v&65535)>(y&65535)){N=(v-y&65535)+M&65535}else{N=M}M=t&31;t=w&31;if((M&65535)<=(t&65535)){L=N;break}L=(M-t&65535)+N&65535}else{t=b[(c[277225]|0)+(x<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){O=c[277228]&65535}else{O=b[(c[277213]|0)+(o<<1)>>1]|0}M=t&-2048;w=O&-2048;y=(M&65535)>(w&65535)?M-w&65535:0;w=t&2016;M=O&2016;if((w&65535)>(M&65535)){P=(w-M&65535)+y&65535}else{P=y}y=t&31;t=O&31;if((y&65535)<=(t&65535)){L=P;break}L=(y-t&65535)+P&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=L;do{if((a[1108928]|0)==0){t=b[(c[277213]|0)+(m+4<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){Q=b[(c[277221]|0)+((t&65535|67616)-(b[(c[277226]|0)+(x<<1)>>1]&63454)>>1<<1)>>1]|0;break}y=c[277228]&65535;M=t&-2048;w=y&-2048;v=(M&65535)>(w&65535)?M-w&65535:0;w=t&2016;M=y&2016;if((w&65535)>(M&65535)){R=(w-M&65535)+v&65535}else{R=v}v=t&31;t=y&31;if((v&65535)<=(t&65535)){Q=R;break}Q=(v-t&65535)+R&65535}else{Q=0}}while(0);x=m+3|0;b[(c[277218]|0)+(x<<1)>>1]=Q;t=a[1108909]|0;a[(c[277219]|0)+x|0]=t;a[(c[277219]|0)+o|0]=t}}while(0);o=E-1&255;if(o<<24>>24!=0){G=o;F=6801}}if((F|0)==6801){F=0;o=m+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){t=a[r+2|0]|0;x=t&255;if(t<<24>>24==0){break}do{if((a[1108928]|0)==0){t=b[(c[277225]|0)+(x<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){S=b[(c[277221]|0)+((t&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}v=c[277228]&65535;y=t&-2048;M=v&-2048;w=(y&65535)>(M&65535)?y-M&65535:0;M=t&2016;y=v&2016;if((M&65535)>(y&65535)){T=(M-y&65535)+w&65535}else{T=w}w=t&31;t=v&31;if((w&65535)<=(t&65535)){S=T;break}S=(w-t&65535)+T&65535}else{t=b[(c[277225]|0)+(x<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){U=c[277228]&65535}else{U=b[(c[277213]|0)+(o<<1)>>1]|0}w=t&-2048;v=U&-2048;y=(w&65535)>(v&65535)?w-v&65535:0;v=t&2016;w=U&2016;if((v&65535)>(w&65535)){V=(v-w&65535)+y&65535}else{V=y}y=t&31;t=U&31;if((y&65535)<=(t&65535)){S=V;break}S=(y-t&65535)+V&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=S;do{if((a[1108928]|0)==0){t=b[(c[277213]|0)+(m+6<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){W=b[(c[277221]|0)+((t&65535|67616)-(b[(c[277226]|0)+(x<<1)>>1]&63454)>>1<<1)>>1]|0;break}y=c[277228]&65535;w=t&-2048;v=y&-2048;M=(w&65535)>(v&65535)?w-v&65535:0;v=t&2016;w=y&2016;if((v&65535)>(w&65535)){X=(v-w&65535)+M&65535}else{X=M}M=t&31;t=y&31;if((M&65535)<=(t&65535)){W=X;break}W=(M-t&65535)+X&65535}else{W=0}}while(0);x=m+5|0;b[(c[277218]|0)+(x<<1)>>1]=W;t=a[1108909]|0;a[(c[277219]|0)+x|0]=t;a[(c[277219]|0)+o|0]=t}}while(0);o=G-1&255;if(o<<24>>24!=0){H=o;F=6826}}if((F|0)==6826){F=0;o=m+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){t=a[r+3|0]|0;x=t&255;if(t<<24>>24==0){break}do{if((a[1108928]|0)==0){t=b[(c[277225]|0)+(x<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){Y=b[(c[277221]|0)+((t&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}M=c[277228]&65535;y=t&-2048;w=M&-2048;v=(y&65535)>(w&65535)?y-w&65535:0;w=t&2016;y=M&2016;if((w&65535)>(y&65535)){Z=(w-y&65535)+v&65535}else{Z=v}v=t&31;t=M&31;if((v&65535)<=(t&65535)){Y=Z;break}Y=(v-t&65535)+Z&65535}else{t=b[(c[277225]|0)+(x<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){_=c[277228]&65535}else{_=b[(c[277213]|0)+(o<<1)>>1]|0}v=t&-2048;M=_&-2048;y=(v&65535)>(M&65535)?v-M&65535:0;M=t&2016;v=_&2016;if((M&65535)>(v&65535)){$=(M-v&65535)+y&65535}else{$=y}y=t&31;t=_&31;if((y&65535)<=(t&65535)){Y=$;break}Y=(y-t&65535)+$&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=Y;do{if((a[1108928]|0)==0){t=b[(c[277213]|0)+(m+8<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){aa=b[(c[277221]|0)+((t&65535|67616)-(b[(c[277226]|0)+(x<<1)>>1]&63454)>>1<<1)>>1]|0;break}y=c[277228]&65535;v=t&-2048;M=y&-2048;w=(v&65535)>(M&65535)?v-M&65535:0;M=t&2016;v=y&2016;if((M&65535)>(v&65535)){ab=(M-v&65535)+w&65535}else{ab=w}w=t&31;t=y&31;if((w&65535)<=(t&65535)){aa=ab;break}aa=(w-t&65535)+ab&65535}else{aa=0}}while(0);x=m+7|0;b[(c[277218]|0)+(x<<1)>>1]=aa;t=a[1108909]|0;a[(c[277219]|0)+x|0]=t;a[(c[277219]|0)+o|0]=t}}while(0);o=H-1&255;if(o<<24>>24!=0){J=o;F=6851}}if((F|0)==6851){F=0;o=m+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){t=a[r+4|0]|0;x=t&255;if(t<<24>>24==0){break}do{if((a[1108928]|0)==0){t=b[(c[277225]|0)+(x<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){ac=b[(c[277221]|0)+((t&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}w=c[277228]&65535;y=t&-2048;v=w&-2048;M=(y&65535)>(v&65535)?y-v&65535:0;v=t&2016;y=w&2016;if((v&65535)>(y&65535)){ad=(v-y&65535)+M&65535}else{ad=M}M=t&31;t=w&31;if((M&65535)<=(t&65535)){ac=ad;break}ac=(M-t&65535)+ad&65535}else{t=b[(c[277225]|0)+(x<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){ae=c[277228]&65535}else{ae=b[(c[277213]|0)+(o<<1)>>1]|0}M=t&-2048;w=ae&-2048;y=(M&65535)>(w&65535)?M-w&65535:0;w=t&2016;M=ae&2016;if((w&65535)>(M&65535)){af=(w-M&65535)+y&65535}else{af=y}y=t&31;t=ae&31;if((y&65535)<=(t&65535)){ac=af;break}ac=(y-t&65535)+af&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=ac;do{if((a[1108928]|0)==0){t=b[(c[277213]|0)+(m+10<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){ag=b[(c[277221]|0)+((t&65535|67616)-(b[(c[277226]|0)+(x<<1)>>1]&63454)>>1<<1)>>1]|0;break}y=c[277228]&65535;M=t&-2048;w=y&-2048;v=(M&65535)>(w&65535)?M-w&65535:0;w=t&2016;M=y&2016;if((w&65535)>(M&65535)){ah=(w-M&65535)+v&65535}else{ah=v}v=t&31;t=y&31;if((v&65535)<=(t&65535)){ag=ah;break}ag=(v-t&65535)+ah&65535}else{ag=0}}while(0);x=m+9|0;b[(c[277218]|0)+(x<<1)>>1]=ag;t=a[1108909]|0;a[(c[277219]|0)+x|0]=t;a[(c[277219]|0)+o|0]=t}}while(0);o=J-1&255;if(o<<24>>24!=0){I=o;F=6876}}if((F|0)==6876){F=0;o=m+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){t=a[r+5|0]|0;x=t&255;if(t<<24>>24==0){break}do{if((a[1108928]|0)==0){t=b[(c[277225]|0)+(x<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){ai=b[(c[277221]|0)+((t&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}v=c[277228]&65535;y=t&-2048;M=v&-2048;w=(y&65535)>(M&65535)?y-M&65535:0;M=t&2016;y=v&2016;if((M&65535)>(y&65535)){aj=(M-y&65535)+w&65535}else{aj=w}w=t&31;t=v&31;if((w&65535)<=(t&65535)){ai=aj;break}ai=(w-t&65535)+aj&65535}else{t=b[(c[277225]|0)+(x<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){ak=c[277228]&65535}else{ak=b[(c[277213]|0)+(o<<1)>>1]|0}w=t&-2048;v=ak&-2048;y=(w&65535)>(v&65535)?w-v&65535:0;v=t&2016;w=ak&2016;if((v&65535)>(w&65535)){al=(v-w&65535)+y&65535}else{al=y}y=t&31;t=ak&31;if((y&65535)<=(t&65535)){ai=al;break}ai=(y-t&65535)+al&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=ai;do{if((a[1108928]|0)==0){t=b[(c[277213]|0)+(m+12<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){am=b[(c[277221]|0)+((t&65535|67616)-(b[(c[277226]|0)+(x<<1)>>1]&63454)>>1<<1)>>1]|0;break}y=c[277228]&65535;w=t&-2048;v=y&-2048;M=(w&65535)>(v&65535)?w-v&65535:0;v=t&2016;w=y&2016;if((v&65535)>(w&65535)){an=(v-w&65535)+M&65535}else{an=M}M=t&31;t=y&31;if((M&65535)<=(t&65535)){am=an;break}am=(M-t&65535)+an&65535}else{am=0}}while(0);x=m+11|0;b[(c[277218]|0)+(x<<1)>>1]=am;t=a[1108909]|0;a[(c[277219]|0)+x|0]=t;a[(c[277219]|0)+o|0]=t}}while(0);o=I-1&255;if(o<<24>>24!=0){K=o;F=6901}}if((F|0)==6901){F=0;o=m+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){t=a[r+6|0]|0;x=t&255;if(t<<24>>24==0){break}do{if((a[1108928]|0)==0){t=b[(c[277225]|0)+(x<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){ao=b[(c[277221]|0)+((t&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}M=c[277228]&65535;y=t&-2048;w=M&-2048;v=(y&65535)>(w&65535)?y-w&65535:0;w=t&2016;y=M&2016;if((w&65535)>(y&65535)){ap=(w-y&65535)+v&65535}else{ap=v}v=t&31;t=M&31;if((v&65535)<=(t&65535)){ao=ap;break}ao=(v-t&65535)+ap&65535}else{t=b[(c[277225]|0)+(x<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){aq=c[277228]&65535}else{aq=b[(c[277213]|0)+(o<<1)>>1]|0}v=t&-2048;M=aq&-2048;y=(v&65535)>(M&65535)?v-M&65535:0;M=t&2016;v=aq&2016;if((M&65535)>(v&65535)){ar=(M-v&65535)+y&65535}else{ar=y}y=t&31;t=aq&31;if((y&65535)<=(t&65535)){ao=ar;break}ao=(y-t&65535)+ar&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=ao;do{if((a[1108928]|0)==0){t=b[(c[277213]|0)+(m+14<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){as=b[(c[277221]|0)+((t&65535|67616)-(b[(c[277226]|0)+(x<<1)>>1]&63454)>>1<<1)>>1]|0;break}y=c[277228]&65535;v=t&-2048;M=y&-2048;w=(v&65535)>(M&65535)?v-M&65535:0;M=t&2016;v=y&2016;if((M&65535)>(v&65535)){at=(M-v&65535)+w&65535}else{at=w}w=t&31;t=y&31;if((w&65535)<=(t&65535)){as=at;break}as=(w-t&65535)+at&65535}else{as=0}}while(0);x=m+13|0;b[(c[277218]|0)+(x<<1)>>1]=as;t=a[1108909]|0;a[(c[277219]|0)+x|0]=t;a[(c[277219]|0)+o|0]=t}}while(0);if(K<<24>>24!=1){F=6926}}do{if((F|0)==6926){F=0;o=m+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+o|0]|0)){break}t=a[r+7|0]|0;x=t&255;if(t<<24>>24==0){break}do{if((a[1108928]|0)==0){t=b[(c[277225]|0)+(x<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){au=b[(c[277221]|0)+((t&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}w=c[277228]&65535;y=t&-2048;v=w&-2048;M=(y&65535)>(v&65535)?y-v&65535:0;v=t&2016;y=w&2016;if((v&65535)>(y&65535)){av=(v-y&65535)+M&65535}else{av=M}M=t&31;t=w&31;if((M&65535)<=(t&65535)){au=av;break}au=(M-t&65535)+av&65535}else{t=b[(c[277225]|0)+(x<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){aw=c[277228]&65535}else{aw=b[(c[277213]|0)+(o<<1)>>1]|0}M=t&-2048;w=aw&-2048;y=(M&65535)>(w&65535)?M-w&65535:0;w=t&2016;M=aw&2016;if((w&65535)>(M&65535)){ax=(w-M&65535)+y&65535}else{ax=y}y=t&31;t=aw&31;if((y&65535)<=(t&65535)){au=ax;break}au=(y-t&65535)+ax&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=au;do{if((a[1108928]|0)==0){t=b[(c[277213]|0)+(m+16<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){ay=b[(c[277221]|0)+((t&65535|67616)-(b[(c[277226]|0)+(x<<1)>>1]&63454)>>1<<1)>>1]|0;break}y=c[277228]&65535;M=t&-2048;w=y&-2048;v=(M&65535)>(w&65535)?M-w&65535:0;w=t&2016;M=y&2016;if((w&65535)>(M&65535)){az=(w-M&65535)+v&65535}else{az=v}v=t&31;t=y&31;if((v&65535)<=(t&65535)){ay=az;break}ay=(v-t&65535)+az&65535}else{ay=0}}while(0);x=m+15|0;b[(c[277218]|0)+(x<<1)>>1]=ay;t=a[1108909]|0;a[(c[277219]|0)+x|0]=t;a[(c[277219]|0)+o|0]=t}}while(0);t=p-1|0;if((t|0)>0){r=r+16|0;p=t;m=(c[277223]|0)+m|0}else{break}}return}m=(d[1394504]|0)+(i<<1)|0;if((e&32768|0)==0){if((j|0)<=0){return}e=h&255;i=e-1&255;p=i<<24>>24==0;r=q+m|0;ay=j;az=f;while(1){switch(g|0){case 5:{aA=e;F=7080;break};case 7:{F=7130;break};case 2:{aB=e;F=7005;break};case 1:{aC=e;F=6980;break};case 6:{aD=e;F=7105;break};case 4:{aE=e;F=7055;break};case 3:{aF=e;F=7030;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+az|0]|0)){au=a[r+7|0]|0;ax=au&255;if(au<<24>>24==0){break}do{if((a[1108928]|0)==0){au=b[(c[277225]|0)+(ax<<1)>>1]|0;if((a[(c[277215]|0)+az|0]&32)!=0){aG=b[(c[277221]|0)+((au&65535|67616)-(b[(c[277213]|0)+(az<<1)>>1]&63454)>>1<<1)>>1]|0;break}aw=c[277228]&65535;av=au&-2048;K=aw&-2048;as=(av&65535)>(K&65535)?av-K&65535:0;K=au&2016;av=aw&2016;if((K&65535)>(av&65535)){aH=(K-av&65535)+as&65535}else{aH=as}as=au&31;au=aw&31;if((as&65535)<=(au&65535)){aG=aH;break}aG=(as-au&65535)+aH&65535}else{au=b[(c[277225]|0)+(ax<<1)>>1]|0;if((a[(c[277215]|0)+az|0]&32)==0){aI=c[277228]&65535}else{aI=b[(c[277213]|0)+(az<<1)>>1]|0}as=au&-2048;aw=aI&-2048;av=(as&65535)>(aw&65535)?as-aw&65535:0;aw=au&2016;as=aI&2016;if((aw&65535)>(as&65535)){aJ=(aw-as&65535)+av&65535}else{aJ=av}av=au&31;au=aI&31;if((av&65535)<=(au&65535)){aG=aJ;break}aG=(av-au&65535)+aJ&65535}}while(0);b[(c[277218]|0)+(az<<1)>>1]=aG;do{if((a[1108928]|0)==0){o=b[(c[277213]|0)+(az+2<<1)>>1]|0;if((a[(c[277215]|0)+az|0]&32)!=0){aK=b[(c[277221]|0)+((o&65535|67616)-(b[(c[277226]|0)+(ax<<1)>>1]&63454)>>1<<1)>>1]|0;break}au=c[277228]&65535;av=o&-2048;as=au&-2048;aw=(av&65535)>(as&65535)?av-as&65535:0;as=o&2016;av=au&2016;if((as&65535)>(av&65535)){aL=(as-av&65535)+aw&65535}else{aL=aw}aw=o&31;o=au&31;if((aw&65535)<=(o&65535)){aK=aL;break}aK=(aw-o&65535)+aL&65535}else{aK=0}}while(0);ax=az+1|0;b[(c[277218]|0)+(ax<<1)>>1]=aK;o=a[1108909]|0;a[(c[277219]|0)+ax|0]=o;a[(c[277219]|0)+az|0]=o}}while(0);if(!p){aC=i;F=6980}break};default:{}}if((F|0)==6980){F=0;o=az+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){ax=a[r+6|0]|0;aw=ax&255;if(ax<<24>>24==0){break}do{if((a[1108928]|0)==0){ax=b[(c[277225]|0)+(aw<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){aM=b[(c[277221]|0)+((ax&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}au=c[277228]&65535;av=ax&-2048;as=au&-2048;K=(av&65535)>(as&65535)?av-as&65535:0;as=ax&2016;av=au&2016;if((as&65535)>(av&65535)){aN=(as-av&65535)+K&65535}else{aN=K}K=ax&31;ax=au&31;if((K&65535)<=(ax&65535)){aM=aN;break}aM=(K-ax&65535)+aN&65535}else{ax=b[(c[277225]|0)+(aw<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){aO=c[277228]&65535}else{aO=b[(c[277213]|0)+(o<<1)>>1]|0}K=ax&-2048;au=aO&-2048;av=(K&65535)>(au&65535)?K-au&65535:0;au=ax&2016;K=aO&2016;if((au&65535)>(K&65535)){aP=(au-K&65535)+av&65535}else{aP=av}av=ax&31;ax=aO&31;if((av&65535)<=(ax&65535)){aM=aP;break}aM=(av-ax&65535)+aP&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=aM;do{if((a[1108928]|0)==0){ax=b[(c[277213]|0)+(az+4<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){aQ=b[(c[277221]|0)+((ax&65535|67616)-(b[(c[277226]|0)+(aw<<1)>>1]&63454)>>1<<1)>>1]|0;break}av=c[277228]&65535;K=ax&-2048;au=av&-2048;as=(K&65535)>(au&65535)?K-au&65535:0;au=ax&2016;K=av&2016;if((au&65535)>(K&65535)){aR=(au-K&65535)+as&65535}else{aR=as}as=ax&31;ax=av&31;if((as&65535)<=(ax&65535)){aQ=aR;break}aQ=(as-ax&65535)+aR&65535}else{aQ=0}}while(0);aw=az+3|0;b[(c[277218]|0)+(aw<<1)>>1]=aQ;ax=a[1108909]|0;a[(c[277219]|0)+aw|0]=ax;a[(c[277219]|0)+o|0]=ax}}while(0);o=aC-1&255;if(o<<24>>24!=0){aB=o;F=7005}}if((F|0)==7005){F=0;o=az+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){ax=a[r+5|0]|0;aw=ax&255;if(ax<<24>>24==0){break}do{if((a[1108928]|0)==0){ax=b[(c[277225]|0)+(aw<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){aS=b[(c[277221]|0)+((ax&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}as=c[277228]&65535;av=ax&-2048;K=as&-2048;au=(av&65535)>(K&65535)?av-K&65535:0;K=ax&2016;av=as&2016;if((K&65535)>(av&65535)){aT=(K-av&65535)+au&65535}else{aT=au}au=ax&31;ax=as&31;if((au&65535)<=(ax&65535)){aS=aT;break}aS=(au-ax&65535)+aT&65535}else{ax=b[(c[277225]|0)+(aw<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){aU=c[277228]&65535}else{aU=b[(c[277213]|0)+(o<<1)>>1]|0}au=ax&-2048;as=aU&-2048;av=(au&65535)>(as&65535)?au-as&65535:0;as=ax&2016;au=aU&2016;if((as&65535)>(au&65535)){aV=(as-au&65535)+av&65535}else{aV=av}av=ax&31;ax=aU&31;if((av&65535)<=(ax&65535)){aS=aV;break}aS=(av-ax&65535)+aV&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=aS;do{if((a[1108928]|0)==0){ax=b[(c[277213]|0)+(az+6<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){aW=b[(c[277221]|0)+((ax&65535|67616)-(b[(c[277226]|0)+(aw<<1)>>1]&63454)>>1<<1)>>1]|0;break}av=c[277228]&65535;au=ax&-2048;as=av&-2048;K=(au&65535)>(as&65535)?au-as&65535:0;as=ax&2016;au=av&2016;if((as&65535)>(au&65535)){aX=(as-au&65535)+K&65535}else{aX=K}K=ax&31;ax=av&31;if((K&65535)<=(ax&65535)){aW=aX;break}aW=(K-ax&65535)+aX&65535}else{aW=0}}while(0);aw=az+5|0;b[(c[277218]|0)+(aw<<1)>>1]=aW;ax=a[1108909]|0;a[(c[277219]|0)+aw|0]=ax;a[(c[277219]|0)+o|0]=ax}}while(0);o=aB-1&255;if(o<<24>>24!=0){aF=o;F=7030}}if((F|0)==7030){F=0;o=az+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){ax=a[r+4|0]|0;aw=ax&255;if(ax<<24>>24==0){break}do{if((a[1108928]|0)==0){ax=b[(c[277225]|0)+(aw<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){aY=b[(c[277221]|0)+((ax&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}K=c[277228]&65535;av=ax&-2048;au=K&-2048;as=(av&65535)>(au&65535)?av-au&65535:0;au=ax&2016;av=K&2016;if((au&65535)>(av&65535)){aZ=(au-av&65535)+as&65535}else{aZ=as}as=ax&31;ax=K&31;if((as&65535)<=(ax&65535)){aY=aZ;break}aY=(as-ax&65535)+aZ&65535}else{ax=b[(c[277225]|0)+(aw<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){a_=c[277228]&65535}else{a_=b[(c[277213]|0)+(o<<1)>>1]|0}as=ax&-2048;K=a_&-2048;av=(as&65535)>(K&65535)?as-K&65535:0;K=ax&2016;as=a_&2016;if((K&65535)>(as&65535)){a$=(K-as&65535)+av&65535}else{a$=av}av=ax&31;ax=a_&31;if((av&65535)<=(ax&65535)){aY=a$;break}aY=(av-ax&65535)+a$&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=aY;do{if((a[1108928]|0)==0){ax=b[(c[277213]|0)+(az+8<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){a0=b[(c[277221]|0)+((ax&65535|67616)-(b[(c[277226]|0)+(aw<<1)>>1]&63454)>>1<<1)>>1]|0;break}av=c[277228]&65535;as=ax&-2048;K=av&-2048;au=(as&65535)>(K&65535)?as-K&65535:0;K=ax&2016;as=av&2016;if((K&65535)>(as&65535)){a1=(K-as&65535)+au&65535}else{a1=au}au=ax&31;ax=av&31;if((au&65535)<=(ax&65535)){a0=a1;break}a0=(au-ax&65535)+a1&65535}else{a0=0}}while(0);aw=az+7|0;b[(c[277218]|0)+(aw<<1)>>1]=a0;ax=a[1108909]|0;a[(c[277219]|0)+aw|0]=ax;a[(c[277219]|0)+o|0]=ax}}while(0);o=aF-1&255;if(o<<24>>24!=0){aE=o;F=7055}}if((F|0)==7055){F=0;o=az+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){ax=a[r+3|0]|0;aw=ax&255;if(ax<<24>>24==0){break}do{if((a[1108928]|0)==0){ax=b[(c[277225]|0)+(aw<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){a2=b[(c[277221]|0)+((ax&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}au=c[277228]&65535;av=ax&-2048;as=au&-2048;K=(av&65535)>(as&65535)?av-as&65535:0;as=ax&2016;av=au&2016;if((as&65535)>(av&65535)){a3=(as-av&65535)+K&65535}else{a3=K}K=ax&31;ax=au&31;if((K&65535)<=(ax&65535)){a2=a3;break}a2=(K-ax&65535)+a3&65535}else{ax=b[(c[277225]|0)+(aw<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){a4=c[277228]&65535}else{a4=b[(c[277213]|0)+(o<<1)>>1]|0}K=ax&-2048;au=a4&-2048;av=(K&65535)>(au&65535)?K-au&65535:0;au=ax&2016;K=a4&2016;if((au&65535)>(K&65535)){a5=(au-K&65535)+av&65535}else{a5=av}av=ax&31;ax=a4&31;if((av&65535)<=(ax&65535)){a2=a5;break}a2=(av-ax&65535)+a5&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=a2;do{if((a[1108928]|0)==0){ax=b[(c[277213]|0)+(az+10<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){a6=b[(c[277221]|0)+((ax&65535|67616)-(b[(c[277226]|0)+(aw<<1)>>1]&63454)>>1<<1)>>1]|0;break}av=c[277228]&65535;K=ax&-2048;au=av&-2048;as=(K&65535)>(au&65535)?K-au&65535:0;au=ax&2016;K=av&2016;if((au&65535)>(K&65535)){a7=(au-K&65535)+as&65535}else{a7=as}as=ax&31;ax=av&31;if((as&65535)<=(ax&65535)){a6=a7;break}a6=(as-ax&65535)+a7&65535}else{a6=0}}while(0);aw=az+9|0;b[(c[277218]|0)+(aw<<1)>>1]=a6;ax=a[1108909]|0;a[(c[277219]|0)+aw|0]=ax;a[(c[277219]|0)+o|0]=ax}}while(0);o=aE-1&255;if(o<<24>>24!=0){aA=o;F=7080}}if((F|0)==7080){F=0;o=az+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){ax=a[r+2|0]|0;aw=ax&255;if(ax<<24>>24==0){break}do{if((a[1108928]|0)==0){ax=b[(c[277225]|0)+(aw<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){a8=b[(c[277221]|0)+((ax&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}as=c[277228]&65535;av=ax&-2048;K=as&-2048;au=(av&65535)>(K&65535)?av-K&65535:0;K=ax&2016;av=as&2016;if((K&65535)>(av&65535)){a9=(K-av&65535)+au&65535}else{a9=au}au=ax&31;ax=as&31;if((au&65535)<=(ax&65535)){a8=a9;break}a8=(au-ax&65535)+a9&65535}else{ax=b[(c[277225]|0)+(aw<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){ba=c[277228]&65535}else{ba=b[(c[277213]|0)+(o<<1)>>1]|0}au=ax&-2048;as=ba&-2048;av=(au&65535)>(as&65535)?au-as&65535:0;as=ax&2016;au=ba&2016;if((as&65535)>(au&65535)){bb=(as-au&65535)+av&65535}else{bb=av}av=ax&31;ax=ba&31;if((av&65535)<=(ax&65535)){a8=bb;break}a8=(av-ax&65535)+bb&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=a8;do{if((a[1108928]|0)==0){ax=b[(c[277213]|0)+(az+12<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){bc=b[(c[277221]|0)+((ax&65535|67616)-(b[(c[277226]|0)+(aw<<1)>>1]&63454)>>1<<1)>>1]|0;break}av=c[277228]&65535;au=ax&-2048;as=av&-2048;K=(au&65535)>(as&65535)?au-as&65535:0;as=ax&2016;au=av&2016;if((as&65535)>(au&65535)){bd=(as-au&65535)+K&65535}else{bd=K}K=ax&31;ax=av&31;if((K&65535)<=(ax&65535)){bc=bd;break}bc=(K-ax&65535)+bd&65535}else{bc=0}}while(0);aw=az+11|0;b[(c[277218]|0)+(aw<<1)>>1]=bc;ax=a[1108909]|0;a[(c[277219]|0)+aw|0]=ax;a[(c[277219]|0)+o|0]=ax}}while(0);o=aA-1&255;if(o<<24>>24!=0){aD=o;F=7105}}if((F|0)==7105){F=0;o=az+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){ax=a[r+1|0]|0;aw=ax&255;if(ax<<24>>24==0){break}do{if((a[1108928]|0)==0){ax=b[(c[277225]|0)+(aw<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){be=b[(c[277221]|0)+((ax&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}K=c[277228]&65535;av=ax&-2048;au=K&-2048;as=(av&65535)>(au&65535)?av-au&65535:0;au=ax&2016;av=K&2016;if((au&65535)>(av&65535)){bf=(au-av&65535)+as&65535}else{bf=as}as=ax&31;ax=K&31;if((as&65535)<=(ax&65535)){be=bf;break}be=(as-ax&65535)+bf&65535}else{ax=b[(c[277225]|0)+(aw<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){bg=c[277228]&65535}else{bg=b[(c[277213]|0)+(o<<1)>>1]|0}as=ax&-2048;K=bg&-2048;av=(as&65535)>(K&65535)?as-K&65535:0;K=ax&2016;as=bg&2016;if((K&65535)>(as&65535)){bh=(K-as&65535)+av&65535}else{bh=av}av=ax&31;ax=bg&31;if((av&65535)<=(ax&65535)){be=bh;break}be=(av-ax&65535)+bh&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=be;do{if((a[1108928]|0)==0){ax=b[(c[277213]|0)+(az+14<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){bi=b[(c[277221]|0)+((ax&65535|67616)-(b[(c[277226]|0)+(aw<<1)>>1]&63454)>>1<<1)>>1]|0;break}av=c[277228]&65535;as=ax&-2048;K=av&-2048;au=(as&65535)>(K&65535)?as-K&65535:0;K=ax&2016;as=av&2016;if((K&65535)>(as&65535)){bj=(K-as&65535)+au&65535}else{bj=au}au=ax&31;ax=av&31;if((au&65535)<=(ax&65535)){bi=bj;break}bi=(au-ax&65535)+bj&65535}else{bi=0}}while(0);aw=az+13|0;b[(c[277218]|0)+(aw<<1)>>1]=bi;ax=a[1108909]|0;a[(c[277219]|0)+aw|0]=ax;a[(c[277219]|0)+o|0]=ax}}while(0);if(aD<<24>>24!=1){F=7130}}do{if((F|0)==7130){F=0;o=az+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+o|0]|0)){break}ax=a[r]|0;aw=ax&255;if(ax<<24>>24==0){break}do{if((a[1108928]|0)==0){ax=b[(c[277225]|0)+(aw<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){bk=b[(c[277221]|0)+((ax&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}au=c[277228]&65535;av=ax&-2048;as=au&-2048;K=(av&65535)>(as&65535)?av-as&65535:0;as=ax&2016;av=au&2016;if((as&65535)>(av&65535)){bl=(as-av&65535)+K&65535}else{bl=K}K=ax&31;ax=au&31;if((K&65535)<=(ax&65535)){bk=bl;break}bk=(K-ax&65535)+bl&65535}else{ax=b[(c[277225]|0)+(aw<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){bm=c[277228]&65535}else{bm=b[(c[277213]|0)+(o<<1)>>1]|0}K=ax&-2048;au=bm&-2048;av=(K&65535)>(au&65535)?K-au&65535:0;au=ax&2016;K=bm&2016;if((au&65535)>(K&65535)){bn=(au-K&65535)+av&65535}else{bn=av}av=ax&31;ax=bm&31;if((av&65535)<=(ax&65535)){bk=bn;break}bk=(av-ax&65535)+bn&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=bk;do{if((a[1108928]|0)==0){ax=b[(c[277213]|0)+(az+16<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){bo=b[(c[277221]|0)+((ax&65535|67616)-(b[(c[277226]|0)+(aw<<1)>>1]&63454)>>1<<1)>>1]|0;break}av=c[277228]&65535;K=ax&-2048;au=av&-2048;as=(K&65535)>(au&65535)?K-au&65535:0;au=ax&2016;K=av&2016;if((au&65535)>(K&65535)){bp=(au-K&65535)+as&65535}else{bp=as}as=ax&31;ax=av&31;if((as&65535)<=(ax&65535)){bo=bp;break}bo=(as-ax&65535)+bp&65535}else{bo=0}}while(0);aw=az+15|0;b[(c[277218]|0)+(aw<<1)>>1]=bo;ax=a[1108909]|0;a[(c[277219]|0)+aw|0]=ax;a[(c[277219]|0)+o|0]=ax}}while(0);ax=ay-1|0;if((ax|0)>0){r=r+16|0;ay=ax;az=(c[277223]|0)+az|0}else{break}}return}az=q+(56-m)|0;m=(j|0)>0;if(l){if(!m){return}l=h&255;q=l-1&255;ay=q<<24>>24==0;r=az;bo=j;bp=f;while(1){switch(g|0){case 5:{bq=l;F=7487;break};case 2:{br=l;F=7412;break};case 6:{bs=l;F=7512;break};case 7:{F=7537;break};case 3:{bt=l;F=7437;break};case 4:{bu=l;F=7462;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+bp|0]|0)){bk=a[r+7|0]|0;bn=bk&255;if(bk<<24>>24==0){break}do{if((a[1108928]|0)==0){bk=b[(c[277225]|0)+(bn<<1)>>1]|0;if((a[(c[277215]|0)+bp|0]&32)!=0){bv=b[(c[277221]|0)+((bk&65535|67616)-(b[(c[277213]|0)+(bp<<1)>>1]&63454)>>1<<1)>>1]|0;break}bm=c[277228]&65535;bl=bk&-2048;aD=bm&-2048;bi=(bl&65535)>(aD&65535)?bl-aD&65535:0;aD=bk&2016;bl=bm&2016;if((aD&65535)>(bl&65535)){bw=(aD-bl&65535)+bi&65535}else{bw=bi}bi=bk&31;bk=bm&31;if((bi&65535)<=(bk&65535)){bv=bw;break}bv=(bi-bk&65535)+bw&65535}else{bk=b[(c[277225]|0)+(bn<<1)>>1]|0;if((a[(c[277215]|0)+bp|0]&32)==0){bx=c[277228]&65535}else{bx=b[(c[277213]|0)+(bp<<1)>>1]|0}bi=bk&-2048;bm=bx&-2048;bl=(bi&65535)>(bm&65535)?bi-bm&65535:0;bm=bk&2016;bi=bx&2016;if((bm&65535)>(bi&65535)){by=(bm-bi&65535)+bl&65535}else{by=bl}bl=bk&31;bk=bx&31;if((bl&65535)<=(bk&65535)){bv=by;break}bv=(bl-bk&65535)+by&65535}}while(0);b[(c[277218]|0)+(bp<<1)>>1]=bv;do{if((a[1108928]|0)==0){o=b[(c[277213]|0)+(bp+2<<1)>>1]|0;if((a[(c[277215]|0)+bp|0]&32)!=0){bz=b[(c[277221]|0)+((o&65535|67616)-(b[(c[277226]|0)+(bn<<1)>>1]&63454)>>1<<1)>>1]|0;break}bk=c[277228]&65535;bl=o&-2048;bi=bk&-2048;bm=(bl&65535)>(bi&65535)?bl-bi&65535:0;bi=o&2016;bl=bk&2016;if((bi&65535)>(bl&65535)){bA=(bi-bl&65535)+bm&65535}else{bA=bm}bm=o&31;o=bk&31;if((bm&65535)<=(o&65535)){bz=bA;break}bz=(bm-o&65535)+bA&65535}else{bz=0}}while(0);bn=bp+1|0;b[(c[277218]|0)+(bn<<1)>>1]=bz;o=a[1108909]|0;a[(c[277219]|0)+bn|0]=o;a[(c[277219]|0)+bp|0]=o}}while(0);if(!ay){bB=q;F=7387}break};case 1:{bB=l;F=7387;break};default:{}}if((F|0)==7387){F=0;o=bp+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){bn=a[r+6|0]|0;bm=bn&255;if(bn<<24>>24==0){break}do{if((a[1108928]|0)==0){bn=b[(c[277225]|0)+(bm<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){bC=b[(c[277221]|0)+((bn&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}bk=c[277228]&65535;bl=bn&-2048;bi=bk&-2048;aD=(bl&65535)>(bi&65535)?bl-bi&65535:0;bi=bn&2016;bl=bk&2016;if((bi&65535)>(bl&65535)){bD=(bi-bl&65535)+aD&65535}else{bD=aD}aD=bn&31;bn=bk&31;if((aD&65535)<=(bn&65535)){bC=bD;break}bC=(aD-bn&65535)+bD&65535}else{bn=b[(c[277225]|0)+(bm<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){bE=c[277228]&65535}else{bE=b[(c[277213]|0)+(o<<1)>>1]|0}aD=bn&-2048;bk=bE&-2048;bl=(aD&65535)>(bk&65535)?aD-bk&65535:0;bk=bn&2016;aD=bE&2016;if((bk&65535)>(aD&65535)){bF=(bk-aD&65535)+bl&65535}else{bF=bl}bl=bn&31;bn=bE&31;if((bl&65535)<=(bn&65535)){bC=bF;break}bC=(bl-bn&65535)+bF&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=bC;do{if((a[1108928]|0)==0){bn=b[(c[277213]|0)+(bp+4<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){bG=b[(c[277221]|0)+((bn&65535|67616)-(b[(c[277226]|0)+(bm<<1)>>1]&63454)>>1<<1)>>1]|0;break}bl=c[277228]&65535;aD=bn&-2048;bk=bl&-2048;bi=(aD&65535)>(bk&65535)?aD-bk&65535:0;bk=bn&2016;aD=bl&2016;if((bk&65535)>(aD&65535)){bH=(bk-aD&65535)+bi&65535}else{bH=bi}bi=bn&31;bn=bl&31;if((bi&65535)<=(bn&65535)){bG=bH;break}bG=(bi-bn&65535)+bH&65535}else{bG=0}}while(0);bm=bp+3|0;b[(c[277218]|0)+(bm<<1)>>1]=bG;bn=a[1108909]|0;a[(c[277219]|0)+bm|0]=bn;a[(c[277219]|0)+o|0]=bn}}while(0);o=bB-1&255;if(o<<24>>24!=0){br=o;F=7412}}if((F|0)==7412){F=0;o=bp+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){bn=a[r+5|0]|0;bm=bn&255;if(bn<<24>>24==0){break}do{if((a[1108928]|0)==0){bn=b[(c[277225]|0)+(bm<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){bI=b[(c[277221]|0)+((bn&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}bi=c[277228]&65535;bl=bn&-2048;aD=bi&-2048;bk=(bl&65535)>(aD&65535)?bl-aD&65535:0;aD=bn&2016;bl=bi&2016;if((aD&65535)>(bl&65535)){bJ=(aD-bl&65535)+bk&65535}else{bJ=bk}bk=bn&31;bn=bi&31;if((bk&65535)<=(bn&65535)){bI=bJ;break}bI=(bk-bn&65535)+bJ&65535}else{bn=b[(c[277225]|0)+(bm<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){bK=c[277228]&65535}else{bK=b[(c[277213]|0)+(o<<1)>>1]|0}bk=bn&-2048;bi=bK&-2048;bl=(bk&65535)>(bi&65535)?bk-bi&65535:0;bi=bn&2016;bk=bK&2016;if((bi&65535)>(bk&65535)){bL=(bi-bk&65535)+bl&65535}else{bL=bl}bl=bn&31;bn=bK&31;if((bl&65535)<=(bn&65535)){bI=bL;break}bI=(bl-bn&65535)+bL&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=bI;do{if((a[1108928]|0)==0){bn=b[(c[277213]|0)+(bp+6<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){bM=b[(c[277221]|0)+((bn&65535|67616)-(b[(c[277226]|0)+(bm<<1)>>1]&63454)>>1<<1)>>1]|0;break}bl=c[277228]&65535;bk=bn&-2048;bi=bl&-2048;aD=(bk&65535)>(bi&65535)?bk-bi&65535:0;bi=bn&2016;bk=bl&2016;if((bi&65535)>(bk&65535)){bN=(bi-bk&65535)+aD&65535}else{bN=aD}aD=bn&31;bn=bl&31;if((aD&65535)<=(bn&65535)){bM=bN;break}bM=(aD-bn&65535)+bN&65535}else{bM=0}}while(0);bm=bp+5|0;b[(c[277218]|0)+(bm<<1)>>1]=bM;bn=a[1108909]|0;a[(c[277219]|0)+bm|0]=bn;a[(c[277219]|0)+o|0]=bn}}while(0);o=br-1&255;if(o<<24>>24!=0){bt=o;F=7437}}if((F|0)==7437){F=0;o=bp+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){bn=a[r+4|0]|0;bm=bn&255;if(bn<<24>>24==0){break}do{if((a[1108928]|0)==0){bn=b[(c[277225]|0)+(bm<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){bO=b[(c[277221]|0)+((bn&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}aD=c[277228]&65535;bl=bn&-2048;bk=aD&-2048;bi=(bl&65535)>(bk&65535)?bl-bk&65535:0;bk=bn&2016;bl=aD&2016;if((bk&65535)>(bl&65535)){bP=(bk-bl&65535)+bi&65535}else{bP=bi}bi=bn&31;bn=aD&31;if((bi&65535)<=(bn&65535)){bO=bP;break}bO=(bi-bn&65535)+bP&65535}else{bn=b[(c[277225]|0)+(bm<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){bQ=c[277228]&65535}else{bQ=b[(c[277213]|0)+(o<<1)>>1]|0}bi=bn&-2048;aD=bQ&-2048;bl=(bi&65535)>(aD&65535)?bi-aD&65535:0;aD=bn&2016;bi=bQ&2016;if((aD&65535)>(bi&65535)){bR=(aD-bi&65535)+bl&65535}else{bR=bl}bl=bn&31;bn=bQ&31;if((bl&65535)<=(bn&65535)){bO=bR;break}bO=(bl-bn&65535)+bR&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=bO;do{if((a[1108928]|0)==0){bn=b[(c[277213]|0)+(bp+8<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){bS=b[(c[277221]|0)+((bn&65535|67616)-(b[(c[277226]|0)+(bm<<1)>>1]&63454)>>1<<1)>>1]|0;break}bl=c[277228]&65535;bi=bn&-2048;aD=bl&-2048;bk=(bi&65535)>(aD&65535)?bi-aD&65535:0;aD=bn&2016;bi=bl&2016;if((aD&65535)>(bi&65535)){bT=(aD-bi&65535)+bk&65535}else{bT=bk}bk=bn&31;bn=bl&31;if((bk&65535)<=(bn&65535)){bS=bT;break}bS=(bk-bn&65535)+bT&65535}else{bS=0}}while(0);bm=bp+7|0;b[(c[277218]|0)+(bm<<1)>>1]=bS;bn=a[1108909]|0;a[(c[277219]|0)+bm|0]=bn;a[(c[277219]|0)+o|0]=bn}}while(0);o=bt-1&255;if(o<<24>>24!=0){bu=o;F=7462}}if((F|0)==7462){F=0;o=bp+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){bn=a[r+3|0]|0;bm=bn&255;if(bn<<24>>24==0){break}do{if((a[1108928]|0)==0){bn=b[(c[277225]|0)+(bm<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){bU=b[(c[277221]|0)+((bn&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}bk=c[277228]&65535;bl=bn&-2048;bi=bk&-2048;aD=(bl&65535)>(bi&65535)?bl-bi&65535:0;bi=bn&2016;bl=bk&2016;if((bi&65535)>(bl&65535)){bV=(bi-bl&65535)+aD&65535}else{bV=aD}aD=bn&31;bn=bk&31;if((aD&65535)<=(bn&65535)){bU=bV;break}bU=(aD-bn&65535)+bV&65535}else{bn=b[(c[277225]|0)+(bm<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){bW=c[277228]&65535}else{bW=b[(c[277213]|0)+(o<<1)>>1]|0}aD=bn&-2048;bk=bW&-2048;bl=(aD&65535)>(bk&65535)?aD-bk&65535:0;bk=bn&2016;aD=bW&2016;if((bk&65535)>(aD&65535)){bX=(bk-aD&65535)+bl&65535}else{bX=bl}bl=bn&31;bn=bW&31;if((bl&65535)<=(bn&65535)){bU=bX;break}bU=(bl-bn&65535)+bX&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=bU;do{if((a[1108928]|0)==0){bn=b[(c[277213]|0)+(bp+10<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){bY=b[(c[277221]|0)+((bn&65535|67616)-(b[(c[277226]|0)+(bm<<1)>>1]&63454)>>1<<1)>>1]|0;break}bl=c[277228]&65535;aD=bn&-2048;bk=bl&-2048;bi=(aD&65535)>(bk&65535)?aD-bk&65535:0;bk=bn&2016;aD=bl&2016;if((bk&65535)>(aD&65535)){bZ=(bk-aD&65535)+bi&65535}else{bZ=bi}bi=bn&31;bn=bl&31;if((bi&65535)<=(bn&65535)){bY=bZ;break}bY=(bi-bn&65535)+bZ&65535}else{bY=0}}while(0);bm=bp+9|0;b[(c[277218]|0)+(bm<<1)>>1]=bY;bn=a[1108909]|0;a[(c[277219]|0)+bm|0]=bn;a[(c[277219]|0)+o|0]=bn}}while(0);o=bu-1&255;if(o<<24>>24!=0){bq=o;F=7487}}if((F|0)==7487){F=0;o=bp+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){bn=a[r+2|0]|0;bm=bn&255;if(bn<<24>>24==0){break}do{if((a[1108928]|0)==0){bn=b[(c[277225]|0)+(bm<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){b_=b[(c[277221]|0)+((bn&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}bi=c[277228]&65535;bl=bn&-2048;aD=bi&-2048;bk=(bl&65535)>(aD&65535)?bl-aD&65535:0;aD=bn&2016;bl=bi&2016;if((aD&65535)>(bl&65535)){b$=(aD-bl&65535)+bk&65535}else{b$=bk}bk=bn&31;bn=bi&31;if((bk&65535)<=(bn&65535)){b_=b$;break}b_=(bk-bn&65535)+b$&65535}else{bn=b[(c[277225]|0)+(bm<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){b0=c[277228]&65535}else{b0=b[(c[277213]|0)+(o<<1)>>1]|0}bk=bn&-2048;bi=b0&-2048;bl=(bk&65535)>(bi&65535)?bk-bi&65535:0;bi=bn&2016;bk=b0&2016;if((bi&65535)>(bk&65535)){b1=(bi-bk&65535)+bl&65535}else{b1=bl}bl=bn&31;bn=b0&31;if((bl&65535)<=(bn&65535)){b_=b1;break}b_=(bl-bn&65535)+b1&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=b_;do{if((a[1108928]|0)==0){bn=b[(c[277213]|0)+(bp+12<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){b2=b[(c[277221]|0)+((bn&65535|67616)-(b[(c[277226]|0)+(bm<<1)>>1]&63454)>>1<<1)>>1]|0;break}bl=c[277228]&65535;bk=bn&-2048;bi=bl&-2048;aD=(bk&65535)>(bi&65535)?bk-bi&65535:0;bi=bn&2016;bk=bl&2016;if((bi&65535)>(bk&65535)){b3=(bi-bk&65535)+aD&65535}else{b3=aD}aD=bn&31;bn=bl&31;if((aD&65535)<=(bn&65535)){b2=b3;break}b2=(aD-bn&65535)+b3&65535}else{b2=0}}while(0);bm=bp+11|0;b[(c[277218]|0)+(bm<<1)>>1]=b2;bn=a[1108909]|0;a[(c[277219]|0)+bm|0]=bn;a[(c[277219]|0)+o|0]=bn}}while(0);o=bq-1&255;if(o<<24>>24!=0){bs=o;F=7512}}if((F|0)==7512){F=0;o=bp+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){bn=a[r+1|0]|0;bm=bn&255;if(bn<<24>>24==0){break}do{if((a[1108928]|0)==0){bn=b[(c[277225]|0)+(bm<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){b4=b[(c[277221]|0)+((bn&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}aD=c[277228]&65535;bl=bn&-2048;bk=aD&-2048;bi=(bl&65535)>(bk&65535)?bl-bk&65535:0;bk=bn&2016;bl=aD&2016;if((bk&65535)>(bl&65535)){b5=(bk-bl&65535)+bi&65535}else{b5=bi}bi=bn&31;bn=aD&31;if((bi&65535)<=(bn&65535)){b4=b5;break}b4=(bi-bn&65535)+b5&65535}else{bn=b[(c[277225]|0)+(bm<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){b6=c[277228]&65535}else{b6=b[(c[277213]|0)+(o<<1)>>1]|0}bi=bn&-2048;aD=b6&-2048;bl=(bi&65535)>(aD&65535)?bi-aD&65535:0;aD=bn&2016;bi=b6&2016;if((aD&65535)>(bi&65535)){b7=(aD-bi&65535)+bl&65535}else{b7=bl}bl=bn&31;bn=b6&31;if((bl&65535)<=(bn&65535)){b4=b7;break}b4=(bl-bn&65535)+b7&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=b4;do{if((a[1108928]|0)==0){bn=b[(c[277213]|0)+(bp+14<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){b8=b[(c[277221]|0)+((bn&65535|67616)-(b[(c[277226]|0)+(bm<<1)>>1]&63454)>>1<<1)>>1]|0;break}bl=c[277228]&65535;bi=bn&-2048;aD=bl&-2048;bk=(bi&65535)>(aD&65535)?bi-aD&65535:0;aD=bn&2016;bi=bl&2016;if((aD&65535)>(bi&65535)){b9=(aD-bi&65535)+bk&65535}else{b9=bk}bk=bn&31;bn=bl&31;if((bk&65535)<=(bn&65535)){b8=b9;break}b8=(bk-bn&65535)+b9&65535}else{b8=0}}while(0);bm=bp+13|0;b[(c[277218]|0)+(bm<<1)>>1]=b8;bn=a[1108909]|0;a[(c[277219]|0)+bm|0]=bn;a[(c[277219]|0)+o|0]=bn}}while(0);if(bs<<24>>24!=1){F=7537}}do{if((F|0)==7537){F=0;o=bp+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+o|0]|0)){break}bn=a[r]|0;bm=bn&255;if(bn<<24>>24==0){break}do{if((a[1108928]|0)==0){bn=b[(c[277225]|0)+(bm<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){ca=b[(c[277221]|0)+((bn&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}bk=c[277228]&65535;bl=bn&-2048;bi=bk&-2048;aD=(bl&65535)>(bi&65535)?bl-bi&65535:0;bi=bn&2016;bl=bk&2016;if((bi&65535)>(bl&65535)){cb=(bi-bl&65535)+aD&65535}else{cb=aD}aD=bn&31;bn=bk&31;if((aD&65535)<=(bn&65535)){ca=cb;break}ca=(aD-bn&65535)+cb&65535}else{bn=b[(c[277225]|0)+(bm<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){cc=c[277228]&65535}else{cc=b[(c[277213]|0)+(o<<1)>>1]|0}aD=bn&-2048;bk=cc&-2048;bl=(aD&65535)>(bk&65535)?aD-bk&65535:0;bk=bn&2016;aD=cc&2016;if((bk&65535)>(aD&65535)){cd=(bk-aD&65535)+bl&65535}else{cd=bl}bl=bn&31;bn=cc&31;if((bl&65535)<=(bn&65535)){ca=cd;break}ca=(bl-bn&65535)+cd&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=ca;do{if((a[1108928]|0)==0){bn=b[(c[277213]|0)+(bp+16<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){ce=b[(c[277221]|0)+((bn&65535|67616)-(b[(c[277226]|0)+(bm<<1)>>1]&63454)>>1<<1)>>1]|0;break}bl=c[277228]&65535;aD=bn&-2048;bk=bl&-2048;bi=(aD&65535)>(bk&65535)?aD-bk&65535:0;bk=bn&2016;aD=bl&2016;if((bk&65535)>(aD&65535)){cf=(bk-aD&65535)+bi&65535}else{cf=bi}bi=bn&31;bn=bl&31;if((bi&65535)<=(bn&65535)){ce=cf;break}ce=(bi-bn&65535)+cf&65535}else{ce=0}}while(0);bm=bp+15|0;b[(c[277218]|0)+(bm<<1)>>1]=ce;bn=a[1108909]|0;a[(c[277219]|0)+bm|0]=bn;a[(c[277219]|0)+o|0]=bn}}while(0);bn=bo-1|0;if((bn|0)>0){r=r-16|0;bo=bn;bp=(c[277223]|0)+bp|0}else{break}}return}else{if(!m){return}m=h&255;h=m-1&255;bp=h<<24>>24==0;bo=az;az=j;j=f;while(1){switch(g|0){case 2:{cg=m;F=7211;break};case 7:{F=7336;break};case 3:{ch=m;F=7236;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+j|0]|0)){f=a[bo]|0;r=f&255;if(f<<24>>24==0){break}do{if((a[1108928]|0)==0){f=b[(c[277225]|0)+(r<<1)>>1]|0;if((a[(c[277215]|0)+j|0]&32)!=0){ci=b[(c[277221]|0)+((f&65535|67616)-(b[(c[277213]|0)+(j<<1)>>1]&63454)>>1<<1)>>1]|0;break}ce=c[277228]&65535;cf=f&-2048;ca=ce&-2048;cd=(cf&65535)>(ca&65535)?cf-ca&65535:0;ca=f&2016;cf=ce&2016;if((ca&65535)>(cf&65535)){cj=(ca-cf&65535)+cd&65535}else{cj=cd}cd=f&31;f=ce&31;if((cd&65535)<=(f&65535)){ci=cj;break}ci=(cd-f&65535)+cj&65535}else{f=b[(c[277225]|0)+(r<<1)>>1]|0;if((a[(c[277215]|0)+j|0]&32)==0){ck=c[277228]&65535}else{ck=b[(c[277213]|0)+(j<<1)>>1]|0}cd=f&-2048;ce=ck&-2048;cf=(cd&65535)>(ce&65535)?cd-ce&65535:0;ce=f&2016;cd=ck&2016;if((ce&65535)>(cd&65535)){cl=(ce-cd&65535)+cf&65535}else{cl=cf}cf=f&31;f=ck&31;if((cf&65535)<=(f&65535)){ci=cl;break}ci=(cf-f&65535)+cl&65535}}while(0);b[(c[277218]|0)+(j<<1)>>1]=ci;do{if((a[1108928]|0)==0){o=b[(c[277213]|0)+(j+2<<1)>>1]|0;if((a[(c[277215]|0)+j|0]&32)!=0){cm=b[(c[277221]|0)+((o&65535|67616)-(b[(c[277226]|0)+(r<<1)>>1]&63454)>>1<<1)>>1]|0;break}f=c[277228]&65535;cf=o&-2048;cd=f&-2048;ce=(cf&65535)>(cd&65535)?cf-cd&65535:0;cd=o&2016;cf=f&2016;if((cd&65535)>(cf&65535)){cn=(cd-cf&65535)+ce&65535}else{cn=ce}ce=o&31;o=f&31;if((ce&65535)<=(o&65535)){cm=cn;break}cm=(ce-o&65535)+cn&65535}else{cm=0}}while(0);r=j+1|0;b[(c[277218]|0)+(r<<1)>>1]=cm;o=a[1108909]|0;a[(c[277219]|0)+r|0]=o;a[(c[277219]|0)+j|0]=o}}while(0);if(!bp){co=h;F=7186}break};case 1:{co=m;F=7186;break};case 6:{cp=m;F=7311;break};case 5:{cq=m;F=7286;break};case 4:{cr=m;F=7261;break};default:{}}if((F|0)==7186){F=0;o=j+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){r=a[bo+1|0]|0;ce=r&255;if(r<<24>>24==0){break}do{if((a[1108928]|0)==0){r=b[(c[277225]|0)+(ce<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){cs=b[(c[277221]|0)+((r&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}f=c[277228]&65535;cf=r&-2048;cd=f&-2048;ca=(cf&65535)>(cd&65535)?cf-cd&65535:0;cd=r&2016;cf=f&2016;if((cd&65535)>(cf&65535)){ct=(cd-cf&65535)+ca&65535}else{ct=ca}ca=r&31;r=f&31;if((ca&65535)<=(r&65535)){cs=ct;break}cs=(ca-r&65535)+ct&65535}else{r=b[(c[277225]|0)+(ce<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){cu=c[277228]&65535}else{cu=b[(c[277213]|0)+(o<<1)>>1]|0}ca=r&-2048;f=cu&-2048;cf=(ca&65535)>(f&65535)?ca-f&65535:0;f=r&2016;ca=cu&2016;if((f&65535)>(ca&65535)){cv=(f-ca&65535)+cf&65535}else{cv=cf}cf=r&31;r=cu&31;if((cf&65535)<=(r&65535)){cs=cv;break}cs=(cf-r&65535)+cv&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=cs;do{if((a[1108928]|0)==0){r=b[(c[277213]|0)+(j+4<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){cw=b[(c[277221]|0)+((r&65535|67616)-(b[(c[277226]|0)+(ce<<1)>>1]&63454)>>1<<1)>>1]|0;break}cf=c[277228]&65535;ca=r&-2048;f=cf&-2048;cd=(ca&65535)>(f&65535)?ca-f&65535:0;f=r&2016;ca=cf&2016;if((f&65535)>(ca&65535)){cx=(f-ca&65535)+cd&65535}else{cx=cd}cd=r&31;r=cf&31;if((cd&65535)<=(r&65535)){cw=cx;break}cw=(cd-r&65535)+cx&65535}else{cw=0}}while(0);ce=j+3|0;b[(c[277218]|0)+(ce<<1)>>1]=cw;r=a[1108909]|0;a[(c[277219]|0)+ce|0]=r;a[(c[277219]|0)+o|0]=r}}while(0);o=co-1&255;if(o<<24>>24!=0){cg=o;F=7211}}if((F|0)==7211){F=0;o=j+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){r=a[bo+2|0]|0;ce=r&255;if(r<<24>>24==0){break}do{if((a[1108928]|0)==0){r=b[(c[277225]|0)+(ce<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){cy=b[(c[277221]|0)+((r&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}cd=c[277228]&65535;cf=r&-2048;ca=cd&-2048;f=(cf&65535)>(ca&65535)?cf-ca&65535:0;ca=r&2016;cf=cd&2016;if((ca&65535)>(cf&65535)){cz=(ca-cf&65535)+f&65535}else{cz=f}f=r&31;r=cd&31;if((f&65535)<=(r&65535)){cy=cz;break}cy=(f-r&65535)+cz&65535}else{r=b[(c[277225]|0)+(ce<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){cA=c[277228]&65535}else{cA=b[(c[277213]|0)+(o<<1)>>1]|0}f=r&-2048;cd=cA&-2048;cf=(f&65535)>(cd&65535)?f-cd&65535:0;cd=r&2016;f=cA&2016;if((cd&65535)>(f&65535)){cB=(cd-f&65535)+cf&65535}else{cB=cf}cf=r&31;r=cA&31;if((cf&65535)<=(r&65535)){cy=cB;break}cy=(cf-r&65535)+cB&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=cy;do{if((a[1108928]|0)==0){r=b[(c[277213]|0)+(j+6<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){cC=b[(c[277221]|0)+((r&65535|67616)-(b[(c[277226]|0)+(ce<<1)>>1]&63454)>>1<<1)>>1]|0;break}cf=c[277228]&65535;f=r&-2048;cd=cf&-2048;ca=(f&65535)>(cd&65535)?f-cd&65535:0;cd=r&2016;f=cf&2016;if((cd&65535)>(f&65535)){cD=(cd-f&65535)+ca&65535}else{cD=ca}ca=r&31;r=cf&31;if((ca&65535)<=(r&65535)){cC=cD;break}cC=(ca-r&65535)+cD&65535}else{cC=0}}while(0);ce=j+5|0;b[(c[277218]|0)+(ce<<1)>>1]=cC;r=a[1108909]|0;a[(c[277219]|0)+ce|0]=r;a[(c[277219]|0)+o|0]=r}}while(0);o=cg-1&255;if(o<<24>>24!=0){ch=o;F=7236}}if((F|0)==7236){F=0;o=j+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){r=a[bo+3|0]|0;ce=r&255;if(r<<24>>24==0){break}do{if((a[1108928]|0)==0){r=b[(c[277225]|0)+(ce<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){cE=b[(c[277221]|0)+((r&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}ca=c[277228]&65535;cf=r&-2048;f=ca&-2048;cd=(cf&65535)>(f&65535)?cf-f&65535:0;f=r&2016;cf=ca&2016;if((f&65535)>(cf&65535)){cF=(f-cf&65535)+cd&65535}else{cF=cd}cd=r&31;r=ca&31;if((cd&65535)<=(r&65535)){cE=cF;break}cE=(cd-r&65535)+cF&65535}else{r=b[(c[277225]|0)+(ce<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){cG=c[277228]&65535}else{cG=b[(c[277213]|0)+(o<<1)>>1]|0}cd=r&-2048;ca=cG&-2048;cf=(cd&65535)>(ca&65535)?cd-ca&65535:0;ca=r&2016;cd=cG&2016;if((ca&65535)>(cd&65535)){cH=(ca-cd&65535)+cf&65535}else{cH=cf}cf=r&31;r=cG&31;if((cf&65535)<=(r&65535)){cE=cH;break}cE=(cf-r&65535)+cH&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=cE;do{if((a[1108928]|0)==0){r=b[(c[277213]|0)+(j+8<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){cI=b[(c[277221]|0)+((r&65535|67616)-(b[(c[277226]|0)+(ce<<1)>>1]&63454)>>1<<1)>>1]|0;break}cf=c[277228]&65535;cd=r&-2048;ca=cf&-2048;f=(cd&65535)>(ca&65535)?cd-ca&65535:0;ca=r&2016;cd=cf&2016;if((ca&65535)>(cd&65535)){cJ=(ca-cd&65535)+f&65535}else{cJ=f}f=r&31;r=cf&31;if((f&65535)<=(r&65535)){cI=cJ;break}cI=(f-r&65535)+cJ&65535}else{cI=0}}while(0);ce=j+7|0;b[(c[277218]|0)+(ce<<1)>>1]=cI;r=a[1108909]|0;a[(c[277219]|0)+ce|0]=r;a[(c[277219]|0)+o|0]=r}}while(0);o=ch-1&255;if(o<<24>>24!=0){cr=o;F=7261}}if((F|0)==7261){F=0;o=j+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){r=a[bo+4|0]|0;ce=r&255;if(r<<24>>24==0){break}do{if((a[1108928]|0)==0){r=b[(c[277225]|0)+(ce<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){cK=b[(c[277221]|0)+((r&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}f=c[277228]&65535;cf=r&-2048;cd=f&-2048;ca=(cf&65535)>(cd&65535)?cf-cd&65535:0;cd=r&2016;cf=f&2016;if((cd&65535)>(cf&65535)){cL=(cd-cf&65535)+ca&65535}else{cL=ca}ca=r&31;r=f&31;if((ca&65535)<=(r&65535)){cK=cL;break}cK=(ca-r&65535)+cL&65535}else{r=b[(c[277225]|0)+(ce<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){cM=c[277228]&65535}else{cM=b[(c[277213]|0)+(o<<1)>>1]|0}ca=r&-2048;f=cM&-2048;cf=(ca&65535)>(f&65535)?ca-f&65535:0;f=r&2016;ca=cM&2016;if((f&65535)>(ca&65535)){cN=(f-ca&65535)+cf&65535}else{cN=cf}cf=r&31;r=cM&31;if((cf&65535)<=(r&65535)){cK=cN;break}cK=(cf-r&65535)+cN&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=cK;do{if((a[1108928]|0)==0){r=b[(c[277213]|0)+(j+10<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){cO=b[(c[277221]|0)+((r&65535|67616)-(b[(c[277226]|0)+(ce<<1)>>1]&63454)>>1<<1)>>1]|0;break}cf=c[277228]&65535;ca=r&-2048;f=cf&-2048;cd=(ca&65535)>(f&65535)?ca-f&65535:0;f=r&2016;ca=cf&2016;if((f&65535)>(ca&65535)){cP=(f-ca&65535)+cd&65535}else{cP=cd}cd=r&31;r=cf&31;if((cd&65535)<=(r&65535)){cO=cP;break}cO=(cd-r&65535)+cP&65535}else{cO=0}}while(0);ce=j+9|0;b[(c[277218]|0)+(ce<<1)>>1]=cO;r=a[1108909]|0;a[(c[277219]|0)+ce|0]=r;a[(c[277219]|0)+o|0]=r}}while(0);o=cr-1&255;if(o<<24>>24!=0){cq=o;F=7286}}if((F|0)==7286){F=0;o=j+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){r=a[bo+5|0]|0;ce=r&255;if(r<<24>>24==0){break}do{if((a[1108928]|0)==0){r=b[(c[277225]|0)+(ce<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){cQ=b[(c[277221]|0)+((r&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}cd=c[277228]&65535;cf=r&-2048;ca=cd&-2048;f=(cf&65535)>(ca&65535)?cf-ca&65535:0;ca=r&2016;cf=cd&2016;if((ca&65535)>(cf&65535)){cR=(ca-cf&65535)+f&65535}else{cR=f}f=r&31;r=cd&31;if((f&65535)<=(r&65535)){cQ=cR;break}cQ=(f-r&65535)+cR&65535}else{r=b[(c[277225]|0)+(ce<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){cS=c[277228]&65535}else{cS=b[(c[277213]|0)+(o<<1)>>1]|0}f=r&-2048;cd=cS&-2048;cf=(f&65535)>(cd&65535)?f-cd&65535:0;cd=r&2016;f=cS&2016;if((cd&65535)>(f&65535)){cT=(cd-f&65535)+cf&65535}else{cT=cf}cf=r&31;r=cS&31;if((cf&65535)<=(r&65535)){cQ=cT;break}cQ=(cf-r&65535)+cT&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=cQ;do{if((a[1108928]|0)==0){r=b[(c[277213]|0)+(j+12<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){cU=b[(c[277221]|0)+((r&65535|67616)-(b[(c[277226]|0)+(ce<<1)>>1]&63454)>>1<<1)>>1]|0;break}cf=c[277228]&65535;f=r&-2048;cd=cf&-2048;ca=(f&65535)>(cd&65535)?f-cd&65535:0;cd=r&2016;f=cf&2016;if((cd&65535)>(f&65535)){cV=(cd-f&65535)+ca&65535}else{cV=ca}ca=r&31;r=cf&31;if((ca&65535)<=(r&65535)){cU=cV;break}cU=(ca-r&65535)+cV&65535}else{cU=0}}while(0);ce=j+11|0;b[(c[277218]|0)+(ce<<1)>>1]=cU;r=a[1108909]|0;a[(c[277219]|0)+ce|0]=r;a[(c[277219]|0)+o|0]=r}}while(0);o=cq-1&255;if(o<<24>>24!=0){cp=o;F=7311}}if((F|0)==7311){F=0;o=j+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){r=a[bo+6|0]|0;ce=r&255;if(r<<24>>24==0){break}do{if((a[1108928]|0)==0){r=b[(c[277225]|0)+(ce<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){cW=b[(c[277221]|0)+((r&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}ca=c[277228]&65535;cf=r&-2048;f=ca&-2048;cd=(cf&65535)>(f&65535)?cf-f&65535:0;f=r&2016;cf=ca&2016;if((f&65535)>(cf&65535)){cX=(f-cf&65535)+cd&65535}else{cX=cd}cd=r&31;r=ca&31;if((cd&65535)<=(r&65535)){cW=cX;break}cW=(cd-r&65535)+cX&65535}else{r=b[(c[277225]|0)+(ce<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){cY=c[277228]&65535}else{cY=b[(c[277213]|0)+(o<<1)>>1]|0}cd=r&-2048;ca=cY&-2048;cf=(cd&65535)>(ca&65535)?cd-ca&65535:0;ca=r&2016;cd=cY&2016;if((ca&65535)>(cd&65535)){cZ=(ca-cd&65535)+cf&65535}else{cZ=cf}cf=r&31;r=cY&31;if((cf&65535)<=(r&65535)){cW=cZ;break}cW=(cf-r&65535)+cZ&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=cW;do{if((a[1108928]|0)==0){r=b[(c[277213]|0)+(j+14<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){c_=b[(c[277221]|0)+((r&65535|67616)-(b[(c[277226]|0)+(ce<<1)>>1]&63454)>>1<<1)>>1]|0;break}cf=c[277228]&65535;cd=r&-2048;ca=cf&-2048;f=(cd&65535)>(ca&65535)?cd-ca&65535:0;ca=r&2016;cd=cf&2016;if((ca&65535)>(cd&65535)){c$=(ca-cd&65535)+f&65535}else{c$=f}f=r&31;r=cf&31;if((f&65535)<=(r&65535)){c_=c$;break}c_=(f-r&65535)+c$&65535}else{c_=0}}while(0);ce=j+13|0;b[(c[277218]|0)+(ce<<1)>>1]=c_;r=a[1108909]|0;a[(c[277219]|0)+ce|0]=r;a[(c[277219]|0)+o|0]=r}}while(0);if(cp<<24>>24!=1){F=7336}}do{if((F|0)==7336){F=0;o=j+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+o|0]|0)){break}r=a[bo+7|0]|0;ce=r&255;if(r<<24>>24==0){break}do{if((a[1108928]|0)==0){r=b[(c[277225]|0)+(ce<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){c0=b[(c[277221]|0)+((r&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}f=c[277228]&65535;cf=r&-2048;cd=f&-2048;ca=(cf&65535)>(cd&65535)?cf-cd&65535:0;cd=r&2016;cf=f&2016;if((cd&65535)>(cf&65535)){c1=(cd-cf&65535)+ca&65535}else{c1=ca}ca=r&31;r=f&31;if((ca&65535)<=(r&65535)){c0=c1;break}c0=(ca-r&65535)+c1&65535}else{r=b[(c[277225]|0)+(ce<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){c2=c[277228]&65535}else{c2=b[(c[277213]|0)+(o<<1)>>1]|0}ca=r&-2048;f=c2&-2048;cf=(ca&65535)>(f&65535)?ca-f&65535:0;f=r&2016;ca=c2&2016;if((f&65535)>(ca&65535)){c3=(f-ca&65535)+cf&65535}else{c3=cf}cf=r&31;r=c2&31;if((cf&65535)<=(r&65535)){c0=c3;break}c0=(cf-r&65535)+c3&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=c0;do{if((a[1108928]|0)==0){r=b[(c[277213]|0)+(j+16<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){c4=b[(c[277221]|0)+((r&65535|67616)-(b[(c[277226]|0)+(ce<<1)>>1]&63454)>>1<<1)>>1]|0;break}cf=c[277228]&65535;ca=r&-2048;f=cf&-2048;cd=(ca&65535)>(f&65535)?ca-f&65535:0;f=r&2016;ca=cf&2016;if((f&65535)>(ca&65535)){c5=(f-ca&65535)+cd&65535}else{c5=cd}cd=r&31;r=cf&31;if((cd&65535)<=(r&65535)){c4=c5;break}c4=(cd-r&65535)+c5&65535}else{c4=0}}while(0);ce=j+15|0;b[(c[277218]|0)+(ce<<1)>>1]=c4;r=a[1108909]|0;a[(c[277219]|0)+ce|0]=r;a[(c[277219]|0)+o|0]=r}}while(0);r=az-1|0;if((r|0)>0){bo=bo-16|0;az=r;j=(c[277223]|0)+j|0}else{break}}return}}function Wz(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0;i=e&1023;j=c[348606]|0;k=(i<<j)+(c[348604]|0)|0;if((e&256|0)==0){l=k}else{l=(c[348602]|0)+k|0}k=l&65535;l=k>>>(j>>>0);j=(e&16384|0)!=0;m=l<<6;do{if(j){n=(c[348622]|0)+m|0;if((a[(c[348618]|0)+l|0]|0)!=0){o=n;break}p=fi[c[348636]&63](n,k,i)|0;a[(c[348618]|0)+l|0]=p;o=n}else{n=(c[348624]|0)+m|0;if((a[(c[348620]|0)+l|0]|0)!=0){o=n;break}p=fi[c[348638]&63](n,k,i)|0;a[(c[348620]|0)+l|0]=p;o=n}}while(0);if((a[(c[348620]|0)+l|0]|0)==2){return}if((a[1394464]|0)==0){q=1106168+((e>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){l=d[1044485]|0;c[276541]=7080+(l<<5);i=0;do{k=i<<1&2;m=i&2;n=i&4;p=0;do{b[1125528+(i<<9)+(p<<1)>>1]=d[(p>>>1&28|m)+(7080+(l<<5))|0]<<6|d[(p<<2&28|k)+(7080+(l<<5))|0]<<11|d[(p>>>3&24|n)+(7080+(l<<5))|0];p=p+1|0;}while(p>>>0<256);i=i+1|0;}while(i>>>0<8);a[1106089]=0}q=1125528+((e>>>10&7)<<9)|0}c[277226]=q;c[277225]=(a[1108928]|0)!=0?1393712:q;if((e&49152|0)==0){if((h|0)<=0){return}q=o+((d[1394504]|0)+(g<<1))|0;i=h;l=f;while(1){p=a[1108908]|0;n=c[277219]|0;do{if((p&255)>(d[n+l|0]|0)){k=a[q]|0;if(k<<24>>24==0){r=p;s=n;break}b[(c[277218]|0)+(l<<1)>>1]=b[(c[277225]|0)+((k&255)<<1)>>1]|0;if((a[1108928]|0)==0){t=b[(c[277213]|0)+(l+2<<1)>>1]|0}else{t=0}k=l+1|0;b[(c[277218]|0)+(k<<1)>>1]=t;m=a[1108909]|0;a[(c[277219]|0)+k|0]=m;a[(c[277219]|0)+l|0]=m;r=a[1108908]|0;s=c[277219]|0}else{r=p;s=n}}while(0);n=l+2|0;do{if((r&255)>(d[s+n|0]|0)){p=a[q+1|0]|0;if(p<<24>>24==0){u=r;v=s;break}b[(c[277218]|0)+(n<<1)>>1]=b[(c[277225]|0)+((p&255)<<1)>>1]|0;if((a[1108928]|0)==0){w=b[(c[277213]|0)+(l+4<<1)>>1]|0}else{w=0}p=l+3|0;b[(c[277218]|0)+(p<<1)>>1]=w;m=a[1108909]|0;a[(c[277219]|0)+p|0]=m;a[(c[277219]|0)+n|0]=m;u=a[1108908]|0;v=c[277219]|0}else{u=r;v=s}}while(0);n=l+4|0;do{if((u&255)>(d[v+n|0]|0)){m=a[q+2|0]|0;if(m<<24>>24==0){x=u;y=v;break}b[(c[277218]|0)+(n<<1)>>1]=b[(c[277225]|0)+((m&255)<<1)>>1]|0;if((a[1108928]|0)==0){z=b[(c[277213]|0)+(l+6<<1)>>1]|0}else{z=0}m=l+5|0;b[(c[277218]|0)+(m<<1)>>1]=z;p=a[1108909]|0;a[(c[277219]|0)+m|0]=p;a[(c[277219]|0)+n|0]=p;x=a[1108908]|0;y=c[277219]|0}else{x=u;y=v}}while(0);n=l+6|0;do{if((x&255)>(d[y+n|0]|0)){p=a[q+3|0]|0;if(p<<24>>24==0){A=x;B=y;break}b[(c[277218]|0)+(n<<1)>>1]=b[(c[277225]|0)+((p&255)<<1)>>1]|0;if((a[1108928]|0)==0){C=b[(c[277213]|0)+(l+8<<1)>>1]|0}else{C=0}p=l+7|0;b[(c[277218]|0)+(p<<1)>>1]=C;m=a[1108909]|0;a[(c[277219]|0)+p|0]=m;a[(c[277219]|0)+n|0]=m;A=a[1108908]|0;B=c[277219]|0}else{A=x;B=y}}while(0);n=l+8|0;do{if((A&255)>(d[B+n|0]|0)){m=a[q+4|0]|0;if(m<<24>>24==0){D=A;E=B;break}b[(c[277218]|0)+(n<<1)>>1]=b[(c[277225]|0)+((m&255)<<1)>>1]|0;if((a[1108928]|0)==0){F=b[(c[277213]|0)+(l+10<<1)>>1]|0}else{F=0}m=l+9|0;b[(c[277218]|0)+(m<<1)>>1]=F;p=a[1108909]|0;a[(c[277219]|0)+m|0]=p;a[(c[277219]|0)+n|0]=p;D=a[1108908]|0;E=c[277219]|0}else{D=A;E=B}}while(0);n=l+10|0;do{if((D&255)>(d[E+n|0]|0)){p=a[q+5|0]|0;if(p<<24>>24==0){G=D;H=E;break}b[(c[277218]|0)+(n<<1)>>1]=b[(c[277225]|0)+((p&255)<<1)>>1]|0;if((a[1108928]|0)==0){I=b[(c[277213]|0)+(l+12<<1)>>1]|0}else{I=0}p=l+11|0;b[(c[277218]|0)+(p<<1)>>1]=I;m=a[1108909]|0;a[(c[277219]|0)+p|0]=m;a[(c[277219]|0)+n|0]=m;G=a[1108908]|0;H=c[277219]|0}else{G=D;H=E}}while(0);n=l+12|0;do{if((G&255)>(d[H+n|0]|0)){m=a[q+6|0]|0;if(m<<24>>24==0){J=G;K=H;break}b[(c[277218]|0)+(n<<1)>>1]=b[(c[277225]|0)+((m&255)<<1)>>1]|0;if((a[1108928]|0)==0){L=b[(c[277213]|0)+(l+14<<1)>>1]|0}else{L=0}m=l+13|0;b[(c[277218]|0)+(m<<1)>>1]=L;p=a[1108909]|0;a[(c[277219]|0)+m|0]=p;a[(c[277219]|0)+n|0]=p;J=a[1108908]|0;K=c[277219]|0}else{J=G;K=H}}while(0);n=l+14|0;do{if((J&255)>(d[K+n|0]|0)){p=a[q+7|0]|0;if(p<<24>>24==0){break}b[(c[277218]|0)+(n<<1)>>1]=b[(c[277225]|0)+((p&255)<<1)>>1]|0;if((a[1108928]|0)==0){M=b[(c[277213]|0)+(l+16<<1)>>1]|0}else{M=0}p=l+15|0;b[(c[277218]|0)+(p<<1)>>1]=M;m=a[1108909]|0;a[(c[277219]|0)+p|0]=m;a[(c[277219]|0)+n|0]=m}}while(0);n=i-1|0;if((n|0)<=0){break}q=q+16|0;i=n;l=(c[277223]|0)+l|0}return}l=(d[1394504]|0)+(g<<1)|0;if((e&32768|0)==0){if((h|0)<=0){return}e=o+l|0;g=h;i=f;while(1){q=a[1108908]|0;M=c[277219]|0;do{if((q&255)>(d[M+i|0]|0)){K=a[e+7|0]|0;if(K<<24>>24==0){N=q;O=M;break}b[(c[277218]|0)+(i<<1)>>1]=b[(c[277225]|0)+((K&255)<<1)>>1]|0;if((a[1108928]|0)==0){P=b[(c[277213]|0)+(i+2<<1)>>1]|0}else{P=0}K=i+1|0;b[(c[277218]|0)+(K<<1)>>1]=P;J=a[1108909]|0;a[(c[277219]|0)+K|0]=J;a[(c[277219]|0)+i|0]=J;N=a[1108908]|0;O=c[277219]|0}else{N=q;O=M}}while(0);M=i+2|0;do{if((N&255)>(d[O+M|0]|0)){q=a[e+6|0]|0;if(q<<24>>24==0){Q=N;R=O;break}b[(c[277218]|0)+(M<<1)>>1]=b[(c[277225]|0)+((q&255)<<1)>>1]|0;if((a[1108928]|0)==0){S=b[(c[277213]|0)+(i+4<<1)>>1]|0}else{S=0}q=i+3|0;b[(c[277218]|0)+(q<<1)>>1]=S;J=a[1108909]|0;a[(c[277219]|0)+q|0]=J;a[(c[277219]|0)+M|0]=J;Q=a[1108908]|0;R=c[277219]|0}else{Q=N;R=O}}while(0);M=i+4|0;do{if((Q&255)>(d[R+M|0]|0)){J=a[e+5|0]|0;if(J<<24>>24==0){T=Q;U=R;break}b[(c[277218]|0)+(M<<1)>>1]=b[(c[277225]|0)+((J&255)<<1)>>1]|0;if((a[1108928]|0)==0){V=b[(c[277213]|0)+(i+6<<1)>>1]|0}else{V=0}J=i+5|0;b[(c[277218]|0)+(J<<1)>>1]=V;q=a[1108909]|0;a[(c[277219]|0)+J|0]=q;a[(c[277219]|0)+M|0]=q;T=a[1108908]|0;U=c[277219]|0}else{T=Q;U=R}}while(0);M=i+6|0;do{if((T&255)>(d[U+M|0]|0)){q=a[e+4|0]|0;if(q<<24>>24==0){W=T;X=U;break}b[(c[277218]|0)+(M<<1)>>1]=b[(c[277225]|0)+((q&255)<<1)>>1]|0;if((a[1108928]|0)==0){Y=b[(c[277213]|0)+(i+8<<1)>>1]|0}else{Y=0}q=i+7|0;b[(c[277218]|0)+(q<<1)>>1]=Y;J=a[1108909]|0;a[(c[277219]|0)+q|0]=J;a[(c[277219]|0)+M|0]=J;W=a[1108908]|0;X=c[277219]|0}else{W=T;X=U}}while(0);M=i+8|0;do{if((W&255)>(d[X+M|0]|0)){J=a[e+3|0]|0;if(J<<24>>24==0){Z=W;_=X;break}b[(c[277218]|0)+(M<<1)>>1]=b[(c[277225]|0)+((J&255)<<1)>>1]|0;if((a[1108928]|0)==0){$=b[(c[277213]|0)+(i+10<<1)>>1]|0}else{$=0}J=i+9|0;b[(c[277218]|0)+(J<<1)>>1]=$;q=a[1108909]|0;a[(c[277219]|0)+J|0]=q;a[(c[277219]|0)+M|0]=q;Z=a[1108908]|0;_=c[277219]|0}else{Z=W;_=X}}while(0);M=i+10|0;do{if((Z&255)>(d[_+M|0]|0)){q=a[e+2|0]|0;if(q<<24>>24==0){aa=Z;ab=_;break}b[(c[277218]|0)+(M<<1)>>1]=b[(c[277225]|0)+((q&255)<<1)>>1]|0;if((a[1108928]|0)==0){ac=b[(c[277213]|0)+(i+12<<1)>>1]|0}else{ac=0}q=i+11|0;b[(c[277218]|0)+(q<<1)>>1]=ac;J=a[1108909]|0;a[(c[277219]|0)+q|0]=J;a[(c[277219]|0)+M|0]=J;aa=a[1108908]|0;ab=c[277219]|0}else{aa=Z;ab=_}}while(0);M=i+12|0;do{if((aa&255)>(d[ab+M|0]|0)){J=a[e+1|0]|0;if(J<<24>>24==0){ad=aa;ae=ab;break}b[(c[277218]|0)+(M<<1)>>1]=b[(c[277225]|0)+((J&255)<<1)>>1]|0;if((a[1108928]|0)==0){af=b[(c[277213]|0)+(i+14<<1)>>1]|0}else{af=0}J=i+13|0;b[(c[277218]|0)+(J<<1)>>1]=af;q=a[1108909]|0;a[(c[277219]|0)+J|0]=q;a[(c[277219]|0)+M|0]=q;ad=a[1108908]|0;ae=c[277219]|0}else{ad=aa;ae=ab}}while(0);M=i+14|0;do{if((ad&255)>(d[ae+M|0]|0)){q=a[e]|0;if(q<<24>>24==0){break}b[(c[277218]|0)+(M<<1)>>1]=b[(c[277225]|0)+((q&255)<<1)>>1]|0;if((a[1108928]|0)==0){ag=b[(c[277213]|0)+(i+16<<1)>>1]|0}else{ag=0}q=i+15|0;b[(c[277218]|0)+(q<<1)>>1]=ag;J=a[1108909]|0;a[(c[277219]|0)+q|0]=J;a[(c[277219]|0)+M|0]=J}}while(0);M=g-1|0;if((M|0)<=0){break}e=e+16|0;g=M;i=(c[277223]|0)+i|0}return}i=o+(56-l)|0;l=(h|0)>0;if(j){if(l){ah=i;ai=h;aj=f}else{return}while(1){j=a[1108908]|0;o=c[277219]|0;do{if((j&255)>(d[o+aj|0]|0)){g=a[ah+7|0]|0;if(g<<24>>24==0){ak=j;al=o;break}b[(c[277218]|0)+(aj<<1)>>1]=b[(c[277225]|0)+((g&255)<<1)>>1]|0;if((a[1108928]|0)==0){am=b[(c[277213]|0)+(aj+2<<1)>>1]|0}else{am=0}g=aj+1|0;b[(c[277218]|0)+(g<<1)>>1]=am;e=a[1108909]|0;a[(c[277219]|0)+g|0]=e;a[(c[277219]|0)+aj|0]=e;ak=a[1108908]|0;al=c[277219]|0}else{ak=j;al=o}}while(0);o=aj+2|0;do{if((ak&255)>(d[al+o|0]|0)){j=a[ah+6|0]|0;if(j<<24>>24==0){an=ak;ao=al;break}b[(c[277218]|0)+(o<<1)>>1]=b[(c[277225]|0)+((j&255)<<1)>>1]|0;if((a[1108928]|0)==0){ap=b[(c[277213]|0)+(aj+4<<1)>>1]|0}else{ap=0}j=aj+3|0;b[(c[277218]|0)+(j<<1)>>1]=ap;e=a[1108909]|0;a[(c[277219]|0)+j|0]=e;a[(c[277219]|0)+o|0]=e;an=a[1108908]|0;ao=c[277219]|0}else{an=ak;ao=al}}while(0);o=aj+4|0;do{if((an&255)>(d[ao+o|0]|0)){e=a[ah+5|0]|0;if(e<<24>>24==0){aq=an;ar=ao;break}b[(c[277218]|0)+(o<<1)>>1]=b[(c[277225]|0)+((e&255)<<1)>>1]|0;if((a[1108928]|0)==0){as=b[(c[277213]|0)+(aj+6<<1)>>1]|0}else{as=0}e=aj+5|0;b[(c[277218]|0)+(e<<1)>>1]=as;j=a[1108909]|0;a[(c[277219]|0)+e|0]=j;a[(c[277219]|0)+o|0]=j;aq=a[1108908]|0;ar=c[277219]|0}else{aq=an;ar=ao}}while(0);o=aj+6|0;do{if((aq&255)>(d[ar+o|0]|0)){j=a[ah+4|0]|0;if(j<<24>>24==0){at=aq;au=ar;break}b[(c[277218]|0)+(o<<1)>>1]=b[(c[277225]|0)+((j&255)<<1)>>1]|0;if((a[1108928]|0)==0){av=b[(c[277213]|0)+(aj+8<<1)>>1]|0}else{av=0}j=aj+7|0;b[(c[277218]|0)+(j<<1)>>1]=av;e=a[1108909]|0;a[(c[277219]|0)+j|0]=e;a[(c[277219]|0)+o|0]=e;at=a[1108908]|0;au=c[277219]|0}else{at=aq;au=ar}}while(0);o=aj+8|0;do{if((at&255)>(d[au+o|0]|0)){e=a[ah+3|0]|0;if(e<<24>>24==0){aw=at;ax=au;break}b[(c[277218]|0)+(o<<1)>>1]=b[(c[277225]|0)+((e&255)<<1)>>1]|0;if((a[1108928]|0)==0){ay=b[(c[277213]|0)+(aj+10<<1)>>1]|0}else{ay=0}e=aj+9|0;b[(c[277218]|0)+(e<<1)>>1]=ay;j=a[1108909]|0;a[(c[277219]|0)+e|0]=j;a[(c[277219]|0)+o|0]=j;aw=a[1108908]|0;ax=c[277219]|0}else{aw=at;ax=au}}while(0);o=aj+10|0;do{if((aw&255)>(d[ax+o|0]|0)){j=a[ah+2|0]|0;if(j<<24>>24==0){az=aw;aA=ax;break}b[(c[277218]|0)+(o<<1)>>1]=b[(c[277225]|0)+((j&255)<<1)>>1]|0;if((a[1108928]|0)==0){aB=b[(c[277213]|0)+(aj+12<<1)>>1]|0}else{aB=0}j=aj+11|0;b[(c[277218]|0)+(j<<1)>>1]=aB;e=a[1108909]|0;a[(c[277219]|0)+j|0]=e;a[(c[277219]|0)+o|0]=e;az=a[1108908]|0;aA=c[277219]|0}else{az=aw;aA=ax}}while(0);o=aj+12|0;do{if((az&255)>(d[aA+o|0]|0)){e=a[ah+1|0]|0;if(e<<24>>24==0){aC=az;aD=aA;break}b[(c[277218]|0)+(o<<1)>>1]=b[(c[277225]|0)+((e&255)<<1)>>1]|0;if((a[1108928]|0)==0){aE=b[(c[277213]|0)+(aj+14<<1)>>1]|0}else{aE=0}e=aj+13|0;b[(c[277218]|0)+(e<<1)>>1]=aE;j=a[1108909]|0;a[(c[277219]|0)+e|0]=j;a[(c[277219]|0)+o|0]=j;aC=a[1108908]|0;aD=c[277219]|0}else{aC=az;aD=aA}}while(0);o=aj+14|0;do{if((aC&255)>(d[aD+o|0]|0)){j=a[ah]|0;if(j<<24>>24==0){break}b[(c[277218]|0)+(o<<1)>>1]=b[(c[277225]|0)+((j&255)<<1)>>1]|0;if((a[1108928]|0)==0){aF=b[(c[277213]|0)+(aj+16<<1)>>1]|0}else{aF=0}j=aj+15|0;b[(c[277218]|0)+(j<<1)>>1]=aF;e=a[1108909]|0;a[(c[277219]|0)+j|0]=e;a[(c[277219]|0)+o|0]=e}}while(0);o=ai-1|0;if((o|0)<=0){break}ah=ah-16|0;ai=o;aj=(c[277223]|0)+aj|0}return}else{if(l){aG=i;aH=h;aI=f}else{return}while(1){f=a[1108908]|0;h=c[277219]|0;do{if((f&255)>(d[h+aI|0]|0)){i=a[aG]|0;if(i<<24>>24==0){aJ=f;aK=h;break}b[(c[277218]|0)+(aI<<1)>>1]=b[(c[277225]|0)+((i&255)<<1)>>1]|0;if((a[1108928]|0)==0){aL=b[(c[277213]|0)+(aI+2<<1)>>1]|0}else{aL=0}i=aI+1|0;b[(c[277218]|0)+(i<<1)>>1]=aL;l=a[1108909]|0;a[(c[277219]|0)+i|0]=l;a[(c[277219]|0)+aI|0]=l;aJ=a[1108908]|0;aK=c[277219]|0}else{aJ=f;aK=h}}while(0);h=aI+2|0;do{if((aJ&255)>(d[aK+h|0]|0)){f=a[aG+1|0]|0;if(f<<24>>24==0){aM=aJ;aN=aK;break}b[(c[277218]|0)+(h<<1)>>1]=b[(c[277225]|0)+((f&255)<<1)>>1]|0;if((a[1108928]|0)==0){aO=b[(c[277213]|0)+(aI+4<<1)>>1]|0}else{aO=0}f=aI+3|0;b[(c[277218]|0)+(f<<1)>>1]=aO;l=a[1108909]|0;a[(c[277219]|0)+f|0]=l;a[(c[277219]|0)+h|0]=l;aM=a[1108908]|0;aN=c[277219]|0}else{aM=aJ;aN=aK}}while(0);h=aI+4|0;do{if((aM&255)>(d[aN+h|0]|0)){l=a[aG+2|0]|0;if(l<<24>>24==0){aP=aM;aQ=aN;break}b[(c[277218]|0)+(h<<1)>>1]=b[(c[277225]|0)+((l&255)<<1)>>1]|0;if((a[1108928]|0)==0){aR=b[(c[277213]|0)+(aI+6<<1)>>1]|0}else{aR=0}l=aI+5|0;b[(c[277218]|0)+(l<<1)>>1]=aR;f=a[1108909]|0;a[(c[277219]|0)+l|0]=f;a[(c[277219]|0)+h|0]=f;aP=a[1108908]|0;aQ=c[277219]|0}else{aP=aM;aQ=aN}}while(0);h=aI+6|0;do{if((aP&255)>(d[aQ+h|0]|0)){f=a[aG+3|0]|0;if(f<<24>>24==0){aS=aP;aT=aQ;break}b[(c[277218]|0)+(h<<1)>>1]=b[(c[277225]|0)+((f&255)<<1)>>1]|0;if((a[1108928]|0)==0){aU=b[(c[277213]|0)+(aI+8<<1)>>1]|0}else{aU=0}f=aI+7|0;b[(c[277218]|0)+(f<<1)>>1]=aU;l=a[1108909]|0;a[(c[277219]|0)+f|0]=l;a[(c[277219]|0)+h|0]=l;aS=a[1108908]|0;aT=c[277219]|0}else{aS=aP;aT=aQ}}while(0);h=aI+8|0;do{if((aS&255)>(d[aT+h|0]|0)){l=a[aG+4|0]|0;if(l<<24>>24==0){aV=aS;aW=aT;break}b[(c[277218]|0)+(h<<1)>>1]=b[(c[277225]|0)+((l&255)<<1)>>1]|0;if((a[1108928]|0)==0){aX=b[(c[277213]|0)+(aI+10<<1)>>1]|0}else{aX=0}l=aI+9|0;b[(c[277218]|0)+(l<<1)>>1]=aX;f=a[1108909]|0;a[(c[277219]|0)+l|0]=f;a[(c[277219]|0)+h|0]=f;aV=a[1108908]|0;aW=c[277219]|0}else{aV=aS;aW=aT}}while(0);h=aI+10|0;do{if((aV&255)>(d[aW+h|0]|0)){f=a[aG+5|0]|0;if(f<<24>>24==0){aY=aV;aZ=aW;break}b[(c[277218]|0)+(h<<1)>>1]=b[(c[277225]|0)+((f&255)<<1)>>1]|0;if((a[1108928]|0)==0){a_=b[(c[277213]|0)+(aI+12<<1)>>1]|0}else{a_=0}f=aI+11|0;b[(c[277218]|0)+(f<<1)>>1]=a_;l=a[1108909]|0;a[(c[277219]|0)+f|0]=l;a[(c[277219]|0)+h|0]=l;aY=a[1108908]|0;aZ=c[277219]|0}else{aY=aV;aZ=aW}}while(0);h=aI+12|0;do{if((aY&255)>(d[aZ+h|0]|0)){l=a[aG+6|0]|0;if(l<<24>>24==0){a$=aY;a0=aZ;break}b[(c[277218]|0)+(h<<1)>>1]=b[(c[277225]|0)+((l&255)<<1)>>1]|0;if((a[1108928]|0)==0){a1=b[(c[277213]|0)+(aI+14<<1)>>1]|0}else{a1=0}l=aI+13|0;b[(c[277218]|0)+(l<<1)>>1]=a1;f=a[1108909]|0;a[(c[277219]|0)+l|0]=f;a[(c[277219]|0)+h|0]=f;a$=a[1108908]|0;a0=c[277219]|0}else{a$=aY;a0=aZ}}while(0);h=aI+14|0;do{if((a$&255)>(d[a0+h|0]|0)){f=a[aG+7|0]|0;if(f<<24>>24==0){break}b[(c[277218]|0)+(h<<1)>>1]=b[(c[277225]|0)+((f&255)<<1)>>1]|0;if((a[1108928]|0)==0){a2=b[(c[277213]|0)+(aI+16<<1)>>1]|0}else{a2=0}f=aI+15|0;b[(c[277218]|0)+(f<<1)>>1]=a2;l=a[1108909]|0;a[(c[277219]|0)+f|0]=l;a[(c[277219]|0)+h|0]=l}}while(0);h=aH-1|0;if((h|0)<=0){break}aG=aG-16|0;aH=h;aI=(c[277223]|0)+aI|0}return}}function WA(f,g,h,i){f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0,cf=0,cg=0,ch=0,ci=0,cj=0,ck=0,cl=0,cm=0,cn=0,co=0,cp=0,cq=0,cr=0,cs=0,ct=0,cu=0,cv=0,cw=0,cx=0,cy=0,cz=0,cA=0,cB=0,cC=0,cD=0,cE=0,cF=0,cG=0,cH=0,cI=0,cJ=0,cK=0,cL=0,cM=0,cN=0,cO=0,cP=0,cQ=0,cR=0,cS=0,cT=0,cU=0,cV=0,cW=0,cX=0,cY=0,cZ=0,c_=0,c$=0,c0=0,c1=0,c2=0,c3=0,c4=0,c5=0,c6=0,c7=0,c8=0,c9=0,da=0,db=0,dc=0,dd=0,de=0,df=0,dg=0,dh=0,di=0,dj=0,dk=0,dl=0,dm=0,dn=0,dp=0,dq=0,dr=0,ds=0,dt=0,du=0,dv=0,dw=0,dx=0,dy=0,dz=0,dA=0,dB=0,dC=0,dD=0,dE=0,dF=0,dG=0,dH=0,dI=0,dJ=0,dK=0,dL=0,dM=0,dN=0,dO=0,dP=0,dQ=0,dR=0,dS=0,dT=0,dU=0,dV=0,dW=0,dX=0,dY=0,dZ=0,d_=0,d$=0,d0=0,d1=0,d2=0,d3=0,d4=0,d5=0,d6=0,d7=0,d8=0,d9=0,ea=0,eb=0,ec=0,ed=0,ee=0,ef=0,eg=0,eh=0,ei=0,ej=0,ek=0,el=0,em=0,en=0,eo=0,ep=0,eq=0,er=0,es=0,et=0,eu=0,ev=0,ew=0,ex=0,ey=0,ez=0,eA=0,eB=0,eC=0,eD=0,eE=0,eF=0,eG=0,eH=0,eI=0,eJ=0,eK=0,eL=0,eM=0,eN=0,eO=0,eP=0,eQ=0,eR=0,eS=0,eT=0,eU=0,eV=0,eW=0,eX=0,eY=0,eZ=0,e_=0,e$=0,e0=0,e1=0,e2=0,e3=0,e4=0,e5=0,e6=0;j=f&1023;k=c[348606]|0;l=(j<<k)+(c[348604]|0)|0;if((f&256|0)==0){m=l}else{m=(c[348602]|0)+l|0}l=m&65535;m=l>>>(k>>>0);k=(f&16384|0)!=0;n=m<<6;do{if(k){o=(c[348622]|0)+n|0;if((a[(c[348618]|0)+m|0]|0)!=0){p=o;break}q=fi[c[348636]&63](o,l,j)|0;a[(c[348618]|0)+m|0]=q;p=o}else{o=(c[348624]|0)+n|0;if((a[(c[348620]|0)+m|0]|0)!=0){p=o;break}q=fi[c[348638]&63](o,l,j)|0;a[(c[348620]|0)+m|0]=q;p=o}}while(0);if((a[(c[348620]|0)+m|0]|0)==2){return}if((a[1394464]|0)==0){r=1106168+((f>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){m=d[1044485]|0;c[276541]=7080+(m<<5);j=0;do{l=j<<1&2;n=j&2;o=j&4;q=0;do{b[1125528+(j<<9)+(q<<1)>>1]=d[(q>>>1&28|n)+(7080+(m<<5))|0]<<6|d[(q<<2&28|l)+(7080+(m<<5))|0]<<11|d[(q>>>3&24|o)+(7080+(m<<5))|0];q=q+1|0;}while(q>>>0<256);j=j+1|0;}while(j>>>0<8);a[1106089]=0}r=1125528+((f>>>10&7)<<9)|0}c[277226]=r;c[277225]=(a[1108928]|0)!=0?1393712:r;if((f&49152|0)==0){if((i|0)<=0){return}r=p+((d[1394504]|0)+(h<<1))|0;j=i;m=g;while(1){q=a[1108908]|0;o=c[277219]|0;do{if((q&255)>(d[o+m|0]|0)){l=a[r]|0;n=l&255;if(l<<24>>24==0){s=q;t=o;break}l=e[(c[277225]|0)+(n<<1)>>1]|0;u=(a[(c[277215]|0)+m|0]&32)==0;if(u){v=c[277228]|0;w=v;x=v&-2082}else{v=e[(c[277213]|0)+(m<<1)>>1]|0;w=v;x=v&63454}if(u){y=c[277228]|0}else{y=e[(c[277213]|0)+(m<<1)>>1]|0}b[(c[277218]|0)+(m<<1)>>1]=((y^l)&2081|e[(c[277220]|0)+((l&2081&w)+((x+(l&63454)|0)>>>1)<<1)>>1])&65535;l=(a[1108928]|0)==0;if(l){z=b[(c[277213]|0)+(m+2<<1)>>1]&63454}else{z=0}u=(a[(c[277215]|0)+m|0]&32)==0;if(u){A=c[277228]|0}else{A=e[(c[277226]|0)+(n<<1)>>1]|0}if(l){B=b[(c[277213]|0)+(m+2<<1)>>1]&2081}else{B=0}if(u){C=c[277228]|0}else{C=e[(c[277226]|0)+(n<<1)>>1]|0}if(l){D=e[(c[277213]|0)+(m+2<<1)>>1]|0}else{D=0}if(u){E=c[277228]|0}else{E=e[(c[277226]|0)+(n<<1)>>1]|0}n=m+1|0;b[(c[277218]|0)+(n<<1)>>1]=((E^D)&2081|e[(c[277220]|0)+((C&B)+(((A&-2082)+z|0)>>>1)<<1)>>1])&65535;u=a[1108909]|0;a[(c[277219]|0)+n|0]=u;a[(c[277219]|0)+m|0]=u;s=a[1108908]|0;t=c[277219]|0}else{s=q;t=o}}while(0);o=m+2|0;do{if((s&255)>(d[t+o|0]|0)){q=a[r+1|0]|0;u=q&255;if(q<<24>>24==0){F=s;G=t;break}q=e[(c[277225]|0)+(u<<1)>>1]|0;n=(a[(c[277215]|0)+o|0]&32)==0;if(n){l=c[277228]|0;H=l;I=l&-2082}else{l=e[(c[277213]|0)+(o<<1)>>1]|0;H=l;I=l&63454}if(n){J=c[277228]|0}else{J=e[(c[277213]|0)+(o<<1)>>1]|0}b[(c[277218]|0)+(o<<1)>>1]=((J^q)&2081|e[(c[277220]|0)+((q&2081&H)+((I+(q&63454)|0)>>>1)<<1)>>1])&65535;q=(a[1108928]|0)==0;if(q){K=b[(c[277213]|0)+(m+4<<1)>>1]&63454}else{K=0}n=(a[(c[277215]|0)+o|0]&32)==0;if(n){L=c[277228]|0}else{L=e[(c[277226]|0)+(u<<1)>>1]|0}if(q){M=b[(c[277213]|0)+(m+4<<1)>>1]&2081}else{M=0}if(n){N=c[277228]|0}else{N=e[(c[277226]|0)+(u<<1)>>1]|0}if(q){O=e[(c[277213]|0)+(m+4<<1)>>1]|0}else{O=0}if(n){P=c[277228]|0}else{P=e[(c[277226]|0)+(u<<1)>>1]|0}u=m+3|0;b[(c[277218]|0)+(u<<1)>>1]=((P^O)&2081|e[(c[277220]|0)+((N&M)+(((L&-2082)+K|0)>>>1)<<1)>>1])&65535;n=a[1108909]|0;a[(c[277219]|0)+u|0]=n;a[(c[277219]|0)+o|0]=n;F=a[1108908]|0;G=c[277219]|0}else{F=s;G=t}}while(0);o=m+4|0;do{if((F&255)>(d[G+o|0]|0)){n=a[r+2|0]|0;u=n&255;if(n<<24>>24==0){Q=F;R=G;break}n=e[(c[277225]|0)+(u<<1)>>1]|0;q=(a[(c[277215]|0)+o|0]&32)==0;if(q){l=c[277228]|0;S=l;T=l&-2082}else{l=e[(c[277213]|0)+(o<<1)>>1]|0;S=l;T=l&63454}if(q){U=c[277228]|0}else{U=e[(c[277213]|0)+(o<<1)>>1]|0}b[(c[277218]|0)+(o<<1)>>1]=((U^n)&2081|e[(c[277220]|0)+((n&2081&S)+((T+(n&63454)|0)>>>1)<<1)>>1])&65535;n=(a[1108928]|0)==0;if(n){V=b[(c[277213]|0)+(m+6<<1)>>1]&63454}else{V=0}q=(a[(c[277215]|0)+o|0]&32)==0;if(q){W=c[277228]|0}else{W=e[(c[277226]|0)+(u<<1)>>1]|0}if(n){X=b[(c[277213]|0)+(m+6<<1)>>1]&2081}else{X=0}if(q){Y=c[277228]|0}else{Y=e[(c[277226]|0)+(u<<1)>>1]|0}if(n){Z=e[(c[277213]|0)+(m+6<<1)>>1]|0}else{Z=0}if(q){_=c[277228]|0}else{_=e[(c[277226]|0)+(u<<1)>>1]|0}u=m+5|0;b[(c[277218]|0)+(u<<1)>>1]=((_^Z)&2081|e[(c[277220]|0)+((Y&X)+(((W&-2082)+V|0)>>>1)<<1)>>1])&65535;q=a[1108909]|0;a[(c[277219]|0)+u|0]=q;a[(c[277219]|0)+o|0]=q;Q=a[1108908]|0;R=c[277219]|0}else{Q=F;R=G}}while(0);o=m+6|0;do{if((Q&255)>(d[R+o|0]|0)){q=a[r+3|0]|0;u=q&255;if(q<<24>>24==0){$=Q;aa=R;break}q=e[(c[277225]|0)+(u<<1)>>1]|0;n=(a[(c[277215]|0)+o|0]&32)==0;if(n){l=c[277228]|0;ab=l;ac=l&-2082}else{l=e[(c[277213]|0)+(o<<1)>>1]|0;ab=l;ac=l&63454}if(n){ad=c[277228]|0}else{ad=e[(c[277213]|0)+(o<<1)>>1]|0}b[(c[277218]|0)+(o<<1)>>1]=((ad^q)&2081|e[(c[277220]|0)+((q&2081&ab)+((ac+(q&63454)|0)>>>1)<<1)>>1])&65535;q=(a[1108928]|0)==0;if(q){ae=b[(c[277213]|0)+(m+8<<1)>>1]&63454}else{ae=0}n=(a[(c[277215]|0)+o|0]&32)==0;if(n){af=c[277228]|0}else{af=e[(c[277226]|0)+(u<<1)>>1]|0}if(q){ag=b[(c[277213]|0)+(m+8<<1)>>1]&2081}else{ag=0}if(n){ah=c[277228]|0}else{ah=e[(c[277226]|0)+(u<<1)>>1]|0}if(q){ai=e[(c[277213]|0)+(m+8<<1)>>1]|0}else{ai=0}if(n){aj=c[277228]|0}else{aj=e[(c[277226]|0)+(u<<1)>>1]|0}u=m+7|0;b[(c[277218]|0)+(u<<1)>>1]=((aj^ai)&2081|e[(c[277220]|0)+((ah&ag)+(((af&-2082)+ae|0)>>>1)<<1)>>1])&65535;n=a[1108909]|0;a[(c[277219]|0)+u|0]=n;a[(c[277219]|0)+o|0]=n;$=a[1108908]|0;aa=c[277219]|0}else{$=Q;aa=R}}while(0);o=m+8|0;do{if(($&255)>(d[aa+o|0]|0)){n=a[r+4|0]|0;u=n&255;if(n<<24>>24==0){ak=$;al=aa;break}n=e[(c[277225]|0)+(u<<1)>>1]|0;q=(a[(c[277215]|0)+o|0]&32)==0;if(q){l=c[277228]|0;am=l;an=l&-2082}else{l=e[(c[277213]|0)+(o<<1)>>1]|0;am=l;an=l&63454}if(q){ao=c[277228]|0}else{ao=e[(c[277213]|0)+(o<<1)>>1]|0}b[(c[277218]|0)+(o<<1)>>1]=((ao^n)&2081|e[(c[277220]|0)+((n&2081&am)+((an+(n&63454)|0)>>>1)<<1)>>1])&65535;n=(a[1108928]|0)==0;if(n){ap=b[(c[277213]|0)+(m+10<<1)>>1]&63454}else{ap=0}q=(a[(c[277215]|0)+o|0]&32)==0;if(q){aq=c[277228]|0}else{aq=e[(c[277226]|0)+(u<<1)>>1]|0}if(n){ar=b[(c[277213]|0)+(m+10<<1)>>1]&2081}else{ar=0}if(q){as=c[277228]|0}else{as=e[(c[277226]|0)+(u<<1)>>1]|0}if(n){at=e[(c[277213]|0)+(m+10<<1)>>1]|0}else{at=0}if(q){au=c[277228]|0}else{au=e[(c[277226]|0)+(u<<1)>>1]|0}u=m+9|0;b[(c[277218]|0)+(u<<1)>>1]=((au^at)&2081|e[(c[277220]|0)+((as&ar)+(((aq&-2082)+ap|0)>>>1)<<1)>>1])&65535;q=a[1108909]|0;a[(c[277219]|0)+u|0]=q;a[(c[277219]|0)+o|0]=q;ak=a[1108908]|0;al=c[277219]|0}else{ak=$;al=aa}}while(0);o=m+10|0;do{if((ak&255)>(d[al+o|0]|0)){q=a[r+5|0]|0;u=q&255;if(q<<24>>24==0){av=ak;aw=al;break}q=e[(c[277225]|0)+(u<<1)>>1]|0;n=(a[(c[277215]|0)+o|0]&32)==0;if(n){l=c[277228]|0;ax=l;ay=l&-2082}else{l=e[(c[277213]|0)+(o<<1)>>1]|0;ax=l;ay=l&63454}if(n){az=c[277228]|0}else{az=e[(c[277213]|0)+(o<<1)>>1]|0}b[(c[277218]|0)+(o<<1)>>1]=((az^q)&2081|e[(c[277220]|0)+((q&2081&ax)+((ay+(q&63454)|0)>>>1)<<1)>>1])&65535;q=(a[1108928]|0)==0;if(q){aA=b[(c[277213]|0)+(m+12<<1)>>1]&63454}else{aA=0}n=(a[(c[277215]|0)+o|0]&32)==0;if(n){aB=c[277228]|0}else{aB=e[(c[277226]|0)+(u<<1)>>1]|0}if(q){aC=b[(c[277213]|0)+(m+12<<1)>>1]&2081}else{aC=0}if(n){aD=c[277228]|0}else{aD=e[(c[277226]|0)+(u<<1)>>1]|0}if(q){aE=e[(c[277213]|0)+(m+12<<1)>>1]|0}else{aE=0}if(n){aF=c[277228]|0}else{aF=e[(c[277226]|0)+(u<<1)>>1]|0}u=m+11|0;b[(c[277218]|0)+(u<<1)>>1]=((aF^aE)&2081|e[(c[277220]|0)+((aD&aC)+(((aB&-2082)+aA|0)>>>1)<<1)>>1])&65535;n=a[1108909]|0;a[(c[277219]|0)+u|0]=n;a[(c[277219]|0)+o|0]=n;av=a[1108908]|0;aw=c[277219]|0}else{av=ak;aw=al}}while(0);o=m+12|0;do{if((av&255)>(d[aw+o|0]|0)){n=a[r+6|0]|0;u=n&255;if(n<<24>>24==0){aG=av;aH=aw;break}n=e[(c[277225]|0)+(u<<1)>>1]|0;q=(a[(c[277215]|0)+o|0]&32)==0;if(q){l=c[277228]|0;aI=l;aJ=l&-2082}else{l=e[(c[277213]|0)+(o<<1)>>1]|0;aI=l;aJ=l&63454}if(q){aK=c[277228]|0}else{aK=e[(c[277213]|0)+(o<<1)>>1]|0}b[(c[277218]|0)+(o<<1)>>1]=((aK^n)&2081|e[(c[277220]|0)+((n&2081&aI)+((aJ+(n&63454)|0)>>>1)<<1)>>1])&65535;n=(a[1108928]|0)==0;if(n){aL=b[(c[277213]|0)+(m+14<<1)>>1]&63454}else{aL=0}q=(a[(c[277215]|0)+o|0]&32)==0;if(q){aM=c[277228]|0}else{aM=e[(c[277226]|0)+(u<<1)>>1]|0}if(n){aN=b[(c[277213]|0)+(m+14<<1)>>1]&2081}else{aN=0}if(q){aO=c[277228]|0}else{aO=e[(c[277226]|0)+(u<<1)>>1]|0}if(n){aP=e[(c[277213]|0)+(m+14<<1)>>1]|0}else{aP=0}if(q){aQ=c[277228]|0}else{aQ=e[(c[277226]|0)+(u<<1)>>1]|0}u=m+13|0;b[(c[277218]|0)+(u<<1)>>1]=((aQ^aP)&2081|e[(c[277220]|0)+((aO&aN)+(((aM&-2082)+aL|0)>>>1)<<1)>>1])&65535;q=a[1108909]|0;a[(c[277219]|0)+u|0]=q;a[(c[277219]|0)+o|0]=q;aG=a[1108908]|0;aH=c[277219]|0}else{aG=av;aH=aw}}while(0);o=m+14|0;do{if((aG&255)>(d[aH+o|0]|0)){q=a[r+7|0]|0;u=q&255;if(q<<24>>24==0){break}q=e[(c[277225]|0)+(u<<1)>>1]|0;n=(a[(c[277215]|0)+o|0]&32)==0;if(n){l=c[277228]|0;aR=l;aS=l&-2082}else{l=e[(c[277213]|0)+(o<<1)>>1]|0;aR=l;aS=l&63454}if(n){aT=c[277228]|0}else{aT=e[(c[277213]|0)+(o<<1)>>1]|0}b[(c[277218]|0)+(o<<1)>>1]=((aT^q)&2081|e[(c[277220]|0)+((q&2081&aR)+((aS+(q&63454)|0)>>>1)<<1)>>1])&65535;q=(a[1108928]|0)==0;if(q){aU=b[(c[277213]|0)+(m+16<<1)>>1]&63454}else{aU=0}n=(a[(c[277215]|0)+o|0]&32)==0;if(n){aV=c[277228]|0}else{aV=e[(c[277226]|0)+(u<<1)>>1]|0}if(q){aW=b[(c[277213]|0)+(m+16<<1)>>1]&2081}else{aW=0}if(n){aX=c[277228]|0}else{aX=e[(c[277226]|0)+(u<<1)>>1]|0}if(q){aY=e[(c[277213]|0)+(m+16<<1)>>1]|0}else{aY=0}if(n){aZ=c[277228]|0}else{aZ=e[(c[277226]|0)+(u<<1)>>1]|0}u=m+15|0;b[(c[277218]|0)+(u<<1)>>1]=((aZ^aY)&2081|e[(c[277220]|0)+((aX&aW)+(((aV&-2082)+aU|0)>>>1)<<1)>>1])&65535;n=a[1108909]|0;a[(c[277219]|0)+u|0]=n;a[(c[277219]|0)+o|0]=n}}while(0);o=j-1|0;if((o|0)<=0){break}r=r+16|0;j=o;m=(c[277223]|0)+m|0}return}m=(d[1394504]|0)+(h<<1)|0;if((f&32768|0)==0){if((i|0)<=0){return}f=p+m|0;h=i;j=g;while(1){r=a[1108908]|0;aU=c[277219]|0;do{if((r&255)>(d[aU+j|0]|0)){aV=a[f+7|0]|0;aW=aV&255;if(aV<<24>>24==0){a_=r;a$=aU;break}aV=e[(c[277225]|0)+(aW<<1)>>1]|0;aX=(a[(c[277215]|0)+j|0]&32)==0;if(aX){aY=c[277228]|0;a0=aY;a1=aY&-2082}else{aY=e[(c[277213]|0)+(j<<1)>>1]|0;a0=aY;a1=aY&63454}if(aX){a2=c[277228]|0}else{a2=e[(c[277213]|0)+(j<<1)>>1]|0}b[(c[277218]|0)+(j<<1)>>1]=((a2^aV)&2081|e[(c[277220]|0)+((aV&2081&a0)+((a1+(aV&63454)|0)>>>1)<<1)>>1])&65535;aV=(a[1108928]|0)==0;if(aV){a3=b[(c[277213]|0)+(j+2<<1)>>1]&63454}else{a3=0}aX=(a[(c[277215]|0)+j|0]&32)==0;if(aX){a4=c[277228]|0}else{a4=e[(c[277226]|0)+(aW<<1)>>1]|0}if(aV){a5=b[(c[277213]|0)+(j+2<<1)>>1]&2081}else{a5=0}if(aX){a6=c[277228]|0}else{a6=e[(c[277226]|0)+(aW<<1)>>1]|0}if(aV){a7=e[(c[277213]|0)+(j+2<<1)>>1]|0}else{a7=0}if(aX){a8=c[277228]|0}else{a8=e[(c[277226]|0)+(aW<<1)>>1]|0}aW=j+1|0;b[(c[277218]|0)+(aW<<1)>>1]=((a8^a7)&2081|e[(c[277220]|0)+((a6&a5)+(((a4&-2082)+a3|0)>>>1)<<1)>>1])&65535;aX=a[1108909]|0;a[(c[277219]|0)+aW|0]=aX;a[(c[277219]|0)+j|0]=aX;a_=a[1108908]|0;a$=c[277219]|0}else{a_=r;a$=aU}}while(0);aU=j+2|0;do{if((a_&255)>(d[a$+aU|0]|0)){r=a[f+6|0]|0;aX=r&255;if(r<<24>>24==0){a9=a_;ba=a$;break}r=e[(c[277225]|0)+(aX<<1)>>1]|0;aW=(a[(c[277215]|0)+aU|0]&32)==0;if(aW){aV=c[277228]|0;bb=aV;bc=aV&-2082}else{aV=e[(c[277213]|0)+(aU<<1)>>1]|0;bb=aV;bc=aV&63454}if(aW){bd=c[277228]|0}else{bd=e[(c[277213]|0)+(aU<<1)>>1]|0}b[(c[277218]|0)+(aU<<1)>>1]=((bd^r)&2081|e[(c[277220]|0)+((r&2081&bb)+((bc+(r&63454)|0)>>>1)<<1)>>1])&65535;r=(a[1108928]|0)==0;if(r){be=b[(c[277213]|0)+(j+4<<1)>>1]&63454}else{be=0}aW=(a[(c[277215]|0)+aU|0]&32)==0;if(aW){bf=c[277228]|0}else{bf=e[(c[277226]|0)+(aX<<1)>>1]|0}if(r){bg=b[(c[277213]|0)+(j+4<<1)>>1]&2081}else{bg=0}if(aW){bh=c[277228]|0}else{bh=e[(c[277226]|0)+(aX<<1)>>1]|0}if(r){bi=e[(c[277213]|0)+(j+4<<1)>>1]|0}else{bi=0}if(aW){bj=c[277228]|0}else{bj=e[(c[277226]|0)+(aX<<1)>>1]|0}aX=j+3|0;b[(c[277218]|0)+(aX<<1)>>1]=((bj^bi)&2081|e[(c[277220]|0)+((bh&bg)+(((bf&-2082)+be|0)>>>1)<<1)>>1])&65535;aW=a[1108909]|0;a[(c[277219]|0)+aX|0]=aW;a[(c[277219]|0)+aU|0]=aW;a9=a[1108908]|0;ba=c[277219]|0}else{a9=a_;ba=a$}}while(0);aU=j+4|0;do{if((a9&255)>(d[ba+aU|0]|0)){aW=a[f+5|0]|0;aX=aW&255;if(aW<<24>>24==0){bk=a9;bl=ba;break}aW=e[(c[277225]|0)+(aX<<1)>>1]|0;r=(a[(c[277215]|0)+aU|0]&32)==0;if(r){aV=c[277228]|0;bm=aV;bn=aV&-2082}else{aV=e[(c[277213]|0)+(aU<<1)>>1]|0;bm=aV;bn=aV&63454}if(r){bo=c[277228]|0}else{bo=e[(c[277213]|0)+(aU<<1)>>1]|0}b[(c[277218]|0)+(aU<<1)>>1]=((bo^aW)&2081|e[(c[277220]|0)+((aW&2081&bm)+((bn+(aW&63454)|0)>>>1)<<1)>>1])&65535;aW=(a[1108928]|0)==0;if(aW){bp=b[(c[277213]|0)+(j+6<<1)>>1]&63454}else{bp=0}r=(a[(c[277215]|0)+aU|0]&32)==0;if(r){bq=c[277228]|0}else{bq=e[(c[277226]|0)+(aX<<1)>>1]|0}if(aW){br=b[(c[277213]|0)+(j+6<<1)>>1]&2081}else{br=0}if(r){bs=c[277228]|0}else{bs=e[(c[277226]|0)+(aX<<1)>>1]|0}if(aW){bt=e[(c[277213]|0)+(j+6<<1)>>1]|0}else{bt=0}if(r){bu=c[277228]|0}else{bu=e[(c[277226]|0)+(aX<<1)>>1]|0}aX=j+5|0;b[(c[277218]|0)+(aX<<1)>>1]=((bu^bt)&2081|e[(c[277220]|0)+((bs&br)+(((bq&-2082)+bp|0)>>>1)<<1)>>1])&65535;r=a[1108909]|0;a[(c[277219]|0)+aX|0]=r;a[(c[277219]|0)+aU|0]=r;bk=a[1108908]|0;bl=c[277219]|0}else{bk=a9;bl=ba}}while(0);aU=j+6|0;do{if((bk&255)>(d[bl+aU|0]|0)){r=a[f+4|0]|0;aX=r&255;if(r<<24>>24==0){bv=bk;bw=bl;break}r=e[(c[277225]|0)+(aX<<1)>>1]|0;aW=(a[(c[277215]|0)+aU|0]&32)==0;if(aW){aV=c[277228]|0;bx=aV;by=aV&-2082}else{aV=e[(c[277213]|0)+(aU<<1)>>1]|0;bx=aV;by=aV&63454}if(aW){bz=c[277228]|0}else{bz=e[(c[277213]|0)+(aU<<1)>>1]|0}b[(c[277218]|0)+(aU<<1)>>1]=((bz^r)&2081|e[(c[277220]|0)+((r&2081&bx)+((by+(r&63454)|0)>>>1)<<1)>>1])&65535;r=(a[1108928]|0)==0;if(r){bA=b[(c[277213]|0)+(j+8<<1)>>1]&63454}else{bA=0}aW=(a[(c[277215]|0)+aU|0]&32)==0;if(aW){bB=c[277228]|0}else{bB=e[(c[277226]|0)+(aX<<1)>>1]|0}if(r){bC=b[(c[277213]|0)+(j+8<<1)>>1]&2081}else{bC=0}if(aW){bD=c[277228]|0}else{bD=e[(c[277226]|0)+(aX<<1)>>1]|0}if(r){bE=e[(c[277213]|0)+(j+8<<1)>>1]|0}else{bE=0}if(aW){bF=c[277228]|0}else{bF=e[(c[277226]|0)+(aX<<1)>>1]|0}aX=j+7|0;b[(c[277218]|0)+(aX<<1)>>1]=((bF^bE)&2081|e[(c[277220]|0)+((bD&bC)+(((bB&-2082)+bA|0)>>>1)<<1)>>1])&65535;aW=a[1108909]|0;a[(c[277219]|0)+aX|0]=aW;a[(c[277219]|0)+aU|0]=aW;bv=a[1108908]|0;bw=c[277219]|0}else{bv=bk;bw=bl}}while(0);aU=j+8|0;do{if((bv&255)>(d[bw+aU|0]|0)){aW=a[f+3|0]|0;aX=aW&255;if(aW<<24>>24==0){bG=bv;bH=bw;break}aW=e[(c[277225]|0)+(aX<<1)>>1]|0;r=(a[(c[277215]|0)+aU|0]&32)==0;if(r){aV=c[277228]|0;bI=aV;bJ=aV&-2082}else{aV=e[(c[277213]|0)+(aU<<1)>>1]|0;bI=aV;bJ=aV&63454}if(r){bK=c[277228]|0}else{bK=e[(c[277213]|0)+(aU<<1)>>1]|0}b[(c[277218]|0)+(aU<<1)>>1]=((bK^aW)&2081|e[(c[277220]|0)+((aW&2081&bI)+((bJ+(aW&63454)|0)>>>1)<<1)>>1])&65535;aW=(a[1108928]|0)==0;if(aW){bL=b[(c[277213]|0)+(j+10<<1)>>1]&63454}else{bL=0}r=(a[(c[277215]|0)+aU|0]&32)==0;if(r){bM=c[277228]|0}else{bM=e[(c[277226]|0)+(aX<<1)>>1]|0}if(aW){bN=b[(c[277213]|0)+(j+10<<1)>>1]&2081}else{bN=0}if(r){bO=c[277228]|0}else{bO=e[(c[277226]|0)+(aX<<1)>>1]|0}if(aW){bP=e[(c[277213]|0)+(j+10<<1)>>1]|0}else{bP=0}if(r){bQ=c[277228]|0}else{bQ=e[(c[277226]|0)+(aX<<1)>>1]|0}aX=j+9|0;b[(c[277218]|0)+(aX<<1)>>1]=((bQ^bP)&2081|e[(c[277220]|0)+((bO&bN)+(((bM&-2082)+bL|0)>>>1)<<1)>>1])&65535;r=a[1108909]|0;a[(c[277219]|0)+aX|0]=r;a[(c[277219]|0)+aU|0]=r;bG=a[1108908]|0;bH=c[277219]|0}else{bG=bv;bH=bw}}while(0);aU=j+10|0;do{if((bG&255)>(d[bH+aU|0]|0)){r=a[f+2|0]|0;aX=r&255;if(r<<24>>24==0){bR=bG;bS=bH;break}r=e[(c[277225]|0)+(aX<<1)>>1]|0;aW=(a[(c[277215]|0)+aU|0]&32)==0;if(aW){aV=c[277228]|0;bT=aV;bU=aV&-2082}else{aV=e[(c[277213]|0)+(aU<<1)>>1]|0;bT=aV;bU=aV&63454}if(aW){bV=c[277228]|0}else{bV=e[(c[277213]|0)+(aU<<1)>>1]|0}b[(c[277218]|0)+(aU<<1)>>1]=((bV^r)&2081|e[(c[277220]|0)+((r&2081&bT)+((bU+(r&63454)|0)>>>1)<<1)>>1])&65535;r=(a[1108928]|0)==0;if(r){bW=b[(c[277213]|0)+(j+12<<1)>>1]&63454}else{bW=0}aW=(a[(c[277215]|0)+aU|0]&32)==0;if(aW){bX=c[277228]|0}else{bX=e[(c[277226]|0)+(aX<<1)>>1]|0}if(r){bY=b[(c[277213]|0)+(j+12<<1)>>1]&2081}else{bY=0}if(aW){bZ=c[277228]|0}else{bZ=e[(c[277226]|0)+(aX<<1)>>1]|0}if(r){b_=e[(c[277213]|0)+(j+12<<1)>>1]|0}else{b_=0}if(aW){b$=c[277228]|0}else{b$=e[(c[277226]|0)+(aX<<1)>>1]|0}aX=j+11|0;b[(c[277218]|0)+(aX<<1)>>1]=((b$^b_)&2081|e[(c[277220]|0)+((bZ&bY)+(((bX&-2082)+bW|0)>>>1)<<1)>>1])&65535;aW=a[1108909]|0;a[(c[277219]|0)+aX|0]=aW;a[(c[277219]|0)+aU|0]=aW;bR=a[1108908]|0;bS=c[277219]|0}else{bR=bG;bS=bH}}while(0);aU=j+12|0;do{if((bR&255)>(d[bS+aU|0]|0)){aW=a[f+1|0]|0;aX=aW&255;if(aW<<24>>24==0){b0=bR;b1=bS;break}aW=e[(c[277225]|0)+(aX<<1)>>1]|0;r=(a[(c[277215]|0)+aU|0]&32)==0;if(r){aV=c[277228]|0;b2=aV;b3=aV&-2082}else{aV=e[(c[277213]|0)+(aU<<1)>>1]|0;b2=aV;b3=aV&63454}if(r){b4=c[277228]|0}else{b4=e[(c[277213]|0)+(aU<<1)>>1]|0}b[(c[277218]|0)+(aU<<1)>>1]=((b4^aW)&2081|e[(c[277220]|0)+((aW&2081&b2)+((b3+(aW&63454)|0)>>>1)<<1)>>1])&65535;aW=(a[1108928]|0)==0;if(aW){b5=b[(c[277213]|0)+(j+14<<1)>>1]&63454}else{b5=0}r=(a[(c[277215]|0)+aU|0]&32)==0;if(r){b6=c[277228]|0}else{b6=e[(c[277226]|0)+(aX<<1)>>1]|0}if(aW){b7=b[(c[277213]|0)+(j+14<<1)>>1]&2081}else{b7=0}if(r){b8=c[277228]|0}else{b8=e[(c[277226]|0)+(aX<<1)>>1]|0}if(aW){b9=e[(c[277213]|0)+(j+14<<1)>>1]|0}else{b9=0}if(r){ca=c[277228]|0}else{ca=e[(c[277226]|0)+(aX<<1)>>1]|0}aX=j+13|0;b[(c[277218]|0)+(aX<<1)>>1]=((ca^b9)&2081|e[(c[277220]|0)+((b8&b7)+(((b6&-2082)+b5|0)>>>1)<<1)>>1])&65535;r=a[1108909]|0;a[(c[277219]|0)+aX|0]=r;a[(c[277219]|0)+aU|0]=r;b0=a[1108908]|0;b1=c[277219]|0}else{b0=bR;b1=bS}}while(0);aU=j+14|0;do{if((b0&255)>(d[b1+aU|0]|0)){r=a[f]|0;aX=r&255;if(r<<24>>24==0){break}r=e[(c[277225]|0)+(aX<<1)>>1]|0;aW=(a[(c[277215]|0)+aU|0]&32)==0;if(aW){aV=c[277228]|0;cb=aV;cc=aV&-2082}else{aV=e[(c[277213]|0)+(aU<<1)>>1]|0;cb=aV;cc=aV&63454}if(aW){cd=c[277228]|0}else{cd=e[(c[277213]|0)+(aU<<1)>>1]|0}b[(c[277218]|0)+(aU<<1)>>1]=((cd^r)&2081|e[(c[277220]|0)+((r&2081&cb)+((cc+(r&63454)|0)>>>1)<<1)>>1])&65535;r=(a[1108928]|0)==0;if(r){ce=b[(c[277213]|0)+(j+16<<1)>>1]&63454}else{ce=0}aW=(a[(c[277215]|0)+aU|0]&32)==0;if(aW){cf=c[277228]|0}else{cf=e[(c[277226]|0)+(aX<<1)>>1]|0}if(r){cg=b[(c[277213]|0)+(j+16<<1)>>1]&2081}else{cg=0}if(aW){ch=c[277228]|0}else{ch=e[(c[277226]|0)+(aX<<1)>>1]|0}if(r){ci=e[(c[277213]|0)+(j+16<<1)>>1]|0}else{ci=0}if(aW){cj=c[277228]|0}else{cj=e[(c[277226]|0)+(aX<<1)>>1]|0}aX=j+15|0;b[(c[277218]|0)+(aX<<1)>>1]=((cj^ci)&2081|e[(c[277220]|0)+((ch&cg)+(((cf&-2082)+ce|0)>>>1)<<1)>>1])&65535;aW=a[1108909]|0;a[(c[277219]|0)+aX|0]=aW;a[(c[277219]|0)+aU|0]=aW}}while(0);aU=h-1|0;if((aU|0)<=0){break}f=f+16|0;h=aU;j=(c[277223]|0)+j|0}return}j=p+(56-m)|0;m=(i|0)>0;if(k){if(m){ck=j;cl=i;cm=g}else{return}while(1){k=a[1108908]|0;p=c[277219]|0;do{if((k&255)>(d[p+cm|0]|0)){h=a[ck+7|0]|0;f=h&255;if(h<<24>>24==0){cn=k;co=p;break}h=e[(c[277225]|0)+(f<<1)>>1]|0;ce=(a[(c[277215]|0)+cm|0]&32)==0;if(ce){cf=c[277228]|0;cp=cf;cq=cf&-2082}else{cf=e[(c[277213]|0)+(cm<<1)>>1]|0;cp=cf;cq=cf&63454}if(ce){cr=c[277228]|0}else{cr=e[(c[277213]|0)+(cm<<1)>>1]|0}b[(c[277218]|0)+(cm<<1)>>1]=((cr^h)&2081|e[(c[277220]|0)+((h&2081&cp)+((cq+(h&63454)|0)>>>1)<<1)>>1])&65535;h=(a[1108928]|0)==0;if(h){cs=b[(c[277213]|0)+(cm+2<<1)>>1]&63454}else{cs=0}ce=(a[(c[277215]|0)+cm|0]&32)==0;if(ce){ct=c[277228]|0}else{ct=e[(c[277226]|0)+(f<<1)>>1]|0}if(h){cu=b[(c[277213]|0)+(cm+2<<1)>>1]&2081}else{cu=0}if(ce){cv=c[277228]|0}else{cv=e[(c[277226]|0)+(f<<1)>>1]|0}if(h){cw=e[(c[277213]|0)+(cm+2<<1)>>1]|0}else{cw=0}if(ce){cx=c[277228]|0}else{cx=e[(c[277226]|0)+(f<<1)>>1]|0}f=cm+1|0;b[(c[277218]|0)+(f<<1)>>1]=((cx^cw)&2081|e[(c[277220]|0)+((cv&cu)+(((ct&-2082)+cs|0)>>>1)<<1)>>1])&65535;ce=a[1108909]|0;a[(c[277219]|0)+f|0]=ce;a[(c[277219]|0)+cm|0]=ce;cn=a[1108908]|0;co=c[277219]|0}else{cn=k;co=p}}while(0);p=cm+2|0;do{if((cn&255)>(d[co+p|0]|0)){k=a[ck+6|0]|0;ce=k&255;if(k<<24>>24==0){cy=cn;cz=co;break}k=e[(c[277225]|0)+(ce<<1)>>1]|0;f=(a[(c[277215]|0)+p|0]&32)==0;if(f){h=c[277228]|0;cA=h;cB=h&-2082}else{h=e[(c[277213]|0)+(p<<1)>>1]|0;cA=h;cB=h&63454}if(f){cC=c[277228]|0}else{cC=e[(c[277213]|0)+(p<<1)>>1]|0}b[(c[277218]|0)+(p<<1)>>1]=((cC^k)&2081|e[(c[277220]|0)+((k&2081&cA)+((cB+(k&63454)|0)>>>1)<<1)>>1])&65535;k=(a[1108928]|0)==0;if(k){cD=b[(c[277213]|0)+(cm+4<<1)>>1]&63454}else{cD=0}f=(a[(c[277215]|0)+p|0]&32)==0;if(f){cE=c[277228]|0}else{cE=e[(c[277226]|0)+(ce<<1)>>1]|0}if(k){cF=b[(c[277213]|0)+(cm+4<<1)>>1]&2081}else{cF=0}if(f){cG=c[277228]|0}else{cG=e[(c[277226]|0)+(ce<<1)>>1]|0}if(k){cH=e[(c[277213]|0)+(cm+4<<1)>>1]|0}else{cH=0}if(f){cI=c[277228]|0}else{cI=e[(c[277226]|0)+(ce<<1)>>1]|0}ce=cm+3|0;b[(c[277218]|0)+(ce<<1)>>1]=((cI^cH)&2081|e[(c[277220]|0)+((cG&cF)+(((cE&-2082)+cD|0)>>>1)<<1)>>1])&65535;f=a[1108909]|0;a[(c[277219]|0)+ce|0]=f;a[(c[277219]|0)+p|0]=f;cy=a[1108908]|0;cz=c[277219]|0}else{cy=cn;cz=co}}while(0);p=cm+4|0;do{if((cy&255)>(d[cz+p|0]|0)){f=a[ck+5|0]|0;ce=f&255;if(f<<24>>24==0){cJ=cy;cK=cz;break}f=e[(c[277225]|0)+(ce<<1)>>1]|0;k=(a[(c[277215]|0)+p|0]&32)==0;if(k){h=c[277228]|0;cL=h;cM=h&-2082}else{h=e[(c[277213]|0)+(p<<1)>>1]|0;cL=h;cM=h&63454}if(k){cN=c[277228]|0}else{cN=e[(c[277213]|0)+(p<<1)>>1]|0}b[(c[277218]|0)+(p<<1)>>1]=((cN^f)&2081|e[(c[277220]|0)+((f&2081&cL)+((cM+(f&63454)|0)>>>1)<<1)>>1])&65535;f=(a[1108928]|0)==0;if(f){cO=b[(c[277213]|0)+(cm+6<<1)>>1]&63454}else{cO=0}k=(a[(c[277215]|0)+p|0]&32)==0;if(k){cP=c[277228]|0}else{cP=e[(c[277226]|0)+(ce<<1)>>1]|0}if(f){cQ=b[(c[277213]|0)+(cm+6<<1)>>1]&2081}else{cQ=0}if(k){cR=c[277228]|0}else{cR=e[(c[277226]|0)+(ce<<1)>>1]|0}if(f){cS=e[(c[277213]|0)+(cm+6<<1)>>1]|0}else{cS=0}if(k){cT=c[277228]|0}else{cT=e[(c[277226]|0)+(ce<<1)>>1]|0}ce=cm+5|0;b[(c[277218]|0)+(ce<<1)>>1]=((cT^cS)&2081|e[(c[277220]|0)+((cR&cQ)+(((cP&-2082)+cO|0)>>>1)<<1)>>1])&65535;k=a[1108909]|0;a[(c[277219]|0)+ce|0]=k;a[(c[277219]|0)+p|0]=k;cJ=a[1108908]|0;cK=c[277219]|0}else{cJ=cy;cK=cz}}while(0);p=cm+6|0;do{if((cJ&255)>(d[cK+p|0]|0)){k=a[ck+4|0]|0;ce=k&255;if(k<<24>>24==0){cU=cJ;cV=cK;break}k=e[(c[277225]|0)+(ce<<1)>>1]|0;f=(a[(c[277215]|0)+p|0]&32)==0;if(f){h=c[277228]|0;cW=h;cX=h&-2082}else{h=e[(c[277213]|0)+(p<<1)>>1]|0;cW=h;cX=h&63454}if(f){cY=c[277228]|0}else{cY=e[(c[277213]|0)+(p<<1)>>1]|0}b[(c[277218]|0)+(p<<1)>>1]=((cY^k)&2081|e[(c[277220]|0)+((k&2081&cW)+((cX+(k&63454)|0)>>>1)<<1)>>1])&65535;k=(a[1108928]|0)==0;if(k){cZ=b[(c[277213]|0)+(cm+8<<1)>>1]&63454}else{cZ=0}f=(a[(c[277215]|0)+p|0]&32)==0;if(f){c_=c[277228]|0}else{c_=e[(c[277226]|0)+(ce<<1)>>1]|0}if(k){c$=b[(c[277213]|0)+(cm+8<<1)>>1]&2081}else{c$=0}if(f){c0=c[277228]|0}else{c0=e[(c[277226]|0)+(ce<<1)>>1]|0}if(k){c1=e[(c[277213]|0)+(cm+8<<1)>>1]|0}else{c1=0}if(f){c2=c[277228]|0}else{c2=e[(c[277226]|0)+(ce<<1)>>1]|0}ce=cm+7|0;b[(c[277218]|0)+(ce<<1)>>1]=((c2^c1)&2081|e[(c[277220]|0)+((c0&c$)+(((c_&-2082)+cZ|0)>>>1)<<1)>>1])&65535;f=a[1108909]|0;a[(c[277219]|0)+ce|0]=f;a[(c[277219]|0)+p|0]=f;cU=a[1108908]|0;cV=c[277219]|0}else{cU=cJ;cV=cK}}while(0);p=cm+8|0;do{if((cU&255)>(d[cV+p|0]|0)){f=a[ck+3|0]|0;ce=f&255;if(f<<24>>24==0){c3=cU;c4=cV;break}f=e[(c[277225]|0)+(ce<<1)>>1]|0;k=(a[(c[277215]|0)+p|0]&32)==0;if(k){h=c[277228]|0;c5=h;c6=h&-2082}else{h=e[(c[277213]|0)+(p<<1)>>1]|0;c5=h;c6=h&63454}if(k){c7=c[277228]|0}else{c7=e[(c[277213]|0)+(p<<1)>>1]|0}b[(c[277218]|0)+(p<<1)>>1]=((c7^f)&2081|e[(c[277220]|0)+((f&2081&c5)+((c6+(f&63454)|0)>>>1)<<1)>>1])&65535;f=(a[1108928]|0)==0;if(f){c8=b[(c[277213]|0)+(cm+10<<1)>>1]&63454}else{c8=0}k=(a[(c[277215]|0)+p|0]&32)==0;if(k){c9=c[277228]|0}else{c9=e[(c[277226]|0)+(ce<<1)>>1]|0}if(f){da=b[(c[277213]|0)+(cm+10<<1)>>1]&2081}else{da=0}if(k){db=c[277228]|0}else{db=e[(c[277226]|0)+(ce<<1)>>1]|0}if(f){dc=e[(c[277213]|0)+(cm+10<<1)>>1]|0}else{dc=0}if(k){dd=c[277228]|0}else{dd=e[(c[277226]|0)+(ce<<1)>>1]|0}ce=cm+9|0;b[(c[277218]|0)+(ce<<1)>>1]=((dd^dc)&2081|e[(c[277220]|0)+((db&da)+(((c9&-2082)+c8|0)>>>1)<<1)>>1])&65535;k=a[1108909]|0;a[(c[277219]|0)+ce|0]=k;a[(c[277219]|0)+p|0]=k;c3=a[1108908]|0;c4=c[277219]|0}else{c3=cU;c4=cV}}while(0);p=cm+10|0;do{if((c3&255)>(d[c4+p|0]|0)){k=a[ck+2|0]|0;ce=k&255;if(k<<24>>24==0){de=c3;df=c4;break}k=e[(c[277225]|0)+(ce<<1)>>1]|0;f=(a[(c[277215]|0)+p|0]&32)==0;if(f){h=c[277228]|0;dg=h;dh=h&-2082}else{h=e[(c[277213]|0)+(p<<1)>>1]|0;dg=h;dh=h&63454}if(f){di=c[277228]|0}else{di=e[(c[277213]|0)+(p<<1)>>1]|0}b[(c[277218]|0)+(p<<1)>>1]=((di^k)&2081|e[(c[277220]|0)+((k&2081&dg)+((dh+(k&63454)|0)>>>1)<<1)>>1])&65535;k=(a[1108928]|0)==0;if(k){dj=b[(c[277213]|0)+(cm+12<<1)>>1]&63454}else{dj=0}f=(a[(c[277215]|0)+p|0]&32)==0;if(f){dk=c[277228]|0}else{dk=e[(c[277226]|0)+(ce<<1)>>1]|0}if(k){dl=b[(c[277213]|0)+(cm+12<<1)>>1]&2081}else{dl=0}if(f){dm=c[277228]|0}else{dm=e[(c[277226]|0)+(ce<<1)>>1]|0}if(k){dn=e[(c[277213]|0)+(cm+12<<1)>>1]|0}else{dn=0}if(f){dp=c[277228]|0}else{dp=e[(c[277226]|0)+(ce<<1)>>1]|0}ce=cm+11|0;b[(c[277218]|0)+(ce<<1)>>1]=((dp^dn)&2081|e[(c[277220]|0)+((dm&dl)+(((dk&-2082)+dj|0)>>>1)<<1)>>1])&65535;f=a[1108909]|0;a[(c[277219]|0)+ce|0]=f;a[(c[277219]|0)+p|0]=f;de=a[1108908]|0;df=c[277219]|0}else{de=c3;df=c4}}while(0);p=cm+12|0;do{if((de&255)>(d[df+p|0]|0)){f=a[ck+1|0]|0;ce=f&255;if(f<<24>>24==0){dq=de;dr=df;break}f=e[(c[277225]|0)+(ce<<1)>>1]|0;k=(a[(c[277215]|0)+p|0]&32)==0;if(k){h=c[277228]|0;ds=h;dt=h&-2082}else{h=e[(c[277213]|0)+(p<<1)>>1]|0;ds=h;dt=h&63454}if(k){du=c[277228]|0}else{du=e[(c[277213]|0)+(p<<1)>>1]|0}b[(c[277218]|0)+(p<<1)>>1]=((du^f)&2081|e[(c[277220]|0)+((f&2081&ds)+((dt+(f&63454)|0)>>>1)<<1)>>1])&65535;f=(a[1108928]|0)==0;if(f){dv=b[(c[277213]|0)+(cm+14<<1)>>1]&63454}else{dv=0}k=(a[(c[277215]|0)+p|0]&32)==0;if(k){dw=c[277228]|0}else{dw=e[(c[277226]|0)+(ce<<1)>>1]|0}if(f){dx=b[(c[277213]|0)+(cm+14<<1)>>1]&2081}else{dx=0}if(k){dy=c[277228]|0}else{dy=e[(c[277226]|0)+(ce<<1)>>1]|0}if(f){dz=e[(c[277213]|0)+(cm+14<<1)>>1]|0}else{dz=0}if(k){dA=c[277228]|0}else{dA=e[(c[277226]|0)+(ce<<1)>>1]|0}ce=cm+13|0;b[(c[277218]|0)+(ce<<1)>>1]=((dA^dz)&2081|e[(c[277220]|0)+((dy&dx)+(((dw&-2082)+dv|0)>>>1)<<1)>>1])&65535;k=a[1108909]|0;a[(c[277219]|0)+ce|0]=k;a[(c[277219]|0)+p|0]=k;dq=a[1108908]|0;dr=c[277219]|0}else{dq=de;dr=df}}while(0);p=cm+14|0;do{if((dq&255)>(d[dr+p|0]|0)){k=a[ck]|0;ce=k&255;if(k<<24>>24==0){break}k=e[(c[277225]|0)+(ce<<1)>>1]|0;f=(a[(c[277215]|0)+p|0]&32)==0;if(f){h=c[277228]|0;dB=h;dC=h&-2082}else{h=e[(c[277213]|0)+(p<<1)>>1]|0;dB=h;dC=h&63454}if(f){dD=c[277228]|0}else{dD=e[(c[277213]|0)+(p<<1)>>1]|0}b[(c[277218]|0)+(p<<1)>>1]=((dD^k)&2081|e[(c[277220]|0)+((k&2081&dB)+((dC+(k&63454)|0)>>>1)<<1)>>1])&65535;k=(a[1108928]|0)==0;if(k){dE=b[(c[277213]|0)+(cm+16<<1)>>1]&63454}else{dE=0}f=(a[(c[277215]|0)+p|0]&32)==0;if(f){dF=c[277228]|0}else{dF=e[(c[277226]|0)+(ce<<1)>>1]|0}if(k){dG=b[(c[277213]|0)+(cm+16<<1)>>1]&2081}else{dG=0}if(f){dH=c[277228]|0}else{dH=e[(c[277226]|0)+(ce<<1)>>1]|0}if(k){dI=e[(c[277213]|0)+(cm+16<<1)>>1]|0}else{dI=0}if(f){dJ=c[277228]|0}else{dJ=e[(c[277226]|0)+(ce<<1)>>1]|0}ce=cm+15|0;b[(c[277218]|0)+(ce<<1)>>1]=((dJ^dI)&2081|e[(c[277220]|0)+((dH&dG)+(((dF&-2082)+dE|0)>>>1)<<1)>>1])&65535;f=a[1108909]|0;a[(c[277219]|0)+ce|0]=f;a[(c[277219]|0)+p|0]=f}}while(0);p=cl-1|0;if((p|0)<=0){break}ck=ck-16|0;cl=p;cm=(c[277223]|0)+cm|0}return}else{if(m){dK=j;dL=i;dM=g}else{return}while(1){g=a[1108908]|0;i=c[277219]|0;do{if((g&255)>(d[i+dM|0]|0)){j=a[dK]|0;m=j&255;if(j<<24>>24==0){dN=g;dO=i;break}j=e[(c[277225]|0)+(m<<1)>>1]|0;cm=(a[(c[277215]|0)+dM|0]&32)==0;if(cm){cl=c[277228]|0;dP=cl;dQ=cl&-2082}else{cl=e[(c[277213]|0)+(dM<<1)>>1]|0;dP=cl;dQ=cl&63454}if(cm){dR=c[277228]|0}else{dR=e[(c[277213]|0)+(dM<<1)>>1]|0}b[(c[277218]|0)+(dM<<1)>>1]=((dR^j)&2081|e[(c[277220]|0)+((j&2081&dP)+((dQ+(j&63454)|0)>>>1)<<1)>>1])&65535;j=(a[1108928]|0)==0;if(j){dS=b[(c[277213]|0)+(dM+2<<1)>>1]&63454}else{dS=0}cm=(a[(c[277215]|0)+dM|0]&32)==0;if(cm){dT=c[277228]|0}else{dT=e[(c[277226]|0)+(m<<1)>>1]|0}if(j){dU=b[(c[277213]|0)+(dM+2<<1)>>1]&2081}else{dU=0}if(cm){dV=c[277228]|0}else{dV=e[(c[277226]|0)+(m<<1)>>1]|0}if(j){dW=e[(c[277213]|0)+(dM+2<<1)>>1]|0}else{dW=0}if(cm){dX=c[277228]|0}else{dX=e[(c[277226]|0)+(m<<1)>>1]|0}m=dM+1|0;b[(c[277218]|0)+(m<<1)>>1]=((dX^dW)&2081|e[(c[277220]|0)+((dV&dU)+(((dT&-2082)+dS|0)>>>1)<<1)>>1])&65535;cm=a[1108909]|0;a[(c[277219]|0)+m|0]=cm;a[(c[277219]|0)+dM|0]=cm;dN=a[1108908]|0;dO=c[277219]|0}else{dN=g;dO=i}}while(0);i=dM+2|0;do{if((dN&255)>(d[dO+i|0]|0)){g=a[dK+1|0]|0;cm=g&255;if(g<<24>>24==0){dY=dN;dZ=dO;break}g=e[(c[277225]|0)+(cm<<1)>>1]|0;m=(a[(c[277215]|0)+i|0]&32)==0;if(m){j=c[277228]|0;d_=j;d$=j&-2082}else{j=e[(c[277213]|0)+(i<<1)>>1]|0;d_=j;d$=j&63454}if(m){d0=c[277228]|0}else{d0=e[(c[277213]|0)+(i<<1)>>1]|0}b[(c[277218]|0)+(i<<1)>>1]=((d0^g)&2081|e[(c[277220]|0)+((g&2081&d_)+((d$+(g&63454)|0)>>>1)<<1)>>1])&65535;g=(a[1108928]|0)==0;if(g){d1=b[(c[277213]|0)+(dM+4<<1)>>1]&63454}else{d1=0}m=(a[(c[277215]|0)+i|0]&32)==0;if(m){d2=c[277228]|0}else{d2=e[(c[277226]|0)+(cm<<1)>>1]|0}if(g){d3=b[(c[277213]|0)+(dM+4<<1)>>1]&2081}else{d3=0}if(m){d4=c[277228]|0}else{d4=e[(c[277226]|0)+(cm<<1)>>1]|0}if(g){d5=e[(c[277213]|0)+(dM+4<<1)>>1]|0}else{d5=0}if(m){d6=c[277228]|0}else{d6=e[(c[277226]|0)+(cm<<1)>>1]|0}cm=dM+3|0;b[(c[277218]|0)+(cm<<1)>>1]=((d6^d5)&2081|e[(c[277220]|0)+((d4&d3)+(((d2&-2082)+d1|0)>>>1)<<1)>>1])&65535;m=a[1108909]|0;a[(c[277219]|0)+cm|0]=m;a[(c[277219]|0)+i|0]=m;dY=a[1108908]|0;dZ=c[277219]|0}else{dY=dN;dZ=dO}}while(0);i=dM+4|0;do{if((dY&255)>(d[dZ+i|0]|0)){m=a[dK+2|0]|0;cm=m&255;if(m<<24>>24==0){d7=dY;d8=dZ;break}m=e[(c[277225]|0)+(cm<<1)>>1]|0;g=(a[(c[277215]|0)+i|0]&32)==0;if(g){j=c[277228]|0;d9=j;ea=j&-2082}else{j=e[(c[277213]|0)+(i<<1)>>1]|0;d9=j;ea=j&63454}if(g){eb=c[277228]|0}else{eb=e[(c[277213]|0)+(i<<1)>>1]|0}b[(c[277218]|0)+(i<<1)>>1]=((eb^m)&2081|e[(c[277220]|0)+((m&2081&d9)+((ea+(m&63454)|0)>>>1)<<1)>>1])&65535;m=(a[1108928]|0)==0;if(m){ec=b[(c[277213]|0)+(dM+6<<1)>>1]&63454}else{ec=0}g=(a[(c[277215]|0)+i|0]&32)==0;if(g){ed=c[277228]|0}else{ed=e[(c[277226]|0)+(cm<<1)>>1]|0}if(m){ee=b[(c[277213]|0)+(dM+6<<1)>>1]&2081}else{ee=0}if(g){ef=c[277228]|0}else{ef=e[(c[277226]|0)+(cm<<1)>>1]|0}if(m){eg=e[(c[277213]|0)+(dM+6<<1)>>1]|0}else{eg=0}if(g){eh=c[277228]|0}else{eh=e[(c[277226]|0)+(cm<<1)>>1]|0}cm=dM+5|0;b[(c[277218]|0)+(cm<<1)>>1]=((eh^eg)&2081|e[(c[277220]|0)+((ef&ee)+(((ed&-2082)+ec|0)>>>1)<<1)>>1])&65535;g=a[1108909]|0;a[(c[277219]|0)+cm|0]=g;a[(c[277219]|0)+i|0]=g;d7=a[1108908]|0;d8=c[277219]|0}else{d7=dY;d8=dZ}}while(0);i=dM+6|0;do{if((d7&255)>(d[d8+i|0]|0)){g=a[dK+3|0]|0;cm=g&255;if(g<<24>>24==0){ei=d7;ej=d8;break}g=e[(c[277225]|0)+(cm<<1)>>1]|0;m=(a[(c[277215]|0)+i|0]&32)==0;if(m){j=c[277228]|0;ek=j;el=j&-2082}else{j=e[(c[277213]|0)+(i<<1)>>1]|0;ek=j;el=j&63454}if(m){em=c[277228]|0}else{em=e[(c[277213]|0)+(i<<1)>>1]|0}b[(c[277218]|0)+(i<<1)>>1]=((em^g)&2081|e[(c[277220]|0)+((g&2081&ek)+((el+(g&63454)|0)>>>1)<<1)>>1])&65535;g=(a[1108928]|0)==0;if(g){en=b[(c[277213]|0)+(dM+8<<1)>>1]&63454}else{en=0}m=(a[(c[277215]|0)+i|0]&32)==0;if(m){eo=c[277228]|0}else{eo=e[(c[277226]|0)+(cm<<1)>>1]|0}if(g){ep=b[(c[277213]|0)+(dM+8<<1)>>1]&2081}else{ep=0}if(m){eq=c[277228]|0}else{eq=e[(c[277226]|0)+(cm<<1)>>1]|0}if(g){er=e[(c[277213]|0)+(dM+8<<1)>>1]|0}else{er=0}if(m){es=c[277228]|0}else{es=e[(c[277226]|0)+(cm<<1)>>1]|0}cm=dM+7|0;b[(c[277218]|0)+(cm<<1)>>1]=((es^er)&2081|e[(c[277220]|0)+((eq&ep)+(((eo&-2082)+en|0)>>>1)<<1)>>1])&65535;m=a[1108909]|0;a[(c[277219]|0)+cm|0]=m;a[(c[277219]|0)+i|0]=m;ei=a[1108908]|0;ej=c[277219]|0}else{ei=d7;ej=d8}}while(0);i=dM+8|0;do{if((ei&255)>(d[ej+i|0]|0)){m=a[dK+4|0]|0;cm=m&255;if(m<<24>>24==0){et=ei;eu=ej;break}m=e[(c[277225]|0)+(cm<<1)>>1]|0;g=(a[(c[277215]|0)+i|0]&32)==0;if(g){j=c[277228]|0;ev=j;ew=j&-2082}else{j=e[(c[277213]|0)+(i<<1)>>1]|0;ev=j;ew=j&63454}if(g){ex=c[277228]|0}else{ex=e[(c[277213]|0)+(i<<1)>>1]|0}b[(c[277218]|0)+(i<<1)>>1]=((ex^m)&2081|e[(c[277220]|0)+((m&2081&ev)+((ew+(m&63454)|0)>>>1)<<1)>>1])&65535;m=(a[1108928]|0)==0;if(m){ey=b[(c[277213]|0)+(dM+10<<1)>>1]&63454}else{ey=0}g=(a[(c[277215]|0)+i|0]&32)==0;if(g){ez=c[277228]|0}else{ez=e[(c[277226]|0)+(cm<<1)>>1]|0}if(m){eA=b[(c[277213]|0)+(dM+10<<1)>>1]&2081}else{eA=0}if(g){eB=c[277228]|0}else{eB=e[(c[277226]|0)+(cm<<1)>>1]|0}if(m){eC=e[(c[277213]|0)+(dM+10<<1)>>1]|0}else{eC=0}if(g){eD=c[277228]|0}else{eD=e[(c[277226]|0)+(cm<<1)>>1]|0}cm=dM+9|0;b[(c[277218]|0)+(cm<<1)>>1]=((eD^eC)&2081|e[(c[277220]|0)+((eB&eA)+(((ez&-2082)+ey|0)>>>1)<<1)>>1])&65535;g=a[1108909]|0;a[(c[277219]|0)+cm|0]=g;a[(c[277219]|0)+i|0]=g;et=a[1108908]|0;eu=c[277219]|0}else{et=ei;eu=ej}}while(0);i=dM+10|0;do{if((et&255)>(d[eu+i|0]|0)){g=a[dK+5|0]|0;cm=g&255;if(g<<24>>24==0){eE=et;eF=eu;break}g=e[(c[277225]|0)+(cm<<1)>>1]|0;m=(a[(c[277215]|0)+i|0]&32)==0;if(m){j=c[277228]|0;eG=j;eH=j&-2082}else{j=e[(c[277213]|0)+(i<<1)>>1]|0;eG=j;eH=j&63454}if(m){eI=c[277228]|0}else{eI=e[(c[277213]|0)+(i<<1)>>1]|0}b[(c[277218]|0)+(i<<1)>>1]=((eI^g)&2081|e[(c[277220]|0)+((g&2081&eG)+((eH+(g&63454)|0)>>>1)<<1)>>1])&65535;g=(a[1108928]|0)==0;if(g){eJ=b[(c[277213]|0)+(dM+12<<1)>>1]&63454}else{eJ=0}m=(a[(c[277215]|0)+i|0]&32)==0;if(m){eK=c[277228]|0}else{eK=e[(c[277226]|0)+(cm<<1)>>1]|0}if(g){eL=b[(c[277213]|0)+(dM+12<<1)>>1]&2081}else{eL=0}if(m){eM=c[277228]|0}else{eM=e[(c[277226]|0)+(cm<<1)>>1]|0}if(g){eN=e[(c[277213]|0)+(dM+12<<1)>>1]|0}else{eN=0}if(m){eO=c[277228]|0}else{eO=e[(c[277226]|0)+(cm<<1)>>1]|0}cm=dM+11|0;b[(c[277218]|0)+(cm<<1)>>1]=((eO^eN)&2081|e[(c[277220]|0)+((eM&eL)+(((eK&-2082)+eJ|0)>>>1)<<1)>>1])&65535;m=a[1108909]|0;a[(c[277219]|0)+cm|0]=m;a[(c[277219]|0)+i|0]=m;eE=a[1108908]|0;eF=c[277219]|0}else{eE=et;eF=eu}}while(0);i=dM+12|0;do{if((eE&255)>(d[eF+i|0]|0)){m=a[dK+6|0]|0;cm=m&255;if(m<<24>>24==0){eP=eE;eQ=eF;break}m=e[(c[277225]|0)+(cm<<1)>>1]|0;g=(a[(c[277215]|0)+i|0]&32)==0;if(g){j=c[277228]|0;eR=j;eS=j&-2082}else{j=e[(c[277213]|0)+(i<<1)>>1]|0;eR=j;eS=j&63454}if(g){eT=c[277228]|0}else{eT=e[(c[277213]|0)+(i<<1)>>1]|0}b[(c[277218]|0)+(i<<1)>>1]=((eT^m)&2081|e[(c[277220]|0)+((m&2081&eR)+((eS+(m&63454)|0)>>>1)<<1)>>1])&65535;m=(a[1108928]|0)==0;if(m){eU=b[(c[277213]|0)+(dM+14<<1)>>1]&63454}else{eU=0}g=(a[(c[277215]|0)+i|0]&32)==0;if(g){eV=c[277228]|0}else{eV=e[(c[277226]|0)+(cm<<1)>>1]|0}if(m){eW=b[(c[277213]|0)+(dM+14<<1)>>1]&2081}else{eW=0}if(g){eX=c[277228]|0}else{eX=e[(c[277226]|0)+(cm<<1)>>1]|0}if(m){eY=e[(c[277213]|0)+(dM+14<<1)>>1]|0}else{eY=0}if(g){eZ=c[277228]|0}else{eZ=e[(c[277226]|0)+(cm<<1)>>1]|0}cm=dM+13|0;b[(c[277218]|0)+(cm<<1)>>1]=((eZ^eY)&2081|e[(c[277220]|0)+((eX&eW)+(((eV&-2082)+eU|0)>>>1)<<1)>>1])&65535;g=a[1108909]|0;a[(c[277219]|0)+cm|0]=g;a[(c[277219]|0)+i|0]=g;eP=a[1108908]|0;eQ=c[277219]|0}else{eP=eE;eQ=eF}}while(0);i=dM+14|0;do{if((eP&255)>(d[eQ+i|0]|0)){g=a[dK+7|0]|0;cm=g&255;if(g<<24>>24==0){break}g=e[(c[277225]|0)+(cm<<1)>>1]|0;m=(a[(c[277215]|0)+i|0]&32)==0;if(m){j=c[277228]|0;e_=j;e$=j&-2082}else{j=e[(c[277213]|0)+(i<<1)>>1]|0;e_=j;e$=j&63454}if(m){e0=c[277228]|0}else{e0=e[(c[277213]|0)+(i<<1)>>1]|0}b[(c[277218]|0)+(i<<1)>>1]=((e0^g)&2081|e[(c[277220]|0)+((g&2081&e_)+((e$+(g&63454)|0)>>>1)<<1)>>1])&65535;g=(a[1108928]|0)==0;if(g){e1=b[(c[277213]|0)+(dM+16<<1)>>1]&63454}else{e1=0}m=(a[(c[277215]|0)+i|0]&32)==0;if(m){e2=c[277228]|0}else{e2=e[(c[277226]|0)+(cm<<1)>>1]|0}if(g){e3=b[(c[277213]|0)+(dM+16<<1)>>1]&2081}else{e3=0}if(m){e4=c[277228]|0}else{e4=e[(c[277226]|0)+(cm<<1)>>1]|0}if(g){e5=e[(c[277213]|0)+(dM+16<<1)>>1]|0}else{e5=0}if(m){e6=c[277228]|0}else{e6=e[(c[277226]|0)+(cm<<1)>>1]|0}cm=dM+15|0;b[(c[277218]|0)+(cm<<1)>>1]=((e6^e5)&2081|e[(c[277220]|0)+((e4&e3)+(((e2&-2082)+e1|0)>>>1)<<1)>>1])&65535;m=a[1108909]|0;a[(c[277219]|0)+cm|0]=m;a[(c[277219]|0)+i|0]=m}}while(0);i=dL-1|0;if((i|0)<=0){break}dK=dK-16|0;dL=i;dM=(c[277223]|0)+dM|0}return}}function WB(f,g,h,i){f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0;j=f&1023;k=c[348606]|0;l=(j<<k)+(c[348604]|0)|0;if((f&256|0)==0){m=l}else{m=(c[348602]|0)+l|0}l=m&65535;m=l>>>(k>>>0);k=(f&16384|0)!=0;n=m<<6;do{if(k){o=(c[348622]|0)+n|0;if((a[(c[348618]|0)+m|0]|0)!=0){p=o;break}q=fi[c[348636]&63](o,l,j)|0;a[(c[348618]|0)+m|0]=q;p=o}else{o=(c[348624]|0)+n|0;if((a[(c[348620]|0)+m|0]|0)!=0){p=o;break}q=fi[c[348638]&63](o,l,j)|0;a[(c[348620]|0)+m|0]=q;p=o}}while(0);if((a[(c[348620]|0)+m|0]|0)==2){return}if((a[1394464]|0)==0){r=1106168+((f>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){m=d[1044485]|0;c[276541]=7080+(m<<5);j=0;do{l=j<<1&2;n=j&2;o=j&4;q=0;do{b[1125528+(j<<9)+(q<<1)>>1]=d[(q>>>1&28|n)+(7080+(m<<5))|0]<<6|d[(q<<2&28|l)+(7080+(m<<5))|0]<<11|d[(q>>>3&24|o)+(7080+(m<<5))|0];q=q+1|0;}while(q>>>0<256);j=j+1|0;}while(j>>>0<8);a[1106089]=0}r=1125528+((f>>>10&7)<<9)|0}c[277226]=r;c[277225]=(a[1108928]|0)!=0?1393712:r;if((f&49152|0)==0){if((i|0)<=0){return}r=p+((d[1394504]|0)+(h<<1))|0;j=i;m=g;while(1){q=a[1108908]|0;o=c[277219]|0;do{if((q&255)>(d[o+m|0]|0)){l=a[r]|0;if(l<<24>>24==0){s=q;t=o;break}n=e[(c[277225]|0)+((l&255)<<1)>>1]|0;l=c[277228]|0;u=(((n&63454)+(l&-2082)|0)>>>1)+(l&2081&n)|0;if((a[1108928]|0)==0){v=u&65535}else{v=(e[(c[277220]|0)+(u<<1)>>1]|(n^l)&2081)&65535}b[(c[277218]|0)+(m<<1)>>1]=v;if((a[1108928]|0)==0){l=e[(c[277213]|0)+(m+2<<1)>>1]|0;n=c[277228]|0;w=(((l&63454)+(n&128990)|0)>>>1)+(n&2081&l)|0}else{l=c[277228]|0;w=e[(c[277220]|0)+((l>>>1&2147482607)<<1)>>1]|l&2081}l=m+1|0;b[(c[277218]|0)+(l<<1)>>1]=w&65535;n=a[1108909]|0;a[(c[277219]|0)+l|0]=n;a[(c[277219]|0)+m|0]=n;s=a[1108908]|0;t=c[277219]|0}else{s=q;t=o}}while(0);o=m+2|0;do{if((s&255)>(d[t+o|0]|0)){q=a[r+1|0]|0;if(q<<24>>24==0){x=s;y=t;break}n=e[(c[277225]|0)+((q&255)<<1)>>1]|0;q=c[277228]|0;l=(((n&63454)+(q&-2082)|0)>>>1)+(q&2081&n)|0;if((a[1108928]|0)==0){z=l&65535}else{z=(e[(c[277220]|0)+(l<<1)>>1]|(n^q)&2081)&65535}b[(c[277218]|0)+(o<<1)>>1]=z;if((a[1108928]|0)==0){q=e[(c[277213]|0)+(m+4<<1)>>1]|0;n=c[277228]|0;A=(((q&63454)+(n&128990)|0)>>>1)+(n&2081&q)|0}else{q=c[277228]|0;A=e[(c[277220]|0)+((q>>>1&2147482607)<<1)>>1]|q&2081}q=m+3|0;b[(c[277218]|0)+(q<<1)>>1]=A&65535;n=a[1108909]|0;a[(c[277219]|0)+q|0]=n;a[(c[277219]|0)+o|0]=n;x=a[1108908]|0;y=c[277219]|0}else{x=s;y=t}}while(0);o=m+4|0;do{if((x&255)>(d[y+o|0]|0)){n=a[r+2|0]|0;if(n<<24>>24==0){B=x;C=y;break}q=e[(c[277225]|0)+((n&255)<<1)>>1]|0;n=c[277228]|0;l=(((q&63454)+(n&-2082)|0)>>>1)+(n&2081&q)|0;if((a[1108928]|0)==0){D=l&65535}else{D=(e[(c[277220]|0)+(l<<1)>>1]|(q^n)&2081)&65535}b[(c[277218]|0)+(o<<1)>>1]=D;if((a[1108928]|0)==0){n=e[(c[277213]|0)+(m+6<<1)>>1]|0;q=c[277228]|0;E=(((n&63454)+(q&128990)|0)>>>1)+(q&2081&n)|0}else{n=c[277228]|0;E=e[(c[277220]|0)+((n>>>1&2147482607)<<1)>>1]|n&2081}n=m+5|0;b[(c[277218]|0)+(n<<1)>>1]=E&65535;q=a[1108909]|0;a[(c[277219]|0)+n|0]=q;a[(c[277219]|0)+o|0]=q;B=a[1108908]|0;C=c[277219]|0}else{B=x;C=y}}while(0);o=m+6|0;do{if((B&255)>(d[C+o|0]|0)){q=a[r+3|0]|0;if(q<<24>>24==0){F=B;G=C;break}n=e[(c[277225]|0)+((q&255)<<1)>>1]|0;q=c[277228]|0;l=(((n&63454)+(q&-2082)|0)>>>1)+(q&2081&n)|0;if((a[1108928]|0)==0){H=l&65535}else{H=(e[(c[277220]|0)+(l<<1)>>1]|(n^q)&2081)&65535}b[(c[277218]|0)+(o<<1)>>1]=H;if((a[1108928]|0)==0){q=e[(c[277213]|0)+(m+8<<1)>>1]|0;n=c[277228]|0;I=(((q&63454)+(n&128990)|0)>>>1)+(n&2081&q)|0}else{q=c[277228]|0;I=e[(c[277220]|0)+((q>>>1&2147482607)<<1)>>1]|q&2081}q=m+7|0;b[(c[277218]|0)+(q<<1)>>1]=I&65535;n=a[1108909]|0;a[(c[277219]|0)+q|0]=n;a[(c[277219]|0)+o|0]=n;F=a[1108908]|0;G=c[277219]|0}else{F=B;G=C}}while(0);o=m+8|0;do{if((F&255)>(d[G+o|0]|0)){n=a[r+4|0]|0;if(n<<24>>24==0){J=F;K=G;break}q=e[(c[277225]|0)+((n&255)<<1)>>1]|0;n=c[277228]|0;l=(((q&63454)+(n&-2082)|0)>>>1)+(n&2081&q)|0;if((a[1108928]|0)==0){L=l&65535}else{L=(e[(c[277220]|0)+(l<<1)>>1]|(q^n)&2081)&65535}b[(c[277218]|0)+(o<<1)>>1]=L;if((a[1108928]|0)==0){n=e[(c[277213]|0)+(m+10<<1)>>1]|0;q=c[277228]|0;M=(((n&63454)+(q&128990)|0)>>>1)+(q&2081&n)|0}else{n=c[277228]|0;M=e[(c[277220]|0)+((n>>>1&2147482607)<<1)>>1]|n&2081}n=m+9|0;b[(c[277218]|0)+(n<<1)>>1]=M&65535;q=a[1108909]|0;a[(c[277219]|0)+n|0]=q;a[(c[277219]|0)+o|0]=q;J=a[1108908]|0;K=c[277219]|0}else{J=F;K=G}}while(0);o=m+10|0;do{if((J&255)>(d[K+o|0]|0)){q=a[r+5|0]|0;if(q<<24>>24==0){N=J;O=K;break}n=e[(c[277225]|0)+((q&255)<<1)>>1]|0;q=c[277228]|0;l=(((n&63454)+(q&-2082)|0)>>>1)+(q&2081&n)|0;if((a[1108928]|0)==0){P=l&65535}else{P=(e[(c[277220]|0)+(l<<1)>>1]|(n^q)&2081)&65535}b[(c[277218]|0)+(o<<1)>>1]=P;if((a[1108928]|0)==0){q=e[(c[277213]|0)+(m+12<<1)>>1]|0;n=c[277228]|0;Q=(((q&63454)+(n&128990)|0)>>>1)+(n&2081&q)|0}else{q=c[277228]|0;Q=e[(c[277220]|0)+((q>>>1&2147482607)<<1)>>1]|q&2081}q=m+11|0;b[(c[277218]|0)+(q<<1)>>1]=Q&65535;n=a[1108909]|0;a[(c[277219]|0)+q|0]=n;a[(c[277219]|0)+o|0]=n;N=a[1108908]|0;O=c[277219]|0}else{N=J;O=K}}while(0);o=m+12|0;do{if((N&255)>(d[O+o|0]|0)){n=a[r+6|0]|0;if(n<<24>>24==0){R=N;S=O;break}q=e[(c[277225]|0)+((n&255)<<1)>>1]|0;n=c[277228]|0;l=(((q&63454)+(n&-2082)|0)>>>1)+(n&2081&q)|0;if((a[1108928]|0)==0){T=l&65535}else{T=(e[(c[277220]|0)+(l<<1)>>1]|(q^n)&2081)&65535}b[(c[277218]|0)+(o<<1)>>1]=T;if((a[1108928]|0)==0){n=e[(c[277213]|0)+(m+14<<1)>>1]|0;q=c[277228]|0;U=(((n&63454)+(q&128990)|0)>>>1)+(q&2081&n)|0}else{n=c[277228]|0;U=e[(c[277220]|0)+((n>>>1&2147482607)<<1)>>1]|n&2081}n=m+13|0;b[(c[277218]|0)+(n<<1)>>1]=U&65535;q=a[1108909]|0;a[(c[277219]|0)+n|0]=q;a[(c[277219]|0)+o|0]=q;R=a[1108908]|0;S=c[277219]|0}else{R=N;S=O}}while(0);o=m+14|0;do{if((R&255)>(d[S+o|0]|0)){q=a[r+7|0]|0;if(q<<24>>24==0){break}n=e[(c[277225]|0)+((q&255)<<1)>>1]|0;q=c[277228]|0;l=(((n&63454)+(q&-2082)|0)>>>1)+(q&2081&n)|0;if((a[1108928]|0)==0){V=l&65535}else{V=(e[(c[277220]|0)+(l<<1)>>1]|(n^q)&2081)&65535}b[(c[277218]|0)+(o<<1)>>1]=V;if((a[1108928]|0)==0){q=e[(c[277213]|0)+(m+16<<1)>>1]|0;n=c[277228]|0;W=(((q&63454)+(n&128990)|0)>>>1)+(n&2081&q)|0}else{q=c[277228]|0;W=e[(c[277220]|0)+((q>>>1&2147482607)<<1)>>1]|q&2081}q=m+15|0;b[(c[277218]|0)+(q<<1)>>1]=W&65535;n=a[1108909]|0;a[(c[277219]|0)+q|0]=n;a[(c[277219]|0)+o|0]=n}}while(0);o=j-1|0;if((o|0)<=0){break}r=r+16|0;j=o;m=(c[277223]|0)+m|0}return}m=(d[1394504]|0)+(h<<1)|0;if((f&32768|0)==0){if((i|0)<=0){return}f=p+m|0;h=i;j=g;while(1){r=a[1108908]|0;W=c[277219]|0;do{if((r&255)>(d[W+j|0]|0)){V=a[f+7|0]|0;if(V<<24>>24==0){X=r;Y=W;break}S=e[(c[277225]|0)+((V&255)<<1)>>1]|0;V=c[277228]|0;R=(((S&63454)+(V&-2082)|0)>>>1)+(V&2081&S)|0;if((a[1108928]|0)==0){Z=R&65535}else{Z=(e[(c[277220]|0)+(R<<1)>>1]|(S^V)&2081)&65535}b[(c[277218]|0)+(j<<1)>>1]=Z;if((a[1108928]|0)==0){V=e[(c[277213]|0)+(j+2<<1)>>1]|0;S=c[277228]|0;_=(((V&63454)+(S&128990)|0)>>>1)+(S&2081&V)|0}else{V=c[277228]|0;_=e[(c[277220]|0)+((V>>>1&2147482607)<<1)>>1]|V&2081}V=j+1|0;b[(c[277218]|0)+(V<<1)>>1]=_&65535;S=a[1108909]|0;a[(c[277219]|0)+V|0]=S;a[(c[277219]|0)+j|0]=S;X=a[1108908]|0;Y=c[277219]|0}else{X=r;Y=W}}while(0);W=j+2|0;do{if((X&255)>(d[Y+W|0]|0)){r=a[f+6|0]|0;if(r<<24>>24==0){$=X;aa=Y;break}S=e[(c[277225]|0)+((r&255)<<1)>>1]|0;r=c[277228]|0;V=(((S&63454)+(r&-2082)|0)>>>1)+(r&2081&S)|0;if((a[1108928]|0)==0){ab=V&65535}else{ab=(e[(c[277220]|0)+(V<<1)>>1]|(S^r)&2081)&65535}b[(c[277218]|0)+(W<<1)>>1]=ab;if((a[1108928]|0)==0){r=e[(c[277213]|0)+(j+4<<1)>>1]|0;S=c[277228]|0;ac=(((r&63454)+(S&128990)|0)>>>1)+(S&2081&r)|0}else{r=c[277228]|0;ac=e[(c[277220]|0)+((r>>>1&2147482607)<<1)>>1]|r&2081}r=j+3|0;b[(c[277218]|0)+(r<<1)>>1]=ac&65535;S=a[1108909]|0;a[(c[277219]|0)+r|0]=S;a[(c[277219]|0)+W|0]=S;$=a[1108908]|0;aa=c[277219]|0}else{$=X;aa=Y}}while(0);W=j+4|0;do{if(($&255)>(d[aa+W|0]|0)){S=a[f+5|0]|0;if(S<<24>>24==0){ad=$;ae=aa;break}r=e[(c[277225]|0)+((S&255)<<1)>>1]|0;S=c[277228]|0;V=(((r&63454)+(S&-2082)|0)>>>1)+(S&2081&r)|0;if((a[1108928]|0)==0){af=V&65535}else{af=(e[(c[277220]|0)+(V<<1)>>1]|(r^S)&2081)&65535}b[(c[277218]|0)+(W<<1)>>1]=af;if((a[1108928]|0)==0){S=e[(c[277213]|0)+(j+6<<1)>>1]|0;r=c[277228]|0;ag=(((S&63454)+(r&128990)|0)>>>1)+(r&2081&S)|0}else{S=c[277228]|0;ag=e[(c[277220]|0)+((S>>>1&2147482607)<<1)>>1]|S&2081}S=j+5|0;b[(c[277218]|0)+(S<<1)>>1]=ag&65535;r=a[1108909]|0;a[(c[277219]|0)+S|0]=r;a[(c[277219]|0)+W|0]=r;ad=a[1108908]|0;ae=c[277219]|0}else{ad=$;ae=aa}}while(0);W=j+6|0;do{if((ad&255)>(d[ae+W|0]|0)){r=a[f+4|0]|0;if(r<<24>>24==0){ah=ad;ai=ae;break}S=e[(c[277225]|0)+((r&255)<<1)>>1]|0;r=c[277228]|0;V=(((S&63454)+(r&-2082)|0)>>>1)+(r&2081&S)|0;if((a[1108928]|0)==0){aj=V&65535}else{aj=(e[(c[277220]|0)+(V<<1)>>1]|(S^r)&2081)&65535}b[(c[277218]|0)+(W<<1)>>1]=aj;if((a[1108928]|0)==0){r=e[(c[277213]|0)+(j+8<<1)>>1]|0;S=c[277228]|0;ak=(((r&63454)+(S&128990)|0)>>>1)+(S&2081&r)|0}else{r=c[277228]|0;ak=e[(c[277220]|0)+((r>>>1&2147482607)<<1)>>1]|r&2081}r=j+7|0;b[(c[277218]|0)+(r<<1)>>1]=ak&65535;S=a[1108909]|0;a[(c[277219]|0)+r|0]=S;a[(c[277219]|0)+W|0]=S;ah=a[1108908]|0;ai=c[277219]|0}else{ah=ad;ai=ae}}while(0);W=j+8|0;do{if((ah&255)>(d[ai+W|0]|0)){S=a[f+3|0]|0;if(S<<24>>24==0){al=ah;am=ai;break}r=e[(c[277225]|0)+((S&255)<<1)>>1]|0;S=c[277228]|0;V=(((r&63454)+(S&-2082)|0)>>>1)+(S&2081&r)|0;if((a[1108928]|0)==0){an=V&65535}else{an=(e[(c[277220]|0)+(V<<1)>>1]|(r^S)&2081)&65535}b[(c[277218]|0)+(W<<1)>>1]=an;if((a[1108928]|0)==0){S=e[(c[277213]|0)+(j+10<<1)>>1]|0;r=c[277228]|0;ao=(((S&63454)+(r&128990)|0)>>>1)+(r&2081&S)|0}else{S=c[277228]|0;ao=e[(c[277220]|0)+((S>>>1&2147482607)<<1)>>1]|S&2081}S=j+9|0;b[(c[277218]|0)+(S<<1)>>1]=ao&65535;r=a[1108909]|0;a[(c[277219]|0)+S|0]=r;a[(c[277219]|0)+W|0]=r;al=a[1108908]|0;am=c[277219]|0}else{al=ah;am=ai}}while(0);W=j+10|0;do{if((al&255)>(d[am+W|0]|0)){r=a[f+2|0]|0;if(r<<24>>24==0){ap=al;aq=am;break}S=e[(c[277225]|0)+((r&255)<<1)>>1]|0;r=c[277228]|0;V=(((S&63454)+(r&-2082)|0)>>>1)+(r&2081&S)|0;if((a[1108928]|0)==0){ar=V&65535}else{ar=(e[(c[277220]|0)+(V<<1)>>1]|(S^r)&2081)&65535}b[(c[277218]|0)+(W<<1)>>1]=ar;if((a[1108928]|0)==0){r=e[(c[277213]|0)+(j+12<<1)>>1]|0;S=c[277228]|0;as=(((r&63454)+(S&128990)|0)>>>1)+(S&2081&r)|0}else{r=c[277228]|0;as=e[(c[277220]|0)+((r>>>1&2147482607)<<1)>>1]|r&2081}r=j+11|0;b[(c[277218]|0)+(r<<1)>>1]=as&65535;S=a[1108909]|0;a[(c[277219]|0)+r|0]=S;a[(c[277219]|0)+W|0]=S;ap=a[1108908]|0;aq=c[277219]|0}else{ap=al;aq=am}}while(0);W=j+12|0;do{if((ap&255)>(d[aq+W|0]|0)){S=a[f+1|0]|0;if(S<<24>>24==0){at=ap;au=aq;break}r=e[(c[277225]|0)+((S&255)<<1)>>1]|0;S=c[277228]|0;V=(((r&63454)+(S&-2082)|0)>>>1)+(S&2081&r)|0;if((a[1108928]|0)==0){av=V&65535}else{av=(e[(c[277220]|0)+(V<<1)>>1]|(r^S)&2081)&65535}b[(c[277218]|0)+(W<<1)>>1]=av;if((a[1108928]|0)==0){S=e[(c[277213]|0)+(j+14<<1)>>1]|0;r=c[277228]|0;aw=(((S&63454)+(r&128990)|0)>>>1)+(r&2081&S)|0}else{S=c[277228]|0;aw=e[(c[277220]|0)+((S>>>1&2147482607)<<1)>>1]|S&2081}S=j+13|0;b[(c[277218]|0)+(S<<1)>>1]=aw&65535;r=a[1108909]|0;a[(c[277219]|0)+S|0]=r;a[(c[277219]|0)+W|0]=r;at=a[1108908]|0;au=c[277219]|0}else{at=ap;au=aq}}while(0);W=j+14|0;do{if((at&255)>(d[au+W|0]|0)){r=a[f]|0;if(r<<24>>24==0){break}S=e[(c[277225]|0)+((r&255)<<1)>>1]|0;r=c[277228]|0;V=(((S&63454)+(r&-2082)|0)>>>1)+(r&2081&S)|0;if((a[1108928]|0)==0){ax=V&65535}else{ax=(e[(c[277220]|0)+(V<<1)>>1]|(S^r)&2081)&65535}b[(c[277218]|0)+(W<<1)>>1]=ax;if((a[1108928]|0)==0){r=e[(c[277213]|0)+(j+16<<1)>>1]|0;S=c[277228]|0;ay=(((r&63454)+(S&128990)|0)>>>1)+(S&2081&r)|0}else{r=c[277228]|0;ay=e[(c[277220]|0)+((r>>>1&2147482607)<<1)>>1]|r&2081}r=j+15|0;b[(c[277218]|0)+(r<<1)>>1]=ay&65535;S=a[1108909]|0;a[(c[277219]|0)+r|0]=S;a[(c[277219]|0)+W|0]=S}}while(0);W=h-1|0;if((W|0)<=0){break}f=f+16|0;h=W;j=(c[277223]|0)+j|0}return}j=p+(56-m)|0;m=(i|0)>0;if(k){if(m){az=j;aA=i;aB=g}else{return}while(1){k=a[1108908]|0;p=c[277219]|0;do{if((k&255)>(d[p+aB|0]|0)){h=a[az+7|0]|0;if(h<<24>>24==0){aC=k;aD=p;break}f=e[(c[277225]|0)+((h&255)<<1)>>1]|0;h=c[277228]|0;ay=(((f&63454)+(h&-2082)|0)>>>1)+(h&2081&f)|0;if((a[1108928]|0)==0){aE=ay&65535}else{aE=(e[(c[277220]|0)+(ay<<1)>>1]|(f^h)&2081)&65535}b[(c[277218]|0)+(aB<<1)>>1]=aE;if((a[1108928]|0)==0){h=e[(c[277213]|0)+(aB+2<<1)>>1]|0;f=c[277228]|0;aF=(((h&63454)+(f&128990)|0)>>>1)+(f&2081&h)|0}else{h=c[277228]|0;aF=e[(c[277220]|0)+((h>>>1&2147482607)<<1)>>1]|h&2081}h=aB+1|0;b[(c[277218]|0)+(h<<1)>>1]=aF&65535;f=a[1108909]|0;a[(c[277219]|0)+h|0]=f;a[(c[277219]|0)+aB|0]=f;aC=a[1108908]|0;aD=c[277219]|0}else{aC=k;aD=p}}while(0);p=aB+2|0;do{if((aC&255)>(d[aD+p|0]|0)){k=a[az+6|0]|0;if(k<<24>>24==0){aG=aC;aH=aD;break}f=e[(c[277225]|0)+((k&255)<<1)>>1]|0;k=c[277228]|0;h=(((f&63454)+(k&-2082)|0)>>>1)+(k&2081&f)|0;if((a[1108928]|0)==0){aI=h&65535}else{aI=(e[(c[277220]|0)+(h<<1)>>1]|(f^k)&2081)&65535}b[(c[277218]|0)+(p<<1)>>1]=aI;if((a[1108928]|0)==0){k=e[(c[277213]|0)+(aB+4<<1)>>1]|0;f=c[277228]|0;aJ=(((k&63454)+(f&128990)|0)>>>1)+(f&2081&k)|0}else{k=c[277228]|0;aJ=e[(c[277220]|0)+((k>>>1&2147482607)<<1)>>1]|k&2081}k=aB+3|0;b[(c[277218]|0)+(k<<1)>>1]=aJ&65535;f=a[1108909]|0;a[(c[277219]|0)+k|0]=f;a[(c[277219]|0)+p|0]=f;aG=a[1108908]|0;aH=c[277219]|0}else{aG=aC;aH=aD}}while(0);p=aB+4|0;do{if((aG&255)>(d[aH+p|0]|0)){f=a[az+5|0]|0;if(f<<24>>24==0){aK=aG;aL=aH;break}k=e[(c[277225]|0)+((f&255)<<1)>>1]|0;f=c[277228]|0;h=(((k&63454)+(f&-2082)|0)>>>1)+(f&2081&k)|0;if((a[1108928]|0)==0){aM=h&65535}else{aM=(e[(c[277220]|0)+(h<<1)>>1]|(k^f)&2081)&65535}b[(c[277218]|0)+(p<<1)>>1]=aM;if((a[1108928]|0)==0){f=e[(c[277213]|0)+(aB+6<<1)>>1]|0;k=c[277228]|0;aN=(((f&63454)+(k&128990)|0)>>>1)+(k&2081&f)|0}else{f=c[277228]|0;aN=e[(c[277220]|0)+((f>>>1&2147482607)<<1)>>1]|f&2081}f=aB+5|0;b[(c[277218]|0)+(f<<1)>>1]=aN&65535;k=a[1108909]|0;a[(c[277219]|0)+f|0]=k;a[(c[277219]|0)+p|0]=k;aK=a[1108908]|0;aL=c[277219]|0}else{aK=aG;aL=aH}}while(0);p=aB+6|0;do{if((aK&255)>(d[aL+p|0]|0)){k=a[az+4|0]|0;if(k<<24>>24==0){aO=aK;aP=aL;break}f=e[(c[277225]|0)+((k&255)<<1)>>1]|0;k=c[277228]|0;h=(((f&63454)+(k&-2082)|0)>>>1)+(k&2081&f)|0;if((a[1108928]|0)==0){aQ=h&65535}else{aQ=(e[(c[277220]|0)+(h<<1)>>1]|(f^k)&2081)&65535}b[(c[277218]|0)+(p<<1)>>1]=aQ;if((a[1108928]|0)==0){k=e[(c[277213]|0)+(aB+8<<1)>>1]|0;f=c[277228]|0;aR=(((k&63454)+(f&128990)|0)>>>1)+(f&2081&k)|0}else{k=c[277228]|0;aR=e[(c[277220]|0)+((k>>>1&2147482607)<<1)>>1]|k&2081}k=aB+7|0;b[(c[277218]|0)+(k<<1)>>1]=aR&65535;f=a[1108909]|0;a[(c[277219]|0)+k|0]=f;a[(c[277219]|0)+p|0]=f;aO=a[1108908]|0;aP=c[277219]|0}else{aO=aK;aP=aL}}while(0);p=aB+8|0;do{if((aO&255)>(d[aP+p|0]|0)){f=a[az+3|0]|0;if(f<<24>>24==0){aS=aO;aT=aP;break}k=e[(c[277225]|0)+((f&255)<<1)>>1]|0;f=c[277228]|0;h=(((k&63454)+(f&-2082)|0)>>>1)+(f&2081&k)|0;if((a[1108928]|0)==0){aU=h&65535}else{aU=(e[(c[277220]|0)+(h<<1)>>1]|(k^f)&2081)&65535}b[(c[277218]|0)+(p<<1)>>1]=aU;if((a[1108928]|0)==0){f=e[(c[277213]|0)+(aB+10<<1)>>1]|0;k=c[277228]|0;aV=(((f&63454)+(k&128990)|0)>>>1)+(k&2081&f)|0}else{f=c[277228]|0;aV=e[(c[277220]|0)+((f>>>1&2147482607)<<1)>>1]|f&2081}f=aB+9|0;b[(c[277218]|0)+(f<<1)>>1]=aV&65535;k=a[1108909]|0;a[(c[277219]|0)+f|0]=k;a[(c[277219]|0)+p|0]=k;aS=a[1108908]|0;aT=c[277219]|0}else{aS=aO;aT=aP}}while(0);p=aB+10|0;do{if((aS&255)>(d[aT+p|0]|0)){k=a[az+2|0]|0;if(k<<24>>24==0){aW=aS;aX=aT;break}f=e[(c[277225]|0)+((k&255)<<1)>>1]|0;k=c[277228]|0;h=(((f&63454)+(k&-2082)|0)>>>1)+(k&2081&f)|0;if((a[1108928]|0)==0){aY=h&65535}else{aY=(e[(c[277220]|0)+(h<<1)>>1]|(f^k)&2081)&65535}b[(c[277218]|0)+(p<<1)>>1]=aY;if((a[1108928]|0)==0){k=e[(c[277213]|0)+(aB+12<<1)>>1]|0;f=c[277228]|0;aZ=(((k&63454)+(f&128990)|0)>>>1)+(f&2081&k)|0}else{k=c[277228]|0;aZ=e[(c[277220]|0)+((k>>>1&2147482607)<<1)>>1]|k&2081}k=aB+11|0;b[(c[277218]|0)+(k<<1)>>1]=aZ&65535;f=a[1108909]|0;a[(c[277219]|0)+k|0]=f;a[(c[277219]|0)+p|0]=f;aW=a[1108908]|0;aX=c[277219]|0}else{aW=aS;aX=aT}}while(0);p=aB+12|0;do{if((aW&255)>(d[aX+p|0]|0)){f=a[az+1|0]|0;if(f<<24>>24==0){a_=aW;a$=aX;break}k=e[(c[277225]|0)+((f&255)<<1)>>1]|0;f=c[277228]|0;h=(((k&63454)+(f&-2082)|0)>>>1)+(f&2081&k)|0;if((a[1108928]|0)==0){a0=h&65535}else{a0=(e[(c[277220]|0)+(h<<1)>>1]|(k^f)&2081)&65535}b[(c[277218]|0)+(p<<1)>>1]=a0;if((a[1108928]|0)==0){f=e[(c[277213]|0)+(aB+14<<1)>>1]|0;k=c[277228]|0;a1=(((f&63454)+(k&128990)|0)>>>1)+(k&2081&f)|0}else{f=c[277228]|0;a1=e[(c[277220]|0)+((f>>>1&2147482607)<<1)>>1]|f&2081}f=aB+13|0;b[(c[277218]|0)+(f<<1)>>1]=a1&65535;k=a[1108909]|0;a[(c[277219]|0)+f|0]=k;a[(c[277219]|0)+p|0]=k;a_=a[1108908]|0;a$=c[277219]|0}else{a_=aW;a$=aX}}while(0);p=aB+14|0;do{if((a_&255)>(d[a$+p|0]|0)){k=a[az]|0;if(k<<24>>24==0){break}f=e[(c[277225]|0)+((k&255)<<1)>>1]|0;k=c[277228]|0;h=(((f&63454)+(k&-2082)|0)>>>1)+(k&2081&f)|0;if((a[1108928]|0)==0){a2=h&65535}else{a2=(e[(c[277220]|0)+(h<<1)>>1]|(f^k)&2081)&65535}b[(c[277218]|0)+(p<<1)>>1]=a2;if((a[1108928]|0)==0){k=e[(c[277213]|0)+(aB+16<<1)>>1]|0;f=c[277228]|0;a3=(((k&63454)+(f&128990)|0)>>>1)+(f&2081&k)|0}else{k=c[277228]|0;a3=e[(c[277220]|0)+((k>>>1&2147482607)<<1)>>1]|k&2081}k=aB+15|0;b[(c[277218]|0)+(k<<1)>>1]=a3&65535;f=a[1108909]|0;a[(c[277219]|0)+k|0]=f;a[(c[277219]|0)+p|0]=f}}while(0);p=aA-1|0;if((p|0)<=0){break}az=az-16|0;aA=p;aB=(c[277223]|0)+aB|0}return}else{if(m){a4=j;a5=i;a6=g}else{return}while(1){g=a[1108908]|0;i=c[277219]|0;do{if((g&255)>(d[i+a6|0]|0)){j=a[a4]|0;if(j<<24>>24==0){a7=g;a8=i;break}m=e[(c[277225]|0)+((j&255)<<1)>>1]|0;j=c[277228]|0;aB=(((m&63454)+(j&-2082)|0)>>>1)+(j&2081&m)|0;if((a[1108928]|0)==0){a9=aB&65535}else{a9=(e[(c[277220]|0)+(aB<<1)>>1]|(m^j)&2081)&65535}b[(c[277218]|0)+(a6<<1)>>1]=a9;if((a[1108928]|0)==0){j=e[(c[277213]|0)+(a6+2<<1)>>1]|0;m=c[277228]|0;ba=(((j&63454)+(m&128990)|0)>>>1)+(m&2081&j)|0}else{j=c[277228]|0;ba=e[(c[277220]|0)+((j>>>1&2147482607)<<1)>>1]|j&2081}j=a6+1|0;b[(c[277218]|0)+(j<<1)>>1]=ba&65535;m=a[1108909]|0;a[(c[277219]|0)+j|0]=m;a[(c[277219]|0)+a6|0]=m;a7=a[1108908]|0;a8=c[277219]|0}else{a7=g;a8=i}}while(0);i=a6+2|0;do{if((a7&255)>(d[a8+i|0]|0)){g=a[a4+1|0]|0;if(g<<24>>24==0){bb=a7;bc=a8;break}m=e[(c[277225]|0)+((g&255)<<1)>>1]|0;g=c[277228]|0;j=(((m&63454)+(g&-2082)|0)>>>1)+(g&2081&m)|0;if((a[1108928]|0)==0){bd=j&65535}else{bd=(e[(c[277220]|0)+(j<<1)>>1]|(m^g)&2081)&65535}b[(c[277218]|0)+(i<<1)>>1]=bd;if((a[1108928]|0)==0){g=e[(c[277213]|0)+(a6+4<<1)>>1]|0;m=c[277228]|0;be=(((g&63454)+(m&128990)|0)>>>1)+(m&2081&g)|0}else{g=c[277228]|0;be=e[(c[277220]|0)+((g>>>1&2147482607)<<1)>>1]|g&2081}g=a6+3|0;b[(c[277218]|0)+(g<<1)>>1]=be&65535;m=a[1108909]|0;a[(c[277219]|0)+g|0]=m;a[(c[277219]|0)+i|0]=m;bb=a[1108908]|0;bc=c[277219]|0}else{bb=a7;bc=a8}}while(0);i=a6+4|0;do{if((bb&255)>(d[bc+i|0]|0)){m=a[a4+2|0]|0;if(m<<24>>24==0){bf=bb;bg=bc;break}g=e[(c[277225]|0)+((m&255)<<1)>>1]|0;m=c[277228]|0;j=(((g&63454)+(m&-2082)|0)>>>1)+(m&2081&g)|0;if((a[1108928]|0)==0){bh=j&65535}else{bh=(e[(c[277220]|0)+(j<<1)>>1]|(g^m)&2081)&65535}b[(c[277218]|0)+(i<<1)>>1]=bh;if((a[1108928]|0)==0){m=e[(c[277213]|0)+(a6+6<<1)>>1]|0;g=c[277228]|0;bi=(((m&63454)+(g&128990)|0)>>>1)+(g&2081&m)|0}else{m=c[277228]|0;bi=e[(c[277220]|0)+((m>>>1&2147482607)<<1)>>1]|m&2081}m=a6+5|0;b[(c[277218]|0)+(m<<1)>>1]=bi&65535;g=a[1108909]|0;a[(c[277219]|0)+m|0]=g;a[(c[277219]|0)+i|0]=g;bf=a[1108908]|0;bg=c[277219]|0}else{bf=bb;bg=bc}}while(0);i=a6+6|0;do{if((bf&255)>(d[bg+i|0]|0)){g=a[a4+3|0]|0;if(g<<24>>24==0){bj=bf;bk=bg;break}m=e[(c[277225]|0)+((g&255)<<1)>>1]|0;g=c[277228]|0;j=(((m&63454)+(g&-2082)|0)>>>1)+(g&2081&m)|0;if((a[1108928]|0)==0){bl=j&65535}else{bl=(e[(c[277220]|0)+(j<<1)>>1]|(m^g)&2081)&65535}b[(c[277218]|0)+(i<<1)>>1]=bl;if((a[1108928]|0)==0){g=e[(c[277213]|0)+(a6+8<<1)>>1]|0;m=c[277228]|0;bm=(((g&63454)+(m&128990)|0)>>>1)+(m&2081&g)|0}else{g=c[277228]|0;bm=e[(c[277220]|0)+((g>>>1&2147482607)<<1)>>1]|g&2081}g=a6+7|0;b[(c[277218]|0)+(g<<1)>>1]=bm&65535;m=a[1108909]|0;a[(c[277219]|0)+g|0]=m;a[(c[277219]|0)+i|0]=m;bj=a[1108908]|0;bk=c[277219]|0}else{bj=bf;bk=bg}}while(0);i=a6+8|0;do{if((bj&255)>(d[bk+i|0]|0)){m=a[a4+4|0]|0;if(m<<24>>24==0){bn=bj;bo=bk;break}g=e[(c[277225]|0)+((m&255)<<1)>>1]|0;m=c[277228]|0;j=(((g&63454)+(m&-2082)|0)>>>1)+(m&2081&g)|0;if((a[1108928]|0)==0){bp=j&65535}else{bp=(e[(c[277220]|0)+(j<<1)>>1]|(g^m)&2081)&65535}b[(c[277218]|0)+(i<<1)>>1]=bp;if((a[1108928]|0)==0){m=e[(c[277213]|0)+(a6+10<<1)>>1]|0;g=c[277228]|0;bq=(((m&63454)+(g&128990)|0)>>>1)+(g&2081&m)|0}else{m=c[277228]|0;bq=e[(c[277220]|0)+((m>>>1&2147482607)<<1)>>1]|m&2081}m=a6+9|0;b[(c[277218]|0)+(m<<1)>>1]=bq&65535;g=a[1108909]|0;a[(c[277219]|0)+m|0]=g;a[(c[277219]|0)+i|0]=g;bn=a[1108908]|0;bo=c[277219]|0}else{bn=bj;bo=bk}}while(0);i=a6+10|0;do{if((bn&255)>(d[bo+i|0]|0)){g=a[a4+5|0]|0;if(g<<24>>24==0){br=bn;bs=bo;break}m=e[(c[277225]|0)+((g&255)<<1)>>1]|0;g=c[277228]|0;j=(((m&63454)+(g&-2082)|0)>>>1)+(g&2081&m)|0;if((a[1108928]|0)==0){bt=j&65535}else{bt=(e[(c[277220]|0)+(j<<1)>>1]|(m^g)&2081)&65535}b[(c[277218]|0)+(i<<1)>>1]=bt;if((a[1108928]|0)==0){g=e[(c[277213]|0)+(a6+12<<1)>>1]|0;m=c[277228]|0;bu=(((g&63454)+(m&128990)|0)>>>1)+(m&2081&g)|0}else{g=c[277228]|0;bu=e[(c[277220]|0)+((g>>>1&2147482607)<<1)>>1]|g&2081}g=a6+11|0;b[(c[277218]|0)+(g<<1)>>1]=bu&65535;m=a[1108909]|0;a[(c[277219]|0)+g|0]=m;a[(c[277219]|0)+i|0]=m;br=a[1108908]|0;bs=c[277219]|0}else{br=bn;bs=bo}}while(0);i=a6+12|0;do{if((br&255)>(d[bs+i|0]|0)){m=a[a4+6|0]|0;if(m<<24>>24==0){bv=br;bw=bs;break}g=e[(c[277225]|0)+((m&255)<<1)>>1]|0;m=c[277228]|0;j=(((g&63454)+(m&-2082)|0)>>>1)+(m&2081&g)|0;if((a[1108928]|0)==0){bx=j&65535}else{bx=(e[(c[277220]|0)+(j<<1)>>1]|(g^m)&2081)&65535}b[(c[277218]|0)+(i<<1)>>1]=bx;if((a[1108928]|0)==0){m=e[(c[277213]|0)+(a6+14<<1)>>1]|0;g=c[277228]|0;by=(((m&63454)+(g&128990)|0)>>>1)+(g&2081&m)|0}else{m=c[277228]|0;by=e[(c[277220]|0)+((m>>>1&2147482607)<<1)>>1]|m&2081}m=a6+13|0;b[(c[277218]|0)+(m<<1)>>1]=by&65535;g=a[1108909]|0;a[(c[277219]|0)+m|0]=g;a[(c[277219]|0)+i|0]=g;bv=a[1108908]|0;bw=c[277219]|0}else{bv=br;bw=bs}}while(0);i=a6+14|0;do{if((bv&255)>(d[bw+i|0]|0)){g=a[a4+7|0]|0;if(g<<24>>24==0){break}m=e[(c[277225]|0)+((g&255)<<1)>>1]|0;g=c[277228]|0;j=(((m&63454)+(g&-2082)|0)>>>1)+(g&2081&m)|0;if((a[1108928]|0)==0){bz=j&65535}else{bz=(e[(c[277220]|0)+(j<<1)>>1]|(m^g)&2081)&65535}b[(c[277218]|0)+(i<<1)>>1]=bz;if((a[1108928]|0)==0){g=e[(c[277213]|0)+(a6+16<<1)>>1]|0;m=c[277228]|0;bA=(((g&63454)+(m&128990)|0)>>>1)+(m&2081&g)|0}else{g=c[277228]|0;bA=e[(c[277220]|0)+((g>>>1&2147482607)<<1)>>1]|g&2081}g=a6+15|0;b[(c[277218]|0)+(g<<1)>>1]=bA&65535;m=a[1108909]|0;a[(c[277219]|0)+g|0]=m;a[(c[277219]|0)+i|0]=m}}while(0);i=a5-1|0;if((i|0)<=0){break}a4=a4-16|0;a5=i;a6=(c[277223]|0)+a6|0}return}}function WC(f,g,h,i){f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0,cf=0,cg=0,ch=0,ci=0,cj=0,ck=0,cl=0,cm=0,cn=0,co=0,cp=0,cq=0,cr=0,cs=0,ct=0,cu=0,cv=0,cw=0,cx=0,cy=0,cz=0,cA=0,cB=0,cC=0,cD=0,cE=0,cF=0,cG=0,cH=0,cI=0,cJ=0,cK=0,cL=0,cM=0,cN=0,cO=0,cP=0,cQ=0,cR=0,cS=0,cT=0,cU=0,cV=0,cW=0,cX=0,cY=0,cZ=0,c_=0,c$=0,c0=0,c1=0,c2=0,c3=0,c4=0,c5=0,c6=0,c7=0,c8=0,c9=0,da=0,db=0,dc=0,dd=0,de=0,df=0,dg=0,dh=0,di=0,dj=0,dk=0,dl=0,dm=0,dn=0,dp=0,dq=0,dr=0,ds=0,dt=0,du=0,dv=0,dw=0,dx=0,dy=0,dz=0,dA=0,dB=0,dC=0,dD=0,dE=0,dF=0,dG=0,dH=0,dI=0,dJ=0,dK=0,dL=0,dM=0,dN=0,dO=0,dP=0,dQ=0,dR=0,dS=0,dT=0,dU=0,dV=0,dW=0,dX=0,dY=0,dZ=0,d_=0,d$=0,d0=0,d1=0,d2=0,d3=0,d4=0,d5=0,d6=0,d7=0;j=f&1023;k=c[348606]|0;l=(j<<k)+(c[348604]|0)|0;if((f&256|0)==0){m=l}else{m=(c[348602]|0)+l|0}l=m&65535;m=l>>>(k>>>0);k=(f&16384|0)!=0;n=m<<6;do{if(k){o=(c[348622]|0)+n|0;if((a[(c[348618]|0)+m|0]|0)!=0){p=o;break}q=fi[c[348636]&63](o,l,j)|0;a[(c[348618]|0)+m|0]=q;p=o}else{o=(c[348624]|0)+n|0;if((a[(c[348620]|0)+m|0]|0)!=0){p=o;break}q=fi[c[348638]&63](o,l,j)|0;a[(c[348620]|0)+m|0]=q;p=o}}while(0);if((a[(c[348620]|0)+m|0]|0)==2){return}if((a[1394464]|0)==0){r=1106168+((f>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){m=d[1044485]|0;c[276541]=7080+(m<<5);j=0;do{l=j<<1&2;n=j&2;o=j&4;q=0;do{b[1125528+(j<<9)+(q<<1)>>1]=d[(q>>>1&28|n)+(7080+(m<<5))|0]<<6|d[(q<<2&28|l)+(7080+(m<<5))|0]<<11|d[(q>>>3&24|o)+(7080+(m<<5))|0];q=q+1|0;}while(q>>>0<256);j=j+1|0;}while(j>>>0<8);a[1106089]=0}r=1125528+((f>>>10&7)<<9)|0}c[277226]=r;c[277225]=(a[1108928]|0)!=0?1393712:r;if((f&49152|0)==0){if((i|0)<=0){return}r=p+((d[1394504]|0)+(h<<1))|0;j=i;m=g;while(1){q=a[1108908]|0;o=c[277219]|0;do{if((q&255)>(d[o+m|0]|0)){l=a[r]|0;n=l&255;if(l<<24>>24==0){s=q;t=o;break}do{if((a[1108928]|0)==0){l=b[(c[277225]|0)+(n<<1)>>1]|0;u=l&65535;v=u&63454;if((a[(c[277215]|0)+m|0]&32)==0){w=c[277228]|0;x=(e[(c[277220]|0)+((((w&-2082)+v|0)>>>1)+(u&2081&w)<<1)>>1]|(w^u)&2081)&65535;break}else{u=b[(c[277213]|0)+(m<<1)>>1]|0;x=(((u&63454)+v|0)>>>1)+(u&l&2081)&65535;break}}else{l=e[(c[277225]|0)+(n<<1)>>1]|0;u=(a[(c[277215]|0)+m|0]&32)==0;if(u){v=c[277228]|0;y=v;z=v&-2082}else{v=e[(c[277213]|0)+(m<<1)>>1]|0;y=v;z=v&63454}if(u){A=c[277228]|0}else{A=e[(c[277213]|0)+(m<<1)>>1]|0}x=((A^l)&2081|e[(c[277220]|0)+((l&2081&y)+((z+(l&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(m<<1)>>1]=x;l=(a[(c[277215]|0)+m|0]&32)==0;do{if((a[1108928]|0)==0){u=e[(c[277213]|0)+(m+2<<1)>>1]|0;v=u&63454;if(l){w=c[277228]|0;B=(e[(c[277220]|0)+((((w&-2082)+v|0)>>>1)+(u&2081&w)<<1)>>1]|(w^u)&2081)&65535;break}else{w=e[(c[277226]|0)+(n<<1)>>1]|0;B=(((w&63454)+v|0)>>>1)+(u&2081&w)&65535;break}}else{if(l){w=c[277228]|0;C=w;D=(c[277220]|0)+((w>>>1&2147482607)<<1)|0}else{w=e[(c[277226]|0)+(n<<1)>>1]|0;C=w;D=(c[277220]|0)+((w>>>1&31727)<<1)|0}B=(e[D>>1]|C&2081)&65535}}while(0);n=m+1|0;b[(c[277218]|0)+(n<<1)>>1]=B;l=a[1108909]|0;a[(c[277219]|0)+n|0]=l;a[(c[277219]|0)+m|0]=l;s=a[1108908]|0;t=c[277219]|0}else{s=q;t=o}}while(0);o=m+2|0;do{if((s&255)>(d[t+o|0]|0)){q=a[r+1|0]|0;l=q&255;if(q<<24>>24==0){E=s;F=t;break}do{if((a[1108928]|0)==0){q=b[(c[277225]|0)+(l<<1)>>1]|0;n=q&65535;w=n&63454;if((a[(c[277215]|0)+o|0]&32)==0){u=c[277228]|0;G=(e[(c[277220]|0)+((((u&-2082)+w|0)>>>1)+(n&2081&u)<<1)>>1]|(u^n)&2081)&65535;break}else{n=b[(c[277213]|0)+(o<<1)>>1]|0;G=(((n&63454)+w|0)>>>1)+(n&q&2081)&65535;break}}else{q=e[(c[277225]|0)+(l<<1)>>1]|0;n=(a[(c[277215]|0)+o|0]&32)==0;if(n){w=c[277228]|0;H=w;I=w&-2082}else{w=e[(c[277213]|0)+(o<<1)>>1]|0;H=w;I=w&63454}if(n){J=c[277228]|0}else{J=e[(c[277213]|0)+(o<<1)>>1]|0}G=((J^q)&2081|e[(c[277220]|0)+((q&2081&H)+((I+(q&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=G;q=(a[(c[277215]|0)+o|0]&32)==0;do{if((a[1108928]|0)==0){n=e[(c[277213]|0)+(m+4<<1)>>1]|0;w=n&63454;if(q){u=c[277228]|0;K=(e[(c[277220]|0)+((((u&-2082)+w|0)>>>1)+(n&2081&u)<<1)>>1]|(u^n)&2081)&65535;break}else{u=e[(c[277226]|0)+(l<<1)>>1]|0;K=(((u&63454)+w|0)>>>1)+(n&2081&u)&65535;break}}else{if(q){u=c[277228]|0;L=u;M=(c[277220]|0)+((u>>>1&2147482607)<<1)|0}else{u=e[(c[277226]|0)+(l<<1)>>1]|0;L=u;M=(c[277220]|0)+((u>>>1&31727)<<1)|0}K=(e[M>>1]|L&2081)&65535}}while(0);l=m+3|0;b[(c[277218]|0)+(l<<1)>>1]=K;q=a[1108909]|0;a[(c[277219]|0)+l|0]=q;a[(c[277219]|0)+o|0]=q;E=a[1108908]|0;F=c[277219]|0}else{E=s;F=t}}while(0);o=m+4|0;do{if((E&255)>(d[F+o|0]|0)){q=a[r+2|0]|0;l=q&255;if(q<<24>>24==0){N=E;O=F;break}do{if((a[1108928]|0)==0){q=b[(c[277225]|0)+(l<<1)>>1]|0;u=q&65535;n=u&63454;if((a[(c[277215]|0)+o|0]&32)==0){w=c[277228]|0;P=(e[(c[277220]|0)+((((w&-2082)+n|0)>>>1)+(u&2081&w)<<1)>>1]|(w^u)&2081)&65535;break}else{u=b[(c[277213]|0)+(o<<1)>>1]|0;P=(((u&63454)+n|0)>>>1)+(u&q&2081)&65535;break}}else{q=e[(c[277225]|0)+(l<<1)>>1]|0;u=(a[(c[277215]|0)+o|0]&32)==0;if(u){n=c[277228]|0;Q=n;R=n&-2082}else{n=e[(c[277213]|0)+(o<<1)>>1]|0;Q=n;R=n&63454}if(u){S=c[277228]|0}else{S=e[(c[277213]|0)+(o<<1)>>1]|0}P=((S^q)&2081|e[(c[277220]|0)+((q&2081&Q)+((R+(q&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=P;q=(a[(c[277215]|0)+o|0]&32)==0;do{if((a[1108928]|0)==0){u=e[(c[277213]|0)+(m+6<<1)>>1]|0;n=u&63454;if(q){w=c[277228]|0;T=(e[(c[277220]|0)+((((w&-2082)+n|0)>>>1)+(u&2081&w)<<1)>>1]|(w^u)&2081)&65535;break}else{w=e[(c[277226]|0)+(l<<1)>>1]|0;T=(((w&63454)+n|0)>>>1)+(u&2081&w)&65535;break}}else{if(q){w=c[277228]|0;U=w;V=(c[277220]|0)+((w>>>1&2147482607)<<1)|0}else{w=e[(c[277226]|0)+(l<<1)>>1]|0;U=w;V=(c[277220]|0)+((w>>>1&31727)<<1)|0}T=(e[V>>1]|U&2081)&65535}}while(0);l=m+5|0;b[(c[277218]|0)+(l<<1)>>1]=T;q=a[1108909]|0;a[(c[277219]|0)+l|0]=q;a[(c[277219]|0)+o|0]=q;N=a[1108908]|0;O=c[277219]|0}else{N=E;O=F}}while(0);o=m+6|0;do{if((N&255)>(d[O+o|0]|0)){q=a[r+3|0]|0;l=q&255;if(q<<24>>24==0){W=N;X=O;break}do{if((a[1108928]|0)==0){q=b[(c[277225]|0)+(l<<1)>>1]|0;w=q&65535;u=w&63454;if((a[(c[277215]|0)+o|0]&32)==0){n=c[277228]|0;Y=(e[(c[277220]|0)+((((n&-2082)+u|0)>>>1)+(w&2081&n)<<1)>>1]|(n^w)&2081)&65535;break}else{w=b[(c[277213]|0)+(o<<1)>>1]|0;Y=(((w&63454)+u|0)>>>1)+(w&q&2081)&65535;break}}else{q=e[(c[277225]|0)+(l<<1)>>1]|0;w=(a[(c[277215]|0)+o|0]&32)==0;if(w){u=c[277228]|0;Z=u;_=u&-2082}else{u=e[(c[277213]|0)+(o<<1)>>1]|0;Z=u;_=u&63454}if(w){$=c[277228]|0}else{$=e[(c[277213]|0)+(o<<1)>>1]|0}Y=(($^q)&2081|e[(c[277220]|0)+((q&2081&Z)+((_+(q&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=Y;q=(a[(c[277215]|0)+o|0]&32)==0;do{if((a[1108928]|0)==0){w=e[(c[277213]|0)+(m+8<<1)>>1]|0;u=w&63454;if(q){n=c[277228]|0;aa=(e[(c[277220]|0)+((((n&-2082)+u|0)>>>1)+(w&2081&n)<<1)>>1]|(n^w)&2081)&65535;break}else{n=e[(c[277226]|0)+(l<<1)>>1]|0;aa=(((n&63454)+u|0)>>>1)+(w&2081&n)&65535;break}}else{if(q){n=c[277228]|0;ab=n;ac=(c[277220]|0)+((n>>>1&2147482607)<<1)|0}else{n=e[(c[277226]|0)+(l<<1)>>1]|0;ab=n;ac=(c[277220]|0)+((n>>>1&31727)<<1)|0}aa=(e[ac>>1]|ab&2081)&65535}}while(0);l=m+7|0;b[(c[277218]|0)+(l<<1)>>1]=aa;q=a[1108909]|0;a[(c[277219]|0)+l|0]=q;a[(c[277219]|0)+o|0]=q;W=a[1108908]|0;X=c[277219]|0}else{W=N;X=O}}while(0);o=m+8|0;do{if((W&255)>(d[X+o|0]|0)){q=a[r+4|0]|0;l=q&255;if(q<<24>>24==0){ad=W;ae=X;break}do{if((a[1108928]|0)==0){q=b[(c[277225]|0)+(l<<1)>>1]|0;n=q&65535;w=n&63454;if((a[(c[277215]|0)+o|0]&32)==0){u=c[277228]|0;af=(e[(c[277220]|0)+((((u&-2082)+w|0)>>>1)+(n&2081&u)<<1)>>1]|(u^n)&2081)&65535;break}else{n=b[(c[277213]|0)+(o<<1)>>1]|0;af=(((n&63454)+w|0)>>>1)+(n&q&2081)&65535;break}}else{q=e[(c[277225]|0)+(l<<1)>>1]|0;n=(a[(c[277215]|0)+o|0]&32)==0;if(n){w=c[277228]|0;ag=w;ah=w&-2082}else{w=e[(c[277213]|0)+(o<<1)>>1]|0;ag=w;ah=w&63454}if(n){ai=c[277228]|0}else{ai=e[(c[277213]|0)+(o<<1)>>1]|0}af=((ai^q)&2081|e[(c[277220]|0)+((q&2081&ag)+((ah+(q&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=af;q=(a[(c[277215]|0)+o|0]&32)==0;do{if((a[1108928]|0)==0){n=e[(c[277213]|0)+(m+10<<1)>>1]|0;w=n&63454;if(q){u=c[277228]|0;aj=(e[(c[277220]|0)+((((u&-2082)+w|0)>>>1)+(n&2081&u)<<1)>>1]|(u^n)&2081)&65535;break}else{u=e[(c[277226]|0)+(l<<1)>>1]|0;aj=(((u&63454)+w|0)>>>1)+(n&2081&u)&65535;break}}else{if(q){u=c[277228]|0;ak=u;al=(c[277220]|0)+((u>>>1&2147482607)<<1)|0}else{u=e[(c[277226]|0)+(l<<1)>>1]|0;ak=u;al=(c[277220]|0)+((u>>>1&31727)<<1)|0}aj=(e[al>>1]|ak&2081)&65535}}while(0);l=m+9|0;b[(c[277218]|0)+(l<<1)>>1]=aj;q=a[1108909]|0;a[(c[277219]|0)+l|0]=q;a[(c[277219]|0)+o|0]=q;ad=a[1108908]|0;ae=c[277219]|0}else{ad=W;ae=X}}while(0);o=m+10|0;do{if((ad&255)>(d[ae+o|0]|0)){q=a[r+5|0]|0;l=q&255;if(q<<24>>24==0){am=ad;an=ae;break}do{if((a[1108928]|0)==0){q=b[(c[277225]|0)+(l<<1)>>1]|0;u=q&65535;n=u&63454;if((a[(c[277215]|0)+o|0]&32)==0){w=c[277228]|0;ao=(e[(c[277220]|0)+((((w&-2082)+n|0)>>>1)+(u&2081&w)<<1)>>1]|(w^u)&2081)&65535;break}else{u=b[(c[277213]|0)+(o<<1)>>1]|0;ao=(((u&63454)+n|0)>>>1)+(u&q&2081)&65535;break}}else{q=e[(c[277225]|0)+(l<<1)>>1]|0;u=(a[(c[277215]|0)+o|0]&32)==0;if(u){n=c[277228]|0;ap=n;aq=n&-2082}else{n=e[(c[277213]|0)+(o<<1)>>1]|0;ap=n;aq=n&63454}if(u){ar=c[277228]|0}else{ar=e[(c[277213]|0)+(o<<1)>>1]|0}ao=((ar^q)&2081|e[(c[277220]|0)+((q&2081&ap)+((aq+(q&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=ao;q=(a[(c[277215]|0)+o|0]&32)==0;do{if((a[1108928]|0)==0){u=e[(c[277213]|0)+(m+12<<1)>>1]|0;n=u&63454;if(q){w=c[277228]|0;as=(e[(c[277220]|0)+((((w&-2082)+n|0)>>>1)+(u&2081&w)<<1)>>1]|(w^u)&2081)&65535;break}else{w=e[(c[277226]|0)+(l<<1)>>1]|0;as=(((w&63454)+n|0)>>>1)+(u&2081&w)&65535;break}}else{if(q){w=c[277228]|0;at=w;au=(c[277220]|0)+((w>>>1&2147482607)<<1)|0}else{w=e[(c[277226]|0)+(l<<1)>>1]|0;at=w;au=(c[277220]|0)+((w>>>1&31727)<<1)|0}as=(e[au>>1]|at&2081)&65535}}while(0);l=m+11|0;b[(c[277218]|0)+(l<<1)>>1]=as;q=a[1108909]|0;a[(c[277219]|0)+l|0]=q;a[(c[277219]|0)+o|0]=q;am=a[1108908]|0;an=c[277219]|0}else{am=ad;an=ae}}while(0);o=m+12|0;do{if((am&255)>(d[an+o|0]|0)){q=a[r+6|0]|0;l=q&255;if(q<<24>>24==0){av=am;aw=an;break}do{if((a[1108928]|0)==0){q=b[(c[277225]|0)+(l<<1)>>1]|0;w=q&65535;u=w&63454;if((a[(c[277215]|0)+o|0]&32)==0){n=c[277228]|0;ax=(e[(c[277220]|0)+((((n&-2082)+u|0)>>>1)+(w&2081&n)<<1)>>1]|(n^w)&2081)&65535;break}else{w=b[(c[277213]|0)+(o<<1)>>1]|0;ax=(((w&63454)+u|0)>>>1)+(w&q&2081)&65535;break}}else{q=e[(c[277225]|0)+(l<<1)>>1]|0;w=(a[(c[277215]|0)+o|0]&32)==0;if(w){u=c[277228]|0;ay=u;az=u&-2082}else{u=e[(c[277213]|0)+(o<<1)>>1]|0;ay=u;az=u&63454}if(w){aA=c[277228]|0}else{aA=e[(c[277213]|0)+(o<<1)>>1]|0}ax=((aA^q)&2081|e[(c[277220]|0)+((q&2081&ay)+((az+(q&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=ax;q=(a[(c[277215]|0)+o|0]&32)==0;do{if((a[1108928]|0)==0){w=e[(c[277213]|0)+(m+14<<1)>>1]|0;u=w&63454;if(q){n=c[277228]|0;aB=(e[(c[277220]|0)+((((n&-2082)+u|0)>>>1)+(w&2081&n)<<1)>>1]|(n^w)&2081)&65535;break}else{n=e[(c[277226]|0)+(l<<1)>>1]|0;aB=(((n&63454)+u|0)>>>1)+(w&2081&n)&65535;break}}else{if(q){n=c[277228]|0;aC=n;aD=(c[277220]|0)+((n>>>1&2147482607)<<1)|0}else{n=e[(c[277226]|0)+(l<<1)>>1]|0;aC=n;aD=(c[277220]|0)+((n>>>1&31727)<<1)|0}aB=(e[aD>>1]|aC&2081)&65535}}while(0);l=m+13|0;b[(c[277218]|0)+(l<<1)>>1]=aB;q=a[1108909]|0;a[(c[277219]|0)+l|0]=q;a[(c[277219]|0)+o|0]=q;av=a[1108908]|0;aw=c[277219]|0}else{av=am;aw=an}}while(0);o=m+14|0;do{if((av&255)>(d[aw+o|0]|0)){q=a[r+7|0]|0;l=q&255;if(q<<24>>24==0){break}do{if((a[1108928]|0)==0){q=b[(c[277225]|0)+(l<<1)>>1]|0;n=q&65535;w=n&63454;if((a[(c[277215]|0)+o|0]&32)==0){u=c[277228]|0;aE=(e[(c[277220]|0)+((((u&-2082)+w|0)>>>1)+(n&2081&u)<<1)>>1]|(u^n)&2081)&65535;break}else{n=b[(c[277213]|0)+(o<<1)>>1]|0;aE=(((n&63454)+w|0)>>>1)+(n&q&2081)&65535;break}}else{q=e[(c[277225]|0)+(l<<1)>>1]|0;n=(a[(c[277215]|0)+o|0]&32)==0;if(n){w=c[277228]|0;aF=w;aG=w&-2082}else{w=e[(c[277213]|0)+(o<<1)>>1]|0;aF=w;aG=w&63454}if(n){aH=c[277228]|0}else{aH=e[(c[277213]|0)+(o<<1)>>1]|0}aE=((aH^q)&2081|e[(c[277220]|0)+((q&2081&aF)+((aG+(q&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=aE;q=(a[(c[277215]|0)+o|0]&32)==0;do{if((a[1108928]|0)==0){n=e[(c[277213]|0)+(m+16<<1)>>1]|0;w=n&63454;if(q){u=c[277228]|0;aI=(e[(c[277220]|0)+((((u&-2082)+w|0)>>>1)+(n&2081&u)<<1)>>1]|(u^n)&2081)&65535;break}else{u=e[(c[277226]|0)+(l<<1)>>1]|0;aI=(((u&63454)+w|0)>>>1)+(n&2081&u)&65535;break}}else{if(q){u=c[277228]|0;aJ=u;aK=(c[277220]|0)+((u>>>1&2147482607)<<1)|0}else{u=e[(c[277226]|0)+(l<<1)>>1]|0;aJ=u;aK=(c[277220]|0)+((u>>>1&31727)<<1)|0}aI=(e[aK>>1]|aJ&2081)&65535}}while(0);l=m+15|0;b[(c[277218]|0)+(l<<1)>>1]=aI;q=a[1108909]|0;a[(c[277219]|0)+l|0]=q;a[(c[277219]|0)+o|0]=q}}while(0);o=j-1|0;if((o|0)<=0){break}r=r+16|0;j=o;m=(c[277223]|0)+m|0}return}m=(d[1394504]|0)+(h<<1)|0;if((f&32768|0)==0){if((i|0)<=0){return}f=p+m|0;h=i;j=g;while(1){r=a[1108908]|0;aI=c[277219]|0;do{if((r&255)>(d[aI+j|0]|0)){aJ=a[f+7|0]|0;aK=aJ&255;if(aJ<<24>>24==0){aL=r;aM=aI;break}do{if((a[1108928]|0)==0){aJ=b[(c[277225]|0)+(aK<<1)>>1]|0;aE=aJ&65535;aG=aE&63454;if((a[(c[277215]|0)+j|0]&32)==0){aF=c[277228]|0;aN=(e[(c[277220]|0)+((((aF&-2082)+aG|0)>>>1)+(aE&2081&aF)<<1)>>1]|(aF^aE)&2081)&65535;break}else{aE=b[(c[277213]|0)+(j<<1)>>1]|0;aN=(((aE&63454)+aG|0)>>>1)+(aE&aJ&2081)&65535;break}}else{aJ=e[(c[277225]|0)+(aK<<1)>>1]|0;aE=(a[(c[277215]|0)+j|0]&32)==0;if(aE){aG=c[277228]|0;aO=aG;aP=aG&-2082}else{aG=e[(c[277213]|0)+(j<<1)>>1]|0;aO=aG;aP=aG&63454}if(aE){aQ=c[277228]|0}else{aQ=e[(c[277213]|0)+(j<<1)>>1]|0}aN=((aQ^aJ)&2081|e[(c[277220]|0)+((aJ&2081&aO)+((aP+(aJ&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(j<<1)>>1]=aN;aJ=(a[(c[277215]|0)+j|0]&32)==0;do{if((a[1108928]|0)==0){aE=e[(c[277213]|0)+(j+2<<1)>>1]|0;aG=aE&63454;if(aJ){aF=c[277228]|0;aR=(e[(c[277220]|0)+((((aF&-2082)+aG|0)>>>1)+(aE&2081&aF)<<1)>>1]|(aF^aE)&2081)&65535;break}else{aF=e[(c[277226]|0)+(aK<<1)>>1]|0;aR=(((aF&63454)+aG|0)>>>1)+(aE&2081&aF)&65535;break}}else{if(aJ){aF=c[277228]|0;aS=aF;aT=(c[277220]|0)+((aF>>>1&2147482607)<<1)|0}else{aF=e[(c[277226]|0)+(aK<<1)>>1]|0;aS=aF;aT=(c[277220]|0)+((aF>>>1&31727)<<1)|0}aR=(e[aT>>1]|aS&2081)&65535}}while(0);aK=j+1|0;b[(c[277218]|0)+(aK<<1)>>1]=aR;aJ=a[1108909]|0;a[(c[277219]|0)+aK|0]=aJ;a[(c[277219]|0)+j|0]=aJ;aL=a[1108908]|0;aM=c[277219]|0}else{aL=r;aM=aI}}while(0);aI=j+2|0;do{if((aL&255)>(d[aM+aI|0]|0)){r=a[f+6|0]|0;aJ=r&255;if(r<<24>>24==0){aU=aL;aV=aM;break}do{if((a[1108928]|0)==0){r=b[(c[277225]|0)+(aJ<<1)>>1]|0;aK=r&65535;aF=aK&63454;if((a[(c[277215]|0)+aI|0]&32)==0){aE=c[277228]|0;aW=(e[(c[277220]|0)+((((aE&-2082)+aF|0)>>>1)+(aK&2081&aE)<<1)>>1]|(aE^aK)&2081)&65535;break}else{aK=b[(c[277213]|0)+(aI<<1)>>1]|0;aW=(((aK&63454)+aF|0)>>>1)+(aK&r&2081)&65535;break}}else{r=e[(c[277225]|0)+(aJ<<1)>>1]|0;aK=(a[(c[277215]|0)+aI|0]&32)==0;if(aK){aF=c[277228]|0;aX=aF;aY=aF&-2082}else{aF=e[(c[277213]|0)+(aI<<1)>>1]|0;aX=aF;aY=aF&63454}if(aK){aZ=c[277228]|0}else{aZ=e[(c[277213]|0)+(aI<<1)>>1]|0}aW=((aZ^r)&2081|e[(c[277220]|0)+((r&2081&aX)+((aY+(r&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(aI<<1)>>1]=aW;r=(a[(c[277215]|0)+aI|0]&32)==0;do{if((a[1108928]|0)==0){aK=e[(c[277213]|0)+(j+4<<1)>>1]|0;aF=aK&63454;if(r){aE=c[277228]|0;a_=(e[(c[277220]|0)+((((aE&-2082)+aF|0)>>>1)+(aK&2081&aE)<<1)>>1]|(aE^aK)&2081)&65535;break}else{aE=e[(c[277226]|0)+(aJ<<1)>>1]|0;a_=(((aE&63454)+aF|0)>>>1)+(aK&2081&aE)&65535;break}}else{if(r){aE=c[277228]|0;a$=aE;a0=(c[277220]|0)+((aE>>>1&2147482607)<<1)|0}else{aE=e[(c[277226]|0)+(aJ<<1)>>1]|0;a$=aE;a0=(c[277220]|0)+((aE>>>1&31727)<<1)|0}a_=(e[a0>>1]|a$&2081)&65535}}while(0);aJ=j+3|0;b[(c[277218]|0)+(aJ<<1)>>1]=a_;r=a[1108909]|0;a[(c[277219]|0)+aJ|0]=r;a[(c[277219]|0)+aI|0]=r;aU=a[1108908]|0;aV=c[277219]|0}else{aU=aL;aV=aM}}while(0);aI=j+4|0;do{if((aU&255)>(d[aV+aI|0]|0)){r=a[f+5|0]|0;aJ=r&255;if(r<<24>>24==0){a1=aU;a2=aV;break}do{if((a[1108928]|0)==0){r=b[(c[277225]|0)+(aJ<<1)>>1]|0;aE=r&65535;aK=aE&63454;if((a[(c[277215]|0)+aI|0]&32)==0){aF=c[277228]|0;a3=(e[(c[277220]|0)+((((aF&-2082)+aK|0)>>>1)+(aE&2081&aF)<<1)>>1]|(aF^aE)&2081)&65535;break}else{aE=b[(c[277213]|0)+(aI<<1)>>1]|0;a3=(((aE&63454)+aK|0)>>>1)+(aE&r&2081)&65535;break}}else{r=e[(c[277225]|0)+(aJ<<1)>>1]|0;aE=(a[(c[277215]|0)+aI|0]&32)==0;if(aE){aK=c[277228]|0;a4=aK;a5=aK&-2082}else{aK=e[(c[277213]|0)+(aI<<1)>>1]|0;a4=aK;a5=aK&63454}if(aE){a6=c[277228]|0}else{a6=e[(c[277213]|0)+(aI<<1)>>1]|0}a3=((a6^r)&2081|e[(c[277220]|0)+((r&2081&a4)+((a5+(r&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(aI<<1)>>1]=a3;r=(a[(c[277215]|0)+aI|0]&32)==0;do{if((a[1108928]|0)==0){aE=e[(c[277213]|0)+(j+6<<1)>>1]|0;aK=aE&63454;if(r){aF=c[277228]|0;a7=(e[(c[277220]|0)+((((aF&-2082)+aK|0)>>>1)+(aE&2081&aF)<<1)>>1]|(aF^aE)&2081)&65535;break}else{aF=e[(c[277226]|0)+(aJ<<1)>>1]|0;a7=(((aF&63454)+aK|0)>>>1)+(aE&2081&aF)&65535;break}}else{if(r){aF=c[277228]|0;a8=aF;a9=(c[277220]|0)+((aF>>>1&2147482607)<<1)|0}else{aF=e[(c[277226]|0)+(aJ<<1)>>1]|0;a8=aF;a9=(c[277220]|0)+((aF>>>1&31727)<<1)|0}a7=(e[a9>>1]|a8&2081)&65535}}while(0);aJ=j+5|0;b[(c[277218]|0)+(aJ<<1)>>1]=a7;r=a[1108909]|0;a[(c[277219]|0)+aJ|0]=r;a[(c[277219]|0)+aI|0]=r;a1=a[1108908]|0;a2=c[277219]|0}else{a1=aU;a2=aV}}while(0);aI=j+6|0;do{if((a1&255)>(d[a2+aI|0]|0)){r=a[f+4|0]|0;aJ=r&255;if(r<<24>>24==0){ba=a1;bb=a2;break}do{if((a[1108928]|0)==0){r=b[(c[277225]|0)+(aJ<<1)>>1]|0;aF=r&65535;aE=aF&63454;if((a[(c[277215]|0)+aI|0]&32)==0){aK=c[277228]|0;bc=(e[(c[277220]|0)+((((aK&-2082)+aE|0)>>>1)+(aF&2081&aK)<<1)>>1]|(aK^aF)&2081)&65535;break}else{aF=b[(c[277213]|0)+(aI<<1)>>1]|0;bc=(((aF&63454)+aE|0)>>>1)+(aF&r&2081)&65535;break}}else{r=e[(c[277225]|0)+(aJ<<1)>>1]|0;aF=(a[(c[277215]|0)+aI|0]&32)==0;if(aF){aE=c[277228]|0;bd=aE;be=aE&-2082}else{aE=e[(c[277213]|0)+(aI<<1)>>1]|0;bd=aE;be=aE&63454}if(aF){bf=c[277228]|0}else{bf=e[(c[277213]|0)+(aI<<1)>>1]|0}bc=((bf^r)&2081|e[(c[277220]|0)+((r&2081&bd)+((be+(r&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(aI<<1)>>1]=bc;r=(a[(c[277215]|0)+aI|0]&32)==0;do{if((a[1108928]|0)==0){aF=e[(c[277213]|0)+(j+8<<1)>>1]|0;aE=aF&63454;if(r){aK=c[277228]|0;bg=(e[(c[277220]|0)+((((aK&-2082)+aE|0)>>>1)+(aF&2081&aK)<<1)>>1]|(aK^aF)&2081)&65535;break}else{aK=e[(c[277226]|0)+(aJ<<1)>>1]|0;bg=(((aK&63454)+aE|0)>>>1)+(aF&2081&aK)&65535;break}}else{if(r){aK=c[277228]|0;bh=aK;bi=(c[277220]|0)+((aK>>>1&2147482607)<<1)|0}else{aK=e[(c[277226]|0)+(aJ<<1)>>1]|0;bh=aK;bi=(c[277220]|0)+((aK>>>1&31727)<<1)|0}bg=(e[bi>>1]|bh&2081)&65535}}while(0);aJ=j+7|0;b[(c[277218]|0)+(aJ<<1)>>1]=bg;r=a[1108909]|0;a[(c[277219]|0)+aJ|0]=r;a[(c[277219]|0)+aI|0]=r;ba=a[1108908]|0;bb=c[277219]|0}else{ba=a1;bb=a2}}while(0);aI=j+8|0;do{if((ba&255)>(d[bb+aI|0]|0)){r=a[f+3|0]|0;aJ=r&255;if(r<<24>>24==0){bj=ba;bk=bb;break}do{if((a[1108928]|0)==0){r=b[(c[277225]|0)+(aJ<<1)>>1]|0;aK=r&65535;aF=aK&63454;if((a[(c[277215]|0)+aI|0]&32)==0){aE=c[277228]|0;bl=(e[(c[277220]|0)+((((aE&-2082)+aF|0)>>>1)+(aK&2081&aE)<<1)>>1]|(aE^aK)&2081)&65535;break}else{aK=b[(c[277213]|0)+(aI<<1)>>1]|0;bl=(((aK&63454)+aF|0)>>>1)+(aK&r&2081)&65535;break}}else{r=e[(c[277225]|0)+(aJ<<1)>>1]|0;aK=(a[(c[277215]|0)+aI|0]&32)==0;if(aK){aF=c[277228]|0;bm=aF;bn=aF&-2082}else{aF=e[(c[277213]|0)+(aI<<1)>>1]|0;bm=aF;bn=aF&63454}if(aK){bo=c[277228]|0}else{bo=e[(c[277213]|0)+(aI<<1)>>1]|0}bl=((bo^r)&2081|e[(c[277220]|0)+((r&2081&bm)+((bn+(r&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(aI<<1)>>1]=bl;r=(a[(c[277215]|0)+aI|0]&32)==0;do{if((a[1108928]|0)==0){aK=e[(c[277213]|0)+(j+10<<1)>>1]|0;aF=aK&63454;if(r){aE=c[277228]|0;bp=(e[(c[277220]|0)+((((aE&-2082)+aF|0)>>>1)+(aK&2081&aE)<<1)>>1]|(aE^aK)&2081)&65535;break}else{aE=e[(c[277226]|0)+(aJ<<1)>>1]|0;bp=(((aE&63454)+aF|0)>>>1)+(aK&2081&aE)&65535;break}}else{if(r){aE=c[277228]|0;bq=aE;br=(c[277220]|0)+((aE>>>1&2147482607)<<1)|0}else{aE=e[(c[277226]|0)+(aJ<<1)>>1]|0;bq=aE;br=(c[277220]|0)+((aE>>>1&31727)<<1)|0}bp=(e[br>>1]|bq&2081)&65535}}while(0);aJ=j+9|0;b[(c[277218]|0)+(aJ<<1)>>1]=bp;r=a[1108909]|0;a[(c[277219]|0)+aJ|0]=r;a[(c[277219]|0)+aI|0]=r;bj=a[1108908]|0;bk=c[277219]|0}else{bj=ba;bk=bb}}while(0);aI=j+10|0;do{if((bj&255)>(d[bk+aI|0]|0)){r=a[f+2|0]|0;aJ=r&255;if(r<<24>>24==0){bs=bj;bt=bk;break}do{if((a[1108928]|0)==0){r=b[(c[277225]|0)+(aJ<<1)>>1]|0;aE=r&65535;aK=aE&63454;if((a[(c[277215]|0)+aI|0]&32)==0){aF=c[277228]|0;bu=(e[(c[277220]|0)+((((aF&-2082)+aK|0)>>>1)+(aE&2081&aF)<<1)>>1]|(aF^aE)&2081)&65535;break}else{aE=b[(c[277213]|0)+(aI<<1)>>1]|0;bu=(((aE&63454)+aK|0)>>>1)+(aE&r&2081)&65535;break}}else{r=e[(c[277225]|0)+(aJ<<1)>>1]|0;aE=(a[(c[277215]|0)+aI|0]&32)==0;if(aE){aK=c[277228]|0;bv=aK;bw=aK&-2082}else{aK=e[(c[277213]|0)+(aI<<1)>>1]|0;bv=aK;bw=aK&63454}if(aE){bx=c[277228]|0}else{bx=e[(c[277213]|0)+(aI<<1)>>1]|0}bu=((bx^r)&2081|e[(c[277220]|0)+((r&2081&bv)+((bw+(r&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(aI<<1)>>1]=bu;r=(a[(c[277215]|0)+aI|0]&32)==0;do{if((a[1108928]|0)==0){aE=e[(c[277213]|0)+(j+12<<1)>>1]|0;aK=aE&63454;if(r){aF=c[277228]|0;by=(e[(c[277220]|0)+((((aF&-2082)+aK|0)>>>1)+(aE&2081&aF)<<1)>>1]|(aF^aE)&2081)&65535;break}else{aF=e[(c[277226]|0)+(aJ<<1)>>1]|0;by=(((aF&63454)+aK|0)>>>1)+(aE&2081&aF)&65535;break}}else{if(r){aF=c[277228]|0;bz=aF;bA=(c[277220]|0)+((aF>>>1&2147482607)<<1)|0}else{aF=e[(c[277226]|0)+(aJ<<1)>>1]|0;bz=aF;bA=(c[277220]|0)+((aF>>>1&31727)<<1)|0}by=(e[bA>>1]|bz&2081)&65535}}while(0);aJ=j+11|0;b[(c[277218]|0)+(aJ<<1)>>1]=by;r=a[1108909]|0;a[(c[277219]|0)+aJ|0]=r;a[(c[277219]|0)+aI|0]=r;bs=a[1108908]|0;bt=c[277219]|0}else{bs=bj;bt=bk}}while(0);aI=j+12|0;do{if((bs&255)>(d[bt+aI|0]|0)){r=a[f+1|0]|0;aJ=r&255;if(r<<24>>24==0){bB=bs;bC=bt;break}do{if((a[1108928]|0)==0){r=b[(c[277225]|0)+(aJ<<1)>>1]|0;aF=r&65535;aE=aF&63454;if((a[(c[277215]|0)+aI|0]&32)==0){aK=c[277228]|0;bD=(e[(c[277220]|0)+((((aK&-2082)+aE|0)>>>1)+(aF&2081&aK)<<1)>>1]|(aK^aF)&2081)&65535;break}else{aF=b[(c[277213]|0)+(aI<<1)>>1]|0;bD=(((aF&63454)+aE|0)>>>1)+(aF&r&2081)&65535;break}}else{r=e[(c[277225]|0)+(aJ<<1)>>1]|0;aF=(a[(c[277215]|0)+aI|0]&32)==0;if(aF){aE=c[277228]|0;bE=aE;bF=aE&-2082}else{aE=e[(c[277213]|0)+(aI<<1)>>1]|0;bE=aE;bF=aE&63454}if(aF){bG=c[277228]|0}else{bG=e[(c[277213]|0)+(aI<<1)>>1]|0}bD=((bG^r)&2081|e[(c[277220]|0)+((r&2081&bE)+((bF+(r&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(aI<<1)>>1]=bD;r=(a[(c[277215]|0)+aI|0]&32)==0;do{if((a[1108928]|0)==0){aF=e[(c[277213]|0)+(j+14<<1)>>1]|0;aE=aF&63454;if(r){aK=c[277228]|0;bH=(e[(c[277220]|0)+((((aK&-2082)+aE|0)>>>1)+(aF&2081&aK)<<1)>>1]|(aK^aF)&2081)&65535;break}else{aK=e[(c[277226]|0)+(aJ<<1)>>1]|0;bH=(((aK&63454)+aE|0)>>>1)+(aF&2081&aK)&65535;break}}else{if(r){aK=c[277228]|0;bI=aK;bJ=(c[277220]|0)+((aK>>>1&2147482607)<<1)|0}else{aK=e[(c[277226]|0)+(aJ<<1)>>1]|0;bI=aK;bJ=(c[277220]|0)+((aK>>>1&31727)<<1)|0}bH=(e[bJ>>1]|bI&2081)&65535}}while(0);aJ=j+13|0;b[(c[277218]|0)+(aJ<<1)>>1]=bH;r=a[1108909]|0;a[(c[277219]|0)+aJ|0]=r;a[(c[277219]|0)+aI|0]=r;bB=a[1108908]|0;bC=c[277219]|0}else{bB=bs;bC=bt}}while(0);aI=j+14|0;do{if((bB&255)>(d[bC+aI|0]|0)){r=a[f]|0;aJ=r&255;if(r<<24>>24==0){break}do{if((a[1108928]|0)==0){r=b[(c[277225]|0)+(aJ<<1)>>1]|0;aK=r&65535;aF=aK&63454;if((a[(c[277215]|0)+aI|0]&32)==0){aE=c[277228]|0;bK=(e[(c[277220]|0)+((((aE&-2082)+aF|0)>>>1)+(aK&2081&aE)<<1)>>1]|(aE^aK)&2081)&65535;break}else{aK=b[(c[277213]|0)+(aI<<1)>>1]|0;bK=(((aK&63454)+aF|0)>>>1)+(aK&r&2081)&65535;break}}else{r=e[(c[277225]|0)+(aJ<<1)>>1]|0;aK=(a[(c[277215]|0)+aI|0]&32)==0;if(aK){aF=c[277228]|0;bL=aF;bM=aF&-2082}else{aF=e[(c[277213]|0)+(aI<<1)>>1]|0;bL=aF;bM=aF&63454}if(aK){bN=c[277228]|0}else{bN=e[(c[277213]|0)+(aI<<1)>>1]|0}bK=((bN^r)&2081|e[(c[277220]|0)+((r&2081&bL)+((bM+(r&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(aI<<1)>>1]=bK;r=(a[(c[277215]|0)+aI|0]&32)==0;do{if((a[1108928]|0)==0){aK=e[(c[277213]|0)+(j+16<<1)>>1]|0;aF=aK&63454;if(r){aE=c[277228]|0;bO=(e[(c[277220]|0)+((((aE&-2082)+aF|0)>>>1)+(aK&2081&aE)<<1)>>1]|(aE^aK)&2081)&65535;break}else{aE=e[(c[277226]|0)+(aJ<<1)>>1]|0;bO=(((aE&63454)+aF|0)>>>1)+(aK&2081&aE)&65535;break}}else{if(r){aE=c[277228]|0;bP=aE;bQ=(c[277220]|0)+((aE>>>1&2147482607)<<1)|0}else{aE=e[(c[277226]|0)+(aJ<<1)>>1]|0;bP=aE;bQ=(c[277220]|0)+((aE>>>1&31727)<<1)|0}bO=(e[bQ>>1]|bP&2081)&65535}}while(0);aJ=j+15|0;b[(c[277218]|0)+(aJ<<1)>>1]=bO;r=a[1108909]|0;a[(c[277219]|0)+aJ|0]=r;a[(c[277219]|0)+aI|0]=r}}while(0);aI=h-1|0;if((aI|0)<=0){break}f=f+16|0;h=aI;j=(c[277223]|0)+j|0}return}j=p+(56-m)|0;m=(i|0)>0;if(k){if(m){bR=j;bS=i;bT=g}else{return}while(1){k=a[1108908]|0;p=c[277219]|0;do{if((k&255)>(d[p+bT|0]|0)){h=a[bR+7|0]|0;f=h&255;if(h<<24>>24==0){bU=k;bV=p;break}do{if((a[1108928]|0)==0){h=b[(c[277225]|0)+(f<<1)>>1]|0;bO=h&65535;bP=bO&63454;if((a[(c[277215]|0)+bT|0]&32)==0){bQ=c[277228]|0;bW=(e[(c[277220]|0)+((((bQ&-2082)+bP|0)>>>1)+(bO&2081&bQ)<<1)>>1]|(bQ^bO)&2081)&65535;break}else{bO=b[(c[277213]|0)+(bT<<1)>>1]|0;bW=(((bO&63454)+bP|0)>>>1)+(bO&h&2081)&65535;break}}else{h=e[(c[277225]|0)+(f<<1)>>1]|0;bO=(a[(c[277215]|0)+bT|0]&32)==0;if(bO){bP=c[277228]|0;bX=bP;bY=bP&-2082}else{bP=e[(c[277213]|0)+(bT<<1)>>1]|0;bX=bP;bY=bP&63454}if(bO){bZ=c[277228]|0}else{bZ=e[(c[277213]|0)+(bT<<1)>>1]|0}bW=((bZ^h)&2081|e[(c[277220]|0)+((h&2081&bX)+((bY+(h&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(bT<<1)>>1]=bW;h=(a[(c[277215]|0)+bT|0]&32)==0;do{if((a[1108928]|0)==0){bO=e[(c[277213]|0)+(bT+2<<1)>>1]|0;bP=bO&63454;if(h){bQ=c[277228]|0;b_=(e[(c[277220]|0)+((((bQ&-2082)+bP|0)>>>1)+(bO&2081&bQ)<<1)>>1]|(bQ^bO)&2081)&65535;break}else{bQ=e[(c[277226]|0)+(f<<1)>>1]|0;b_=(((bQ&63454)+bP|0)>>>1)+(bO&2081&bQ)&65535;break}}else{if(h){bQ=c[277228]|0;b$=bQ;b0=(c[277220]|0)+((bQ>>>1&2147482607)<<1)|0}else{bQ=e[(c[277226]|0)+(f<<1)>>1]|0;b$=bQ;b0=(c[277220]|0)+((bQ>>>1&31727)<<1)|0}b_=(e[b0>>1]|b$&2081)&65535}}while(0);f=bT+1|0;b[(c[277218]|0)+(f<<1)>>1]=b_;h=a[1108909]|0;a[(c[277219]|0)+f|0]=h;a[(c[277219]|0)+bT|0]=h;bU=a[1108908]|0;bV=c[277219]|0}else{bU=k;bV=p}}while(0);p=bT+2|0;do{if((bU&255)>(d[bV+p|0]|0)){k=a[bR+6|0]|0;h=k&255;if(k<<24>>24==0){b1=bU;b2=bV;break}do{if((a[1108928]|0)==0){k=b[(c[277225]|0)+(h<<1)>>1]|0;f=k&65535;bQ=f&63454;if((a[(c[277215]|0)+p|0]&32)==0){bO=c[277228]|0;b3=(e[(c[277220]|0)+((((bO&-2082)+bQ|0)>>>1)+(f&2081&bO)<<1)>>1]|(bO^f)&2081)&65535;break}else{f=b[(c[277213]|0)+(p<<1)>>1]|0;b3=(((f&63454)+bQ|0)>>>1)+(f&k&2081)&65535;break}}else{k=e[(c[277225]|0)+(h<<1)>>1]|0;f=(a[(c[277215]|0)+p|0]&32)==0;if(f){bQ=c[277228]|0;b4=bQ;b5=bQ&-2082}else{bQ=e[(c[277213]|0)+(p<<1)>>1]|0;b4=bQ;b5=bQ&63454}if(f){b6=c[277228]|0}else{b6=e[(c[277213]|0)+(p<<1)>>1]|0}b3=((b6^k)&2081|e[(c[277220]|0)+((k&2081&b4)+((b5+(k&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=b3;k=(a[(c[277215]|0)+p|0]&32)==0;do{if((a[1108928]|0)==0){f=e[(c[277213]|0)+(bT+4<<1)>>1]|0;bQ=f&63454;if(k){bO=c[277228]|0;b7=(e[(c[277220]|0)+((((bO&-2082)+bQ|0)>>>1)+(f&2081&bO)<<1)>>1]|(bO^f)&2081)&65535;break}else{bO=e[(c[277226]|0)+(h<<1)>>1]|0;b7=(((bO&63454)+bQ|0)>>>1)+(f&2081&bO)&65535;break}}else{if(k){bO=c[277228]|0;b8=bO;b9=(c[277220]|0)+((bO>>>1&2147482607)<<1)|0}else{bO=e[(c[277226]|0)+(h<<1)>>1]|0;b8=bO;b9=(c[277220]|0)+((bO>>>1&31727)<<1)|0}b7=(e[b9>>1]|b8&2081)&65535}}while(0);h=bT+3|0;b[(c[277218]|0)+(h<<1)>>1]=b7;k=a[1108909]|0;a[(c[277219]|0)+h|0]=k;a[(c[277219]|0)+p|0]=k;b1=a[1108908]|0;b2=c[277219]|0}else{b1=bU;b2=bV}}while(0);p=bT+4|0;do{if((b1&255)>(d[b2+p|0]|0)){k=a[bR+5|0]|0;h=k&255;if(k<<24>>24==0){ca=b1;cb=b2;break}do{if((a[1108928]|0)==0){k=b[(c[277225]|0)+(h<<1)>>1]|0;bO=k&65535;f=bO&63454;if((a[(c[277215]|0)+p|0]&32)==0){bQ=c[277228]|0;cc=(e[(c[277220]|0)+((((bQ&-2082)+f|0)>>>1)+(bO&2081&bQ)<<1)>>1]|(bQ^bO)&2081)&65535;break}else{bO=b[(c[277213]|0)+(p<<1)>>1]|0;cc=(((bO&63454)+f|0)>>>1)+(bO&k&2081)&65535;break}}else{k=e[(c[277225]|0)+(h<<1)>>1]|0;bO=(a[(c[277215]|0)+p|0]&32)==0;if(bO){f=c[277228]|0;cd=f;ce=f&-2082}else{f=e[(c[277213]|0)+(p<<1)>>1]|0;cd=f;ce=f&63454}if(bO){cf=c[277228]|0}else{cf=e[(c[277213]|0)+(p<<1)>>1]|0}cc=((cf^k)&2081|e[(c[277220]|0)+((k&2081&cd)+((ce+(k&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=cc;k=(a[(c[277215]|0)+p|0]&32)==0;do{if((a[1108928]|0)==0){bO=e[(c[277213]|0)+(bT+6<<1)>>1]|0;f=bO&63454;if(k){bQ=c[277228]|0;cg=(e[(c[277220]|0)+((((bQ&-2082)+f|0)>>>1)+(bO&2081&bQ)<<1)>>1]|(bQ^bO)&2081)&65535;break}else{bQ=e[(c[277226]|0)+(h<<1)>>1]|0;cg=(((bQ&63454)+f|0)>>>1)+(bO&2081&bQ)&65535;break}}else{if(k){bQ=c[277228]|0;ch=bQ;ci=(c[277220]|0)+((bQ>>>1&2147482607)<<1)|0}else{bQ=e[(c[277226]|0)+(h<<1)>>1]|0;ch=bQ;ci=(c[277220]|0)+((bQ>>>1&31727)<<1)|0}cg=(e[ci>>1]|ch&2081)&65535}}while(0);h=bT+5|0;b[(c[277218]|0)+(h<<1)>>1]=cg;k=a[1108909]|0;a[(c[277219]|0)+h|0]=k;a[(c[277219]|0)+p|0]=k;ca=a[1108908]|0;cb=c[277219]|0}else{ca=b1;cb=b2}}while(0);p=bT+6|0;do{if((ca&255)>(d[cb+p|0]|0)){k=a[bR+4|0]|0;h=k&255;if(k<<24>>24==0){cj=ca;ck=cb;break}do{if((a[1108928]|0)==0){k=b[(c[277225]|0)+(h<<1)>>1]|0;bQ=k&65535;bO=bQ&63454;if((a[(c[277215]|0)+p|0]&32)==0){f=c[277228]|0;cl=(e[(c[277220]|0)+((((f&-2082)+bO|0)>>>1)+(bQ&2081&f)<<1)>>1]|(f^bQ)&2081)&65535;break}else{bQ=b[(c[277213]|0)+(p<<1)>>1]|0;cl=(((bQ&63454)+bO|0)>>>1)+(bQ&k&2081)&65535;break}}else{k=e[(c[277225]|0)+(h<<1)>>1]|0;bQ=(a[(c[277215]|0)+p|0]&32)==0;if(bQ){bO=c[277228]|0;cm=bO;cn=bO&-2082}else{bO=e[(c[277213]|0)+(p<<1)>>1]|0;cm=bO;cn=bO&63454}if(bQ){co=c[277228]|0}else{co=e[(c[277213]|0)+(p<<1)>>1]|0}cl=((co^k)&2081|e[(c[277220]|0)+((k&2081&cm)+((cn+(k&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=cl;k=(a[(c[277215]|0)+p|0]&32)==0;do{if((a[1108928]|0)==0){bQ=e[(c[277213]|0)+(bT+8<<1)>>1]|0;bO=bQ&63454;if(k){f=c[277228]|0;cp=(e[(c[277220]|0)+((((f&-2082)+bO|0)>>>1)+(bQ&2081&f)<<1)>>1]|(f^bQ)&2081)&65535;break}else{f=e[(c[277226]|0)+(h<<1)>>1]|0;cp=(((f&63454)+bO|0)>>>1)+(bQ&2081&f)&65535;break}}else{if(k){f=c[277228]|0;cq=f;cr=(c[277220]|0)+((f>>>1&2147482607)<<1)|0}else{f=e[(c[277226]|0)+(h<<1)>>1]|0;cq=f;cr=(c[277220]|0)+((f>>>1&31727)<<1)|0}cp=(e[cr>>1]|cq&2081)&65535}}while(0);h=bT+7|0;b[(c[277218]|0)+(h<<1)>>1]=cp;k=a[1108909]|0;a[(c[277219]|0)+h|0]=k;a[(c[277219]|0)+p|0]=k;cj=a[1108908]|0;ck=c[277219]|0}else{cj=ca;ck=cb}}while(0);p=bT+8|0;do{if((cj&255)>(d[ck+p|0]|0)){k=a[bR+3|0]|0;h=k&255;if(k<<24>>24==0){cs=cj;ct=ck;break}do{if((a[1108928]|0)==0){k=b[(c[277225]|0)+(h<<1)>>1]|0;f=k&65535;bQ=f&63454;if((a[(c[277215]|0)+p|0]&32)==0){bO=c[277228]|0;cu=(e[(c[277220]|0)+((((bO&-2082)+bQ|0)>>>1)+(f&2081&bO)<<1)>>1]|(bO^f)&2081)&65535;break}else{f=b[(c[277213]|0)+(p<<1)>>1]|0;cu=(((f&63454)+bQ|0)>>>1)+(f&k&2081)&65535;break}}else{k=e[(c[277225]|0)+(h<<1)>>1]|0;f=(a[(c[277215]|0)+p|0]&32)==0;if(f){bQ=c[277228]|0;cv=bQ;cw=bQ&-2082}else{bQ=e[(c[277213]|0)+(p<<1)>>1]|0;cv=bQ;cw=bQ&63454}if(f){cx=c[277228]|0}else{cx=e[(c[277213]|0)+(p<<1)>>1]|0}cu=((cx^k)&2081|e[(c[277220]|0)+((k&2081&cv)+((cw+(k&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=cu;k=(a[(c[277215]|0)+p|0]&32)==0;do{if((a[1108928]|0)==0){f=e[(c[277213]|0)+(bT+10<<1)>>1]|0;bQ=f&63454;if(k){bO=c[277228]|0;cy=(e[(c[277220]|0)+((((bO&-2082)+bQ|0)>>>1)+(f&2081&bO)<<1)>>1]|(bO^f)&2081)&65535;break}else{bO=e[(c[277226]|0)+(h<<1)>>1]|0;cy=(((bO&63454)+bQ|0)>>>1)+(f&2081&bO)&65535;break}}else{if(k){bO=c[277228]|0;cz=bO;cA=(c[277220]|0)+((bO>>>1&2147482607)<<1)|0}else{bO=e[(c[277226]|0)+(h<<1)>>1]|0;cz=bO;cA=(c[277220]|0)+((bO>>>1&31727)<<1)|0}cy=(e[cA>>1]|cz&2081)&65535}}while(0);h=bT+9|0;b[(c[277218]|0)+(h<<1)>>1]=cy;k=a[1108909]|0;a[(c[277219]|0)+h|0]=k;a[(c[277219]|0)+p|0]=k;cs=a[1108908]|0;ct=c[277219]|0}else{cs=cj;ct=ck}}while(0);p=bT+10|0;do{if((cs&255)>(d[ct+p|0]|0)){k=a[bR+2|0]|0;h=k&255;if(k<<24>>24==0){cB=cs;cC=ct;break}do{if((a[1108928]|0)==0){k=b[(c[277225]|0)+(h<<1)>>1]|0;bO=k&65535;f=bO&63454;if((a[(c[277215]|0)+p|0]&32)==0){bQ=c[277228]|0;cD=(e[(c[277220]|0)+((((bQ&-2082)+f|0)>>>1)+(bO&2081&bQ)<<1)>>1]|(bQ^bO)&2081)&65535;break}else{bO=b[(c[277213]|0)+(p<<1)>>1]|0;cD=(((bO&63454)+f|0)>>>1)+(bO&k&2081)&65535;break}}else{k=e[(c[277225]|0)+(h<<1)>>1]|0;bO=(a[(c[277215]|0)+p|0]&32)==0;if(bO){f=c[277228]|0;cE=f;cF=f&-2082}else{f=e[(c[277213]|0)+(p<<1)>>1]|0;cE=f;cF=f&63454}if(bO){cG=c[277228]|0}else{cG=e[(c[277213]|0)+(p<<1)>>1]|0}cD=((cG^k)&2081|e[(c[277220]|0)+((k&2081&cE)+((cF+(k&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=cD;k=(a[(c[277215]|0)+p|0]&32)==0;do{if((a[1108928]|0)==0){bO=e[(c[277213]|0)+(bT+12<<1)>>1]|0;f=bO&63454;if(k){bQ=c[277228]|0;cH=(e[(c[277220]|0)+((((bQ&-2082)+f|0)>>>1)+(bO&2081&bQ)<<1)>>1]|(bQ^bO)&2081)&65535;break}else{bQ=e[(c[277226]|0)+(h<<1)>>1]|0;cH=(((bQ&63454)+f|0)>>>1)+(bO&2081&bQ)&65535;break}}else{if(k){bQ=c[277228]|0;cI=bQ;cJ=(c[277220]|0)+((bQ>>>1&2147482607)<<1)|0}else{bQ=e[(c[277226]|0)+(h<<1)>>1]|0;cI=bQ;cJ=(c[277220]|0)+((bQ>>>1&31727)<<1)|0}cH=(e[cJ>>1]|cI&2081)&65535}}while(0);h=bT+11|0;b[(c[277218]|0)+(h<<1)>>1]=cH;k=a[1108909]|0;a[(c[277219]|0)+h|0]=k;a[(c[277219]|0)+p|0]=k;cB=a[1108908]|0;cC=c[277219]|0}else{cB=cs;cC=ct}}while(0);p=bT+12|0;do{if((cB&255)>(d[cC+p|0]|0)){k=a[bR+1|0]|0;h=k&255;if(k<<24>>24==0){cK=cB;cL=cC;break}do{if((a[1108928]|0)==0){k=b[(c[277225]|0)+(h<<1)>>1]|0;bQ=k&65535;bO=bQ&63454;if((a[(c[277215]|0)+p|0]&32)==0){f=c[277228]|0;cM=(e[(c[277220]|0)+((((f&-2082)+bO|0)>>>1)+(bQ&2081&f)<<1)>>1]|(f^bQ)&2081)&65535;break}else{bQ=b[(c[277213]|0)+(p<<1)>>1]|0;cM=(((bQ&63454)+bO|0)>>>1)+(bQ&k&2081)&65535;break}}else{k=e[(c[277225]|0)+(h<<1)>>1]|0;bQ=(a[(c[277215]|0)+p|0]&32)==0;if(bQ){bO=c[277228]|0;cN=bO;cO=bO&-2082}else{bO=e[(c[277213]|0)+(p<<1)>>1]|0;cN=bO;cO=bO&63454}if(bQ){cP=c[277228]|0}else{cP=e[(c[277213]|0)+(p<<1)>>1]|0}cM=((cP^k)&2081|e[(c[277220]|0)+((k&2081&cN)+((cO+(k&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=cM;k=(a[(c[277215]|0)+p|0]&32)==0;do{if((a[1108928]|0)==0){bQ=e[(c[277213]|0)+(bT+14<<1)>>1]|0;bO=bQ&63454;if(k){f=c[277228]|0;cQ=(e[(c[277220]|0)+((((f&-2082)+bO|0)>>>1)+(bQ&2081&f)<<1)>>1]|(f^bQ)&2081)&65535;break}else{f=e[(c[277226]|0)+(h<<1)>>1]|0;cQ=(((f&63454)+bO|0)>>>1)+(bQ&2081&f)&65535;break}}else{if(k){f=c[277228]|0;cR=f;cS=(c[277220]|0)+((f>>>1&2147482607)<<1)|0}else{f=e[(c[277226]|0)+(h<<1)>>1]|0;cR=f;cS=(c[277220]|0)+((f>>>1&31727)<<1)|0}cQ=(e[cS>>1]|cR&2081)&65535}}while(0);h=bT+13|0;b[(c[277218]|0)+(h<<1)>>1]=cQ;k=a[1108909]|0;a[(c[277219]|0)+h|0]=k;a[(c[277219]|0)+p|0]=k;cK=a[1108908]|0;cL=c[277219]|0}else{cK=cB;cL=cC}}while(0);p=bT+14|0;do{if((cK&255)>(d[cL+p|0]|0)){k=a[bR]|0;h=k&255;if(k<<24>>24==0){break}do{if((a[1108928]|0)==0){k=b[(c[277225]|0)+(h<<1)>>1]|0;f=k&65535;bQ=f&63454;if((a[(c[277215]|0)+p|0]&32)==0){bO=c[277228]|0;cT=(e[(c[277220]|0)+((((bO&-2082)+bQ|0)>>>1)+(f&2081&bO)<<1)>>1]|(bO^f)&2081)&65535;break}else{f=b[(c[277213]|0)+(p<<1)>>1]|0;cT=(((f&63454)+bQ|0)>>>1)+(f&k&2081)&65535;break}}else{k=e[(c[277225]|0)+(h<<1)>>1]|0;f=(a[(c[277215]|0)+p|0]&32)==0;if(f){bQ=c[277228]|0;cU=bQ;cV=bQ&-2082}else{bQ=e[(c[277213]|0)+(p<<1)>>1]|0;cU=bQ;cV=bQ&63454}if(f){cW=c[277228]|0}else{cW=e[(c[277213]|0)+(p<<1)>>1]|0}cT=((cW^k)&2081|e[(c[277220]|0)+((k&2081&cU)+((cV+(k&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=cT;k=(a[(c[277215]|0)+p|0]&32)==0;do{if((a[1108928]|0)==0){f=e[(c[277213]|0)+(bT+16<<1)>>1]|0;bQ=f&63454;if(k){bO=c[277228]|0;cX=(e[(c[277220]|0)+((((bO&-2082)+bQ|0)>>>1)+(f&2081&bO)<<1)>>1]|(bO^f)&2081)&65535;break}else{bO=e[(c[277226]|0)+(h<<1)>>1]|0;cX=(((bO&63454)+bQ|0)>>>1)+(f&2081&bO)&65535;break}}else{if(k){bO=c[277228]|0;cY=bO;cZ=(c[277220]|0)+((bO>>>1&2147482607)<<1)|0}else{bO=e[(c[277226]|0)+(h<<1)>>1]|0;cY=bO;cZ=(c[277220]|0)+((bO>>>1&31727)<<1)|0}cX=(e[cZ>>1]|cY&2081)&65535}}while(0);h=bT+15|0;b[(c[277218]|0)+(h<<1)>>1]=cX;k=a[1108909]|0;a[(c[277219]|0)+h|0]=k;a[(c[277219]|0)+p|0]=k}}while(0);p=bS-1|0;if((p|0)<=0){break}bR=bR-16|0;bS=p;bT=(c[277223]|0)+bT|0}return}else{if(m){c_=j;c$=i;c0=g}else{return}while(1){g=a[1108908]|0;i=c[277219]|0;do{if((g&255)>(d[i+c0|0]|0)){j=a[c_]|0;m=j&255;if(j<<24>>24==0){c1=g;c2=i;break}do{if((a[1108928]|0)==0){j=b[(c[277225]|0)+(m<<1)>>1]|0;bT=j&65535;bS=bT&63454;if((a[(c[277215]|0)+c0|0]&32)==0){bR=c[277228]|0;c3=(e[(c[277220]|0)+((((bR&-2082)+bS|0)>>>1)+(bT&2081&bR)<<1)>>1]|(bR^bT)&2081)&65535;break}else{bT=b[(c[277213]|0)+(c0<<1)>>1]|0;c3=(((bT&63454)+bS|0)>>>1)+(bT&j&2081)&65535;break}}else{j=e[(c[277225]|0)+(m<<1)>>1]|0;bT=(a[(c[277215]|0)+c0|0]&32)==0;if(bT){bS=c[277228]|0;c4=bS;c5=bS&-2082}else{bS=e[(c[277213]|0)+(c0<<1)>>1]|0;c4=bS;c5=bS&63454}if(bT){c6=c[277228]|0}else{c6=e[(c[277213]|0)+(c0<<1)>>1]|0}c3=((c6^j)&2081|e[(c[277220]|0)+((j&2081&c4)+((c5+(j&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(c0<<1)>>1]=c3;j=(a[(c[277215]|0)+c0|0]&32)==0;do{if((a[1108928]|0)==0){bT=e[(c[277213]|0)+(c0+2<<1)>>1]|0;bS=bT&63454;if(j){bR=c[277228]|0;c7=(e[(c[277220]|0)+((((bR&-2082)+bS|0)>>>1)+(bT&2081&bR)<<1)>>1]|(bR^bT)&2081)&65535;break}else{bR=e[(c[277226]|0)+(m<<1)>>1]|0;c7=(((bR&63454)+bS|0)>>>1)+(bT&2081&bR)&65535;break}}else{if(j){bR=c[277228]|0;c8=bR;c9=(c[277220]|0)+((bR>>>1&2147482607)<<1)|0}else{bR=e[(c[277226]|0)+(m<<1)>>1]|0;c8=bR;c9=(c[277220]|0)+((bR>>>1&31727)<<1)|0}c7=(e[c9>>1]|c8&2081)&65535}}while(0);m=c0+1|0;b[(c[277218]|0)+(m<<1)>>1]=c7;j=a[1108909]|0;a[(c[277219]|0)+m|0]=j;a[(c[277219]|0)+c0|0]=j;c1=a[1108908]|0;c2=c[277219]|0}else{c1=g;c2=i}}while(0);i=c0+2|0;do{if((c1&255)>(d[c2+i|0]|0)){g=a[c_+1|0]|0;j=g&255;if(g<<24>>24==0){da=c1;db=c2;break}do{if((a[1108928]|0)==0){g=b[(c[277225]|0)+(j<<1)>>1]|0;m=g&65535;bR=m&63454;if((a[(c[277215]|0)+i|0]&32)==0){bT=c[277228]|0;dc=(e[(c[277220]|0)+((((bT&-2082)+bR|0)>>>1)+(m&2081&bT)<<1)>>1]|(bT^m)&2081)&65535;break}else{m=b[(c[277213]|0)+(i<<1)>>1]|0;dc=(((m&63454)+bR|0)>>>1)+(m&g&2081)&65535;break}}else{g=e[(c[277225]|0)+(j<<1)>>1]|0;m=(a[(c[277215]|0)+i|0]&32)==0;if(m){bR=c[277228]|0;dd=bR;de=bR&-2082}else{bR=e[(c[277213]|0)+(i<<1)>>1]|0;dd=bR;de=bR&63454}if(m){df=c[277228]|0}else{df=e[(c[277213]|0)+(i<<1)>>1]|0}dc=((df^g)&2081|e[(c[277220]|0)+((g&2081&dd)+((de+(g&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(i<<1)>>1]=dc;g=(a[(c[277215]|0)+i|0]&32)==0;do{if((a[1108928]|0)==0){m=e[(c[277213]|0)+(c0+4<<1)>>1]|0;bR=m&63454;if(g){bT=c[277228]|0;dg=(e[(c[277220]|0)+((((bT&-2082)+bR|0)>>>1)+(m&2081&bT)<<1)>>1]|(bT^m)&2081)&65535;break}else{bT=e[(c[277226]|0)+(j<<1)>>1]|0;dg=(((bT&63454)+bR|0)>>>1)+(m&2081&bT)&65535;break}}else{if(g){bT=c[277228]|0;dh=bT;di=(c[277220]|0)+((bT>>>1&2147482607)<<1)|0}else{bT=e[(c[277226]|0)+(j<<1)>>1]|0;dh=bT;di=(c[277220]|0)+((bT>>>1&31727)<<1)|0}dg=(e[di>>1]|dh&2081)&65535}}while(0);j=c0+3|0;b[(c[277218]|0)+(j<<1)>>1]=dg;g=a[1108909]|0;a[(c[277219]|0)+j|0]=g;a[(c[277219]|0)+i|0]=g;da=a[1108908]|0;db=c[277219]|0}else{da=c1;db=c2}}while(0);i=c0+4|0;do{if((da&255)>(d[db+i|0]|0)){g=a[c_+2|0]|0;j=g&255;if(g<<24>>24==0){dj=da;dk=db;break}do{if((a[1108928]|0)==0){g=b[(c[277225]|0)+(j<<1)>>1]|0;bT=g&65535;m=bT&63454;if((a[(c[277215]|0)+i|0]&32)==0){bR=c[277228]|0;dl=(e[(c[277220]|0)+((((bR&-2082)+m|0)>>>1)+(bT&2081&bR)<<1)>>1]|(bR^bT)&2081)&65535;break}else{bT=b[(c[277213]|0)+(i<<1)>>1]|0;dl=(((bT&63454)+m|0)>>>1)+(bT&g&2081)&65535;break}}else{g=e[(c[277225]|0)+(j<<1)>>1]|0;bT=(a[(c[277215]|0)+i|0]&32)==0;if(bT){m=c[277228]|0;dm=m;dn=m&-2082}else{m=e[(c[277213]|0)+(i<<1)>>1]|0;dm=m;dn=m&63454}if(bT){dp=c[277228]|0}else{dp=e[(c[277213]|0)+(i<<1)>>1]|0}dl=((dp^g)&2081|e[(c[277220]|0)+((g&2081&dm)+((dn+(g&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(i<<1)>>1]=dl;g=(a[(c[277215]|0)+i|0]&32)==0;do{if((a[1108928]|0)==0){bT=e[(c[277213]|0)+(c0+6<<1)>>1]|0;m=bT&63454;if(g){bR=c[277228]|0;dq=(e[(c[277220]|0)+((((bR&-2082)+m|0)>>>1)+(bT&2081&bR)<<1)>>1]|(bR^bT)&2081)&65535;break}else{bR=e[(c[277226]|0)+(j<<1)>>1]|0;dq=(((bR&63454)+m|0)>>>1)+(bT&2081&bR)&65535;break}}else{if(g){bR=c[277228]|0;dr=bR;ds=(c[277220]|0)+((bR>>>1&2147482607)<<1)|0}else{bR=e[(c[277226]|0)+(j<<1)>>1]|0;dr=bR;ds=(c[277220]|0)+((bR>>>1&31727)<<1)|0}dq=(e[ds>>1]|dr&2081)&65535}}while(0);j=c0+5|0;b[(c[277218]|0)+(j<<1)>>1]=dq;g=a[1108909]|0;a[(c[277219]|0)+j|0]=g;a[(c[277219]|0)+i|0]=g;dj=a[1108908]|0;dk=c[277219]|0}else{dj=da;dk=db}}while(0);i=c0+6|0;do{if((dj&255)>(d[dk+i|0]|0)){g=a[c_+3|0]|0;j=g&255;if(g<<24>>24==0){dt=dj;du=dk;break}do{if((a[1108928]|0)==0){g=b[(c[277225]|0)+(j<<1)>>1]|0;bR=g&65535;bT=bR&63454;if((a[(c[277215]|0)+i|0]&32)==0){m=c[277228]|0;dv=(e[(c[277220]|0)+((((m&-2082)+bT|0)>>>1)+(bR&2081&m)<<1)>>1]|(m^bR)&2081)&65535;break}else{bR=b[(c[277213]|0)+(i<<1)>>1]|0;dv=(((bR&63454)+bT|0)>>>1)+(bR&g&2081)&65535;break}}else{g=e[(c[277225]|0)+(j<<1)>>1]|0;bR=(a[(c[277215]|0)+i|0]&32)==0;if(bR){bT=c[277228]|0;dw=bT;dx=bT&-2082}else{bT=e[(c[277213]|0)+(i<<1)>>1]|0;dw=bT;dx=bT&63454}if(bR){dy=c[277228]|0}else{dy=e[(c[277213]|0)+(i<<1)>>1]|0}dv=((dy^g)&2081|e[(c[277220]|0)+((g&2081&dw)+((dx+(g&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(i<<1)>>1]=dv;g=(a[(c[277215]|0)+i|0]&32)==0;do{if((a[1108928]|0)==0){bR=e[(c[277213]|0)+(c0+8<<1)>>1]|0;bT=bR&63454;if(g){m=c[277228]|0;dz=(e[(c[277220]|0)+((((m&-2082)+bT|0)>>>1)+(bR&2081&m)<<1)>>1]|(m^bR)&2081)&65535;break}else{m=e[(c[277226]|0)+(j<<1)>>1]|0;dz=(((m&63454)+bT|0)>>>1)+(bR&2081&m)&65535;break}}else{if(g){m=c[277228]|0;dA=m;dB=(c[277220]|0)+((m>>>1&2147482607)<<1)|0}else{m=e[(c[277226]|0)+(j<<1)>>1]|0;dA=m;dB=(c[277220]|0)+((m>>>1&31727)<<1)|0}dz=(e[dB>>1]|dA&2081)&65535}}while(0);j=c0+7|0;b[(c[277218]|0)+(j<<1)>>1]=dz;g=a[1108909]|0;a[(c[277219]|0)+j|0]=g;a[(c[277219]|0)+i|0]=g;dt=a[1108908]|0;du=c[277219]|0}else{dt=dj;du=dk}}while(0);i=c0+8|0;do{if((dt&255)>(d[du+i|0]|0)){g=a[c_+4|0]|0;j=g&255;if(g<<24>>24==0){dC=dt;dD=du;break}do{if((a[1108928]|0)==0){g=b[(c[277225]|0)+(j<<1)>>1]|0;m=g&65535;bR=m&63454;if((a[(c[277215]|0)+i|0]&32)==0){bT=c[277228]|0;dE=(e[(c[277220]|0)+((((bT&-2082)+bR|0)>>>1)+(m&2081&bT)<<1)>>1]|(bT^m)&2081)&65535;break}else{m=b[(c[277213]|0)+(i<<1)>>1]|0;dE=(((m&63454)+bR|0)>>>1)+(m&g&2081)&65535;break}}else{g=e[(c[277225]|0)+(j<<1)>>1]|0;m=(a[(c[277215]|0)+i|0]&32)==0;if(m){bR=c[277228]|0;dF=bR;dG=bR&-2082}else{bR=e[(c[277213]|0)+(i<<1)>>1]|0;dF=bR;dG=bR&63454}if(m){dH=c[277228]|0}else{dH=e[(c[277213]|0)+(i<<1)>>1]|0}dE=((dH^g)&2081|e[(c[277220]|0)+((g&2081&dF)+((dG+(g&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(i<<1)>>1]=dE;g=(a[(c[277215]|0)+i|0]&32)==0;do{if((a[1108928]|0)==0){m=e[(c[277213]|0)+(c0+10<<1)>>1]|0;bR=m&63454;if(g){bT=c[277228]|0;dI=(e[(c[277220]|0)+((((bT&-2082)+bR|0)>>>1)+(m&2081&bT)<<1)>>1]|(bT^m)&2081)&65535;break}else{bT=e[(c[277226]|0)+(j<<1)>>1]|0;dI=(((bT&63454)+bR|0)>>>1)+(m&2081&bT)&65535;break}}else{if(g){bT=c[277228]|0;dJ=bT;dK=(c[277220]|0)+((bT>>>1&2147482607)<<1)|0}else{bT=e[(c[277226]|0)+(j<<1)>>1]|0;dJ=bT;dK=(c[277220]|0)+((bT>>>1&31727)<<1)|0}dI=(e[dK>>1]|dJ&2081)&65535}}while(0);j=c0+9|0;b[(c[277218]|0)+(j<<1)>>1]=dI;g=a[1108909]|0;a[(c[277219]|0)+j|0]=g;a[(c[277219]|0)+i|0]=g;dC=a[1108908]|0;dD=c[277219]|0}else{dC=dt;dD=du}}while(0);i=c0+10|0;do{if((dC&255)>(d[dD+i|0]|0)){g=a[c_+5|0]|0;j=g&255;if(g<<24>>24==0){dL=dC;dM=dD;break}do{if((a[1108928]|0)==0){g=b[(c[277225]|0)+(j<<1)>>1]|0;bT=g&65535;m=bT&63454;if((a[(c[277215]|0)+i|0]&32)==0){bR=c[277228]|0;dN=(e[(c[277220]|0)+((((bR&-2082)+m|0)>>>1)+(bT&2081&bR)<<1)>>1]|(bR^bT)&2081)&65535;break}else{bT=b[(c[277213]|0)+(i<<1)>>1]|0;dN=(((bT&63454)+m|0)>>>1)+(bT&g&2081)&65535;break}}else{g=e[(c[277225]|0)+(j<<1)>>1]|0;bT=(a[(c[277215]|0)+i|0]&32)==0;if(bT){m=c[277228]|0;dO=m;dP=m&-2082}else{m=e[(c[277213]|0)+(i<<1)>>1]|0;dO=m;dP=m&63454}if(bT){dQ=c[277228]|0}else{dQ=e[(c[277213]|0)+(i<<1)>>1]|0}dN=((dQ^g)&2081|e[(c[277220]|0)+((g&2081&dO)+((dP+(g&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(i<<1)>>1]=dN;g=(a[(c[277215]|0)+i|0]&32)==0;do{if((a[1108928]|0)==0){bT=e[(c[277213]|0)+(c0+12<<1)>>1]|0;m=bT&63454;if(g){bR=c[277228]|0;dR=(e[(c[277220]|0)+((((bR&-2082)+m|0)>>>1)+(bT&2081&bR)<<1)>>1]|(bR^bT)&2081)&65535;break}else{bR=e[(c[277226]|0)+(j<<1)>>1]|0;dR=(((bR&63454)+m|0)>>>1)+(bT&2081&bR)&65535;break}}else{if(g){bR=c[277228]|0;dS=bR;dT=(c[277220]|0)+((bR>>>1&2147482607)<<1)|0}else{bR=e[(c[277226]|0)+(j<<1)>>1]|0;dS=bR;dT=(c[277220]|0)+((bR>>>1&31727)<<1)|0}dR=(e[dT>>1]|dS&2081)&65535}}while(0);j=c0+11|0;b[(c[277218]|0)+(j<<1)>>1]=dR;g=a[1108909]|0;a[(c[277219]|0)+j|0]=g;a[(c[277219]|0)+i|0]=g;dL=a[1108908]|0;dM=c[277219]|0}else{dL=dC;dM=dD}}while(0);i=c0+12|0;do{if((dL&255)>(d[dM+i|0]|0)){g=a[c_+6|0]|0;j=g&255;if(g<<24>>24==0){dU=dL;dV=dM;break}do{if((a[1108928]|0)==0){g=b[(c[277225]|0)+(j<<1)>>1]|0;bR=g&65535;bT=bR&63454;if((a[(c[277215]|0)+i|0]&32)==0){m=c[277228]|0;dW=(e[(c[277220]|0)+((((m&-2082)+bT|0)>>>1)+(bR&2081&m)<<1)>>1]|(m^bR)&2081)&65535;break}else{bR=b[(c[277213]|0)+(i<<1)>>1]|0;dW=(((bR&63454)+bT|0)>>>1)+(bR&g&2081)&65535;break}}else{g=e[(c[277225]|0)+(j<<1)>>1]|0;bR=(a[(c[277215]|0)+i|0]&32)==0;if(bR){bT=c[277228]|0;dX=bT;dY=bT&-2082}else{bT=e[(c[277213]|0)+(i<<1)>>1]|0;dX=bT;dY=bT&63454}if(bR){dZ=c[277228]|0}else{dZ=e[(c[277213]|0)+(i<<1)>>1]|0}dW=((dZ^g)&2081|e[(c[277220]|0)+((g&2081&dX)+((dY+(g&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(i<<1)>>1]=dW;g=(a[(c[277215]|0)+i|0]&32)==0;do{if((a[1108928]|0)==0){bR=e[(c[277213]|0)+(c0+14<<1)>>1]|0;bT=bR&63454;if(g){m=c[277228]|0;d_=(e[(c[277220]|0)+((((m&-2082)+bT|0)>>>1)+(bR&2081&m)<<1)>>1]|(m^bR)&2081)&65535;break}else{m=e[(c[277226]|0)+(j<<1)>>1]|0;d_=(((m&63454)+bT|0)>>>1)+(bR&2081&m)&65535;break}}else{if(g){m=c[277228]|0;d$=m;d0=(c[277220]|0)+((m>>>1&2147482607)<<1)|0}else{m=e[(c[277226]|0)+(j<<1)>>1]|0;d$=m;d0=(c[277220]|0)+((m>>>1&31727)<<1)|0}d_=(e[d0>>1]|d$&2081)&65535}}while(0);j=c0+13|0;b[(c[277218]|0)+(j<<1)>>1]=d_;g=a[1108909]|0;a[(c[277219]|0)+j|0]=g;a[(c[277219]|0)+i|0]=g;dU=a[1108908]|0;dV=c[277219]|0}else{dU=dL;dV=dM}}while(0);i=c0+14|0;do{if((dU&255)>(d[dV+i|0]|0)){g=a[c_+7|0]|0;j=g&255;if(g<<24>>24==0){break}do{if((a[1108928]|0)==0){g=b[(c[277225]|0)+(j<<1)>>1]|0;m=g&65535;bR=m&63454;if((a[(c[277215]|0)+i|0]&32)==0){bT=c[277228]|0;d1=(e[(c[277220]|0)+((((bT&-2082)+bR|0)>>>1)+(m&2081&bT)<<1)>>1]|(bT^m)&2081)&65535;break}else{m=b[(c[277213]|0)+(i<<1)>>1]|0;d1=(((m&63454)+bR|0)>>>1)+(m&g&2081)&65535;break}}else{g=e[(c[277225]|0)+(j<<1)>>1]|0;m=(a[(c[277215]|0)+i|0]&32)==0;if(m){bR=c[277228]|0;d2=bR;d3=bR&-2082}else{bR=e[(c[277213]|0)+(i<<1)>>1]|0;d2=bR;d3=bR&63454}if(m){d4=c[277228]|0}else{d4=e[(c[277213]|0)+(i<<1)>>1]|0}d1=((d4^g)&2081|e[(c[277220]|0)+((g&2081&d2)+((d3+(g&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(i<<1)>>1]=d1;g=(a[(c[277215]|0)+i|0]&32)==0;do{if((a[1108928]|0)==0){m=e[(c[277213]|0)+(c0+16<<1)>>1]|0;bR=m&63454;if(g){bT=c[277228]|0;d5=(e[(c[277220]|0)+((((bT&-2082)+bR|0)>>>1)+(m&2081&bT)<<1)>>1]|(bT^m)&2081)&65535;break}else{bT=e[(c[277226]|0)+(j<<1)>>1]|0;d5=(((bT&63454)+bR|0)>>>1)+(m&2081&bT)&65535;break}}else{if(g){bT=c[277228]|0;d6=bT;d7=(c[277220]|0)+((bT>>>1&2147482607)<<1)|0}else{bT=e[(c[277226]|0)+(j<<1)>>1]|0;d6=bT;d7=(c[277220]|0)+((bT>>>1&31727)<<1)|0}d5=(e[d7>>1]|d6&2081)&65535}}while(0);j=c0+15|0;b[(c[277218]|0)+(j<<1)>>1]=d5;g=a[1108909]|0;a[(c[277219]|0)+j|0]=g;a[(c[277219]|0)+i|0]=g}}while(0);i=c$-1|0;if((i|0)<=0){break}c_=c_-16|0;c$=i;c0=(c[277223]|0)+c0|0}return}}function WD(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0,cf=0,cg=0,ch=0,ci=0,cj=0,ck=0,cl=0,cm=0,cn=0,co=0,cp=0,cq=0,cr=0,cs=0,ct=0,cu=0,cv=0,cw=0,cx=0,cy=0,cz=0,cA=0,cB=0,cC=0,cD=0,cE=0,cF=0,cG=0,cH=0,cI=0,cJ=0,cK=0,cL=0,cM=0,cN=0,cO=0,cP=0,cQ=0,cR=0,cS=0,cT=0,cU=0,cV=0,cW=0,cX=0,cY=0,cZ=0,c_=0,c$=0,c0=0,c1=0,c2=0,c3=0,c4=0,c5=0,c6=0,c7=0,c8=0,c9=0,da=0,db=0,dc=0,dd=0,de=0,df=0,dg=0,dh=0,di=0,dj=0,dk=0,dl=0,dm=0,dn=0,dp=0,dq=0,dr=0,ds=0,dt=0,du=0,dv=0,dw=0,dx=0,dy=0,dz=0,dA=0,dB=0,dC=0,dD=0,dE=0,dF=0,dG=0,dH=0,dI=0,dJ=0,dK=0,dL=0,dM=0,dN=0,dO=0,dP=0,dQ=0,dR=0,dS=0,dT=0,dU=0,dV=0,dW=0,dX=0,dY=0,dZ=0,d_=0,d$=0,d0=0,d1=0,d2=0,d3=0,d4=0,d5=0,d6=0;i=e&1023;j=c[348606]|0;k=(i<<j)+(c[348604]|0)|0;if((e&256|0)==0){l=k}else{l=(c[348602]|0)+k|0}k=l&65535;l=k>>>(j>>>0);j=(e&16384|0)!=0;m=l<<6;do{if(j){n=(c[348622]|0)+m|0;if((a[(c[348618]|0)+l|0]|0)!=0){o=n;break}p=fi[c[348636]&63](n,k,i)|0;a[(c[348618]|0)+l|0]=p;o=n}else{n=(c[348624]|0)+m|0;if((a[(c[348620]|0)+l|0]|0)!=0){o=n;break}p=fi[c[348638]&63](n,k,i)|0;a[(c[348620]|0)+l|0]=p;o=n}}while(0);if((a[(c[348620]|0)+l|0]|0)==2){return}if((a[1394464]|0)==0){q=1106168+((e>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){l=d[1044485]|0;c[276541]=7080+(l<<5);i=0;do{k=i<<1&2;m=i&2;n=i&4;p=0;do{b[1125528+(i<<9)+(p<<1)>>1]=d[(p>>>1&28|m)+(7080+(l<<5))|0]<<6|d[(p<<2&28|k)+(7080+(l<<5))|0]<<11|d[(p>>>3&24|n)+(7080+(l<<5))|0];p=p+1|0;}while(p>>>0<256);i=i+1|0;}while(i>>>0<8);a[1106089]=0}q=1125528+((e>>>10&7)<<9)|0}c[277226]=q;c[277225]=(a[1108928]|0)!=0?1393712:q;if((e&49152|0)==0){if((h|0)<=0){return}q=o+((d[1394504]|0)+(g<<1))|0;i=h;l=f;while(1){p=a[1108908]|0;n=c[277219]|0;do{if((p&255)>(d[n+l|0]|0)){k=a[q]|0;m=k&255;if(k<<24>>24==0){r=p;s=n;break}k=b[(c[277225]|0)+(m<<1)>>1]|0;if((a[(c[277215]|0)+l|0]&32)==0){t=c[277228]&65535}else{t=b[(c[277213]|0)+(l<<1)>>1]|0}u=k&-2048;v=t&-2048;w=(u&65535)>(v&65535)?u-v&65535:0;v=k&2016;u=t&2016;if((v&65535)>(u&65535)){x=(v-u&65535)+w&65535}else{x=w}w=k&31;k=t&31;if((w&65535)>(k&65535)){y=(w-k&65535)+x&65535}else{y=x}b[(c[277218]|0)+(l<<1)>>1]=y;if((a[1108928]|0)==0){z=b[(c[277213]|0)+(l+2<<1)>>1]|0}else{z=0}if((a[(c[277215]|0)+l|0]&32)==0){A=c[277228]&65535}else{A=b[(c[277226]|0)+(m<<1)>>1]|0}m=z&-2048;k=A&-2048;w=(m&65535)>(k&65535)?m-k&65535:0;k=z&2016;m=A&2016;if((k&65535)>(m&65535)){B=(k-m&65535)+w&65535}else{B=w}w=z&31;m=A&31;if((w&65535)>(m&65535)){C=(w-m&65535)+B&65535}else{C=B}m=l+1|0;b[(c[277218]|0)+(m<<1)>>1]=C;w=a[1108909]|0;a[(c[277219]|0)+m|0]=w;a[(c[277219]|0)+l|0]=w;r=a[1108908]|0;s=c[277219]|0}else{r=p;s=n}}while(0);n=l+2|0;do{if((r&255)>(d[s+n|0]|0)){p=a[q+1|0]|0;w=p&255;if(p<<24>>24==0){D=r;E=s;break}p=b[(c[277225]|0)+(w<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)==0){F=c[277228]&65535}else{F=b[(c[277213]|0)+(n<<1)>>1]|0}m=p&-2048;k=F&-2048;u=(m&65535)>(k&65535)?m-k&65535:0;k=p&2016;m=F&2016;if((k&65535)>(m&65535)){G=(k-m&65535)+u&65535}else{G=u}u=p&31;p=F&31;if((u&65535)>(p&65535)){H=(u-p&65535)+G&65535}else{H=G}b[(c[277218]|0)+(n<<1)>>1]=H;if((a[1108928]|0)==0){I=b[(c[277213]|0)+(l+4<<1)>>1]|0}else{I=0}if((a[(c[277215]|0)+n|0]&32)==0){J=c[277228]&65535}else{J=b[(c[277226]|0)+(w<<1)>>1]|0}w=I&-2048;p=J&-2048;u=(w&65535)>(p&65535)?w-p&65535:0;p=I&2016;w=J&2016;if((p&65535)>(w&65535)){K=(p-w&65535)+u&65535}else{K=u}u=I&31;w=J&31;if((u&65535)>(w&65535)){L=(u-w&65535)+K&65535}else{L=K}w=l+3|0;b[(c[277218]|0)+(w<<1)>>1]=L;u=a[1108909]|0;a[(c[277219]|0)+w|0]=u;a[(c[277219]|0)+n|0]=u;D=a[1108908]|0;E=c[277219]|0}else{D=r;E=s}}while(0);n=l+4|0;do{if((D&255)>(d[E+n|0]|0)){u=a[q+2|0]|0;w=u&255;if(u<<24>>24==0){M=D;N=E;break}u=b[(c[277225]|0)+(w<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)==0){O=c[277228]&65535}else{O=b[(c[277213]|0)+(n<<1)>>1]|0}p=u&-2048;m=O&-2048;k=(p&65535)>(m&65535)?p-m&65535:0;m=u&2016;p=O&2016;if((m&65535)>(p&65535)){P=(m-p&65535)+k&65535}else{P=k}k=u&31;u=O&31;if((k&65535)>(u&65535)){Q=(k-u&65535)+P&65535}else{Q=P}b[(c[277218]|0)+(n<<1)>>1]=Q;if((a[1108928]|0)==0){R=b[(c[277213]|0)+(l+6<<1)>>1]|0}else{R=0}if((a[(c[277215]|0)+n|0]&32)==0){S=c[277228]&65535}else{S=b[(c[277226]|0)+(w<<1)>>1]|0}w=R&-2048;u=S&-2048;k=(w&65535)>(u&65535)?w-u&65535:0;u=R&2016;w=S&2016;if((u&65535)>(w&65535)){T=(u-w&65535)+k&65535}else{T=k}k=R&31;w=S&31;if((k&65535)>(w&65535)){U=(k-w&65535)+T&65535}else{U=T}w=l+5|0;b[(c[277218]|0)+(w<<1)>>1]=U;k=a[1108909]|0;a[(c[277219]|0)+w|0]=k;a[(c[277219]|0)+n|0]=k;M=a[1108908]|0;N=c[277219]|0}else{M=D;N=E}}while(0);n=l+6|0;do{if((M&255)>(d[N+n|0]|0)){k=a[q+3|0]|0;w=k&255;if(k<<24>>24==0){V=M;W=N;break}k=b[(c[277225]|0)+(w<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)==0){X=c[277228]&65535}else{X=b[(c[277213]|0)+(n<<1)>>1]|0}u=k&-2048;p=X&-2048;m=(u&65535)>(p&65535)?u-p&65535:0;p=k&2016;u=X&2016;if((p&65535)>(u&65535)){Y=(p-u&65535)+m&65535}else{Y=m}m=k&31;k=X&31;if((m&65535)>(k&65535)){Z=(m-k&65535)+Y&65535}else{Z=Y}b[(c[277218]|0)+(n<<1)>>1]=Z;if((a[1108928]|0)==0){_=b[(c[277213]|0)+(l+8<<1)>>1]|0}else{_=0}if((a[(c[277215]|0)+n|0]&32)==0){$=c[277228]&65535}else{$=b[(c[277226]|0)+(w<<1)>>1]|0}w=_&-2048;k=$&-2048;m=(w&65535)>(k&65535)?w-k&65535:0;k=_&2016;w=$&2016;if((k&65535)>(w&65535)){aa=(k-w&65535)+m&65535}else{aa=m}m=_&31;w=$&31;if((m&65535)>(w&65535)){ab=(m-w&65535)+aa&65535}else{ab=aa}w=l+7|0;b[(c[277218]|0)+(w<<1)>>1]=ab;m=a[1108909]|0;a[(c[277219]|0)+w|0]=m;a[(c[277219]|0)+n|0]=m;V=a[1108908]|0;W=c[277219]|0}else{V=M;W=N}}while(0);n=l+8|0;do{if((V&255)>(d[W+n|0]|0)){m=a[q+4|0]|0;w=m&255;if(m<<24>>24==0){ac=V;ad=W;break}m=b[(c[277225]|0)+(w<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)==0){ae=c[277228]&65535}else{ae=b[(c[277213]|0)+(n<<1)>>1]|0}k=m&-2048;u=ae&-2048;p=(k&65535)>(u&65535)?k-u&65535:0;u=m&2016;k=ae&2016;if((u&65535)>(k&65535)){af=(u-k&65535)+p&65535}else{af=p}p=m&31;m=ae&31;if((p&65535)>(m&65535)){ag=(p-m&65535)+af&65535}else{ag=af}b[(c[277218]|0)+(n<<1)>>1]=ag;if((a[1108928]|0)==0){ah=b[(c[277213]|0)+(l+10<<1)>>1]|0}else{ah=0}if((a[(c[277215]|0)+n|0]&32)==0){ai=c[277228]&65535}else{ai=b[(c[277226]|0)+(w<<1)>>1]|0}w=ah&-2048;m=ai&-2048;p=(w&65535)>(m&65535)?w-m&65535:0;m=ah&2016;w=ai&2016;if((m&65535)>(w&65535)){aj=(m-w&65535)+p&65535}else{aj=p}p=ah&31;w=ai&31;if((p&65535)>(w&65535)){ak=(p-w&65535)+aj&65535}else{ak=aj}w=l+9|0;b[(c[277218]|0)+(w<<1)>>1]=ak;p=a[1108909]|0;a[(c[277219]|0)+w|0]=p;a[(c[277219]|0)+n|0]=p;ac=a[1108908]|0;ad=c[277219]|0}else{ac=V;ad=W}}while(0);n=l+10|0;do{if((ac&255)>(d[ad+n|0]|0)){p=a[q+5|0]|0;w=p&255;if(p<<24>>24==0){al=ac;am=ad;break}p=b[(c[277225]|0)+(w<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)==0){an=c[277228]&65535}else{an=b[(c[277213]|0)+(n<<1)>>1]|0}m=p&-2048;k=an&-2048;u=(m&65535)>(k&65535)?m-k&65535:0;k=p&2016;m=an&2016;if((k&65535)>(m&65535)){ao=(k-m&65535)+u&65535}else{ao=u}u=p&31;p=an&31;if((u&65535)>(p&65535)){ap=(u-p&65535)+ao&65535}else{ap=ao}b[(c[277218]|0)+(n<<1)>>1]=ap;if((a[1108928]|0)==0){aq=b[(c[277213]|0)+(l+12<<1)>>1]|0}else{aq=0}if((a[(c[277215]|0)+n|0]&32)==0){ar=c[277228]&65535}else{ar=b[(c[277226]|0)+(w<<1)>>1]|0}w=aq&-2048;p=ar&-2048;u=(w&65535)>(p&65535)?w-p&65535:0;p=aq&2016;w=ar&2016;if((p&65535)>(w&65535)){as=(p-w&65535)+u&65535}else{as=u}u=aq&31;w=ar&31;if((u&65535)>(w&65535)){at=(u-w&65535)+as&65535}else{at=as}w=l+11|0;b[(c[277218]|0)+(w<<1)>>1]=at;u=a[1108909]|0;a[(c[277219]|0)+w|0]=u;a[(c[277219]|0)+n|0]=u;al=a[1108908]|0;am=c[277219]|0}else{al=ac;am=ad}}while(0);n=l+12|0;do{if((al&255)>(d[am+n|0]|0)){u=a[q+6|0]|0;w=u&255;if(u<<24>>24==0){au=al;av=am;break}u=b[(c[277225]|0)+(w<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)==0){aw=c[277228]&65535}else{aw=b[(c[277213]|0)+(n<<1)>>1]|0}p=u&-2048;m=aw&-2048;k=(p&65535)>(m&65535)?p-m&65535:0;m=u&2016;p=aw&2016;if((m&65535)>(p&65535)){ax=(m-p&65535)+k&65535}else{ax=k}k=u&31;u=aw&31;if((k&65535)>(u&65535)){ay=(k-u&65535)+ax&65535}else{ay=ax}b[(c[277218]|0)+(n<<1)>>1]=ay;if((a[1108928]|0)==0){az=b[(c[277213]|0)+(l+14<<1)>>1]|0}else{az=0}if((a[(c[277215]|0)+n|0]&32)==0){aA=c[277228]&65535}else{aA=b[(c[277226]|0)+(w<<1)>>1]|0}w=az&-2048;u=aA&-2048;k=(w&65535)>(u&65535)?w-u&65535:0;u=az&2016;w=aA&2016;if((u&65535)>(w&65535)){aB=(u-w&65535)+k&65535}else{aB=k}k=az&31;w=aA&31;if((k&65535)>(w&65535)){aC=(k-w&65535)+aB&65535}else{aC=aB}w=l+13|0;b[(c[277218]|0)+(w<<1)>>1]=aC;k=a[1108909]|0;a[(c[277219]|0)+w|0]=k;a[(c[277219]|0)+n|0]=k;au=a[1108908]|0;av=c[277219]|0}else{au=al;av=am}}while(0);n=l+14|0;do{if((au&255)>(d[av+n|0]|0)){k=a[q+7|0]|0;w=k&255;if(k<<24>>24==0){break}k=b[(c[277225]|0)+(w<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)==0){aD=c[277228]&65535}else{aD=b[(c[277213]|0)+(n<<1)>>1]|0}u=k&-2048;p=aD&-2048;m=(u&65535)>(p&65535)?u-p&65535:0;p=k&2016;u=aD&2016;if((p&65535)>(u&65535)){aE=(p-u&65535)+m&65535}else{aE=m}m=k&31;k=aD&31;if((m&65535)>(k&65535)){aF=(m-k&65535)+aE&65535}else{aF=aE}b[(c[277218]|0)+(n<<1)>>1]=aF;if((a[1108928]|0)==0){aG=b[(c[277213]|0)+(l+16<<1)>>1]|0}else{aG=0}if((a[(c[277215]|0)+n|0]&32)==0){aH=c[277228]&65535}else{aH=b[(c[277226]|0)+(w<<1)>>1]|0}w=aG&-2048;k=aH&-2048;m=(w&65535)>(k&65535)?w-k&65535:0;k=aG&2016;w=aH&2016;if((k&65535)>(w&65535)){aI=(k-w&65535)+m&65535}else{aI=m}m=aG&31;w=aH&31;if((m&65535)>(w&65535)){aJ=(m-w&65535)+aI&65535}else{aJ=aI}w=l+15|0;b[(c[277218]|0)+(w<<1)>>1]=aJ;m=a[1108909]|0;a[(c[277219]|0)+w|0]=m;a[(c[277219]|0)+n|0]=m}}while(0);n=i-1|0;if((n|0)<=0){break}q=q+16|0;i=n;l=(c[277223]|0)+l|0}return}l=(d[1394504]|0)+(g<<1)|0;if((e&32768|0)==0){if((h|0)<=0){return}e=o+l|0;g=h;i=f;while(1){q=a[1108908]|0;aJ=c[277219]|0;do{if((q&255)>(d[aJ+i|0]|0)){aI=a[e+7|0]|0;aH=aI&255;if(aI<<24>>24==0){aK=q;aL=aJ;break}aI=b[(c[277225]|0)+(aH<<1)>>1]|0;if((a[(c[277215]|0)+i|0]&32)==0){aM=c[277228]&65535}else{aM=b[(c[277213]|0)+(i<<1)>>1]|0}aG=aI&-2048;aF=aM&-2048;aE=(aG&65535)>(aF&65535)?aG-aF&65535:0;aF=aI&2016;aG=aM&2016;if((aF&65535)>(aG&65535)){aN=(aF-aG&65535)+aE&65535}else{aN=aE}aE=aI&31;aI=aM&31;if((aE&65535)>(aI&65535)){aO=(aE-aI&65535)+aN&65535}else{aO=aN}b[(c[277218]|0)+(i<<1)>>1]=aO;if((a[1108928]|0)==0){aP=b[(c[277213]|0)+(i+2<<1)>>1]|0}else{aP=0}if((a[(c[277215]|0)+i|0]&32)==0){aQ=c[277228]&65535}else{aQ=b[(c[277226]|0)+(aH<<1)>>1]|0}aH=aP&-2048;aI=aQ&-2048;aE=(aH&65535)>(aI&65535)?aH-aI&65535:0;aI=aP&2016;aH=aQ&2016;if((aI&65535)>(aH&65535)){aR=(aI-aH&65535)+aE&65535}else{aR=aE}aE=aP&31;aH=aQ&31;if((aE&65535)>(aH&65535)){aS=(aE-aH&65535)+aR&65535}else{aS=aR}aH=i+1|0;b[(c[277218]|0)+(aH<<1)>>1]=aS;aE=a[1108909]|0;a[(c[277219]|0)+aH|0]=aE;a[(c[277219]|0)+i|0]=aE;aK=a[1108908]|0;aL=c[277219]|0}else{aK=q;aL=aJ}}while(0);aJ=i+2|0;do{if((aK&255)>(d[aL+aJ|0]|0)){q=a[e+6|0]|0;aE=q&255;if(q<<24>>24==0){aT=aK;aU=aL;break}q=b[(c[277225]|0)+(aE<<1)>>1]|0;if((a[(c[277215]|0)+aJ|0]&32)==0){aV=c[277228]&65535}else{aV=b[(c[277213]|0)+(aJ<<1)>>1]|0}aH=q&-2048;aI=aV&-2048;aG=(aH&65535)>(aI&65535)?aH-aI&65535:0;aI=q&2016;aH=aV&2016;if((aI&65535)>(aH&65535)){aW=(aI-aH&65535)+aG&65535}else{aW=aG}aG=q&31;q=aV&31;if((aG&65535)>(q&65535)){aX=(aG-q&65535)+aW&65535}else{aX=aW}b[(c[277218]|0)+(aJ<<1)>>1]=aX;if((a[1108928]|0)==0){aY=b[(c[277213]|0)+(i+4<<1)>>1]|0}else{aY=0}if((a[(c[277215]|0)+aJ|0]&32)==0){aZ=c[277228]&65535}else{aZ=b[(c[277226]|0)+(aE<<1)>>1]|0}aE=aY&-2048;q=aZ&-2048;aG=(aE&65535)>(q&65535)?aE-q&65535:0;q=aY&2016;aE=aZ&2016;if((q&65535)>(aE&65535)){a_=(q-aE&65535)+aG&65535}else{a_=aG}aG=aY&31;aE=aZ&31;if((aG&65535)>(aE&65535)){a$=(aG-aE&65535)+a_&65535}else{a$=a_}aE=i+3|0;b[(c[277218]|0)+(aE<<1)>>1]=a$;aG=a[1108909]|0;a[(c[277219]|0)+aE|0]=aG;a[(c[277219]|0)+aJ|0]=aG;aT=a[1108908]|0;aU=c[277219]|0}else{aT=aK;aU=aL}}while(0);aJ=i+4|0;do{if((aT&255)>(d[aU+aJ|0]|0)){aG=a[e+5|0]|0;aE=aG&255;if(aG<<24>>24==0){a0=aT;a1=aU;break}aG=b[(c[277225]|0)+(aE<<1)>>1]|0;if((a[(c[277215]|0)+aJ|0]&32)==0){a2=c[277228]&65535}else{a2=b[(c[277213]|0)+(aJ<<1)>>1]|0}q=aG&-2048;aH=a2&-2048;aI=(q&65535)>(aH&65535)?q-aH&65535:0;aH=aG&2016;q=a2&2016;if((aH&65535)>(q&65535)){a3=(aH-q&65535)+aI&65535}else{a3=aI}aI=aG&31;aG=a2&31;if((aI&65535)>(aG&65535)){a4=(aI-aG&65535)+a3&65535}else{a4=a3}b[(c[277218]|0)+(aJ<<1)>>1]=a4;if((a[1108928]|0)==0){a5=b[(c[277213]|0)+(i+6<<1)>>1]|0}else{a5=0}if((a[(c[277215]|0)+aJ|0]&32)==0){a6=c[277228]&65535}else{a6=b[(c[277226]|0)+(aE<<1)>>1]|0}aE=a5&-2048;aG=a6&-2048;aI=(aE&65535)>(aG&65535)?aE-aG&65535:0;aG=a5&2016;aE=a6&2016;if((aG&65535)>(aE&65535)){a7=(aG-aE&65535)+aI&65535}else{a7=aI}aI=a5&31;aE=a6&31;if((aI&65535)>(aE&65535)){a8=(aI-aE&65535)+a7&65535}else{a8=a7}aE=i+5|0;b[(c[277218]|0)+(aE<<1)>>1]=a8;aI=a[1108909]|0;a[(c[277219]|0)+aE|0]=aI;a[(c[277219]|0)+aJ|0]=aI;a0=a[1108908]|0;a1=c[277219]|0}else{a0=aT;a1=aU}}while(0);aJ=i+6|0;do{if((a0&255)>(d[a1+aJ|0]|0)){aI=a[e+4|0]|0;aE=aI&255;if(aI<<24>>24==0){a9=a0;ba=a1;break}aI=b[(c[277225]|0)+(aE<<1)>>1]|0;if((a[(c[277215]|0)+aJ|0]&32)==0){bb=c[277228]&65535}else{bb=b[(c[277213]|0)+(aJ<<1)>>1]|0}aG=aI&-2048;q=bb&-2048;aH=(aG&65535)>(q&65535)?aG-q&65535:0;q=aI&2016;aG=bb&2016;if((q&65535)>(aG&65535)){bc=(q-aG&65535)+aH&65535}else{bc=aH}aH=aI&31;aI=bb&31;if((aH&65535)>(aI&65535)){bd=(aH-aI&65535)+bc&65535}else{bd=bc}b[(c[277218]|0)+(aJ<<1)>>1]=bd;if((a[1108928]|0)==0){be=b[(c[277213]|0)+(i+8<<1)>>1]|0}else{be=0}if((a[(c[277215]|0)+aJ|0]&32)==0){bf=c[277228]&65535}else{bf=b[(c[277226]|0)+(aE<<1)>>1]|0}aE=be&-2048;aI=bf&-2048;aH=(aE&65535)>(aI&65535)?aE-aI&65535:0;aI=be&2016;aE=bf&2016;if((aI&65535)>(aE&65535)){bg=(aI-aE&65535)+aH&65535}else{bg=aH}aH=be&31;aE=bf&31;if((aH&65535)>(aE&65535)){bh=(aH-aE&65535)+bg&65535}else{bh=bg}aE=i+7|0;b[(c[277218]|0)+(aE<<1)>>1]=bh;aH=a[1108909]|0;a[(c[277219]|0)+aE|0]=aH;a[(c[277219]|0)+aJ|0]=aH;a9=a[1108908]|0;ba=c[277219]|0}else{a9=a0;ba=a1}}while(0);aJ=i+8|0;do{if((a9&255)>(d[ba+aJ|0]|0)){aH=a[e+3|0]|0;aE=aH&255;if(aH<<24>>24==0){bi=a9;bj=ba;break}aH=b[(c[277225]|0)+(aE<<1)>>1]|0;if((a[(c[277215]|0)+aJ|0]&32)==0){bk=c[277228]&65535}else{bk=b[(c[277213]|0)+(aJ<<1)>>1]|0}aI=aH&-2048;aG=bk&-2048;q=(aI&65535)>(aG&65535)?aI-aG&65535:0;aG=aH&2016;aI=bk&2016;if((aG&65535)>(aI&65535)){bl=(aG-aI&65535)+q&65535}else{bl=q}q=aH&31;aH=bk&31;if((q&65535)>(aH&65535)){bm=(q-aH&65535)+bl&65535}else{bm=bl}b[(c[277218]|0)+(aJ<<1)>>1]=bm;if((a[1108928]|0)==0){bn=b[(c[277213]|0)+(i+10<<1)>>1]|0}else{bn=0}if((a[(c[277215]|0)+aJ|0]&32)==0){bo=c[277228]&65535}else{bo=b[(c[277226]|0)+(aE<<1)>>1]|0}aE=bn&-2048;aH=bo&-2048;q=(aE&65535)>(aH&65535)?aE-aH&65535:0;aH=bn&2016;aE=bo&2016;if((aH&65535)>(aE&65535)){bp=(aH-aE&65535)+q&65535}else{bp=q}q=bn&31;aE=bo&31;if((q&65535)>(aE&65535)){bq=(q-aE&65535)+bp&65535}else{bq=bp}aE=i+9|0;b[(c[277218]|0)+(aE<<1)>>1]=bq;q=a[1108909]|0;a[(c[277219]|0)+aE|0]=q;a[(c[277219]|0)+aJ|0]=q;bi=a[1108908]|0;bj=c[277219]|0}else{bi=a9;bj=ba}}while(0);aJ=i+10|0;do{if((bi&255)>(d[bj+aJ|0]|0)){q=a[e+2|0]|0;aE=q&255;if(q<<24>>24==0){br=bi;bs=bj;break}q=b[(c[277225]|0)+(aE<<1)>>1]|0;if((a[(c[277215]|0)+aJ|0]&32)==0){bt=c[277228]&65535}else{bt=b[(c[277213]|0)+(aJ<<1)>>1]|0}aH=q&-2048;aI=bt&-2048;aG=(aH&65535)>(aI&65535)?aH-aI&65535:0;aI=q&2016;aH=bt&2016;if((aI&65535)>(aH&65535)){bu=(aI-aH&65535)+aG&65535}else{bu=aG}aG=q&31;q=bt&31;if((aG&65535)>(q&65535)){bv=(aG-q&65535)+bu&65535}else{bv=bu}b[(c[277218]|0)+(aJ<<1)>>1]=bv;if((a[1108928]|0)==0){bw=b[(c[277213]|0)+(i+12<<1)>>1]|0}else{bw=0}if((a[(c[277215]|0)+aJ|0]&32)==0){bx=c[277228]&65535}else{bx=b[(c[277226]|0)+(aE<<1)>>1]|0}aE=bw&-2048;q=bx&-2048;aG=(aE&65535)>(q&65535)?aE-q&65535:0;q=bw&2016;aE=bx&2016;if((q&65535)>(aE&65535)){by=(q-aE&65535)+aG&65535}else{by=aG}aG=bw&31;aE=bx&31;if((aG&65535)>(aE&65535)){bz=(aG-aE&65535)+by&65535}else{bz=by}aE=i+11|0;b[(c[277218]|0)+(aE<<1)>>1]=bz;aG=a[1108909]|0;a[(c[277219]|0)+aE|0]=aG;a[(c[277219]|0)+aJ|0]=aG;br=a[1108908]|0;bs=c[277219]|0}else{br=bi;bs=bj}}while(0);aJ=i+12|0;do{if((br&255)>(d[bs+aJ|0]|0)){aG=a[e+1|0]|0;aE=aG&255;if(aG<<24>>24==0){bA=br;bB=bs;break}aG=b[(c[277225]|0)+(aE<<1)>>1]|0;if((a[(c[277215]|0)+aJ|0]&32)==0){bC=c[277228]&65535}else{bC=b[(c[277213]|0)+(aJ<<1)>>1]|0}q=aG&-2048;aH=bC&-2048;aI=(q&65535)>(aH&65535)?q-aH&65535:0;aH=aG&2016;q=bC&2016;if((aH&65535)>(q&65535)){bD=(aH-q&65535)+aI&65535}else{bD=aI}aI=aG&31;aG=bC&31;if((aI&65535)>(aG&65535)){bE=(aI-aG&65535)+bD&65535}else{bE=bD}b[(c[277218]|0)+(aJ<<1)>>1]=bE;if((a[1108928]|0)==0){bF=b[(c[277213]|0)+(i+14<<1)>>1]|0}else{bF=0}if((a[(c[277215]|0)+aJ|0]&32)==0){bG=c[277228]&65535}else{bG=b[(c[277226]|0)+(aE<<1)>>1]|0}aE=bF&-2048;aG=bG&-2048;aI=(aE&65535)>(aG&65535)?aE-aG&65535:0;aG=bF&2016;aE=bG&2016;if((aG&65535)>(aE&65535)){bH=(aG-aE&65535)+aI&65535}else{bH=aI}aI=bF&31;aE=bG&31;if((aI&65535)>(aE&65535)){bI=(aI-aE&65535)+bH&65535}else{bI=bH}aE=i+13|0;b[(c[277218]|0)+(aE<<1)>>1]=bI;aI=a[1108909]|0;a[(c[277219]|0)+aE|0]=aI;a[(c[277219]|0)+aJ|0]=aI;bA=a[1108908]|0;bB=c[277219]|0}else{bA=br;bB=bs}}while(0);aJ=i+14|0;do{if((bA&255)>(d[bB+aJ|0]|0)){aI=a[e]|0;aE=aI&255;if(aI<<24>>24==0){break}aI=b[(c[277225]|0)+(aE<<1)>>1]|0;if((a[(c[277215]|0)+aJ|0]&32)==0){bJ=c[277228]&65535}else{bJ=b[(c[277213]|0)+(aJ<<1)>>1]|0}aG=aI&-2048;q=bJ&-2048;aH=(aG&65535)>(q&65535)?aG-q&65535:0;q=aI&2016;aG=bJ&2016;if((q&65535)>(aG&65535)){bK=(q-aG&65535)+aH&65535}else{bK=aH}aH=aI&31;aI=bJ&31;if((aH&65535)>(aI&65535)){bL=(aH-aI&65535)+bK&65535}else{bL=bK}b[(c[277218]|0)+(aJ<<1)>>1]=bL;if((a[1108928]|0)==0){bM=b[(c[277213]|0)+(i+16<<1)>>1]|0}else{bM=0}if((a[(c[277215]|0)+aJ|0]&32)==0){bN=c[277228]&65535}else{bN=b[(c[277226]|0)+(aE<<1)>>1]|0}aE=bM&-2048;aI=bN&-2048;aH=(aE&65535)>(aI&65535)?aE-aI&65535:0;aI=bM&2016;aE=bN&2016;if((aI&65535)>(aE&65535)){bO=(aI-aE&65535)+aH&65535}else{bO=aH}aH=bM&31;aE=bN&31;if((aH&65535)>(aE&65535)){bP=(aH-aE&65535)+bO&65535}else{bP=bO}aE=i+15|0;b[(c[277218]|0)+(aE<<1)>>1]=bP;aH=a[1108909]|0;a[(c[277219]|0)+aE|0]=aH;a[(c[277219]|0)+aJ|0]=aH}}while(0);aJ=g-1|0;if((aJ|0)<=0){break}e=e+16|0;g=aJ;i=(c[277223]|0)+i|0}return}i=o+(56-l)|0;l=(h|0)>0;if(j){if(l){bQ=i;bR=h;bS=f}else{return}while(1){j=a[1108908]|0;o=c[277219]|0;do{if((j&255)>(d[o+bS|0]|0)){g=a[bQ+7|0]|0;e=g&255;if(g<<24>>24==0){bT=j;bU=o;break}g=b[(c[277225]|0)+(e<<1)>>1]|0;if((a[(c[277215]|0)+bS|0]&32)==0){bV=c[277228]&65535}else{bV=b[(c[277213]|0)+(bS<<1)>>1]|0}bP=g&-2048;bO=bV&-2048;bN=(bP&65535)>(bO&65535)?bP-bO&65535:0;bO=g&2016;bP=bV&2016;if((bO&65535)>(bP&65535)){bW=(bO-bP&65535)+bN&65535}else{bW=bN}bN=g&31;g=bV&31;if((bN&65535)>(g&65535)){bX=(bN-g&65535)+bW&65535}else{bX=bW}b[(c[277218]|0)+(bS<<1)>>1]=bX;if((a[1108928]|0)==0){bY=b[(c[277213]|0)+(bS+2<<1)>>1]|0}else{bY=0}if((a[(c[277215]|0)+bS|0]&32)==0){bZ=c[277228]&65535}else{bZ=b[(c[277226]|0)+(e<<1)>>1]|0}e=bY&-2048;g=bZ&-2048;bN=(e&65535)>(g&65535)?e-g&65535:0;g=bY&2016;e=bZ&2016;if((g&65535)>(e&65535)){b_=(g-e&65535)+bN&65535}else{b_=bN}bN=bY&31;e=bZ&31;if((bN&65535)>(e&65535)){b$=(bN-e&65535)+b_&65535}else{b$=b_}e=bS+1|0;b[(c[277218]|0)+(e<<1)>>1]=b$;bN=a[1108909]|0;a[(c[277219]|0)+e|0]=bN;a[(c[277219]|0)+bS|0]=bN;bT=a[1108908]|0;bU=c[277219]|0}else{bT=j;bU=o}}while(0);o=bS+2|0;do{if((bT&255)>(d[bU+o|0]|0)){j=a[bQ+6|0]|0;bN=j&255;if(j<<24>>24==0){b0=bT;b1=bU;break}j=b[(c[277225]|0)+(bN<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){b2=c[277228]&65535}else{b2=b[(c[277213]|0)+(o<<1)>>1]|0}e=j&-2048;g=b2&-2048;bP=(e&65535)>(g&65535)?e-g&65535:0;g=j&2016;e=b2&2016;if((g&65535)>(e&65535)){b3=(g-e&65535)+bP&65535}else{b3=bP}bP=j&31;j=b2&31;if((bP&65535)>(j&65535)){b4=(bP-j&65535)+b3&65535}else{b4=b3}b[(c[277218]|0)+(o<<1)>>1]=b4;if((a[1108928]|0)==0){b5=b[(c[277213]|0)+(bS+4<<1)>>1]|0}else{b5=0}if((a[(c[277215]|0)+o|0]&32)==0){b6=c[277228]&65535}else{b6=b[(c[277226]|0)+(bN<<1)>>1]|0}bN=b5&-2048;j=b6&-2048;bP=(bN&65535)>(j&65535)?bN-j&65535:0;j=b5&2016;bN=b6&2016;if((j&65535)>(bN&65535)){b7=(j-bN&65535)+bP&65535}else{b7=bP}bP=b5&31;bN=b6&31;if((bP&65535)>(bN&65535)){b8=(bP-bN&65535)+b7&65535}else{b8=b7}bN=bS+3|0;b[(c[277218]|0)+(bN<<1)>>1]=b8;bP=a[1108909]|0;a[(c[277219]|0)+bN|0]=bP;a[(c[277219]|0)+o|0]=bP;b0=a[1108908]|0;b1=c[277219]|0}else{b0=bT;b1=bU}}while(0);o=bS+4|0;do{if((b0&255)>(d[b1+o|0]|0)){bP=a[bQ+5|0]|0;bN=bP&255;if(bP<<24>>24==0){b9=b0;ca=b1;break}bP=b[(c[277225]|0)+(bN<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){cb=c[277228]&65535}else{cb=b[(c[277213]|0)+(o<<1)>>1]|0}j=bP&-2048;e=cb&-2048;g=(j&65535)>(e&65535)?j-e&65535:0;e=bP&2016;j=cb&2016;if((e&65535)>(j&65535)){cc=(e-j&65535)+g&65535}else{cc=g}g=bP&31;bP=cb&31;if((g&65535)>(bP&65535)){cd=(g-bP&65535)+cc&65535}else{cd=cc}b[(c[277218]|0)+(o<<1)>>1]=cd;if((a[1108928]|0)==0){ce=b[(c[277213]|0)+(bS+6<<1)>>1]|0}else{ce=0}if((a[(c[277215]|0)+o|0]&32)==0){cf=c[277228]&65535}else{cf=b[(c[277226]|0)+(bN<<1)>>1]|0}bN=ce&-2048;bP=cf&-2048;g=(bN&65535)>(bP&65535)?bN-bP&65535:0;bP=ce&2016;bN=cf&2016;if((bP&65535)>(bN&65535)){cg=(bP-bN&65535)+g&65535}else{cg=g}g=ce&31;bN=cf&31;if((g&65535)>(bN&65535)){ch=(g-bN&65535)+cg&65535}else{ch=cg}bN=bS+5|0;b[(c[277218]|0)+(bN<<1)>>1]=ch;g=a[1108909]|0;a[(c[277219]|0)+bN|0]=g;a[(c[277219]|0)+o|0]=g;b9=a[1108908]|0;ca=c[277219]|0}else{b9=b0;ca=b1}}while(0);o=bS+6|0;do{if((b9&255)>(d[ca+o|0]|0)){g=a[bQ+4|0]|0;bN=g&255;if(g<<24>>24==0){ci=b9;cj=ca;break}g=b[(c[277225]|0)+(bN<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){ck=c[277228]&65535}else{ck=b[(c[277213]|0)+(o<<1)>>1]|0}bP=g&-2048;j=ck&-2048;e=(bP&65535)>(j&65535)?bP-j&65535:0;j=g&2016;bP=ck&2016;if((j&65535)>(bP&65535)){cl=(j-bP&65535)+e&65535}else{cl=e}e=g&31;g=ck&31;if((e&65535)>(g&65535)){cm=(e-g&65535)+cl&65535}else{cm=cl}b[(c[277218]|0)+(o<<1)>>1]=cm;if((a[1108928]|0)==0){cn=b[(c[277213]|0)+(bS+8<<1)>>1]|0}else{cn=0}if((a[(c[277215]|0)+o|0]&32)==0){co=c[277228]&65535}else{co=b[(c[277226]|0)+(bN<<1)>>1]|0}bN=cn&-2048;g=co&-2048;e=(bN&65535)>(g&65535)?bN-g&65535:0;g=cn&2016;bN=co&2016;if((g&65535)>(bN&65535)){cp=(g-bN&65535)+e&65535}else{cp=e}e=cn&31;bN=co&31;if((e&65535)>(bN&65535)){cq=(e-bN&65535)+cp&65535}else{cq=cp}bN=bS+7|0;b[(c[277218]|0)+(bN<<1)>>1]=cq;e=a[1108909]|0;a[(c[277219]|0)+bN|0]=e;a[(c[277219]|0)+o|0]=e;ci=a[1108908]|0;cj=c[277219]|0}else{ci=b9;cj=ca}}while(0);o=bS+8|0;do{if((ci&255)>(d[cj+o|0]|0)){e=a[bQ+3|0]|0;bN=e&255;if(e<<24>>24==0){cr=ci;cs=cj;break}e=b[(c[277225]|0)+(bN<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){ct=c[277228]&65535}else{ct=b[(c[277213]|0)+(o<<1)>>1]|0}g=e&-2048;bP=ct&-2048;j=(g&65535)>(bP&65535)?g-bP&65535:0;bP=e&2016;g=ct&2016;if((bP&65535)>(g&65535)){cu=(bP-g&65535)+j&65535}else{cu=j}j=e&31;e=ct&31;if((j&65535)>(e&65535)){cv=(j-e&65535)+cu&65535}else{cv=cu}b[(c[277218]|0)+(o<<1)>>1]=cv;if((a[1108928]|0)==0){cw=b[(c[277213]|0)+(bS+10<<1)>>1]|0}else{cw=0}if((a[(c[277215]|0)+o|0]&32)==0){cx=c[277228]&65535}else{cx=b[(c[277226]|0)+(bN<<1)>>1]|0}bN=cw&-2048;e=cx&-2048;j=(bN&65535)>(e&65535)?bN-e&65535:0;e=cw&2016;bN=cx&2016;if((e&65535)>(bN&65535)){cy=(e-bN&65535)+j&65535}else{cy=j}j=cw&31;bN=cx&31;if((j&65535)>(bN&65535)){cz=(j-bN&65535)+cy&65535}else{cz=cy}bN=bS+9|0;b[(c[277218]|0)+(bN<<1)>>1]=cz;j=a[1108909]|0;a[(c[277219]|0)+bN|0]=j;a[(c[277219]|0)+o|0]=j;cr=a[1108908]|0;cs=c[277219]|0}else{cr=ci;cs=cj}}while(0);o=bS+10|0;do{if((cr&255)>(d[cs+o|0]|0)){j=a[bQ+2|0]|0;bN=j&255;if(j<<24>>24==0){cA=cr;cB=cs;break}j=b[(c[277225]|0)+(bN<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){cC=c[277228]&65535}else{cC=b[(c[277213]|0)+(o<<1)>>1]|0}e=j&-2048;g=cC&-2048;bP=(e&65535)>(g&65535)?e-g&65535:0;g=j&2016;e=cC&2016;if((g&65535)>(e&65535)){cD=(g-e&65535)+bP&65535}else{cD=bP}bP=j&31;j=cC&31;if((bP&65535)>(j&65535)){cE=(bP-j&65535)+cD&65535}else{cE=cD}b[(c[277218]|0)+(o<<1)>>1]=cE;if((a[1108928]|0)==0){cF=b[(c[277213]|0)+(bS+12<<1)>>1]|0}else{cF=0}if((a[(c[277215]|0)+o|0]&32)==0){cG=c[277228]&65535}else{cG=b[(c[277226]|0)+(bN<<1)>>1]|0}bN=cF&-2048;j=cG&-2048;bP=(bN&65535)>(j&65535)?bN-j&65535:0;j=cF&2016;bN=cG&2016;if((j&65535)>(bN&65535)){cH=(j-bN&65535)+bP&65535}else{cH=bP}bP=cF&31;bN=cG&31;if((bP&65535)>(bN&65535)){cI=(bP-bN&65535)+cH&65535}else{cI=cH}bN=bS+11|0;b[(c[277218]|0)+(bN<<1)>>1]=cI;bP=a[1108909]|0;a[(c[277219]|0)+bN|0]=bP;a[(c[277219]|0)+o|0]=bP;cA=a[1108908]|0;cB=c[277219]|0}else{cA=cr;cB=cs}}while(0);o=bS+12|0;do{if((cA&255)>(d[cB+o|0]|0)){bP=a[bQ+1|0]|0;bN=bP&255;if(bP<<24>>24==0){cJ=cA;cK=cB;break}bP=b[(c[277225]|0)+(bN<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){cL=c[277228]&65535}else{cL=b[(c[277213]|0)+(o<<1)>>1]|0}j=bP&-2048;e=cL&-2048;g=(j&65535)>(e&65535)?j-e&65535:0;e=bP&2016;j=cL&2016;if((e&65535)>(j&65535)){cM=(e-j&65535)+g&65535}else{cM=g}g=bP&31;bP=cL&31;if((g&65535)>(bP&65535)){cN=(g-bP&65535)+cM&65535}else{cN=cM}b[(c[277218]|0)+(o<<1)>>1]=cN;if((a[1108928]|0)==0){cO=b[(c[277213]|0)+(bS+14<<1)>>1]|0}else{cO=0}if((a[(c[277215]|0)+o|0]&32)==0){cP=c[277228]&65535}else{cP=b[(c[277226]|0)+(bN<<1)>>1]|0}bN=cO&-2048;bP=cP&-2048;g=(bN&65535)>(bP&65535)?bN-bP&65535:0;bP=cO&2016;bN=cP&2016;if((bP&65535)>(bN&65535)){cQ=(bP-bN&65535)+g&65535}else{cQ=g}g=cO&31;bN=cP&31;if((g&65535)>(bN&65535)){cR=(g-bN&65535)+cQ&65535}else{cR=cQ}bN=bS+13|0;b[(c[277218]|0)+(bN<<1)>>1]=cR;g=a[1108909]|0;a[(c[277219]|0)+bN|0]=g;a[(c[277219]|0)+o|0]=g;cJ=a[1108908]|0;cK=c[277219]|0}else{cJ=cA;cK=cB}}while(0);o=bS+14|0;do{if((cJ&255)>(d[cK+o|0]|0)){g=a[bQ]|0;bN=g&255;if(g<<24>>24==0){break}g=b[(c[277225]|0)+(bN<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){cS=c[277228]&65535}else{cS=b[(c[277213]|0)+(o<<1)>>1]|0}bP=g&-2048;j=cS&-2048;e=(bP&65535)>(j&65535)?bP-j&65535:0;j=g&2016;bP=cS&2016;if((j&65535)>(bP&65535)){cT=(j-bP&65535)+e&65535}else{cT=e}e=g&31;g=cS&31;if((e&65535)>(g&65535)){cU=(e-g&65535)+cT&65535}else{cU=cT}b[(c[277218]|0)+(o<<1)>>1]=cU;if((a[1108928]|0)==0){cV=b[(c[277213]|0)+(bS+16<<1)>>1]|0}else{cV=0}if((a[(c[277215]|0)+o|0]&32)==0){cW=c[277228]&65535}else{cW=b[(c[277226]|0)+(bN<<1)>>1]|0}bN=cV&-2048;g=cW&-2048;e=(bN&65535)>(g&65535)?bN-g&65535:0;g=cV&2016;bN=cW&2016;if((g&65535)>(bN&65535)){cX=(g-bN&65535)+e&65535}else{cX=e}e=cV&31;bN=cW&31;if((e&65535)>(bN&65535)){cY=(e-bN&65535)+cX&65535}else{cY=cX}bN=bS+15|0;b[(c[277218]|0)+(bN<<1)>>1]=cY;e=a[1108909]|0;a[(c[277219]|0)+bN|0]=e;a[(c[277219]|0)+o|0]=e}}while(0);o=bR-1|0;if((o|0)<=0){break}bQ=bQ-16|0;bR=o;bS=(c[277223]|0)+bS|0}return}else{if(l){cZ=i;c_=h;c$=f}else{return}while(1){f=a[1108908]|0;h=c[277219]|0;do{if((f&255)>(d[h+c$|0]|0)){i=a[cZ]|0;l=i&255;if(i<<24>>24==0){c0=f;c1=h;break}i=b[(c[277225]|0)+(l<<1)>>1]|0;if((a[(c[277215]|0)+c$|0]&32)==0){c2=c[277228]&65535}else{c2=b[(c[277213]|0)+(c$<<1)>>1]|0}bS=i&-2048;bR=c2&-2048;bQ=(bS&65535)>(bR&65535)?bS-bR&65535:0;bR=i&2016;bS=c2&2016;if((bR&65535)>(bS&65535)){c3=(bR-bS&65535)+bQ&65535}else{c3=bQ}bQ=i&31;i=c2&31;if((bQ&65535)>(i&65535)){c4=(bQ-i&65535)+c3&65535}else{c4=c3}b[(c[277218]|0)+(c$<<1)>>1]=c4;if((a[1108928]|0)==0){c5=b[(c[277213]|0)+(c$+2<<1)>>1]|0}else{c5=0}if((a[(c[277215]|0)+c$|0]&32)==0){c6=c[277228]&65535}else{c6=b[(c[277226]|0)+(l<<1)>>1]|0}l=c5&-2048;i=c6&-2048;bQ=(l&65535)>(i&65535)?l-i&65535:0;i=c5&2016;l=c6&2016;if((i&65535)>(l&65535)){c7=(i-l&65535)+bQ&65535}else{c7=bQ}bQ=c5&31;l=c6&31;if((bQ&65535)>(l&65535)){c8=(bQ-l&65535)+c7&65535}else{c8=c7}l=c$+1|0;b[(c[277218]|0)+(l<<1)>>1]=c8;bQ=a[1108909]|0;a[(c[277219]|0)+l|0]=bQ;a[(c[277219]|0)+c$|0]=bQ;c0=a[1108908]|0;c1=c[277219]|0}else{c0=f;c1=h}}while(0);h=c$+2|0;do{if((c0&255)>(d[c1+h|0]|0)){f=a[cZ+1|0]|0;bQ=f&255;if(f<<24>>24==0){c9=c0;da=c1;break}f=b[(c[277225]|0)+(bQ<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)==0){db=c[277228]&65535}else{db=b[(c[277213]|0)+(h<<1)>>1]|0}l=f&-2048;i=db&-2048;bS=(l&65535)>(i&65535)?l-i&65535:0;i=f&2016;l=db&2016;if((i&65535)>(l&65535)){dc=(i-l&65535)+bS&65535}else{dc=bS}bS=f&31;f=db&31;if((bS&65535)>(f&65535)){dd=(bS-f&65535)+dc&65535}else{dd=dc}b[(c[277218]|0)+(h<<1)>>1]=dd;if((a[1108928]|0)==0){de=b[(c[277213]|0)+(c$+4<<1)>>1]|0}else{de=0}if((a[(c[277215]|0)+h|0]&32)==0){df=c[277228]&65535}else{df=b[(c[277226]|0)+(bQ<<1)>>1]|0}bQ=de&-2048;f=df&-2048;bS=(bQ&65535)>(f&65535)?bQ-f&65535:0;f=de&2016;bQ=df&2016;if((f&65535)>(bQ&65535)){dg=(f-bQ&65535)+bS&65535}else{dg=bS}bS=de&31;bQ=df&31;if((bS&65535)>(bQ&65535)){dh=(bS-bQ&65535)+dg&65535}else{dh=dg}bQ=c$+3|0;b[(c[277218]|0)+(bQ<<1)>>1]=dh;bS=a[1108909]|0;a[(c[277219]|0)+bQ|0]=bS;a[(c[277219]|0)+h|0]=bS;c9=a[1108908]|0;da=c[277219]|0}else{c9=c0;da=c1}}while(0);h=c$+4|0;do{if((c9&255)>(d[da+h|0]|0)){bS=a[cZ+2|0]|0;bQ=bS&255;if(bS<<24>>24==0){di=c9;dj=da;break}bS=b[(c[277225]|0)+(bQ<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)==0){dk=c[277228]&65535}else{dk=b[(c[277213]|0)+(h<<1)>>1]|0}f=bS&-2048;l=dk&-2048;i=(f&65535)>(l&65535)?f-l&65535:0;l=bS&2016;f=dk&2016;if((l&65535)>(f&65535)){dl=(l-f&65535)+i&65535}else{dl=i}i=bS&31;bS=dk&31;if((i&65535)>(bS&65535)){dm=(i-bS&65535)+dl&65535}else{dm=dl}b[(c[277218]|0)+(h<<1)>>1]=dm;if((a[1108928]|0)==0){dn=b[(c[277213]|0)+(c$+6<<1)>>1]|0}else{dn=0}if((a[(c[277215]|0)+h|0]&32)==0){dp=c[277228]&65535}else{dp=b[(c[277226]|0)+(bQ<<1)>>1]|0}bQ=dn&-2048;bS=dp&-2048;i=(bQ&65535)>(bS&65535)?bQ-bS&65535:0;bS=dn&2016;bQ=dp&2016;if((bS&65535)>(bQ&65535)){dq=(bS-bQ&65535)+i&65535}else{dq=i}i=dn&31;bQ=dp&31;if((i&65535)>(bQ&65535)){dr=(i-bQ&65535)+dq&65535}else{dr=dq}bQ=c$+5|0;b[(c[277218]|0)+(bQ<<1)>>1]=dr;i=a[1108909]|0;a[(c[277219]|0)+bQ|0]=i;a[(c[277219]|0)+h|0]=i;di=a[1108908]|0;dj=c[277219]|0}else{di=c9;dj=da}}while(0);h=c$+6|0;do{if((di&255)>(d[dj+h|0]|0)){i=a[cZ+3|0]|0;bQ=i&255;if(i<<24>>24==0){ds=di;dt=dj;break}i=b[(c[277225]|0)+(bQ<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)==0){du=c[277228]&65535}else{du=b[(c[277213]|0)+(h<<1)>>1]|0}bS=i&-2048;f=du&-2048;l=(bS&65535)>(f&65535)?bS-f&65535:0;f=i&2016;bS=du&2016;if((f&65535)>(bS&65535)){dv=(f-bS&65535)+l&65535}else{dv=l}l=i&31;i=du&31;if((l&65535)>(i&65535)){dw=(l-i&65535)+dv&65535}else{dw=dv}b[(c[277218]|0)+(h<<1)>>1]=dw;if((a[1108928]|0)==0){dx=b[(c[277213]|0)+(c$+8<<1)>>1]|0}else{dx=0}if((a[(c[277215]|0)+h|0]&32)==0){dy=c[277228]&65535}else{dy=b[(c[277226]|0)+(bQ<<1)>>1]|0}bQ=dx&-2048;i=dy&-2048;l=(bQ&65535)>(i&65535)?bQ-i&65535:0;i=dx&2016;bQ=dy&2016;if((i&65535)>(bQ&65535)){dz=(i-bQ&65535)+l&65535}else{dz=l}l=dx&31;bQ=dy&31;if((l&65535)>(bQ&65535)){dA=(l-bQ&65535)+dz&65535}else{dA=dz}bQ=c$+7|0;b[(c[277218]|0)+(bQ<<1)>>1]=dA;l=a[1108909]|0;a[(c[277219]|0)+bQ|0]=l;a[(c[277219]|0)+h|0]=l;ds=a[1108908]|0;dt=c[277219]|0}else{ds=di;dt=dj}}while(0);h=c$+8|0;do{if((ds&255)>(d[dt+h|0]|0)){l=a[cZ+4|0]|0;bQ=l&255;if(l<<24>>24==0){dB=ds;dC=dt;break}l=b[(c[277225]|0)+(bQ<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)==0){dD=c[277228]&65535}else{dD=b[(c[277213]|0)+(h<<1)>>1]|0}i=l&-2048;bS=dD&-2048;f=(i&65535)>(bS&65535)?i-bS&65535:0;bS=l&2016;i=dD&2016;if((bS&65535)>(i&65535)){dE=(bS-i&65535)+f&65535}else{dE=f}f=l&31;l=dD&31;if((f&65535)>(l&65535)){dF=(f-l&65535)+dE&65535}else{dF=dE}b[(c[277218]|0)+(h<<1)>>1]=dF;if((a[1108928]|0)==0){dG=b[(c[277213]|0)+(c$+10<<1)>>1]|0}else{dG=0}if((a[(c[277215]|0)+h|0]&32)==0){dH=c[277228]&65535}else{dH=b[(c[277226]|0)+(bQ<<1)>>1]|0}bQ=dG&-2048;l=dH&-2048;f=(bQ&65535)>(l&65535)?bQ-l&65535:0;l=dG&2016;bQ=dH&2016;if((l&65535)>(bQ&65535)){dI=(l-bQ&65535)+f&65535}else{dI=f}f=dG&31;bQ=dH&31;if((f&65535)>(bQ&65535)){dJ=(f-bQ&65535)+dI&65535}else{dJ=dI}bQ=c$+9|0;b[(c[277218]|0)+(bQ<<1)>>1]=dJ;f=a[1108909]|0;a[(c[277219]|0)+bQ|0]=f;a[(c[277219]|0)+h|0]=f;dB=a[1108908]|0;dC=c[277219]|0}else{dB=ds;dC=dt}}while(0);h=c$+10|0;do{if((dB&255)>(d[dC+h|0]|0)){f=a[cZ+5|0]|0;bQ=f&255;if(f<<24>>24==0){dK=dB;dL=dC;break}f=b[(c[277225]|0)+(bQ<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)==0){dM=c[277228]&65535}else{dM=b[(c[277213]|0)+(h<<1)>>1]|0}l=f&-2048;i=dM&-2048;bS=(l&65535)>(i&65535)?l-i&65535:0;i=f&2016;l=dM&2016;if((i&65535)>(l&65535)){dN=(i-l&65535)+bS&65535}else{dN=bS}bS=f&31;f=dM&31;if((bS&65535)>(f&65535)){dO=(bS-f&65535)+dN&65535}else{dO=dN}b[(c[277218]|0)+(h<<1)>>1]=dO;if((a[1108928]|0)==0){dP=b[(c[277213]|0)+(c$+12<<1)>>1]|0}else{dP=0}if((a[(c[277215]|0)+h|0]&32)==0){dQ=c[277228]&65535}else{dQ=b[(c[277226]|0)+(bQ<<1)>>1]|0}bQ=dP&-2048;f=dQ&-2048;bS=(bQ&65535)>(f&65535)?bQ-f&65535:0;f=dP&2016;bQ=dQ&2016;if((f&65535)>(bQ&65535)){dR=(f-bQ&65535)+bS&65535}else{dR=bS}bS=dP&31;bQ=dQ&31;if((bS&65535)>(bQ&65535)){dS=(bS-bQ&65535)+dR&65535}else{dS=dR}bQ=c$+11|0;b[(c[277218]|0)+(bQ<<1)>>1]=dS;bS=a[1108909]|0;a[(c[277219]|0)+bQ|0]=bS;a[(c[277219]|0)+h|0]=bS;dK=a[1108908]|0;dL=c[277219]|0}else{dK=dB;dL=dC}}while(0);h=c$+12|0;do{if((dK&255)>(d[dL+h|0]|0)){bS=a[cZ+6|0]|0;bQ=bS&255;if(bS<<24>>24==0){dT=dK;dU=dL;break}bS=b[(c[277225]|0)+(bQ<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)==0){dV=c[277228]&65535}else{dV=b[(c[277213]|0)+(h<<1)>>1]|0}f=bS&-2048;l=dV&-2048;i=(f&65535)>(l&65535)?f-l&65535:0;l=bS&2016;f=dV&2016;if((l&65535)>(f&65535)){dW=(l-f&65535)+i&65535}else{dW=i}i=bS&31;bS=dV&31;if((i&65535)>(bS&65535)){dX=(i-bS&65535)+dW&65535}else{dX=dW}b[(c[277218]|0)+(h<<1)>>1]=dX;if((a[1108928]|0)==0){dY=b[(c[277213]|0)+(c$+14<<1)>>1]|0}else{dY=0}if((a[(c[277215]|0)+h|0]&32)==0){dZ=c[277228]&65535}else{dZ=b[(c[277226]|0)+(bQ<<1)>>1]|0}bQ=dY&-2048;bS=dZ&-2048;i=(bQ&65535)>(bS&65535)?bQ-bS&65535:0;bS=dY&2016;bQ=dZ&2016;if((bS&65535)>(bQ&65535)){d_=(bS-bQ&65535)+i&65535}else{d_=i}i=dY&31;bQ=dZ&31;if((i&65535)>(bQ&65535)){d$=(i-bQ&65535)+d_&65535}else{d$=d_}bQ=c$+13|0;b[(c[277218]|0)+(bQ<<1)>>1]=d$;i=a[1108909]|0;a[(c[277219]|0)+bQ|0]=i;a[(c[277219]|0)+h|0]=i;dT=a[1108908]|0;dU=c[277219]|0}else{dT=dK;dU=dL}}while(0);h=c$+14|0;do{if((dT&255)>(d[dU+h|0]|0)){i=a[cZ+7|0]|0;bQ=i&255;if(i<<24>>24==0){break}i=b[(c[277225]|0)+(bQ<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)==0){d0=c[277228]&65535}else{d0=b[(c[277213]|0)+(h<<1)>>1]|0}bS=i&-2048;f=d0&-2048;l=(bS&65535)>(f&65535)?bS-f&65535:0;f=i&2016;bS=d0&2016;if((f&65535)>(bS&65535)){d1=(f-bS&65535)+l&65535}else{d1=l}l=i&31;i=d0&31;if((l&65535)>(i&65535)){d2=(l-i&65535)+d1&65535}else{d2=d1}b[(c[277218]|0)+(h<<1)>>1]=d2;if((a[1108928]|0)==0){d3=b[(c[277213]|0)+(c$+16<<1)>>1]|0}else{d3=0}if((a[(c[277215]|0)+h|0]&32)==0){d4=c[277228]&65535}else{d4=b[(c[277226]|0)+(bQ<<1)>>1]|0}bQ=d3&-2048;i=d4&-2048;l=(bQ&65535)>(i&65535)?bQ-i&65535:0;i=d3&2016;bQ=d4&2016;if((i&65535)>(bQ&65535)){d5=(i-bQ&65535)+l&65535}else{d5=l}l=d3&31;bQ=d4&31;if((l&65535)>(bQ&65535)){d6=(l-bQ&65535)+d5&65535}else{d6=d5}bQ=c$+15|0;b[(c[277218]|0)+(bQ<<1)>>1]=d6;l=a[1108909]|0;a[(c[277219]|0)+bQ|0]=l;a[(c[277219]|0)+h|0]=l}}while(0);h=c_-1|0;if((h|0)<=0){break}cZ=cZ-16|0;c_=h;c$=(c[277223]|0)+c$|0}return}}function WE(f,g,h,i){f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0;j=f&1023;k=c[348606]|0;l=(j<<k)+(c[348604]|0)|0;if((f&256|0)==0){m=l}else{m=(c[348602]|0)+l|0}l=m&65535;m=l>>>(k>>>0);k=(f&16384|0)!=0;n=m<<6;do{if(k){o=(c[348622]|0)+n|0;if((a[(c[348618]|0)+m|0]|0)!=0){p=o;break}q=fi[c[348636]&63](o,l,j)|0;a[(c[348618]|0)+m|0]=q;p=o}else{o=(c[348624]|0)+n|0;if((a[(c[348620]|0)+m|0]|0)!=0){p=o;break}q=fi[c[348638]&63](o,l,j)|0;a[(c[348620]|0)+m|0]=q;p=o}}while(0);if((a[(c[348620]|0)+m|0]|0)==2){return}if((a[1394464]|0)==0){r=1106168+((f>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){m=d[1044485]|0;c[276541]=7080+(m<<5);j=0;do{l=j<<1&2;n=j&2;o=j&4;q=0;do{b[1125528+(j<<9)+(q<<1)>>1]=d[(q>>>1&28|n)+(7080+(m<<5))|0]<<6|d[(q<<2&28|l)+(7080+(m<<5))|0]<<11|d[(q>>>3&24|o)+(7080+(m<<5))|0];q=q+1|0;}while(q>>>0<256);j=j+1|0;}while(j>>>0<8);a[1106089]=0}r=1125528+((f>>>10&7)<<9)|0}c[277226]=r;c[277225]=(a[1108928]|0)!=0?1393712:r;if((f&49152|0)==0){if((i|0)<=0){return}r=p+((d[1394504]|0)+(h<<1))|0;j=i;m=g;while(1){q=a[1108908]|0;o=c[277219]|0;do{if((q&255)>(d[o+m|0]|0)){l=a[r]|0;if(l<<24>>24==0){s=q;t=o;break}n=b[(c[277225]|0)+((l&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){u=b[(c[277221]|0)+(((n&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{l=c[277228]&65535;v=n&-2048;w=l&-2048;x=(v&65535)>(w&65535)?v-w&65535:0;w=n&2016;v=l&2016;if((w&65535)>(v&65535)){y=(w-v&65535)+x&65535}else{y=x}x=n&31;v=l&31;if((x&65535)<=(v&65535)){u=y;break}u=(x-v&65535)+y&65535}}while(0);b[(c[277218]|0)+(m<<1)>>1]=u;if((a[1108928]|0)==0){z=b[(c[277221]|0)+(((e[(c[277213]|0)+(m+2<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{z=0}n=m+1|0;b[(c[277218]|0)+(n<<1)>>1]=z;v=a[1108909]|0;a[(c[277219]|0)+n|0]=v;a[(c[277219]|0)+m|0]=v;s=a[1108908]|0;t=c[277219]|0}else{s=q;t=o}}while(0);o=m+2|0;do{if((s&255)>(d[t+o|0]|0)){q=a[r+1|0]|0;if(q<<24>>24==0){A=s;B=t;break}v=b[(c[277225]|0)+((q&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){C=b[(c[277221]|0)+(((v&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{q=c[277228]&65535;n=v&-2048;x=q&-2048;l=(n&65535)>(x&65535)?n-x&65535:0;x=v&2016;n=q&2016;if((x&65535)>(n&65535)){D=(x-n&65535)+l&65535}else{D=l}l=v&31;n=q&31;if((l&65535)<=(n&65535)){C=D;break}C=(l-n&65535)+D&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=C;if((a[1108928]|0)==0){E=b[(c[277221]|0)+(((e[(c[277213]|0)+(m+4<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{E=0}v=m+3|0;b[(c[277218]|0)+(v<<1)>>1]=E;n=a[1108909]|0;a[(c[277219]|0)+v|0]=n;a[(c[277219]|0)+o|0]=n;A=a[1108908]|0;B=c[277219]|0}else{A=s;B=t}}while(0);o=m+4|0;do{if((A&255)>(d[B+o|0]|0)){n=a[r+2|0]|0;if(n<<24>>24==0){F=A;G=B;break}v=b[(c[277225]|0)+((n&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){H=b[(c[277221]|0)+(((v&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{n=c[277228]&65535;l=v&-2048;q=n&-2048;x=(l&65535)>(q&65535)?l-q&65535:0;q=v&2016;l=n&2016;if((q&65535)>(l&65535)){I=(q-l&65535)+x&65535}else{I=x}x=v&31;l=n&31;if((x&65535)<=(l&65535)){H=I;break}H=(x-l&65535)+I&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=H;if((a[1108928]|0)==0){J=b[(c[277221]|0)+(((e[(c[277213]|0)+(m+6<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{J=0}v=m+5|0;b[(c[277218]|0)+(v<<1)>>1]=J;l=a[1108909]|0;a[(c[277219]|0)+v|0]=l;a[(c[277219]|0)+o|0]=l;F=a[1108908]|0;G=c[277219]|0}else{F=A;G=B}}while(0);o=m+6|0;do{if((F&255)>(d[G+o|0]|0)){l=a[r+3|0]|0;if(l<<24>>24==0){K=F;L=G;break}v=b[(c[277225]|0)+((l&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){M=b[(c[277221]|0)+(((v&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{l=c[277228]&65535;x=v&-2048;n=l&-2048;q=(x&65535)>(n&65535)?x-n&65535:0;n=v&2016;x=l&2016;if((n&65535)>(x&65535)){N=(n-x&65535)+q&65535}else{N=q}q=v&31;x=l&31;if((q&65535)<=(x&65535)){M=N;break}M=(q-x&65535)+N&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=M;if((a[1108928]|0)==0){O=b[(c[277221]|0)+(((e[(c[277213]|0)+(m+8<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{O=0}v=m+7|0;b[(c[277218]|0)+(v<<1)>>1]=O;x=a[1108909]|0;a[(c[277219]|0)+v|0]=x;a[(c[277219]|0)+o|0]=x;K=a[1108908]|0;L=c[277219]|0}else{K=F;L=G}}while(0);o=m+8|0;do{if((K&255)>(d[L+o|0]|0)){x=a[r+4|0]|0;if(x<<24>>24==0){P=K;Q=L;break}v=b[(c[277225]|0)+((x&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){R=b[(c[277221]|0)+(((v&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{x=c[277228]&65535;q=v&-2048;l=x&-2048;n=(q&65535)>(l&65535)?q-l&65535:0;l=v&2016;q=x&2016;if((l&65535)>(q&65535)){S=(l-q&65535)+n&65535}else{S=n}n=v&31;q=x&31;if((n&65535)<=(q&65535)){R=S;break}R=(n-q&65535)+S&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=R;if((a[1108928]|0)==0){T=b[(c[277221]|0)+(((e[(c[277213]|0)+(m+10<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{T=0}v=m+9|0;b[(c[277218]|0)+(v<<1)>>1]=T;q=a[1108909]|0;a[(c[277219]|0)+v|0]=q;a[(c[277219]|0)+o|0]=q;P=a[1108908]|0;Q=c[277219]|0}else{P=K;Q=L}}while(0);o=m+10|0;do{if((P&255)>(d[Q+o|0]|0)){q=a[r+5|0]|0;if(q<<24>>24==0){U=P;V=Q;break}v=b[(c[277225]|0)+((q&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){W=b[(c[277221]|0)+(((v&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{q=c[277228]&65535;n=v&-2048;x=q&-2048;l=(n&65535)>(x&65535)?n-x&65535:0;x=v&2016;n=q&2016;if((x&65535)>(n&65535)){X=(x-n&65535)+l&65535}else{X=l}l=v&31;n=q&31;if((l&65535)<=(n&65535)){W=X;break}W=(l-n&65535)+X&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=W;if((a[1108928]|0)==0){Y=b[(c[277221]|0)+(((e[(c[277213]|0)+(m+12<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{Y=0}v=m+11|0;b[(c[277218]|0)+(v<<1)>>1]=Y;n=a[1108909]|0;a[(c[277219]|0)+v|0]=n;a[(c[277219]|0)+o|0]=n;U=a[1108908]|0;V=c[277219]|0}else{U=P;V=Q}}while(0);o=m+12|0;do{if((U&255)>(d[V+o|0]|0)){n=a[r+6|0]|0;if(n<<24>>24==0){Z=U;_=V;break}v=b[(c[277225]|0)+((n&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){$=b[(c[277221]|0)+(((v&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{n=c[277228]&65535;l=v&-2048;q=n&-2048;x=(l&65535)>(q&65535)?l-q&65535:0;q=v&2016;l=n&2016;if((q&65535)>(l&65535)){aa=(q-l&65535)+x&65535}else{aa=x}x=v&31;l=n&31;if((x&65535)<=(l&65535)){$=aa;break}$=(x-l&65535)+aa&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=$;if((a[1108928]|0)==0){ab=b[(c[277221]|0)+(((e[(c[277213]|0)+(m+14<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{ab=0}v=m+13|0;b[(c[277218]|0)+(v<<1)>>1]=ab;l=a[1108909]|0;a[(c[277219]|0)+v|0]=l;a[(c[277219]|0)+o|0]=l;Z=a[1108908]|0;_=c[277219]|0}else{Z=U;_=V}}while(0);o=m+14|0;do{if((Z&255)>(d[_+o|0]|0)){l=a[r+7|0]|0;if(l<<24>>24==0){break}v=b[(c[277225]|0)+((l&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){ac=b[(c[277221]|0)+(((v&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{l=c[277228]&65535;x=v&-2048;n=l&-2048;q=(x&65535)>(n&65535)?x-n&65535:0;n=v&2016;x=l&2016;if((n&65535)>(x&65535)){ad=(n-x&65535)+q&65535}else{ad=q}q=v&31;x=l&31;if((q&65535)<=(x&65535)){ac=ad;break}ac=(q-x&65535)+ad&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=ac;if((a[1108928]|0)==0){ae=b[(c[277221]|0)+(((e[(c[277213]|0)+(m+16<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{ae=0}v=m+15|0;b[(c[277218]|0)+(v<<1)>>1]=ae;x=a[1108909]|0;a[(c[277219]|0)+v|0]=x;a[(c[277219]|0)+o|0]=x}}while(0);o=j-1|0;if((o|0)<=0){break}r=r+16|0;j=o;m=(c[277223]|0)+m|0}return}m=(d[1394504]|0)+(h<<1)|0;if((f&32768|0)==0){if((i|0)<=0){return}f=p+m|0;h=i;j=g;while(1){r=a[1108908]|0;ae=c[277219]|0;do{if((r&255)>(d[ae+j|0]|0)){ac=a[f+7|0]|0;if(ac<<24>>24==0){af=r;ag=ae;break}ad=b[(c[277225]|0)+((ac&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){ah=b[(c[277221]|0)+(((ad&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{ac=c[277228]&65535;_=ad&-2048;Z=ac&-2048;V=(_&65535)>(Z&65535)?_-Z&65535:0;Z=ad&2016;_=ac&2016;if((Z&65535)>(_&65535)){ai=(Z-_&65535)+V&65535}else{ai=V}V=ad&31;_=ac&31;if((V&65535)<=(_&65535)){ah=ai;break}ah=(V-_&65535)+ai&65535}}while(0);b[(c[277218]|0)+(j<<1)>>1]=ah;if((a[1108928]|0)==0){aj=b[(c[277221]|0)+(((e[(c[277213]|0)+(j+2<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{aj=0}ad=j+1|0;b[(c[277218]|0)+(ad<<1)>>1]=aj;_=a[1108909]|0;a[(c[277219]|0)+ad|0]=_;a[(c[277219]|0)+j|0]=_;af=a[1108908]|0;ag=c[277219]|0}else{af=r;ag=ae}}while(0);ae=j+2|0;do{if((af&255)>(d[ag+ae|0]|0)){r=a[f+6|0]|0;if(r<<24>>24==0){ak=af;al=ag;break}_=b[(c[277225]|0)+((r&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){am=b[(c[277221]|0)+(((_&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{r=c[277228]&65535;ad=_&-2048;V=r&-2048;ac=(ad&65535)>(V&65535)?ad-V&65535:0;V=_&2016;ad=r&2016;if((V&65535)>(ad&65535)){an=(V-ad&65535)+ac&65535}else{an=ac}ac=_&31;ad=r&31;if((ac&65535)<=(ad&65535)){am=an;break}am=(ac-ad&65535)+an&65535}}while(0);b[(c[277218]|0)+(ae<<1)>>1]=am;if((a[1108928]|0)==0){ao=b[(c[277221]|0)+(((e[(c[277213]|0)+(j+4<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{ao=0}_=j+3|0;b[(c[277218]|0)+(_<<1)>>1]=ao;ad=a[1108909]|0;a[(c[277219]|0)+_|0]=ad;a[(c[277219]|0)+ae|0]=ad;ak=a[1108908]|0;al=c[277219]|0}else{ak=af;al=ag}}while(0);ae=j+4|0;do{if((ak&255)>(d[al+ae|0]|0)){ad=a[f+5|0]|0;if(ad<<24>>24==0){ap=ak;aq=al;break}_=b[(c[277225]|0)+((ad&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){ar=b[(c[277221]|0)+(((_&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{ad=c[277228]&65535;ac=_&-2048;r=ad&-2048;V=(ac&65535)>(r&65535)?ac-r&65535:0;r=_&2016;ac=ad&2016;if((r&65535)>(ac&65535)){as=(r-ac&65535)+V&65535}else{as=V}V=_&31;ac=ad&31;if((V&65535)<=(ac&65535)){ar=as;break}ar=(V-ac&65535)+as&65535}}while(0);b[(c[277218]|0)+(ae<<1)>>1]=ar;if((a[1108928]|0)==0){at=b[(c[277221]|0)+(((e[(c[277213]|0)+(j+6<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{at=0}_=j+5|0;b[(c[277218]|0)+(_<<1)>>1]=at;ac=a[1108909]|0;a[(c[277219]|0)+_|0]=ac;a[(c[277219]|0)+ae|0]=ac;ap=a[1108908]|0;aq=c[277219]|0}else{ap=ak;aq=al}}while(0);ae=j+6|0;do{if((ap&255)>(d[aq+ae|0]|0)){ac=a[f+4|0]|0;if(ac<<24>>24==0){au=ap;av=aq;break}_=b[(c[277225]|0)+((ac&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aw=b[(c[277221]|0)+(((_&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{ac=c[277228]&65535;V=_&-2048;ad=ac&-2048;r=(V&65535)>(ad&65535)?V-ad&65535:0;ad=_&2016;V=ac&2016;if((ad&65535)>(V&65535)){ax=(ad-V&65535)+r&65535}else{ax=r}r=_&31;V=ac&31;if((r&65535)<=(V&65535)){aw=ax;break}aw=(r-V&65535)+ax&65535}}while(0);b[(c[277218]|0)+(ae<<1)>>1]=aw;if((a[1108928]|0)==0){ay=b[(c[277221]|0)+(((e[(c[277213]|0)+(j+8<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{ay=0}_=j+7|0;b[(c[277218]|0)+(_<<1)>>1]=ay;V=a[1108909]|0;a[(c[277219]|0)+_|0]=V;a[(c[277219]|0)+ae|0]=V;au=a[1108908]|0;av=c[277219]|0}else{au=ap;av=aq}}while(0);ae=j+8|0;do{if((au&255)>(d[av+ae|0]|0)){V=a[f+3|0]|0;if(V<<24>>24==0){az=au;aA=av;break}_=b[(c[277225]|0)+((V&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aB=b[(c[277221]|0)+(((_&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{V=c[277228]&65535;r=_&-2048;ac=V&-2048;ad=(r&65535)>(ac&65535)?r-ac&65535:0;ac=_&2016;r=V&2016;if((ac&65535)>(r&65535)){aC=(ac-r&65535)+ad&65535}else{aC=ad}ad=_&31;r=V&31;if((ad&65535)<=(r&65535)){aB=aC;break}aB=(ad-r&65535)+aC&65535}}while(0);b[(c[277218]|0)+(ae<<1)>>1]=aB;if((a[1108928]|0)==0){aD=b[(c[277221]|0)+(((e[(c[277213]|0)+(j+10<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{aD=0}_=j+9|0;b[(c[277218]|0)+(_<<1)>>1]=aD;r=a[1108909]|0;a[(c[277219]|0)+_|0]=r;a[(c[277219]|0)+ae|0]=r;az=a[1108908]|0;aA=c[277219]|0}else{az=au;aA=av}}while(0);ae=j+10|0;do{if((az&255)>(d[aA+ae|0]|0)){r=a[f+2|0]|0;if(r<<24>>24==0){aE=az;aF=aA;break}_=b[(c[277225]|0)+((r&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aG=b[(c[277221]|0)+(((_&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{r=c[277228]&65535;ad=_&-2048;V=r&-2048;ac=(ad&65535)>(V&65535)?ad-V&65535:0;V=_&2016;ad=r&2016;if((V&65535)>(ad&65535)){aH=(V-ad&65535)+ac&65535}else{aH=ac}ac=_&31;ad=r&31;if((ac&65535)<=(ad&65535)){aG=aH;break}aG=(ac-ad&65535)+aH&65535}}while(0);b[(c[277218]|0)+(ae<<1)>>1]=aG;if((a[1108928]|0)==0){aI=b[(c[277221]|0)+(((e[(c[277213]|0)+(j+12<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{aI=0}_=j+11|0;b[(c[277218]|0)+(_<<1)>>1]=aI;ad=a[1108909]|0;a[(c[277219]|0)+_|0]=ad;a[(c[277219]|0)+ae|0]=ad;aE=a[1108908]|0;aF=c[277219]|0}else{aE=az;aF=aA}}while(0);ae=j+12|0;do{if((aE&255)>(d[aF+ae|0]|0)){ad=a[f+1|0]|0;if(ad<<24>>24==0){aJ=aE;aK=aF;break}_=b[(c[277225]|0)+((ad&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aL=b[(c[277221]|0)+(((_&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{ad=c[277228]&65535;ac=_&-2048;r=ad&-2048;V=(ac&65535)>(r&65535)?ac-r&65535:0;r=_&2016;ac=ad&2016;if((r&65535)>(ac&65535)){aM=(r-ac&65535)+V&65535}else{aM=V}V=_&31;ac=ad&31;if((V&65535)<=(ac&65535)){aL=aM;break}aL=(V-ac&65535)+aM&65535}}while(0);b[(c[277218]|0)+(ae<<1)>>1]=aL;if((a[1108928]|0)==0){aN=b[(c[277221]|0)+(((e[(c[277213]|0)+(j+14<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{aN=0}_=j+13|0;b[(c[277218]|0)+(_<<1)>>1]=aN;ac=a[1108909]|0;a[(c[277219]|0)+_|0]=ac;a[(c[277219]|0)+ae|0]=ac;aJ=a[1108908]|0;aK=c[277219]|0}else{aJ=aE;aK=aF}}while(0);ae=j+14|0;do{if((aJ&255)>(d[aK+ae|0]|0)){ac=a[f]|0;if(ac<<24>>24==0){break}_=b[(c[277225]|0)+((ac&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aO=b[(c[277221]|0)+(((_&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{ac=c[277228]&65535;V=_&-2048;ad=ac&-2048;r=(V&65535)>(ad&65535)?V-ad&65535:0;ad=_&2016;V=ac&2016;if((ad&65535)>(V&65535)){aP=(ad-V&65535)+r&65535}else{aP=r}r=_&31;V=ac&31;if((r&65535)<=(V&65535)){aO=aP;break}aO=(r-V&65535)+aP&65535}}while(0);b[(c[277218]|0)+(ae<<1)>>1]=aO;if((a[1108928]|0)==0){aQ=b[(c[277221]|0)+(((e[(c[277213]|0)+(j+16<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{aQ=0}_=j+15|0;b[(c[277218]|0)+(_<<1)>>1]=aQ;V=a[1108909]|0;a[(c[277219]|0)+_|0]=V;a[(c[277219]|0)+ae|0]=V}}while(0);ae=h-1|0;if((ae|0)<=0){break}f=f+16|0;h=ae;j=(c[277223]|0)+j|0}return}j=p+(56-m)|0;m=(i|0)>0;if(k){if(m){aR=j;aS=i;aT=g}else{return}while(1){k=a[1108908]|0;p=c[277219]|0;do{if((k&255)>(d[p+aT|0]|0)){h=a[aR+7|0]|0;if(h<<24>>24==0){aU=k;aV=p;break}f=b[(c[277225]|0)+((h&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aW=b[(c[277221]|0)+(((f&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{h=c[277228]&65535;aQ=f&-2048;aO=h&-2048;aP=(aQ&65535)>(aO&65535)?aQ-aO&65535:0;aO=f&2016;aQ=h&2016;if((aO&65535)>(aQ&65535)){aX=(aO-aQ&65535)+aP&65535}else{aX=aP}aP=f&31;aQ=h&31;if((aP&65535)<=(aQ&65535)){aW=aX;break}aW=(aP-aQ&65535)+aX&65535}}while(0);b[(c[277218]|0)+(aT<<1)>>1]=aW;if((a[1108928]|0)==0){aY=b[(c[277221]|0)+(((e[(c[277213]|0)+(aT+2<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{aY=0}f=aT+1|0;b[(c[277218]|0)+(f<<1)>>1]=aY;aQ=a[1108909]|0;a[(c[277219]|0)+f|0]=aQ;a[(c[277219]|0)+aT|0]=aQ;aU=a[1108908]|0;aV=c[277219]|0}else{aU=k;aV=p}}while(0);p=aT+2|0;do{if((aU&255)>(d[aV+p|0]|0)){k=a[aR+6|0]|0;if(k<<24>>24==0){aZ=aU;a_=aV;break}aQ=b[(c[277225]|0)+((k&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){a$=b[(c[277221]|0)+(((aQ&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{k=c[277228]&65535;f=aQ&-2048;aP=k&-2048;h=(f&65535)>(aP&65535)?f-aP&65535:0;aP=aQ&2016;f=k&2016;if((aP&65535)>(f&65535)){a0=(aP-f&65535)+h&65535}else{a0=h}h=aQ&31;f=k&31;if((h&65535)<=(f&65535)){a$=a0;break}a$=(h-f&65535)+a0&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=a$;if((a[1108928]|0)==0){a1=b[(c[277221]|0)+(((e[(c[277213]|0)+(aT+4<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{a1=0}aQ=aT+3|0;b[(c[277218]|0)+(aQ<<1)>>1]=a1;f=a[1108909]|0;a[(c[277219]|0)+aQ|0]=f;a[(c[277219]|0)+p|0]=f;aZ=a[1108908]|0;a_=c[277219]|0}else{aZ=aU;a_=aV}}while(0);p=aT+4|0;do{if((aZ&255)>(d[a_+p|0]|0)){f=a[aR+5|0]|0;if(f<<24>>24==0){a2=aZ;a3=a_;break}aQ=b[(c[277225]|0)+((f&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){a4=b[(c[277221]|0)+(((aQ&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{f=c[277228]&65535;h=aQ&-2048;k=f&-2048;aP=(h&65535)>(k&65535)?h-k&65535:0;k=aQ&2016;h=f&2016;if((k&65535)>(h&65535)){a5=(k-h&65535)+aP&65535}else{a5=aP}aP=aQ&31;h=f&31;if((aP&65535)<=(h&65535)){a4=a5;break}a4=(aP-h&65535)+a5&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=a4;if((a[1108928]|0)==0){a6=b[(c[277221]|0)+(((e[(c[277213]|0)+(aT+6<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{a6=0}aQ=aT+5|0;b[(c[277218]|0)+(aQ<<1)>>1]=a6;h=a[1108909]|0;a[(c[277219]|0)+aQ|0]=h;a[(c[277219]|0)+p|0]=h;a2=a[1108908]|0;a3=c[277219]|0}else{a2=aZ;a3=a_}}while(0);p=aT+6|0;do{if((a2&255)>(d[a3+p|0]|0)){h=a[aR+4|0]|0;if(h<<24>>24==0){a7=a2;a8=a3;break}aQ=b[(c[277225]|0)+((h&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){a9=b[(c[277221]|0)+(((aQ&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{h=c[277228]&65535;aP=aQ&-2048;f=h&-2048;k=(aP&65535)>(f&65535)?aP-f&65535:0;f=aQ&2016;aP=h&2016;if((f&65535)>(aP&65535)){ba=(f-aP&65535)+k&65535}else{ba=k}k=aQ&31;aP=h&31;if((k&65535)<=(aP&65535)){a9=ba;break}a9=(k-aP&65535)+ba&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=a9;if((a[1108928]|0)==0){bb=b[(c[277221]|0)+(((e[(c[277213]|0)+(aT+8<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{bb=0}aQ=aT+7|0;b[(c[277218]|0)+(aQ<<1)>>1]=bb;aP=a[1108909]|0;a[(c[277219]|0)+aQ|0]=aP;a[(c[277219]|0)+p|0]=aP;a7=a[1108908]|0;a8=c[277219]|0}else{a7=a2;a8=a3}}while(0);p=aT+8|0;do{if((a7&255)>(d[a8+p|0]|0)){aP=a[aR+3|0]|0;if(aP<<24>>24==0){bc=a7;bd=a8;break}aQ=b[(c[277225]|0)+((aP&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){be=b[(c[277221]|0)+(((aQ&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{aP=c[277228]&65535;k=aQ&-2048;h=aP&-2048;f=(k&65535)>(h&65535)?k-h&65535:0;h=aQ&2016;k=aP&2016;if((h&65535)>(k&65535)){bf=(h-k&65535)+f&65535}else{bf=f}f=aQ&31;k=aP&31;if((f&65535)<=(k&65535)){be=bf;break}be=(f-k&65535)+bf&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=be;if((a[1108928]|0)==0){bg=b[(c[277221]|0)+(((e[(c[277213]|0)+(aT+10<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{bg=0}aQ=aT+9|0;b[(c[277218]|0)+(aQ<<1)>>1]=bg;k=a[1108909]|0;a[(c[277219]|0)+aQ|0]=k;a[(c[277219]|0)+p|0]=k;bc=a[1108908]|0;bd=c[277219]|0}else{bc=a7;bd=a8}}while(0);p=aT+10|0;do{if((bc&255)>(d[bd+p|0]|0)){k=a[aR+2|0]|0;if(k<<24>>24==0){bh=bc;bi=bd;break}aQ=b[(c[277225]|0)+((k&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){bj=b[(c[277221]|0)+(((aQ&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{k=c[277228]&65535;f=aQ&-2048;aP=k&-2048;h=(f&65535)>(aP&65535)?f-aP&65535:0;aP=aQ&2016;f=k&2016;if((aP&65535)>(f&65535)){bk=(aP-f&65535)+h&65535}else{bk=h}h=aQ&31;f=k&31;if((h&65535)<=(f&65535)){bj=bk;break}bj=(h-f&65535)+bk&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=bj;if((a[1108928]|0)==0){bl=b[(c[277221]|0)+(((e[(c[277213]|0)+(aT+12<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{bl=0}aQ=aT+11|0;b[(c[277218]|0)+(aQ<<1)>>1]=bl;f=a[1108909]|0;a[(c[277219]|0)+aQ|0]=f;a[(c[277219]|0)+p|0]=f;bh=a[1108908]|0;bi=c[277219]|0}else{bh=bc;bi=bd}}while(0);p=aT+12|0;do{if((bh&255)>(d[bi+p|0]|0)){f=a[aR+1|0]|0;if(f<<24>>24==0){bm=bh;bn=bi;break}aQ=b[(c[277225]|0)+((f&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){bo=b[(c[277221]|0)+(((aQ&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{f=c[277228]&65535;h=aQ&-2048;k=f&-2048;aP=(h&65535)>(k&65535)?h-k&65535:0;k=aQ&2016;h=f&2016;if((k&65535)>(h&65535)){bp=(k-h&65535)+aP&65535}else{bp=aP}aP=aQ&31;h=f&31;if((aP&65535)<=(h&65535)){bo=bp;break}bo=(aP-h&65535)+bp&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=bo;if((a[1108928]|0)==0){bq=b[(c[277221]|0)+(((e[(c[277213]|0)+(aT+14<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{bq=0}aQ=aT+13|0;b[(c[277218]|0)+(aQ<<1)>>1]=bq;h=a[1108909]|0;a[(c[277219]|0)+aQ|0]=h;a[(c[277219]|0)+p|0]=h;bm=a[1108908]|0;bn=c[277219]|0}else{bm=bh;bn=bi}}while(0);p=aT+14|0;do{if((bm&255)>(d[bn+p|0]|0)){h=a[aR]|0;if(h<<24>>24==0){break}aQ=b[(c[277225]|0)+((h&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){br=b[(c[277221]|0)+(((aQ&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{h=c[277228]&65535;aP=aQ&-2048;f=h&-2048;k=(aP&65535)>(f&65535)?aP-f&65535:0;f=aQ&2016;aP=h&2016;if((f&65535)>(aP&65535)){bs=(f-aP&65535)+k&65535}else{bs=k}k=aQ&31;aP=h&31;if((k&65535)<=(aP&65535)){br=bs;break}br=(k-aP&65535)+bs&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=br;if((a[1108928]|0)==0){bt=b[(c[277221]|0)+(((e[(c[277213]|0)+(aT+16<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{bt=0}aQ=aT+15|0;b[(c[277218]|0)+(aQ<<1)>>1]=bt;aP=a[1108909]|0;a[(c[277219]|0)+aQ|0]=aP;a[(c[277219]|0)+p|0]=aP}}while(0);p=aS-1|0;if((p|0)<=0){break}aR=aR-16|0;aS=p;aT=(c[277223]|0)+aT|0}return}else{if(m){bu=j;bv=i;bw=g}else{return}while(1){g=a[1108908]|0;i=c[277219]|0;do{if((g&255)>(d[i+bw|0]|0)){j=a[bu]|0;if(j<<24>>24==0){bx=g;by=i;break}m=b[(c[277225]|0)+((j&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){bz=b[(c[277221]|0)+(((m&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{j=c[277228]&65535;aT=m&-2048;aS=j&-2048;aR=(aT&65535)>(aS&65535)?aT-aS&65535:0;aS=m&2016;aT=j&2016;if((aS&65535)>(aT&65535)){bA=(aS-aT&65535)+aR&65535}else{bA=aR}aR=m&31;aT=j&31;if((aR&65535)<=(aT&65535)){bz=bA;break}bz=(aR-aT&65535)+bA&65535}}while(0);b[(c[277218]|0)+(bw<<1)>>1]=bz;if((a[1108928]|0)==0){bB=b[(c[277221]|0)+(((e[(c[277213]|0)+(bw+2<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{bB=0}m=bw+1|0;b[(c[277218]|0)+(m<<1)>>1]=bB;aT=a[1108909]|0;a[(c[277219]|0)+m|0]=aT;a[(c[277219]|0)+bw|0]=aT;bx=a[1108908]|0;by=c[277219]|0}else{bx=g;by=i}}while(0);i=bw+2|0;do{if((bx&255)>(d[by+i|0]|0)){g=a[bu+1|0]|0;if(g<<24>>24==0){bC=bx;bD=by;break}aT=b[(c[277225]|0)+((g&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){bE=b[(c[277221]|0)+(((aT&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{g=c[277228]&65535;m=aT&-2048;aR=g&-2048;j=(m&65535)>(aR&65535)?m-aR&65535:0;aR=aT&2016;m=g&2016;if((aR&65535)>(m&65535)){bF=(aR-m&65535)+j&65535}else{bF=j}j=aT&31;m=g&31;if((j&65535)<=(m&65535)){bE=bF;break}bE=(j-m&65535)+bF&65535}}while(0);b[(c[277218]|0)+(i<<1)>>1]=bE;if((a[1108928]|0)==0){bG=b[(c[277221]|0)+(((e[(c[277213]|0)+(bw+4<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{bG=0}aT=bw+3|0;b[(c[277218]|0)+(aT<<1)>>1]=bG;m=a[1108909]|0;a[(c[277219]|0)+aT|0]=m;a[(c[277219]|0)+i|0]=m;bC=a[1108908]|0;bD=c[277219]|0}else{bC=bx;bD=by}}while(0);i=bw+4|0;do{if((bC&255)>(d[bD+i|0]|0)){m=a[bu+2|0]|0;if(m<<24>>24==0){bH=bC;bI=bD;break}aT=b[(c[277225]|0)+((m&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){bJ=b[(c[277221]|0)+(((aT&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{m=c[277228]&65535;j=aT&-2048;g=m&-2048;aR=(j&65535)>(g&65535)?j-g&65535:0;g=aT&2016;j=m&2016;if((g&65535)>(j&65535)){bK=(g-j&65535)+aR&65535}else{bK=aR}aR=aT&31;j=m&31;if((aR&65535)<=(j&65535)){bJ=bK;break}bJ=(aR-j&65535)+bK&65535}}while(0);b[(c[277218]|0)+(i<<1)>>1]=bJ;if((a[1108928]|0)==0){bL=b[(c[277221]|0)+(((e[(c[277213]|0)+(bw+6<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{bL=0}aT=bw+5|0;b[(c[277218]|0)+(aT<<1)>>1]=bL;j=a[1108909]|0;a[(c[277219]|0)+aT|0]=j;a[(c[277219]|0)+i|0]=j;bH=a[1108908]|0;bI=c[277219]|0}else{bH=bC;bI=bD}}while(0);i=bw+6|0;do{if((bH&255)>(d[bI+i|0]|0)){j=a[bu+3|0]|0;if(j<<24>>24==0){bM=bH;bN=bI;break}aT=b[(c[277225]|0)+((j&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){bO=b[(c[277221]|0)+(((aT&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{j=c[277228]&65535;aR=aT&-2048;m=j&-2048;g=(aR&65535)>(m&65535)?aR-m&65535:0;m=aT&2016;aR=j&2016;if((m&65535)>(aR&65535)){bP=(m-aR&65535)+g&65535}else{bP=g}g=aT&31;aR=j&31;if((g&65535)<=(aR&65535)){bO=bP;break}bO=(g-aR&65535)+bP&65535}}while(0);b[(c[277218]|0)+(i<<1)>>1]=bO;if((a[1108928]|0)==0){bQ=b[(c[277221]|0)+(((e[(c[277213]|0)+(bw+8<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{bQ=0}aT=bw+7|0;b[(c[277218]|0)+(aT<<1)>>1]=bQ;aR=a[1108909]|0;a[(c[277219]|0)+aT|0]=aR;a[(c[277219]|0)+i|0]=aR;bM=a[1108908]|0;bN=c[277219]|0}else{bM=bH;bN=bI}}while(0);i=bw+8|0;do{if((bM&255)>(d[bN+i|0]|0)){aR=a[bu+4|0]|0;if(aR<<24>>24==0){bR=bM;bS=bN;break}aT=b[(c[277225]|0)+((aR&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){bT=b[(c[277221]|0)+(((aT&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{aR=c[277228]&65535;g=aT&-2048;j=aR&-2048;m=(g&65535)>(j&65535)?g-j&65535:0;j=aT&2016;g=aR&2016;if((j&65535)>(g&65535)){bU=(j-g&65535)+m&65535}else{bU=m}m=aT&31;g=aR&31;if((m&65535)<=(g&65535)){bT=bU;break}bT=(m-g&65535)+bU&65535}}while(0);b[(c[277218]|0)+(i<<1)>>1]=bT;if((a[1108928]|0)==0){bV=b[(c[277221]|0)+(((e[(c[277213]|0)+(bw+10<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{bV=0}aT=bw+9|0;b[(c[277218]|0)+(aT<<1)>>1]=bV;g=a[1108909]|0;a[(c[277219]|0)+aT|0]=g;a[(c[277219]|0)+i|0]=g;bR=a[1108908]|0;bS=c[277219]|0}else{bR=bM;bS=bN}}while(0);i=bw+10|0;do{if((bR&255)>(d[bS+i|0]|0)){g=a[bu+5|0]|0;if(g<<24>>24==0){bW=bR;bX=bS;break}aT=b[(c[277225]|0)+((g&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){bY=b[(c[277221]|0)+(((aT&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{g=c[277228]&65535;m=aT&-2048;aR=g&-2048;j=(m&65535)>(aR&65535)?m-aR&65535:0;aR=aT&2016;m=g&2016;if((aR&65535)>(m&65535)){bZ=(aR-m&65535)+j&65535}else{bZ=j}j=aT&31;m=g&31;if((j&65535)<=(m&65535)){bY=bZ;break}bY=(j-m&65535)+bZ&65535}}while(0);b[(c[277218]|0)+(i<<1)>>1]=bY;if((a[1108928]|0)==0){b_=b[(c[277221]|0)+(((e[(c[277213]|0)+(bw+12<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{b_=0}aT=bw+11|0;b[(c[277218]|0)+(aT<<1)>>1]=b_;m=a[1108909]|0;a[(c[277219]|0)+aT|0]=m;a[(c[277219]|0)+i|0]=m;bW=a[1108908]|0;bX=c[277219]|0}else{bW=bR;bX=bS}}while(0);i=bw+12|0;do{if((bW&255)>(d[bX+i|0]|0)){m=a[bu+6|0]|0;if(m<<24>>24==0){b$=bW;b0=bX;break}aT=b[(c[277225]|0)+((m&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){b1=b[(c[277221]|0)+(((aT&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{m=c[277228]&65535;j=aT&-2048;g=m&-2048;aR=(j&65535)>(g&65535)?j-g&65535:0;g=aT&2016;j=m&2016;if((g&65535)>(j&65535)){b2=(g-j&65535)+aR&65535}else{b2=aR}aR=aT&31;j=m&31;if((aR&65535)<=(j&65535)){b1=b2;break}b1=(aR-j&65535)+b2&65535}}while(0);b[(c[277218]|0)+(i<<1)>>1]=b1;if((a[1108928]|0)==0){b3=b[(c[277221]|0)+(((e[(c[277213]|0)+(bw+14<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{b3=0}aT=bw+13|0;b[(c[277218]|0)+(aT<<1)>>1]=b3;j=a[1108909]|0;a[(c[277219]|0)+aT|0]=j;a[(c[277219]|0)+i|0]=j;b$=a[1108908]|0;b0=c[277219]|0}else{b$=bW;b0=bX}}while(0);i=bw+14|0;do{if((b$&255)>(d[b0+i|0]|0)){j=a[bu+7|0]|0;if(j<<24>>24==0){break}aT=b[(c[277225]|0)+((j&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){b4=b[(c[277221]|0)+(((aT&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{j=c[277228]&65535;aR=aT&-2048;m=j&-2048;g=(aR&65535)>(m&65535)?aR-m&65535:0;m=aT&2016;aR=j&2016;if((m&65535)>(aR&65535)){b5=(m-aR&65535)+g&65535}else{b5=g}g=aT&31;aR=j&31;if((g&65535)<=(aR&65535)){b4=b5;break}b4=(g-aR&65535)+b5&65535}}while(0);b[(c[277218]|0)+(i<<1)>>1]=b4;if((a[1108928]|0)==0){b6=b[(c[277221]|0)+(((e[(c[277213]|0)+(bw+16<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{b6=0}aT=bw+15|0;b[(c[277218]|0)+(aT<<1)>>1]=b6;aR=a[1108909]|0;a[(c[277219]|0)+aT|0]=aR;a[(c[277219]|0)+i|0]=aR}}while(0);i=bv-1|0;if((i|0)<=0){break}bu=bu-16|0;bv=i;bw=(c[277223]|0)+bw|0}return}}function WF(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0,cf=0,cg=0,ch=0,ci=0,cj=0,ck=0,cl=0,cm=0,cn=0,co=0,cp=0,cq=0,cr=0,cs=0,ct=0,cu=0,cv=0,cw=0,cx=0,cy=0,cz=0,cA=0,cB=0,cC=0,cD=0,cE=0,cF=0,cG=0,cH=0,cI=0,cJ=0,cK=0,cL=0,cM=0,cN=0,cO=0,cP=0,cQ=0,cR=0,cS=0,cT=0,cU=0,cV=0,cW=0,cX=0,cY=0,cZ=0,c_=0,c$=0,c0=0,c1=0,c2=0,c3=0,c4=0,c5=0,c6=0,c7=0,c8=0,c9=0,da=0,db=0,dc=0,dd=0,de=0,df=0,dg=0,dh=0,di=0,dj=0,dk=0,dl=0,dm=0,dn=0,dp=0,dq=0,dr=0,ds=0,dt=0,du=0,dv=0,dw=0,dx=0,dy=0,dz=0,dA=0,dB=0,dC=0,dD=0;i=e&1023;j=c[348606]|0;k=(i<<j)+(c[348604]|0)|0;if((e&256|0)==0){l=k}else{l=(c[348602]|0)+k|0}k=l&65535;l=k>>>(j>>>0);j=(e&16384|0)!=0;m=l<<6;do{if(j){n=(c[348622]|0)+m|0;if((a[(c[348618]|0)+l|0]|0)!=0){o=n;break}p=fi[c[348636]&63](n,k,i)|0;a[(c[348618]|0)+l|0]=p;o=n}else{n=(c[348624]|0)+m|0;if((a[(c[348620]|0)+l|0]|0)!=0){o=n;break}p=fi[c[348638]&63](n,k,i)|0;a[(c[348620]|0)+l|0]=p;o=n}}while(0);if((a[(c[348620]|0)+l|0]|0)==2){return}if((a[1394464]|0)==0){q=1106168+((e>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){l=d[1044485]|0;c[276541]=7080+(l<<5);i=0;do{k=i<<1&2;m=i&2;n=i&4;p=0;do{b[1125528+(i<<9)+(p<<1)>>1]=d[(p>>>1&28|m)+(7080+(l<<5))|0]<<6|d[(p<<2&28|k)+(7080+(l<<5))|0]<<11|d[(p>>>3&24|n)+(7080+(l<<5))|0];p=p+1|0;}while(p>>>0<256);i=i+1|0;}while(i>>>0<8);a[1106089]=0}q=1125528+((e>>>10&7)<<9)|0}c[277226]=q;c[277225]=(a[1108928]|0)!=0?1393712:q;if((e&49152|0)==0){if((h|0)<=0){return}q=o+((d[1394504]|0)+(g<<1))|0;i=h;l=f;while(1){p=a[1108908]|0;n=c[277219]|0;do{if((p&255)>(d[n+l|0]|0)){k=a[q]|0;m=k&255;if(k<<24>>24==0){r=p;s=n;break}do{if((a[1108928]|0)==0){k=b[(c[277225]|0)+(m<<1)>>1]|0;if((a[(c[277215]|0)+l|0]&32)!=0){t=b[(c[277221]|0)+((k&65535|67616)-(b[(c[277213]|0)+(l<<1)>>1]&63454)>>1<<1)>>1]|0;break}u=c[277228]&65535;v=k&-2048;w=u&-2048;x=(v&65535)>(w&65535)?v-w&65535:0;w=k&2016;v=u&2016;if((w&65535)>(v&65535)){y=(w-v&65535)+x&65535}else{y=x}x=k&31;k=u&31;if((x&65535)<=(k&65535)){t=y;break}t=(x-k&65535)+y&65535}else{k=b[(c[277225]|0)+(m<<1)>>1]|0;if((a[(c[277215]|0)+l|0]&32)==0){z=c[277228]&65535}else{z=b[(c[277213]|0)+(l<<1)>>1]|0}x=k&-2048;u=z&-2048;v=(x&65535)>(u&65535)?x-u&65535:0;u=k&2016;x=z&2016;if((u&65535)>(x&65535)){A=(u-x&65535)+v&65535}else{A=v}v=k&31;k=z&31;if((v&65535)<=(k&65535)){t=A;break}t=(v-k&65535)+A&65535}}while(0);b[(c[277218]|0)+(l<<1)>>1]=t;do{if((a[1108928]|0)==0){k=b[(c[277213]|0)+(l+2<<1)>>1]|0;if((a[(c[277215]|0)+l|0]&32)!=0){B=b[(c[277221]|0)+((k&65535|67616)-(b[(c[277226]|0)+(m<<1)>>1]&63454)>>1<<1)>>1]|0;break}v=c[277228]&65535;x=k&-2048;u=v&-2048;w=(x&65535)>(u&65535)?x-u&65535:0;u=k&2016;x=v&2016;if((u&65535)>(x&65535)){C=(u-x&65535)+w&65535}else{C=w}w=k&31;k=v&31;if((w&65535)<=(k&65535)){B=C;break}B=(w-k&65535)+C&65535}else{B=0}}while(0);m=l+1|0;b[(c[277218]|0)+(m<<1)>>1]=B;k=a[1108909]|0;a[(c[277219]|0)+m|0]=k;a[(c[277219]|0)+l|0]=k;r=a[1108908]|0;s=c[277219]|0}else{r=p;s=n}}while(0);n=l+2|0;do{if((r&255)>(d[s+n|0]|0)){p=a[q+1|0]|0;k=p&255;if(p<<24>>24==0){D=r;E=s;break}do{if((a[1108928]|0)==0){p=b[(c[277225]|0)+(k<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)!=0){F=b[(c[277221]|0)+((p&65535|67616)-(b[(c[277213]|0)+(n<<1)>>1]&63454)>>1<<1)>>1]|0;break}m=c[277228]&65535;w=p&-2048;v=m&-2048;x=(w&65535)>(v&65535)?w-v&65535:0;v=p&2016;w=m&2016;if((v&65535)>(w&65535)){G=(v-w&65535)+x&65535}else{G=x}x=p&31;p=m&31;if((x&65535)<=(p&65535)){F=G;break}F=(x-p&65535)+G&65535}else{p=b[(c[277225]|0)+(k<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)==0){H=c[277228]&65535}else{H=b[(c[277213]|0)+(n<<1)>>1]|0}x=p&-2048;m=H&-2048;w=(x&65535)>(m&65535)?x-m&65535:0;m=p&2016;x=H&2016;if((m&65535)>(x&65535)){I=(m-x&65535)+w&65535}else{I=w}w=p&31;p=H&31;if((w&65535)<=(p&65535)){F=I;break}F=(w-p&65535)+I&65535}}while(0);b[(c[277218]|0)+(n<<1)>>1]=F;do{if((a[1108928]|0)==0){p=b[(c[277213]|0)+(l+4<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)!=0){J=b[(c[277221]|0)+((p&65535|67616)-(b[(c[277226]|0)+(k<<1)>>1]&63454)>>1<<1)>>1]|0;break}w=c[277228]&65535;x=p&-2048;m=w&-2048;v=(x&65535)>(m&65535)?x-m&65535:0;m=p&2016;x=w&2016;if((m&65535)>(x&65535)){K=(m-x&65535)+v&65535}else{K=v}v=p&31;p=w&31;if((v&65535)<=(p&65535)){J=K;break}J=(v-p&65535)+K&65535}else{J=0}}while(0);k=l+3|0;b[(c[277218]|0)+(k<<1)>>1]=J;p=a[1108909]|0;a[(c[277219]|0)+k|0]=p;a[(c[277219]|0)+n|0]=p;D=a[1108908]|0;E=c[277219]|0}else{D=r;E=s}}while(0);n=l+4|0;do{if((D&255)>(d[E+n|0]|0)){p=a[q+2|0]|0;k=p&255;if(p<<24>>24==0){L=D;M=E;break}do{if((a[1108928]|0)==0){p=b[(c[277225]|0)+(k<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)!=0){N=b[(c[277221]|0)+((p&65535|67616)-(b[(c[277213]|0)+(n<<1)>>1]&63454)>>1<<1)>>1]|0;break}v=c[277228]&65535;w=p&-2048;x=v&-2048;m=(w&65535)>(x&65535)?w-x&65535:0;x=p&2016;w=v&2016;if((x&65535)>(w&65535)){O=(x-w&65535)+m&65535}else{O=m}m=p&31;p=v&31;if((m&65535)<=(p&65535)){N=O;break}N=(m-p&65535)+O&65535}else{p=b[(c[277225]|0)+(k<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)==0){P=c[277228]&65535}else{P=b[(c[277213]|0)+(n<<1)>>1]|0}m=p&-2048;v=P&-2048;w=(m&65535)>(v&65535)?m-v&65535:0;v=p&2016;m=P&2016;if((v&65535)>(m&65535)){Q=(v-m&65535)+w&65535}else{Q=w}w=p&31;p=P&31;if((w&65535)<=(p&65535)){N=Q;break}N=(w-p&65535)+Q&65535}}while(0);b[(c[277218]|0)+(n<<1)>>1]=N;do{if((a[1108928]|0)==0){p=b[(c[277213]|0)+(l+6<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)!=0){R=b[(c[277221]|0)+((p&65535|67616)-(b[(c[277226]|0)+(k<<1)>>1]&63454)>>1<<1)>>1]|0;break}w=c[277228]&65535;m=p&-2048;v=w&-2048;x=(m&65535)>(v&65535)?m-v&65535:0;v=p&2016;m=w&2016;if((v&65535)>(m&65535)){S=(v-m&65535)+x&65535}else{S=x}x=p&31;p=w&31;if((x&65535)<=(p&65535)){R=S;break}R=(x-p&65535)+S&65535}else{R=0}}while(0);k=l+5|0;b[(c[277218]|0)+(k<<1)>>1]=R;p=a[1108909]|0;a[(c[277219]|0)+k|0]=p;a[(c[277219]|0)+n|0]=p;L=a[1108908]|0;M=c[277219]|0}else{L=D;M=E}}while(0);n=l+6|0;do{if((L&255)>(d[M+n|0]|0)){p=a[q+3|0]|0;k=p&255;if(p<<24>>24==0){T=L;U=M;break}do{if((a[1108928]|0)==0){p=b[(c[277225]|0)+(k<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)!=0){V=b[(c[277221]|0)+((p&65535|67616)-(b[(c[277213]|0)+(n<<1)>>1]&63454)>>1<<1)>>1]|0;break}x=c[277228]&65535;w=p&-2048;m=x&-2048;v=(w&65535)>(m&65535)?w-m&65535:0;m=p&2016;w=x&2016;if((m&65535)>(w&65535)){W=(m-w&65535)+v&65535}else{W=v}v=p&31;p=x&31;if((v&65535)<=(p&65535)){V=W;break}V=(v-p&65535)+W&65535}else{p=b[(c[277225]|0)+(k<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)==0){X=c[277228]&65535}else{X=b[(c[277213]|0)+(n<<1)>>1]|0}v=p&-2048;x=X&-2048;w=(v&65535)>(x&65535)?v-x&65535:0;x=p&2016;v=X&2016;if((x&65535)>(v&65535)){Y=(x-v&65535)+w&65535}else{Y=w}w=p&31;p=X&31;if((w&65535)<=(p&65535)){V=Y;break}V=(w-p&65535)+Y&65535}}while(0);b[(c[277218]|0)+(n<<1)>>1]=V;do{if((a[1108928]|0)==0){p=b[(c[277213]|0)+(l+8<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)!=0){Z=b[(c[277221]|0)+((p&65535|67616)-(b[(c[277226]|0)+(k<<1)>>1]&63454)>>1<<1)>>1]|0;break}w=c[277228]&65535;v=p&-2048;x=w&-2048;m=(v&65535)>(x&65535)?v-x&65535:0;x=p&2016;v=w&2016;if((x&65535)>(v&65535)){_=(x-v&65535)+m&65535}else{_=m}m=p&31;p=w&31;if((m&65535)<=(p&65535)){Z=_;break}Z=(m-p&65535)+_&65535}else{Z=0}}while(0);k=l+7|0;b[(c[277218]|0)+(k<<1)>>1]=Z;p=a[1108909]|0;a[(c[277219]|0)+k|0]=p;a[(c[277219]|0)+n|0]=p;T=a[1108908]|0;U=c[277219]|0}else{T=L;U=M}}while(0);n=l+8|0;do{if((T&255)>(d[U+n|0]|0)){p=a[q+4|0]|0;k=p&255;if(p<<24>>24==0){$=T;aa=U;break}do{if((a[1108928]|0)==0){p=b[(c[277225]|0)+(k<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)!=0){ab=b[(c[277221]|0)+((p&65535|67616)-(b[(c[277213]|0)+(n<<1)>>1]&63454)>>1<<1)>>1]|0;break}m=c[277228]&65535;w=p&-2048;v=m&-2048;x=(w&65535)>(v&65535)?w-v&65535:0;v=p&2016;w=m&2016;if((v&65535)>(w&65535)){ac=(v-w&65535)+x&65535}else{ac=x}x=p&31;p=m&31;if((x&65535)<=(p&65535)){ab=ac;break}ab=(x-p&65535)+ac&65535}else{p=b[(c[277225]|0)+(k<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)==0){ad=c[277228]&65535}else{ad=b[(c[277213]|0)+(n<<1)>>1]|0}x=p&-2048;m=ad&-2048;w=(x&65535)>(m&65535)?x-m&65535:0;m=p&2016;x=ad&2016;if((m&65535)>(x&65535)){ae=(m-x&65535)+w&65535}else{ae=w}w=p&31;p=ad&31;if((w&65535)<=(p&65535)){ab=ae;break}ab=(w-p&65535)+ae&65535}}while(0);b[(c[277218]|0)+(n<<1)>>1]=ab;do{if((a[1108928]|0)==0){p=b[(c[277213]|0)+(l+10<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)!=0){af=b[(c[277221]|0)+((p&65535|67616)-(b[(c[277226]|0)+(k<<1)>>1]&63454)>>1<<1)>>1]|0;break}w=c[277228]&65535;x=p&-2048;m=w&-2048;v=(x&65535)>(m&65535)?x-m&65535:0;m=p&2016;x=w&2016;if((m&65535)>(x&65535)){ag=(m-x&65535)+v&65535}else{ag=v}v=p&31;p=w&31;if((v&65535)<=(p&65535)){af=ag;break}af=(v-p&65535)+ag&65535}else{af=0}}while(0);k=l+9|0;b[(c[277218]|0)+(k<<1)>>1]=af;p=a[1108909]|0;a[(c[277219]|0)+k|0]=p;a[(c[277219]|0)+n|0]=p;$=a[1108908]|0;aa=c[277219]|0}else{$=T;aa=U}}while(0);n=l+10|0;do{if(($&255)>(d[aa+n|0]|0)){p=a[q+5|0]|0;k=p&255;if(p<<24>>24==0){ah=$;ai=aa;break}do{if((a[1108928]|0)==0){p=b[(c[277225]|0)+(k<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)!=0){aj=b[(c[277221]|0)+((p&65535|67616)-(b[(c[277213]|0)+(n<<1)>>1]&63454)>>1<<1)>>1]|0;break}v=c[277228]&65535;w=p&-2048;x=v&-2048;m=(w&65535)>(x&65535)?w-x&65535:0;x=p&2016;w=v&2016;if((x&65535)>(w&65535)){ak=(x-w&65535)+m&65535}else{ak=m}m=p&31;p=v&31;if((m&65535)<=(p&65535)){aj=ak;break}aj=(m-p&65535)+ak&65535}else{p=b[(c[277225]|0)+(k<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)==0){al=c[277228]&65535}else{al=b[(c[277213]|0)+(n<<1)>>1]|0}m=p&-2048;v=al&-2048;w=(m&65535)>(v&65535)?m-v&65535:0;v=p&2016;m=al&2016;if((v&65535)>(m&65535)){am=(v-m&65535)+w&65535}else{am=w}w=p&31;p=al&31;if((w&65535)<=(p&65535)){aj=am;break}aj=(w-p&65535)+am&65535}}while(0);b[(c[277218]|0)+(n<<1)>>1]=aj;do{if((a[1108928]|0)==0){p=b[(c[277213]|0)+(l+12<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)!=0){an=b[(c[277221]|0)+((p&65535|67616)-(b[(c[277226]|0)+(k<<1)>>1]&63454)>>1<<1)>>1]|0;break}w=c[277228]&65535;m=p&-2048;v=w&-2048;x=(m&65535)>(v&65535)?m-v&65535:0;v=p&2016;m=w&2016;if((v&65535)>(m&65535)){ao=(v-m&65535)+x&65535}else{ao=x}x=p&31;p=w&31;if((x&65535)<=(p&65535)){an=ao;break}an=(x-p&65535)+ao&65535}else{an=0}}while(0);k=l+11|0;b[(c[277218]|0)+(k<<1)>>1]=an;p=a[1108909]|0;a[(c[277219]|0)+k|0]=p;a[(c[277219]|0)+n|0]=p;ah=a[1108908]|0;ai=c[277219]|0}else{ah=$;ai=aa}}while(0);n=l+12|0;do{if((ah&255)>(d[ai+n|0]|0)){p=a[q+6|0]|0;k=p&255;if(p<<24>>24==0){ap=ah;aq=ai;break}do{if((a[1108928]|0)==0){p=b[(c[277225]|0)+(k<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)!=0){ar=b[(c[277221]|0)+((p&65535|67616)-(b[(c[277213]|0)+(n<<1)>>1]&63454)>>1<<1)>>1]|0;break}x=c[277228]&65535;w=p&-2048;m=x&-2048;v=(w&65535)>(m&65535)?w-m&65535:0;m=p&2016;w=x&2016;if((m&65535)>(w&65535)){as=(m-w&65535)+v&65535}else{as=v}v=p&31;p=x&31;if((v&65535)<=(p&65535)){ar=as;break}ar=(v-p&65535)+as&65535}else{p=b[(c[277225]|0)+(k<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)==0){at=c[277228]&65535}else{at=b[(c[277213]|0)+(n<<1)>>1]|0}v=p&-2048;x=at&-2048;w=(v&65535)>(x&65535)?v-x&65535:0;x=p&2016;v=at&2016;if((x&65535)>(v&65535)){au=(x-v&65535)+w&65535}else{au=w}w=p&31;p=at&31;if((w&65535)<=(p&65535)){ar=au;break}ar=(w-p&65535)+au&65535}}while(0);b[(c[277218]|0)+(n<<1)>>1]=ar;do{if((a[1108928]|0)==0){p=b[(c[277213]|0)+(l+14<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)!=0){av=b[(c[277221]|0)+((p&65535|67616)-(b[(c[277226]|0)+(k<<1)>>1]&63454)>>1<<1)>>1]|0;break}w=c[277228]&65535;v=p&-2048;x=w&-2048;m=(v&65535)>(x&65535)?v-x&65535:0;x=p&2016;v=w&2016;if((x&65535)>(v&65535)){aw=(x-v&65535)+m&65535}else{aw=m}m=p&31;p=w&31;if((m&65535)<=(p&65535)){av=aw;break}av=(m-p&65535)+aw&65535}else{av=0}}while(0);k=l+13|0;b[(c[277218]|0)+(k<<1)>>1]=av;p=a[1108909]|0;a[(c[277219]|0)+k|0]=p;a[(c[277219]|0)+n|0]=p;ap=a[1108908]|0;aq=c[277219]|0}else{ap=ah;aq=ai}}while(0);n=l+14|0;do{if((ap&255)>(d[aq+n|0]|0)){p=a[q+7|0]|0;k=p&255;if(p<<24>>24==0){break}do{if((a[1108928]|0)==0){p=b[(c[277225]|0)+(k<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)!=0){ax=b[(c[277221]|0)+((p&65535|67616)-(b[(c[277213]|0)+(n<<1)>>1]&63454)>>1<<1)>>1]|0;break}m=c[277228]&65535;w=p&-2048;v=m&-2048;x=(w&65535)>(v&65535)?w-v&65535:0;v=p&2016;w=m&2016;if((v&65535)>(w&65535)){ay=(v-w&65535)+x&65535}else{ay=x}x=p&31;p=m&31;if((x&65535)<=(p&65535)){ax=ay;break}ax=(x-p&65535)+ay&65535}else{p=b[(c[277225]|0)+(k<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)==0){az=c[277228]&65535}else{az=b[(c[277213]|0)+(n<<1)>>1]|0}x=p&-2048;m=az&-2048;w=(x&65535)>(m&65535)?x-m&65535:0;m=p&2016;x=az&2016;if((m&65535)>(x&65535)){aA=(m-x&65535)+w&65535}else{aA=w}w=p&31;p=az&31;if((w&65535)<=(p&65535)){ax=aA;break}ax=(w-p&65535)+aA&65535}}while(0);b[(c[277218]|0)+(n<<1)>>1]=ax;do{if((a[1108928]|0)==0){p=b[(c[277213]|0)+(l+16<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)!=0){aB=b[(c[277221]|0)+((p&65535|67616)-(b[(c[277226]|0)+(k<<1)>>1]&63454)>>1<<1)>>1]|0;break}w=c[277228]&65535;x=p&-2048;m=w&-2048;v=(x&65535)>(m&65535)?x-m&65535:0;m=p&2016;x=w&2016;if((m&65535)>(x&65535)){aC=(m-x&65535)+v&65535}else{aC=v}v=p&31;p=w&31;if((v&65535)<=(p&65535)){aB=aC;break}aB=(v-p&65535)+aC&65535}else{aB=0}}while(0);k=l+15|0;b[(c[277218]|0)+(k<<1)>>1]=aB;p=a[1108909]|0;a[(c[277219]|0)+k|0]=p;a[(c[277219]|0)+n|0]=p}}while(0);n=i-1|0;if((n|0)<=0){break}q=q+16|0;i=n;l=(c[277223]|0)+l|0}return}l=(d[1394504]|0)+(g<<1)|0;if((e&32768|0)==0){if((h|0)<=0){return}e=o+l|0;g=h;i=f;while(1){q=a[1108908]|0;aB=c[277219]|0;do{if((q&255)>(d[aB+i|0]|0)){aC=a[e+7|0]|0;ax=aC&255;if(aC<<24>>24==0){aD=q;aE=aB;break}do{if((a[1108928]|0)==0){aC=b[(c[277225]|0)+(ax<<1)>>1]|0;if((a[(c[277215]|0)+i|0]&32)!=0){aF=b[(c[277221]|0)+((aC&65535|67616)-(b[(c[277213]|0)+(i<<1)>>1]&63454)>>1<<1)>>1]|0;break}aA=c[277228]&65535;az=aC&-2048;ay=aA&-2048;aq=(az&65535)>(ay&65535)?az-ay&65535:0;ay=aC&2016;az=aA&2016;if((ay&65535)>(az&65535)){aG=(ay-az&65535)+aq&65535}else{aG=aq}aq=aC&31;aC=aA&31;if((aq&65535)<=(aC&65535)){aF=aG;break}aF=(aq-aC&65535)+aG&65535}else{aC=b[(c[277225]|0)+(ax<<1)>>1]|0;if((a[(c[277215]|0)+i|0]&32)==0){aH=c[277228]&65535}else{aH=b[(c[277213]|0)+(i<<1)>>1]|0}aq=aC&-2048;aA=aH&-2048;az=(aq&65535)>(aA&65535)?aq-aA&65535:0;aA=aC&2016;aq=aH&2016;if((aA&65535)>(aq&65535)){aI=(aA-aq&65535)+az&65535}else{aI=az}az=aC&31;aC=aH&31;if((az&65535)<=(aC&65535)){aF=aI;break}aF=(az-aC&65535)+aI&65535}}while(0);b[(c[277218]|0)+(i<<1)>>1]=aF;do{if((a[1108928]|0)==0){aC=b[(c[277213]|0)+(i+2<<1)>>1]|0;if((a[(c[277215]|0)+i|0]&32)!=0){aJ=b[(c[277221]|0)+((aC&65535|67616)-(b[(c[277226]|0)+(ax<<1)>>1]&63454)>>1<<1)>>1]|0;break}az=c[277228]&65535;aq=aC&-2048;aA=az&-2048;ay=(aq&65535)>(aA&65535)?aq-aA&65535:0;aA=aC&2016;aq=az&2016;if((aA&65535)>(aq&65535)){aK=(aA-aq&65535)+ay&65535}else{aK=ay}ay=aC&31;aC=az&31;if((ay&65535)<=(aC&65535)){aJ=aK;break}aJ=(ay-aC&65535)+aK&65535}else{aJ=0}}while(0);ax=i+1|0;b[(c[277218]|0)+(ax<<1)>>1]=aJ;aC=a[1108909]|0;a[(c[277219]|0)+ax|0]=aC;a[(c[277219]|0)+i|0]=aC;aD=a[1108908]|0;aE=c[277219]|0}else{aD=q;aE=aB}}while(0);aB=i+2|0;do{if((aD&255)>(d[aE+aB|0]|0)){q=a[e+6|0]|0;aC=q&255;if(q<<24>>24==0){aL=aD;aM=aE;break}do{if((a[1108928]|0)==0){q=b[(c[277225]|0)+(aC<<1)>>1]|0;if((a[(c[277215]|0)+aB|0]&32)!=0){aN=b[(c[277221]|0)+((q&65535|67616)-(b[(c[277213]|0)+(aB<<1)>>1]&63454)>>1<<1)>>1]|0;break}ax=c[277228]&65535;ay=q&-2048;az=ax&-2048;aq=(ay&65535)>(az&65535)?ay-az&65535:0;az=q&2016;ay=ax&2016;if((az&65535)>(ay&65535)){aO=(az-ay&65535)+aq&65535}else{aO=aq}aq=q&31;q=ax&31;if((aq&65535)<=(q&65535)){aN=aO;break}aN=(aq-q&65535)+aO&65535}else{q=b[(c[277225]|0)+(aC<<1)>>1]|0;if((a[(c[277215]|0)+aB|0]&32)==0){aP=c[277228]&65535}else{aP=b[(c[277213]|0)+(aB<<1)>>1]|0}aq=q&-2048;ax=aP&-2048;ay=(aq&65535)>(ax&65535)?aq-ax&65535:0;ax=q&2016;aq=aP&2016;if((ax&65535)>(aq&65535)){aQ=(ax-aq&65535)+ay&65535}else{aQ=ay}ay=q&31;q=aP&31;if((ay&65535)<=(q&65535)){aN=aQ;break}aN=(ay-q&65535)+aQ&65535}}while(0);b[(c[277218]|0)+(aB<<1)>>1]=aN;do{if((a[1108928]|0)==0){q=b[(c[277213]|0)+(i+4<<1)>>1]|0;if((a[(c[277215]|0)+aB|0]&32)!=0){aR=b[(c[277221]|0)+((q&65535|67616)-(b[(c[277226]|0)+(aC<<1)>>1]&63454)>>1<<1)>>1]|0;break}ay=c[277228]&65535;aq=q&-2048;ax=ay&-2048;az=(aq&65535)>(ax&65535)?aq-ax&65535:0;ax=q&2016;aq=ay&2016;if((ax&65535)>(aq&65535)){aS=(ax-aq&65535)+az&65535}else{aS=az}az=q&31;q=ay&31;if((az&65535)<=(q&65535)){aR=aS;break}aR=(az-q&65535)+aS&65535}else{aR=0}}while(0);aC=i+3|0;b[(c[277218]|0)+(aC<<1)>>1]=aR;q=a[1108909]|0;a[(c[277219]|0)+aC|0]=q;a[(c[277219]|0)+aB|0]=q;aL=a[1108908]|0;aM=c[277219]|0}else{aL=aD;aM=aE}}while(0);aB=i+4|0;do{if((aL&255)>(d[aM+aB|0]|0)){q=a[e+5|0]|0;aC=q&255;if(q<<24>>24==0){aT=aL;aU=aM;break}do{if((a[1108928]|0)==0){q=b[(c[277225]|0)+(aC<<1)>>1]|0;if((a[(c[277215]|0)+aB|0]&32)!=0){aV=b[(c[277221]|0)+((q&65535|67616)-(b[(c[277213]|0)+(aB<<1)>>1]&63454)>>1<<1)>>1]|0;break}az=c[277228]&65535;ay=q&-2048;aq=az&-2048;ax=(ay&65535)>(aq&65535)?ay-aq&65535:0;aq=q&2016;ay=az&2016;if((aq&65535)>(ay&65535)){aW=(aq-ay&65535)+ax&65535}else{aW=ax}ax=q&31;q=az&31;if((ax&65535)<=(q&65535)){aV=aW;break}aV=(ax-q&65535)+aW&65535}else{q=b[(c[277225]|0)+(aC<<1)>>1]|0;if((a[(c[277215]|0)+aB|0]&32)==0){aX=c[277228]&65535}else{aX=b[(c[277213]|0)+(aB<<1)>>1]|0}ax=q&-2048;az=aX&-2048;ay=(ax&65535)>(az&65535)?ax-az&65535:0;az=q&2016;ax=aX&2016;if((az&65535)>(ax&65535)){aY=(az-ax&65535)+ay&65535}else{aY=ay}ay=q&31;q=aX&31;if((ay&65535)<=(q&65535)){aV=aY;break}aV=(ay-q&65535)+aY&65535}}while(0);b[(c[277218]|0)+(aB<<1)>>1]=aV;do{if((a[1108928]|0)==0){q=b[(c[277213]|0)+(i+6<<1)>>1]|0;if((a[(c[277215]|0)+aB|0]&32)!=0){aZ=b[(c[277221]|0)+((q&65535|67616)-(b[(c[277226]|0)+(aC<<1)>>1]&63454)>>1<<1)>>1]|0;break}ay=c[277228]&65535;ax=q&-2048;az=ay&-2048;aq=(ax&65535)>(az&65535)?ax-az&65535:0;az=q&2016;ax=ay&2016;if((az&65535)>(ax&65535)){a_=(az-ax&65535)+aq&65535}else{a_=aq}aq=q&31;q=ay&31;if((aq&65535)<=(q&65535)){aZ=a_;break}aZ=(aq-q&65535)+a_&65535}else{aZ=0}}while(0);aC=i+5|0;b[(c[277218]|0)+(aC<<1)>>1]=aZ;q=a[1108909]|0;a[(c[277219]|0)+aC|0]=q;a[(c[277219]|0)+aB|0]=q;aT=a[1108908]|0;aU=c[277219]|0}else{aT=aL;aU=aM}}while(0);aB=i+6|0;do{if((aT&255)>(d[aU+aB|0]|0)){q=a[e+4|0]|0;aC=q&255;if(q<<24>>24==0){a$=aT;a0=aU;break}do{if((a[1108928]|0)==0){q=b[(c[277225]|0)+(aC<<1)>>1]|0;if((a[(c[277215]|0)+aB|0]&32)!=0){a1=b[(c[277221]|0)+((q&65535|67616)-(b[(c[277213]|0)+(aB<<1)>>1]&63454)>>1<<1)>>1]|0;break}aq=c[277228]&65535;ay=q&-2048;ax=aq&-2048;az=(ay&65535)>(ax&65535)?ay-ax&65535:0;ax=q&2016;ay=aq&2016;if((ax&65535)>(ay&65535)){a2=(ax-ay&65535)+az&65535}else{a2=az}az=q&31;q=aq&31;if((az&65535)<=(q&65535)){a1=a2;break}a1=(az-q&65535)+a2&65535}else{q=b[(c[277225]|0)+(aC<<1)>>1]|0;if((a[(c[277215]|0)+aB|0]&32)==0){a3=c[277228]&65535}else{a3=b[(c[277213]|0)+(aB<<1)>>1]|0}az=q&-2048;aq=a3&-2048;ay=(az&65535)>(aq&65535)?az-aq&65535:0;aq=q&2016;az=a3&2016;if((aq&65535)>(az&65535)){a4=(aq-az&65535)+ay&65535}else{a4=ay}ay=q&31;q=a3&31;if((ay&65535)<=(q&65535)){a1=a4;break}a1=(ay-q&65535)+a4&65535}}while(0);b[(c[277218]|0)+(aB<<1)>>1]=a1;do{if((a[1108928]|0)==0){q=b[(c[277213]|0)+(i+8<<1)>>1]|0;if((a[(c[277215]|0)+aB|0]&32)!=0){a5=b[(c[277221]|0)+((q&65535|67616)-(b[(c[277226]|0)+(aC<<1)>>1]&63454)>>1<<1)>>1]|0;break}ay=c[277228]&65535;az=q&-2048;aq=ay&-2048;ax=(az&65535)>(aq&65535)?az-aq&65535:0;aq=q&2016;az=ay&2016;if((aq&65535)>(az&65535)){a6=(aq-az&65535)+ax&65535}else{a6=ax}ax=q&31;q=ay&31;if((ax&65535)<=(q&65535)){a5=a6;break}a5=(ax-q&65535)+a6&65535}else{a5=0}}while(0);aC=i+7|0;b[(c[277218]|0)+(aC<<1)>>1]=a5;q=a[1108909]|0;a[(c[277219]|0)+aC|0]=q;a[(c[277219]|0)+aB|0]=q;a$=a[1108908]|0;a0=c[277219]|0}else{a$=aT;a0=aU}}while(0);aB=i+8|0;do{if((a$&255)>(d[a0+aB|0]|0)){q=a[e+3|0]|0;aC=q&255;if(q<<24>>24==0){a7=a$;a8=a0;break}do{if((a[1108928]|0)==0){q=b[(c[277225]|0)+(aC<<1)>>1]|0;if((a[(c[277215]|0)+aB|0]&32)!=0){a9=b[(c[277221]|0)+((q&65535|67616)-(b[(c[277213]|0)+(aB<<1)>>1]&63454)>>1<<1)>>1]|0;break}ax=c[277228]&65535;ay=q&-2048;az=ax&-2048;aq=(ay&65535)>(az&65535)?ay-az&65535:0;az=q&2016;ay=ax&2016;if((az&65535)>(ay&65535)){ba=(az-ay&65535)+aq&65535}else{ba=aq}aq=q&31;q=ax&31;if((aq&65535)<=(q&65535)){a9=ba;break}a9=(aq-q&65535)+ba&65535}else{q=b[(c[277225]|0)+(aC<<1)>>1]|0;if((a[(c[277215]|0)+aB|0]&32)==0){bb=c[277228]&65535}else{bb=b[(c[277213]|0)+(aB<<1)>>1]|0}aq=q&-2048;ax=bb&-2048;ay=(aq&65535)>(ax&65535)?aq-ax&65535:0;ax=q&2016;aq=bb&2016;if((ax&65535)>(aq&65535)){bc=(ax-aq&65535)+ay&65535}else{bc=ay}ay=q&31;q=bb&31;if((ay&65535)<=(q&65535)){a9=bc;break}a9=(ay-q&65535)+bc&65535}}while(0);b[(c[277218]|0)+(aB<<1)>>1]=a9;do{if((a[1108928]|0)==0){q=b[(c[277213]|0)+(i+10<<1)>>1]|0;if((a[(c[277215]|0)+aB|0]&32)!=0){bd=b[(c[277221]|0)+((q&65535|67616)-(b[(c[277226]|0)+(aC<<1)>>1]&63454)>>1<<1)>>1]|0;break}ay=c[277228]&65535;aq=q&-2048;ax=ay&-2048;az=(aq&65535)>(ax&65535)?aq-ax&65535:0;ax=q&2016;aq=ay&2016;if((ax&65535)>(aq&65535)){be=(ax-aq&65535)+az&65535}else{be=az}az=q&31;q=ay&31;if((az&65535)<=(q&65535)){bd=be;break}bd=(az-q&65535)+be&65535}else{bd=0}}while(0);aC=i+9|0;b[(c[277218]|0)+(aC<<1)>>1]=bd;q=a[1108909]|0;a[(c[277219]|0)+aC|0]=q;a[(c[277219]|0)+aB|0]=q;a7=a[1108908]|0;a8=c[277219]|0}else{a7=a$;a8=a0}}while(0);aB=i+10|0;do{if((a7&255)>(d[a8+aB|0]|0)){q=a[e+2|0]|0;aC=q&255;if(q<<24>>24==0){bf=a7;bg=a8;break}do{if((a[1108928]|0)==0){q=b[(c[277225]|0)+(aC<<1)>>1]|0;if((a[(c[277215]|0)+aB|0]&32)!=0){bh=b[(c[277221]|0)+((q&65535|67616)-(b[(c[277213]|0)+(aB<<1)>>1]&63454)>>1<<1)>>1]|0;break}az=c[277228]&65535;ay=q&-2048;aq=az&-2048;ax=(ay&65535)>(aq&65535)?ay-aq&65535:0;aq=q&2016;ay=az&2016;if((aq&65535)>(ay&65535)){bi=(aq-ay&65535)+ax&65535}else{bi=ax}ax=q&31;q=az&31;if((ax&65535)<=(q&65535)){bh=bi;break}bh=(ax-q&65535)+bi&65535}else{q=b[(c[277225]|0)+(aC<<1)>>1]|0;if((a[(c[277215]|0)+aB|0]&32)==0){bj=c[277228]&65535}else{bj=b[(c[277213]|0)+(aB<<1)>>1]|0}ax=q&-2048;az=bj&-2048;ay=(ax&65535)>(az&65535)?ax-az&65535:0;az=q&2016;ax=bj&2016;if((az&65535)>(ax&65535)){bk=(az-ax&65535)+ay&65535}else{bk=ay}ay=q&31;q=bj&31;if((ay&65535)<=(q&65535)){bh=bk;break}bh=(ay-q&65535)+bk&65535}}while(0);b[(c[277218]|0)+(aB<<1)>>1]=bh;do{if((a[1108928]|0)==0){q=b[(c[277213]|0)+(i+12<<1)>>1]|0;if((a[(c[277215]|0)+aB|0]&32)!=0){bl=b[(c[277221]|0)+((q&65535|67616)-(b[(c[277226]|0)+(aC<<1)>>1]&63454)>>1<<1)>>1]|0;break}ay=c[277228]&65535;ax=q&-2048;az=ay&-2048;aq=(ax&65535)>(az&65535)?ax-az&65535:0;az=q&2016;ax=ay&2016;if((az&65535)>(ax&65535)){bm=(az-ax&65535)+aq&65535}else{bm=aq}aq=q&31;q=ay&31;if((aq&65535)<=(q&65535)){bl=bm;break}bl=(aq-q&65535)+bm&65535}else{bl=0}}while(0);aC=i+11|0;b[(c[277218]|0)+(aC<<1)>>1]=bl;q=a[1108909]|0;a[(c[277219]|0)+aC|0]=q;a[(c[277219]|0)+aB|0]=q;bf=a[1108908]|0;bg=c[277219]|0}else{bf=a7;bg=a8}}while(0);aB=i+12|0;do{if((bf&255)>(d[bg+aB|0]|0)){q=a[e+1|0]|0;aC=q&255;if(q<<24>>24==0){bn=bf;bo=bg;break}do{if((a[1108928]|0)==0){q=b[(c[277225]|0)+(aC<<1)>>1]|0;if((a[(c[277215]|0)+aB|0]&32)!=0){bp=b[(c[277221]|0)+((q&65535|67616)-(b[(c[277213]|0)+(aB<<1)>>1]&63454)>>1<<1)>>1]|0;break}aq=c[277228]&65535;ay=q&-2048;ax=aq&-2048;az=(ay&65535)>(ax&65535)?ay-ax&65535:0;ax=q&2016;ay=aq&2016;if((ax&65535)>(ay&65535)){bq=(ax-ay&65535)+az&65535}else{bq=az}az=q&31;q=aq&31;if((az&65535)<=(q&65535)){bp=bq;break}bp=(az-q&65535)+bq&65535}else{q=b[(c[277225]|0)+(aC<<1)>>1]|0;if((a[(c[277215]|0)+aB|0]&32)==0){br=c[277228]&65535}else{br=b[(c[277213]|0)+(aB<<1)>>1]|0}az=q&-2048;aq=br&-2048;ay=(az&65535)>(aq&65535)?az-aq&65535:0;aq=q&2016;az=br&2016;if((aq&65535)>(az&65535)){bs=(aq-az&65535)+ay&65535}else{bs=ay}ay=q&31;q=br&31;if((ay&65535)<=(q&65535)){bp=bs;break}bp=(ay-q&65535)+bs&65535}}while(0);b[(c[277218]|0)+(aB<<1)>>1]=bp;do{if((a[1108928]|0)==0){q=b[(c[277213]|0)+(i+14<<1)>>1]|0;if((a[(c[277215]|0)+aB|0]&32)!=0){bt=b[(c[277221]|0)+((q&65535|67616)-(b[(c[277226]|0)+(aC<<1)>>1]&63454)>>1<<1)>>1]|0;break}ay=c[277228]&65535;az=q&-2048;aq=ay&-2048;ax=(az&65535)>(aq&65535)?az-aq&65535:0;aq=q&2016;az=ay&2016;if((aq&65535)>(az&65535)){bu=(aq-az&65535)+ax&65535}else{bu=ax}ax=q&31;q=ay&31;if((ax&65535)<=(q&65535)){bt=bu;break}bt=(ax-q&65535)+bu&65535}else{bt=0}}while(0);aC=i+13|0;b[(c[277218]|0)+(aC<<1)>>1]=bt;q=a[1108909]|0;a[(c[277219]|0)+aC|0]=q;a[(c[277219]|0)+aB|0]=q;bn=a[1108908]|0;bo=c[277219]|0}else{bn=bf;bo=bg}}while(0);aB=i+14|0;do{if((bn&255)>(d[bo+aB|0]|0)){q=a[e]|0;aC=q&255;if(q<<24>>24==0){break}do{if((a[1108928]|0)==0){q=b[(c[277225]|0)+(aC<<1)>>1]|0;if((a[(c[277215]|0)+aB|0]&32)!=0){bv=b[(c[277221]|0)+((q&65535|67616)-(b[(c[277213]|0)+(aB<<1)>>1]&63454)>>1<<1)>>1]|0;break}ax=c[277228]&65535;ay=q&-2048;az=ax&-2048;aq=(ay&65535)>(az&65535)?ay-az&65535:0;az=q&2016;ay=ax&2016;if((az&65535)>(ay&65535)){bw=(az-ay&65535)+aq&65535}else{bw=aq}aq=q&31;q=ax&31;if((aq&65535)<=(q&65535)){bv=bw;break}bv=(aq-q&65535)+bw&65535}else{q=b[(c[277225]|0)+(aC<<1)>>1]|0;if((a[(c[277215]|0)+aB|0]&32)==0){bx=c[277228]&65535}else{bx=b[(c[277213]|0)+(aB<<1)>>1]|0}aq=q&-2048;ax=bx&-2048;ay=(aq&65535)>(ax&65535)?aq-ax&65535:0;ax=q&2016;aq=bx&2016;if((ax&65535)>(aq&65535)){by=(ax-aq&65535)+ay&65535}else{by=ay}ay=q&31;q=bx&31;if((ay&65535)<=(q&65535)){bv=by;break}bv=(ay-q&65535)+by&65535}}while(0);b[(c[277218]|0)+(aB<<1)>>1]=bv;do{if((a[1108928]|0)==0){q=b[(c[277213]|0)+(i+16<<1)>>1]|0;if((a[(c[277215]|0)+aB|0]&32)!=0){bz=b[(c[277221]|0)+((q&65535|67616)-(b[(c[277226]|0)+(aC<<1)>>1]&63454)>>1<<1)>>1]|0;break}ay=c[277228]&65535;aq=q&-2048;ax=ay&-2048;az=(aq&65535)>(ax&65535)?aq-ax&65535:0;ax=q&2016;aq=ay&2016;if((ax&65535)>(aq&65535)){bA=(ax-aq&65535)+az&65535}else{bA=az}az=q&31;q=ay&31;if((az&65535)<=(q&65535)){bz=bA;break}bz=(az-q&65535)+bA&65535}else{bz=0}}while(0);aC=i+15|0;b[(c[277218]|0)+(aC<<1)>>1]=bz;q=a[1108909]|0;a[(c[277219]|0)+aC|0]=q;a[(c[277219]|0)+aB|0]=q}}while(0);aB=g-1|0;if((aB|0)<=0){break}e=e+16|0;g=aB;i=(c[277223]|0)+i|0}return}i=o+(56-l)|0;l=(h|0)>0;if(j){if(l){bB=i;bC=h;bD=f}else{return}while(1){j=a[1108908]|0;o=c[277219]|0;do{if((j&255)>(d[o+bD|0]|0)){g=a[bB+7|0]|0;e=g&255;if(g<<24>>24==0){bE=j;bF=o;break}do{if((a[1108928]|0)==0){g=b[(c[277225]|0)+(e<<1)>>1]|0;if((a[(c[277215]|0)+bD|0]&32)!=0){bG=b[(c[277221]|0)+((g&65535|67616)-(b[(c[277213]|0)+(bD<<1)>>1]&63454)>>1<<1)>>1]|0;break}bz=c[277228]&65535;bA=g&-2048;bv=bz&-2048;by=(bA&65535)>(bv&65535)?bA-bv&65535:0;bv=g&2016;bA=bz&2016;if((bv&65535)>(bA&65535)){bH=(bv-bA&65535)+by&65535}else{bH=by}by=g&31;g=bz&31;if((by&65535)<=(g&65535)){bG=bH;break}bG=(by-g&65535)+bH&65535}else{g=b[(c[277225]|0)+(e<<1)>>1]|0;if((a[(c[277215]|0)+bD|0]&32)==0){bI=c[277228]&65535}else{bI=b[(c[277213]|0)+(bD<<1)>>1]|0}by=g&-2048;bz=bI&-2048;bA=(by&65535)>(bz&65535)?by-bz&65535:0;bz=g&2016;by=bI&2016;if((bz&65535)>(by&65535)){bJ=(bz-by&65535)+bA&65535}else{bJ=bA}bA=g&31;g=bI&31;if((bA&65535)<=(g&65535)){bG=bJ;break}bG=(bA-g&65535)+bJ&65535}}while(0);b[(c[277218]|0)+(bD<<1)>>1]=bG;do{if((a[1108928]|0)==0){g=b[(c[277213]|0)+(bD+2<<1)>>1]|0;if((a[(c[277215]|0)+bD|0]&32)!=0){bK=b[(c[277221]|0)+((g&65535|67616)-(b[(c[277226]|0)+(e<<1)>>1]&63454)>>1<<1)>>1]|0;break}bA=c[277228]&65535;by=g&-2048;bz=bA&-2048;bv=(by&65535)>(bz&65535)?by-bz&65535:0;bz=g&2016;by=bA&2016;if((bz&65535)>(by&65535)){bL=(bz-by&65535)+bv&65535}else{bL=bv}bv=g&31;g=bA&31;if((bv&65535)<=(g&65535)){bK=bL;break}bK=(bv-g&65535)+bL&65535}else{bK=0}}while(0);e=bD+1|0;b[(c[277218]|0)+(e<<1)>>1]=bK;g=a[1108909]|0;a[(c[277219]|0)+e|0]=g;a[(c[277219]|0)+bD|0]=g;bE=a[1108908]|0;bF=c[277219]|0}else{bE=j;bF=o}}while(0);o=bD+2|0;do{if((bE&255)>(d[bF+o|0]|0)){j=a[bB+6|0]|0;g=j&255;if(j<<24>>24==0){bM=bE;bN=bF;break}do{if((a[1108928]|0)==0){j=b[(c[277225]|0)+(g<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){bO=b[(c[277221]|0)+((j&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}e=c[277228]&65535;bv=j&-2048;bA=e&-2048;by=(bv&65535)>(bA&65535)?bv-bA&65535:0;bA=j&2016;bv=e&2016;if((bA&65535)>(bv&65535)){bP=(bA-bv&65535)+by&65535}else{bP=by}by=j&31;j=e&31;if((by&65535)<=(j&65535)){bO=bP;break}bO=(by-j&65535)+bP&65535}else{j=b[(c[277225]|0)+(g<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){bQ=c[277228]&65535}else{bQ=b[(c[277213]|0)+(o<<1)>>1]|0}by=j&-2048;e=bQ&-2048;bv=(by&65535)>(e&65535)?by-e&65535:0;e=j&2016;by=bQ&2016;if((e&65535)>(by&65535)){bR=(e-by&65535)+bv&65535}else{bR=bv}bv=j&31;j=bQ&31;if((bv&65535)<=(j&65535)){bO=bR;break}bO=(bv-j&65535)+bR&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=bO;do{if((a[1108928]|0)==0){j=b[(c[277213]|0)+(bD+4<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){bS=b[(c[277221]|0)+((j&65535|67616)-(b[(c[277226]|0)+(g<<1)>>1]&63454)>>1<<1)>>1]|0;break}bv=c[277228]&65535;by=j&-2048;e=bv&-2048;bA=(by&65535)>(e&65535)?by-e&65535:0;e=j&2016;by=bv&2016;if((e&65535)>(by&65535)){bT=(e-by&65535)+bA&65535}else{bT=bA}bA=j&31;j=bv&31;if((bA&65535)<=(j&65535)){bS=bT;break}bS=(bA-j&65535)+bT&65535}else{bS=0}}while(0);g=bD+3|0;b[(c[277218]|0)+(g<<1)>>1]=bS;j=a[1108909]|0;a[(c[277219]|0)+g|0]=j;a[(c[277219]|0)+o|0]=j;bM=a[1108908]|0;bN=c[277219]|0}else{bM=bE;bN=bF}}while(0);o=bD+4|0;do{if((bM&255)>(d[bN+o|0]|0)){j=a[bB+5|0]|0;g=j&255;if(j<<24>>24==0){bU=bM;bV=bN;break}do{if((a[1108928]|0)==0){j=b[(c[277225]|0)+(g<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){bW=b[(c[277221]|0)+((j&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}bA=c[277228]&65535;bv=j&-2048;by=bA&-2048;e=(bv&65535)>(by&65535)?bv-by&65535:0;by=j&2016;bv=bA&2016;if((by&65535)>(bv&65535)){bX=(by-bv&65535)+e&65535}else{bX=e}e=j&31;j=bA&31;if((e&65535)<=(j&65535)){bW=bX;break}bW=(e-j&65535)+bX&65535}else{j=b[(c[277225]|0)+(g<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){bY=c[277228]&65535}else{bY=b[(c[277213]|0)+(o<<1)>>1]|0}e=j&-2048;bA=bY&-2048;bv=(e&65535)>(bA&65535)?e-bA&65535:0;bA=j&2016;e=bY&2016;if((bA&65535)>(e&65535)){bZ=(bA-e&65535)+bv&65535}else{bZ=bv}bv=j&31;j=bY&31;if((bv&65535)<=(j&65535)){bW=bZ;break}bW=(bv-j&65535)+bZ&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=bW;do{if((a[1108928]|0)==0){j=b[(c[277213]|0)+(bD+6<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){b_=b[(c[277221]|0)+((j&65535|67616)-(b[(c[277226]|0)+(g<<1)>>1]&63454)>>1<<1)>>1]|0;break}bv=c[277228]&65535;e=j&-2048;bA=bv&-2048;by=(e&65535)>(bA&65535)?e-bA&65535:0;bA=j&2016;e=bv&2016;if((bA&65535)>(e&65535)){b$=(bA-e&65535)+by&65535}else{b$=by}by=j&31;j=bv&31;if((by&65535)<=(j&65535)){b_=b$;break}b_=(by-j&65535)+b$&65535}else{b_=0}}while(0);g=bD+5|0;b[(c[277218]|0)+(g<<1)>>1]=b_;j=a[1108909]|0;a[(c[277219]|0)+g|0]=j;a[(c[277219]|0)+o|0]=j;bU=a[1108908]|0;bV=c[277219]|0}else{bU=bM;bV=bN}}while(0);o=bD+6|0;do{if((bU&255)>(d[bV+o|0]|0)){j=a[bB+4|0]|0;g=j&255;if(j<<24>>24==0){b0=bU;b1=bV;break}do{if((a[1108928]|0)==0){j=b[(c[277225]|0)+(g<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){b2=b[(c[277221]|0)+((j&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}by=c[277228]&65535;bv=j&-2048;e=by&-2048;bA=(bv&65535)>(e&65535)?bv-e&65535:0;e=j&2016;bv=by&2016;if((e&65535)>(bv&65535)){b3=(e-bv&65535)+bA&65535}else{b3=bA}bA=j&31;j=by&31;if((bA&65535)<=(j&65535)){b2=b3;break}b2=(bA-j&65535)+b3&65535}else{j=b[(c[277225]|0)+(g<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){b4=c[277228]&65535}else{b4=b[(c[277213]|0)+(o<<1)>>1]|0}bA=j&-2048;by=b4&-2048;bv=(bA&65535)>(by&65535)?bA-by&65535:0;by=j&2016;bA=b4&2016;if((by&65535)>(bA&65535)){b5=(by-bA&65535)+bv&65535}else{b5=bv}bv=j&31;j=b4&31;if((bv&65535)<=(j&65535)){b2=b5;break}b2=(bv-j&65535)+b5&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=b2;do{if((a[1108928]|0)==0){j=b[(c[277213]|0)+(bD+8<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){b6=b[(c[277221]|0)+((j&65535|67616)-(b[(c[277226]|0)+(g<<1)>>1]&63454)>>1<<1)>>1]|0;break}bv=c[277228]&65535;bA=j&-2048;by=bv&-2048;e=(bA&65535)>(by&65535)?bA-by&65535:0;by=j&2016;bA=bv&2016;if((by&65535)>(bA&65535)){b7=(by-bA&65535)+e&65535}else{b7=e}e=j&31;j=bv&31;if((e&65535)<=(j&65535)){b6=b7;break}b6=(e-j&65535)+b7&65535}else{b6=0}}while(0);g=bD+7|0;b[(c[277218]|0)+(g<<1)>>1]=b6;j=a[1108909]|0;a[(c[277219]|0)+g|0]=j;a[(c[277219]|0)+o|0]=j;b0=a[1108908]|0;b1=c[277219]|0}else{b0=bU;b1=bV}}while(0);o=bD+8|0;do{if((b0&255)>(d[b1+o|0]|0)){j=a[bB+3|0]|0;g=j&255;if(j<<24>>24==0){b8=b0;b9=b1;break}do{if((a[1108928]|0)==0){j=b[(c[277225]|0)+(g<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){ca=b[(c[277221]|0)+((j&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}e=c[277228]&65535;bv=j&-2048;bA=e&-2048;by=(bv&65535)>(bA&65535)?bv-bA&65535:0;bA=j&2016;bv=e&2016;if((bA&65535)>(bv&65535)){cb=(bA-bv&65535)+by&65535}else{cb=by}by=j&31;j=e&31;if((by&65535)<=(j&65535)){ca=cb;break}ca=(by-j&65535)+cb&65535}else{j=b[(c[277225]|0)+(g<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){cc=c[277228]&65535}else{cc=b[(c[277213]|0)+(o<<1)>>1]|0}by=j&-2048;e=cc&-2048;bv=(by&65535)>(e&65535)?by-e&65535:0;e=j&2016;by=cc&2016;if((e&65535)>(by&65535)){cd=(e-by&65535)+bv&65535}else{cd=bv}bv=j&31;j=cc&31;if((bv&65535)<=(j&65535)){ca=cd;break}ca=(bv-j&65535)+cd&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=ca;do{if((a[1108928]|0)==0){j=b[(c[277213]|0)+(bD+10<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){ce=b[(c[277221]|0)+((j&65535|67616)-(b[(c[277226]|0)+(g<<1)>>1]&63454)>>1<<1)>>1]|0;break}bv=c[277228]&65535;by=j&-2048;e=bv&-2048;bA=(by&65535)>(e&65535)?by-e&65535:0;e=j&2016;by=bv&2016;if((e&65535)>(by&65535)){cf=(e-by&65535)+bA&65535}else{cf=bA}bA=j&31;j=bv&31;if((bA&65535)<=(j&65535)){ce=cf;break}ce=(bA-j&65535)+cf&65535}else{ce=0}}while(0);g=bD+9|0;b[(c[277218]|0)+(g<<1)>>1]=ce;j=a[1108909]|0;a[(c[277219]|0)+g|0]=j;a[(c[277219]|0)+o|0]=j;b8=a[1108908]|0;b9=c[277219]|0}else{b8=b0;b9=b1}}while(0);o=bD+10|0;do{if((b8&255)>(d[b9+o|0]|0)){j=a[bB+2|0]|0;g=j&255;if(j<<24>>24==0){cg=b8;ch=b9;break}do{if((a[1108928]|0)==0){j=b[(c[277225]|0)+(g<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){ci=b[(c[277221]|0)+((j&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}bA=c[277228]&65535;bv=j&-2048;by=bA&-2048;e=(bv&65535)>(by&65535)?bv-by&65535:0;by=j&2016;bv=bA&2016;if((by&65535)>(bv&65535)){cj=(by-bv&65535)+e&65535}else{cj=e}e=j&31;j=bA&31;if((e&65535)<=(j&65535)){ci=cj;break}ci=(e-j&65535)+cj&65535}else{j=b[(c[277225]|0)+(g<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){ck=c[277228]&65535}else{ck=b[(c[277213]|0)+(o<<1)>>1]|0}e=j&-2048;bA=ck&-2048;bv=(e&65535)>(bA&65535)?e-bA&65535:0;bA=j&2016;e=ck&2016;if((bA&65535)>(e&65535)){cl=(bA-e&65535)+bv&65535}else{cl=bv}bv=j&31;j=ck&31;if((bv&65535)<=(j&65535)){ci=cl;break}ci=(bv-j&65535)+cl&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=ci;do{if((a[1108928]|0)==0){j=b[(c[277213]|0)+(bD+12<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){cm=b[(c[277221]|0)+((j&65535|67616)-(b[(c[277226]|0)+(g<<1)>>1]&63454)>>1<<1)>>1]|0;break}bv=c[277228]&65535;e=j&-2048;bA=bv&-2048;by=(e&65535)>(bA&65535)?e-bA&65535:0;bA=j&2016;e=bv&2016;if((bA&65535)>(e&65535)){cn=(bA-e&65535)+by&65535}else{cn=by}by=j&31;j=bv&31;if((by&65535)<=(j&65535)){cm=cn;break}cm=(by-j&65535)+cn&65535}else{cm=0}}while(0);g=bD+11|0;b[(c[277218]|0)+(g<<1)>>1]=cm;j=a[1108909]|0;a[(c[277219]|0)+g|0]=j;a[(c[277219]|0)+o|0]=j;cg=a[1108908]|0;ch=c[277219]|0}else{cg=b8;ch=b9}}while(0);o=bD+12|0;do{if((cg&255)>(d[ch+o|0]|0)){j=a[bB+1|0]|0;g=j&255;if(j<<24>>24==0){co=cg;cp=ch;break}do{if((a[1108928]|0)==0){j=b[(c[277225]|0)+(g<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){cq=b[(c[277221]|0)+((j&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}by=c[277228]&65535;bv=j&-2048;e=by&-2048;bA=(bv&65535)>(e&65535)?bv-e&65535:0;e=j&2016;bv=by&2016;if((e&65535)>(bv&65535)){cr=(e-bv&65535)+bA&65535}else{cr=bA}bA=j&31;j=by&31;if((bA&65535)<=(j&65535)){cq=cr;break}cq=(bA-j&65535)+cr&65535}else{j=b[(c[277225]|0)+(g<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){cs=c[277228]&65535}else{cs=b[(c[277213]|0)+(o<<1)>>1]|0}bA=j&-2048;by=cs&-2048;bv=(bA&65535)>(by&65535)?bA-by&65535:0;by=j&2016;bA=cs&2016;if((by&65535)>(bA&65535)){ct=(by-bA&65535)+bv&65535}else{ct=bv}bv=j&31;j=cs&31;if((bv&65535)<=(j&65535)){cq=ct;break}cq=(bv-j&65535)+ct&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=cq;do{if((a[1108928]|0)==0){j=b[(c[277213]|0)+(bD+14<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){cu=b[(c[277221]|0)+((j&65535|67616)-(b[(c[277226]|0)+(g<<1)>>1]&63454)>>1<<1)>>1]|0;break}bv=c[277228]&65535;bA=j&-2048;by=bv&-2048;e=(bA&65535)>(by&65535)?bA-by&65535:0;by=j&2016;bA=bv&2016;if((by&65535)>(bA&65535)){cv=(by-bA&65535)+e&65535}else{cv=e}e=j&31;j=bv&31;if((e&65535)<=(j&65535)){cu=cv;break}cu=(e-j&65535)+cv&65535}else{cu=0}}while(0);g=bD+13|0;b[(c[277218]|0)+(g<<1)>>1]=cu;j=a[1108909]|0;a[(c[277219]|0)+g|0]=j;a[(c[277219]|0)+o|0]=j;co=a[1108908]|0;cp=c[277219]|0}else{co=cg;cp=ch}}while(0);o=bD+14|0;do{if((co&255)>(d[cp+o|0]|0)){j=a[bB]|0;g=j&255;if(j<<24>>24==0){break}do{if((a[1108928]|0)==0){j=b[(c[277225]|0)+(g<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){cw=b[(c[277221]|0)+((j&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}e=c[277228]&65535;bv=j&-2048;bA=e&-2048;by=(bv&65535)>(bA&65535)?bv-bA&65535:0;bA=j&2016;bv=e&2016;if((bA&65535)>(bv&65535)){cx=(bA-bv&65535)+by&65535}else{cx=by}by=j&31;j=e&31;if((by&65535)<=(j&65535)){cw=cx;break}cw=(by-j&65535)+cx&65535}else{j=b[(c[277225]|0)+(g<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){cy=c[277228]&65535}else{cy=b[(c[277213]|0)+(o<<1)>>1]|0}by=j&-2048;e=cy&-2048;bv=(by&65535)>(e&65535)?by-e&65535:0;e=j&2016;by=cy&2016;if((e&65535)>(by&65535)){cz=(e-by&65535)+bv&65535}else{cz=bv}bv=j&31;j=cy&31;if((bv&65535)<=(j&65535)){cw=cz;break}cw=(bv-j&65535)+cz&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=cw;do{if((a[1108928]|0)==0){j=b[(c[277213]|0)+(bD+16<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){cA=b[(c[277221]|0)+((j&65535|67616)-(b[(c[277226]|0)+(g<<1)>>1]&63454)>>1<<1)>>1]|0;break}bv=c[277228]&65535;by=j&-2048;e=bv&-2048;bA=(by&65535)>(e&65535)?by-e&65535:0;e=j&2016;by=bv&2016;if((e&65535)>(by&65535)){cB=(e-by&65535)+bA&65535}else{cB=bA}bA=j&31;j=bv&31;if((bA&65535)<=(j&65535)){cA=cB;break}cA=(bA-j&65535)+cB&65535}else{cA=0}}while(0);g=bD+15|0;b[(c[277218]|0)+(g<<1)>>1]=cA;j=a[1108909]|0;a[(c[277219]|0)+g|0]=j;a[(c[277219]|0)+o|0]=j}}while(0);o=bC-1|0;if((o|0)<=0){break}bB=bB-16|0;bC=o;bD=(c[277223]|0)+bD|0}return}else{if(l){cC=i;cD=h;cE=f}else{return}while(1){f=a[1108908]|0;h=c[277219]|0;do{if((f&255)>(d[h+cE|0]|0)){i=a[cC]|0;l=i&255;if(i<<24>>24==0){cF=f;cG=h;break}do{if((a[1108928]|0)==0){i=b[(c[277225]|0)+(l<<1)>>1]|0;if((a[(c[277215]|0)+cE|0]&32)!=0){cH=b[(c[277221]|0)+((i&65535|67616)-(b[(c[277213]|0)+(cE<<1)>>1]&63454)>>1<<1)>>1]|0;break}bD=c[277228]&65535;bC=i&-2048;bB=bD&-2048;cA=(bC&65535)>(bB&65535)?bC-bB&65535:0;bB=i&2016;bC=bD&2016;if((bB&65535)>(bC&65535)){cI=(bB-bC&65535)+cA&65535}else{cI=cA}cA=i&31;i=bD&31;if((cA&65535)<=(i&65535)){cH=cI;break}cH=(cA-i&65535)+cI&65535}else{i=b[(c[277225]|0)+(l<<1)>>1]|0;if((a[(c[277215]|0)+cE|0]&32)==0){cJ=c[277228]&65535}else{cJ=b[(c[277213]|0)+(cE<<1)>>1]|0}cA=i&-2048;bD=cJ&-2048;bC=(cA&65535)>(bD&65535)?cA-bD&65535:0;bD=i&2016;cA=cJ&2016;if((bD&65535)>(cA&65535)){cK=(bD-cA&65535)+bC&65535}else{cK=bC}bC=i&31;i=cJ&31;if((bC&65535)<=(i&65535)){cH=cK;break}cH=(bC-i&65535)+cK&65535}}while(0);b[(c[277218]|0)+(cE<<1)>>1]=cH;do{if((a[1108928]|0)==0){i=b[(c[277213]|0)+(cE+2<<1)>>1]|0;if((a[(c[277215]|0)+cE|0]&32)!=0){cL=b[(c[277221]|0)+((i&65535|67616)-(b[(c[277226]|0)+(l<<1)>>1]&63454)>>1<<1)>>1]|0;break}bC=c[277228]&65535;cA=i&-2048;bD=bC&-2048;bB=(cA&65535)>(bD&65535)?cA-bD&65535:0;bD=i&2016;cA=bC&2016;if((bD&65535)>(cA&65535)){cM=(bD-cA&65535)+bB&65535}else{cM=bB}bB=i&31;i=bC&31;if((bB&65535)<=(i&65535)){cL=cM;break}cL=(bB-i&65535)+cM&65535}else{cL=0}}while(0);l=cE+1|0;b[(c[277218]|0)+(l<<1)>>1]=cL;i=a[1108909]|0;a[(c[277219]|0)+l|0]=i;a[(c[277219]|0)+cE|0]=i;cF=a[1108908]|0;cG=c[277219]|0}else{cF=f;cG=h}}while(0);h=cE+2|0;do{if((cF&255)>(d[cG+h|0]|0)){f=a[cC+1|0]|0;i=f&255;if(f<<24>>24==0){cN=cF;cO=cG;break}do{if((a[1108928]|0)==0){f=b[(c[277225]|0)+(i<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)!=0){cP=b[(c[277221]|0)+((f&65535|67616)-(b[(c[277213]|0)+(h<<1)>>1]&63454)>>1<<1)>>1]|0;break}l=c[277228]&65535;bB=f&-2048;bC=l&-2048;cA=(bB&65535)>(bC&65535)?bB-bC&65535:0;bC=f&2016;bB=l&2016;if((bC&65535)>(bB&65535)){cQ=(bC-bB&65535)+cA&65535}else{cQ=cA}cA=f&31;f=l&31;if((cA&65535)<=(f&65535)){cP=cQ;break}cP=(cA-f&65535)+cQ&65535}else{f=b[(c[277225]|0)+(i<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)==0){cR=c[277228]&65535}else{cR=b[(c[277213]|0)+(h<<1)>>1]|0}cA=f&-2048;l=cR&-2048;bB=(cA&65535)>(l&65535)?cA-l&65535:0;l=f&2016;cA=cR&2016;if((l&65535)>(cA&65535)){cS=(l-cA&65535)+bB&65535}else{cS=bB}bB=f&31;f=cR&31;if((bB&65535)<=(f&65535)){cP=cS;break}cP=(bB-f&65535)+cS&65535}}while(0);b[(c[277218]|0)+(h<<1)>>1]=cP;do{if((a[1108928]|0)==0){f=b[(c[277213]|0)+(cE+4<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)!=0){cT=b[(c[277221]|0)+((f&65535|67616)-(b[(c[277226]|0)+(i<<1)>>1]&63454)>>1<<1)>>1]|0;break}bB=c[277228]&65535;cA=f&-2048;l=bB&-2048;bC=(cA&65535)>(l&65535)?cA-l&65535:0;l=f&2016;cA=bB&2016;if((l&65535)>(cA&65535)){cU=(l-cA&65535)+bC&65535}else{cU=bC}bC=f&31;f=bB&31;if((bC&65535)<=(f&65535)){cT=cU;break}cT=(bC-f&65535)+cU&65535}else{cT=0}}while(0);i=cE+3|0;b[(c[277218]|0)+(i<<1)>>1]=cT;f=a[1108909]|0;a[(c[277219]|0)+i|0]=f;a[(c[277219]|0)+h|0]=f;cN=a[1108908]|0;cO=c[277219]|0}else{cN=cF;cO=cG}}while(0);h=cE+4|0;do{if((cN&255)>(d[cO+h|0]|0)){f=a[cC+2|0]|0;i=f&255;if(f<<24>>24==0){cV=cN;cW=cO;break}do{if((a[1108928]|0)==0){f=b[(c[277225]|0)+(i<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)!=0){cX=b[(c[277221]|0)+((f&65535|67616)-(b[(c[277213]|0)+(h<<1)>>1]&63454)>>1<<1)>>1]|0;break}bC=c[277228]&65535;bB=f&-2048;cA=bC&-2048;l=(bB&65535)>(cA&65535)?bB-cA&65535:0;cA=f&2016;bB=bC&2016;if((cA&65535)>(bB&65535)){cY=(cA-bB&65535)+l&65535}else{cY=l}l=f&31;f=bC&31;if((l&65535)<=(f&65535)){cX=cY;break}cX=(l-f&65535)+cY&65535}else{f=b[(c[277225]|0)+(i<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)==0){cZ=c[277228]&65535}else{cZ=b[(c[277213]|0)+(h<<1)>>1]|0}l=f&-2048;bC=cZ&-2048;bB=(l&65535)>(bC&65535)?l-bC&65535:0;bC=f&2016;l=cZ&2016;if((bC&65535)>(l&65535)){c_=(bC-l&65535)+bB&65535}else{c_=bB}bB=f&31;f=cZ&31;if((bB&65535)<=(f&65535)){cX=c_;break}cX=(bB-f&65535)+c_&65535}}while(0);b[(c[277218]|0)+(h<<1)>>1]=cX;do{if((a[1108928]|0)==0){f=b[(c[277213]|0)+(cE+6<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)!=0){c$=b[(c[277221]|0)+((f&65535|67616)-(b[(c[277226]|0)+(i<<1)>>1]&63454)>>1<<1)>>1]|0;break}bB=c[277228]&65535;l=f&-2048;bC=bB&-2048;cA=(l&65535)>(bC&65535)?l-bC&65535:0;bC=f&2016;l=bB&2016;if((bC&65535)>(l&65535)){c0=(bC-l&65535)+cA&65535}else{c0=cA}cA=f&31;f=bB&31;if((cA&65535)<=(f&65535)){c$=c0;break}c$=(cA-f&65535)+c0&65535}else{c$=0}}while(0);i=cE+5|0;b[(c[277218]|0)+(i<<1)>>1]=c$;f=a[1108909]|0;a[(c[277219]|0)+i|0]=f;a[(c[277219]|0)+h|0]=f;cV=a[1108908]|0;cW=c[277219]|0}else{cV=cN;cW=cO}}while(0);h=cE+6|0;do{if((cV&255)>(d[cW+h|0]|0)){f=a[cC+3|0]|0;i=f&255;if(f<<24>>24==0){c1=cV;c2=cW;break}do{if((a[1108928]|0)==0){f=b[(c[277225]|0)+(i<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)!=0){c3=b[(c[277221]|0)+((f&65535|67616)-(b[(c[277213]|0)+(h<<1)>>1]&63454)>>1<<1)>>1]|0;break}cA=c[277228]&65535;bB=f&-2048;l=cA&-2048;bC=(bB&65535)>(l&65535)?bB-l&65535:0;l=f&2016;bB=cA&2016;if((l&65535)>(bB&65535)){c4=(l-bB&65535)+bC&65535}else{c4=bC}bC=f&31;f=cA&31;if((bC&65535)<=(f&65535)){c3=c4;break}c3=(bC-f&65535)+c4&65535}else{f=b[(c[277225]|0)+(i<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)==0){c5=c[277228]&65535}else{c5=b[(c[277213]|0)+(h<<1)>>1]|0}bC=f&-2048;cA=c5&-2048;bB=(bC&65535)>(cA&65535)?bC-cA&65535:0;cA=f&2016;bC=c5&2016;if((cA&65535)>(bC&65535)){c6=(cA-bC&65535)+bB&65535}else{c6=bB}bB=f&31;f=c5&31;if((bB&65535)<=(f&65535)){c3=c6;break}c3=(bB-f&65535)+c6&65535}}while(0);b[(c[277218]|0)+(h<<1)>>1]=c3;do{if((a[1108928]|0)==0){f=b[(c[277213]|0)+(cE+8<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)!=0){c7=b[(c[277221]|0)+((f&65535|67616)-(b[(c[277226]|0)+(i<<1)>>1]&63454)>>1<<1)>>1]|0;break}bB=c[277228]&65535;bC=f&-2048;cA=bB&-2048;l=(bC&65535)>(cA&65535)?bC-cA&65535:0;cA=f&2016;bC=bB&2016;if((cA&65535)>(bC&65535)){c8=(cA-bC&65535)+l&65535}else{c8=l}l=f&31;f=bB&31;if((l&65535)<=(f&65535)){c7=c8;break}c7=(l-f&65535)+c8&65535}else{c7=0}}while(0);i=cE+7|0;b[(c[277218]|0)+(i<<1)>>1]=c7;f=a[1108909]|0;a[(c[277219]|0)+i|0]=f;a[(c[277219]|0)+h|0]=f;c1=a[1108908]|0;c2=c[277219]|0}else{c1=cV;c2=cW}}while(0);h=cE+8|0;do{if((c1&255)>(d[c2+h|0]|0)){f=a[cC+4|0]|0;i=f&255;if(f<<24>>24==0){c9=c1;da=c2;break}do{if((a[1108928]|0)==0){f=b[(c[277225]|0)+(i<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)!=0){db=b[(c[277221]|0)+((f&65535|67616)-(b[(c[277213]|0)+(h<<1)>>1]&63454)>>1<<1)>>1]|0;break}l=c[277228]&65535;bB=f&-2048;bC=l&-2048;cA=(bB&65535)>(bC&65535)?bB-bC&65535:0;bC=f&2016;bB=l&2016;if((bC&65535)>(bB&65535)){dc=(bC-bB&65535)+cA&65535}else{dc=cA}cA=f&31;f=l&31;if((cA&65535)<=(f&65535)){db=dc;break}db=(cA-f&65535)+dc&65535}else{f=b[(c[277225]|0)+(i<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)==0){dd=c[277228]&65535}else{dd=b[(c[277213]|0)+(h<<1)>>1]|0}cA=f&-2048;l=dd&-2048;bB=(cA&65535)>(l&65535)?cA-l&65535:0;l=f&2016;cA=dd&2016;if((l&65535)>(cA&65535)){de=(l-cA&65535)+bB&65535}else{de=bB}bB=f&31;f=dd&31;if((bB&65535)<=(f&65535)){db=de;break}db=(bB-f&65535)+de&65535}}while(0);b[(c[277218]|0)+(h<<1)>>1]=db;do{if((a[1108928]|0)==0){f=b[(c[277213]|0)+(cE+10<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)!=0){df=b[(c[277221]|0)+((f&65535|67616)-(b[(c[277226]|0)+(i<<1)>>1]&63454)>>1<<1)>>1]|0;break}bB=c[277228]&65535;cA=f&-2048;l=bB&-2048;bC=(cA&65535)>(l&65535)?cA-l&65535:0;l=f&2016;cA=bB&2016;if((l&65535)>(cA&65535)){dg=(l-cA&65535)+bC&65535}else{dg=bC}bC=f&31;f=bB&31;if((bC&65535)<=(f&65535)){df=dg;break}df=(bC-f&65535)+dg&65535}else{df=0}}while(0);i=cE+9|0;b[(c[277218]|0)+(i<<1)>>1]=df;f=a[1108909]|0;a[(c[277219]|0)+i|0]=f;a[(c[277219]|0)+h|0]=f;c9=a[1108908]|0;da=c[277219]|0}else{c9=c1;da=c2}}while(0);h=cE+10|0;do{if((c9&255)>(d[da+h|0]|0)){f=a[cC+5|0]|0;i=f&255;if(f<<24>>24==0){dh=c9;di=da;break}do{if((a[1108928]|0)==0){f=b[(c[277225]|0)+(i<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)!=0){dj=b[(c[277221]|0)+((f&65535|67616)-(b[(c[277213]|0)+(h<<1)>>1]&63454)>>1<<1)>>1]|0;break}bC=c[277228]&65535;bB=f&-2048;cA=bC&-2048;l=(bB&65535)>(cA&65535)?bB-cA&65535:0;cA=f&2016;bB=bC&2016;if((cA&65535)>(bB&65535)){dk=(cA-bB&65535)+l&65535}else{dk=l}l=f&31;f=bC&31;if((l&65535)<=(f&65535)){dj=dk;break}dj=(l-f&65535)+dk&65535}else{f=b[(c[277225]|0)+(i<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)==0){dl=c[277228]&65535}else{dl=b[(c[277213]|0)+(h<<1)>>1]|0}l=f&-2048;bC=dl&-2048;bB=(l&65535)>(bC&65535)?l-bC&65535:0;bC=f&2016;l=dl&2016;if((bC&65535)>(l&65535)){dm=(bC-l&65535)+bB&65535}else{dm=bB}bB=f&31;f=dl&31;if((bB&65535)<=(f&65535)){dj=dm;break}dj=(bB-f&65535)+dm&65535}}while(0);b[(c[277218]|0)+(h<<1)>>1]=dj;do{if((a[1108928]|0)==0){f=b[(c[277213]|0)+(cE+12<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)!=0){dn=b[(c[277221]|0)+((f&65535|67616)-(b[(c[277226]|0)+(i<<1)>>1]&63454)>>1<<1)>>1]|0;break}bB=c[277228]&65535;l=f&-2048;bC=bB&-2048;cA=(l&65535)>(bC&65535)?l-bC&65535:0;bC=f&2016;l=bB&2016;if((bC&65535)>(l&65535)){dp=(bC-l&65535)+cA&65535}else{dp=cA}cA=f&31;f=bB&31;if((cA&65535)<=(f&65535)){dn=dp;break}dn=(cA-f&65535)+dp&65535}else{dn=0}}while(0);i=cE+11|0;b[(c[277218]|0)+(i<<1)>>1]=dn;f=a[1108909]|0;a[(c[277219]|0)+i|0]=f;a[(c[277219]|0)+h|0]=f;dh=a[1108908]|0;di=c[277219]|0}else{dh=c9;di=da}}while(0);h=cE+12|0;do{if((dh&255)>(d[di+h|0]|0)){f=a[cC+6|0]|0;i=f&255;if(f<<24>>24==0){dq=dh;dr=di;break}do{if((a[1108928]|0)==0){f=b[(c[277225]|0)+(i<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)!=0){ds=b[(c[277221]|0)+((f&65535|67616)-(b[(c[277213]|0)+(h<<1)>>1]&63454)>>1<<1)>>1]|0;break}cA=c[277228]&65535;bB=f&-2048;l=cA&-2048;bC=(bB&65535)>(l&65535)?bB-l&65535:0;l=f&2016;bB=cA&2016;if((l&65535)>(bB&65535)){dt=(l-bB&65535)+bC&65535}else{dt=bC}bC=f&31;f=cA&31;if((bC&65535)<=(f&65535)){ds=dt;break}ds=(bC-f&65535)+dt&65535}else{f=b[(c[277225]|0)+(i<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)==0){du=c[277228]&65535}else{du=b[(c[277213]|0)+(h<<1)>>1]|0}bC=f&-2048;cA=du&-2048;bB=(bC&65535)>(cA&65535)?bC-cA&65535:0;cA=f&2016;bC=du&2016;if((cA&65535)>(bC&65535)){dv=(cA-bC&65535)+bB&65535}else{dv=bB}bB=f&31;f=du&31;if((bB&65535)<=(f&65535)){ds=dv;break}ds=(bB-f&65535)+dv&65535}}while(0);b[(c[277218]|0)+(h<<1)>>1]=ds;do{if((a[1108928]|0)==0){f=b[(c[277213]|0)+(cE+14<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)!=0){dw=b[(c[277221]|0)+((f&65535|67616)-(b[(c[277226]|0)+(i<<1)>>1]&63454)>>1<<1)>>1]|0;break}bB=c[277228]&65535;bC=f&-2048;cA=bB&-2048;l=(bC&65535)>(cA&65535)?bC-cA&65535:0;cA=f&2016;bC=bB&2016;if((cA&65535)>(bC&65535)){dx=(cA-bC&65535)+l&65535}else{dx=l}l=f&31;f=bB&31;if((l&65535)<=(f&65535)){dw=dx;break}dw=(l-f&65535)+dx&65535}else{dw=0}}while(0);i=cE+13|0;b[(c[277218]|0)+(i<<1)>>1]=dw;f=a[1108909]|0;a[(c[277219]|0)+i|0]=f;a[(c[277219]|0)+h|0]=f;dq=a[1108908]|0;dr=c[277219]|0}else{dq=dh;dr=di}}while(0);h=cE+14|0;do{if((dq&255)>(d[dr+h|0]|0)){f=a[cC+7|0]|0;i=f&255;if(f<<24>>24==0){break}do{if((a[1108928]|0)==0){f=b[(c[277225]|0)+(i<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)!=0){dy=b[(c[277221]|0)+((f&65535|67616)-(b[(c[277213]|0)+(h<<1)>>1]&63454)>>1<<1)>>1]|0;break}l=c[277228]&65535;bB=f&-2048;bC=l&-2048;cA=(bB&65535)>(bC&65535)?bB-bC&65535:0;bC=f&2016;bB=l&2016;if((bC&65535)>(bB&65535)){dz=(bC-bB&65535)+cA&65535}else{dz=cA}cA=f&31;f=l&31;if((cA&65535)<=(f&65535)){dy=dz;break}dy=(cA-f&65535)+dz&65535}else{f=b[(c[277225]|0)+(i<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)==0){dA=c[277228]&65535}else{dA=b[(c[277213]|0)+(h<<1)>>1]|0}cA=f&-2048;l=dA&-2048;bB=(cA&65535)>(l&65535)?cA-l&65535:0;l=f&2016;cA=dA&2016;if((l&65535)>(cA&65535)){dB=(l-cA&65535)+bB&65535}else{dB=bB}bB=f&31;f=dA&31;if((bB&65535)<=(f&65535)){dy=dB;break}dy=(bB-f&65535)+dB&65535}}while(0);b[(c[277218]|0)+(h<<1)>>1]=dy;do{if((a[1108928]|0)==0){f=b[(c[277213]|0)+(cE+16<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)!=0){dC=b[(c[277221]|0)+((f&65535|67616)-(b[(c[277226]|0)+(i<<1)>>1]&63454)>>1<<1)>>1]|0;break}bB=c[277228]&65535;cA=f&-2048;l=bB&-2048;bC=(cA&65535)>(l&65535)?cA-l&65535:0;l=f&2016;cA=bB&2016;if((l&65535)>(cA&65535)){dD=(l-cA&65535)+bC&65535}else{dD=bC}bC=f&31;f=bB&31;if((bC&65535)<=(f&65535)){dC=dD;break}dC=(bC-f&65535)+dD&65535}else{dC=0}}while(0);i=cE+15|0;b[(c[277218]|0)+(i<<1)>>1]=dC;f=a[1108909]|0;a[(c[277219]|0)+i|0]=f;a[(c[277219]|0)+h|0]=f}}while(0);h=cD-1|0;if((h|0)<=0){break}cC=cC-16|0;cD=h;cE=(c[277223]|0)+cE|0}return}}function WG(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0;i=c[263194]|0;c[277226]=1106168;c[277225]=(a[1108928]|0)!=0?1393712:1106168;j=c[277230]|0;if(j>>>0>(c[277231]|0)>>>0){return}k=f>>>0<g>>>0;l=g-1|0;m=ab(c[277223]|0,j)|0;n=j;o=1097960+(j<<4)|0;while(1){j=e[o+12>>1]<<19>>19;p=e[o+8>>1]<<19;q=e[o+10>>1]<<19;r=n+1|0;s=(e[o+14>>1]<<19>>19)-(q>>19)|0;t=(s&8192|0)!=0?s|-1024:s&1023;s=b[o+2>>1]|0;u=((a[1044414]|0)==0?r:r^255)&255;v=(ab(u,s)|0)&-64;w=v+(p>>11)+((ab(t,s)|0)&-64)|0;s=b[o+6>>1]|0;v=(ab(s,u)|0)&-64;u=v+(q>>11)+((ab(t,s)|0)&-64)|0;s=b[o>>1]|0;if((a[1044413]|0)==0){t=b[o+4>>1]|0;x=s;y=t<<16>>16;z=f;A=t}else{t=b[o+4>>1]|0;x=-s|0;y=-(t<<16>>16)|0;z=l;A=t}t=j-(p>>19)|0;p=(t&8192|0)!=0?t|-1024:t&1023;t=ab(z,s)|0;j=t+((ab(s,p)|0)&-64)|0;s=A<<16>>16;t=ab(s,z)|0;q=((ab(s,p)|0)&-64)+t|0;L16019:do{if((a[1044415]|0)==0){if(k){B=q;C=j;D=f}else{break}while(1){t=C+w|0;p=(B+u|0)>>>8;s=a[i+(t>>>8<<1&14|p<<4&112|d[(c[263194]|0)+(p<<5&32512|t>>>10&254)|0]<<7|1)|0]|0;t=((s&255)>>>4&8|3)+h|0;p=D+m|0;do{if((t|0)>(d[(c[277219]|0)+p|0]|0)){v=s&127;if(v<<24>>24==0){break}b[(c[277218]|0)+(p<<1)>>1]=b[(c[277225]|0)+((v&255)<<1)>>1]|0;a[(c[277219]|0)+p|0]=t&255}}while(0);t=D+1|0;if(t>>>0>=g>>>0){break L16019}B=B+y|0;C=C+x|0;D=t}}else{if(k){E=q;F=j;G=f}else{break}while(1){t=F+w|0;p=t>>8;s=E+u>>8;do{if((s|p)>>>0<1024){H=s<<4&112|p<<1&14|d[(c[263194]|0)+((s<<5&-256)+(t>>10&-2))|0]<<7;I=11513}else{if((a[1044415]|0)!=3){break}H=s<<4&112|p<<1&14;I=11513}}while(0);do{if((I|0)==11513){I=0;p=a[i+(H|1)|0]|0;s=((p&255)>>>4&8|3)+h|0;t=G+m|0;if((s|0)<=(d[(c[277219]|0)+t|0]|0)){break}v=p&127;if(v<<24>>24==0){break}b[(c[277218]|0)+(t<<1)>>1]=b[(c[277225]|0)+((v&255)<<1)>>1]|0;a[(c[277219]|0)+t|0]=s&255}}while(0);s=G+1|0;if(s>>>0<g>>>0){E=E+y|0;F=F+x|0;G=s}else{break}}}}while(0);if(r>>>0>(c[277231]|0)>>>0){break}m=(c[277223]|0)+m|0;n=r;o=o+16|0}return}function WH(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;i=c[263194]|0;c[277226]=1106168;c[277225]=(a[1108928]|0)!=0?1393712:1106168;j=c[277230]|0;if(j>>>0>(c[277231]|0)>>>0){return}k=f>>>0<g>>>0;l=g-1|0;m=ab(c[277223]|0,j)|0;n=j;o=1097960+(j<<4)|0;while(1){j=e[o+12>>1]<<19>>19;p=e[o+8>>1]<<19;q=e[o+10>>1]<<19;r=n+1|0;s=(e[o+14>>1]<<19>>19)-(q>>19)|0;t=(s&8192|0)!=0?s|-1024:s&1023;s=b[o+2>>1]|0;u=((a[1044414]|0)==0?r:r^255)&255;v=(ab(u,s)|0)&-64;w=v+(p>>11)+((ab(t,s)|0)&-64)|0;s=b[o+6>>1]|0;v=(ab(s,u)|0)&-64;u=v+(q>>11)+((ab(t,s)|0)&-64)|0;s=b[o>>1]|0;if((a[1044413]|0)==0){t=b[o+4>>1]|0;x=s;y=t<<16>>16;z=f;A=t}else{t=b[o+4>>1]|0;x=-s|0;y=-(t<<16>>16)|0;z=l;A=t}t=j-(p>>19)|0;p=(t&8192|0)!=0?t|-1024:t&1023;t=ab(z,s)|0;j=t+((ab(s,p)|0)&-64)|0;s=A<<16>>16;t=ab(s,z)|0;q=((ab(s,p)|0)&-64)+t|0;L16053:do{if((a[1044415]|0)==0){if(k){B=q;C=j;D=f}else{break}while(1){t=C+w|0;p=(B+u|0)>>>8;s=a[i+(t>>>8<<1&14|p<<4&112|d[(c[263194]|0)+(p<<5&32512|t>>>10&254)|0]<<7|1)|0]|0;t=((s&255)>>>4&8|3)+h|0;p=D+m|0;do{if((t|0)>(d[(c[277219]|0)+p|0]|0)){v=s&127;if(v<<24>>24==0){break}E=e[(c[277225]|0)+((v&255)<<1)>>1]|0;v=(a[(c[277215]|0)+p|0]&32)==0;if(v){F=c[277228]|0;G=F;H=F&-2082}else{F=e[(c[277213]|0)+(p<<1)>>1]|0;G=F;H=F&63454}if(v){I=c[277228]|0}else{I=e[(c[277213]|0)+(p<<1)>>1]|0}b[(c[277218]|0)+(p<<1)>>1]=((I^E)&2081|e[(c[277220]|0)+((E&2081&G)+((H+(E&63454)|0)>>>1)<<1)>>1])&65535;a[(c[277219]|0)+p|0]=t&255}}while(0);t=D+1|0;if(t>>>0>=g>>>0){break L16053}B=B+y|0;C=C+x|0;D=t}}else{if(k){J=q;K=j;L=f}else{break}while(1){t=K+w|0;p=t>>8;s=J+u>>8;do{if((s|p)>>>0<1024){M=s<<4&112|p<<1&14|d[(c[263194]|0)+((s<<5&-256)+(t>>10&-2))|0]<<7;N=11545}else{if((a[1044415]|0)!=3){break}M=s<<4&112|p<<1&14;N=11545}}while(0);do{if((N|0)==11545){N=0;p=a[i+(M|1)|0]|0;s=((p&255)>>>4&8|3)+h|0;t=L+m|0;if((s|0)<=(d[(c[277219]|0)+t|0]|0)){break}E=p&127;if(E<<24>>24==0){break}p=e[(c[277225]|0)+((E&255)<<1)>>1]|0;E=(a[(c[277215]|0)+t|0]&32)==0;if(E){v=c[277228]|0;O=v;P=v&-2082}else{v=e[(c[277213]|0)+(t<<1)>>1]|0;O=v;P=v&63454}if(E){Q=c[277228]|0}else{Q=e[(c[277213]|0)+(t<<1)>>1]|0}b[(c[277218]|0)+(t<<1)>>1]=((Q^p)&2081|e[(c[277220]|0)+((p&2081&O)+((P+(p&63454)|0)>>>1)<<1)>>1])&65535;a[(c[277219]|0)+t|0]=s&255}}while(0);s=L+1|0;if(s>>>0<g>>>0){J=J+y|0;K=K+x|0;L=s}else{break}}}}while(0);if(r>>>0>(c[277231]|0)>>>0){break}m=(c[277223]|0)+m|0;n=r;o=o+16|0}return}function WI(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;i=c[263194]|0;c[277226]=1106168;c[277225]=(a[1108928]|0)!=0?1393712:1106168;j=c[277230]|0;if(j>>>0>(c[277231]|0)>>>0){return}k=f>>>0<g>>>0;l=g-1|0;m=ab(c[277223]|0,j)|0;n=j;o=1097960+(j<<4)|0;while(1){j=e[o+12>>1]<<19>>19;p=e[o+8>>1]<<19;q=e[o+10>>1]<<19;r=n+1|0;s=(e[o+14>>1]<<19>>19)-(q>>19)|0;t=(s&8192|0)!=0?s|-1024:s&1023;s=b[o+2>>1]|0;u=((a[1044414]|0)==0?r:r^255)&255;v=(ab(u,s)|0)&-64;w=v+(p>>11)+((ab(t,s)|0)&-64)|0;s=b[o+6>>1]|0;v=(ab(s,u)|0)&-64;u=v+(q>>11)+((ab(t,s)|0)&-64)|0;s=b[o>>1]|0;if((a[1044413]|0)==0){t=b[o+4>>1]|0;x=s;y=t<<16>>16;z=f;A=t}else{t=b[o+4>>1]|0;x=-s|0;y=-(t<<16>>16)|0;z=l;A=t}t=j-(p>>19)|0;p=(t&8192|0)!=0?t|-1024:t&1023;t=ab(z,s)|0;j=t+((ab(s,p)|0)&-64)|0;s=A<<16>>16;t=ab(s,z)|0;q=((ab(s,p)|0)&-64)+t|0;L16103:do{if((a[1044415]|0)==0){if(k){B=q;C=j;D=f}else{break}while(1){t=C+w|0;p=(B+u|0)>>>8;s=a[i+(t>>>8<<1&14|p<<4&112|d[(c[263194]|0)+(p<<5&32512|t>>>10&254)|0]<<7|1)|0]|0;t=((s&255)>>>4&8|3)+h|0;p=D+m|0;do{if((t|0)>(d[(c[277219]|0)+p|0]|0)){v=s&127;if(v<<24>>24==0){break}E=e[(c[277225]|0)+((v&255)<<1)>>1]|0;v=c[277228]|0;F=(((E&63454)+(v&-2082)|0)>>>1)+(v&2081&E)|0;if((a[1108928]|0)==0){G=F&65535}else{G=(e[(c[277220]|0)+(F<<1)>>1]|(E^v)&2081)&65535}b[(c[277218]|0)+(p<<1)>>1]=G;a[(c[277219]|0)+p|0]=t&255}}while(0);t=D+1|0;if(t>>>0>=g>>>0){break L16103}B=B+y|0;C=C+x|0;D=t}}else{if(k){H=q;I=j;J=f}else{break}while(1){t=I+w|0;p=t>>8;s=H+u>>8;do{if((s|p)>>>0<1024){K=s<<4&112|p<<1&14|d[(c[263194]|0)+((s<<5&-256)+(t>>10&-2))|0]<<7;L=11579}else{if((a[1044415]|0)!=3){break}K=s<<4&112|p<<1&14;L=11579}}while(0);do{if((L|0)==11579){L=0;p=a[i+(K|1)|0]|0;s=((p&255)>>>4&8|3)+h|0;t=J+m|0;if((s|0)<=(d[(c[277219]|0)+t|0]|0)){break}v=p&127;if(v<<24>>24==0){break}p=e[(c[277225]|0)+((v&255)<<1)>>1]|0;v=c[277228]|0;E=(((p&63454)+(v&-2082)|0)>>>1)+(v&2081&p)|0;if((a[1108928]|0)==0){M=E&65535}else{M=(e[(c[277220]|0)+(E<<1)>>1]|(p^v)&2081)&65535}b[(c[277218]|0)+(t<<1)>>1]=M;a[(c[277219]|0)+t|0]=s&255}}while(0);s=J+1|0;if(s>>>0<g>>>0){H=H+y|0;I=I+x|0;J=s}else{break}}}}while(0);if(r>>>0>(c[277231]|0)>>>0){break}m=(c[277223]|0)+m|0;n=r;o=o+16|0}return}function WJ(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;i=c[263194]|0;c[277226]=1106168;c[277225]=(a[1108928]|0)!=0?1393712:1106168;j=c[277230]|0;if(j>>>0>(c[277231]|0)>>>0){return}k=f>>>0<g>>>0;l=g-1|0;m=ab(c[277223]|0,j)|0;n=j;o=1097960+(j<<4)|0;while(1){j=e[o+12>>1]<<19>>19;p=e[o+8>>1]<<19;q=e[o+10>>1]<<19;r=n+1|0;s=(e[o+14>>1]<<19>>19)-(q>>19)|0;t=(s&8192|0)!=0?s|-1024:s&1023;s=b[o+2>>1]|0;u=((a[1044414]|0)==0?r:r^255)&255;v=(ab(u,s)|0)&-64;w=v+(p>>11)+((ab(t,s)|0)&-64)|0;s=b[o+6>>1]|0;v=(ab(s,u)|0)&-64;u=v+(q>>11)+((ab(t,s)|0)&-64)|0;s=b[o>>1]|0;if((a[1044413]|0)==0){t=b[o+4>>1]|0;x=s;y=t<<16>>16;z=f;A=t}else{t=b[o+4>>1]|0;x=-s|0;y=-(t<<16>>16)|0;z=l;A=t}t=j-(p>>19)|0;p=(t&8192|0)!=0?t|-1024:t&1023;t=ab(z,s)|0;j=t+((ab(s,p)|0)&-64)|0;s=A<<16>>16;t=ab(s,z)|0;q=((ab(s,p)|0)&-64)+t|0;L16143:do{if((a[1044415]|0)==0){if(k){B=q;C=j;D=f}else{break}while(1){t=C+w|0;p=(B+u|0)>>>8;s=a[i+(t>>>8<<1&14|p<<4&112|d[(c[263194]|0)+(p<<5&32512|t>>>10&254)|0]<<7|1)|0]|0;t=((s&255)>>>4&8|3)+h|0;p=D+m|0;do{if((t|0)>(d[(c[277219]|0)+p|0]|0)){v=s&127;E=v&255;if(v<<24>>24==0){break}do{if((a[1108928]|0)==0){v=b[(c[277225]|0)+(E<<1)>>1]|0;F=v&65535;G=F&63454;if((a[(c[277215]|0)+p|0]&32)==0){H=c[277228]|0;I=(e[(c[277220]|0)+((((H&-2082)+G|0)>>>1)+(F&2081&H)<<1)>>1]|(H^F)&2081)&65535;break}else{F=b[(c[277213]|0)+(p<<1)>>1]|0;I=(((F&63454)+G|0)>>>1)+(F&v&2081)&65535;break}}else{v=e[(c[277225]|0)+(E<<1)>>1]|0;F=(a[(c[277215]|0)+p|0]&32)==0;if(F){G=c[277228]|0;J=G;K=G&-2082}else{G=e[(c[277213]|0)+(p<<1)>>1]|0;J=G;K=G&63454}if(F){L=c[277228]|0}else{L=e[(c[277213]|0)+(p<<1)>>1]|0}I=((L^v)&2081|e[(c[277220]|0)+((v&2081&J)+((K+(v&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=I;a[(c[277219]|0)+p|0]=t&255}}while(0);t=D+1|0;if(t>>>0>=g>>>0){break L16143}B=B+y|0;C=C+x|0;D=t}}else{if(k){M=q;N=j;O=f}else{break}while(1){t=N+w|0;p=t>>8;s=M+u>>8;do{if((s|p)>>>0<1024){P=s<<4&112|p<<1&14|d[(c[263194]|0)+((s<<5&-256)+(t>>10&-2))|0]<<7;Q=11618}else{if((a[1044415]|0)!=3){break}P=s<<4&112|p<<1&14;Q=11618}}while(0);do{if((Q|0)==11618){Q=0;p=a[i+(P|1)|0]|0;s=((p&255)>>>4&8|3)+h|0;t=O+m|0;if((s|0)<=(d[(c[277219]|0)+t|0]|0)){break}E=p&127;p=E&255;if(E<<24>>24==0){break}do{if((a[1108928]|0)==0){E=b[(c[277225]|0)+(p<<1)>>1]|0;v=E&65535;F=v&63454;if((a[(c[277215]|0)+t|0]&32)==0){G=c[277228]|0;R=(e[(c[277220]|0)+((((G&-2082)+F|0)>>>1)+(v&2081&G)<<1)>>1]|(G^v)&2081)&65535;break}else{v=b[(c[277213]|0)+(t<<1)>>1]|0;R=(((v&63454)+F|0)>>>1)+(v&E&2081)&65535;break}}else{E=e[(c[277225]|0)+(p<<1)>>1]|0;v=(a[(c[277215]|0)+t|0]&32)==0;if(v){F=c[277228]|0;S=F;T=F&-2082}else{F=e[(c[277213]|0)+(t<<1)>>1]|0;S=F;T=F&63454}if(v){U=c[277228]|0}else{U=e[(c[277213]|0)+(t<<1)>>1]|0}R=((U^E)&2081|e[(c[277220]|0)+((E&2081&S)+((T+(E&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(t<<1)>>1]=R;a[(c[277219]|0)+t|0]=s&255}}while(0);p=O+1|0;if(p>>>0<g>>>0){M=M+y|0;N=N+x|0;O=p}else{break}}}}while(0);if(r>>>0>(c[277231]|0)>>>0){break}m=(c[277223]|0)+m|0;n=r;o=o+16|0}return}function WK(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;i=c[263194]|0;c[277226]=1106168;c[277225]=(a[1108928]|0)!=0?1393712:1106168;j=c[277230]|0;if(j>>>0>(c[277231]|0)>>>0){return}k=f>>>0<g>>>0;l=g-1|0;m=ab(c[277223]|0,j)|0;n=j;o=1097960+(j<<4)|0;while(1){j=e[o+12>>1]<<19>>19;p=e[o+8>>1]<<19;q=e[o+10>>1]<<19;r=n+1|0;s=(e[o+14>>1]<<19>>19)-(q>>19)|0;t=(s&8192|0)!=0?s|-1024:s&1023;s=b[o+2>>1]|0;u=((a[1044414]|0)==0?r:r^255)&255;v=(ab(u,s)|0)&-64;w=v+(p>>11)+((ab(t,s)|0)&-64)|0;s=b[o+6>>1]|0;v=(ab(s,u)|0)&-64;u=v+(q>>11)+((ab(t,s)|0)&-64)|0;s=b[o>>1]|0;if((a[1044413]|0)==0){t=b[o+4>>1]|0;x=s;y=t<<16>>16;z=f;A=t}else{t=b[o+4>>1]|0;x=-s|0;y=-(t<<16>>16)|0;z=l;A=t}t=j-(p>>19)|0;p=(t&8192|0)!=0?t|-1024:t&1023;t=ab(z,s)|0;j=t+((ab(s,p)|0)&-64)|0;s=A<<16>>16;t=ab(s,z)|0;q=((ab(s,p)|0)&-64)+t|0;L16207:do{if((a[1044415]|0)==0){if(k){B=q;C=j;D=f}else{break}while(1){t=C+w|0;p=(B+u|0)>>>8;s=a[i+(t>>>8<<1&14|p<<4&112|d[(c[263194]|0)+(p<<5&32512|t>>>10&254)|0]<<7|1)|0]|0;t=((s&255)>>>4&8|3)+h|0;p=D+m|0;do{if((t|0)>(d[(c[277219]|0)+p|0]|0)){v=s&127;if(v<<24>>24==0){break}E=b[(c[277225]|0)+((v&255)<<1)>>1]|0;if((a[(c[277215]|0)+p|0]&32)==0){F=c[277228]&65535}else{F=b[(c[277213]|0)+(p<<1)>>1]|0}v=E&-2048;G=F&-2048;H=(v&65535)>(G&65535)?v-G&65535:0;G=E&2016;v=F&2016;if((G&65535)>(v&65535)){I=(G-v&65535)+H&65535}else{I=H}H=E&31;E=F&31;if((H&65535)>(E&65535)){J=(H-E&65535)+I&65535}else{J=I}b[(c[277218]|0)+(p<<1)>>1]=J;a[(c[277219]|0)+p|0]=t&255}}while(0);t=D+1|0;if(t>>>0>=g>>>0){break L16207}B=B+y|0;C=C+x|0;D=t}}else{if(k){K=q;L=j;M=f}else{break}while(1){t=L+w|0;p=t>>8;s=K+u>>8;do{if((s|p)>>>0<1024){N=s<<4&112|p<<1&14|d[(c[263194]|0)+((s<<5&-256)+(t>>10&-2))|0]<<7;O=11662}else{if((a[1044415]|0)!=3){break}N=s<<4&112|p<<1&14;O=11662}}while(0);do{if((O|0)==11662){O=0;p=a[i+(N|1)|0]|0;s=((p&255)>>>4&8|3)+h|0;t=M+m|0;if((s|0)<=(d[(c[277219]|0)+t|0]|0)){break}E=p&127;if(E<<24>>24==0){break}p=b[(c[277225]|0)+((E&255)<<1)>>1]|0;if((a[(c[277215]|0)+t|0]&32)==0){P=c[277228]&65535}else{P=b[(c[277213]|0)+(t<<1)>>1]|0}E=p&-2048;H=P&-2048;v=(E&65535)>(H&65535)?E-H&65535:0;H=p&2016;E=P&2016;if((H&65535)>(E&65535)){Q=(H-E&65535)+v&65535}else{Q=v}v=p&31;p=P&31;if((v&65535)>(p&65535)){R=(v-p&65535)+Q&65535}else{R=Q}b[(c[277218]|0)+(t<<1)>>1]=R;a[(c[277219]|0)+t|0]=s&255}}while(0);s=M+1|0;if(s>>>0<g>>>0){K=K+y|0;L=L+x|0;M=s}else{break}}}}while(0);if(r>>>0>(c[277231]|0)>>>0){break}m=(c[277223]|0)+m|0;n=r;o=o+16|0}return}function WL(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;i=c[263194]|0;c[277226]=1106168;c[277225]=(a[1108928]|0)!=0?1393712:1106168;j=c[277230]|0;if(j>>>0>(c[277231]|0)>>>0){return}k=f>>>0<g>>>0;l=g-1|0;m=ab(c[277223]|0,j)|0;n=j;o=1097960+(j<<4)|0;while(1){j=e[o+12>>1]<<19>>19;p=e[o+8>>1]<<19;q=e[o+10>>1]<<19;r=n+1|0;s=(e[o+14>>1]<<19>>19)-(q>>19)|0;t=(s&8192|0)!=0?s|-1024:s&1023;s=b[o+2>>1]|0;u=((a[1044414]|0)==0?r:r^255)&255;v=(ab(u,s)|0)&-64;w=v+(p>>11)+((ab(t,s)|0)&-64)|0;s=b[o+6>>1]|0;v=(ab(s,u)|0)&-64;u=v+(q>>11)+((ab(t,s)|0)&-64)|0;s=b[o>>1]|0;if((a[1044413]|0)==0){t=b[o+4>>1]|0;x=s;y=t<<16>>16;z=f;A=t}else{t=b[o+4>>1]|0;x=-s|0;y=-(t<<16>>16)|0;z=l;A=t}t=j-(p>>19)|0;p=(t&8192|0)!=0?t|-1024:t&1023;t=ab(z,s)|0;j=t+((ab(s,p)|0)&-64)|0;s=A<<16>>16;t=ab(s,z)|0;q=((ab(s,p)|0)&-64)+t|0;L16261:do{if((a[1044415]|0)==0){if(k){B=q;C=j;D=f}else{break}while(1){t=C+w|0;p=(B+u|0)>>>8;s=a[i+(t>>>8<<1&14|p<<4&112|d[(c[263194]|0)+(p<<5&32512|t>>>10&254)|0]<<7|1)|0]|0;t=((s&255)>>>4&8|3)+h|0;p=D+m|0;do{if((t|0)>(d[(c[277219]|0)+p|0]|0)){v=s&127;if(v<<24>>24==0){break}E=b[(c[277225]|0)+((v&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){F=b[(c[277221]|0)+(((E&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{v=c[277228]&65535;G=E&-2048;H=v&-2048;I=(G&65535)>(H&65535)?G-H&65535:0;H=E&2016;G=v&2016;if((H&65535)>(G&65535)){J=(H-G&65535)+I&65535}else{J=I}I=E&31;G=v&31;if((I&65535)<=(G&65535)){F=J;break}F=(I-G&65535)+J&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=F;a[(c[277219]|0)+p|0]=t&255}}while(0);t=D+1|0;if(t>>>0>=g>>>0){break L16261}B=B+y|0;C=C+x|0;D=t}}else{if(k){K=q;L=j;M=f}else{break}while(1){t=L+w|0;p=t>>8;s=K+u>>8;do{if((s|p)>>>0<1024){N=s<<4&112|p<<1&14|d[(c[263194]|0)+((s<<5&-256)+(t>>10&-2))|0]<<7;O=11701}else{if((a[1044415]|0)!=3){break}N=s<<4&112|p<<1&14;O=11701}}while(0);do{if((O|0)==11701){O=0;p=a[i+(N|1)|0]|0;s=((p&255)>>>4&8|3)+h|0;t=M+m|0;if((s|0)<=(d[(c[277219]|0)+t|0]|0)){break}E=p&127;if(E<<24>>24==0){break}p=b[(c[277225]|0)+((E&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){P=b[(c[277221]|0)+(((p&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{E=c[277228]&65535;G=p&-2048;I=E&-2048;v=(G&65535)>(I&65535)?G-I&65535:0;I=p&2016;G=E&2016;if((I&65535)>(G&65535)){Q=(I-G&65535)+v&65535}else{Q=v}v=p&31;G=E&31;if((v&65535)<=(G&65535)){P=Q;break}P=(v-G&65535)+Q&65535}}while(0);b[(c[277218]|0)+(t<<1)>>1]=P;a[(c[277219]|0)+t|0]=s&255}}while(0);p=M+1|0;if(p>>>0<g>>>0){K=K+y|0;L=L+x|0;M=p}else{break}}}}while(0);if(r>>>0>(c[277231]|0)>>>0){break}m=(c[277223]|0)+m|0;n=r;o=o+16|0}return}function WM(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;i=c[263194]|0;c[277226]=1106168;c[277225]=(a[1108928]|0)!=0?1393712:1106168;j=c[277230]|0;if(j>>>0>(c[277231]|0)>>>0){return}k=f>>>0<g>>>0;l=g-1|0;m=ab(c[277223]|0,j)|0;n=j;o=1097960+(j<<4)|0;while(1){j=e[o+12>>1]<<19>>19;p=e[o+8>>1]<<19;q=e[o+10>>1]<<19;r=n+1|0;s=(e[o+14>>1]<<19>>19)-(q>>19)|0;t=(s&8192|0)!=0?s|-1024:s&1023;s=b[o+2>>1]|0;u=((a[1044414]|0)==0?r:r^255)&255;v=(ab(u,s)|0)&-64;w=v+(p>>11)+((ab(t,s)|0)&-64)|0;s=b[o+6>>1]|0;v=(ab(s,u)|0)&-64;u=v+(q>>11)+((ab(t,s)|0)&-64)|0;s=b[o>>1]|0;if((a[1044413]|0)==0){t=b[o+4>>1]|0;x=s;y=t<<16>>16;z=f;A=t}else{t=b[o+4>>1]|0;x=-s|0;y=-(t<<16>>16)|0;z=l;A=t}t=j-(p>>19)|0;p=(t&8192|0)!=0?t|-1024:t&1023;t=ab(z,s)|0;j=t+((ab(s,p)|0)&-64)|0;s=A<<16>>16;t=ab(s,z)|0;q=((ab(s,p)|0)&-64)+t|0;L16311:do{if((a[1044415]|0)==0){if(k){B=q;C=j;D=f}else{break}while(1){t=C+w|0;p=(B+u|0)>>>8;s=a[i+(t>>>8<<1&14|p<<4&112|d[(c[263194]|0)+(p<<5&32512|t>>>10&254)|0]<<7|1)|0]|0;t=((s&255)>>>4&8|3)+h|0;p=D+m|0;do{if((t|0)>(d[(c[277219]|0)+p|0]|0)){v=s&127;E=v&255;if(v<<24>>24==0){break}do{if((a[1108928]|0)==0){v=b[(c[277225]|0)+(E<<1)>>1]|0;if((a[(c[277215]|0)+p|0]&32)!=0){F=b[(c[277221]|0)+((v&65535|67616)-(b[(c[277213]|0)+(p<<1)>>1]&63454)>>1<<1)>>1]|0;break}G=c[277228]&65535;H=v&-2048;I=G&-2048;J=(H&65535)>(I&65535)?H-I&65535:0;I=v&2016;H=G&2016;if((I&65535)>(H&65535)){K=(I-H&65535)+J&65535}else{K=J}J=v&31;v=G&31;if((J&65535)<=(v&65535)){F=K;break}F=(J-v&65535)+K&65535}else{v=b[(c[277225]|0)+(E<<1)>>1]|0;if((a[(c[277215]|0)+p|0]&32)==0){L=c[277228]&65535}else{L=b[(c[277213]|0)+(p<<1)>>1]|0}J=v&-2048;G=L&-2048;H=(J&65535)>(G&65535)?J-G&65535:0;G=v&2016;J=L&2016;if((G&65535)>(J&65535)){M=(G-J&65535)+H&65535}else{M=H}H=v&31;v=L&31;if((H&65535)<=(v&65535)){F=M;break}F=(H-v&65535)+M&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=F;a[(c[277219]|0)+p|0]=t&255}}while(0);t=D+1|0;if(t>>>0>=g>>>0){break L16311}B=B+y|0;C=C+x|0;D=t}}else{if(k){N=q;O=j;P=f}else{break}while(1){t=O+w|0;p=t>>8;s=N+u>>8;do{if((s|p)>>>0<1024){Q=s<<4&112|p<<1&14|d[(c[263194]|0)+((s<<5&-256)+(t>>10&-2))|0]<<7;R=11747}else{if((a[1044415]|0)!=3){break}Q=s<<4&112|p<<1&14;R=11747}}while(0);do{if((R|0)==11747){R=0;p=a[i+(Q|1)|0]|0;s=((p&255)>>>4&8|3)+h|0;t=P+m|0;if((s|0)<=(d[(c[277219]|0)+t|0]|0)){break}E=p&127;p=E&255;if(E<<24>>24==0){break}do{if((a[1108928]|0)==0){E=b[(c[277225]|0)+(p<<1)>>1]|0;if((a[(c[277215]|0)+t|0]&32)!=0){S=b[(c[277221]|0)+((E&65535|67616)-(b[(c[277213]|0)+(t<<1)>>1]&63454)>>1<<1)>>1]|0;break}v=c[277228]&65535;H=E&-2048;J=v&-2048;G=(H&65535)>(J&65535)?H-J&65535:0;J=E&2016;H=v&2016;if((J&65535)>(H&65535)){T=(J-H&65535)+G&65535}else{T=G}G=E&31;E=v&31;if((G&65535)<=(E&65535)){S=T;break}S=(G-E&65535)+T&65535}else{E=b[(c[277225]|0)+(p<<1)>>1]|0;if((a[(c[277215]|0)+t|0]&32)==0){U=c[277228]&65535}else{U=b[(c[277213]|0)+(t<<1)>>1]|0}G=E&-2048;v=U&-2048;H=(G&65535)>(v&65535)?G-v&65535:0;v=E&2016;G=U&2016;if((v&65535)>(G&65535)){V=(v-G&65535)+H&65535}else{V=H}H=E&31;E=U&31;if((H&65535)<=(E&65535)){S=V;break}S=(H-E&65535)+V&65535}}while(0);b[(c[277218]|0)+(t<<1)>>1]=S;a[(c[277219]|0)+t|0]=s&255}}while(0);p=P+1|0;if(p>>>0<g>>>0){N=N+y|0;O=O+x|0;P=p}else{break}}}}while(0);if(r>>>0>(c[277231]|0)>>>0){break}m=(c[277223]|0)+m|0;n=r;o=o+16|0}return}function WN(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;i=c[263194]|0;c[277226]=1106168;c[277225]=(a[1108928]|0)!=0?1393712:1106168;j=c[277230]|0;if((a[1044434]|0)==0){k=j;l=1;m=0}else{n=d[1044432]|0;o=((j-(d[1044433]|0)|0)>>>0)%(n>>>0)|0;k=j-o|0;l=n;m=o}if((a[1044435]|0)==0){p=f;q=g;r=1}else{o=d[1044432]|0;n=g-1+o|0;p=f-((f|0)%(o|0)|0)|0;q=n-((n|0)%(o|0)|0)|0;r=o}o=c[277231]|0;if(k>>>0>o>>>0){return}n=(p|0)<(q|0);j=r&255;s=q-1|0;t=r-1|0;r=m;m=l;l=ab(c[277223]|0,k)|0;u=k;v=1097960+(k<<4)|0;k=o;while(1){if((m+u|0)>>>0>k>>>0){w=k+1-u|0}else{w=m}o=e[v+12>>1]<<19>>19;x=e[v+8>>1]<<19;y=e[v+10>>1]<<19;z=u+1|0;A=(e[v+14>>1]<<19>>19)-(y>>19)|0;B=(A&8192|0)!=0?A|-1024:A&1023;A=b[v+2>>1]|0;C=((a[1044414]|0)==0?z:z^255)&255;z=(ab(C,A)|0)&-64;D=z+(x>>11)+((ab(B,A)|0)&-64)|0;A=b[v+6>>1]|0;z=(ab(A,C)|0)&-64;C=z+(y>>11)+((ab(B,A)|0)&-64)|0;A=b[v>>1]|0;if((a[1044413]|0)==0){B=b[v+4>>1]|0;E=A;F=B<<16>>16;G=p;H=B}else{B=b[v+4>>1]|0;E=-A|0;F=-(B<<16>>16)|0;G=s;H=B}B=o-(x>>19)|0;x=(B&8192|0)!=0?B|-1024:B&1023;B=ab(G,A)|0;o=B+((ab(A,x)|0)&-64)|0;A=H<<16>>16;B=ab(A,G)|0;y=((ab(A,x)|0)&-64)+B|0;do{if((a[1044415]|0)==0){if(!n){break}B=(r|0)>=(w|0);x=o;A=y;z=1;I=p;while(1){J=z-1&255;do{if(J<<24>>24==0){K=x+D|0;L=(A+C|0)>>>8;M=a[i+(L<<4&112|K>>>8<<1&14|d[(c[263194]|0)+(L<<5&32512|K>>>10&254)|0]<<7|1)|0]|0;K=M&127;if(K<<24>>24==0|B){N=j;break}L=t+I|0;O=(L|0)<(I|0);P=(M<<24>>24<0?11:3)+h|0;M=K&255;K=P&255;Q=r;while(1){if(!O){R=L;do{S=R+l|0;T=(ab(c[277223]|0,Q)|0)+S|0;if((R|0)>=(f|0)&(P|0)>(d[(c[277219]|0)+T|0]|0)&(R|0)<(g|0)){b[(c[277218]|0)+(T<<1)>>1]=b[(c[277225]|0)+(M<<1)>>1]|0;T=(ab(c[277223]|0,Q)|0)+S|0;a[(c[277219]|0)+T|0]=K}R=R-1|0;}while((R|0)>=(I|0))}R=Q+1|0;if((R|0)<(w|0)){Q=R}else{N=j;break}}}else{N=J}}while(0);J=I+1|0;if((J|0)<(q|0)){x=x+E|0;A=A+F|0;z=N;I=J}else{break}}}else{if(!n){break}I=(r|0)>=(w|0);z=o;A=y;x=1;B=p;while(1){J=x-1&255;do{if(J<<24>>24==0){Q=z+D|0;K=Q>>8;M=A+C>>8;if((K|M)>>>0<1024){U=K<<1&14|M<<4&112|d[(c[263194]|0)+((M<<5&-256)+(Q>>10&-2))|0]<<7}else{if((a[1044415]|0)!=3){V=j;break}U=K<<1&14|M<<4&112}M=a[i+(U|1)|0]|0;K=M&127;if(K<<24>>24==0|I){V=j;break}Q=t+B|0;P=(Q|0)<(B|0);L=(M<<24>>24<0?11:3)+h|0;M=K&255;K=L&255;O=r;while(1){if(!P){R=Q;do{T=R+l|0;S=(ab(c[277223]|0,O)|0)+T|0;if((R|0)>=(f|0)&(L|0)>(d[(c[277219]|0)+S|0]|0)&(R|0)<(g|0)){b[(c[277218]|0)+(S<<1)>>1]=b[(c[277225]|0)+(M<<1)>>1]|0;S=(ab(c[277223]|0,O)|0)+T|0;a[(c[277219]|0)+S|0]=K}R=R-1|0;}while((R|0)>=(B|0))}R=O+1|0;if((R|0)<(w|0)){O=R}else{V=j;break}}}else{V=J}}while(0);J=B+1|0;if((J|0)<(q|0)){z=z+E|0;A=A+F|0;x=V;B=J}else{break}}}}while(0);C=w+u|0;D=(ab(c[277223]|0,w)|0)+l|0;y=c[277231]|0;if(C>>>0>y>>>0){break}else{r=0;m=w;l=D;u=C;v=v+(w<<4)|0;k=y}}return}function WO(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ac=0,ad=0;i=c[263194]|0;c[277226]=1106168;c[277225]=(a[1108928]|0)!=0?1393712:1106168;j=c[277230]|0;if((a[1044434]|0)==0){k=j;l=1;m=0}else{n=d[1044432]|0;o=((j-(d[1044433]|0)|0)>>>0)%(n>>>0)|0;k=j-o|0;l=n;m=o}if((a[1044435]|0)==0){p=f;q=g;r=1}else{o=d[1044432]|0;n=g-1+o|0;p=f-((f|0)%(o|0)|0)|0;q=n-((n|0)%(o|0)|0)|0;r=o}o=c[277231]|0;if(k>>>0>o>>>0){return}n=(p|0)<(q|0);j=r&255;s=q-1|0;t=r-1|0;r=m;m=l;l=ab(c[277223]|0,k)|0;u=k;v=1097960+(k<<4)|0;k=o;while(1){if((m+u|0)>>>0>k>>>0){w=k+1-u|0}else{w=m}o=e[v+12>>1]<<19>>19;x=e[v+8>>1]<<19;y=e[v+10>>1]<<19;z=u+1|0;A=(e[v+14>>1]<<19>>19)-(y>>19)|0;B=(A&8192|0)!=0?A|-1024:A&1023;A=b[v+2>>1]|0;C=((a[1044414]|0)==0?z:z^255)&255;z=(ab(C,A)|0)&-64;D=z+(x>>11)+((ab(B,A)|0)&-64)|0;A=b[v+6>>1]|0;z=(ab(A,C)|0)&-64;C=z+(y>>11)+((ab(B,A)|0)&-64)|0;A=b[v>>1]|0;if((a[1044413]|0)==0){B=b[v+4>>1]|0;E=A;F=B<<16>>16;G=p;H=B}else{B=b[v+4>>1]|0;E=-A|0;F=-(B<<16>>16)|0;G=s;H=B}B=o-(x>>19)|0;x=(B&8192|0)!=0?B|-1024:B&1023;B=ab(G,A)|0;o=B+((ab(A,x)|0)&-64)|0;A=H<<16>>16;B=ab(A,G)|0;y=((ab(A,x)|0)&-64)+B|0;do{if((a[1044415]|0)==0){if(!n){break}B=(r|0)>=(w|0);x=o;A=y;z=1;I=p;while(1){J=z-1&255;do{if(J<<24>>24==0){K=x+D|0;L=(A+C|0)>>>8;M=a[i+(L<<4&112|K>>>8<<1&14|d[(c[263194]|0)+(L<<5&32512|K>>>10&254)|0]<<7|1)|0]|0;K=M&127;if(K<<24>>24==0|B){N=j;break}L=t+I|0;O=(L|0)<(I|0);P=(M<<24>>24<0?11:3)+h|0;M=K&255;K=P&255;Q=r;while(1){if(!O){R=L;do{S=R+l|0;T=(ab(c[277223]|0,Q)|0)+S|0;if((R|0)>=(f|0)&(P|0)>(d[(c[277219]|0)+T|0]|0)&(R|0)<(g|0)){U=e[(c[277225]|0)+(M<<1)>>1]|0;V=(a[(c[277215]|0)+T|0]&32)==0;if(V){W=c[277228]|0;X=W;Y=W&-2082}else{W=e[(c[277213]|0)+(T<<1)>>1]|0;X=W;Y=W&63454}if(V){Z=c[277228]|0}else{Z=e[(c[277213]|0)+(T<<1)>>1]|0}b[(c[277218]|0)+(T<<1)>>1]=((Z^U)&2081|e[(c[277220]|0)+((U&2081&X)+((Y+(U&63454)|0)>>>1)<<1)>>1])&65535;U=(ab(c[277223]|0,Q)|0)+S|0;a[(c[277219]|0)+U|0]=K}R=R-1|0;}while((R|0)>=(I|0))}R=Q+1|0;if((R|0)<(w|0)){Q=R}else{N=j;break}}}else{N=J}}while(0);J=I+1|0;if((J|0)<(q|0)){x=x+E|0;A=A+F|0;z=N;I=J}else{break}}}else{if(!n){break}I=(r|0)>=(w|0);z=o;A=y;x=1;B=p;while(1){J=x-1&255;do{if(J<<24>>24==0){Q=z+D|0;K=Q>>8;M=A+C>>8;if((K|M)>>>0<1024){_=K<<1&14|M<<4&112|d[(c[263194]|0)+((M<<5&-256)+(Q>>10&-2))|0]<<7}else{if((a[1044415]|0)!=3){$=j;break}_=K<<1&14|M<<4&112}M=a[i+(_|1)|0]|0;K=M&127;if(K<<24>>24==0|I){$=j;break}Q=t+B|0;P=(Q|0)<(B|0);L=(M<<24>>24<0?11:3)+h|0;M=K&255;K=L&255;O=r;while(1){if(!P){R=Q;do{U=R+l|0;S=(ab(c[277223]|0,O)|0)+U|0;if((R|0)>=(f|0)&(L|0)>(d[(c[277219]|0)+S|0]|0)&(R|0)<(g|0)){T=e[(c[277225]|0)+(M<<1)>>1]|0;V=(a[(c[277215]|0)+S|0]&32)==0;if(V){W=c[277228]|0;aa=W;ac=W&-2082}else{W=e[(c[277213]|0)+(S<<1)>>1]|0;aa=W;ac=W&63454}if(V){ad=c[277228]|0}else{ad=e[(c[277213]|0)+(S<<1)>>1]|0}b[(c[277218]|0)+(S<<1)>>1]=((ad^T)&2081|e[(c[277220]|0)+((T&2081&aa)+((ac+(T&63454)|0)>>>1)<<1)>>1])&65535;T=(ab(c[277223]|0,O)|0)+U|0;a[(c[277219]|0)+T|0]=K}R=R-1|0;}while((R|0)>=(B|0))}R=O+1|0;if((R|0)<(w|0)){O=R}else{$=j;break}}}else{$=J}}while(0);J=B+1|0;if((J|0)<(q|0)){z=z+E|0;A=A+F|0;x=$;B=J}else{break}}}}while(0);C=w+u|0;D=(ab(c[277223]|0,w)|0)+l|0;y=c[277231]|0;if(C>>>0>y>>>0){break}else{r=0;m=w;l=D;u=C;v=v+(w<<4)|0;k=y}}return}function WP(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;i=c[263194]|0;c[277226]=1106168;c[277225]=(a[1108928]|0)!=0?1393712:1106168;j=c[277230]|0;if((a[1044434]|0)==0){k=j;l=1;m=0}else{n=d[1044432]|0;o=((j-(d[1044433]|0)|0)>>>0)%(n>>>0)|0;k=j-o|0;l=n;m=o}if((a[1044435]|0)==0){p=f;q=g;r=1}else{o=d[1044432]|0;n=g-1+o|0;p=f-((f|0)%(o|0)|0)|0;q=n-((n|0)%(o|0)|0)|0;r=o}o=c[277231]|0;if(k>>>0>o>>>0){return}n=(p|0)<(q|0);j=r&255;s=q-1|0;t=r-1|0;r=m;m=l;l=ab(c[277223]|0,k)|0;u=k;v=1097960+(k<<4)|0;k=o;while(1){if((m+u|0)>>>0>k>>>0){w=k+1-u|0}else{w=m}o=e[v+12>>1]<<19>>19;x=e[v+8>>1]<<19;y=e[v+10>>1]<<19;z=u+1|0;A=(e[v+14>>1]<<19>>19)-(y>>19)|0;B=(A&8192|0)!=0?A|-1024:A&1023;A=b[v+2>>1]|0;C=((a[1044414]|0)==0?z:z^255)&255;z=(ab(C,A)|0)&-64;D=z+(x>>11)+((ab(B,A)|0)&-64)|0;A=b[v+6>>1]|0;z=(ab(A,C)|0)&-64;C=z+(y>>11)+((ab(B,A)|0)&-64)|0;A=b[v>>1]|0;if((a[1044413]|0)==0){B=b[v+4>>1]|0;E=A;F=B<<16>>16;G=p;H=B}else{B=b[v+4>>1]|0;E=-A|0;F=-(B<<16>>16)|0;G=s;H=B}B=o-(x>>19)|0;x=(B&8192|0)!=0?B|-1024:B&1023;B=ab(G,A)|0;o=B+((ab(A,x)|0)&-64)|0;A=H<<16>>16;B=ab(A,G)|0;y=((ab(A,x)|0)&-64)+B|0;do{if((a[1044415]|0)==0){if(!n){break}B=(r|0)>=(w|0);x=o;A=y;z=1;I=p;while(1){J=z-1&255;do{if(J<<24>>24==0){K=x+D|0;L=(A+C|0)>>>8;M=a[i+(L<<4&112|K>>>8<<1&14|d[(c[263194]|0)+(L<<5&32512|K>>>10&254)|0]<<7|1)|0]|0;K=M&127;if(K<<24>>24==0|B){N=j;break}L=t+I|0;O=(L|0)<(I|0);P=(M<<24>>24<0?11:3)+h|0;M=K&255;K=P&255;Q=r;while(1){if(!O){R=L;do{S=R+l|0;T=(ab(c[277223]|0,Q)|0)+S|0;if((R|0)>=(f|0)&(P|0)>(d[(c[277219]|0)+T|0]|0)&(R|0)<(g|0)){U=e[(c[277225]|0)+(M<<1)>>1]|0;V=c[277228]|0;W=(((U&63454)+(V&-2082)|0)>>>1)+(V&2081&U)|0;if((a[1108928]|0)==0){X=W&65535}else{X=(e[(c[277220]|0)+(W<<1)>>1]|(U^V)&2081)&65535}b[(c[277218]|0)+(T<<1)>>1]=X;T=(ab(c[277223]|0,Q)|0)+S|0;a[(c[277219]|0)+T|0]=K}R=R-1|0;}while((R|0)>=(I|0))}R=Q+1|0;if((R|0)<(w|0)){Q=R}else{N=j;break}}}else{N=J}}while(0);J=I+1|0;if((J|0)<(q|0)){x=x+E|0;A=A+F|0;z=N;I=J}else{break}}}else{if(!n){break}I=(r|0)>=(w|0);z=o;A=y;x=1;B=p;while(1){J=x-1&255;do{if(J<<24>>24==0){Q=z+D|0;K=Q>>8;M=A+C>>8;if((K|M)>>>0<1024){Y=K<<1&14|M<<4&112|d[(c[263194]|0)+((M<<5&-256)+(Q>>10&-2))|0]<<7}else{if((a[1044415]|0)!=3){Z=j;break}Y=K<<1&14|M<<4&112}M=a[i+(Y|1)|0]|0;K=M&127;if(K<<24>>24==0|I){Z=j;break}Q=t+B|0;P=(Q|0)<(B|0);L=(M<<24>>24<0?11:3)+h|0;M=K&255;K=L&255;O=r;while(1){if(!P){R=Q;do{T=R+l|0;S=(ab(c[277223]|0,O)|0)+T|0;if((R|0)>=(f|0)&(L|0)>(d[(c[277219]|0)+S|0]|0)&(R|0)<(g|0)){V=e[(c[277225]|0)+(M<<1)>>1]|0;U=c[277228]|0;W=(((V&63454)+(U&-2082)|0)>>>1)+(U&2081&V)|0;if((a[1108928]|0)==0){_=W&65535}else{_=(e[(c[277220]|0)+(W<<1)>>1]|(V^U)&2081)&65535}b[(c[277218]|0)+(S<<1)>>1]=_;S=(ab(c[277223]|0,O)|0)+T|0;a[(c[277219]|0)+S|0]=K}R=R-1|0;}while((R|0)>=(B|0))}R=O+1|0;if((R|0)<(w|0)){O=R}else{Z=j;break}}}else{Z=J}}while(0);J=B+1|0;if((J|0)<(q|0)){z=z+E|0;A=A+F|0;x=Z;B=J}else{break}}}}while(0);C=w+u|0;D=(ab(c[277223]|0,w)|0)+l|0;y=c[277231]|0;if(C>>>0>y>>>0){break}else{r=0;m=w;l=D;u=C;v=v+(w<<4)|0;k=y}}return}function WQ(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0;i=c[263194]|0;c[277226]=1106168;c[277225]=(a[1108928]|0)!=0?1393712:1106168;j=c[277230]|0;if((a[1044434]|0)==0){k=j;l=1;m=0}else{n=d[1044432]|0;o=((j-(d[1044433]|0)|0)>>>0)%(n>>>0)|0;k=j-o|0;l=n;m=o}if((a[1044435]|0)==0){p=f;q=g;r=1}else{o=d[1044432]|0;n=g-1+o|0;p=f-((f|0)%(o|0)|0)|0;q=n-((n|0)%(o|0)|0)|0;r=o}o=c[277231]|0;if(k>>>0>o>>>0){return}n=(p|0)<(q|0);j=r&255;s=q-1|0;t=r-1|0;r=m;m=l;l=ab(c[277223]|0,k)|0;u=k;v=1097960+(k<<4)|0;k=o;while(1){if((m+u|0)>>>0>k>>>0){w=k+1-u|0}else{w=m}o=e[v+12>>1]<<19>>19;x=e[v+8>>1]<<19;y=e[v+10>>1]<<19;z=u+1|0;A=(e[v+14>>1]<<19>>19)-(y>>19)|0;B=(A&8192|0)!=0?A|-1024:A&1023;A=b[v+2>>1]|0;C=((a[1044414]|0)==0?z:z^255)&255;z=(ab(C,A)|0)&-64;D=z+(x>>11)+((ab(B,A)|0)&-64)|0;A=b[v+6>>1]|0;z=(ab(A,C)|0)&-64;C=z+(y>>11)+((ab(B,A)|0)&-64)|0;A=b[v>>1]|0;if((a[1044413]|0)==0){B=b[v+4>>1]|0;E=A;F=B<<16>>16;G=p;H=B}else{B=b[v+4>>1]|0;E=-A|0;F=-(B<<16>>16)|0;G=s;H=B}B=o-(x>>19)|0;x=(B&8192|0)!=0?B|-1024:B&1023;B=ab(G,A)|0;o=B+((ab(A,x)|0)&-64)|0;A=H<<16>>16;B=ab(A,G)|0;y=((ab(A,x)|0)&-64)+B|0;do{if((a[1044415]|0)==0){if(!n){break}B=(r|0)>=(w|0);x=o;A=y;z=1;I=p;while(1){J=z-1&255;do{if(J<<24>>24==0){K=x+D|0;L=(A+C|0)>>>8;M=a[i+(L<<4&112|K>>>8<<1&14|d[(c[263194]|0)+(L<<5&32512|K>>>10&254)|0]<<7|1)|0]|0;K=M&127;if(K<<24>>24==0|B){N=j;break}L=t+I|0;O=(L|0)<(I|0);P=(M<<24>>24<0?11:3)+h|0;M=K&255;K=P&255;Q=r;while(1){if(!O){R=L;do{S=R+l|0;T=(ab(c[277223]|0,Q)|0)+S|0;if((R|0)>=(f|0)&(P|0)>(d[(c[277219]|0)+T|0]|0)&(R|0)<(g|0)){do{if((a[1108928]|0)==0){U=b[(c[277225]|0)+(M<<1)>>1]|0;V=U&65535;W=V&63454;if((a[(c[277215]|0)+T|0]&32)==0){X=c[277228]|0;Y=(e[(c[277220]|0)+((((X&-2082)+W|0)>>>1)+(V&2081&X)<<1)>>1]|(X^V)&2081)&65535;break}else{V=b[(c[277213]|0)+(T<<1)>>1]|0;Y=(((V&63454)+W|0)>>>1)+(V&U&2081)&65535;break}}else{U=e[(c[277225]|0)+(M<<1)>>1]|0;V=(a[(c[277215]|0)+T|0]&32)==0;if(V){W=c[277228]|0;Z=W;_=W&-2082}else{W=e[(c[277213]|0)+(T<<1)>>1]|0;Z=W;_=W&63454}if(V){$=c[277228]|0}else{$=e[(c[277213]|0)+(T<<1)>>1]|0}Y=(($^U)&2081|e[(c[277220]|0)+((U&2081&Z)+((_+(U&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(T<<1)>>1]=Y;U=(ab(c[277223]|0,Q)|0)+S|0;a[(c[277219]|0)+U|0]=K}R=R-1|0;}while((R|0)>=(I|0))}R=Q+1|0;if((R|0)<(w|0)){Q=R}else{N=j;break}}}else{N=J}}while(0);J=I+1|0;if((J|0)<(q|0)){x=x+E|0;A=A+F|0;z=N;I=J}else{break}}}else{if(!n){break}I=(r|0)>=(w|0);z=o;A=y;x=1;B=p;while(1){J=x-1&255;do{if(J<<24>>24==0){Q=z+D|0;K=Q>>8;M=A+C>>8;if((K|M)>>>0<1024){aa=K<<1&14|M<<4&112|d[(c[263194]|0)+((M<<5&-256)+(Q>>10&-2))|0]<<7}else{if((a[1044415]|0)!=3){ac=j;break}aa=K<<1&14|M<<4&112}M=a[i+(aa|1)|0]|0;K=M&127;if(K<<24>>24==0|I){ac=j;break}Q=t+B|0;P=(Q|0)<(B|0);L=(M<<24>>24<0?11:3)+h|0;M=K&255;K=L&255;O=r;while(1){if(!P){R=Q;do{U=R+l|0;V=(ab(c[277223]|0,O)|0)+U|0;if((R|0)>=(f|0)&(L|0)>(d[(c[277219]|0)+V|0]|0)&(R|0)<(g|0)){do{if((a[1108928]|0)==0){W=b[(c[277225]|0)+(M<<1)>>1]|0;X=W&65535;ad=X&63454;if((a[(c[277215]|0)+V|0]&32)==0){ae=c[277228]|0;af=(e[(c[277220]|0)+((((ae&-2082)+ad|0)>>>1)+(X&2081&ae)<<1)>>1]|(ae^X)&2081)&65535;break}else{X=b[(c[277213]|0)+(V<<1)>>1]|0;af=(((X&63454)+ad|0)>>>1)+(X&W&2081)&65535;break}}else{W=e[(c[277225]|0)+(M<<1)>>1]|0;X=(a[(c[277215]|0)+V|0]&32)==0;if(X){ad=c[277228]|0;ag=ad;ah=ad&-2082}else{ad=e[(c[277213]|0)+(V<<1)>>1]|0;ag=ad;ah=ad&63454}if(X){ai=c[277228]|0}else{ai=e[(c[277213]|0)+(V<<1)>>1]|0}af=((ai^W)&2081|e[(c[277220]|0)+((W&2081&ag)+((ah+(W&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(V<<1)>>1]=af;S=(ab(c[277223]|0,O)|0)+U|0;a[(c[277219]|0)+S|0]=K}R=R-1|0;}while((R|0)>=(B|0))}R=O+1|0;if((R|0)<(w|0)){O=R}else{ac=j;break}}}else{ac=J}}while(0);J=B+1|0;if((J|0)<(q|0)){z=z+E|0;A=A+F|0;x=ac;B=J}else{break}}}}while(0);C=w+u|0;D=(ab(c[277223]|0,w)|0)+l|0;y=c[277231]|0;if(C>>>0>y>>>0){break}else{r=0;m=w;l=D;u=C;v=v+(w<<4)|0;k=y}}return}function WR(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ac=0,ad=0,ae=0;i=c[263194]|0;c[277226]=1106168;c[277225]=(a[1108928]|0)!=0?1393712:1106168;j=c[277230]|0;if((a[1044434]|0)==0){k=j;l=1;m=0}else{n=d[1044432]|0;o=((j-(d[1044433]|0)|0)>>>0)%(n>>>0)|0;k=j-o|0;l=n;m=o}if((a[1044435]|0)==0){p=f;q=g;r=1}else{o=d[1044432]|0;n=g-1+o|0;p=f-((f|0)%(o|0)|0)|0;q=n-((n|0)%(o|0)|0)|0;r=o}o=c[277231]|0;if(k>>>0>o>>>0){return}n=(p|0)<(q|0);j=r&255;s=q-1|0;t=r-1|0;r=m;m=l;l=ab(c[277223]|0,k)|0;u=k;v=1097960+(k<<4)|0;k=o;while(1){if((m+u|0)>>>0>k>>>0){w=k+1-u|0}else{w=m}o=e[v+12>>1]<<19>>19;x=e[v+8>>1]<<19;y=e[v+10>>1]<<19;z=u+1|0;A=(e[v+14>>1]<<19>>19)-(y>>19)|0;B=(A&8192|0)!=0?A|-1024:A&1023;A=b[v+2>>1]|0;C=((a[1044414]|0)==0?z:z^255)&255;z=(ab(C,A)|0)&-64;D=z+(x>>11)+((ab(B,A)|0)&-64)|0;A=b[v+6>>1]|0;z=(ab(A,C)|0)&-64;C=z+(y>>11)+((ab(B,A)|0)&-64)|0;A=b[v>>1]|0;if((a[1044413]|0)==0){B=b[v+4>>1]|0;E=A;F=B<<16>>16;G=p;H=B}else{B=b[v+4>>1]|0;E=-A|0;F=-(B<<16>>16)|0;G=s;H=B}B=o-(x>>19)|0;x=(B&8192|0)!=0?B|-1024:B&1023;B=ab(G,A)|0;o=B+((ab(A,x)|0)&-64)|0;A=H<<16>>16;B=ab(A,G)|0;y=((ab(A,x)|0)&-64)+B|0;do{if((a[1044415]|0)==0){if(!n){break}B=(r|0)>=(w|0);x=o;A=y;z=1;I=p;while(1){J=z-1&255;do{if(J<<24>>24==0){K=x+D|0;L=(A+C|0)>>>8;M=a[i+(L<<4&112|K>>>8<<1&14|d[(c[263194]|0)+(L<<5&32512|K>>>10&254)|0]<<7|1)|0]|0;K=M&127;if(K<<24>>24==0|B){N=j;break}L=t+I|0;O=(L|0)<(I|0);P=(M<<24>>24<0?11:3)+h|0;M=K&255;K=P&255;Q=r;while(1){if(!O){R=L;do{S=R+l|0;T=(ab(c[277223]|0,Q)|0)+S|0;if((R|0)>=(f|0)&(P|0)>(d[(c[277219]|0)+T|0]|0)&(R|0)<(g|0)){U=b[(c[277225]|0)+(M<<1)>>1]|0;if((a[(c[277215]|0)+T|0]&32)==0){V=c[277228]&65535}else{V=b[(c[277213]|0)+(T<<1)>>1]|0}W=U&-2048;X=V&-2048;Y=(W&65535)>(X&65535)?W-X&65535:0;X=U&2016;W=V&2016;if((X&65535)>(W&65535)){Z=(X-W&65535)+Y&65535}else{Z=Y}Y=U&31;U=V&31;if((Y&65535)>(U&65535)){_=(Y-U&65535)+Z&65535}else{_=Z}b[(c[277218]|0)+(T<<1)>>1]=_;T=(ab(c[277223]|0,Q)|0)+S|0;a[(c[277219]|0)+T|0]=K}R=R-1|0;}while((R|0)>=(I|0))}R=Q+1|0;if((R|0)<(w|0)){Q=R}else{N=j;break}}}else{N=J}}while(0);J=I+1|0;if((J|0)<(q|0)){x=x+E|0;A=A+F|0;z=N;I=J}else{break}}}else{if(!n){break}I=(r|0)>=(w|0);z=o;A=y;x=1;B=p;while(1){J=x-1&255;do{if(J<<24>>24==0){Q=z+D|0;K=Q>>8;M=A+C>>8;if((K|M)>>>0<1024){$=K<<1&14|M<<4&112|d[(c[263194]|0)+((M<<5&-256)+(Q>>10&-2))|0]<<7}else{if((a[1044415]|0)!=3){aa=j;break}$=K<<1&14|M<<4&112}M=a[i+($|1)|0]|0;K=M&127;if(K<<24>>24==0|I){aa=j;break}Q=t+B|0;P=(Q|0)<(B|0);L=(M<<24>>24<0?11:3)+h|0;M=K&255;K=L&255;O=r;while(1){if(!P){R=Q;do{T=R+l|0;S=(ab(c[277223]|0,O)|0)+T|0;if((R|0)>=(f|0)&(L|0)>(d[(c[277219]|0)+S|0]|0)&(R|0)<(g|0)){U=b[(c[277225]|0)+(M<<1)>>1]|0;if((a[(c[277215]|0)+S|0]&32)==0){ac=c[277228]&65535}else{ac=b[(c[277213]|0)+(S<<1)>>1]|0}Y=U&-2048;W=ac&-2048;X=(Y&65535)>(W&65535)?Y-W&65535:0;W=U&2016;Y=ac&2016;if((W&65535)>(Y&65535)){ad=(W-Y&65535)+X&65535}else{ad=X}X=U&31;U=ac&31;if((X&65535)>(U&65535)){ae=(X-U&65535)+ad&65535}else{ae=ad}b[(c[277218]|0)+(S<<1)>>1]=ae;S=(ab(c[277223]|0,O)|0)+T|0;a[(c[277219]|0)+S|0]=K}R=R-1|0;}while((R|0)>=(B|0))}R=O+1|0;if((R|0)<(w|0)){O=R}else{aa=j;break}}}else{aa=J}}while(0);J=B+1|0;if((J|0)<(q|0)){z=z+E|0;A=A+F|0;x=aa;B=J}else{break}}}}while(0);C=w+u|0;D=(ab(c[277223]|0,w)|0)+l|0;y=c[277231]|0;if(C>>>0>y>>>0){break}else{r=0;m=w;l=D;u=C;v=v+(w<<4)|0;k=y}}return}function WS(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ac=0,ad=0,ae=0,af=0;i=c[263194]|0;c[277226]=1106168;c[277225]=(a[1108928]|0)!=0?1393712:1106168;j=c[277230]|0;if((a[1044434]|0)==0){k=j;l=1;m=0}else{n=d[1044432]|0;o=((j-(d[1044433]|0)|0)>>>0)%(n>>>0)|0;k=j-o|0;l=n;m=o}if((a[1044435]|0)==0){p=f;q=g;r=1}else{o=d[1044432]|0;n=g-1+o|0;p=f-((f|0)%(o|0)|0)|0;q=n-((n|0)%(o|0)|0)|0;r=o}o=c[277231]|0;if(k>>>0>o>>>0){return}n=(p|0)<(q|0);j=r&255;s=q-1|0;t=r-1|0;r=m;m=l;l=ab(c[277223]|0,k)|0;u=k;v=1097960+(k<<4)|0;k=o;while(1){if((m+u|0)>>>0>k>>>0){w=k+1-u|0}else{w=m}o=e[v+12>>1]<<19>>19;x=e[v+8>>1]<<19;y=e[v+10>>1]<<19;z=u+1|0;A=(e[v+14>>1]<<19>>19)-(y>>19)|0;B=(A&8192|0)!=0?A|-1024:A&1023;A=b[v+2>>1]|0;C=((a[1044414]|0)==0?z:z^255)&255;z=(ab(C,A)|0)&-64;D=z+(x>>11)+((ab(B,A)|0)&-64)|0;A=b[v+6>>1]|0;z=(ab(A,C)|0)&-64;C=z+(y>>11)+((ab(B,A)|0)&-64)|0;A=b[v>>1]|0;if((a[1044413]|0)==0){B=b[v+4>>1]|0;E=A;F=B<<16>>16;G=p;H=B}else{B=b[v+4>>1]|0;E=-A|0;F=-(B<<16>>16)|0;G=s;H=B}B=o-(x>>19)|0;x=(B&8192|0)!=0?B|-1024:B&1023;B=ab(G,A)|0;o=B+((ab(A,x)|0)&-64)|0;A=H<<16>>16;B=ab(A,G)|0;y=((ab(A,x)|0)&-64)+B|0;do{if((a[1044415]|0)==0){if(!n){break}B=(r|0)>=(w|0);x=o;A=y;z=1;I=p;while(1){J=z-1&255;do{if(J<<24>>24==0){K=x+D|0;L=(A+C|0)>>>8;M=a[i+(L<<4&112|K>>>8<<1&14|d[(c[263194]|0)+(L<<5&32512|K>>>10&254)|0]<<7|1)|0]|0;K=M&127;if(K<<24>>24==0|B){N=j;break}L=t+I|0;O=(L|0)<(I|0);P=(M<<24>>24<0?11:3)+h|0;M=K&255;K=P&255;Q=r;while(1){if(!O){R=L;do{S=R+l|0;T=(ab(c[277223]|0,Q)|0)+S|0;if((R|0)>=(f|0)&(P|0)>(d[(c[277219]|0)+T|0]|0)&(R|0)<(g|0)){U=b[(c[277225]|0)+(M<<1)>>1]|0;do{if((a[1108928]|0)==0){V=b[(c[277221]|0)+(((U&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{W=c[277228]&65535;X=U&-2048;Y=W&-2048;Z=(X&65535)>(Y&65535)?X-Y&65535:0;Y=U&2016;X=W&2016;if((Y&65535)>(X&65535)){_=(Y-X&65535)+Z&65535}else{_=Z}Z=U&31;X=W&31;if((Z&65535)<=(X&65535)){V=_;break}V=(Z-X&65535)+_&65535}}while(0);b[(c[277218]|0)+(T<<1)>>1]=V;U=(ab(c[277223]|0,Q)|0)+S|0;a[(c[277219]|0)+U|0]=K}R=R-1|0;}while((R|0)>=(I|0))}R=Q+1|0;if((R|0)<(w|0)){Q=R}else{N=j;break}}}else{N=J}}while(0);J=I+1|0;if((J|0)<(q|0)){x=x+E|0;A=A+F|0;z=N;I=J}else{break}}}else{if(!n){break}I=(r|0)>=(w|0);z=o;A=y;x=1;B=p;while(1){J=x-1&255;do{if(J<<24>>24==0){Q=z+D|0;K=Q>>8;M=A+C>>8;if((K|M)>>>0<1024){$=K<<1&14|M<<4&112|d[(c[263194]|0)+((M<<5&-256)+(Q>>10&-2))|0]<<7}else{if((a[1044415]|0)!=3){aa=j;break}$=K<<1&14|M<<4&112}M=a[i+($|1)|0]|0;K=M&127;if(K<<24>>24==0|I){aa=j;break}Q=t+B|0;P=(Q|0)<(B|0);L=(M<<24>>24<0?11:3)+h|0;M=K&255;K=L&255;O=r;while(1){if(!P){R=Q;do{U=R+l|0;X=(ab(c[277223]|0,O)|0)+U|0;if((R|0)>=(f|0)&(L|0)>(d[(c[277219]|0)+X|0]|0)&(R|0)<(g|0)){Z=b[(c[277225]|0)+(M<<1)>>1]|0;do{if((a[1108928]|0)==0){ac=b[(c[277221]|0)+(((Z&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{W=c[277228]&65535;Y=Z&-2048;ad=W&-2048;ae=(Y&65535)>(ad&65535)?Y-ad&65535:0;ad=Z&2016;Y=W&2016;if((ad&65535)>(Y&65535)){af=(ad-Y&65535)+ae&65535}else{af=ae}ae=Z&31;Y=W&31;if((ae&65535)<=(Y&65535)){ac=af;break}ac=(ae-Y&65535)+af&65535}}while(0);b[(c[277218]|0)+(X<<1)>>1]=ac;Z=(ab(c[277223]|0,O)|0)+U|0;a[(c[277219]|0)+Z|0]=K}R=R-1|0;}while((R|0)>=(B|0))}R=O+1|0;if((R|0)<(w|0)){O=R}else{aa=j;break}}}else{aa=J}}while(0);J=B+1|0;if((J|0)<(q|0)){z=z+E|0;A=A+F|0;x=aa;B=J}else{break}}}}while(0);C=w+u|0;D=(ab(c[277223]|0,w)|0)+l|0;y=c[277231]|0;if(C>>>0>y>>>0){break}else{r=0;m=w;l=D;u=C;v=v+(w<<4)|0;k=y}}return}function WT(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0;i=c[263194]|0;c[277226]=1106168;c[277225]=(a[1108928]|0)!=0?1393712:1106168;j=c[277230]|0;if((a[1044434]|0)==0){k=j;l=1;m=0}else{n=d[1044432]|0;o=((j-(d[1044433]|0)|0)>>>0)%(n>>>0)|0;k=j-o|0;l=n;m=o}if((a[1044435]|0)==0){p=f;q=g;r=1}else{o=d[1044432]|0;n=g-1+o|0;p=f-((f|0)%(o|0)|0)|0;q=n-((n|0)%(o|0)|0)|0;r=o}o=c[277231]|0;if(k>>>0>o>>>0){return}n=(p|0)<(q|0);j=r&255;s=q-1|0;t=r-1|0;r=m;m=l;l=ab(c[277223]|0,k)|0;u=k;v=1097960+(k<<4)|0;k=o;while(1){if((m+u|0)>>>0>k>>>0){w=k+1-u|0}else{w=m}o=e[v+12>>1]<<19>>19;x=e[v+8>>1]<<19;y=e[v+10>>1]<<19;z=u+1|0;A=(e[v+14>>1]<<19>>19)-(y>>19)|0;B=(A&8192|0)!=0?A|-1024:A&1023;A=b[v+2>>1]|0;C=((a[1044414]|0)==0?z:z^255)&255;z=(ab(C,A)|0)&-64;D=z+(x>>11)+((ab(B,A)|0)&-64)|0;A=b[v+6>>1]|0;z=(ab(A,C)|0)&-64;C=z+(y>>11)+((ab(B,A)|0)&-64)|0;A=b[v>>1]|0;if((a[1044413]|0)==0){B=b[v+4>>1]|0;E=A;F=B<<16>>16;G=p;H=B}else{B=b[v+4>>1]|0;E=-A|0;F=-(B<<16>>16)|0;G=s;H=B}B=o-(x>>19)|0;x=(B&8192|0)!=0?B|-1024:B&1023;B=ab(G,A)|0;o=B+((ab(A,x)|0)&-64)|0;A=H<<16>>16;B=ab(A,G)|0;y=((ab(A,x)|0)&-64)+B|0;do{if((a[1044415]|0)==0){if(!n){break}B=(r|0)>=(w|0);x=o;A=y;z=1;I=p;while(1){J=z-1&255;do{if(J<<24>>24==0){K=x+D|0;L=(A+C|0)>>>8;M=a[i+(L<<4&112|K>>>8<<1&14|d[(c[263194]|0)+(L<<5&32512|K>>>10&254)|0]<<7|1)|0]|0;K=M&127;if(K<<24>>24==0|B){N=j;break}L=t+I|0;O=(L|0)<(I|0);P=(M<<24>>24<0?11:3)+h|0;M=K&255;K=P&255;Q=r;while(1){if(!O){R=L;do{S=R+l|0;T=(ab(c[277223]|0,Q)|0)+S|0;if((R|0)>=(f|0)&(P|0)>(d[(c[277219]|0)+T|0]|0)&(R|0)<(g|0)){do{if((a[1108928]|0)==0){U=b[(c[277225]|0)+(M<<1)>>1]|0;if((a[(c[277215]|0)+T|0]&32)!=0){V=b[(c[277221]|0)+((U&65535|67616)-(b[(c[277213]|0)+(T<<1)>>1]&63454)>>1<<1)>>1]|0;break}W=c[277228]&65535;X=U&-2048;Y=W&-2048;Z=(X&65535)>(Y&65535)?X-Y&65535:0;Y=U&2016;X=W&2016;if((Y&65535)>(X&65535)){_=(Y-X&65535)+Z&65535}else{_=Z}Z=U&31;U=W&31;if((Z&65535)<=(U&65535)){V=_;break}V=(Z-U&65535)+_&65535}else{U=b[(c[277225]|0)+(M<<1)>>1]|0;if((a[(c[277215]|0)+T|0]&32)==0){$=c[277228]&65535}else{$=b[(c[277213]|0)+(T<<1)>>1]|0}Z=U&-2048;W=$&-2048;X=(Z&65535)>(W&65535)?Z-W&65535:0;W=U&2016;Z=$&2016;if((W&65535)>(Z&65535)){aa=(W-Z&65535)+X&65535}else{aa=X}X=U&31;U=$&31;if((X&65535)<=(U&65535)){V=aa;break}V=(X-U&65535)+aa&65535}}while(0);b[(c[277218]|0)+(T<<1)>>1]=V;U=(ab(c[277223]|0,Q)|0)+S|0;a[(c[277219]|0)+U|0]=K}R=R-1|0;}while((R|0)>=(I|0))}R=Q+1|0;if((R|0)<(w|0)){Q=R}else{N=j;break}}}else{N=J}}while(0);J=I+1|0;if((J|0)<(q|0)){x=x+E|0;A=A+F|0;z=N;I=J}else{break}}}else{if(!n){break}I=(r|0)>=(w|0);z=o;A=y;x=1;B=p;while(1){J=x-1&255;do{if(J<<24>>24==0){Q=z+D|0;K=Q>>8;M=A+C>>8;if((K|M)>>>0<1024){ac=K<<1&14|M<<4&112|d[(c[263194]|0)+((M<<5&-256)+(Q>>10&-2))|0]<<7}else{if((a[1044415]|0)!=3){ad=j;break}ac=K<<1&14|M<<4&112}M=a[i+(ac|1)|0]|0;K=M&127;if(K<<24>>24==0|I){ad=j;break}Q=t+B|0;P=(Q|0)<(B|0);L=(M<<24>>24<0?11:3)+h|0;M=K&255;K=L&255;O=r;while(1){if(!P){R=Q;do{U=R+l|0;X=(ab(c[277223]|0,O)|0)+U|0;if((R|0)>=(f|0)&(L|0)>(d[(c[277219]|0)+X|0]|0)&(R|0)<(g|0)){do{if((a[1108928]|0)==0){Z=b[(c[277225]|0)+(M<<1)>>1]|0;if((a[(c[277215]|0)+X|0]&32)!=0){ae=b[(c[277221]|0)+((Z&65535|67616)-(b[(c[277213]|0)+(X<<1)>>1]&63454)>>1<<1)>>1]|0;break}W=c[277228]&65535;Y=Z&-2048;af=W&-2048;ag=(Y&65535)>(af&65535)?Y-af&65535:0;af=Z&2016;Y=W&2016;if((af&65535)>(Y&65535)){ah=(af-Y&65535)+ag&65535}else{ah=ag}ag=Z&31;Z=W&31;if((ag&65535)<=(Z&65535)){ae=ah;break}ae=(ag-Z&65535)+ah&65535}else{Z=b[(c[277225]|0)+(M<<1)>>1]|0;if((a[(c[277215]|0)+X|0]&32)==0){ai=c[277228]&65535}else{ai=b[(c[277213]|0)+(X<<1)>>1]|0}ag=Z&-2048;W=ai&-2048;Y=(ag&65535)>(W&65535)?ag-W&65535:0;W=Z&2016;ag=ai&2016;if((W&65535)>(ag&65535)){aj=(W-ag&65535)+Y&65535}else{aj=Y}Y=Z&31;Z=ai&31;if((Y&65535)<=(Z&65535)){ae=aj;break}ae=(Y-Z&65535)+aj&65535}}while(0);b[(c[277218]|0)+(X<<1)>>1]=ae;S=(ab(c[277223]|0,O)|0)+U|0;a[(c[277219]|0)+S|0]=K}R=R-1|0;}while((R|0)>=(B|0))}R=O+1|0;if((R|0)<(w|0)){O=R}else{ad=j;break}}}else{ad=J}}while(0);J=B+1|0;if((J|0)<(q|0)){z=z+E|0;A=A+F|0;x=ad;B=J}else{break}}}}while(0);C=w+u|0;D=(ab(c[277223]|0,w)|0)+l|0;y=c[277231]|0;if(C>>>0>y>>>0){break}else{r=0;m=w;l=D;u=C;v=v+(w<<4)|0;k=y}}return}function WU(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;i=c[263194]|0;do{if((a[(c[263195]|0)+8496|0]&1)==0){j=1106168}else{if((a[1106089]|0)==0){j=1125528;break}k=d[1044485]|0;c[276541]=7080+(k<<5);l=0;do{m=l<<1&2;n=l&2;o=l&4;p=0;do{b[1125528+(l<<9)+(p<<1)>>1]=d[(p>>>1&28|n)+(7080+(k<<5))|0]<<6|d[(p<<2&28|m)+(7080+(k<<5))|0]<<11|d[(p>>>3&24|o)+(7080+(k<<5))|0];p=p+1|0;}while(p>>>0<256);l=l+1|0;}while(l>>>0<8);a[1106089]=0;j=1125528}}while(0);c[277226]=j;c[277225]=(a[1108928]|0)!=0?1393712:j;j=c[277230]|0;if(j>>>0>(c[277231]|0)>>>0){return}l=f>>>0<g>>>0;k=h+7|0;h=k&255;p=g-1|0;o=ab(c[277223]|0,j)|0;m=j;n=1097960+(j<<4)|0;while(1){j=e[n+12>>1]<<19>>19;q=e[n+8>>1]<<19;r=e[n+10>>1]<<19;s=m+1|0;t=(e[n+14>>1]<<19>>19)-(r>>19)|0;u=(t&8192|0)!=0?t|-1024:t&1023;t=b[n+2>>1]|0;v=((a[1044414]|0)==0?s:s^255)&255;w=(ab(v,t)|0)&-64;x=w+(q>>11)+((ab(u,t)|0)&-64)|0;t=b[n+6>>1]|0;w=(ab(t,v)|0)&-64;v=w+(r>>11)+((ab(u,t)|0)&-64)|0;t=b[n>>1]|0;if((a[1044413]|0)==0){u=b[n+4>>1]|0;y=t;z=u<<16>>16;A=f;B=u}else{u=b[n+4>>1]|0;y=-t|0;z=-(u<<16>>16)|0;A=p;B=u}u=j-(q>>19)|0;q=(u&8192|0)!=0?u|-1024:u&1023;u=ab(A,t)|0;j=u+((ab(t,q)|0)&-64)|0;t=B<<16>>16;u=ab(t,A)|0;r=((ab(t,q)|0)&-64)+u|0;L16946:do{if((a[1044415]|0)==0){if(l){C=r;D=j;E=f}else{break}while(1){u=D+x|0;q=(C+v|0)>>>8;t=E+o|0;do{if((k|0)>(d[(c[277219]|0)+t|0]|0)){w=a[i+(u>>>8<<1&14|q<<4&112|d[(c[263194]|0)+(q<<5&32512|u>>>10&254)|0]<<7|1)|0]|0;if(w<<24>>24==0){break}b[(c[277218]|0)+(t<<1)>>1]=b[(c[277225]|0)+((w&255)<<1)>>1]|0;a[(c[277219]|0)+t|0]=h}}while(0);t=E+1|0;if(t>>>0>=g>>>0){break L16946}C=C+z|0;D=D+y|0;E=t}}else{if(l){F=r;G=j;H=f}else{break}while(1){t=G+x|0;u=t>>8;q=F+v>>8;do{if((q|u)>>>0<1024){I=q<<4&112|u<<1&14|d[(c[263194]|0)+((q<<5&-256)+(t>>10&-2))|0]<<7;J=12180}else{if((a[1044415]|0)!=3){break}I=q<<4&112|u<<1&14;J=12180}}while(0);do{if((J|0)==12180){J=0;u=H+o|0;if((k|0)<=(d[(c[277219]|0)+u|0]|0)){break}q=a[i+(I|1)|0]|0;if(q<<24>>24==0){break}b[(c[277218]|0)+(u<<1)>>1]=b[(c[277225]|0)+((q&255)<<1)>>1]|0;a[(c[277219]|0)+u|0]=h}}while(0);u=H+1|0;if(u>>>0<g>>>0){F=F+z|0;G=G+y|0;H=u}else{break}}}}while(0);if(s>>>0>(c[277231]|0)>>>0){break}o=(c[277223]|0)+o|0;m=s;n=n+16|0}return}function WV(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;i=c[263194]|0;do{if((a[(c[263195]|0)+8496|0]&1)==0){j=1106168}else{if((a[1106089]|0)==0){j=1125528;break}k=d[1044485]|0;c[276541]=7080+(k<<5);l=0;do{m=l<<1&2;n=l&2;o=l&4;p=0;do{b[1125528+(l<<9)+(p<<1)>>1]=d[(p>>>1&28|n)+(7080+(k<<5))|0]<<6|d[(p<<2&28|m)+(7080+(k<<5))|0]<<11|d[(p>>>3&24|o)+(7080+(k<<5))|0];p=p+1|0;}while(p>>>0<256);l=l+1|0;}while(l>>>0<8);a[1106089]=0;j=1125528}}while(0);c[277226]=j;c[277225]=(a[1108928]|0)!=0?1393712:j;j=c[277230]|0;if(j>>>0>(c[277231]|0)>>>0){return}l=f>>>0<g>>>0;k=h+7|0;h=k&255;p=g-1|0;o=ab(c[277223]|0,j)|0;m=j;n=1097960+(j<<4)|0;while(1){j=e[n+12>>1]<<19>>19;q=e[n+8>>1]<<19;r=e[n+10>>1]<<19;s=m+1|0;t=(e[n+14>>1]<<19>>19)-(r>>19)|0;u=(t&8192|0)!=0?t|-1024:t&1023;t=b[n+2>>1]|0;v=((a[1044414]|0)==0?s:s^255)&255;w=(ab(v,t)|0)&-64;x=w+(q>>11)+((ab(u,t)|0)&-64)|0;t=b[n+6>>1]|0;w=(ab(t,v)|0)&-64;v=w+(r>>11)+((ab(u,t)|0)&-64)|0;t=b[n>>1]|0;if((a[1044413]|0)==0){u=b[n+4>>1]|0;y=t;z=u<<16>>16;A=f;B=u}else{u=b[n+4>>1]|0;y=-t|0;z=-(u<<16>>16)|0;A=p;B=u}u=j-(q>>19)|0;q=(u&8192|0)!=0?u|-1024:u&1023;u=ab(A,t)|0;j=u+((ab(t,q)|0)&-64)|0;t=B<<16>>16;u=ab(t,A)|0;r=((ab(t,q)|0)&-64)+u|0;L16990:do{if((a[1044415]|0)==0){if(l){C=r;D=j;E=f}else{break}while(1){u=D+x|0;q=(C+v|0)>>>8;t=E+o|0;do{if((k|0)>(d[(c[277219]|0)+t|0]|0)){w=a[i+(u>>>8<<1&14|q<<4&112|d[(c[263194]|0)+(q<<5&32512|u>>>10&254)|0]<<7|1)|0]|0;if(w<<24>>24==0){break}F=e[(c[277225]|0)+((w&255)<<1)>>1]|0;w=(a[(c[277215]|0)+t|0]&32)==0;if(w){G=c[277228]|0;H=G;I=G&-2082}else{G=e[(c[277213]|0)+(t<<1)>>1]|0;H=G;I=G&63454}if(w){J=c[277228]|0}else{J=e[(c[277213]|0)+(t<<1)>>1]|0}b[(c[277218]|0)+(t<<1)>>1]=((J^F)&2081|e[(c[277220]|0)+((F&2081&H)+((I+(F&63454)|0)>>>1)<<1)>>1])&65535;a[(c[277219]|0)+t|0]=h}}while(0);t=E+1|0;if(t>>>0>=g>>>0){break L16990}C=C+z|0;D=D+y|0;E=t}}else{if(l){K=r;L=j;M=f}else{break}while(1){t=L+x|0;u=t>>8;q=K+v>>8;do{if((q|u)>>>0<1024){N=q<<4&112|u<<1&14|d[(c[263194]|0)+((q<<5&-256)+(t>>10&-2))|0]<<7;O=12219}else{if((a[1044415]|0)!=3){break}N=q<<4&112|u<<1&14;O=12219}}while(0);do{if((O|0)==12219){O=0;u=M+o|0;if((k|0)<=(d[(c[277219]|0)+u|0]|0)){break}q=a[i+(N|1)|0]|0;if(q<<24>>24==0){break}t=e[(c[277225]|0)+((q&255)<<1)>>1]|0;q=(a[(c[277215]|0)+u|0]&32)==0;if(q){F=c[277228]|0;P=F;Q=F&-2082}else{F=e[(c[277213]|0)+(u<<1)>>1]|0;P=F;Q=F&63454}if(q){R=c[277228]|0}else{R=e[(c[277213]|0)+(u<<1)>>1]|0}b[(c[277218]|0)+(u<<1)>>1]=((R^t)&2081|e[(c[277220]|0)+((t&2081&P)+((Q+(t&63454)|0)>>>1)<<1)>>1])&65535;a[(c[277219]|0)+u|0]=h}}while(0);u=M+1|0;if(u>>>0<g>>>0){K=K+z|0;L=L+y|0;M=u}else{break}}}}while(0);if(s>>>0>(c[277231]|0)>>>0){break}o=(c[277223]|0)+o|0;m=s;n=n+16|0}return}function WW(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;i=c[263194]|0;do{if((a[(c[263195]|0)+8496|0]&1)==0){j=1106168}else{if((a[1106089]|0)==0){j=1125528;break}k=d[1044485]|0;c[276541]=7080+(k<<5);l=0;do{m=l<<1&2;n=l&2;o=l&4;p=0;do{b[1125528+(l<<9)+(p<<1)>>1]=d[(p>>>1&28|n)+(7080+(k<<5))|0]<<6|d[(p<<2&28|m)+(7080+(k<<5))|0]<<11|d[(p>>>3&24|o)+(7080+(k<<5))|0];p=p+1|0;}while(p>>>0<256);l=l+1|0;}while(l>>>0<8);a[1106089]=0;j=1125528}}while(0);c[277226]=j;c[277225]=(a[1108928]|0)!=0?1393712:j;j=c[277230]|0;if(j>>>0>(c[277231]|0)>>>0){return}l=f>>>0<g>>>0;k=h+7|0;h=k&255;p=g-1|0;o=ab(c[277223]|0,j)|0;m=j;n=1097960+(j<<4)|0;while(1){j=e[n+12>>1]<<19>>19;q=e[n+8>>1]<<19;r=e[n+10>>1]<<19;s=m+1|0;t=(e[n+14>>1]<<19>>19)-(r>>19)|0;u=(t&8192|0)!=0?t|-1024:t&1023;t=b[n+2>>1]|0;v=((a[1044414]|0)==0?s:s^255)&255;w=(ab(v,t)|0)&-64;x=w+(q>>11)+((ab(u,t)|0)&-64)|0;t=b[n+6>>1]|0;w=(ab(t,v)|0)&-64;v=w+(r>>11)+((ab(u,t)|0)&-64)|0;t=b[n>>1]|0;if((a[1044413]|0)==0){u=b[n+4>>1]|0;y=t;z=u<<16>>16;A=f;B=u}else{u=b[n+4>>1]|0;y=-t|0;z=-(u<<16>>16)|0;A=p;B=u}u=j-(q>>19)|0;q=(u&8192|0)!=0?u|-1024:u&1023;u=ab(A,t)|0;j=u+((ab(t,q)|0)&-64)|0;t=B<<16>>16;u=ab(t,A)|0;r=((ab(t,q)|0)&-64)+u|0;L17050:do{if((a[1044415]|0)==0){if(l){C=r;D=j;E=f}else{break}while(1){u=D+x|0;q=(C+v|0)>>>8;t=E+o|0;do{if((k|0)>(d[(c[277219]|0)+t|0]|0)){w=a[i+(u>>>8<<1&14|q<<4&112|d[(c[263194]|0)+(q<<5&32512|u>>>10&254)|0]<<7|1)|0]|0;if(w<<24>>24==0){break}F=e[(c[277225]|0)+((w&255)<<1)>>1]|0;w=c[277228]|0;G=(((F&63454)+(w&-2082)|0)>>>1)+(w&2081&F)|0;if((a[1108928]|0)==0){H=G&65535}else{H=(e[(c[277220]|0)+(G<<1)>>1]|(F^w)&2081)&65535}b[(c[277218]|0)+(t<<1)>>1]=H;a[(c[277219]|0)+t|0]=h}}while(0);t=E+1|0;if(t>>>0>=g>>>0){break L17050}C=C+z|0;D=D+y|0;E=t}}else{if(l){I=r;J=j;K=f}else{break}while(1){t=J+x|0;u=t>>8;q=I+v>>8;do{if((q|u)>>>0<1024){L=q<<4&112|u<<1&14|d[(c[263194]|0)+((q<<5&-256)+(t>>10&-2))|0]<<7;M=12260}else{if((a[1044415]|0)!=3){break}L=q<<4&112|u<<1&14;M=12260}}while(0);do{if((M|0)==12260){M=0;u=K+o|0;if((k|0)<=(d[(c[277219]|0)+u|0]|0)){break}q=a[i+(L|1)|0]|0;if(q<<24>>24==0){break}t=e[(c[277225]|0)+((q&255)<<1)>>1]|0;q=c[277228]|0;w=(((t&63454)+(q&-2082)|0)>>>1)+(q&2081&t)|0;if((a[1108928]|0)==0){N=w&65535}else{N=(e[(c[277220]|0)+(w<<1)>>1]|(t^q)&2081)&65535}b[(c[277218]|0)+(u<<1)>>1]=N;a[(c[277219]|0)+u|0]=h}}while(0);u=K+1|0;if(u>>>0<g>>>0){I=I+z|0;J=J+y|0;K=u}else{break}}}}while(0);if(s>>>0>(c[277231]|0)>>>0){break}o=(c[277223]|0)+o|0;m=s;n=n+16|0}return}
function UA(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0,cf=0,cg=0,ch=0,ci=0,cj=0,ck=0,cl=0,cm=0,cn=0,co=0,cp=0,cq=0,cr=0,cs=0,ct=0,cu=0,cv=0,cw=0,cx=0,cy=0,cz=0,cA=0,cB=0,cC=0;i=e&1023;j=c[348606]|0;k=(i<<j)+(c[348604]|0)|0;if((e&256|0)==0){l=k}else{l=(c[348602]|0)+k|0}k=l&65535;l=k>>>(j>>>0);j=(e&16384|0)!=0;m=l<<6;do{if(j){n=(c[348622]|0)+m|0;if((a[(c[348618]|0)+l|0]|0)!=0){o=n;break}p=fi[c[348636]&63](n,k,i)|0;a[(c[348618]|0)+l|0]=p;o=n}else{n=(c[348624]|0)+m|0;if((a[(c[348620]|0)+l|0]|0)!=0){o=n;break}p=fi[c[348638]&63](n,k,i)|0;a[(c[348620]|0)+l|0]=p;o=n}}while(0);if((a[(c[348620]|0)+l|0]|0)==2){return}if((a[1394464]|0)==0){q=1106168+((e>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){l=d[1044485]|0;c[276541]=7080+(l<<5);i=0;do{k=i<<1&2;m=i&2;n=i&4;p=0;do{b[1125528+(i<<9)+(p<<1)>>1]=d[(p>>>1&28|m)+(7080+(l<<5))|0]<<6|d[(p<<2&28|k)+(7080+(l<<5))|0]<<11|d[(p>>>3&24|n)+(7080+(l<<5))|0];p=p+1|0;}while(p>>>0<256);i=i+1|0;}while(i>>>0<8);a[1106089]=0}q=1125528+((e>>>10&7)<<9)|0}c[277226]=q;c[277225]=(a[1108928]|0)!=0?1393712:q;if((e&49152|0)==0){if((h|0)<=0){return}q=o+g|0;i=h;l=f;while(1){p=a[1108908]|0;n=c[277219]|0;do{if((p&255)>(d[n+l|0]|0)){k=a[q]|0;m=k&255;if(k<<24>>24==0){r=p;s=n;break}do{if((a[1108928]|0)==0){k=b[(c[277225]|0)+(m<<1)>>1]|0;if((a[(c[277215]|0)+l|0]&32)!=0){t=b[(c[277221]|0)+((k&65535|67616)-(b[(c[277213]|0)+(l<<1)>>1]&63454)>>1<<1)>>1]|0;break}u=c[277228]&65535;v=k&-2048;w=u&-2048;x=(v&65535)>(w&65535)?v-w&65535:0;w=k&2016;v=u&2016;if((w&65535)>(v&65535)){y=(w-v&65535)+x&65535}else{y=x}x=k&31;k=u&31;if((x&65535)<=(k&65535)){t=y;break}t=(x-k&65535)+y&65535}else{k=b[(c[277225]|0)+(m<<1)>>1]|0;if((a[(c[277215]|0)+l|0]&32)==0){z=c[277228]&65535}else{z=b[(c[277213]|0)+(l<<1)>>1]|0}x=k&-2048;u=z&-2048;v=(x&65535)>(u&65535)?x-u&65535:0;u=k&2016;x=z&2016;if((u&65535)>(x&65535)){A=(u-x&65535)+v&65535}else{A=v}v=k&31;k=z&31;if((v&65535)<=(k&65535)){t=A;break}t=(v-k&65535)+A&65535}}while(0);m=l+1|0;b[(c[277218]|0)+(m<<1)>>1]=t;b[(c[277218]|0)+(l<<1)>>1]=t;k=a[1108909]|0;a[(c[277219]|0)+m|0]=k;a[(c[277219]|0)+l|0]=k;r=a[1108908]|0;s=c[277219]|0}else{r=p;s=n}}while(0);n=l+2|0;do{if((r&255)>(d[s+n|0]|0)){p=a[q+1|0]|0;k=p&255;if(p<<24>>24==0){B=r;C=s;break}do{if((a[1108928]|0)==0){p=b[(c[277225]|0)+(k<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)!=0){D=b[(c[277221]|0)+((p&65535|67616)-(b[(c[277213]|0)+(n<<1)>>1]&63454)>>1<<1)>>1]|0;break}m=c[277228]&65535;v=p&-2048;x=m&-2048;u=(v&65535)>(x&65535)?v-x&65535:0;x=p&2016;v=m&2016;if((x&65535)>(v&65535)){E=(x-v&65535)+u&65535}else{E=u}u=p&31;p=m&31;if((u&65535)<=(p&65535)){D=E;break}D=(u-p&65535)+E&65535}else{p=b[(c[277225]|0)+(k<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)==0){F=c[277228]&65535}else{F=b[(c[277213]|0)+(n<<1)>>1]|0}u=p&-2048;m=F&-2048;v=(u&65535)>(m&65535)?u-m&65535:0;m=p&2016;u=F&2016;if((m&65535)>(u&65535)){G=(m-u&65535)+v&65535}else{G=v}v=p&31;p=F&31;if((v&65535)<=(p&65535)){D=G;break}D=(v-p&65535)+G&65535}}while(0);k=l+3|0;b[(c[277218]|0)+(k<<1)>>1]=D;b[(c[277218]|0)+(n<<1)>>1]=D;p=a[1108909]|0;a[(c[277219]|0)+k|0]=p;a[(c[277219]|0)+n|0]=p;B=a[1108908]|0;C=c[277219]|0}else{B=r;C=s}}while(0);n=l+4|0;do{if((B&255)>(d[C+n|0]|0)){p=a[q+2|0]|0;k=p&255;if(p<<24>>24==0){H=B;I=C;break}do{if((a[1108928]|0)==0){p=b[(c[277225]|0)+(k<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)!=0){J=b[(c[277221]|0)+((p&65535|67616)-(b[(c[277213]|0)+(n<<1)>>1]&63454)>>1<<1)>>1]|0;break}v=c[277228]&65535;u=p&-2048;m=v&-2048;x=(u&65535)>(m&65535)?u-m&65535:0;m=p&2016;u=v&2016;if((m&65535)>(u&65535)){K=(m-u&65535)+x&65535}else{K=x}x=p&31;p=v&31;if((x&65535)<=(p&65535)){J=K;break}J=(x-p&65535)+K&65535}else{p=b[(c[277225]|0)+(k<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)==0){L=c[277228]&65535}else{L=b[(c[277213]|0)+(n<<1)>>1]|0}x=p&-2048;v=L&-2048;u=(x&65535)>(v&65535)?x-v&65535:0;v=p&2016;x=L&2016;if((v&65535)>(x&65535)){M=(v-x&65535)+u&65535}else{M=u}u=p&31;p=L&31;if((u&65535)<=(p&65535)){J=M;break}J=(u-p&65535)+M&65535}}while(0);k=l+5|0;b[(c[277218]|0)+(k<<1)>>1]=J;b[(c[277218]|0)+(n<<1)>>1]=J;p=a[1108909]|0;a[(c[277219]|0)+k|0]=p;a[(c[277219]|0)+n|0]=p;H=a[1108908]|0;I=c[277219]|0}else{H=B;I=C}}while(0);n=l+6|0;do{if((H&255)>(d[I+n|0]|0)){p=a[q+3|0]|0;k=p&255;if(p<<24>>24==0){N=H;O=I;break}do{if((a[1108928]|0)==0){p=b[(c[277225]|0)+(k<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)!=0){P=b[(c[277221]|0)+((p&65535|67616)-(b[(c[277213]|0)+(n<<1)>>1]&63454)>>1<<1)>>1]|0;break}u=c[277228]&65535;x=p&-2048;v=u&-2048;m=(x&65535)>(v&65535)?x-v&65535:0;v=p&2016;x=u&2016;if((v&65535)>(x&65535)){Q=(v-x&65535)+m&65535}else{Q=m}m=p&31;p=u&31;if((m&65535)<=(p&65535)){P=Q;break}P=(m-p&65535)+Q&65535}else{p=b[(c[277225]|0)+(k<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)==0){R=c[277228]&65535}else{R=b[(c[277213]|0)+(n<<1)>>1]|0}m=p&-2048;u=R&-2048;x=(m&65535)>(u&65535)?m-u&65535:0;u=p&2016;m=R&2016;if((u&65535)>(m&65535)){S=(u-m&65535)+x&65535}else{S=x}x=p&31;p=R&31;if((x&65535)<=(p&65535)){P=S;break}P=(x-p&65535)+S&65535}}while(0);k=l+7|0;b[(c[277218]|0)+(k<<1)>>1]=P;b[(c[277218]|0)+(n<<1)>>1]=P;p=a[1108909]|0;a[(c[277219]|0)+k|0]=p;a[(c[277219]|0)+n|0]=p;N=a[1108908]|0;O=c[277219]|0}else{N=H;O=I}}while(0);n=l+8|0;do{if((N&255)>(d[O+n|0]|0)){p=a[q+4|0]|0;k=p&255;if(p<<24>>24==0){T=N;U=O;break}do{if((a[1108928]|0)==0){p=b[(c[277225]|0)+(k<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)!=0){V=b[(c[277221]|0)+((p&65535|67616)-(b[(c[277213]|0)+(n<<1)>>1]&63454)>>1<<1)>>1]|0;break}x=c[277228]&65535;m=p&-2048;u=x&-2048;v=(m&65535)>(u&65535)?m-u&65535:0;u=p&2016;m=x&2016;if((u&65535)>(m&65535)){W=(u-m&65535)+v&65535}else{W=v}v=p&31;p=x&31;if((v&65535)<=(p&65535)){V=W;break}V=(v-p&65535)+W&65535}else{p=b[(c[277225]|0)+(k<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)==0){X=c[277228]&65535}else{X=b[(c[277213]|0)+(n<<1)>>1]|0}v=p&-2048;x=X&-2048;m=(v&65535)>(x&65535)?v-x&65535:0;x=p&2016;v=X&2016;if((x&65535)>(v&65535)){Y=(x-v&65535)+m&65535}else{Y=m}m=p&31;p=X&31;if((m&65535)<=(p&65535)){V=Y;break}V=(m-p&65535)+Y&65535}}while(0);k=l+9|0;b[(c[277218]|0)+(k<<1)>>1]=V;b[(c[277218]|0)+(n<<1)>>1]=V;p=a[1108909]|0;a[(c[277219]|0)+k|0]=p;a[(c[277219]|0)+n|0]=p;T=a[1108908]|0;U=c[277219]|0}else{T=N;U=O}}while(0);n=l+10|0;do{if((T&255)>(d[U+n|0]|0)){p=a[q+5|0]|0;k=p&255;if(p<<24>>24==0){Z=T;_=U;break}do{if((a[1108928]|0)==0){p=b[(c[277225]|0)+(k<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)!=0){$=b[(c[277221]|0)+((p&65535|67616)-(b[(c[277213]|0)+(n<<1)>>1]&63454)>>1<<1)>>1]|0;break}m=c[277228]&65535;v=p&-2048;x=m&-2048;u=(v&65535)>(x&65535)?v-x&65535:0;x=p&2016;v=m&2016;if((x&65535)>(v&65535)){aa=(x-v&65535)+u&65535}else{aa=u}u=p&31;p=m&31;if((u&65535)<=(p&65535)){$=aa;break}$=(u-p&65535)+aa&65535}else{p=b[(c[277225]|0)+(k<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)==0){ab=c[277228]&65535}else{ab=b[(c[277213]|0)+(n<<1)>>1]|0}u=p&-2048;m=ab&-2048;v=(u&65535)>(m&65535)?u-m&65535:0;m=p&2016;u=ab&2016;if((m&65535)>(u&65535)){ac=(m-u&65535)+v&65535}else{ac=v}v=p&31;p=ab&31;if((v&65535)<=(p&65535)){$=ac;break}$=(v-p&65535)+ac&65535}}while(0);k=l+11|0;b[(c[277218]|0)+(k<<1)>>1]=$;b[(c[277218]|0)+(n<<1)>>1]=$;p=a[1108909]|0;a[(c[277219]|0)+k|0]=p;a[(c[277219]|0)+n|0]=p;Z=a[1108908]|0;_=c[277219]|0}else{Z=T;_=U}}while(0);n=l+12|0;do{if((Z&255)>(d[_+n|0]|0)){p=a[q+6|0]|0;k=p&255;if(p<<24>>24==0){ad=Z;ae=_;break}do{if((a[1108928]|0)==0){p=b[(c[277225]|0)+(k<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)!=0){af=b[(c[277221]|0)+((p&65535|67616)-(b[(c[277213]|0)+(n<<1)>>1]&63454)>>1<<1)>>1]|0;break}v=c[277228]&65535;u=p&-2048;m=v&-2048;x=(u&65535)>(m&65535)?u-m&65535:0;m=p&2016;u=v&2016;if((m&65535)>(u&65535)){ag=(m-u&65535)+x&65535}else{ag=x}x=p&31;p=v&31;if((x&65535)<=(p&65535)){af=ag;break}af=(x-p&65535)+ag&65535}else{p=b[(c[277225]|0)+(k<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)==0){ah=c[277228]&65535}else{ah=b[(c[277213]|0)+(n<<1)>>1]|0}x=p&-2048;v=ah&-2048;u=(x&65535)>(v&65535)?x-v&65535:0;v=p&2016;x=ah&2016;if((v&65535)>(x&65535)){ai=(v-x&65535)+u&65535}else{ai=u}u=p&31;p=ah&31;if((u&65535)<=(p&65535)){af=ai;break}af=(u-p&65535)+ai&65535}}while(0);k=l+13|0;b[(c[277218]|0)+(k<<1)>>1]=af;b[(c[277218]|0)+(n<<1)>>1]=af;p=a[1108909]|0;a[(c[277219]|0)+k|0]=p;a[(c[277219]|0)+n|0]=p;ad=a[1108908]|0;ae=c[277219]|0}else{ad=Z;ae=_}}while(0);n=l+14|0;do{if((ad&255)>(d[ae+n|0]|0)){p=a[q+7|0]|0;k=p&255;if(p<<24>>24==0){break}do{if((a[1108928]|0)==0){p=b[(c[277225]|0)+(k<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)!=0){aj=b[(c[277221]|0)+((p&65535|67616)-(b[(c[277213]|0)+(n<<1)>>1]&63454)>>1<<1)>>1]|0;break}u=c[277228]&65535;x=p&-2048;v=u&-2048;m=(x&65535)>(v&65535)?x-v&65535:0;v=p&2016;x=u&2016;if((v&65535)>(x&65535)){ak=(v-x&65535)+m&65535}else{ak=m}m=p&31;p=u&31;if((m&65535)<=(p&65535)){aj=ak;break}aj=(m-p&65535)+ak&65535}else{p=b[(c[277225]|0)+(k<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)==0){al=c[277228]&65535}else{al=b[(c[277213]|0)+(n<<1)>>1]|0}m=p&-2048;u=al&-2048;x=(m&65535)>(u&65535)?m-u&65535:0;u=p&2016;m=al&2016;if((u&65535)>(m&65535)){am=(u-m&65535)+x&65535}else{am=x}x=p&31;p=al&31;if((x&65535)<=(p&65535)){aj=am;break}aj=(x-p&65535)+am&65535}}while(0);k=l+15|0;b[(c[277218]|0)+(k<<1)>>1]=aj;b[(c[277218]|0)+(n<<1)>>1]=aj;p=a[1108909]|0;a[(c[277219]|0)+k|0]=p;a[(c[277219]|0)+n|0]=p}}while(0);n=i-1|0;if((n|0)<=0){break}q=q+8|0;i=n;l=(c[277223]|0)+l|0}return}if((e&32768|0)==0){if((h|0)<=0){return}e=o+g|0;l=h;i=f;while(1){q=a[1108908]|0;aj=c[277219]|0;do{if((q&255)>(d[aj+i|0]|0)){am=a[e+7|0]|0;al=am&255;if(am<<24>>24==0){an=q;ao=aj;break}do{if((a[1108928]|0)==0){am=b[(c[277225]|0)+(al<<1)>>1]|0;if((a[(c[277215]|0)+i|0]&32)!=0){ap=b[(c[277221]|0)+((am&65535|67616)-(b[(c[277213]|0)+(i<<1)>>1]&63454)>>1<<1)>>1]|0;break}ak=c[277228]&65535;ae=am&-2048;ad=ak&-2048;_=(ae&65535)>(ad&65535)?ae-ad&65535:0;ad=am&2016;ae=ak&2016;if((ad&65535)>(ae&65535)){aq=(ad-ae&65535)+_&65535}else{aq=_}_=am&31;am=ak&31;if((_&65535)<=(am&65535)){ap=aq;break}ap=(_-am&65535)+aq&65535}else{am=b[(c[277225]|0)+(al<<1)>>1]|0;if((a[(c[277215]|0)+i|0]&32)==0){ar=c[277228]&65535}else{ar=b[(c[277213]|0)+(i<<1)>>1]|0}_=am&-2048;ak=ar&-2048;ae=(_&65535)>(ak&65535)?_-ak&65535:0;ak=am&2016;_=ar&2016;if((ak&65535)>(_&65535)){as=(ak-_&65535)+ae&65535}else{as=ae}ae=am&31;am=ar&31;if((ae&65535)<=(am&65535)){ap=as;break}ap=(ae-am&65535)+as&65535}}while(0);al=i+1|0;b[(c[277218]|0)+(al<<1)>>1]=ap;b[(c[277218]|0)+(i<<1)>>1]=ap;am=a[1108909]|0;a[(c[277219]|0)+al|0]=am;a[(c[277219]|0)+i|0]=am;an=a[1108908]|0;ao=c[277219]|0}else{an=q;ao=aj}}while(0);aj=i+2|0;do{if((an&255)>(d[ao+aj|0]|0)){q=a[e+6|0]|0;am=q&255;if(q<<24>>24==0){at=an;au=ao;break}do{if((a[1108928]|0)==0){q=b[(c[277225]|0)+(am<<1)>>1]|0;if((a[(c[277215]|0)+aj|0]&32)!=0){av=b[(c[277221]|0)+((q&65535|67616)-(b[(c[277213]|0)+(aj<<1)>>1]&63454)>>1<<1)>>1]|0;break}al=c[277228]&65535;ae=q&-2048;_=al&-2048;ak=(ae&65535)>(_&65535)?ae-_&65535:0;_=q&2016;ae=al&2016;if((_&65535)>(ae&65535)){aw=(_-ae&65535)+ak&65535}else{aw=ak}ak=q&31;q=al&31;if((ak&65535)<=(q&65535)){av=aw;break}av=(ak-q&65535)+aw&65535}else{q=b[(c[277225]|0)+(am<<1)>>1]|0;if((a[(c[277215]|0)+aj|0]&32)==0){ax=c[277228]&65535}else{ax=b[(c[277213]|0)+(aj<<1)>>1]|0}ak=q&-2048;al=ax&-2048;ae=(ak&65535)>(al&65535)?ak-al&65535:0;al=q&2016;ak=ax&2016;if((al&65535)>(ak&65535)){ay=(al-ak&65535)+ae&65535}else{ay=ae}ae=q&31;q=ax&31;if((ae&65535)<=(q&65535)){av=ay;break}av=(ae-q&65535)+ay&65535}}while(0);am=i+3|0;b[(c[277218]|0)+(am<<1)>>1]=av;b[(c[277218]|0)+(aj<<1)>>1]=av;q=a[1108909]|0;a[(c[277219]|0)+am|0]=q;a[(c[277219]|0)+aj|0]=q;at=a[1108908]|0;au=c[277219]|0}else{at=an;au=ao}}while(0);aj=i+4|0;do{if((at&255)>(d[au+aj|0]|0)){q=a[e+5|0]|0;am=q&255;if(q<<24>>24==0){az=at;aA=au;break}do{if((a[1108928]|0)==0){q=b[(c[277225]|0)+(am<<1)>>1]|0;if((a[(c[277215]|0)+aj|0]&32)!=0){aB=b[(c[277221]|0)+((q&65535|67616)-(b[(c[277213]|0)+(aj<<1)>>1]&63454)>>1<<1)>>1]|0;break}ae=c[277228]&65535;ak=q&-2048;al=ae&-2048;_=(ak&65535)>(al&65535)?ak-al&65535:0;al=q&2016;ak=ae&2016;if((al&65535)>(ak&65535)){aC=(al-ak&65535)+_&65535}else{aC=_}_=q&31;q=ae&31;if((_&65535)<=(q&65535)){aB=aC;break}aB=(_-q&65535)+aC&65535}else{q=b[(c[277225]|0)+(am<<1)>>1]|0;if((a[(c[277215]|0)+aj|0]&32)==0){aD=c[277228]&65535}else{aD=b[(c[277213]|0)+(aj<<1)>>1]|0}_=q&-2048;ae=aD&-2048;ak=(_&65535)>(ae&65535)?_-ae&65535:0;ae=q&2016;_=aD&2016;if((ae&65535)>(_&65535)){aE=(ae-_&65535)+ak&65535}else{aE=ak}ak=q&31;q=aD&31;if((ak&65535)<=(q&65535)){aB=aE;break}aB=(ak-q&65535)+aE&65535}}while(0);am=i+5|0;b[(c[277218]|0)+(am<<1)>>1]=aB;b[(c[277218]|0)+(aj<<1)>>1]=aB;q=a[1108909]|0;a[(c[277219]|0)+am|0]=q;a[(c[277219]|0)+aj|0]=q;az=a[1108908]|0;aA=c[277219]|0}else{az=at;aA=au}}while(0);aj=i+6|0;do{if((az&255)>(d[aA+aj|0]|0)){q=a[e+4|0]|0;am=q&255;if(q<<24>>24==0){aF=az;aG=aA;break}do{if((a[1108928]|0)==0){q=b[(c[277225]|0)+(am<<1)>>1]|0;if((a[(c[277215]|0)+aj|0]&32)!=0){aH=b[(c[277221]|0)+((q&65535|67616)-(b[(c[277213]|0)+(aj<<1)>>1]&63454)>>1<<1)>>1]|0;break}ak=c[277228]&65535;_=q&-2048;ae=ak&-2048;al=(_&65535)>(ae&65535)?_-ae&65535:0;ae=q&2016;_=ak&2016;if((ae&65535)>(_&65535)){aI=(ae-_&65535)+al&65535}else{aI=al}al=q&31;q=ak&31;if((al&65535)<=(q&65535)){aH=aI;break}aH=(al-q&65535)+aI&65535}else{q=b[(c[277225]|0)+(am<<1)>>1]|0;if((a[(c[277215]|0)+aj|0]&32)==0){aJ=c[277228]&65535}else{aJ=b[(c[277213]|0)+(aj<<1)>>1]|0}al=q&-2048;ak=aJ&-2048;_=(al&65535)>(ak&65535)?al-ak&65535:0;ak=q&2016;al=aJ&2016;if((ak&65535)>(al&65535)){aK=(ak-al&65535)+_&65535}else{aK=_}_=q&31;q=aJ&31;if((_&65535)<=(q&65535)){aH=aK;break}aH=(_-q&65535)+aK&65535}}while(0);am=i+7|0;b[(c[277218]|0)+(am<<1)>>1]=aH;b[(c[277218]|0)+(aj<<1)>>1]=aH;q=a[1108909]|0;a[(c[277219]|0)+am|0]=q;a[(c[277219]|0)+aj|0]=q;aF=a[1108908]|0;aG=c[277219]|0}else{aF=az;aG=aA}}while(0);aj=i+8|0;do{if((aF&255)>(d[aG+aj|0]|0)){q=a[e+3|0]|0;am=q&255;if(q<<24>>24==0){aL=aF;aM=aG;break}do{if((a[1108928]|0)==0){q=b[(c[277225]|0)+(am<<1)>>1]|0;if((a[(c[277215]|0)+aj|0]&32)!=0){aN=b[(c[277221]|0)+((q&65535|67616)-(b[(c[277213]|0)+(aj<<1)>>1]&63454)>>1<<1)>>1]|0;break}_=c[277228]&65535;al=q&-2048;ak=_&-2048;ae=(al&65535)>(ak&65535)?al-ak&65535:0;ak=q&2016;al=_&2016;if((ak&65535)>(al&65535)){aO=(ak-al&65535)+ae&65535}else{aO=ae}ae=q&31;q=_&31;if((ae&65535)<=(q&65535)){aN=aO;break}aN=(ae-q&65535)+aO&65535}else{q=b[(c[277225]|0)+(am<<1)>>1]|0;if((a[(c[277215]|0)+aj|0]&32)==0){aP=c[277228]&65535}else{aP=b[(c[277213]|0)+(aj<<1)>>1]|0}ae=q&-2048;_=aP&-2048;al=(ae&65535)>(_&65535)?ae-_&65535:0;_=q&2016;ae=aP&2016;if((_&65535)>(ae&65535)){aQ=(_-ae&65535)+al&65535}else{aQ=al}al=q&31;q=aP&31;if((al&65535)<=(q&65535)){aN=aQ;break}aN=(al-q&65535)+aQ&65535}}while(0);am=i+9|0;b[(c[277218]|0)+(am<<1)>>1]=aN;b[(c[277218]|0)+(aj<<1)>>1]=aN;q=a[1108909]|0;a[(c[277219]|0)+am|0]=q;a[(c[277219]|0)+aj|0]=q;aL=a[1108908]|0;aM=c[277219]|0}else{aL=aF;aM=aG}}while(0);aj=i+10|0;do{if((aL&255)>(d[aM+aj|0]|0)){q=a[e+2|0]|0;am=q&255;if(q<<24>>24==0){aR=aL;aS=aM;break}do{if((a[1108928]|0)==0){q=b[(c[277225]|0)+(am<<1)>>1]|0;if((a[(c[277215]|0)+aj|0]&32)!=0){aT=b[(c[277221]|0)+((q&65535|67616)-(b[(c[277213]|0)+(aj<<1)>>1]&63454)>>1<<1)>>1]|0;break}al=c[277228]&65535;ae=q&-2048;_=al&-2048;ak=(ae&65535)>(_&65535)?ae-_&65535:0;_=q&2016;ae=al&2016;if((_&65535)>(ae&65535)){aU=(_-ae&65535)+ak&65535}else{aU=ak}ak=q&31;q=al&31;if((ak&65535)<=(q&65535)){aT=aU;break}aT=(ak-q&65535)+aU&65535}else{q=b[(c[277225]|0)+(am<<1)>>1]|0;if((a[(c[277215]|0)+aj|0]&32)==0){aV=c[277228]&65535}else{aV=b[(c[277213]|0)+(aj<<1)>>1]|0}ak=q&-2048;al=aV&-2048;ae=(ak&65535)>(al&65535)?ak-al&65535:0;al=q&2016;ak=aV&2016;if((al&65535)>(ak&65535)){aW=(al-ak&65535)+ae&65535}else{aW=ae}ae=q&31;q=aV&31;if((ae&65535)<=(q&65535)){aT=aW;break}aT=(ae-q&65535)+aW&65535}}while(0);am=i+11|0;b[(c[277218]|0)+(am<<1)>>1]=aT;b[(c[277218]|0)+(aj<<1)>>1]=aT;q=a[1108909]|0;a[(c[277219]|0)+am|0]=q;a[(c[277219]|0)+aj|0]=q;aR=a[1108908]|0;aS=c[277219]|0}else{aR=aL;aS=aM}}while(0);aj=i+12|0;do{if((aR&255)>(d[aS+aj|0]|0)){q=a[e+1|0]|0;am=q&255;if(q<<24>>24==0){aX=aR;aY=aS;break}do{if((a[1108928]|0)==0){q=b[(c[277225]|0)+(am<<1)>>1]|0;if((a[(c[277215]|0)+aj|0]&32)!=0){aZ=b[(c[277221]|0)+((q&65535|67616)-(b[(c[277213]|0)+(aj<<1)>>1]&63454)>>1<<1)>>1]|0;break}ae=c[277228]&65535;ak=q&-2048;al=ae&-2048;_=(ak&65535)>(al&65535)?ak-al&65535:0;al=q&2016;ak=ae&2016;if((al&65535)>(ak&65535)){a_=(al-ak&65535)+_&65535}else{a_=_}_=q&31;q=ae&31;if((_&65535)<=(q&65535)){aZ=a_;break}aZ=(_-q&65535)+a_&65535}else{q=b[(c[277225]|0)+(am<<1)>>1]|0;if((a[(c[277215]|0)+aj|0]&32)==0){a$=c[277228]&65535}else{a$=b[(c[277213]|0)+(aj<<1)>>1]|0}_=q&-2048;ae=a$&-2048;ak=(_&65535)>(ae&65535)?_-ae&65535:0;ae=q&2016;_=a$&2016;if((ae&65535)>(_&65535)){a0=(ae-_&65535)+ak&65535}else{a0=ak}ak=q&31;q=a$&31;if((ak&65535)<=(q&65535)){aZ=a0;break}aZ=(ak-q&65535)+a0&65535}}while(0);am=i+13|0;b[(c[277218]|0)+(am<<1)>>1]=aZ;b[(c[277218]|0)+(aj<<1)>>1]=aZ;q=a[1108909]|0;a[(c[277219]|0)+am|0]=q;a[(c[277219]|0)+aj|0]=q;aX=a[1108908]|0;aY=c[277219]|0}else{aX=aR;aY=aS}}while(0);aj=i+14|0;do{if((aX&255)>(d[aY+aj|0]|0)){q=a[e]|0;am=q&255;if(q<<24>>24==0){break}do{if((a[1108928]|0)==0){q=b[(c[277225]|0)+(am<<1)>>1]|0;if((a[(c[277215]|0)+aj|0]&32)!=0){a1=b[(c[277221]|0)+((q&65535|67616)-(b[(c[277213]|0)+(aj<<1)>>1]&63454)>>1<<1)>>1]|0;break}ak=c[277228]&65535;_=q&-2048;ae=ak&-2048;al=(_&65535)>(ae&65535)?_-ae&65535:0;ae=q&2016;_=ak&2016;if((ae&65535)>(_&65535)){a2=(ae-_&65535)+al&65535}else{a2=al}al=q&31;q=ak&31;if((al&65535)<=(q&65535)){a1=a2;break}a1=(al-q&65535)+a2&65535}else{q=b[(c[277225]|0)+(am<<1)>>1]|0;if((a[(c[277215]|0)+aj|0]&32)==0){a3=c[277228]&65535}else{a3=b[(c[277213]|0)+(aj<<1)>>1]|0}al=q&-2048;ak=a3&-2048;_=(al&65535)>(ak&65535)?al-ak&65535:0;ak=q&2016;al=a3&2016;if((ak&65535)>(al&65535)){a4=(ak-al&65535)+_&65535}else{a4=_}_=q&31;q=a3&31;if((_&65535)<=(q&65535)){a1=a4;break}a1=(_-q&65535)+a4&65535}}while(0);am=i+15|0;b[(c[277218]|0)+(am<<1)>>1]=a1;b[(c[277218]|0)+(aj<<1)>>1]=a1;q=a[1108909]|0;a[(c[277219]|0)+am|0]=q;a[(c[277219]|0)+aj|0]=q}}while(0);aj=l-1|0;if((aj|0)<=0){break}e=e+8|0;l=aj;i=(c[277223]|0)+i|0}return}i=o+(56-g)|0;g=(h|0)>0;if(j){if(g){a5=i;a6=h;a7=f}else{return}while(1){j=a[1108908]|0;o=c[277219]|0;do{if((j&255)>(d[o+a7|0]|0)){l=a[a5+7|0]|0;e=l&255;if(l<<24>>24==0){a8=j;a9=o;break}do{if((a[1108928]|0)==0){l=b[(c[277225]|0)+(e<<1)>>1]|0;if((a[(c[277215]|0)+a7|0]&32)!=0){ba=b[(c[277221]|0)+((l&65535|67616)-(b[(c[277213]|0)+(a7<<1)>>1]&63454)>>1<<1)>>1]|0;break}a1=c[277228]&65535;a4=l&-2048;a3=a1&-2048;a2=(a4&65535)>(a3&65535)?a4-a3&65535:0;a3=l&2016;a4=a1&2016;if((a3&65535)>(a4&65535)){bb=(a3-a4&65535)+a2&65535}else{bb=a2}a2=l&31;l=a1&31;if((a2&65535)<=(l&65535)){ba=bb;break}ba=(a2-l&65535)+bb&65535}else{l=b[(c[277225]|0)+(e<<1)>>1]|0;if((a[(c[277215]|0)+a7|0]&32)==0){bc=c[277228]&65535}else{bc=b[(c[277213]|0)+(a7<<1)>>1]|0}a2=l&-2048;a1=bc&-2048;a4=(a2&65535)>(a1&65535)?a2-a1&65535:0;a1=l&2016;a2=bc&2016;if((a1&65535)>(a2&65535)){bd=(a1-a2&65535)+a4&65535}else{bd=a4}a4=l&31;l=bc&31;if((a4&65535)<=(l&65535)){ba=bd;break}ba=(a4-l&65535)+bd&65535}}while(0);e=a7+1|0;b[(c[277218]|0)+(e<<1)>>1]=ba;b[(c[277218]|0)+(a7<<1)>>1]=ba;l=a[1108909]|0;a[(c[277219]|0)+e|0]=l;a[(c[277219]|0)+a7|0]=l;a8=a[1108908]|0;a9=c[277219]|0}else{a8=j;a9=o}}while(0);o=a7+2|0;do{if((a8&255)>(d[a9+o|0]|0)){j=a[a5+6|0]|0;l=j&255;if(j<<24>>24==0){be=a8;bf=a9;break}do{if((a[1108928]|0)==0){j=b[(c[277225]|0)+(l<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){bg=b[(c[277221]|0)+((j&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}e=c[277228]&65535;a4=j&-2048;a2=e&-2048;a1=(a4&65535)>(a2&65535)?a4-a2&65535:0;a2=j&2016;a4=e&2016;if((a2&65535)>(a4&65535)){bh=(a2-a4&65535)+a1&65535}else{bh=a1}a1=j&31;j=e&31;if((a1&65535)<=(j&65535)){bg=bh;break}bg=(a1-j&65535)+bh&65535}else{j=b[(c[277225]|0)+(l<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){bi=c[277228]&65535}else{bi=b[(c[277213]|0)+(o<<1)>>1]|0}a1=j&-2048;e=bi&-2048;a4=(a1&65535)>(e&65535)?a1-e&65535:0;e=j&2016;a1=bi&2016;if((e&65535)>(a1&65535)){bj=(e-a1&65535)+a4&65535}else{bj=a4}a4=j&31;j=bi&31;if((a4&65535)<=(j&65535)){bg=bj;break}bg=(a4-j&65535)+bj&65535}}while(0);l=a7+3|0;b[(c[277218]|0)+(l<<1)>>1]=bg;b[(c[277218]|0)+(o<<1)>>1]=bg;j=a[1108909]|0;a[(c[277219]|0)+l|0]=j;a[(c[277219]|0)+o|0]=j;be=a[1108908]|0;bf=c[277219]|0}else{be=a8;bf=a9}}while(0);o=a7+4|0;do{if((be&255)>(d[bf+o|0]|0)){j=a[a5+5|0]|0;l=j&255;if(j<<24>>24==0){bk=be;bl=bf;break}do{if((a[1108928]|0)==0){j=b[(c[277225]|0)+(l<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){bm=b[(c[277221]|0)+((j&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}a4=c[277228]&65535;a1=j&-2048;e=a4&-2048;a2=(a1&65535)>(e&65535)?a1-e&65535:0;e=j&2016;a1=a4&2016;if((e&65535)>(a1&65535)){bn=(e-a1&65535)+a2&65535}else{bn=a2}a2=j&31;j=a4&31;if((a2&65535)<=(j&65535)){bm=bn;break}bm=(a2-j&65535)+bn&65535}else{j=b[(c[277225]|0)+(l<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){bo=c[277228]&65535}else{bo=b[(c[277213]|0)+(o<<1)>>1]|0}a2=j&-2048;a4=bo&-2048;a1=(a2&65535)>(a4&65535)?a2-a4&65535:0;a4=j&2016;a2=bo&2016;if((a4&65535)>(a2&65535)){bp=(a4-a2&65535)+a1&65535}else{bp=a1}a1=j&31;j=bo&31;if((a1&65535)<=(j&65535)){bm=bp;break}bm=(a1-j&65535)+bp&65535}}while(0);l=a7+5|0;b[(c[277218]|0)+(l<<1)>>1]=bm;b[(c[277218]|0)+(o<<1)>>1]=bm;j=a[1108909]|0;a[(c[277219]|0)+l|0]=j;a[(c[277219]|0)+o|0]=j;bk=a[1108908]|0;bl=c[277219]|0}else{bk=be;bl=bf}}while(0);o=a7+6|0;do{if((bk&255)>(d[bl+o|0]|0)){j=a[a5+4|0]|0;l=j&255;if(j<<24>>24==0){bq=bk;br=bl;break}do{if((a[1108928]|0)==0){j=b[(c[277225]|0)+(l<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){bs=b[(c[277221]|0)+((j&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}a1=c[277228]&65535;a2=j&-2048;a4=a1&-2048;e=(a2&65535)>(a4&65535)?a2-a4&65535:0;a4=j&2016;a2=a1&2016;if((a4&65535)>(a2&65535)){bt=(a4-a2&65535)+e&65535}else{bt=e}e=j&31;j=a1&31;if((e&65535)<=(j&65535)){bs=bt;break}bs=(e-j&65535)+bt&65535}else{j=b[(c[277225]|0)+(l<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){bu=c[277228]&65535}else{bu=b[(c[277213]|0)+(o<<1)>>1]|0}e=j&-2048;a1=bu&-2048;a2=(e&65535)>(a1&65535)?e-a1&65535:0;a1=j&2016;e=bu&2016;if((a1&65535)>(e&65535)){bv=(a1-e&65535)+a2&65535}else{bv=a2}a2=j&31;j=bu&31;if((a2&65535)<=(j&65535)){bs=bv;break}bs=(a2-j&65535)+bv&65535}}while(0);l=a7+7|0;b[(c[277218]|0)+(l<<1)>>1]=bs;b[(c[277218]|0)+(o<<1)>>1]=bs;j=a[1108909]|0;a[(c[277219]|0)+l|0]=j;a[(c[277219]|0)+o|0]=j;bq=a[1108908]|0;br=c[277219]|0}else{bq=bk;br=bl}}while(0);o=a7+8|0;do{if((bq&255)>(d[br+o|0]|0)){j=a[a5+3|0]|0;l=j&255;if(j<<24>>24==0){bw=bq;bx=br;break}do{if((a[1108928]|0)==0){j=b[(c[277225]|0)+(l<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){by=b[(c[277221]|0)+((j&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}a2=c[277228]&65535;e=j&-2048;a1=a2&-2048;a4=(e&65535)>(a1&65535)?e-a1&65535:0;a1=j&2016;e=a2&2016;if((a1&65535)>(e&65535)){bz=(a1-e&65535)+a4&65535}else{bz=a4}a4=j&31;j=a2&31;if((a4&65535)<=(j&65535)){by=bz;break}by=(a4-j&65535)+bz&65535}else{j=b[(c[277225]|0)+(l<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){bA=c[277228]&65535}else{bA=b[(c[277213]|0)+(o<<1)>>1]|0}a4=j&-2048;a2=bA&-2048;e=(a4&65535)>(a2&65535)?a4-a2&65535:0;a2=j&2016;a4=bA&2016;if((a2&65535)>(a4&65535)){bB=(a2-a4&65535)+e&65535}else{bB=e}e=j&31;j=bA&31;if((e&65535)<=(j&65535)){by=bB;break}by=(e-j&65535)+bB&65535}}while(0);l=a7+9|0;b[(c[277218]|0)+(l<<1)>>1]=by;b[(c[277218]|0)+(o<<1)>>1]=by;j=a[1108909]|0;a[(c[277219]|0)+l|0]=j;a[(c[277219]|0)+o|0]=j;bw=a[1108908]|0;bx=c[277219]|0}else{bw=bq;bx=br}}while(0);o=a7+10|0;do{if((bw&255)>(d[bx+o|0]|0)){j=a[a5+2|0]|0;l=j&255;if(j<<24>>24==0){bC=bw;bD=bx;break}do{if((a[1108928]|0)==0){j=b[(c[277225]|0)+(l<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){bE=b[(c[277221]|0)+((j&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}e=c[277228]&65535;a4=j&-2048;a2=e&-2048;a1=(a4&65535)>(a2&65535)?a4-a2&65535:0;a2=j&2016;a4=e&2016;if((a2&65535)>(a4&65535)){bF=(a2-a4&65535)+a1&65535}else{bF=a1}a1=j&31;j=e&31;if((a1&65535)<=(j&65535)){bE=bF;break}bE=(a1-j&65535)+bF&65535}else{j=b[(c[277225]|0)+(l<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){bG=c[277228]&65535}else{bG=b[(c[277213]|0)+(o<<1)>>1]|0}a1=j&-2048;e=bG&-2048;a4=(a1&65535)>(e&65535)?a1-e&65535:0;e=j&2016;a1=bG&2016;if((e&65535)>(a1&65535)){bH=(e-a1&65535)+a4&65535}else{bH=a4}a4=j&31;j=bG&31;if((a4&65535)<=(j&65535)){bE=bH;break}bE=(a4-j&65535)+bH&65535}}while(0);l=a7+11|0;b[(c[277218]|0)+(l<<1)>>1]=bE;b[(c[277218]|0)+(o<<1)>>1]=bE;j=a[1108909]|0;a[(c[277219]|0)+l|0]=j;a[(c[277219]|0)+o|0]=j;bC=a[1108908]|0;bD=c[277219]|0}else{bC=bw;bD=bx}}while(0);o=a7+12|0;do{if((bC&255)>(d[bD+o|0]|0)){j=a[a5+1|0]|0;l=j&255;if(j<<24>>24==0){bI=bC;bJ=bD;break}do{if((a[1108928]|0)==0){j=b[(c[277225]|0)+(l<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){bK=b[(c[277221]|0)+((j&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}a4=c[277228]&65535;a1=j&-2048;e=a4&-2048;a2=(a1&65535)>(e&65535)?a1-e&65535:0;e=j&2016;a1=a4&2016;if((e&65535)>(a1&65535)){bL=(e-a1&65535)+a2&65535}else{bL=a2}a2=j&31;j=a4&31;if((a2&65535)<=(j&65535)){bK=bL;break}bK=(a2-j&65535)+bL&65535}else{j=b[(c[277225]|0)+(l<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){bM=c[277228]&65535}else{bM=b[(c[277213]|0)+(o<<1)>>1]|0}a2=j&-2048;a4=bM&-2048;a1=(a2&65535)>(a4&65535)?a2-a4&65535:0;a4=j&2016;a2=bM&2016;if((a4&65535)>(a2&65535)){bN=(a4-a2&65535)+a1&65535}else{bN=a1}a1=j&31;j=bM&31;if((a1&65535)<=(j&65535)){bK=bN;break}bK=(a1-j&65535)+bN&65535}}while(0);l=a7+13|0;b[(c[277218]|0)+(l<<1)>>1]=bK;b[(c[277218]|0)+(o<<1)>>1]=bK;j=a[1108909]|0;a[(c[277219]|0)+l|0]=j;a[(c[277219]|0)+o|0]=j;bI=a[1108908]|0;bJ=c[277219]|0}else{bI=bC;bJ=bD}}while(0);o=a7+14|0;do{if((bI&255)>(d[bJ+o|0]|0)){j=a[a5]|0;l=j&255;if(j<<24>>24==0){break}do{if((a[1108928]|0)==0){j=b[(c[277225]|0)+(l<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){bO=b[(c[277221]|0)+((j&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}a1=c[277228]&65535;a2=j&-2048;a4=a1&-2048;e=(a2&65535)>(a4&65535)?a2-a4&65535:0;a4=j&2016;a2=a1&2016;if((a4&65535)>(a2&65535)){bP=(a4-a2&65535)+e&65535}else{bP=e}e=j&31;j=a1&31;if((e&65535)<=(j&65535)){bO=bP;break}bO=(e-j&65535)+bP&65535}else{j=b[(c[277225]|0)+(l<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){bQ=c[277228]&65535}else{bQ=b[(c[277213]|0)+(o<<1)>>1]|0}e=j&-2048;a1=bQ&-2048;a2=(e&65535)>(a1&65535)?e-a1&65535:0;a1=j&2016;e=bQ&2016;if((a1&65535)>(e&65535)){bR=(a1-e&65535)+a2&65535}else{bR=a2}a2=j&31;j=bQ&31;if((a2&65535)<=(j&65535)){bO=bR;break}bO=(a2-j&65535)+bR&65535}}while(0);l=a7+15|0;b[(c[277218]|0)+(l<<1)>>1]=bO;b[(c[277218]|0)+(o<<1)>>1]=bO;j=a[1108909]|0;a[(c[277219]|0)+l|0]=j;a[(c[277219]|0)+o|0]=j}}while(0);o=a6-1|0;if((o|0)<=0){break}a5=a5-8|0;a6=o;a7=(c[277223]|0)+a7|0}return}else{if(g){bS=i;bT=h;bU=f}else{return}while(1){f=a[1108908]|0;h=c[277219]|0;do{if((f&255)>(d[h+bU|0]|0)){i=a[bS]|0;g=i&255;if(i<<24>>24==0){bV=f;bW=h;break}do{if((a[1108928]|0)==0){i=b[(c[277225]|0)+(g<<1)>>1]|0;if((a[(c[277215]|0)+bU|0]&32)!=0){bX=b[(c[277221]|0)+((i&65535|67616)-(b[(c[277213]|0)+(bU<<1)>>1]&63454)>>1<<1)>>1]|0;break}a7=c[277228]&65535;a6=i&-2048;a5=a7&-2048;bO=(a6&65535)>(a5&65535)?a6-a5&65535:0;a5=i&2016;a6=a7&2016;if((a5&65535)>(a6&65535)){bY=(a5-a6&65535)+bO&65535}else{bY=bO}bO=i&31;i=a7&31;if((bO&65535)<=(i&65535)){bX=bY;break}bX=(bO-i&65535)+bY&65535}else{i=b[(c[277225]|0)+(g<<1)>>1]|0;if((a[(c[277215]|0)+bU|0]&32)==0){bZ=c[277228]&65535}else{bZ=b[(c[277213]|0)+(bU<<1)>>1]|0}bO=i&-2048;a7=bZ&-2048;a6=(bO&65535)>(a7&65535)?bO-a7&65535:0;a7=i&2016;bO=bZ&2016;if((a7&65535)>(bO&65535)){b_=(a7-bO&65535)+a6&65535}else{b_=a6}a6=i&31;i=bZ&31;if((a6&65535)<=(i&65535)){bX=b_;break}bX=(a6-i&65535)+b_&65535}}while(0);g=bU+1|0;b[(c[277218]|0)+(g<<1)>>1]=bX;b[(c[277218]|0)+(bU<<1)>>1]=bX;i=a[1108909]|0;a[(c[277219]|0)+g|0]=i;a[(c[277219]|0)+bU|0]=i;bV=a[1108908]|0;bW=c[277219]|0}else{bV=f;bW=h}}while(0);h=bU+2|0;do{if((bV&255)>(d[bW+h|0]|0)){f=a[bS+1|0]|0;i=f&255;if(f<<24>>24==0){b$=bV;b0=bW;break}do{if((a[1108928]|0)==0){f=b[(c[277225]|0)+(i<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)!=0){b1=b[(c[277221]|0)+((f&65535|67616)-(b[(c[277213]|0)+(h<<1)>>1]&63454)>>1<<1)>>1]|0;break}g=c[277228]&65535;a6=f&-2048;bO=g&-2048;a7=(a6&65535)>(bO&65535)?a6-bO&65535:0;bO=f&2016;a6=g&2016;if((bO&65535)>(a6&65535)){b2=(bO-a6&65535)+a7&65535}else{b2=a7}a7=f&31;f=g&31;if((a7&65535)<=(f&65535)){b1=b2;break}b1=(a7-f&65535)+b2&65535}else{f=b[(c[277225]|0)+(i<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)==0){b3=c[277228]&65535}else{b3=b[(c[277213]|0)+(h<<1)>>1]|0}a7=f&-2048;g=b3&-2048;a6=(a7&65535)>(g&65535)?a7-g&65535:0;g=f&2016;a7=b3&2016;if((g&65535)>(a7&65535)){b4=(g-a7&65535)+a6&65535}else{b4=a6}a6=f&31;f=b3&31;if((a6&65535)<=(f&65535)){b1=b4;break}b1=(a6-f&65535)+b4&65535}}while(0);i=bU+3|0;b[(c[277218]|0)+(i<<1)>>1]=b1;b[(c[277218]|0)+(h<<1)>>1]=b1;f=a[1108909]|0;a[(c[277219]|0)+i|0]=f;a[(c[277219]|0)+h|0]=f;b$=a[1108908]|0;b0=c[277219]|0}else{b$=bV;b0=bW}}while(0);h=bU+4|0;do{if((b$&255)>(d[b0+h|0]|0)){f=a[bS+2|0]|0;i=f&255;if(f<<24>>24==0){b5=b$;b6=b0;break}do{if((a[1108928]|0)==0){f=b[(c[277225]|0)+(i<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)!=0){b7=b[(c[277221]|0)+((f&65535|67616)-(b[(c[277213]|0)+(h<<1)>>1]&63454)>>1<<1)>>1]|0;break}a6=c[277228]&65535;a7=f&-2048;g=a6&-2048;bO=(a7&65535)>(g&65535)?a7-g&65535:0;g=f&2016;a7=a6&2016;if((g&65535)>(a7&65535)){b8=(g-a7&65535)+bO&65535}else{b8=bO}bO=f&31;f=a6&31;if((bO&65535)<=(f&65535)){b7=b8;break}b7=(bO-f&65535)+b8&65535}else{f=b[(c[277225]|0)+(i<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)==0){b9=c[277228]&65535}else{b9=b[(c[277213]|0)+(h<<1)>>1]|0}bO=f&-2048;a6=b9&-2048;a7=(bO&65535)>(a6&65535)?bO-a6&65535:0;a6=f&2016;bO=b9&2016;if((a6&65535)>(bO&65535)){ca=(a6-bO&65535)+a7&65535}else{ca=a7}a7=f&31;f=b9&31;if((a7&65535)<=(f&65535)){b7=ca;break}b7=(a7-f&65535)+ca&65535}}while(0);i=bU+5|0;b[(c[277218]|0)+(i<<1)>>1]=b7;b[(c[277218]|0)+(h<<1)>>1]=b7;f=a[1108909]|0;a[(c[277219]|0)+i|0]=f;a[(c[277219]|0)+h|0]=f;b5=a[1108908]|0;b6=c[277219]|0}else{b5=b$;b6=b0}}while(0);h=bU+6|0;do{if((b5&255)>(d[b6+h|0]|0)){f=a[bS+3|0]|0;i=f&255;if(f<<24>>24==0){cb=b5;cc=b6;break}do{if((a[1108928]|0)==0){f=b[(c[277225]|0)+(i<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)!=0){cd=b[(c[277221]|0)+((f&65535|67616)-(b[(c[277213]|0)+(h<<1)>>1]&63454)>>1<<1)>>1]|0;break}a7=c[277228]&65535;bO=f&-2048;a6=a7&-2048;g=(bO&65535)>(a6&65535)?bO-a6&65535:0;a6=f&2016;bO=a7&2016;if((a6&65535)>(bO&65535)){ce=(a6-bO&65535)+g&65535}else{ce=g}g=f&31;f=a7&31;if((g&65535)<=(f&65535)){cd=ce;break}cd=(g-f&65535)+ce&65535}else{f=b[(c[277225]|0)+(i<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)==0){cf=c[277228]&65535}else{cf=b[(c[277213]|0)+(h<<1)>>1]|0}g=f&-2048;a7=cf&-2048;bO=(g&65535)>(a7&65535)?g-a7&65535:0;a7=f&2016;g=cf&2016;if((a7&65535)>(g&65535)){cg=(a7-g&65535)+bO&65535}else{cg=bO}bO=f&31;f=cf&31;if((bO&65535)<=(f&65535)){cd=cg;break}cd=(bO-f&65535)+cg&65535}}while(0);i=bU+7|0;b[(c[277218]|0)+(i<<1)>>1]=cd;b[(c[277218]|0)+(h<<1)>>1]=cd;f=a[1108909]|0;a[(c[277219]|0)+i|0]=f;a[(c[277219]|0)+h|0]=f;cb=a[1108908]|0;cc=c[277219]|0}else{cb=b5;cc=b6}}while(0);h=bU+8|0;do{if((cb&255)>(d[cc+h|0]|0)){f=a[bS+4|0]|0;i=f&255;if(f<<24>>24==0){ch=cb;ci=cc;break}do{if((a[1108928]|0)==0){f=b[(c[277225]|0)+(i<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)!=0){cj=b[(c[277221]|0)+((f&65535|67616)-(b[(c[277213]|0)+(h<<1)>>1]&63454)>>1<<1)>>1]|0;break}bO=c[277228]&65535;g=f&-2048;a7=bO&-2048;a6=(g&65535)>(a7&65535)?g-a7&65535:0;a7=f&2016;g=bO&2016;if((a7&65535)>(g&65535)){ck=(a7-g&65535)+a6&65535}else{ck=a6}a6=f&31;f=bO&31;if((a6&65535)<=(f&65535)){cj=ck;break}cj=(a6-f&65535)+ck&65535}else{f=b[(c[277225]|0)+(i<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)==0){cl=c[277228]&65535}else{cl=b[(c[277213]|0)+(h<<1)>>1]|0}a6=f&-2048;bO=cl&-2048;g=(a6&65535)>(bO&65535)?a6-bO&65535:0;bO=f&2016;a6=cl&2016;if((bO&65535)>(a6&65535)){cm=(bO-a6&65535)+g&65535}else{cm=g}g=f&31;f=cl&31;if((g&65535)<=(f&65535)){cj=cm;break}cj=(g-f&65535)+cm&65535}}while(0);i=bU+9|0;b[(c[277218]|0)+(i<<1)>>1]=cj;b[(c[277218]|0)+(h<<1)>>1]=cj;f=a[1108909]|0;a[(c[277219]|0)+i|0]=f;a[(c[277219]|0)+h|0]=f;ch=a[1108908]|0;ci=c[277219]|0}else{ch=cb;ci=cc}}while(0);h=bU+10|0;do{if((ch&255)>(d[ci+h|0]|0)){f=a[bS+5|0]|0;i=f&255;if(f<<24>>24==0){cn=ch;co=ci;break}do{if((a[1108928]|0)==0){f=b[(c[277225]|0)+(i<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)!=0){cp=b[(c[277221]|0)+((f&65535|67616)-(b[(c[277213]|0)+(h<<1)>>1]&63454)>>1<<1)>>1]|0;break}g=c[277228]&65535;a6=f&-2048;bO=g&-2048;a7=(a6&65535)>(bO&65535)?a6-bO&65535:0;bO=f&2016;a6=g&2016;if((bO&65535)>(a6&65535)){cq=(bO-a6&65535)+a7&65535}else{cq=a7}a7=f&31;f=g&31;if((a7&65535)<=(f&65535)){cp=cq;break}cp=(a7-f&65535)+cq&65535}else{f=b[(c[277225]|0)+(i<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)==0){cr=c[277228]&65535}else{cr=b[(c[277213]|0)+(h<<1)>>1]|0}a7=f&-2048;g=cr&-2048;a6=(a7&65535)>(g&65535)?a7-g&65535:0;g=f&2016;a7=cr&2016;if((g&65535)>(a7&65535)){cs=(g-a7&65535)+a6&65535}else{cs=a6}a6=f&31;f=cr&31;if((a6&65535)<=(f&65535)){cp=cs;break}cp=(a6-f&65535)+cs&65535}}while(0);i=bU+11|0;b[(c[277218]|0)+(i<<1)>>1]=cp;b[(c[277218]|0)+(h<<1)>>1]=cp;f=a[1108909]|0;a[(c[277219]|0)+i|0]=f;a[(c[277219]|0)+h|0]=f;cn=a[1108908]|0;co=c[277219]|0}else{cn=ch;co=ci}}while(0);h=bU+12|0;do{if((cn&255)>(d[co+h|0]|0)){f=a[bS+6|0]|0;i=f&255;if(f<<24>>24==0){ct=cn;cu=co;break}do{if((a[1108928]|0)==0){f=b[(c[277225]|0)+(i<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)!=0){cv=b[(c[277221]|0)+((f&65535|67616)-(b[(c[277213]|0)+(h<<1)>>1]&63454)>>1<<1)>>1]|0;break}a6=c[277228]&65535;a7=f&-2048;g=a6&-2048;bO=(a7&65535)>(g&65535)?a7-g&65535:0;g=f&2016;a7=a6&2016;if((g&65535)>(a7&65535)){cw=(g-a7&65535)+bO&65535}else{cw=bO}bO=f&31;f=a6&31;if((bO&65535)<=(f&65535)){cv=cw;break}cv=(bO-f&65535)+cw&65535}else{f=b[(c[277225]|0)+(i<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)==0){cx=c[277228]&65535}else{cx=b[(c[277213]|0)+(h<<1)>>1]|0}bO=f&-2048;a6=cx&-2048;a7=(bO&65535)>(a6&65535)?bO-a6&65535:0;a6=f&2016;bO=cx&2016;if((a6&65535)>(bO&65535)){cy=(a6-bO&65535)+a7&65535}else{cy=a7}a7=f&31;f=cx&31;if((a7&65535)<=(f&65535)){cv=cy;break}cv=(a7-f&65535)+cy&65535}}while(0);i=bU+13|0;b[(c[277218]|0)+(i<<1)>>1]=cv;b[(c[277218]|0)+(h<<1)>>1]=cv;f=a[1108909]|0;a[(c[277219]|0)+i|0]=f;a[(c[277219]|0)+h|0]=f;ct=a[1108908]|0;cu=c[277219]|0}else{ct=cn;cu=co}}while(0);h=bU+14|0;do{if((ct&255)>(d[cu+h|0]|0)){f=a[bS+7|0]|0;i=f&255;if(f<<24>>24==0){break}do{if((a[1108928]|0)==0){f=b[(c[277225]|0)+(i<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)!=0){cz=b[(c[277221]|0)+((f&65535|67616)-(b[(c[277213]|0)+(h<<1)>>1]&63454)>>1<<1)>>1]|0;break}a7=c[277228]&65535;bO=f&-2048;a6=a7&-2048;g=(bO&65535)>(a6&65535)?bO-a6&65535:0;a6=f&2016;bO=a7&2016;if((a6&65535)>(bO&65535)){cA=(a6-bO&65535)+g&65535}else{cA=g}g=f&31;f=a7&31;if((g&65535)<=(f&65535)){cz=cA;break}cz=(g-f&65535)+cA&65535}else{f=b[(c[277225]|0)+(i<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)==0){cB=c[277228]&65535}else{cB=b[(c[277213]|0)+(h<<1)>>1]|0}g=f&-2048;a7=cB&-2048;bO=(g&65535)>(a7&65535)?g-a7&65535:0;a7=f&2016;g=cB&2016;if((a7&65535)>(g&65535)){cC=(a7-g&65535)+bO&65535}else{cC=bO}bO=f&31;f=cB&31;if((bO&65535)<=(f&65535)){cz=cC;break}cz=(bO-f&65535)+cC&65535}}while(0);i=bU+15|0;b[(c[277218]|0)+(i<<1)>>1]=cz;b[(c[277218]|0)+(h<<1)>>1]=cz;f=a[1108909]|0;a[(c[277219]|0)+i|0]=f;a[(c[277219]|0)+h|0]=f}}while(0);h=bT-1|0;if((h|0)<=0){break}bS=bS-8|0;bT=h;bU=(c[277223]|0)+bU|0}return}}function UB(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0;i=c[263194]|0;c[277226]=1106168;c[277225]=(a[1108928]|0)!=0?1393712:1106168;j=c[277230]|0;if(j>>>0>(c[277231]|0)>>>0){return}k=f>>>0<g>>>0;l=g-1|0;m=ab(c[277223]|0,j)|0;n=j;o=1097960+(j<<4)|0;while(1){j=e[o+12>>1]<<19>>19;p=e[o+8>>1]<<19;q=e[o+10>>1]<<19;r=n+1|0;s=(e[o+14>>1]<<19>>19)-(q>>19)|0;t=(s&8192|0)!=0?s|-1024:s&1023;s=b[o+2>>1]|0;u=((a[1044414]|0)==0?r:r^255)&255;v=(ab(u,s)|0)&-64;w=v+(p>>11)+((ab(t,s)|0)&-64)|0;s=b[o+6>>1]|0;v=(ab(s,u)|0)&-64;u=v+(q>>11)+((ab(t,s)|0)&-64)|0;s=b[o>>1]|0;if((a[1044413]|0)==0){t=b[o+4>>1]|0;x=s;y=t<<16>>16;z=f;A=t}else{t=b[o+4>>1]|0;x=-s|0;y=-(t<<16>>16)|0;z=l;A=t}t=j-(p>>19)|0;p=(t&8192|0)!=0?t|-1024:t&1023;t=ab(z,s)|0;j=t+((ab(s,p)|0)&-64)|0;s=A<<16>>16;t=ab(s,z)|0;q=((ab(s,p)|0)&-64)+t|0;L14469:do{if((a[1044415]|0)==0){if(k){B=q;C=j;D=f}else{break}while(1){t=C+w|0;p=(B+u|0)>>>8;s=a[i+(t>>>8<<1&14|p<<4&112|d[(c[263194]|0)+(p<<5&32512|t>>>10&254)|0]<<7|1)|0]|0;t=((s&255)>>>4&8|3)+h|0;p=(D<<1)+m|0;do{if((t|0)>(d[(c[277219]|0)+p|0]|0)){v=s&127;if(v<<24>>24==0){break}E=b[(c[277225]|0)+((v&255)<<1)>>1]|0;v=p+1|0;b[(c[277218]|0)+(v<<1)>>1]=E;b[(c[277218]|0)+(p<<1)>>1]=E;E=t&255;a[(c[277219]|0)+v|0]=E;a[(c[277219]|0)+p|0]=E}}while(0);p=D+1|0;if(p>>>0>=g>>>0){break L14469}B=B+y|0;C=C+x|0;D=p}}else{if(k){F=q;G=j;H=f}else{break}while(1){p=G+w|0;t=p>>8;s=F+u>>8;do{if((s|t)>>>0<1024){I=s<<4&112|t<<1&14|d[(c[263194]|0)+((s<<5&-256)+(p>>10&-2))|0]<<7;J=11120}else{if((a[1044415]|0)!=3){break}I=s<<4&112|t<<1&14;J=11120}}while(0);do{if((J|0)==11120){J=0;t=a[i+(I|1)|0]|0;s=((t&255)>>>4&8|3)+h|0;p=(H<<1)+m|0;if((s|0)<=(d[(c[277219]|0)+p|0]|0)){break}E=t&127;if(E<<24>>24==0){break}t=b[(c[277225]|0)+((E&255)<<1)>>1]|0;E=p+1|0;b[(c[277218]|0)+(E<<1)>>1]=t;b[(c[277218]|0)+(p<<1)>>1]=t;t=s&255;a[(c[277219]|0)+E|0]=t;a[(c[277219]|0)+p|0]=t}}while(0);t=H+1|0;if(t>>>0<g>>>0){F=F+y|0;G=G+x|0;H=t}else{break}}}}while(0);if(r>>>0>(c[277231]|0)>>>0){break}m=(c[277223]|0)+m|0;n=r;o=o+16|0}return}function UC(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;i=c[263194]|0;c[277226]=1106168;c[277225]=(a[1108928]|0)!=0?1393712:1106168;j=c[277230]|0;if(j>>>0>(c[277231]|0)>>>0){return}k=f>>>0<g>>>0;l=g-1|0;m=ab(c[277223]|0,j)|0;n=j;o=1097960+(j<<4)|0;while(1){j=e[o+12>>1]<<19>>19;p=e[o+8>>1]<<19;q=e[o+10>>1]<<19;r=n+1|0;s=(e[o+14>>1]<<19>>19)-(q>>19)|0;t=(s&8192|0)!=0?s|-1024:s&1023;s=b[o+2>>1]|0;u=((a[1044414]|0)==0?r:r^255)&255;v=(ab(u,s)|0)&-64;w=v+(p>>11)+((ab(t,s)|0)&-64)|0;s=b[o+6>>1]|0;v=(ab(s,u)|0)&-64;u=v+(q>>11)+((ab(t,s)|0)&-64)|0;s=b[o>>1]|0;if((a[1044413]|0)==0){t=b[o+4>>1]|0;x=s;y=t<<16>>16;z=f;A=t}else{t=b[o+4>>1]|0;x=-s|0;y=-(t<<16>>16)|0;z=l;A=t}t=j-(p>>19)|0;p=(t&8192|0)!=0?t|-1024:t&1023;t=ab(z,s)|0;j=t+((ab(s,p)|0)&-64)|0;s=A<<16>>16;t=ab(s,z)|0;q=((ab(s,p)|0)&-64)+t|0;L14503:do{if((a[1044415]|0)==0){if(k){B=q;C=j;D=f}else{break}while(1){t=C+w|0;p=(B+u|0)>>>8;s=a[i+(t>>>8<<1&14|p<<4&112|d[(c[263194]|0)+(p<<5&32512|t>>>10&254)|0]<<7|1)|0]|0;t=((s&255)>>>4&8|3)+h|0;p=(D<<1)+m|0;do{if((t|0)>(d[(c[277219]|0)+p|0]|0)){v=s&127;if(v<<24>>24==0){break}E=e[(c[277225]|0)+((v&255)<<1)>>1]|0;v=(a[(c[277215]|0)+p|0]&32)==0;if(v){F=c[277228]|0;G=F;H=F&-2082}else{F=e[(c[277213]|0)+(p<<1)>>1]|0;G=F;H=F&63454}if(v){I=c[277228]|0}else{I=e[(c[277213]|0)+(p<<1)>>1]|0}v=((I^E)&2081|e[(c[277220]|0)+((E&2081&G)+((H+(E&63454)|0)>>>1)<<1)>>1])&65535;E=p+1|0;b[(c[277218]|0)+(E<<1)>>1]=v;b[(c[277218]|0)+(p<<1)>>1]=v;v=t&255;a[(c[277219]|0)+E|0]=v;a[(c[277219]|0)+p|0]=v}}while(0);p=D+1|0;if(p>>>0>=g>>>0){break L14503}B=B+y|0;C=C+x|0;D=p}}else{if(k){J=q;K=j;L=f}else{break}while(1){p=K+w|0;t=p>>8;s=J+u>>8;do{if((s|t)>>>0<1024){M=s<<4&112|t<<1&14|d[(c[263194]|0)+((s<<5&-256)+(p>>10&-2))|0]<<7;N=11152}else{if((a[1044415]|0)!=3){break}M=s<<4&112|t<<1&14;N=11152}}while(0);do{if((N|0)==11152){N=0;t=a[i+(M|1)|0]|0;s=((t&255)>>>4&8|3)+h|0;p=(L<<1)+m|0;if((s|0)<=(d[(c[277219]|0)+p|0]|0)){break}v=t&127;if(v<<24>>24==0){break}t=e[(c[277225]|0)+((v&255)<<1)>>1]|0;v=(a[(c[277215]|0)+p|0]&32)==0;if(v){E=c[277228]|0;O=E;P=E&-2082}else{E=e[(c[277213]|0)+(p<<1)>>1]|0;O=E;P=E&63454}if(v){Q=c[277228]|0}else{Q=e[(c[277213]|0)+(p<<1)>>1]|0}v=((Q^t)&2081|e[(c[277220]|0)+((t&2081&O)+((P+(t&63454)|0)>>>1)<<1)>>1])&65535;t=p+1|0;b[(c[277218]|0)+(t<<1)>>1]=v;b[(c[277218]|0)+(p<<1)>>1]=v;v=s&255;a[(c[277219]|0)+t|0]=v;a[(c[277219]|0)+p|0]=v}}while(0);v=L+1|0;if(v>>>0<g>>>0){J=J+y|0;K=K+x|0;L=v}else{break}}}}while(0);if(r>>>0>(c[277231]|0)>>>0){break}m=(c[277223]|0)+m|0;n=r;o=o+16|0}return}function UD(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;i=c[263194]|0;c[277226]=1106168;c[277225]=(a[1108928]|0)!=0?1393712:1106168;j=c[277230]|0;if(j>>>0>(c[277231]|0)>>>0){return}k=f>>>0<g>>>0;l=g-1|0;m=ab(c[277223]|0,j)|0;n=j;o=1097960+(j<<4)|0;while(1){j=e[o+12>>1]<<19>>19;p=e[o+8>>1]<<19;q=e[o+10>>1]<<19;r=n+1|0;s=(e[o+14>>1]<<19>>19)-(q>>19)|0;t=(s&8192|0)!=0?s|-1024:s&1023;s=b[o+2>>1]|0;u=((a[1044414]|0)==0?r:r^255)&255;v=(ab(u,s)|0)&-64;w=v+(p>>11)+((ab(t,s)|0)&-64)|0;s=b[o+6>>1]|0;v=(ab(s,u)|0)&-64;u=v+(q>>11)+((ab(t,s)|0)&-64)|0;s=b[o>>1]|0;if((a[1044413]|0)==0){t=b[o+4>>1]|0;x=s;y=t<<16>>16;z=f;A=t}else{t=b[o+4>>1]|0;x=-s|0;y=-(t<<16>>16)|0;z=l;A=t}t=j-(p>>19)|0;p=(t&8192|0)!=0?t|-1024:t&1023;t=ab(z,s)|0;j=t+((ab(s,p)|0)&-64)|0;s=A<<16>>16;t=ab(s,z)|0;q=((ab(s,p)|0)&-64)+t|0;L14553:do{if((a[1044415]|0)==0){if(k){B=q;C=j;D=f}else{break}while(1){t=C+w|0;p=(B+u|0)>>>8;s=a[i+(t>>>8<<1&14|p<<4&112|d[(c[263194]|0)+(p<<5&32512|t>>>10&254)|0]<<7|1)|0]|0;t=((s&255)>>>4&8|3)+h|0;p=(D<<1)+m|0;do{if((t|0)>(d[(c[277219]|0)+p|0]|0)){v=s&127;if(v<<24>>24==0){break}E=e[(c[277225]|0)+((v&255)<<1)>>1]|0;v=c[277228]|0;F=(((E&63454)+(v&-2082)|0)>>>1)+(v&2081&E)|0;if((a[1108928]|0)==0){G=F&65535}else{G=(e[(c[277220]|0)+(F<<1)>>1]|(E^v)&2081)&65535}v=p+1|0;b[(c[277218]|0)+(v<<1)>>1]=G;b[(c[277218]|0)+(p<<1)>>1]=G;E=t&255;a[(c[277219]|0)+v|0]=E;a[(c[277219]|0)+p|0]=E}}while(0);p=D+1|0;if(p>>>0>=g>>>0){break L14553}B=B+y|0;C=C+x|0;D=p}}else{if(k){H=q;I=j;J=f}else{break}while(1){p=I+w|0;t=p>>8;s=H+u>>8;do{if((s|t)>>>0<1024){K=s<<4&112|t<<1&14|d[(c[263194]|0)+((s<<5&-256)+(p>>10&-2))|0]<<7;L=11186}else{if((a[1044415]|0)!=3){break}K=s<<4&112|t<<1&14;L=11186}}while(0);do{if((L|0)==11186){L=0;t=a[i+(K|1)|0]|0;s=((t&255)>>>4&8|3)+h|0;p=(J<<1)+m|0;if((s|0)<=(d[(c[277219]|0)+p|0]|0)){break}E=t&127;if(E<<24>>24==0){break}t=e[(c[277225]|0)+((E&255)<<1)>>1]|0;E=c[277228]|0;v=(((t&63454)+(E&-2082)|0)>>>1)+(E&2081&t)|0;if((a[1108928]|0)==0){M=v&65535}else{M=(e[(c[277220]|0)+(v<<1)>>1]|(t^E)&2081)&65535}E=p+1|0;b[(c[277218]|0)+(E<<1)>>1]=M;b[(c[277218]|0)+(p<<1)>>1]=M;t=s&255;a[(c[277219]|0)+E|0]=t;a[(c[277219]|0)+p|0]=t}}while(0);t=J+1|0;if(t>>>0<g>>>0){H=H+y|0;I=I+x|0;J=t}else{break}}}}while(0);if(r>>>0>(c[277231]|0)>>>0){break}m=(c[277223]|0)+m|0;n=r;o=o+16|0}return}function UE(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;i=c[263194]|0;c[277226]=1106168;c[277225]=(a[1108928]|0)!=0?1393712:1106168;j=c[277230]|0;if(j>>>0>(c[277231]|0)>>>0){return}k=f>>>0<g>>>0;l=g-1|0;m=ab(c[277223]|0,j)|0;n=j;o=1097960+(j<<4)|0;while(1){j=e[o+12>>1]<<19>>19;p=e[o+8>>1]<<19;q=e[o+10>>1]<<19;r=n+1|0;s=(e[o+14>>1]<<19>>19)-(q>>19)|0;t=(s&8192|0)!=0?s|-1024:s&1023;s=b[o+2>>1]|0;u=((a[1044414]|0)==0?r:r^255)&255;v=(ab(u,s)|0)&-64;w=v+(p>>11)+((ab(t,s)|0)&-64)|0;s=b[o+6>>1]|0;v=(ab(s,u)|0)&-64;u=v+(q>>11)+((ab(t,s)|0)&-64)|0;s=b[o>>1]|0;if((a[1044413]|0)==0){t=b[o+4>>1]|0;x=s;y=t<<16>>16;z=f;A=t}else{t=b[o+4>>1]|0;x=-s|0;y=-(t<<16>>16)|0;z=l;A=t}t=j-(p>>19)|0;p=(t&8192|0)!=0?t|-1024:t&1023;t=ab(z,s)|0;j=t+((ab(s,p)|0)&-64)|0;s=A<<16>>16;t=ab(s,z)|0;q=((ab(s,p)|0)&-64)+t|0;L14593:do{if((a[1044415]|0)==0){if(k){B=q;C=j;D=f}else{break}while(1){t=C+w|0;p=(B+u|0)>>>8;s=a[i+(t>>>8<<1&14|p<<4&112|d[(c[263194]|0)+(p<<5&32512|t>>>10&254)|0]<<7|1)|0]|0;t=((s&255)>>>4&8|3)+h|0;p=(D<<1)+m|0;do{if((t|0)>(d[(c[277219]|0)+p|0]|0)){v=s&127;E=v&255;if(v<<24>>24==0){break}do{if((a[1108928]|0)==0){v=b[(c[277225]|0)+(E<<1)>>1]|0;F=v&65535;G=F&63454;if((a[(c[277215]|0)+p|0]&32)==0){H=c[277228]|0;I=(e[(c[277220]|0)+((((H&-2082)+G|0)>>>1)+(F&2081&H)<<1)>>1]|(H^F)&2081)&65535;break}else{F=b[(c[277213]|0)+(p<<1)>>1]|0;I=(((F&63454)+G|0)>>>1)+(F&v&2081)&65535;break}}else{v=e[(c[277225]|0)+(E<<1)>>1]|0;F=(a[(c[277215]|0)+p|0]&32)==0;if(F){G=c[277228]|0;J=G;K=G&-2082}else{G=e[(c[277213]|0)+(p<<1)>>1]|0;J=G;K=G&63454}if(F){L=c[277228]|0}else{L=e[(c[277213]|0)+(p<<1)>>1]|0}I=((L^v)&2081|e[(c[277220]|0)+((v&2081&J)+((K+(v&63454)|0)>>>1)<<1)>>1])&65535}}while(0);E=p+1|0;b[(c[277218]|0)+(E<<1)>>1]=I;b[(c[277218]|0)+(p<<1)>>1]=I;v=t&255;a[(c[277219]|0)+E|0]=v;a[(c[277219]|0)+p|0]=v}}while(0);p=D+1|0;if(p>>>0>=g>>>0){break L14593}B=B+y|0;C=C+x|0;D=p}}else{if(k){M=q;N=j;O=f}else{break}while(1){p=N+w|0;t=p>>8;s=M+u>>8;do{if((s|t)>>>0<1024){P=s<<4&112|t<<1&14|d[(c[263194]|0)+((s<<5&-256)+(p>>10&-2))|0]<<7;Q=11225}else{if((a[1044415]|0)!=3){break}P=s<<4&112|t<<1&14;Q=11225}}while(0);do{if((Q|0)==11225){Q=0;t=a[i+(P|1)|0]|0;s=((t&255)>>>4&8|3)+h|0;p=(O<<1)+m|0;if((s|0)<=(d[(c[277219]|0)+p|0]|0)){break}v=t&127;t=v&255;if(v<<24>>24==0){break}do{if((a[1108928]|0)==0){v=b[(c[277225]|0)+(t<<1)>>1]|0;E=v&65535;F=E&63454;if((a[(c[277215]|0)+p|0]&32)==0){G=c[277228]|0;R=(e[(c[277220]|0)+((((G&-2082)+F|0)>>>1)+(E&2081&G)<<1)>>1]|(G^E)&2081)&65535;break}else{E=b[(c[277213]|0)+(p<<1)>>1]|0;R=(((E&63454)+F|0)>>>1)+(E&v&2081)&65535;break}}else{v=e[(c[277225]|0)+(t<<1)>>1]|0;E=(a[(c[277215]|0)+p|0]&32)==0;if(E){F=c[277228]|0;S=F;T=F&-2082}else{F=e[(c[277213]|0)+(p<<1)>>1]|0;S=F;T=F&63454}if(E){U=c[277228]|0}else{U=e[(c[277213]|0)+(p<<1)>>1]|0}R=((U^v)&2081|e[(c[277220]|0)+((v&2081&S)+((T+(v&63454)|0)>>>1)<<1)>>1])&65535}}while(0);t=p+1|0;b[(c[277218]|0)+(t<<1)>>1]=R;b[(c[277218]|0)+(p<<1)>>1]=R;v=s&255;a[(c[277219]|0)+t|0]=v;a[(c[277219]|0)+p|0]=v}}while(0);v=O+1|0;if(v>>>0<g>>>0){M=M+y|0;N=N+x|0;O=v}else{break}}}}while(0);if(r>>>0>(c[277231]|0)>>>0){break}m=(c[277223]|0)+m|0;n=r;o=o+16|0}return}function UF(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;i=c[263194]|0;c[277226]=1106168;c[277225]=(a[1108928]|0)!=0?1393712:1106168;j=c[277230]|0;if(j>>>0>(c[277231]|0)>>>0){return}k=f>>>0<g>>>0;l=g-1|0;m=ab(c[277223]|0,j)|0;n=j;o=1097960+(j<<4)|0;while(1){j=e[o+12>>1]<<19>>19;p=e[o+8>>1]<<19;q=e[o+10>>1]<<19;r=n+1|0;s=(e[o+14>>1]<<19>>19)-(q>>19)|0;t=(s&8192|0)!=0?s|-1024:s&1023;s=b[o+2>>1]|0;u=((a[1044414]|0)==0?r:r^255)&255;v=(ab(u,s)|0)&-64;w=v+(p>>11)+((ab(t,s)|0)&-64)|0;s=b[o+6>>1]|0;v=(ab(s,u)|0)&-64;u=v+(q>>11)+((ab(t,s)|0)&-64)|0;s=b[o>>1]|0;if((a[1044413]|0)==0){t=b[o+4>>1]|0;x=s;y=t<<16>>16;z=f;A=t}else{t=b[o+4>>1]|0;x=-s|0;y=-(t<<16>>16)|0;z=l;A=t}t=j-(p>>19)|0;p=(t&8192|0)!=0?t|-1024:t&1023;t=ab(z,s)|0;j=t+((ab(s,p)|0)&-64)|0;s=A<<16>>16;t=ab(s,z)|0;q=((ab(s,p)|0)&-64)+t|0;L14657:do{if((a[1044415]|0)==0){if(k){B=q;C=j;D=f}else{break}while(1){t=C+w|0;p=(B+u|0)>>>8;s=a[i+(t>>>8<<1&14|p<<4&112|d[(c[263194]|0)+(p<<5&32512|t>>>10&254)|0]<<7|1)|0]|0;t=((s&255)>>>4&8|3)+h|0;p=(D<<1)+m|0;do{if((t|0)>(d[(c[277219]|0)+p|0]|0)){v=s&127;if(v<<24>>24==0){break}E=b[(c[277225]|0)+((v&255)<<1)>>1]|0;if((a[(c[277215]|0)+p|0]&32)==0){F=c[277228]&65535}else{F=b[(c[277213]|0)+(p<<1)>>1]|0}v=E&-2048;G=F&-2048;H=(v&65535)>(G&65535)?v-G&65535:0;G=E&2016;v=F&2016;if((G&65535)>(v&65535)){I=(G-v&65535)+H&65535}else{I=H}H=E&31;E=F&31;if((H&65535)>(E&65535)){J=(H-E&65535)+I&65535}else{J=I}E=p+1|0;b[(c[277218]|0)+(E<<1)>>1]=J;b[(c[277218]|0)+(p<<1)>>1]=J;H=t&255;a[(c[277219]|0)+E|0]=H;a[(c[277219]|0)+p|0]=H}}while(0);p=D+1|0;if(p>>>0>=g>>>0){break L14657}B=B+y|0;C=C+x|0;D=p}}else{if(k){K=q;L=j;M=f}else{break}while(1){p=L+w|0;t=p>>8;s=K+u>>8;do{if((s|t)>>>0<1024){N=s<<4&112|t<<1&14|d[(c[263194]|0)+((s<<5&-256)+(p>>10&-2))|0]<<7;O=11269}else{if((a[1044415]|0)!=3){break}N=s<<4&112|t<<1&14;O=11269}}while(0);do{if((O|0)==11269){O=0;t=a[i+(N|1)|0]|0;s=((t&255)>>>4&8|3)+h|0;p=(M<<1)+m|0;if((s|0)<=(d[(c[277219]|0)+p|0]|0)){break}H=t&127;if(H<<24>>24==0){break}t=b[(c[277225]|0)+((H&255)<<1)>>1]|0;if((a[(c[277215]|0)+p|0]&32)==0){P=c[277228]&65535}else{P=b[(c[277213]|0)+(p<<1)>>1]|0}H=t&-2048;E=P&-2048;v=(H&65535)>(E&65535)?H-E&65535:0;E=t&2016;H=P&2016;if((E&65535)>(H&65535)){Q=(E-H&65535)+v&65535}else{Q=v}v=t&31;t=P&31;if((v&65535)>(t&65535)){R=(v-t&65535)+Q&65535}else{R=Q}t=p+1|0;b[(c[277218]|0)+(t<<1)>>1]=R;b[(c[277218]|0)+(p<<1)>>1]=R;v=s&255;a[(c[277219]|0)+t|0]=v;a[(c[277219]|0)+p|0]=v}}while(0);v=M+1|0;if(v>>>0<g>>>0){K=K+y|0;L=L+x|0;M=v}else{break}}}}while(0);if(r>>>0>(c[277231]|0)>>>0){break}m=(c[277223]|0)+m|0;n=r;o=o+16|0}return}function UG(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0;i=c[263194]|0;c[277226]=1106168;c[277225]=(a[1108928]|0)!=0?1393712:1106168;j=c[277230]|0;if(j>>>0>(c[277231]|0)>>>0){return}k=f>>>0<g>>>0;l=g-1|0;m=ab(c[277223]|0,j)|0;n=j;o=1097960+(j<<4)|0;while(1){j=e[o+12>>1]<<19>>19;p=e[o+8>>1]<<19;q=e[o+10>>1]<<19;r=n+1|0;s=(e[o+14>>1]<<19>>19)-(q>>19)|0;t=(s&8192|0)!=0?s|-1024:s&1023;s=b[o+2>>1]|0;u=((a[1044414]|0)==0?r:r^255)&255;v=(ab(u,s)|0)&-64;w=v+(p>>11)+((ab(t,s)|0)&-64)|0;s=b[o+6>>1]|0;v=(ab(s,u)|0)&-64;u=v+(q>>11)+((ab(t,s)|0)&-64)|0;s=b[o>>1]|0;if((a[1044413]|0)==0){t=b[o+4>>1]|0;x=s;y=t<<16>>16;z=f;A=t}else{t=b[o+4>>1]|0;x=-s|0;y=-(t<<16>>16)|0;z=l;A=t}t=j-(p>>19)|0;p=(t&8192|0)!=0?t|-1024:t&1023;t=ab(z,s)|0;j=t+((ab(s,p)|0)&-64)|0;s=A<<16>>16;t=ab(s,z)|0;q=((ab(s,p)|0)&-64)+t|0;L14711:do{if((a[1044415]|0)==0){if(k){B=q;C=j;D=f}else{break}while(1){t=C+w|0;p=(B+u|0)>>>8;s=a[i+(t>>>8<<1&14|p<<4&112|d[(c[263194]|0)+(p<<5&32512|t>>>10&254)|0]<<7|1)|0]|0;t=((s&255)>>>4&8|3)+h|0;p=(D<<1)+m|0;do{if((t|0)>(d[(c[277219]|0)+p|0]|0)){v=s&127;if(v<<24>>24==0){break}E=b[(c[277225]|0)+((v&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){F=b[(c[277221]|0)+(((E&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{v=c[277228]&65535;G=E&-2048;H=v&-2048;I=(G&65535)>(H&65535)?G-H&65535:0;H=E&2016;G=v&2016;if((H&65535)>(G&65535)){J=(H-G&65535)+I&65535}else{J=I}I=E&31;G=v&31;if((I&65535)<=(G&65535)){F=J;break}F=(I-G&65535)+J&65535}}while(0);E=p+1|0;b[(c[277218]|0)+(E<<1)>>1]=F;b[(c[277218]|0)+(p<<1)>>1]=F;G=t&255;a[(c[277219]|0)+E|0]=G;a[(c[277219]|0)+p|0]=G}}while(0);p=D+1|0;if(p>>>0>=g>>>0){break L14711}B=B+y|0;C=C+x|0;D=p}}else{if(k){K=q;L=j;M=f}else{break}while(1){p=L+w|0;t=p>>8;s=K+u>>8;do{if((s|t)>>>0<1024){N=s<<4&112|t<<1&14|d[(c[263194]|0)+((s<<5&-256)+(p>>10&-2))|0]<<7;O=11308}else{if((a[1044415]|0)!=3){break}N=s<<4&112|t<<1&14;O=11308}}while(0);do{if((O|0)==11308){O=0;t=a[i+(N|1)|0]|0;s=((t&255)>>>4&8|3)+h|0;p=(M<<1)+m|0;if((s|0)<=(d[(c[277219]|0)+p|0]|0)){break}G=t&127;if(G<<24>>24==0){break}t=b[(c[277225]|0)+((G&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){P=b[(c[277221]|0)+(((t&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{G=c[277228]&65535;E=t&-2048;I=G&-2048;v=(E&65535)>(I&65535)?E-I&65535:0;I=t&2016;E=G&2016;if((I&65535)>(E&65535)){Q=(I-E&65535)+v&65535}else{Q=v}v=t&31;E=G&31;if((v&65535)<=(E&65535)){P=Q;break}P=(v-E&65535)+Q&65535}}while(0);t=p+1|0;b[(c[277218]|0)+(t<<1)>>1]=P;b[(c[277218]|0)+(p<<1)>>1]=P;E=s&255;a[(c[277219]|0)+t|0]=E;a[(c[277219]|0)+p|0]=E}}while(0);E=M+1|0;if(E>>>0<g>>>0){K=K+y|0;L=L+x|0;M=E}else{break}}}}while(0);if(r>>>0>(c[277231]|0)>>>0){break}m=(c[277223]|0)+m|0;n=r;o=o+16|0}return}function UH(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;i=c[263194]|0;c[277226]=1106168;c[277225]=(a[1108928]|0)!=0?1393712:1106168;j=c[277230]|0;if(j>>>0>(c[277231]|0)>>>0){return}k=f>>>0<g>>>0;l=g-1|0;m=ab(c[277223]|0,j)|0;n=j;o=1097960+(j<<4)|0;while(1){j=e[o+12>>1]<<19>>19;p=e[o+8>>1]<<19;q=e[o+10>>1]<<19;r=n+1|0;s=(e[o+14>>1]<<19>>19)-(q>>19)|0;t=(s&8192|0)!=0?s|-1024:s&1023;s=b[o+2>>1]|0;u=((a[1044414]|0)==0?r:r^255)&255;v=(ab(u,s)|0)&-64;w=v+(p>>11)+((ab(t,s)|0)&-64)|0;s=b[o+6>>1]|0;v=(ab(s,u)|0)&-64;u=v+(q>>11)+((ab(t,s)|0)&-64)|0;s=b[o>>1]|0;if((a[1044413]|0)==0){t=b[o+4>>1]|0;x=s;y=t<<16>>16;z=f;A=t}else{t=b[o+4>>1]|0;x=-s|0;y=-(t<<16>>16)|0;z=l;A=t}t=j-(p>>19)|0;p=(t&8192|0)!=0?t|-1024:t&1023;t=ab(z,s)|0;j=t+((ab(s,p)|0)&-64)|0;s=A<<16>>16;t=ab(s,z)|0;q=((ab(s,p)|0)&-64)+t|0;L14761:do{if((a[1044415]|0)==0){if(k){B=q;C=j;D=f}else{break}while(1){t=C+w|0;p=(B+u|0)>>>8;s=a[i+(t>>>8<<1&14|p<<4&112|d[(c[263194]|0)+(p<<5&32512|t>>>10&254)|0]<<7|1)|0]|0;t=((s&255)>>>4&8|3)+h|0;p=(D<<1)+m|0;do{if((t|0)>(d[(c[277219]|0)+p|0]|0)){v=s&127;E=v&255;if(v<<24>>24==0){break}do{if((a[1108928]|0)==0){v=b[(c[277225]|0)+(E<<1)>>1]|0;if((a[(c[277215]|0)+p|0]&32)!=0){F=b[(c[277221]|0)+((v&65535|67616)-(b[(c[277213]|0)+(p<<1)>>1]&63454)>>1<<1)>>1]|0;break}G=c[277228]&65535;H=v&-2048;I=G&-2048;J=(H&65535)>(I&65535)?H-I&65535:0;I=v&2016;H=G&2016;if((I&65535)>(H&65535)){K=(I-H&65535)+J&65535}else{K=J}J=v&31;v=G&31;if((J&65535)<=(v&65535)){F=K;break}F=(J-v&65535)+K&65535}else{v=b[(c[277225]|0)+(E<<1)>>1]|0;if((a[(c[277215]|0)+p|0]&32)==0){L=c[277228]&65535}else{L=b[(c[277213]|0)+(p<<1)>>1]|0}J=v&-2048;G=L&-2048;H=(J&65535)>(G&65535)?J-G&65535:0;G=v&2016;J=L&2016;if((G&65535)>(J&65535)){M=(G-J&65535)+H&65535}else{M=H}H=v&31;v=L&31;if((H&65535)<=(v&65535)){F=M;break}F=(H-v&65535)+M&65535}}while(0);E=p+1|0;b[(c[277218]|0)+(E<<1)>>1]=F;b[(c[277218]|0)+(p<<1)>>1]=F;v=t&255;a[(c[277219]|0)+E|0]=v;a[(c[277219]|0)+p|0]=v}}while(0);p=D+1|0;if(p>>>0>=g>>>0){break L14761}B=B+y|0;C=C+x|0;D=p}}else{if(k){N=q;O=j;P=f}else{break}while(1){p=O+w|0;t=p>>8;s=N+u>>8;do{if((s|t)>>>0<1024){Q=s<<4&112|t<<1&14|d[(c[263194]|0)+((s<<5&-256)+(p>>10&-2))|0]<<7;R=11354}else{if((a[1044415]|0)!=3){break}Q=s<<4&112|t<<1&14;R=11354}}while(0);do{if((R|0)==11354){R=0;t=a[i+(Q|1)|0]|0;s=((t&255)>>>4&8|3)+h|0;p=(P<<1)+m|0;if((s|0)<=(d[(c[277219]|0)+p|0]|0)){break}v=t&127;t=v&255;if(v<<24>>24==0){break}do{if((a[1108928]|0)==0){v=b[(c[277225]|0)+(t<<1)>>1]|0;if((a[(c[277215]|0)+p|0]&32)!=0){S=b[(c[277221]|0)+((v&65535|67616)-(b[(c[277213]|0)+(p<<1)>>1]&63454)>>1<<1)>>1]|0;break}E=c[277228]&65535;H=v&-2048;J=E&-2048;G=(H&65535)>(J&65535)?H-J&65535:0;J=v&2016;H=E&2016;if((J&65535)>(H&65535)){T=(J-H&65535)+G&65535}else{T=G}G=v&31;v=E&31;if((G&65535)<=(v&65535)){S=T;break}S=(G-v&65535)+T&65535}else{v=b[(c[277225]|0)+(t<<1)>>1]|0;if((a[(c[277215]|0)+p|0]&32)==0){U=c[277228]&65535}else{U=b[(c[277213]|0)+(p<<1)>>1]|0}G=v&-2048;E=U&-2048;H=(G&65535)>(E&65535)?G-E&65535:0;E=v&2016;G=U&2016;if((E&65535)>(G&65535)){V=(E-G&65535)+H&65535}else{V=H}H=v&31;v=U&31;if((H&65535)<=(v&65535)){S=V;break}S=(H-v&65535)+V&65535}}while(0);t=p+1|0;b[(c[277218]|0)+(t<<1)>>1]=S;b[(c[277218]|0)+(p<<1)>>1]=S;v=s&255;a[(c[277219]|0)+t|0]=v;a[(c[277219]|0)+p|0]=v}}while(0);v=P+1|0;if(v>>>0<g>>>0){N=N+y|0;O=O+x|0;P=v}else{break}}}}while(0);if(r>>>0>(c[277231]|0)>>>0){break}m=(c[277223]|0)+m|0;n=r;o=o+16|0}return}function UI(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;i=c[263194]|0;c[277226]=1106168;c[277225]=(a[1108928]|0)!=0?1393712:1106168;j=c[277230]|0;if((a[1044434]|0)==0){k=j;l=1;m=0}else{n=d[1044432]|0;o=((j-(d[1044433]|0)|0)>>>0)%(n>>>0)|0;k=j-o|0;l=n;m=o}if((a[1044435]|0)==0){p=f;q=g;r=1}else{o=d[1044432]|0;n=g-1+o|0;p=f-((f|0)%(o|0)|0)|0;q=n-((n|0)%(o|0)|0)|0;r=o}o=c[277231]|0;if(k>>>0>o>>>0){return}n=(p|0)<(q|0);j=r&255;s=q-1|0;t=r-1|0;r=m;m=l;l=ab(c[277223]|0,k)|0;u=k;v=1097960+(k<<4)|0;k=o;while(1){if((m+u|0)>>>0>k>>>0){w=k+1-u|0}else{w=m}o=e[v+12>>1]<<19>>19;x=e[v+8>>1]<<19;y=e[v+10>>1]<<19;z=u+1|0;A=(e[v+14>>1]<<19>>19)-(y>>19)|0;B=(A&8192|0)!=0?A|-1024:A&1023;A=b[v+2>>1]|0;C=((a[1044414]|0)==0?z:z^255)&255;z=(ab(C,A)|0)&-64;D=z+(x>>11)+((ab(B,A)|0)&-64)|0;A=b[v+6>>1]|0;z=(ab(A,C)|0)&-64;C=z+(y>>11)+((ab(B,A)|0)&-64)|0;A=b[v>>1]|0;if((a[1044413]|0)==0){B=b[v+4>>1]|0;E=A;F=B<<16>>16;G=p;H=B}else{B=b[v+4>>1]|0;E=-A|0;F=-(B<<16>>16)|0;G=s;H=B}B=o-(x>>19)|0;x=(B&8192|0)!=0?B|-1024:B&1023;B=ab(G,A)|0;o=B+((ab(A,x)|0)&-64)|0;A=H<<16>>16;B=ab(A,G)|0;y=((ab(A,x)|0)&-64)+B|0;do{if((a[1044415]|0)==0){if(!n){break}B=(r|0)>=(w|0);x=o;A=y;z=1;I=p;while(1){J=z-1&255;do{if(J<<24>>24==0){K=x+D|0;L=(A+C|0)>>>8;M=a[i+(L<<4&112|K>>>8<<1&14|d[(c[263194]|0)+(L<<5&32512|K>>>10&254)|0]<<7|1)|0]|0;K=M&127;if(K<<24>>24==0|B){N=j;break}L=t+I|0;O=(L|0)<(I|0);P=(M<<24>>24<0?11:3)+h|0;M=K&255;K=P&255;Q=r;while(1){if(!O){R=L;do{S=(R<<1)+l|0;T=(ab(c[277223]|0,Q)|0)+S|0;if((R|0)>=(f|0)&(P|0)>(d[(c[277219]|0)+T|0]|0)&(R|0)<(g|0)){U=b[(c[277225]|0)+(M<<1)>>1]|0;b[(c[277218]|0)+(T+1<<1)>>1]=U;T=(ab(c[277223]|0,Q)|0)+S|0;b[(c[277218]|0)+(T<<1)>>1]=U;U=S+1+(ab(c[277223]|0,Q)|0)|0;a[(c[277219]|0)+U|0]=K;U=(ab(c[277223]|0,Q)|0)+S|0;a[(c[277219]|0)+U|0]=K}R=R-1|0;}while((R|0)>=(I|0))}R=Q+1|0;if((R|0)<(w|0)){Q=R}else{N=j;break}}}else{N=J}}while(0);J=I+1|0;if((J|0)<(q|0)){x=x+E|0;A=A+F|0;z=N;I=J}else{break}}}else{if(!n){break}I=(r|0)>=(w|0);z=o;A=y;x=1;B=p;while(1){J=x-1&255;do{if(J<<24>>24==0){Q=z+D|0;K=Q>>8;M=A+C>>8;if((K|M)>>>0<1024){V=K<<1&14|M<<4&112|d[(c[263194]|0)+((M<<5&-256)+(Q>>10&-2))|0]<<7}else{if((a[1044415]|0)!=3){W=j;break}V=K<<1&14|M<<4&112}M=a[i+(V|1)|0]|0;K=M&127;if(K<<24>>24==0|I){W=j;break}Q=t+B|0;P=(Q|0)<(B|0);L=(M<<24>>24<0?11:3)+h|0;M=K&255;K=L&255;O=r;while(1){if(!P){R=Q;do{U=(R<<1)+l|0;S=(ab(c[277223]|0,O)|0)+U|0;if((R|0)>=(f|0)&(L|0)>(d[(c[277219]|0)+S|0]|0)&(R|0)<(g|0)){T=b[(c[277225]|0)+(M<<1)>>1]|0;b[(c[277218]|0)+(S+1<<1)>>1]=T;S=(ab(c[277223]|0,O)|0)+U|0;b[(c[277218]|0)+(S<<1)>>1]=T;T=U+1+(ab(c[277223]|0,O)|0)|0;a[(c[277219]|0)+T|0]=K;T=(ab(c[277223]|0,O)|0)+U|0;a[(c[277219]|0)+T|0]=K}R=R-1|0;}while((R|0)>=(B|0))}R=O+1|0;if((R|0)<(w|0)){O=R}else{W=j;break}}}else{W=J}}while(0);J=B+1|0;if((J|0)<(q|0)){z=z+E|0;A=A+F|0;x=W;B=J}else{break}}}}while(0);C=w+u|0;D=(ab(c[277223]|0,w)|0)+l|0;y=c[277231]|0;if(C>>>0>y>>>0){break}else{r=0;m=w;l=D;u=C;v=v+(w<<4)|0;k=y}}return}function UJ(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ac=0,ad=0,ae=0;i=c[263194]|0;c[277226]=1106168;c[277225]=(a[1108928]|0)!=0?1393712:1106168;j=c[277230]|0;if((a[1044434]|0)==0){k=j;l=1;m=0}else{n=d[1044432]|0;o=((j-(d[1044433]|0)|0)>>>0)%(n>>>0)|0;k=j-o|0;l=n;m=o}if((a[1044435]|0)==0){p=f;q=g;r=1}else{o=d[1044432]|0;n=g-1+o|0;p=f-((f|0)%(o|0)|0)|0;q=n-((n|0)%(o|0)|0)|0;r=o}o=c[277231]|0;if(k>>>0>o>>>0){return}n=(p|0)<(q|0);j=r&255;s=q-1|0;t=r-1|0;r=m;m=l;l=ab(c[277223]|0,k)|0;u=k;v=1097960+(k<<4)|0;k=o;while(1){if((m+u|0)>>>0>k>>>0){w=k+1-u|0}else{w=m}o=e[v+12>>1]<<19>>19;x=e[v+8>>1]<<19;y=e[v+10>>1]<<19;z=u+1|0;A=(e[v+14>>1]<<19>>19)-(y>>19)|0;B=(A&8192|0)!=0?A|-1024:A&1023;A=b[v+2>>1]|0;C=((a[1044414]|0)==0?z:z^255)&255;z=(ab(C,A)|0)&-64;D=z+(x>>11)+((ab(B,A)|0)&-64)|0;A=b[v+6>>1]|0;z=(ab(A,C)|0)&-64;C=z+(y>>11)+((ab(B,A)|0)&-64)|0;A=b[v>>1]|0;if((a[1044413]|0)==0){B=b[v+4>>1]|0;E=A;F=B<<16>>16;G=p;H=B}else{B=b[v+4>>1]|0;E=-A|0;F=-(B<<16>>16)|0;G=s;H=B}B=o-(x>>19)|0;x=(B&8192|0)!=0?B|-1024:B&1023;B=ab(G,A)|0;o=B+((ab(A,x)|0)&-64)|0;A=H<<16>>16;B=ab(A,G)|0;y=((ab(A,x)|0)&-64)+B|0;do{if((a[1044415]|0)==0){if(!n){break}B=(r|0)>=(w|0);x=o;A=y;z=1;I=p;while(1){J=z-1&255;do{if(J<<24>>24==0){K=x+D|0;L=(A+C|0)>>>8;M=a[i+(L<<4&112|K>>>8<<1&14|d[(c[263194]|0)+(L<<5&32512|K>>>10&254)|0]<<7|1)|0]|0;K=M&127;if(K<<24>>24==0|B){N=j;break}L=t+I|0;O=(L|0)<(I|0);P=(M<<24>>24<0?11:3)+h|0;M=K&255;K=P&255;Q=r;while(1){if(!O){R=L;do{S=(R<<1)+l|0;T=ab(c[277223]|0,Q)|0;U=T+S|0;if((R|0)>=(f|0)&(P|0)>(d[(c[277219]|0)+U|0]|0)&(R|0)<(g|0)){V=e[(c[277225]|0)+(M<<1)>>1]|0;W=(a[(c[277215]|0)+U|0]&32)==0;if(W){X=c[277228]|0;Y=X;Z=X&-2082}else{X=e[(c[277213]|0)+(U<<1)>>1]|0;Y=X;Z=X&63454}if(W){_=c[277228]|0}else{_=e[(c[277213]|0)+(U<<1)>>1]|0}U=((_^V)&2081|e[(c[277220]|0)+((V&2081&Y)+((Z+(V&63454)|0)>>>1)<<1)>>1])&65535;V=S+1|0;b[(c[277218]|0)+(V+T<<1)>>1]=U;T=(ab(c[277223]|0,Q)|0)+S|0;b[(c[277218]|0)+(T<<1)>>1]=U;U=(ab(c[277223]|0,Q)|0)+V|0;a[(c[277219]|0)+U|0]=K;U=(ab(c[277223]|0,Q)|0)+S|0;a[(c[277219]|0)+U|0]=K}R=R-1|0;}while((R|0)>=(I|0))}R=Q+1|0;if((R|0)<(w|0)){Q=R}else{N=j;break}}}else{N=J}}while(0);J=I+1|0;if((J|0)<(q|0)){x=x+E|0;A=A+F|0;z=N;I=J}else{break}}}else{if(!n){break}I=(r|0)>=(w|0);z=o;A=y;x=1;B=p;while(1){J=x-1&255;do{if(J<<24>>24==0){Q=z+D|0;K=Q>>8;M=A+C>>8;if((K|M)>>>0<1024){$=K<<1&14|M<<4&112|d[(c[263194]|0)+((M<<5&-256)+(Q>>10&-2))|0]<<7}else{if((a[1044415]|0)!=3){aa=j;break}$=K<<1&14|M<<4&112}M=a[i+($|1)|0]|0;K=M&127;if(K<<24>>24==0|I){aa=j;break}Q=t+B|0;P=(Q|0)<(B|0);L=(M<<24>>24<0?11:3)+h|0;M=K&255;K=L&255;O=r;while(1){if(!P){R=Q;do{U=(R<<1)+l|0;S=ab(c[277223]|0,O)|0;V=S+U|0;if((R|0)>=(f|0)&(L|0)>(d[(c[277219]|0)+V|0]|0)&(R|0)<(g|0)){T=e[(c[277225]|0)+(M<<1)>>1]|0;W=(a[(c[277215]|0)+V|0]&32)==0;if(W){X=c[277228]|0;ac=X;ad=X&-2082}else{X=e[(c[277213]|0)+(V<<1)>>1]|0;ac=X;ad=X&63454}if(W){ae=c[277228]|0}else{ae=e[(c[277213]|0)+(V<<1)>>1]|0}V=((ae^T)&2081|e[(c[277220]|0)+((T&2081&ac)+((ad+(T&63454)|0)>>>1)<<1)>>1])&65535;T=U+1|0;b[(c[277218]|0)+(T+S<<1)>>1]=V;S=(ab(c[277223]|0,O)|0)+U|0;b[(c[277218]|0)+(S<<1)>>1]=V;V=(ab(c[277223]|0,O)|0)+T|0;a[(c[277219]|0)+V|0]=K;V=(ab(c[277223]|0,O)|0)+U|0;a[(c[277219]|0)+V|0]=K}R=R-1|0;}while((R|0)>=(B|0))}R=O+1|0;if((R|0)<(w|0)){O=R}else{aa=j;break}}}else{aa=J}}while(0);J=B+1|0;if((J|0)<(q|0)){z=z+E|0;A=A+F|0;x=aa;B=J}else{break}}}}while(0);C=w+u|0;D=(ab(c[277223]|0,w)|0)+l|0;y=c[277231]|0;if(C>>>0>y>>>0){break}else{r=0;m=w;l=D;u=C;v=v+(w<<4)|0;k=y}}return}function UK(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;i=c[263194]|0;c[277226]=1106168;c[277225]=(a[1108928]|0)!=0?1393712:1106168;j=c[277230]|0;if((a[1044434]|0)==0){k=j;l=1;m=0}else{n=d[1044432]|0;o=((j-(d[1044433]|0)|0)>>>0)%(n>>>0)|0;k=j-o|0;l=n;m=o}if((a[1044435]|0)==0){p=f;q=g;r=1}else{o=d[1044432]|0;n=g-1+o|0;p=f-((f|0)%(o|0)|0)|0;q=n-((n|0)%(o|0)|0)|0;r=o}o=c[277231]|0;if(k>>>0>o>>>0){return}n=(p|0)<(q|0);j=r&255;s=q-1|0;t=r-1|0;r=m;m=l;l=ab(c[277223]|0,k)|0;u=k;v=1097960+(k<<4)|0;k=o;while(1){if((m+u|0)>>>0>k>>>0){w=k+1-u|0}else{w=m}o=e[v+12>>1]<<19>>19;x=e[v+8>>1]<<19;y=e[v+10>>1]<<19;z=u+1|0;A=(e[v+14>>1]<<19>>19)-(y>>19)|0;B=(A&8192|0)!=0?A|-1024:A&1023;A=b[v+2>>1]|0;C=((a[1044414]|0)==0?z:z^255)&255;z=(ab(C,A)|0)&-64;D=z+(x>>11)+((ab(B,A)|0)&-64)|0;A=b[v+6>>1]|0;z=(ab(A,C)|0)&-64;C=z+(y>>11)+((ab(B,A)|0)&-64)|0;A=b[v>>1]|0;if((a[1044413]|0)==0){B=b[v+4>>1]|0;E=A;F=B<<16>>16;G=p;H=B}else{B=b[v+4>>1]|0;E=-A|0;F=-(B<<16>>16)|0;G=s;H=B}B=o-(x>>19)|0;x=(B&8192|0)!=0?B|-1024:B&1023;B=ab(G,A)|0;o=B+((ab(A,x)|0)&-64)|0;A=H<<16>>16;B=ab(A,G)|0;y=((ab(A,x)|0)&-64)+B|0;do{if((a[1044415]|0)==0){if(!n){break}B=(r|0)>=(w|0);x=o;A=y;z=1;I=p;while(1){J=z-1&255;do{if(J<<24>>24==0){K=x+D|0;L=(A+C|0)>>>8;M=a[i+(L<<4&112|K>>>8<<1&14|d[(c[263194]|0)+(L<<5&32512|K>>>10&254)|0]<<7|1)|0]|0;K=M&127;if(K<<24>>24==0|B){N=j;break}L=t+I|0;O=(L|0)<(I|0);P=(M<<24>>24<0?11:3)+h|0;M=K&255;K=P&255;Q=r;while(1){if(!O){R=L;do{S=(R<<1)+l|0;T=ab(c[277223]|0,Q)|0;if((R|0)>=(f|0)&(P|0)>(d[(c[277219]|0)+(T+S)|0]|0)&(R|0)<(g|0)){U=e[(c[277225]|0)+(M<<1)>>1]|0;V=c[277228]|0;W=(((U&63454)+(V&-2082)|0)>>>1)+(V&2081&U)|0;if((a[1108928]|0)==0){X=W&65535}else{X=(e[(c[277220]|0)+(W<<1)>>1]|(U^V)&2081)&65535}V=S+1|0;b[(c[277218]|0)+(V+T<<1)>>1]=X;T=(ab(c[277223]|0,Q)|0)+S|0;b[(c[277218]|0)+(T<<1)>>1]=X;T=(ab(c[277223]|0,Q)|0)+V|0;a[(c[277219]|0)+T|0]=K;T=(ab(c[277223]|0,Q)|0)+S|0;a[(c[277219]|0)+T|0]=K}R=R-1|0;}while((R|0)>=(I|0))}R=Q+1|0;if((R|0)<(w|0)){Q=R}else{N=j;break}}}else{N=J}}while(0);J=I+1|0;if((J|0)<(q|0)){x=x+E|0;A=A+F|0;z=N;I=J}else{break}}}else{if(!n){break}I=(r|0)>=(w|0);z=o;A=y;x=1;B=p;while(1){J=x-1&255;do{if(J<<24>>24==0){Q=z+D|0;K=Q>>8;M=A+C>>8;if((K|M)>>>0<1024){Y=K<<1&14|M<<4&112|d[(c[263194]|0)+((M<<5&-256)+(Q>>10&-2))|0]<<7}else{if((a[1044415]|0)!=3){Z=j;break}Y=K<<1&14|M<<4&112}M=a[i+(Y|1)|0]|0;K=M&127;if(K<<24>>24==0|I){Z=j;break}Q=t+B|0;P=(Q|0)<(B|0);L=(M<<24>>24<0?11:3)+h|0;M=K&255;K=L&255;O=r;while(1){if(!P){R=Q;do{T=(R<<1)+l|0;S=ab(c[277223]|0,O)|0;if((R|0)>=(f|0)&(L|0)>(d[(c[277219]|0)+(S+T)|0]|0)&(R|0)<(g|0)){V=e[(c[277225]|0)+(M<<1)>>1]|0;U=c[277228]|0;W=(((V&63454)+(U&-2082)|0)>>>1)+(U&2081&V)|0;if((a[1108928]|0)==0){_=W&65535}else{_=(e[(c[277220]|0)+(W<<1)>>1]|(V^U)&2081)&65535}U=T+1|0;b[(c[277218]|0)+(U+S<<1)>>1]=_;S=(ab(c[277223]|0,O)|0)+T|0;b[(c[277218]|0)+(S<<1)>>1]=_;S=(ab(c[277223]|0,O)|0)+U|0;a[(c[277219]|0)+S|0]=K;S=(ab(c[277223]|0,O)|0)+T|0;a[(c[277219]|0)+S|0]=K}R=R-1|0;}while((R|0)>=(B|0))}R=O+1|0;if((R|0)<(w|0)){O=R}else{Z=j;break}}}else{Z=J}}while(0);J=B+1|0;if((J|0)<(q|0)){z=z+E|0;A=A+F|0;x=Z;B=J}else{break}}}}while(0);C=w+u|0;D=(ab(c[277223]|0,w)|0)+l|0;y=c[277231]|0;if(C>>>0>y>>>0){break}else{r=0;m=w;l=D;u=C;v=v+(w<<4)|0;k=y}}return}function UL(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0;i=c[263194]|0;c[277226]=1106168;c[277225]=(a[1108928]|0)!=0?1393712:1106168;j=c[277230]|0;if((a[1044434]|0)==0){k=j;l=1;m=0}else{n=d[1044432]|0;o=((j-(d[1044433]|0)|0)>>>0)%(n>>>0)|0;k=j-o|0;l=n;m=o}if((a[1044435]|0)==0){p=f;q=g;r=1}else{o=d[1044432]|0;n=g-1+o|0;p=f-((f|0)%(o|0)|0)|0;q=n-((n|0)%(o|0)|0)|0;r=o}o=c[277231]|0;if(k>>>0>o>>>0){return}n=(p|0)<(q|0);j=r&255;s=q-1|0;t=r-1|0;r=m;m=l;l=ab(c[277223]|0,k)|0;u=k;v=1097960+(k<<4)|0;k=o;while(1){if((m+u|0)>>>0>k>>>0){w=k+1-u|0}else{w=m}o=e[v+12>>1]<<19>>19;x=e[v+8>>1]<<19;y=e[v+10>>1]<<19;z=u+1|0;A=(e[v+14>>1]<<19>>19)-(y>>19)|0;B=(A&8192|0)!=0?A|-1024:A&1023;A=b[v+2>>1]|0;C=((a[1044414]|0)==0?z:z^255)&255;z=(ab(C,A)|0)&-64;D=z+(x>>11)+((ab(B,A)|0)&-64)|0;A=b[v+6>>1]|0;z=(ab(A,C)|0)&-64;C=z+(y>>11)+((ab(B,A)|0)&-64)|0;A=b[v>>1]|0;if((a[1044413]|0)==0){B=b[v+4>>1]|0;E=A;F=B<<16>>16;G=p;H=B}else{B=b[v+4>>1]|0;E=-A|0;F=-(B<<16>>16)|0;G=s;H=B}B=o-(x>>19)|0;x=(B&8192|0)!=0?B|-1024:B&1023;B=ab(G,A)|0;o=B+((ab(A,x)|0)&-64)|0;A=H<<16>>16;B=ab(A,G)|0;y=((ab(A,x)|0)&-64)+B|0;do{if((a[1044415]|0)==0){if(!n){break}B=(r|0)>=(w|0);x=o;A=y;z=1;I=p;while(1){J=z-1&255;do{if(J<<24>>24==0){K=x+D|0;L=(A+C|0)>>>8;M=a[i+(L<<4&112|K>>>8<<1&14|d[(c[263194]|0)+(L<<5&32512|K>>>10&254)|0]<<7|1)|0]|0;K=M&127;if(K<<24>>24==0|B){N=j;break}L=t+I|0;O=(L|0)<(I|0);P=(M<<24>>24<0?11:3)+h|0;M=K&255;K=P&255;Q=r;while(1){if(!O){R=L;do{S=(R<<1)+l|0;T=ab(c[277223]|0,Q)|0;U=T+S|0;if((R|0)>=(f|0)&(P|0)>(d[(c[277219]|0)+U|0]|0)&(R|0)<(g|0)){do{if((a[1108928]|0)==0){V=b[(c[277225]|0)+(M<<1)>>1]|0;W=V&65535;X=W&63454;if((a[(c[277215]|0)+U|0]&32)==0){Y=c[277228]|0;Z=(e[(c[277220]|0)+((((Y&-2082)+X|0)>>>1)+(W&2081&Y)<<1)>>1]|(Y^W)&2081)&65535;break}else{W=b[(c[277213]|0)+(U<<1)>>1]|0;Z=(((W&63454)+X|0)>>>1)+(W&V&2081)&65535;break}}else{V=e[(c[277225]|0)+(M<<1)>>1]|0;W=(a[(c[277215]|0)+U|0]&32)==0;if(W){X=c[277228]|0;_=X;$=X&-2082}else{X=e[(c[277213]|0)+(U<<1)>>1]|0;_=X;$=X&63454}if(W){aa=c[277228]|0}else{aa=e[(c[277213]|0)+(U<<1)>>1]|0}Z=((aa^V)&2081|e[(c[277220]|0)+((V&2081&_)+(($+(V&63454)|0)>>>1)<<1)>>1])&65535}}while(0);U=S+1|0;b[(c[277218]|0)+(U+T<<1)>>1]=Z;V=(ab(c[277223]|0,Q)|0)+S|0;b[(c[277218]|0)+(V<<1)>>1]=Z;V=(ab(c[277223]|0,Q)|0)+U|0;a[(c[277219]|0)+V|0]=K;V=(ab(c[277223]|0,Q)|0)+S|0;a[(c[277219]|0)+V|0]=K}R=R-1|0;}while((R|0)>=(I|0))}R=Q+1|0;if((R|0)<(w|0)){Q=R}else{N=j;break}}}else{N=J}}while(0);J=I+1|0;if((J|0)<(q|0)){x=x+E|0;A=A+F|0;z=N;I=J}else{break}}}else{if(!n){break}I=(r|0)>=(w|0);z=o;A=y;x=1;B=p;while(1){J=x-1&255;do{if(J<<24>>24==0){Q=z+D|0;K=Q>>8;M=A+C>>8;if((K|M)>>>0<1024){ac=K<<1&14|M<<4&112|d[(c[263194]|0)+((M<<5&-256)+(Q>>10&-2))|0]<<7}else{if((a[1044415]|0)!=3){ad=j;break}ac=K<<1&14|M<<4&112}M=a[i+(ac|1)|0]|0;K=M&127;if(K<<24>>24==0|I){ad=j;break}Q=t+B|0;P=(Q|0)<(B|0);L=(M<<24>>24<0?11:3)+h|0;M=K&255;K=L&255;O=r;while(1){if(!P){R=Q;do{V=(R<<1)+l|0;U=ab(c[277223]|0,O)|0;W=U+V|0;if((R|0)>=(f|0)&(L|0)>(d[(c[277219]|0)+W|0]|0)&(R|0)<(g|0)){do{if((a[1108928]|0)==0){X=b[(c[277225]|0)+(M<<1)>>1]|0;Y=X&65535;ae=Y&63454;if((a[(c[277215]|0)+W|0]&32)==0){af=c[277228]|0;ag=(e[(c[277220]|0)+((((af&-2082)+ae|0)>>>1)+(Y&2081&af)<<1)>>1]|(af^Y)&2081)&65535;break}else{Y=b[(c[277213]|0)+(W<<1)>>1]|0;ag=(((Y&63454)+ae|0)>>>1)+(Y&X&2081)&65535;break}}else{X=e[(c[277225]|0)+(M<<1)>>1]|0;Y=(a[(c[277215]|0)+W|0]&32)==0;if(Y){ae=c[277228]|0;ah=ae;ai=ae&-2082}else{ae=e[(c[277213]|0)+(W<<1)>>1]|0;ah=ae;ai=ae&63454}if(Y){aj=c[277228]|0}else{aj=e[(c[277213]|0)+(W<<1)>>1]|0}ag=((aj^X)&2081|e[(c[277220]|0)+((X&2081&ah)+((ai+(X&63454)|0)>>>1)<<1)>>1])&65535}}while(0);W=V+1|0;b[(c[277218]|0)+(W+U<<1)>>1]=ag;S=(ab(c[277223]|0,O)|0)+V|0;b[(c[277218]|0)+(S<<1)>>1]=ag;S=(ab(c[277223]|0,O)|0)+W|0;a[(c[277219]|0)+S|0]=K;S=(ab(c[277223]|0,O)|0)+V|0;a[(c[277219]|0)+S|0]=K}R=R-1|0;}while((R|0)>=(B|0))}R=O+1|0;if((R|0)<(w|0)){O=R}else{ad=j;break}}}else{ad=J}}while(0);J=B+1|0;if((J|0)<(q|0)){z=z+E|0;A=A+F|0;x=ad;B=J}else{break}}}}while(0);C=w+u|0;D=(ab(c[277223]|0,w)|0)+l|0;y=c[277231]|0;if(C>>>0>y>>>0){break}else{r=0;m=w;l=D;u=C;v=v+(w<<4)|0;k=y}}return}function UM(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ac=0,ad=0,ae=0;i=c[263194]|0;c[277226]=1106168;c[277225]=(a[1108928]|0)!=0?1393712:1106168;j=c[277230]|0;if((a[1044434]|0)==0){k=j;l=1;m=0}else{n=d[1044432]|0;o=((j-(d[1044433]|0)|0)>>>0)%(n>>>0)|0;k=j-o|0;l=n;m=o}if((a[1044435]|0)==0){p=f;q=g;r=1}else{o=d[1044432]|0;n=g-1+o|0;p=f-((f|0)%(o|0)|0)|0;q=n-((n|0)%(o|0)|0)|0;r=o}o=c[277231]|0;if(k>>>0>o>>>0){return}n=(p|0)<(q|0);j=r&255;s=q-1|0;t=r-1|0;r=m;m=l;l=ab(c[277223]|0,k)|0;u=k;v=1097960+(k<<4)|0;k=o;while(1){if((m+u|0)>>>0>k>>>0){w=k+1-u|0}else{w=m}o=e[v+12>>1]<<19>>19;x=e[v+8>>1]<<19;y=e[v+10>>1]<<19;z=u+1|0;A=(e[v+14>>1]<<19>>19)-(y>>19)|0;B=(A&8192|0)!=0?A|-1024:A&1023;A=b[v+2>>1]|0;C=((a[1044414]|0)==0?z:z^255)&255;z=(ab(C,A)|0)&-64;D=z+(x>>11)+((ab(B,A)|0)&-64)|0;A=b[v+6>>1]|0;z=(ab(A,C)|0)&-64;C=z+(y>>11)+((ab(B,A)|0)&-64)|0;A=b[v>>1]|0;if((a[1044413]|0)==0){B=b[v+4>>1]|0;E=A;F=B<<16>>16;G=p;H=B}else{B=b[v+4>>1]|0;E=-A|0;F=-(B<<16>>16)|0;G=s;H=B}B=o-(x>>19)|0;x=(B&8192|0)!=0?B|-1024:B&1023;B=ab(G,A)|0;o=B+((ab(A,x)|0)&-64)|0;A=H<<16>>16;B=ab(A,G)|0;y=((ab(A,x)|0)&-64)+B|0;do{if((a[1044415]|0)==0){if(!n){break}B=(r|0)>=(w|0);x=o;A=y;z=1;I=p;while(1){J=z-1&255;do{if(J<<24>>24==0){K=x+D|0;L=(A+C|0)>>>8;M=a[i+(L<<4&112|K>>>8<<1&14|d[(c[263194]|0)+(L<<5&32512|K>>>10&254)|0]<<7|1)|0]|0;K=M&127;if(K<<24>>24==0|B){N=j;break}L=t+I|0;O=(L|0)<(I|0);P=(M<<24>>24<0?11:3)+h|0;M=K&255;K=P&255;Q=r;while(1){if(!O){R=L;do{S=(R<<1)+l|0;T=ab(c[277223]|0,Q)|0;U=T+S|0;if((R|0)>=(f|0)&(P|0)>(d[(c[277219]|0)+U|0]|0)&(R|0)<(g|0)){V=b[(c[277225]|0)+(M<<1)>>1]|0;if((a[(c[277215]|0)+U|0]&32)==0){W=c[277228]&65535}else{W=b[(c[277213]|0)+(U<<1)>>1]|0}U=V&-2048;X=W&-2048;Y=(U&65535)>(X&65535)?U-X&65535:0;X=V&2016;U=W&2016;if((X&65535)>(U&65535)){Z=(X-U&65535)+Y&65535}else{Z=Y}Y=V&31;V=W&31;if((Y&65535)>(V&65535)){_=(Y-V&65535)+Z&65535}else{_=Z}V=S+1|0;b[(c[277218]|0)+(V+T<<1)>>1]=_;T=(ab(c[277223]|0,Q)|0)+S|0;b[(c[277218]|0)+(T<<1)>>1]=_;T=(ab(c[277223]|0,Q)|0)+V|0;a[(c[277219]|0)+T|0]=K;T=(ab(c[277223]|0,Q)|0)+S|0;a[(c[277219]|0)+T|0]=K}R=R-1|0;}while((R|0)>=(I|0))}R=Q+1|0;if((R|0)<(w|0)){Q=R}else{N=j;break}}}else{N=J}}while(0);J=I+1|0;if((J|0)<(q|0)){x=x+E|0;A=A+F|0;z=N;I=J}else{break}}}else{if(!n){break}I=(r|0)>=(w|0);z=o;A=y;x=1;B=p;while(1){J=x-1&255;do{if(J<<24>>24==0){Q=z+D|0;K=Q>>8;M=A+C>>8;if((K|M)>>>0<1024){$=K<<1&14|M<<4&112|d[(c[263194]|0)+((M<<5&-256)+(Q>>10&-2))|0]<<7}else{if((a[1044415]|0)!=3){aa=j;break}$=K<<1&14|M<<4&112}M=a[i+($|1)|0]|0;K=M&127;if(K<<24>>24==0|I){aa=j;break}Q=t+B|0;P=(Q|0)<(B|0);L=(M<<24>>24<0?11:3)+h|0;M=K&255;K=L&255;O=r;while(1){if(!P){R=Q;do{T=(R<<1)+l|0;S=ab(c[277223]|0,O)|0;V=S+T|0;if((R|0)>=(f|0)&(L|0)>(d[(c[277219]|0)+V|0]|0)&(R|0)<(g|0)){Y=b[(c[277225]|0)+(M<<1)>>1]|0;if((a[(c[277215]|0)+V|0]&32)==0){ac=c[277228]&65535}else{ac=b[(c[277213]|0)+(V<<1)>>1]|0}V=Y&-2048;U=ac&-2048;X=(V&65535)>(U&65535)?V-U&65535:0;U=Y&2016;V=ac&2016;if((U&65535)>(V&65535)){ad=(U-V&65535)+X&65535}else{ad=X}X=Y&31;Y=ac&31;if((X&65535)>(Y&65535)){ae=(X-Y&65535)+ad&65535}else{ae=ad}Y=T+1|0;b[(c[277218]|0)+(Y+S<<1)>>1]=ae;S=(ab(c[277223]|0,O)|0)+T|0;b[(c[277218]|0)+(S<<1)>>1]=ae;S=(ab(c[277223]|0,O)|0)+Y|0;a[(c[277219]|0)+S|0]=K;S=(ab(c[277223]|0,O)|0)+T|0;a[(c[277219]|0)+S|0]=K}R=R-1|0;}while((R|0)>=(B|0))}R=O+1|0;if((R|0)<(w|0)){O=R}else{aa=j;break}}}else{aa=J}}while(0);J=B+1|0;if((J|0)<(q|0)){z=z+E|0;A=A+F|0;x=aa;B=J}else{break}}}}while(0);C=w+u|0;D=(ab(c[277223]|0,w)|0)+l|0;y=c[277231]|0;if(C>>>0>y>>>0){break}else{r=0;m=w;l=D;u=C;v=v+(w<<4)|0;k=y}}return}function UN(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ac=0,ad=0,ae=0,af=0;i=c[263194]|0;c[277226]=1106168;c[277225]=(a[1108928]|0)!=0?1393712:1106168;j=c[277230]|0;if((a[1044434]|0)==0){k=j;l=1;m=0}else{n=d[1044432]|0;o=((j-(d[1044433]|0)|0)>>>0)%(n>>>0)|0;k=j-o|0;l=n;m=o}if((a[1044435]|0)==0){p=f;q=g;r=1}else{o=d[1044432]|0;n=g-1+o|0;p=f-((f|0)%(o|0)|0)|0;q=n-((n|0)%(o|0)|0)|0;r=o}o=c[277231]|0;if(k>>>0>o>>>0){return}n=(p|0)<(q|0);j=r&255;s=q-1|0;t=r-1|0;r=m;m=l;l=ab(c[277223]|0,k)|0;u=k;v=1097960+(k<<4)|0;k=o;while(1){if((m+u|0)>>>0>k>>>0){w=k+1-u|0}else{w=m}o=e[v+12>>1]<<19>>19;x=e[v+8>>1]<<19;y=e[v+10>>1]<<19;z=u+1|0;A=(e[v+14>>1]<<19>>19)-(y>>19)|0;B=(A&8192|0)!=0?A|-1024:A&1023;A=b[v+2>>1]|0;C=((a[1044414]|0)==0?z:z^255)&255;z=(ab(C,A)|0)&-64;D=z+(x>>11)+((ab(B,A)|0)&-64)|0;A=b[v+6>>1]|0;z=(ab(A,C)|0)&-64;C=z+(y>>11)+((ab(B,A)|0)&-64)|0;A=b[v>>1]|0;if((a[1044413]|0)==0){B=b[v+4>>1]|0;E=A;F=B<<16>>16;G=p;H=B}else{B=b[v+4>>1]|0;E=-A|0;F=-(B<<16>>16)|0;G=s;H=B}B=o-(x>>19)|0;x=(B&8192|0)!=0?B|-1024:B&1023;B=ab(G,A)|0;o=B+((ab(A,x)|0)&-64)|0;A=H<<16>>16;B=ab(A,G)|0;y=((ab(A,x)|0)&-64)+B|0;do{if((a[1044415]|0)==0){if(!n){break}B=(r|0)>=(w|0);x=o;A=y;z=1;I=p;while(1){J=z-1&255;do{if(J<<24>>24==0){K=x+D|0;L=(A+C|0)>>>8;M=a[i+(L<<4&112|K>>>8<<1&14|d[(c[263194]|0)+(L<<5&32512|K>>>10&254)|0]<<7|1)|0]|0;K=M&127;if(K<<24>>24==0|B){N=j;break}L=t+I|0;O=(L|0)<(I|0);P=(M<<24>>24<0?11:3)+h|0;M=K&255;K=P&255;Q=r;while(1){if(!O){R=L;do{S=(R<<1)+l|0;T=ab(c[277223]|0,Q)|0;if((R|0)>=(f|0)&(P|0)>(d[(c[277219]|0)+(T+S)|0]|0)&(R|0)<(g|0)){U=b[(c[277225]|0)+(M<<1)>>1]|0;do{if((a[1108928]|0)==0){V=b[(c[277221]|0)+(((U&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{W=c[277228]&65535;X=U&-2048;Y=W&-2048;Z=(X&65535)>(Y&65535)?X-Y&65535:0;Y=U&2016;X=W&2016;if((Y&65535)>(X&65535)){_=(Y-X&65535)+Z&65535}else{_=Z}Z=U&31;X=W&31;if((Z&65535)<=(X&65535)){V=_;break}V=(Z-X&65535)+_&65535}}while(0);U=S+1|0;b[(c[277218]|0)+(U+T<<1)>>1]=V;X=(ab(c[277223]|0,Q)|0)+S|0;b[(c[277218]|0)+(X<<1)>>1]=V;X=(ab(c[277223]|0,Q)|0)+U|0;a[(c[277219]|0)+X|0]=K;X=(ab(c[277223]|0,Q)|0)+S|0;a[(c[277219]|0)+X|0]=K}R=R-1|0;}while((R|0)>=(I|0))}R=Q+1|0;if((R|0)<(w|0)){Q=R}else{N=j;break}}}else{N=J}}while(0);J=I+1|0;if((J|0)<(q|0)){x=x+E|0;A=A+F|0;z=N;I=J}else{break}}}else{if(!n){break}I=(r|0)>=(w|0);z=o;A=y;x=1;B=p;while(1){J=x-1&255;do{if(J<<24>>24==0){Q=z+D|0;K=Q>>8;M=A+C>>8;if((K|M)>>>0<1024){$=K<<1&14|M<<4&112|d[(c[263194]|0)+((M<<5&-256)+(Q>>10&-2))|0]<<7}else{if((a[1044415]|0)!=3){aa=j;break}$=K<<1&14|M<<4&112}M=a[i+($|1)|0]|0;K=M&127;if(K<<24>>24==0|I){aa=j;break}Q=t+B|0;P=(Q|0)<(B|0);L=(M<<24>>24<0?11:3)+h|0;M=K&255;K=L&255;O=r;while(1){if(!P){R=Q;do{X=(R<<1)+l|0;U=ab(c[277223]|0,O)|0;if((R|0)>=(f|0)&(L|0)>(d[(c[277219]|0)+(U+X)|0]|0)&(R|0)<(g|0)){Z=b[(c[277225]|0)+(M<<1)>>1]|0;do{if((a[1108928]|0)==0){ac=b[(c[277221]|0)+(((Z&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{W=c[277228]&65535;Y=Z&-2048;ad=W&-2048;ae=(Y&65535)>(ad&65535)?Y-ad&65535:0;ad=Z&2016;Y=W&2016;if((ad&65535)>(Y&65535)){af=(ad-Y&65535)+ae&65535}else{af=ae}ae=Z&31;Y=W&31;if((ae&65535)<=(Y&65535)){ac=af;break}ac=(ae-Y&65535)+af&65535}}while(0);Z=X+1|0;b[(c[277218]|0)+(Z+U<<1)>>1]=ac;S=(ab(c[277223]|0,O)|0)+X|0;b[(c[277218]|0)+(S<<1)>>1]=ac;S=(ab(c[277223]|0,O)|0)+Z|0;a[(c[277219]|0)+S|0]=K;S=(ab(c[277223]|0,O)|0)+X|0;a[(c[277219]|0)+S|0]=K}R=R-1|0;}while((R|0)>=(B|0))}R=O+1|0;if((R|0)<(w|0)){O=R}else{aa=j;break}}}else{aa=J}}while(0);J=B+1|0;if((J|0)<(q|0)){z=z+E|0;A=A+F|0;x=aa;B=J}else{break}}}}while(0);C=w+u|0;D=(ab(c[277223]|0,w)|0)+l|0;y=c[277231]|0;if(C>>>0>y>>>0){break}else{r=0;m=w;l=D;u=C;v=v+(w<<4)|0;k=y}}return}function UO(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0;i=c[263194]|0;c[277226]=1106168;c[277225]=(a[1108928]|0)!=0?1393712:1106168;j=c[277230]|0;if((a[1044434]|0)==0){k=j;l=1;m=0}else{n=d[1044432]|0;o=((j-(d[1044433]|0)|0)>>>0)%(n>>>0)|0;k=j-o|0;l=n;m=o}if((a[1044435]|0)==0){p=f;q=g;r=1}else{o=d[1044432]|0;n=g-1+o|0;p=f-((f|0)%(o|0)|0)|0;q=n-((n|0)%(o|0)|0)|0;r=o}o=c[277231]|0;if(k>>>0>o>>>0){return}n=(p|0)<(q|0);j=r&255;s=q-1|0;t=r-1|0;r=m;m=l;l=ab(c[277223]|0,k)|0;u=k;v=1097960+(k<<4)|0;k=o;while(1){if((m+u|0)>>>0>k>>>0){w=k+1-u|0}else{w=m}o=e[v+12>>1]<<19>>19;x=e[v+8>>1]<<19;y=e[v+10>>1]<<19;z=u+1|0;A=(e[v+14>>1]<<19>>19)-(y>>19)|0;B=(A&8192|0)!=0?A|-1024:A&1023;A=b[v+2>>1]|0;C=((a[1044414]|0)==0?z:z^255)&255;z=(ab(C,A)|0)&-64;D=z+(x>>11)+((ab(B,A)|0)&-64)|0;A=b[v+6>>1]|0;z=(ab(A,C)|0)&-64;C=z+(y>>11)+((ab(B,A)|0)&-64)|0;A=b[v>>1]|0;if((a[1044413]|0)==0){B=b[v+4>>1]|0;E=A;F=B<<16>>16;G=p;H=B}else{B=b[v+4>>1]|0;E=-A|0;F=-(B<<16>>16)|0;G=s;H=B}B=o-(x>>19)|0;x=(B&8192|0)!=0?B|-1024:B&1023;B=ab(G,A)|0;o=B+((ab(A,x)|0)&-64)|0;A=H<<16>>16;B=ab(A,G)|0;y=((ab(A,x)|0)&-64)+B|0;do{if((a[1044415]|0)==0){if(!n){break}B=(r|0)>=(w|0);x=o;A=y;z=1;I=p;while(1){J=z-1&255;do{if(J<<24>>24==0){K=x+D|0;L=(A+C|0)>>>8;M=a[i+(L<<4&112|K>>>8<<1&14|d[(c[263194]|0)+(L<<5&32512|K>>>10&254)|0]<<7|1)|0]|0;K=M&127;if(K<<24>>24==0|B){N=j;break}L=t+I|0;O=(L|0)<(I|0);P=(M<<24>>24<0?11:3)+h|0;M=K&255;K=P&255;Q=r;while(1){if(!O){R=L;do{S=(R<<1)+l|0;T=ab(c[277223]|0,Q)|0;U=T+S|0;if((R|0)>=(f|0)&(P|0)>(d[(c[277219]|0)+U|0]|0)&(R|0)<(g|0)){do{if((a[1108928]|0)==0){V=b[(c[277225]|0)+(M<<1)>>1]|0;if((a[(c[277215]|0)+U|0]&32)!=0){W=b[(c[277221]|0)+((V&65535|67616)-(b[(c[277213]|0)+(U<<1)>>1]&63454)>>1<<1)>>1]|0;break}X=c[277228]&65535;Y=V&-2048;Z=X&-2048;_=(Y&65535)>(Z&65535)?Y-Z&65535:0;Z=V&2016;Y=X&2016;if((Z&65535)>(Y&65535)){$=(Z-Y&65535)+_&65535}else{$=_}_=V&31;V=X&31;if((_&65535)<=(V&65535)){W=$;break}W=(_-V&65535)+$&65535}else{V=b[(c[277225]|0)+(M<<1)>>1]|0;if((a[(c[277215]|0)+U|0]&32)==0){aa=c[277228]&65535}else{aa=b[(c[277213]|0)+(U<<1)>>1]|0}_=V&-2048;X=aa&-2048;Y=(_&65535)>(X&65535)?_-X&65535:0;X=V&2016;_=aa&2016;if((X&65535)>(_&65535)){ac=(X-_&65535)+Y&65535}else{ac=Y}Y=V&31;V=aa&31;if((Y&65535)<=(V&65535)){W=ac;break}W=(Y-V&65535)+ac&65535}}while(0);U=S+1|0;b[(c[277218]|0)+(U+T<<1)>>1]=W;V=(ab(c[277223]|0,Q)|0)+S|0;b[(c[277218]|0)+(V<<1)>>1]=W;V=(ab(c[277223]|0,Q)|0)+U|0;a[(c[277219]|0)+V|0]=K;V=(ab(c[277223]|0,Q)|0)+S|0;a[(c[277219]|0)+V|0]=K}R=R-1|0;}while((R|0)>=(I|0))}R=Q+1|0;if((R|0)<(w|0)){Q=R}else{N=j;break}}}else{N=J}}while(0);J=I+1|0;if((J|0)<(q|0)){x=x+E|0;A=A+F|0;z=N;I=J}else{break}}}else{if(!n){break}I=(r|0)>=(w|0);z=o;A=y;x=1;B=p;while(1){J=x-1&255;do{if(J<<24>>24==0){Q=z+D|0;K=Q>>8;M=A+C>>8;if((K|M)>>>0<1024){ad=K<<1&14|M<<4&112|d[(c[263194]|0)+((M<<5&-256)+(Q>>10&-2))|0]<<7}else{if((a[1044415]|0)!=3){ae=j;break}ad=K<<1&14|M<<4&112}M=a[i+(ad|1)|0]|0;K=M&127;if(K<<24>>24==0|I){ae=j;break}Q=t+B|0;P=(Q|0)<(B|0);L=(M<<24>>24<0?11:3)+h|0;M=K&255;K=L&255;O=r;while(1){if(!P){R=Q;do{V=(R<<1)+l|0;U=ab(c[277223]|0,O)|0;Y=U+V|0;if((R|0)>=(f|0)&(L|0)>(d[(c[277219]|0)+Y|0]|0)&(R|0)<(g|0)){do{if((a[1108928]|0)==0){_=b[(c[277225]|0)+(M<<1)>>1]|0;if((a[(c[277215]|0)+Y|0]&32)!=0){af=b[(c[277221]|0)+((_&65535|67616)-(b[(c[277213]|0)+(Y<<1)>>1]&63454)>>1<<1)>>1]|0;break}X=c[277228]&65535;Z=_&-2048;ag=X&-2048;ah=(Z&65535)>(ag&65535)?Z-ag&65535:0;ag=_&2016;Z=X&2016;if((ag&65535)>(Z&65535)){ai=(ag-Z&65535)+ah&65535}else{ai=ah}ah=_&31;_=X&31;if((ah&65535)<=(_&65535)){af=ai;break}af=(ah-_&65535)+ai&65535}else{_=b[(c[277225]|0)+(M<<1)>>1]|0;if((a[(c[277215]|0)+Y|0]&32)==0){aj=c[277228]&65535}else{aj=b[(c[277213]|0)+(Y<<1)>>1]|0}ah=_&-2048;X=aj&-2048;Z=(ah&65535)>(X&65535)?ah-X&65535:0;X=_&2016;ah=aj&2016;if((X&65535)>(ah&65535)){ak=(X-ah&65535)+Z&65535}else{ak=Z}Z=_&31;_=aj&31;if((Z&65535)<=(_&65535)){af=ak;break}af=(Z-_&65535)+ak&65535}}while(0);Y=V+1|0;b[(c[277218]|0)+(Y+U<<1)>>1]=af;S=(ab(c[277223]|0,O)|0)+V|0;b[(c[277218]|0)+(S<<1)>>1]=af;S=(ab(c[277223]|0,O)|0)+Y|0;a[(c[277219]|0)+S|0]=K;S=(ab(c[277223]|0,O)|0)+V|0;a[(c[277219]|0)+S|0]=K}R=R-1|0;}while((R|0)>=(B|0))}R=O+1|0;if((R|0)<(w|0)){O=R}else{ae=j;break}}}else{ae=J}}while(0);J=B+1|0;if((J|0)<(q|0)){z=z+E|0;A=A+F|0;x=ae;B=J}else{break}}}}while(0);C=w+u|0;D=(ab(c[277223]|0,w)|0)+l|0;y=c[277231]|0;if(C>>>0>y>>>0){break}else{r=0;m=w;l=D;u=C;v=v+(w<<4)|0;k=y}}return}function UP(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0;i=c[263194]|0;do{if((a[(c[263195]|0)+8496|0]&1)==0){j=1106168}else{if((a[1106089]|0)==0){j=1125528;break}k=d[1044485]|0;c[276541]=7080+(k<<5);l=0;do{m=l<<1&2;n=l&2;o=l&4;p=0;do{b[1125528+(l<<9)+(p<<1)>>1]=d[(p>>>1&28|n)+(7080+(k<<5))|0]<<6|d[(p<<2&28|m)+(7080+(k<<5))|0]<<11|d[(p>>>3&24|o)+(7080+(k<<5))|0];p=p+1|0;}while(p>>>0<256);l=l+1|0;}while(l>>>0<8);a[1106089]=0;j=1125528}}while(0);c[277226]=j;c[277225]=(a[1108928]|0)!=0?1393712:j;j=c[277230]|0;if(j>>>0>(c[277231]|0)>>>0){return}l=f>>>0<g>>>0;k=h+7|0;h=k&255;p=g-1|0;o=ab(c[277223]|0,j)|0;m=j;n=1097960+(j<<4)|0;while(1){j=e[n+12>>1]<<19>>19;q=e[n+8>>1]<<19;r=e[n+10>>1]<<19;s=m+1|0;t=(e[n+14>>1]<<19>>19)-(r>>19)|0;u=(t&8192|0)!=0?t|-1024:t&1023;t=b[n+2>>1]|0;v=((a[1044414]|0)==0?s:s^255)&255;w=(ab(v,t)|0)&-64;x=w+(q>>11)+((ab(u,t)|0)&-64)|0;t=b[n+6>>1]|0;w=(ab(t,v)|0)&-64;v=w+(r>>11)+((ab(u,t)|0)&-64)|0;t=b[n>>1]|0;if((a[1044413]|0)==0){u=b[n+4>>1]|0;y=t;z=u<<16>>16;A=f;B=u}else{u=b[n+4>>1]|0;y=-t|0;z=-(u<<16>>16)|0;A=p;B=u}u=j-(q>>19)|0;q=(u&8192|0)!=0?u|-1024:u&1023;u=ab(A,t)|0;j=u+((ab(t,q)|0)&-64)|0;t=B<<16>>16;u=ab(t,A)|0;r=((ab(t,q)|0)&-64)+u|0;L15396:do{if((a[1044415]|0)==0){if(l){C=r;D=j;E=f}else{break}while(1){u=D+x|0;q=(C+v|0)>>>8;t=(E<<1)+o|0;do{if((k|0)>(d[(c[277219]|0)+t|0]|0)){w=a[i+(u>>>8<<1&14|q<<4&112|d[(c[263194]|0)+(q<<5&32512|u>>>10&254)|0]<<7|1)|0]|0;if(w<<24>>24==0){break}F=b[(c[277225]|0)+((w&255)<<1)>>1]|0;w=t+1|0;b[(c[277218]|0)+(w<<1)>>1]=F;b[(c[277218]|0)+(t<<1)>>1]=F;a[(c[277219]|0)+w|0]=h;a[(c[277219]|0)+t|0]=h}}while(0);t=E+1|0;if(t>>>0>=g>>>0){break L15396}C=C+z|0;D=D+y|0;E=t}}else{if(l){G=r;H=j;I=f}else{break}while(1){t=H+x|0;u=t>>8;q=G+v>>8;do{if((q|u)>>>0<1024){J=q<<4&112|u<<1&14|d[(c[263194]|0)+((q<<5&-256)+(t>>10&-2))|0]<<7;K=11787}else{if((a[1044415]|0)!=3){break}J=q<<4&112|u<<1&14;K=11787}}while(0);do{if((K|0)==11787){K=0;u=(I<<1)+o|0;if((k|0)<=(d[(c[277219]|0)+u|0]|0)){break}q=a[i+(J|1)|0]|0;if(q<<24>>24==0){break}t=b[(c[277225]|0)+((q&255)<<1)>>1]|0;q=u+1|0;b[(c[277218]|0)+(q<<1)>>1]=t;b[(c[277218]|0)+(u<<1)>>1]=t;a[(c[277219]|0)+q|0]=h;a[(c[277219]|0)+u|0]=h}}while(0);u=I+1|0;if(u>>>0<g>>>0){G=G+z|0;H=H+y|0;I=u}else{break}}}}while(0);if(s>>>0>(c[277231]|0)>>>0){break}o=(c[277223]|0)+o|0;m=s;n=n+16|0}return}function UQ(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;i=c[263194]|0;do{if((a[(c[263195]|0)+8496|0]&1)==0){j=1106168}else{if((a[1106089]|0)==0){j=1125528;break}k=d[1044485]|0;c[276541]=7080+(k<<5);l=0;do{m=l<<1&2;n=l&2;o=l&4;p=0;do{b[1125528+(l<<9)+(p<<1)>>1]=d[(p>>>1&28|n)+(7080+(k<<5))|0]<<6|d[(p<<2&28|m)+(7080+(k<<5))|0]<<11|d[(p>>>3&24|o)+(7080+(k<<5))|0];p=p+1|0;}while(p>>>0<256);l=l+1|0;}while(l>>>0<8);a[1106089]=0;j=1125528}}while(0);c[277226]=j;c[277225]=(a[1108928]|0)!=0?1393712:j;j=c[277230]|0;if(j>>>0>(c[277231]|0)>>>0){return}l=f>>>0<g>>>0;k=h+7|0;h=k&255;p=g-1|0;o=ab(c[277223]|0,j)|0;m=j;n=1097960+(j<<4)|0;while(1){j=e[n+12>>1]<<19>>19;q=e[n+8>>1]<<19;r=e[n+10>>1]<<19;s=m+1|0;t=(e[n+14>>1]<<19>>19)-(r>>19)|0;u=(t&8192|0)!=0?t|-1024:t&1023;t=b[n+2>>1]|0;v=((a[1044414]|0)==0?s:s^255)&255;w=(ab(v,t)|0)&-64;x=w+(q>>11)+((ab(u,t)|0)&-64)|0;t=b[n+6>>1]|0;w=(ab(t,v)|0)&-64;v=w+(r>>11)+((ab(u,t)|0)&-64)|0;t=b[n>>1]|0;if((a[1044413]|0)==0){u=b[n+4>>1]|0;y=t;z=u<<16>>16;A=f;B=u}else{u=b[n+4>>1]|0;y=-t|0;z=-(u<<16>>16)|0;A=p;B=u}u=j-(q>>19)|0;q=(u&8192|0)!=0?u|-1024:u&1023;u=ab(A,t)|0;j=u+((ab(t,q)|0)&-64)|0;t=B<<16>>16;u=ab(t,A)|0;r=((ab(t,q)|0)&-64)+u|0;L15440:do{if((a[1044415]|0)==0){if(l){C=r;D=j;E=f}else{break}while(1){u=D+x|0;q=(C+v|0)>>>8;t=(E<<1)+o|0;do{if((k|0)>(d[(c[277219]|0)+t|0]|0)){w=a[i+(u>>>8<<1&14|q<<4&112|d[(c[263194]|0)+(q<<5&32512|u>>>10&254)|0]<<7|1)|0]|0;if(w<<24>>24==0){break}F=e[(c[277225]|0)+((w&255)<<1)>>1]|0;w=(a[(c[277215]|0)+t|0]&32)==0;if(w){G=c[277228]|0;H=G;I=G&-2082}else{G=e[(c[277213]|0)+(t<<1)>>1]|0;H=G;I=G&63454}if(w){J=c[277228]|0}else{J=e[(c[277213]|0)+(t<<1)>>1]|0}w=((J^F)&2081|e[(c[277220]|0)+((F&2081&H)+((I+(F&63454)|0)>>>1)<<1)>>1])&65535;F=t+1|0;b[(c[277218]|0)+(F<<1)>>1]=w;b[(c[277218]|0)+(t<<1)>>1]=w;a[(c[277219]|0)+F|0]=h;a[(c[277219]|0)+t|0]=h}}while(0);t=E+1|0;if(t>>>0>=g>>>0){break L15440}C=C+z|0;D=D+y|0;E=t}}else{if(l){K=r;L=j;M=f}else{break}while(1){t=L+x|0;u=t>>8;q=K+v>>8;do{if((q|u)>>>0<1024){N=q<<4&112|u<<1&14|d[(c[263194]|0)+((q<<5&-256)+(t>>10&-2))|0]<<7;O=11826}else{if((a[1044415]|0)!=3){break}N=q<<4&112|u<<1&14;O=11826}}while(0);do{if((O|0)==11826){O=0;u=(M<<1)+o|0;if((k|0)<=(d[(c[277219]|0)+u|0]|0)){break}q=a[i+(N|1)|0]|0;if(q<<24>>24==0){break}t=e[(c[277225]|0)+((q&255)<<1)>>1]|0;q=(a[(c[277215]|0)+u|0]&32)==0;if(q){F=c[277228]|0;P=F;Q=F&-2082}else{F=e[(c[277213]|0)+(u<<1)>>1]|0;P=F;Q=F&63454}if(q){R=c[277228]|0}else{R=e[(c[277213]|0)+(u<<1)>>1]|0}q=((R^t)&2081|e[(c[277220]|0)+((t&2081&P)+((Q+(t&63454)|0)>>>1)<<1)>>1])&65535;t=u+1|0;b[(c[277218]|0)+(t<<1)>>1]=q;b[(c[277218]|0)+(u<<1)>>1]=q;a[(c[277219]|0)+t|0]=h;a[(c[277219]|0)+u|0]=h}}while(0);u=M+1|0;if(u>>>0<g>>>0){K=K+z|0;L=L+y|0;M=u}else{break}}}}while(0);if(s>>>0>(c[277231]|0)>>>0){break}o=(c[277223]|0)+o|0;m=s;n=n+16|0}return}function UR(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0;i=c[263194]|0;do{if((a[(c[263195]|0)+8496|0]&1)==0){j=1106168}else{if((a[1106089]|0)==0){j=1125528;break}k=d[1044485]|0;c[276541]=7080+(k<<5);l=0;do{m=l<<1&2;n=l&2;o=l&4;p=0;do{b[1125528+(l<<9)+(p<<1)>>1]=d[(p>>>1&28|n)+(7080+(k<<5))|0]<<6|d[(p<<2&28|m)+(7080+(k<<5))|0]<<11|d[(p>>>3&24|o)+(7080+(k<<5))|0];p=p+1|0;}while(p>>>0<256);l=l+1|0;}while(l>>>0<8);a[1106089]=0;j=1125528}}while(0);c[277226]=j;c[277225]=(a[1108928]|0)!=0?1393712:j;j=c[277230]|0;if(j>>>0>(c[277231]|0)>>>0){return}l=f>>>0<g>>>0;k=h+7|0;h=k&255;p=g-1|0;o=ab(c[277223]|0,j)|0;m=j;n=1097960+(j<<4)|0;while(1){j=e[n+12>>1]<<19>>19;q=e[n+8>>1]<<19;r=e[n+10>>1]<<19;s=m+1|0;t=(e[n+14>>1]<<19>>19)-(r>>19)|0;u=(t&8192|0)!=0?t|-1024:t&1023;t=b[n+2>>1]|0;v=((a[1044414]|0)==0?s:s^255)&255;w=(ab(v,t)|0)&-64;x=w+(q>>11)+((ab(u,t)|0)&-64)|0;t=b[n+6>>1]|0;w=(ab(t,v)|0)&-64;v=w+(r>>11)+((ab(u,t)|0)&-64)|0;t=b[n>>1]|0;if((a[1044413]|0)==0){u=b[n+4>>1]|0;y=t;z=u<<16>>16;A=f;B=u}else{u=b[n+4>>1]|0;y=-t|0;z=-(u<<16>>16)|0;A=p;B=u}u=j-(q>>19)|0;q=(u&8192|0)!=0?u|-1024:u&1023;u=ab(A,t)|0;j=u+((ab(t,q)|0)&-64)|0;t=B<<16>>16;u=ab(t,A)|0;r=((ab(t,q)|0)&-64)+u|0;L15500:do{if((a[1044415]|0)==0){if(l){C=r;D=j;E=f}else{break}while(1){u=D+x|0;q=(C+v|0)>>>8;t=(E<<1)+o|0;do{if((k|0)>(d[(c[277219]|0)+t|0]|0)){w=a[i+(u>>>8<<1&14|q<<4&112|d[(c[263194]|0)+(q<<5&32512|u>>>10&254)|0]<<7|1)|0]|0;if(w<<24>>24==0){break}F=e[(c[277225]|0)+((w&255)<<1)>>1]|0;w=c[277228]|0;G=(((F&63454)+(w&-2082)|0)>>>1)+(w&2081&F)|0;if((a[1108928]|0)==0){H=G&65535}else{H=(e[(c[277220]|0)+(G<<1)>>1]|(F^w)&2081)&65535}w=t+1|0;b[(c[277218]|0)+(w<<1)>>1]=H;b[(c[277218]|0)+(t<<1)>>1]=H;a[(c[277219]|0)+w|0]=h;a[(c[277219]|0)+t|0]=h}}while(0);t=E+1|0;if(t>>>0>=g>>>0){break L15500}C=C+z|0;D=D+y|0;E=t}}else{if(l){I=r;J=j;K=f}else{break}while(1){t=J+x|0;u=t>>8;q=I+v>>8;do{if((q|u)>>>0<1024){L=q<<4&112|u<<1&14|d[(c[263194]|0)+((q<<5&-256)+(t>>10&-2))|0]<<7;M=11867}else{if((a[1044415]|0)!=3){break}L=q<<4&112|u<<1&14;M=11867}}while(0);do{if((M|0)==11867){M=0;u=(K<<1)+o|0;if((k|0)<=(d[(c[277219]|0)+u|0]|0)){break}q=a[i+(L|1)|0]|0;if(q<<24>>24==0){break}t=e[(c[277225]|0)+((q&255)<<1)>>1]|0;q=c[277228]|0;w=(((t&63454)+(q&-2082)|0)>>>1)+(q&2081&t)|0;if((a[1108928]|0)==0){N=w&65535}else{N=(e[(c[277220]|0)+(w<<1)>>1]|(t^q)&2081)&65535}q=u+1|0;b[(c[277218]|0)+(q<<1)>>1]=N;b[(c[277218]|0)+(u<<1)>>1]=N;a[(c[277219]|0)+q|0]=h;a[(c[277219]|0)+u|0]=h}}while(0);u=K+1|0;if(u>>>0<g>>>0){I=I+z|0;J=J+y|0;K=u}else{break}}}}while(0);if(s>>>0>(c[277231]|0)>>>0){break}o=(c[277223]|0)+o|0;m=s;n=n+16|0}return}function US(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;i=c[263194]|0;do{if((a[(c[263195]|0)+8496|0]&1)==0){j=1106168}else{if((a[1106089]|0)==0){j=1125528;break}k=d[1044485]|0;c[276541]=7080+(k<<5);l=0;do{m=l<<1&2;n=l&2;o=l&4;p=0;do{b[1125528+(l<<9)+(p<<1)>>1]=d[(p>>>1&28|n)+(7080+(k<<5))|0]<<6|d[(p<<2&28|m)+(7080+(k<<5))|0]<<11|d[(p>>>3&24|o)+(7080+(k<<5))|0];p=p+1|0;}while(p>>>0<256);l=l+1|0;}while(l>>>0<8);a[1106089]=0;j=1125528}}while(0);c[277226]=j;c[277225]=(a[1108928]|0)!=0?1393712:j;j=c[277230]|0;if(j>>>0>(c[277231]|0)>>>0){return}l=f>>>0<g>>>0;k=h+7|0;h=k&255;p=g-1|0;o=ab(c[277223]|0,j)|0;m=j;n=1097960+(j<<4)|0;while(1){j=e[n+12>>1]<<19>>19;q=e[n+8>>1]<<19;r=e[n+10>>1]<<19;s=m+1|0;t=(e[n+14>>1]<<19>>19)-(r>>19)|0;u=(t&8192|0)!=0?t|-1024:t&1023;t=b[n+2>>1]|0;v=((a[1044414]|0)==0?s:s^255)&255;w=(ab(v,t)|0)&-64;x=w+(q>>11)+((ab(u,t)|0)&-64)|0;t=b[n+6>>1]|0;w=(ab(t,v)|0)&-64;v=w+(r>>11)+((ab(u,t)|0)&-64)|0;t=b[n>>1]|0;if((a[1044413]|0)==0){u=b[n+4>>1]|0;y=t;z=u<<16>>16;A=f;B=u}else{u=b[n+4>>1]|0;y=-t|0;z=-(u<<16>>16)|0;A=p;B=u}u=j-(q>>19)|0;q=(u&8192|0)!=0?u|-1024:u&1023;u=ab(A,t)|0;j=u+((ab(t,q)|0)&-64)|0;t=B<<16>>16;u=ab(t,A)|0;r=((ab(t,q)|0)&-64)+u|0;L20:do{if((a[1044415]|0)==0){if(l){C=r;D=j;E=f}else{break}while(1){u=D+x|0;q=(C+v|0)>>>8;t=(E<<1)+o|0;do{if((k|0)>(d[(c[277219]|0)+t|0]|0)){w=a[i+(u>>>8<<1&14|q<<4&112|d[(c[263194]|0)+(q<<5&32512|u>>>10&254)|0]<<7|1)|0]|0;F=w&255;if(w<<24>>24==0){break}do{if((a[1108928]|0)==0){w=b[(c[277225]|0)+(F<<1)>>1]|0;G=w&65535;H=G&63454;if((a[(c[277215]|0)+t|0]&32)==0){I=c[277228]|0;J=(e[(c[277220]|0)+((((I&-2082)+H|0)>>>1)+(G&2081&I)<<1)>>1]|(I^G)&2081)&65535;break}else{G=b[(c[277213]|0)+(t<<1)>>1]|0;J=(((G&63454)+H|0)>>>1)+(G&w&2081)&65535;break}}else{w=e[(c[277225]|0)+(F<<1)>>1]|0;G=(a[(c[277215]|0)+t|0]&32)==0;if(G){H=c[277228]|0;K=H;L=H&-2082}else{H=e[(c[277213]|0)+(t<<1)>>1]|0;K=H;L=H&63454}if(G){M=c[277228]|0}else{M=e[(c[277213]|0)+(t<<1)>>1]|0}J=((M^w)&2081|e[(c[277220]|0)+((w&2081&K)+((L+(w&63454)|0)>>>1)<<1)>>1])&65535}}while(0);F=t+1|0;b[(c[277218]|0)+(F<<1)>>1]=J;b[(c[277218]|0)+(t<<1)>>1]=J;a[(c[277219]|0)+F|0]=h;a[(c[277219]|0)+t|0]=h}}while(0);t=E+1|0;if(t>>>0>=g>>>0){break L20}C=C+z|0;D=D+y|0;E=t}}else{if(l){N=r;O=j;P=f}else{break}while(1){t=O+x|0;u=t>>8;q=N+v>>8;do{if((q|u)>>>0<1024){Q=q<<4&112|u<<1&14|d[(c[263194]|0)+((q<<5&-256)+(t>>10&-2))|0]<<7;R=36}else{if((a[1044415]|0)!=3){break}Q=q<<4&112|u<<1&14;R=36}}while(0);do{if((R|0)==36){R=0;u=(P<<1)+o|0;if((k|0)<=(d[(c[277219]|0)+u|0]|0)){break}q=a[i+(Q|1)|0]|0;t=q&255;if(q<<24>>24==0){break}do{if((a[1108928]|0)==0){q=b[(c[277225]|0)+(t<<1)>>1]|0;F=q&65535;w=F&63454;if((a[(c[277215]|0)+u|0]&32)==0){G=c[277228]|0;S=(e[(c[277220]|0)+((((G&-2082)+w|0)>>>1)+(F&2081&G)<<1)>>1]|(G^F)&2081)&65535;break}else{F=b[(c[277213]|0)+(u<<1)>>1]|0;S=(((F&63454)+w|0)>>>1)+(F&q&2081)&65535;break}}else{q=e[(c[277225]|0)+(t<<1)>>1]|0;F=(a[(c[277215]|0)+u|0]&32)==0;if(F){w=c[277228]|0;T=w;U=w&-2082}else{w=e[(c[277213]|0)+(u<<1)>>1]|0;T=w;U=w&63454}if(F){V=c[277228]|0}else{V=e[(c[277213]|0)+(u<<1)>>1]|0}S=((V^q)&2081|e[(c[277220]|0)+((q&2081&T)+((U+(q&63454)|0)>>>1)<<1)>>1])&65535}}while(0);t=u+1|0;b[(c[277218]|0)+(t<<1)>>1]=S;b[(c[277218]|0)+(u<<1)>>1]=S;a[(c[277219]|0)+t|0]=h;a[(c[277219]|0)+u|0]=h}}while(0);t=P+1|0;if(t>>>0<g>>>0){N=N+z|0;O=O+y|0;P=t}else{break}}}}while(0);if(s>>>0>(c[277231]|0)>>>0){break}o=(c[277223]|0)+o|0;m=s;n=n+16|0}return}function UT(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;i=c[263194]|0;do{if((a[(c[263195]|0)+8496|0]&1)==0){j=1106168}else{if((a[1106089]|0)==0){j=1125528;break}k=d[1044485]|0;c[276541]=7080+(k<<5);l=0;do{m=l<<1&2;n=l&2;o=l&4;p=0;do{b[1125528+(l<<9)+(p<<1)>>1]=d[(p>>>1&28|n)+(7080+(k<<5))|0]<<6|d[(p<<2&28|m)+(7080+(k<<5))|0]<<11|d[(p>>>3&24|o)+(7080+(k<<5))|0];p=p+1|0;}while(p>>>0<256);l=l+1|0;}while(l>>>0<8);a[1106089]=0;j=1125528}}while(0);c[277226]=j;c[277225]=(a[1108928]|0)!=0?1393712:j;j=c[277230]|0;if(j>>>0>(c[277231]|0)>>>0){return}l=f>>>0<g>>>0;k=h+7|0;h=k&255;p=g-1|0;o=ab(c[277223]|0,j)|0;m=j;n=1097960+(j<<4)|0;while(1){j=e[n+12>>1]<<19>>19;q=e[n+8>>1]<<19;r=e[n+10>>1]<<19;s=m+1|0;t=(e[n+14>>1]<<19>>19)-(r>>19)|0;u=(t&8192|0)!=0?t|-1024:t&1023;t=b[n+2>>1]|0;v=((a[1044414]|0)==0?s:s^255)&255;w=(ab(v,t)|0)&-64;x=w+(q>>11)+((ab(u,t)|0)&-64)|0;t=b[n+6>>1]|0;w=(ab(t,v)|0)&-64;v=w+(r>>11)+((ab(u,t)|0)&-64)|0;t=b[n>>1]|0;if((a[1044413]|0)==0){u=b[n+4>>1]|0;y=t;z=u<<16>>16;A=f;B=u}else{u=b[n+4>>1]|0;y=-t|0;z=-(u<<16>>16)|0;A=p;B=u}u=j-(q>>19)|0;q=(u&8192|0)!=0?u|-1024:u&1023;u=ab(A,t)|0;j=u+((ab(t,q)|0)&-64)|0;t=B<<16>>16;u=ab(t,A)|0;r=((ab(t,q)|0)&-64)+u|0;L94:do{if((a[1044415]|0)==0){if(l){C=r;D=j;E=f}else{break}while(1){u=D+x|0;q=(C+v|0)>>>8;t=(E<<1)+o|0;do{if((k|0)>(d[(c[277219]|0)+t|0]|0)){w=a[i+(u>>>8<<1&14|q<<4&112|d[(c[263194]|0)+(q<<5&32512|u>>>10&254)|0]<<7|1)|0]|0;if(w<<24>>24==0){break}F=b[(c[277225]|0)+((w&255)<<1)>>1]|0;if((a[(c[277215]|0)+t|0]&32)==0){G=c[277228]&65535}else{G=b[(c[277213]|0)+(t<<1)>>1]|0}w=F&-2048;H=G&-2048;I=(w&65535)>(H&65535)?w-H&65535:0;H=F&2016;w=G&2016;if((H&65535)>(w&65535)){J=(H-w&65535)+I&65535}else{J=I}I=F&31;F=G&31;if((I&65535)>(F&65535)){K=(I-F&65535)+J&65535}else{K=J}F=t+1|0;b[(c[277218]|0)+(F<<1)>>1]=K;b[(c[277218]|0)+(t<<1)>>1]=K;a[(c[277219]|0)+F|0]=h;a[(c[277219]|0)+t|0]=h}}while(0);t=E+1|0;if(t>>>0>=g>>>0){break L94}C=C+z|0;D=D+y|0;E=t}}else{if(l){L=r;M=j;N=f}else{break}while(1){t=M+x|0;u=t>>8;q=L+v>>8;do{if((q|u)>>>0<1024){O=q<<4&112|u<<1&14|d[(c[263194]|0)+((q<<5&-256)+(t>>10&-2))|0]<<7;P=87}else{if((a[1044415]|0)!=3){break}O=q<<4&112|u<<1&14;P=87}}while(0);do{if((P|0)==87){P=0;u=(N<<1)+o|0;if((k|0)<=(d[(c[277219]|0)+u|0]|0)){break}q=a[i+(O|1)|0]|0;if(q<<24>>24==0){break}t=b[(c[277225]|0)+((q&255)<<1)>>1]|0;if((a[(c[277215]|0)+u|0]&32)==0){Q=c[277228]&65535}else{Q=b[(c[277213]|0)+(u<<1)>>1]|0}q=t&-2048;F=Q&-2048;I=(q&65535)>(F&65535)?q-F&65535:0;F=t&2016;q=Q&2016;if((F&65535)>(q&65535)){R=(F-q&65535)+I&65535}else{R=I}I=t&31;t=Q&31;if((I&65535)>(t&65535)){S=(I-t&65535)+R&65535}else{S=R}t=u+1|0;b[(c[277218]|0)+(t<<1)>>1]=S;b[(c[277218]|0)+(u<<1)>>1]=S;a[(c[277219]|0)+t|0]=h;a[(c[277219]|0)+u|0]=h}}while(0);u=N+1|0;if(u>>>0<g>>>0){L=L+z|0;M=M+y|0;N=u}else{break}}}}while(0);if(s>>>0>(c[277231]|0)>>>0){break}o=(c[277223]|0)+o|0;m=s;n=n+16|0}return}function UU(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;i=c[263194]|0;do{if((a[(c[263195]|0)+8496|0]&1)==0){j=1106168}else{if((a[1106089]|0)==0){j=1125528;break}k=d[1044485]|0;c[276541]=7080+(k<<5);l=0;do{m=l<<1&2;n=l&2;o=l&4;p=0;do{b[1125528+(l<<9)+(p<<1)>>1]=d[(p>>>1&28|n)+(7080+(k<<5))|0]<<6|d[(p<<2&28|m)+(7080+(k<<5))|0]<<11|d[(p>>>3&24|o)+(7080+(k<<5))|0];p=p+1|0;}while(p>>>0<256);l=l+1|0;}while(l>>>0<8);a[1106089]=0;j=1125528}}while(0);c[277226]=j;c[277225]=(a[1108928]|0)!=0?1393712:j;j=c[277230]|0;if(j>>>0>(c[277231]|0)>>>0){return}l=f>>>0<g>>>0;k=h+7|0;h=k&255;p=g-1|0;o=ab(c[277223]|0,j)|0;m=j;n=1097960+(j<<4)|0;while(1){j=e[n+12>>1]<<19>>19;q=e[n+8>>1]<<19;r=e[n+10>>1]<<19;s=m+1|0;t=(e[n+14>>1]<<19>>19)-(r>>19)|0;u=(t&8192|0)!=0?t|-1024:t&1023;t=b[n+2>>1]|0;v=((a[1044414]|0)==0?s:s^255)&255;w=(ab(v,t)|0)&-64;x=w+(q>>11)+((ab(u,t)|0)&-64)|0;t=b[n+6>>1]|0;w=(ab(t,v)|0)&-64;v=w+(r>>11)+((ab(u,t)|0)&-64)|0;t=b[n>>1]|0;if((a[1044413]|0)==0){u=b[n+4>>1]|0;y=t;z=u<<16>>16;A=f;B=u}else{u=b[n+4>>1]|0;y=-t|0;z=-(u<<16>>16)|0;A=p;B=u}u=j-(q>>19)|0;q=(u&8192|0)!=0?u|-1024:u&1023;u=ab(A,t)|0;j=u+((ab(t,q)|0)&-64)|0;t=B<<16>>16;u=ab(t,A)|0;r=((ab(t,q)|0)&-64)+u|0;L158:do{if((a[1044415]|0)==0){if(l){C=r;D=j;E=f}else{break}while(1){u=D+x|0;q=(C+v|0)>>>8;t=(E<<1)+o|0;do{if((k|0)>(d[(c[277219]|0)+t|0]|0)){w=a[i+(u>>>8<<1&14|q<<4&112|d[(c[263194]|0)+(q<<5&32512|u>>>10&254)|0]<<7|1)|0]|0;if(w<<24>>24==0){break}F=b[(c[277225]|0)+((w&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){G=b[(c[277221]|0)+(((F&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{w=c[277228]&65535;H=F&-2048;I=w&-2048;J=(H&65535)>(I&65535)?H-I&65535:0;I=F&2016;H=w&2016;if((I&65535)>(H&65535)){K=(I-H&65535)+J&65535}else{K=J}J=F&31;H=w&31;if((J&65535)<=(H&65535)){G=K;break}G=(J-H&65535)+K&65535}}while(0);F=t+1|0;b[(c[277218]|0)+(F<<1)>>1]=G;b[(c[277218]|0)+(t<<1)>>1]=G;a[(c[277219]|0)+F|0]=h;a[(c[277219]|0)+t|0]=h}}while(0);t=E+1|0;if(t>>>0>=g>>>0){break L158}C=C+z|0;D=D+y|0;E=t}}else{if(l){L=r;M=j;N=f}else{break}while(1){t=M+x|0;u=t>>8;q=L+v>>8;do{if((q|u)>>>0<1024){O=q<<4&112|u<<1&14|d[(c[263194]|0)+((q<<5&-256)+(t>>10&-2))|0]<<7;P=133}else{if((a[1044415]|0)!=3){break}O=q<<4&112|u<<1&14;P=133}}while(0);do{if((P|0)==133){P=0;u=(N<<1)+o|0;if((k|0)<=(d[(c[277219]|0)+u|0]|0)){break}q=a[i+(O|1)|0]|0;if(q<<24>>24==0){break}t=b[(c[277225]|0)+((q&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){Q=b[(c[277221]|0)+(((t&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{q=c[277228]&65535;F=t&-2048;H=q&-2048;J=(F&65535)>(H&65535)?F-H&65535:0;H=t&2016;F=q&2016;if((H&65535)>(F&65535)){R=(H-F&65535)+J&65535}else{R=J}J=t&31;F=q&31;if((J&65535)<=(F&65535)){Q=R;break}Q=(J-F&65535)+R&65535}}while(0);t=u+1|0;b[(c[277218]|0)+(t<<1)>>1]=Q;b[(c[277218]|0)+(u<<1)>>1]=Q;a[(c[277219]|0)+t|0]=h;a[(c[277219]|0)+u|0]=h}}while(0);t=N+1|0;if(t>>>0<g>>>0){L=L+z|0;M=M+y|0;N=t}else{break}}}}while(0);if(s>>>0>(c[277231]|0)>>>0){break}o=(c[277223]|0)+o|0;m=s;n=n+16|0}return}function UV(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;i=c[263194]|0;do{if((a[(c[263195]|0)+8496|0]&1)==0){j=1106168}else{if((a[1106089]|0)==0){j=1125528;break}k=d[1044485]|0;c[276541]=7080+(k<<5);l=0;do{m=l<<1&2;n=l&2;o=l&4;p=0;do{b[1125528+(l<<9)+(p<<1)>>1]=d[(p>>>1&28|n)+(7080+(k<<5))|0]<<6|d[(p<<2&28|m)+(7080+(k<<5))|0]<<11|d[(p>>>3&24|o)+(7080+(k<<5))|0];p=p+1|0;}while(p>>>0<256);l=l+1|0;}while(l>>>0<8);a[1106089]=0;j=1125528}}while(0);c[277226]=j;c[277225]=(a[1108928]|0)!=0?1393712:j;j=c[277230]|0;if(j>>>0>(c[277231]|0)>>>0){return}l=f>>>0<g>>>0;k=h+7|0;h=k&255;p=g-1|0;o=ab(c[277223]|0,j)|0;m=j;n=1097960+(j<<4)|0;while(1){j=e[n+12>>1]<<19>>19;q=e[n+8>>1]<<19;r=e[n+10>>1]<<19;s=m+1|0;t=(e[n+14>>1]<<19>>19)-(r>>19)|0;u=(t&8192|0)!=0?t|-1024:t&1023;t=b[n+2>>1]|0;v=((a[1044414]|0)==0?s:s^255)&255;w=(ab(v,t)|0)&-64;x=w+(q>>11)+((ab(u,t)|0)&-64)|0;t=b[n+6>>1]|0;w=(ab(t,v)|0)&-64;v=w+(r>>11)+((ab(u,t)|0)&-64)|0;t=b[n>>1]|0;if((a[1044413]|0)==0){u=b[n+4>>1]|0;y=t;z=u<<16>>16;A=f;B=u}else{u=b[n+4>>1]|0;y=-t|0;z=-(u<<16>>16)|0;A=p;B=u}u=j-(q>>19)|0;q=(u&8192|0)!=0?u|-1024:u&1023;u=ab(A,t)|0;j=u+((ab(t,q)|0)&-64)|0;t=B<<16>>16;u=ab(t,A)|0;r=((ab(t,q)|0)&-64)+u|0;L218:do{if((a[1044415]|0)==0){if(l){C=r;D=j;E=f}else{break}while(1){u=D+x|0;q=(C+v|0)>>>8;t=(E<<1)+o|0;do{if((k|0)>(d[(c[277219]|0)+t|0]|0)){w=a[i+(u>>>8<<1&14|q<<4&112|d[(c[263194]|0)+(q<<5&32512|u>>>10&254)|0]<<7|1)|0]|0;F=w&255;if(w<<24>>24==0){break}do{if((a[1108928]|0)==0){w=b[(c[277225]|0)+(F<<1)>>1]|0;if((a[(c[277215]|0)+t|0]&32)!=0){G=b[(c[277221]|0)+((w&65535|67616)-(b[(c[277213]|0)+(t<<1)>>1]&63454)>>1<<1)>>1]|0;break}H=c[277228]&65535;I=w&-2048;J=H&-2048;K=(I&65535)>(J&65535)?I-J&65535:0;J=w&2016;I=H&2016;if((J&65535)>(I&65535)){L=(J-I&65535)+K&65535}else{L=K}K=w&31;w=H&31;if((K&65535)<=(w&65535)){G=L;break}G=(K-w&65535)+L&65535}else{w=b[(c[277225]|0)+(F<<1)>>1]|0;if((a[(c[277215]|0)+t|0]&32)==0){M=c[277228]&65535}else{M=b[(c[277213]|0)+(t<<1)>>1]|0}K=w&-2048;H=M&-2048;I=(K&65535)>(H&65535)?K-H&65535:0;H=w&2016;K=M&2016;if((H&65535)>(K&65535)){N=(H-K&65535)+I&65535}else{N=I}I=w&31;w=M&31;if((I&65535)<=(w&65535)){G=N;break}G=(I-w&65535)+N&65535}}while(0);F=t+1|0;b[(c[277218]|0)+(F<<1)>>1]=G;b[(c[277218]|0)+(t<<1)>>1]=G;a[(c[277219]|0)+F|0]=h;a[(c[277219]|0)+t|0]=h}}while(0);t=E+1|0;if(t>>>0>=g>>>0){break L218}C=C+z|0;D=D+y|0;E=t}}else{if(l){O=r;P=j;Q=f}else{break}while(1){t=P+x|0;u=t>>8;q=O+v>>8;do{if((q|u)>>>0<1024){R=q<<4&112|u<<1&14|d[(c[263194]|0)+((q<<5&-256)+(t>>10&-2))|0]<<7;S=186}else{if((a[1044415]|0)!=3){break}R=q<<4&112|u<<1&14;S=186}}while(0);do{if((S|0)==186){S=0;u=(Q<<1)+o|0;if((k|0)<=(d[(c[277219]|0)+u|0]|0)){break}q=a[i+(R|1)|0]|0;t=q&255;if(q<<24>>24==0){break}do{if((a[1108928]|0)==0){q=b[(c[277225]|0)+(t<<1)>>1]|0;if((a[(c[277215]|0)+u|0]&32)!=0){T=b[(c[277221]|0)+((q&65535|67616)-(b[(c[277213]|0)+(u<<1)>>1]&63454)>>1<<1)>>1]|0;break}F=c[277228]&65535;w=q&-2048;I=F&-2048;K=(w&65535)>(I&65535)?w-I&65535:0;I=q&2016;w=F&2016;if((I&65535)>(w&65535)){U=(I-w&65535)+K&65535}else{U=K}K=q&31;q=F&31;if((K&65535)<=(q&65535)){T=U;break}T=(K-q&65535)+U&65535}else{q=b[(c[277225]|0)+(t<<1)>>1]|0;if((a[(c[277215]|0)+u|0]&32)==0){V=c[277228]&65535}else{V=b[(c[277213]|0)+(u<<1)>>1]|0}K=q&-2048;F=V&-2048;w=(K&65535)>(F&65535)?K-F&65535:0;F=q&2016;K=V&2016;if((F&65535)>(K&65535)){W=(F-K&65535)+w&65535}else{W=w}w=q&31;q=V&31;if((w&65535)<=(q&65535)){T=W;break}T=(w-q&65535)+W&65535}}while(0);t=u+1|0;b[(c[277218]|0)+(t<<1)>>1]=T;b[(c[277218]|0)+(u<<1)>>1]=T;a[(c[277219]|0)+t|0]=h;a[(c[277219]|0)+u|0]=h}}while(0);t=Q+1|0;if(t>>>0<g>>>0){O=O+z|0;P=P+y|0;Q=t}else{break}}}}while(0);if(s>>>0>(c[277231]|0)>>>0){break}o=(c[277223]|0)+o|0;m=s;n=n+16|0}return}function UW(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;i=c[263194]|0;do{if((a[(c[263195]|0)+8496|0]&1)==0){j=1106168}else{if((a[1106089]|0)==0){j=1125528;break}k=d[1044485]|0;c[276541]=7080+(k<<5);l=0;do{m=l<<1&2;n=l&2;o=l&4;p=0;do{b[1125528+(l<<9)+(p<<1)>>1]=d[(p>>>1&28|n)+(7080+(k<<5))|0]<<6|d[(p<<2&28|m)+(7080+(k<<5))|0]<<11|d[(p>>>3&24|o)+(7080+(k<<5))|0];p=p+1|0;}while(p>>>0<256);l=l+1|0;}while(l>>>0<8);a[1106089]=0;j=1125528}}while(0);c[277226]=j;c[277225]=(a[1108928]|0)!=0?1393712:j;j=c[277230]|0;if((a[1044434]|0)==0){q=f;r=g;s=0;t=1;u=j}else{l=d[1044432]|0;k=((j-(d[1044433]|0)|0)>>>0)%(l>>>0)|0;p=g-1+l|0;q=f-((f|0)%(l|0)|0)|0;r=p-((p|0)%(l|0)|0)|0;s=k;t=l;u=j-k|0}k=c[277231]|0;if(u>>>0>k>>>0){return}j=(q|0)<(r|0);l=t&255;p=h+7|0;h=p&255;o=r-1|0;m=t-1|0;n=s;s=t;t=ab(c[277223]|0,u)|0;v=u;w=1097960+(u<<4)|0;u=k;while(1){if((s+v|0)>>>0>u>>>0){x=u+1-v|0}else{x=s}k=e[w+12>>1]<<19>>19;y=e[w+8>>1]<<19;z=e[w+10>>1]<<19;A=v+1|0;B=(e[w+14>>1]<<19>>19)-(z>>19)|0;C=(B&8192|0)!=0?B|-1024:B&1023;B=b[w+2>>1]|0;D=((a[1044414]|0)==0?A:A^255)&255;A=(ab(D,B)|0)&-64;E=A+(y>>11)+((ab(C,B)|0)&-64)|0;B=b[w+6>>1]|0;A=(ab(B,D)|0)&-64;D=A+(z>>11)+((ab(C,B)|0)&-64)|0;B=b[w>>1]|0;if((a[1044413]|0)==0){C=b[w+4>>1]|0;F=B;G=C<<16>>16;H=q;I=C}else{C=b[w+4>>1]|0;F=-B|0;G=-(C<<16>>16)|0;H=o;I=C}C=k-(y>>19)|0;y=(C&8192|0)!=0?C|-1024:C&1023;C=ab(H,B)|0;k=C+((ab(B,y)|0)&-64)|0;B=I<<16>>16;C=ab(B,H)|0;z=((ab(B,y)|0)&-64)+C|0;do{if((a[1044415]|0)==0){if(!j){break}C=(n|0)>=(x|0);y=k;B=z;A=1;J=q;while(1){K=A-1&255;do{if(K<<24>>24==0){L=y+E|0;M=(B+D|0)>>>8;N=a[i+(M<<4&112|L>>>8<<1&14|d[(c[263194]|0)+(M<<5&32512|L>>>10&254)|0]<<7|1)|0]|0;if(N<<24>>24==0|C){O=l;break}L=m+J|0;M=(L|0)<(J|0);P=N&255;N=n;while(1){if(!M){Q=L;do{R=(Q<<1)+t|0;S=(ab(c[277223]|0,N)|0)+R|0;if((Q|0)>=(f|0)&(p|0)>(d[(c[277219]|0)+S|0]|0)&(Q|0)<(g|0)){T=b[(c[277225]|0)+(P<<1)>>1]|0;b[(c[277218]|0)+(S+1<<1)>>1]=T;S=(ab(c[277223]|0,N)|0)+R|0;b[(c[277218]|0)+(S<<1)>>1]=T;T=R+1+(ab(c[277223]|0,N)|0)|0;a[(c[277219]|0)+T|0]=h;T=(ab(c[277223]|0,N)|0)+R|0;a[(c[277219]|0)+T|0]=h}Q=Q-1|0;}while((Q|0)>=(J|0))}Q=N+1|0;if((Q|0)<(x|0)){N=Q}else{O=l;break}}}else{O=K}}while(0);K=J+1|0;if((K|0)<(r|0)){y=y+F|0;B=B+G|0;A=O;J=K}else{break}}}else{if(!j){break}J=(n|0)>=(x|0);A=k;B=z;y=1;C=q;while(1){K=y-1&255;do{if(K<<24>>24==0){N=A+E|0;P=N>>8;L=B+D>>8;if((P|L)>>>0<1024){U=P<<1&14|L<<4&112|d[(c[263194]|0)+((L<<5&-256)+(N>>10&-2))|0]<<7}else{if((a[1044415]|0)!=3){V=l;break}U=P<<1&14|L<<4&112}L=a[i+(U|1)|0]|0;if(L<<24>>24==0|J){V=l;break}P=m+C|0;N=(P|0)<(C|0);M=L&255;L=n;while(1){if(!N){Q=P;do{T=(Q<<1)+t|0;R=(ab(c[277223]|0,L)|0)+T|0;if((Q|0)>=(f|0)&(p|0)>(d[(c[277219]|0)+R|0]|0)&(Q|0)<(g|0)){S=b[(c[277225]|0)+(M<<1)>>1]|0;b[(c[277218]|0)+(R+1<<1)>>1]=S;R=(ab(c[277223]|0,L)|0)+T|0;b[(c[277218]|0)+(R<<1)>>1]=S;S=T+1+(ab(c[277223]|0,L)|0)|0;a[(c[277219]|0)+S|0]=h;S=(ab(c[277223]|0,L)|0)+T|0;a[(c[277219]|0)+S|0]=h}Q=Q-1|0;}while((Q|0)>=(C|0))}Q=L+1|0;if((Q|0)<(x|0)){L=Q}else{V=l;break}}}else{V=K}}while(0);K=C+1|0;if((K|0)<(r|0)){A=A+F|0;B=B+G|0;y=V;C=K}else{break}}}}while(0);D=x+v|0;E=(ab(c[277223]|0,x)|0)+t|0;z=c[277231]|0;if(D>>>0>z>>>0){break}else{n=0;s=x;t=E;v=D;w=w+(x<<4)|0;u=z}}return}function UX(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ac=0,ad=0;i=c[263194]|0;do{if((a[(c[263195]|0)+8496|0]&1)==0){j=1106168}else{if((a[1106089]|0)==0){j=1125528;break}k=d[1044485]|0;c[276541]=7080+(k<<5);l=0;do{m=l<<1&2;n=l&2;o=l&4;p=0;do{b[1125528+(l<<9)+(p<<1)>>1]=d[(p>>>1&28|n)+(7080+(k<<5))|0]<<6|d[(p<<2&28|m)+(7080+(k<<5))|0]<<11|d[(p>>>3&24|o)+(7080+(k<<5))|0];p=p+1|0;}while(p>>>0<256);l=l+1|0;}while(l>>>0<8);a[1106089]=0;j=1125528}}while(0);c[277226]=j;c[277225]=(a[1108928]|0)!=0?1393712:j;j=c[277230]|0;if((a[1044434]|0)==0){q=f;r=g;s=0;t=1;u=j}else{l=d[1044432]|0;k=((j-(d[1044433]|0)|0)>>>0)%(l>>>0)|0;p=g-1+l|0;q=f-((f|0)%(l|0)|0)|0;r=p-((p|0)%(l|0)|0)|0;s=k;t=l;u=j-k|0}k=c[277231]|0;if(u>>>0>k>>>0){return}j=(q|0)<(r|0);l=t&255;p=h+7|0;h=p&255;o=r-1|0;m=t-1|0;n=s;s=t;t=ab(c[277223]|0,u)|0;v=u;w=1097960+(u<<4)|0;u=k;while(1){if((s+v|0)>>>0>u>>>0){x=u+1-v|0}else{x=s}k=e[w+12>>1]<<19>>19;y=e[w+8>>1]<<19;z=e[w+10>>1]<<19;A=v+1|0;B=(e[w+14>>1]<<19>>19)-(z>>19)|0;C=(B&8192|0)!=0?B|-1024:B&1023;B=b[w+2>>1]|0;D=((a[1044414]|0)==0?A:A^255)&255;A=(ab(D,B)|0)&-64;E=A+(y>>11)+((ab(C,B)|0)&-64)|0;B=b[w+6>>1]|0;A=(ab(B,D)|0)&-64;D=A+(z>>11)+((ab(C,B)|0)&-64)|0;B=b[w>>1]|0;if((a[1044413]|0)==0){C=b[w+4>>1]|0;F=B;G=C<<16>>16;H=q;I=C}else{C=b[w+4>>1]|0;F=-B|0;G=-(C<<16>>16)|0;H=o;I=C}C=k-(y>>19)|0;y=(C&8192|0)!=0?C|-1024:C&1023;C=ab(H,B)|0;k=C+((ab(B,y)|0)&-64)|0;B=I<<16>>16;C=ab(B,H)|0;z=((ab(B,y)|0)&-64)+C|0;do{if((a[1044415]|0)==0){if(!j){break}C=(n|0)>=(x|0);y=k;B=z;A=1;J=q;while(1){K=A-1&255;do{if(K<<24>>24==0){L=y+E|0;M=(B+D|0)>>>8;N=a[i+(M<<4&112|L>>>8<<1&14|d[(c[263194]|0)+(M<<5&32512|L>>>10&254)|0]<<7|1)|0]|0;if(N<<24>>24==0|C){O=l;break}L=m+J|0;M=(L|0)<(J|0);P=N&255;N=n;while(1){if(!M){Q=L;do{R=(Q<<1)+t|0;S=ab(c[277223]|0,N)|0;T=S+R|0;if((Q|0)>=(f|0)&(p|0)>(d[(c[277219]|0)+T|0]|0)&(Q|0)<(g|0)){U=e[(c[277225]|0)+(P<<1)>>1]|0;V=(a[(c[277215]|0)+T|0]&32)==0;if(V){W=c[277228]|0;X=W;Y=W&-2082}else{W=e[(c[277213]|0)+(T<<1)>>1]|0;X=W;Y=W&63454}if(V){Z=c[277228]|0}else{Z=e[(c[277213]|0)+(T<<1)>>1]|0}T=((Z^U)&2081|e[(c[277220]|0)+((U&2081&X)+((Y+(U&63454)|0)>>>1)<<1)>>1])&65535;U=R+1|0;b[(c[277218]|0)+(U+S<<1)>>1]=T;S=(ab(c[277223]|0,N)|0)+R|0;b[(c[277218]|0)+(S<<1)>>1]=T;T=(ab(c[277223]|0,N)|0)+U|0;a[(c[277219]|0)+T|0]=h;T=(ab(c[277223]|0,N)|0)+R|0;a[(c[277219]|0)+T|0]=h}Q=Q-1|0;}while((Q|0)>=(J|0))}Q=N+1|0;if((Q|0)<(x|0)){N=Q}else{O=l;break}}}else{O=K}}while(0);K=J+1|0;if((K|0)<(r|0)){y=y+F|0;B=B+G|0;A=O;J=K}else{break}}}else{if(!j){break}J=(n|0)>=(x|0);A=k;B=z;y=1;C=q;while(1){K=y-1&255;do{if(K<<24>>24==0){N=A+E|0;P=N>>8;L=B+D>>8;if((P|L)>>>0<1024){_=P<<1&14|L<<4&112|d[(c[263194]|0)+((L<<5&-256)+(N>>10&-2))|0]<<7}else{if((a[1044415]|0)!=3){$=l;break}_=P<<1&14|L<<4&112}L=a[i+(_|1)|0]|0;if(L<<24>>24==0|J){$=l;break}P=m+C|0;N=(P|0)<(C|0);M=L&255;L=n;while(1){if(!N){Q=P;do{T=(Q<<1)+t|0;R=ab(c[277223]|0,L)|0;U=R+T|0;if((Q|0)>=(f|0)&(p|0)>(d[(c[277219]|0)+U|0]|0)&(Q|0)<(g|0)){S=e[(c[277225]|0)+(M<<1)>>1]|0;V=(a[(c[277215]|0)+U|0]&32)==0;if(V){W=c[277228]|0;aa=W;ac=W&-2082}else{W=e[(c[277213]|0)+(U<<1)>>1]|0;aa=W;ac=W&63454}if(V){ad=c[277228]|0}else{ad=e[(c[277213]|0)+(U<<1)>>1]|0}U=((ad^S)&2081|e[(c[277220]|0)+((S&2081&aa)+((ac+(S&63454)|0)>>>1)<<1)>>1])&65535;S=T+1|0;b[(c[277218]|0)+(S+R<<1)>>1]=U;R=(ab(c[277223]|0,L)|0)+T|0;b[(c[277218]|0)+(R<<1)>>1]=U;U=(ab(c[277223]|0,L)|0)+S|0;a[(c[277219]|0)+U|0]=h;U=(ab(c[277223]|0,L)|0)+T|0;a[(c[277219]|0)+U|0]=h}Q=Q-1|0;}while((Q|0)>=(C|0))}Q=L+1|0;if((Q|0)<(x|0)){L=Q}else{$=l;break}}}else{$=K}}while(0);K=C+1|0;if((K|0)<(r|0)){A=A+F|0;B=B+G|0;y=$;C=K}else{break}}}}while(0);D=x+v|0;E=(ab(c[277223]|0,x)|0)+t|0;z=c[277231]|0;if(D>>>0>z>>>0){break}else{n=0;s=x;t=E;v=D;w=w+(x<<4)|0;u=z}}return}function UY(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;i=c[263194]|0;do{if((a[(c[263195]|0)+8496|0]&1)==0){j=1106168}else{if((a[1106089]|0)==0){j=1125528;break}k=d[1044485]|0;c[276541]=7080+(k<<5);l=0;do{m=l<<1&2;n=l&2;o=l&4;p=0;do{b[1125528+(l<<9)+(p<<1)>>1]=d[(p>>>1&28|n)+(7080+(k<<5))|0]<<6|d[(p<<2&28|m)+(7080+(k<<5))|0]<<11|d[(p>>>3&24|o)+(7080+(k<<5))|0];p=p+1|0;}while(p>>>0<256);l=l+1|0;}while(l>>>0<8);a[1106089]=0;j=1125528}}while(0);c[277226]=j;c[277225]=(a[1108928]|0)!=0?1393712:j;j=c[277230]|0;if((a[1044434]|0)==0){q=f;r=g;s=0;t=1;u=j}else{l=d[1044432]|0;k=((j-(d[1044433]|0)|0)>>>0)%(l>>>0)|0;p=g-1+l|0;q=f-((f|0)%(l|0)|0)|0;r=p-((p|0)%(l|0)|0)|0;s=k;t=l;u=j-k|0}k=c[277231]|0;if(u>>>0>k>>>0){return}j=(q|0)<(r|0);l=t&255;p=h+7|0;h=p&255;o=r-1|0;m=t-1|0;n=s;s=t;t=ab(c[277223]|0,u)|0;v=u;w=1097960+(u<<4)|0;u=k;while(1){if((s+v|0)>>>0>u>>>0){x=u+1-v|0}else{x=s}k=e[w+12>>1]<<19>>19;y=e[w+8>>1]<<19;z=e[w+10>>1]<<19;A=v+1|0;B=(e[w+14>>1]<<19>>19)-(z>>19)|0;C=(B&8192|0)!=0?B|-1024:B&1023;B=b[w+2>>1]|0;D=((a[1044414]|0)==0?A:A^255)&255;A=(ab(D,B)|0)&-64;E=A+(y>>11)+((ab(C,B)|0)&-64)|0;B=b[w+6>>1]|0;A=(ab(B,D)|0)&-64;D=A+(z>>11)+((ab(C,B)|0)&-64)|0;B=b[w>>1]|0;if((a[1044413]|0)==0){C=b[w+4>>1]|0;F=B;G=C<<16>>16;H=q;I=C}else{C=b[w+4>>1]|0;F=-B|0;G=-(C<<16>>16)|0;H=o;I=C}C=k-(y>>19)|0;y=(C&8192|0)!=0?C|-1024:C&1023;C=ab(H,B)|0;k=C+((ab(B,y)|0)&-64)|0;B=I<<16>>16;C=ab(B,H)|0;z=((ab(B,y)|0)&-64)+C|0;do{if((a[1044415]|0)==0){if(!j){break}C=(n|0)>=(x|0);y=k;B=z;A=1;J=q;while(1){K=A-1&255;do{if(K<<24>>24==0){L=y+E|0;M=(B+D|0)>>>8;N=a[i+(M<<4&112|L>>>8<<1&14|d[(c[263194]|0)+(M<<5&32512|L>>>10&254)|0]<<7|1)|0]|0;if(N<<24>>24==0|C){O=l;break}L=m+J|0;M=(L|0)<(J|0);P=N&255;N=n;while(1){if(!M){Q=L;do{R=(Q<<1)+t|0;S=ab(c[277223]|0,N)|0;if((Q|0)>=(f|0)&(p|0)>(d[(c[277219]|0)+(S+R)|0]|0)&(Q|0)<(g|0)){T=e[(c[277225]|0)+(P<<1)>>1]|0;U=c[277228]|0;V=(((T&63454)+(U&-2082)|0)>>>1)+(U&2081&T)|0;if((a[1108928]|0)==0){W=V&65535}else{W=(e[(c[277220]|0)+(V<<1)>>1]|(T^U)&2081)&65535}U=R+1|0;b[(c[277218]|0)+(U+S<<1)>>1]=W;S=(ab(c[277223]|0,N)|0)+R|0;b[(c[277218]|0)+(S<<1)>>1]=W;S=(ab(c[277223]|0,N)|0)+U|0;a[(c[277219]|0)+S|0]=h;S=(ab(c[277223]|0,N)|0)+R|0;a[(c[277219]|0)+S|0]=h}Q=Q-1|0;}while((Q|0)>=(J|0))}Q=N+1|0;if((Q|0)<(x|0)){N=Q}else{O=l;break}}}else{O=K}}while(0);K=J+1|0;if((K|0)<(r|0)){y=y+F|0;B=B+G|0;A=O;J=K}else{break}}}else{if(!j){break}J=(n|0)>=(x|0);A=k;B=z;y=1;C=q;while(1){K=y-1&255;do{if(K<<24>>24==0){N=A+E|0;P=N>>8;L=B+D>>8;if((P|L)>>>0<1024){X=P<<1&14|L<<4&112|d[(c[263194]|0)+((L<<5&-256)+(N>>10&-2))|0]<<7}else{if((a[1044415]|0)!=3){Y=l;break}X=P<<1&14|L<<4&112}L=a[i+(X|1)|0]|0;if(L<<24>>24==0|J){Y=l;break}P=m+C|0;N=(P|0)<(C|0);M=L&255;L=n;while(1){if(!N){Q=P;do{S=(Q<<1)+t|0;R=ab(c[277223]|0,L)|0;if((Q|0)>=(f|0)&(p|0)>(d[(c[277219]|0)+(R+S)|0]|0)&(Q|0)<(g|0)){U=e[(c[277225]|0)+(M<<1)>>1]|0;T=c[277228]|0;V=(((U&63454)+(T&-2082)|0)>>>1)+(T&2081&U)|0;if((a[1108928]|0)==0){Z=V&65535}else{Z=(e[(c[277220]|0)+(V<<1)>>1]|(U^T)&2081)&65535}T=S+1|0;b[(c[277218]|0)+(T+R<<1)>>1]=Z;R=(ab(c[277223]|0,L)|0)+S|0;b[(c[277218]|0)+(R<<1)>>1]=Z;R=(ab(c[277223]|0,L)|0)+T|0;a[(c[277219]|0)+R|0]=h;R=(ab(c[277223]|0,L)|0)+S|0;a[(c[277219]|0)+R|0]=h}Q=Q-1|0;}while((Q|0)>=(C|0))}Q=L+1|0;if((Q|0)<(x|0)){L=Q}else{Y=l;break}}}else{Y=K}}while(0);K=C+1|0;if((K|0)<(r|0)){A=A+F|0;B=B+G|0;y=Y;C=K}else{break}}}}while(0);D=x+v|0;E=(ab(c[277223]|0,x)|0)+t|0;z=c[277231]|0;if(D>>>0>z>>>0){break}else{n=0;s=x;t=E;v=D;w=w+(x<<4)|0;u=z}}return}function UZ(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0;i=c[263194]|0;do{if((a[(c[263195]|0)+8496|0]&1)==0){j=1106168}else{if((a[1106089]|0)==0){j=1125528;break}k=d[1044485]|0;c[276541]=7080+(k<<5);l=0;do{m=l<<1&2;n=l&2;o=l&4;p=0;do{b[1125528+(l<<9)+(p<<1)>>1]=d[(p>>>1&28|n)+(7080+(k<<5))|0]<<6|d[(p<<2&28|m)+(7080+(k<<5))|0]<<11|d[(p>>>3&24|o)+(7080+(k<<5))|0];p=p+1|0;}while(p>>>0<256);l=l+1|0;}while(l>>>0<8);a[1106089]=0;j=1125528}}while(0);c[277226]=j;c[277225]=(a[1108928]|0)!=0?1393712:j;j=c[277230]|0;if((a[1044434]|0)==0){q=f;r=g;s=0;t=1;u=j}else{l=d[1044432]|0;k=((j-(d[1044433]|0)|0)>>>0)%(l>>>0)|0;p=g-1+l|0;q=f-((f|0)%(l|0)|0)|0;r=p-((p|0)%(l|0)|0)|0;s=k;t=l;u=j-k|0}k=c[277231]|0;if(u>>>0>k>>>0){return}j=(q|0)<(r|0);l=t&255;p=h+7|0;h=p&255;o=r-1|0;m=t-1|0;n=s;s=t;t=ab(c[277223]|0,u)|0;v=u;w=1097960+(u<<4)|0;u=k;while(1){if((s+v|0)>>>0>u>>>0){x=u+1-v|0}else{x=s}k=e[w+12>>1]<<19>>19;y=e[w+8>>1]<<19;z=e[w+10>>1]<<19;A=v+1|0;B=(e[w+14>>1]<<19>>19)-(z>>19)|0;C=(B&8192|0)!=0?B|-1024:B&1023;B=b[w+2>>1]|0;D=((a[1044414]|0)==0?A:A^255)&255;A=(ab(D,B)|0)&-64;E=A+(y>>11)+((ab(C,B)|0)&-64)|0;B=b[w+6>>1]|0;A=(ab(B,D)|0)&-64;D=A+(z>>11)+((ab(C,B)|0)&-64)|0;B=b[w>>1]|0;if((a[1044413]|0)==0){C=b[w+4>>1]|0;F=B;G=C<<16>>16;H=q;I=C}else{C=b[w+4>>1]|0;F=-B|0;G=-(C<<16>>16)|0;H=o;I=C}C=k-(y>>19)|0;y=(C&8192|0)!=0?C|-1024:C&1023;C=ab(H,B)|0;k=C+((ab(B,y)|0)&-64)|0;B=I<<16>>16;C=ab(B,H)|0;z=((ab(B,y)|0)&-64)+C|0;do{if((a[1044415]|0)==0){if(!j){break}C=(n|0)>=(x|0);y=k;B=z;A=1;J=q;while(1){K=A-1&255;do{if(K<<24>>24==0){L=y+E|0;M=(B+D|0)>>>8;N=a[i+(M<<4&112|L>>>8<<1&14|d[(c[263194]|0)+(M<<5&32512|L>>>10&254)|0]<<7|1)|0]|0;if(N<<24>>24==0|C){O=l;break}L=m+J|0;M=(L|0)<(J|0);P=N&255;N=n;while(1){if(!M){Q=L;do{R=(Q<<1)+t|0;S=ab(c[277223]|0,N)|0;T=S+R|0;if((Q|0)>=(f|0)&(p|0)>(d[(c[277219]|0)+T|0]|0)&(Q|0)<(g|0)){do{if((a[1108928]|0)==0){U=b[(c[277225]|0)+(P<<1)>>1]|0;V=U&65535;W=V&63454;if((a[(c[277215]|0)+T|0]&32)==0){X=c[277228]|0;Y=(e[(c[277220]|0)+((((X&-2082)+W|0)>>>1)+(V&2081&X)<<1)>>1]|(X^V)&2081)&65535;break}else{V=b[(c[277213]|0)+(T<<1)>>1]|0;Y=(((V&63454)+W|0)>>>1)+(V&U&2081)&65535;break}}else{U=e[(c[277225]|0)+(P<<1)>>1]|0;V=(a[(c[277215]|0)+T|0]&32)==0;if(V){W=c[277228]|0;Z=W;_=W&-2082}else{W=e[(c[277213]|0)+(T<<1)>>1]|0;Z=W;_=W&63454}if(V){$=c[277228]|0}else{$=e[(c[277213]|0)+(T<<1)>>1]|0}Y=(($^U)&2081|e[(c[277220]|0)+((U&2081&Z)+((_+(U&63454)|0)>>>1)<<1)>>1])&65535}}while(0);T=R+1|0;b[(c[277218]|0)+(T+S<<1)>>1]=Y;U=(ab(c[277223]|0,N)|0)+R|0;b[(c[277218]|0)+(U<<1)>>1]=Y;U=(ab(c[277223]|0,N)|0)+T|0;a[(c[277219]|0)+U|0]=h;U=(ab(c[277223]|0,N)|0)+R|0;a[(c[277219]|0)+U|0]=h}Q=Q-1|0;}while((Q|0)>=(J|0))}Q=N+1|0;if((Q|0)<(x|0)){N=Q}else{O=l;break}}}else{O=K}}while(0);K=J+1|0;if((K|0)<(r|0)){y=y+F|0;B=B+G|0;A=O;J=K}else{break}}}else{if(!j){break}J=(n|0)>=(x|0);A=k;B=z;y=1;C=q;while(1){K=y-1&255;do{if(K<<24>>24==0){N=A+E|0;P=N>>8;L=B+D>>8;if((P|L)>>>0<1024){aa=P<<1&14|L<<4&112|d[(c[263194]|0)+((L<<5&-256)+(N>>10&-2))|0]<<7}else{if((a[1044415]|0)!=3){ac=l;break}aa=P<<1&14|L<<4&112}L=a[i+(aa|1)|0]|0;if(L<<24>>24==0|J){ac=l;break}P=m+C|0;N=(P|0)<(C|0);M=L&255;L=n;while(1){if(!N){Q=P;do{U=(Q<<1)+t|0;T=ab(c[277223]|0,L)|0;V=T+U|0;if((Q|0)>=(f|0)&(p|0)>(d[(c[277219]|0)+V|0]|0)&(Q|0)<(g|0)){do{if((a[1108928]|0)==0){W=b[(c[277225]|0)+(M<<1)>>1]|0;X=W&65535;ad=X&63454;if((a[(c[277215]|0)+V|0]&32)==0){ae=c[277228]|0;af=(e[(c[277220]|0)+((((ae&-2082)+ad|0)>>>1)+(X&2081&ae)<<1)>>1]|(ae^X)&2081)&65535;break}else{X=b[(c[277213]|0)+(V<<1)>>1]|0;af=(((X&63454)+ad|0)>>>1)+(X&W&2081)&65535;break}}else{W=e[(c[277225]|0)+(M<<1)>>1]|0;X=(a[(c[277215]|0)+V|0]&32)==0;if(X){ad=c[277228]|0;ag=ad;ah=ad&-2082}else{ad=e[(c[277213]|0)+(V<<1)>>1]|0;ag=ad;ah=ad&63454}if(X){ai=c[277228]|0}else{ai=e[(c[277213]|0)+(V<<1)>>1]|0}af=((ai^W)&2081|e[(c[277220]|0)+((W&2081&ag)+((ah+(W&63454)|0)>>>1)<<1)>>1])&65535}}while(0);V=U+1|0;b[(c[277218]|0)+(V+T<<1)>>1]=af;R=(ab(c[277223]|0,L)|0)+U|0;b[(c[277218]|0)+(R<<1)>>1]=af;R=(ab(c[277223]|0,L)|0)+V|0;a[(c[277219]|0)+R|0]=h;R=(ab(c[277223]|0,L)|0)+U|0;a[(c[277219]|0)+R|0]=h}Q=Q-1|0;}while((Q|0)>=(C|0))}Q=L+1|0;if((Q|0)<(x|0)){L=Q}else{ac=l;break}}}else{ac=K}}while(0);K=C+1|0;if((K|0)<(r|0)){A=A+F|0;B=B+G|0;y=ac;C=K}else{break}}}}while(0);D=x+v|0;E=(ab(c[277223]|0,x)|0)+t|0;z=c[277231]|0;if(D>>>0>z>>>0){break}else{n=0;s=x;t=E;v=D;w=w+(x<<4)|0;u=z}}return}function U_(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ac=0,ad=0;i=c[263194]|0;do{if((a[(c[263195]|0)+8496|0]&1)==0){j=1106168}else{if((a[1106089]|0)==0){j=1125528;break}k=d[1044485]|0;c[276541]=7080+(k<<5);l=0;do{m=l<<1&2;n=l&2;o=l&4;p=0;do{b[1125528+(l<<9)+(p<<1)>>1]=d[(p>>>1&28|n)+(7080+(k<<5))|0]<<6|d[(p<<2&28|m)+(7080+(k<<5))|0]<<11|d[(p>>>3&24|o)+(7080+(k<<5))|0];p=p+1|0;}while(p>>>0<256);l=l+1|0;}while(l>>>0<8);a[1106089]=0;j=1125528}}while(0);c[277226]=j;c[277225]=(a[1108928]|0)!=0?1393712:j;j=c[277230]|0;if((a[1044434]|0)==0){q=f;r=g;s=0;t=1;u=j}else{l=d[1044432]|0;k=((j-(d[1044433]|0)|0)>>>0)%(l>>>0)|0;p=g-1+l|0;q=f-((f|0)%(l|0)|0)|0;r=p-((p|0)%(l|0)|0)|0;s=k;t=l;u=j-k|0}k=c[277231]|0;if(u>>>0>k>>>0){return}j=(q|0)<(r|0);l=t&255;p=h+7|0;h=p&255;o=r-1|0;m=t-1|0;n=s;s=t;t=ab(c[277223]|0,u)|0;v=u;w=1097960+(u<<4)|0;u=k;while(1){if((s+v|0)>>>0>u>>>0){x=u+1-v|0}else{x=s}k=e[w+12>>1]<<19>>19;y=e[w+8>>1]<<19;z=e[w+10>>1]<<19;A=v+1|0;B=(e[w+14>>1]<<19>>19)-(z>>19)|0;C=(B&8192|0)!=0?B|-1024:B&1023;B=b[w+2>>1]|0;D=((a[1044414]|0)==0?A:A^255)&255;A=(ab(D,B)|0)&-64;E=A+(y>>11)+((ab(C,B)|0)&-64)|0;B=b[w+6>>1]|0;A=(ab(B,D)|0)&-64;D=A+(z>>11)+((ab(C,B)|0)&-64)|0;B=b[w>>1]|0;if((a[1044413]|0)==0){C=b[w+4>>1]|0;F=B;G=C<<16>>16;H=q;I=C}else{C=b[w+4>>1]|0;F=-B|0;G=-(C<<16>>16)|0;H=o;I=C}C=k-(y>>19)|0;y=(C&8192|0)!=0?C|-1024:C&1023;C=ab(H,B)|0;k=C+((ab(B,y)|0)&-64)|0;B=I<<16>>16;C=ab(B,H)|0;z=((ab(B,y)|0)&-64)+C|0;do{if((a[1044415]|0)==0){if(!j){break}C=(n|0)>=(x|0);y=k;B=z;A=1;J=q;while(1){K=A-1&255;do{if(K<<24>>24==0){L=y+E|0;M=(B+D|0)>>>8;N=a[i+(M<<4&112|L>>>8<<1&14|d[(c[263194]|0)+(M<<5&32512|L>>>10&254)|0]<<7|1)|0]|0;if(N<<24>>24==0|C){O=l;break}L=m+J|0;M=(L|0)<(J|0);P=N&255;N=n;while(1){if(!M){Q=L;do{R=(Q<<1)+t|0;S=ab(c[277223]|0,N)|0;T=S+R|0;if((Q|0)>=(f|0)&(p|0)>(d[(c[277219]|0)+T|0]|0)&(Q|0)<(g|0)){U=b[(c[277225]|0)+(P<<1)>>1]|0;if((a[(c[277215]|0)+T|0]&32)==0){V=c[277228]&65535}else{V=b[(c[277213]|0)+(T<<1)>>1]|0}T=U&-2048;W=V&-2048;X=(T&65535)>(W&65535)?T-W&65535:0;W=U&2016;T=V&2016;if((W&65535)>(T&65535)){Y=(W-T&65535)+X&65535}else{Y=X}X=U&31;U=V&31;if((X&65535)>(U&65535)){Z=(X-U&65535)+Y&65535}else{Z=Y}U=R+1|0;b[(c[277218]|0)+(U+S<<1)>>1]=Z;S=(ab(c[277223]|0,N)|0)+R|0;b[(c[277218]|0)+(S<<1)>>1]=Z;S=(ab(c[277223]|0,N)|0)+U|0;a[(c[277219]|0)+S|0]=h;S=(ab(c[277223]|0,N)|0)+R|0;a[(c[277219]|0)+S|0]=h}Q=Q-1|0;}while((Q|0)>=(J|0))}Q=N+1|0;if((Q|0)<(x|0)){N=Q}else{O=l;break}}}else{O=K}}while(0);K=J+1|0;if((K|0)<(r|0)){y=y+F|0;B=B+G|0;A=O;J=K}else{break}}}else{if(!j){break}J=(n|0)>=(x|0);A=k;B=z;y=1;C=q;while(1){K=y-1&255;do{if(K<<24>>24==0){N=A+E|0;P=N>>8;L=B+D>>8;if((P|L)>>>0<1024){_=P<<1&14|L<<4&112|d[(c[263194]|0)+((L<<5&-256)+(N>>10&-2))|0]<<7}else{if((a[1044415]|0)!=3){$=l;break}_=P<<1&14|L<<4&112}L=a[i+(_|1)|0]|0;if(L<<24>>24==0|J){$=l;break}P=m+C|0;N=(P|0)<(C|0);M=L&255;L=n;while(1){if(!N){Q=P;do{S=(Q<<1)+t|0;R=ab(c[277223]|0,L)|0;U=R+S|0;if((Q|0)>=(f|0)&(p|0)>(d[(c[277219]|0)+U|0]|0)&(Q|0)<(g|0)){X=b[(c[277225]|0)+(M<<1)>>1]|0;if((a[(c[277215]|0)+U|0]&32)==0){aa=c[277228]&65535}else{aa=b[(c[277213]|0)+(U<<1)>>1]|0}U=X&-2048;T=aa&-2048;W=(U&65535)>(T&65535)?U-T&65535:0;T=X&2016;U=aa&2016;if((T&65535)>(U&65535)){ac=(T-U&65535)+W&65535}else{ac=W}W=X&31;X=aa&31;if((W&65535)>(X&65535)){ad=(W-X&65535)+ac&65535}else{ad=ac}X=S+1|0;b[(c[277218]|0)+(X+R<<1)>>1]=ad;R=(ab(c[277223]|0,L)|0)+S|0;b[(c[277218]|0)+(R<<1)>>1]=ad;R=(ab(c[277223]|0,L)|0)+X|0;a[(c[277219]|0)+R|0]=h;R=(ab(c[277223]|0,L)|0)+S|0;a[(c[277219]|0)+R|0]=h}Q=Q-1|0;}while((Q|0)>=(C|0))}Q=L+1|0;if((Q|0)<(x|0)){L=Q}else{$=l;break}}}else{$=K}}while(0);K=C+1|0;if((K|0)<(r|0)){A=A+F|0;B=B+G|0;y=$;C=K}else{break}}}}while(0);D=x+v|0;E=(ab(c[277223]|0,x)|0)+t|0;z=c[277231]|0;if(D>>>0>z>>>0){break}else{n=0;s=x;t=E;v=D;w=w+(x<<4)|0;u=z}}return}function U$(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ac=0,ad=0,ae=0;i=c[263194]|0;do{if((a[(c[263195]|0)+8496|0]&1)==0){j=1106168}else{if((a[1106089]|0)==0){j=1125528;break}k=d[1044485]|0;c[276541]=7080+(k<<5);l=0;do{m=l<<1&2;n=l&2;o=l&4;p=0;do{b[1125528+(l<<9)+(p<<1)>>1]=d[(p>>>1&28|n)+(7080+(k<<5))|0]<<6|d[(p<<2&28|m)+(7080+(k<<5))|0]<<11|d[(p>>>3&24|o)+(7080+(k<<5))|0];p=p+1|0;}while(p>>>0<256);l=l+1|0;}while(l>>>0<8);a[1106089]=0;j=1125528}}while(0);c[277226]=j;c[277225]=(a[1108928]|0)!=0?1393712:j;j=c[277230]|0;if((a[1044434]|0)==0){q=f;r=g;s=0;t=1;u=j}else{l=d[1044432]|0;k=((j-(d[1044433]|0)|0)>>>0)%(l>>>0)|0;p=g-1+l|0;q=f-((f|0)%(l|0)|0)|0;r=p-((p|0)%(l|0)|0)|0;s=k;t=l;u=j-k|0}k=c[277231]|0;if(u>>>0>k>>>0){return}j=(q|0)<(r|0);l=t&255;p=h+7|0;h=p&255;o=r-1|0;m=t-1|0;n=s;s=t;t=ab(c[277223]|0,u)|0;v=u;w=1097960+(u<<4)|0;u=k;while(1){if((s+v|0)>>>0>u>>>0){x=u+1-v|0}else{x=s}k=e[w+12>>1]<<19>>19;y=e[w+8>>1]<<19;z=e[w+10>>1]<<19;A=v+1|0;B=(e[w+14>>1]<<19>>19)-(z>>19)|0;C=(B&8192|0)!=0?B|-1024:B&1023;B=b[w+2>>1]|0;D=((a[1044414]|0)==0?A:A^255)&255;A=(ab(D,B)|0)&-64;E=A+(y>>11)+((ab(C,B)|0)&-64)|0;B=b[w+6>>1]|0;A=(ab(B,D)|0)&-64;D=A+(z>>11)+((ab(C,B)|0)&-64)|0;B=b[w>>1]|0;if((a[1044413]|0)==0){C=b[w+4>>1]|0;F=B;G=C<<16>>16;H=q;I=C}else{C=b[w+4>>1]|0;F=-B|0;G=-(C<<16>>16)|0;H=o;I=C}C=k-(y>>19)|0;y=(C&8192|0)!=0?C|-1024:C&1023;C=ab(H,B)|0;k=C+((ab(B,y)|0)&-64)|0;B=I<<16>>16;C=ab(B,H)|0;z=((ab(B,y)|0)&-64)+C|0;do{if((a[1044415]|0)==0){if(!j){break}C=(n|0)>=(x|0);y=k;B=z;A=1;J=q;while(1){K=A-1&255;do{if(K<<24>>24==0){L=y+E|0;M=(B+D|0)>>>8;N=a[i+(M<<4&112|L>>>8<<1&14|d[(c[263194]|0)+(M<<5&32512|L>>>10&254)|0]<<7|1)|0]|0;if(N<<24>>24==0|C){O=l;break}L=m+J|0;M=(L|0)<(J|0);P=N&255;N=n;while(1){if(!M){Q=L;do{R=(Q<<1)+t|0;S=ab(c[277223]|0,N)|0;if((Q|0)>=(f|0)&(p|0)>(d[(c[277219]|0)+(S+R)|0]|0)&(Q|0)<(g|0)){T=b[(c[277225]|0)+(P<<1)>>1]|0;do{if((a[1108928]|0)==0){U=b[(c[277221]|0)+(((T&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{V=c[277228]&65535;W=T&-2048;X=V&-2048;Y=(W&65535)>(X&65535)?W-X&65535:0;X=T&2016;W=V&2016;if((X&65535)>(W&65535)){Z=(X-W&65535)+Y&65535}else{Z=Y}Y=T&31;W=V&31;if((Y&65535)<=(W&65535)){U=Z;break}U=(Y-W&65535)+Z&65535}}while(0);T=R+1|0;b[(c[277218]|0)+(T+S<<1)>>1]=U;W=(ab(c[277223]|0,N)|0)+R|0;b[(c[277218]|0)+(W<<1)>>1]=U;W=(ab(c[277223]|0,N)|0)+T|0;a[(c[277219]|0)+W|0]=h;W=(ab(c[277223]|0,N)|0)+R|0;a[(c[277219]|0)+W|0]=h}Q=Q-1|0;}while((Q|0)>=(J|0))}Q=N+1|0;if((Q|0)<(x|0)){N=Q}else{O=l;break}}}else{O=K}}while(0);K=J+1|0;if((K|0)<(r|0)){y=y+F|0;B=B+G|0;A=O;J=K}else{break}}}else{if(!j){break}J=(n|0)>=(x|0);A=k;B=z;y=1;C=q;while(1){K=y-1&255;do{if(K<<24>>24==0){N=A+E|0;P=N>>8;L=B+D>>8;if((P|L)>>>0<1024){_=P<<1&14|L<<4&112|d[(c[263194]|0)+((L<<5&-256)+(N>>10&-2))|0]<<7}else{if((a[1044415]|0)!=3){$=l;break}_=P<<1&14|L<<4&112}L=a[i+(_|1)|0]|0;if(L<<24>>24==0|J){$=l;break}P=m+C|0;N=(P|0)<(C|0);M=L&255;L=n;while(1){if(!N){Q=P;do{W=(Q<<1)+t|0;T=ab(c[277223]|0,L)|0;if((Q|0)>=(f|0)&(p|0)>(d[(c[277219]|0)+(T+W)|0]|0)&(Q|0)<(g|0)){Y=b[(c[277225]|0)+(M<<1)>>1]|0;do{if((a[1108928]|0)==0){aa=b[(c[277221]|0)+(((Y&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{V=c[277228]&65535;X=Y&-2048;ac=V&-2048;ad=(X&65535)>(ac&65535)?X-ac&65535:0;ac=Y&2016;X=V&2016;if((ac&65535)>(X&65535)){ae=(ac-X&65535)+ad&65535}else{ae=ad}ad=Y&31;X=V&31;if((ad&65535)<=(X&65535)){aa=ae;break}aa=(ad-X&65535)+ae&65535}}while(0);Y=W+1|0;b[(c[277218]|0)+(Y+T<<1)>>1]=aa;R=(ab(c[277223]|0,L)|0)+W|0;b[(c[277218]|0)+(R<<1)>>1]=aa;R=(ab(c[277223]|0,L)|0)+Y|0;a[(c[277219]|0)+R|0]=h;R=(ab(c[277223]|0,L)|0)+W|0;a[(c[277219]|0)+R|0]=h}Q=Q-1|0;}while((Q|0)>=(C|0))}Q=L+1|0;if((Q|0)<(x|0)){L=Q}else{$=l;break}}}else{$=K}}while(0);K=C+1|0;if((K|0)<(r|0)){A=A+F|0;B=B+G|0;y=$;C=K}else{break}}}}while(0);D=x+v|0;E=(ab(c[277223]|0,x)|0)+t|0;z=c[277231]|0;if(D>>>0>z>>>0){break}else{n=0;s=x;t=E;v=D;w=w+(x<<4)|0;u=z}}return}function U0(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0;i=c[263194]|0;do{if((a[(c[263195]|0)+8496|0]&1)==0){j=1106168}else{if((a[1106089]|0)==0){j=1125528;break}k=d[1044485]|0;c[276541]=7080+(k<<5);l=0;do{m=l<<1&2;n=l&2;o=l&4;p=0;do{b[1125528+(l<<9)+(p<<1)>>1]=d[(p>>>1&28|n)+(7080+(k<<5))|0]<<6|d[(p<<2&28|m)+(7080+(k<<5))|0]<<11|d[(p>>>3&24|o)+(7080+(k<<5))|0];p=p+1|0;}while(p>>>0<256);l=l+1|0;}while(l>>>0<8);a[1106089]=0;j=1125528}}while(0);c[277226]=j;c[277225]=(a[1108928]|0)!=0?1393712:j;j=c[277230]|0;if((a[1044434]|0)==0){q=f;r=g;s=0;t=1;u=j}else{l=d[1044432]|0;k=((j-(d[1044433]|0)|0)>>>0)%(l>>>0)|0;p=g-1+l|0;q=f-((f|0)%(l|0)|0)|0;r=p-((p|0)%(l|0)|0)|0;s=k;t=l;u=j-k|0}k=c[277231]|0;if(u>>>0>k>>>0){return}j=(q|0)<(r|0);l=t&255;p=h+7|0;h=p&255;o=r-1|0;m=t-1|0;n=s;s=t;t=ab(c[277223]|0,u)|0;v=u;w=1097960+(u<<4)|0;u=k;while(1){if((s+v|0)>>>0>u>>>0){x=u+1-v|0}else{x=s}k=e[w+12>>1]<<19>>19;y=e[w+8>>1]<<19;z=e[w+10>>1]<<19;A=v+1|0;B=(e[w+14>>1]<<19>>19)-(z>>19)|0;C=(B&8192|0)!=0?B|-1024:B&1023;B=b[w+2>>1]|0;D=((a[1044414]|0)==0?A:A^255)&255;A=(ab(D,B)|0)&-64;E=A+(y>>11)+((ab(C,B)|0)&-64)|0;B=b[w+6>>1]|0;A=(ab(B,D)|0)&-64;D=A+(z>>11)+((ab(C,B)|0)&-64)|0;B=b[w>>1]|0;if((a[1044413]|0)==0){C=b[w+4>>1]|0;F=B;G=C<<16>>16;H=q;I=C}else{C=b[w+4>>1]|0;F=-B|0;G=-(C<<16>>16)|0;H=o;I=C}C=k-(y>>19)|0;y=(C&8192|0)!=0?C|-1024:C&1023;C=ab(H,B)|0;k=C+((ab(B,y)|0)&-64)|0;B=I<<16>>16;C=ab(B,H)|0;z=((ab(B,y)|0)&-64)+C|0;do{if((a[1044415]|0)==0){if(!j){break}C=(n|0)>=(x|0);y=k;B=z;A=1;J=q;while(1){K=A-1&255;do{if(K<<24>>24==0){L=y+E|0;M=(B+D|0)>>>8;N=a[i+(M<<4&112|L>>>8<<1&14|d[(c[263194]|0)+(M<<5&32512|L>>>10&254)|0]<<7|1)|0]|0;if(N<<24>>24==0|C){O=l;break}L=m+J|0;M=(L|0)<(J|0);P=N&255;N=n;while(1){if(!M){Q=L;do{R=(Q<<1)+t|0;S=ab(c[277223]|0,N)|0;T=S+R|0;if((Q|0)>=(f|0)&(p|0)>(d[(c[277219]|0)+T|0]|0)&(Q|0)<(g|0)){do{if((a[1108928]|0)==0){U=b[(c[277225]|0)+(P<<1)>>1]|0;if((a[(c[277215]|0)+T|0]&32)!=0){V=b[(c[277221]|0)+((U&65535|67616)-(b[(c[277213]|0)+(T<<1)>>1]&63454)>>1<<1)>>1]|0;break}W=c[277228]&65535;X=U&-2048;Y=W&-2048;Z=(X&65535)>(Y&65535)?X-Y&65535:0;Y=U&2016;X=W&2016;if((Y&65535)>(X&65535)){_=(Y-X&65535)+Z&65535}else{_=Z}Z=U&31;U=W&31;if((Z&65535)<=(U&65535)){V=_;break}V=(Z-U&65535)+_&65535}else{U=b[(c[277225]|0)+(P<<1)>>1]|0;if((a[(c[277215]|0)+T|0]&32)==0){$=c[277228]&65535}else{$=b[(c[277213]|0)+(T<<1)>>1]|0}Z=U&-2048;W=$&-2048;X=(Z&65535)>(W&65535)?Z-W&65535:0;W=U&2016;Z=$&2016;if((W&65535)>(Z&65535)){aa=(W-Z&65535)+X&65535}else{aa=X}X=U&31;U=$&31;if((X&65535)<=(U&65535)){V=aa;break}V=(X-U&65535)+aa&65535}}while(0);T=R+1|0;b[(c[277218]|0)+(T+S<<1)>>1]=V;U=(ab(c[277223]|0,N)|0)+R|0;b[(c[277218]|0)+(U<<1)>>1]=V;U=(ab(c[277223]|0,N)|0)+T|0;a[(c[277219]|0)+U|0]=h;U=(ab(c[277223]|0,N)|0)+R|0;a[(c[277219]|0)+U|0]=h}Q=Q-1|0;}while((Q|0)>=(J|0))}Q=N+1|0;if((Q|0)<(x|0)){N=Q}else{O=l;break}}}else{O=K}}while(0);K=J+1|0;if((K|0)<(r|0)){y=y+F|0;B=B+G|0;A=O;J=K}else{break}}}else{if(!j){break}J=(n|0)>=(x|0);A=k;B=z;y=1;C=q;while(1){K=y-1&255;do{if(K<<24>>24==0){N=A+E|0;P=N>>8;L=B+D>>8;if((P|L)>>>0<1024){ac=P<<1&14|L<<4&112|d[(c[263194]|0)+((L<<5&-256)+(N>>10&-2))|0]<<7}else{if((a[1044415]|0)!=3){ad=l;break}ac=P<<1&14|L<<4&112}L=a[i+(ac|1)|0]|0;if(L<<24>>24==0|J){ad=l;break}P=m+C|0;N=(P|0)<(C|0);M=L&255;L=n;while(1){if(!N){Q=P;do{U=(Q<<1)+t|0;T=ab(c[277223]|0,L)|0;X=T+U|0;if((Q|0)>=(f|0)&(p|0)>(d[(c[277219]|0)+X|0]|0)&(Q|0)<(g|0)){do{if((a[1108928]|0)==0){Z=b[(c[277225]|0)+(M<<1)>>1]|0;if((a[(c[277215]|0)+X|0]&32)!=0){ae=b[(c[277221]|0)+((Z&65535|67616)-(b[(c[277213]|0)+(X<<1)>>1]&63454)>>1<<1)>>1]|0;break}W=c[277228]&65535;Y=Z&-2048;af=W&-2048;ag=(Y&65535)>(af&65535)?Y-af&65535:0;af=Z&2016;Y=W&2016;if((af&65535)>(Y&65535)){ah=(af-Y&65535)+ag&65535}else{ah=ag}ag=Z&31;Z=W&31;if((ag&65535)<=(Z&65535)){ae=ah;break}ae=(ag-Z&65535)+ah&65535}else{Z=b[(c[277225]|0)+(M<<1)>>1]|0;if((a[(c[277215]|0)+X|0]&32)==0){ai=c[277228]&65535}else{ai=b[(c[277213]|0)+(X<<1)>>1]|0}ag=Z&-2048;W=ai&-2048;Y=(ag&65535)>(W&65535)?ag-W&65535:0;W=Z&2016;ag=ai&2016;if((W&65535)>(ag&65535)){aj=(W-ag&65535)+Y&65535}else{aj=Y}Y=Z&31;Z=ai&31;if((Y&65535)<=(Z&65535)){ae=aj;break}ae=(Y-Z&65535)+aj&65535}}while(0);X=U+1|0;b[(c[277218]|0)+(X+T<<1)>>1]=ae;R=(ab(c[277223]|0,L)|0)+U|0;b[(c[277218]|0)+(R<<1)>>1]=ae;R=(ab(c[277223]|0,L)|0)+X|0;a[(c[277219]|0)+R|0]=h;R=(ab(c[277223]|0,L)|0)+U|0;a[(c[277219]|0)+R|0]=h}Q=Q-1|0;}while((Q|0)>=(C|0))}Q=L+1|0;if((Q|0)<(x|0)){L=Q}else{ad=l;break}}}else{ad=K}}while(0);K=C+1|0;if((K|0)<(r|0)){A=A+F|0;B=B+G|0;y=ad;C=K}else{break}}}}while(0);D=x+v|0;E=(ab(c[277223]|0,x)|0)+t|0;z=c[277231]|0;if(D>>>0>z>>>0){break}else{n=0;s=x;t=E;v=D;w=w+(x<<4)|0;u=z}}return}function U1(d,e,f){d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;c[277226]=1106168;c[277225]=(a[1108928]|0)!=0?1393712:1106168;g=c[277230]|0;h=c[277231]|0;if(g>>>0>h>>>0){return}i=e>>>0<f>>>0;j=d;d=g;g=h;while(1){if(i){h=e;do{k=(h<<1)+j|0;if((a[(c[277219]|0)+k|0]|0)==0){l=b[c[277225]>>1]|0;m=k+1|0;b[(c[277218]|0)+(m<<1)>>1]=l;b[(c[277218]|0)+(k<<1)>>1]=l;a[(c[277219]|0)+m|0]=1;a[(c[277219]|0)+k|0]=1}h=h+1|0;}while(h>>>0<f>>>0);n=c[277231]|0}else{n=g}h=d+1|0;if(h>>>0>n>>>0){break}else{j=(c[277223]|0)+j|0;d=h;g=n}}return}function U2(d,f,g){d=d|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;c[277226]=1106168;c[277225]=(a[1108928]|0)!=0?1393712:1106168;h=c[277230]|0;i=c[277231]|0;if(h>>>0>i>>>0){return}j=f>>>0<g>>>0;k=d;d=h;h=i;while(1){if(j){i=f;do{l=(i<<1)+k|0;if((a[(c[277219]|0)+l|0]|0)==0){m=e[c[277225]>>1]|0;n=(a[(c[277215]|0)+l|0]&32)==0;if(n){o=c[277228]|0;p=o;q=o&-2082}else{o=e[(c[277213]|0)+(l<<1)>>1]|0;p=o;q=o&63454}if(n){r=c[277228]|0}else{r=e[(c[277213]|0)+(l<<1)>>1]|0}n=((r^m)&2081|e[(c[277220]|0)+((m&2081&p)+((q+(m&63454)|0)>>>1)<<1)>>1])&65535;m=l+1|0;b[(c[277218]|0)+(m<<1)>>1]=n;b[(c[277218]|0)+(l<<1)>>1]=n;a[(c[277219]|0)+m|0]=1;a[(c[277219]|0)+l|0]=1}i=i+1|0;}while(i>>>0<g>>>0);s=c[277231]|0}else{s=h}i=d+1|0;if(i>>>0>s>>>0){break}else{k=(c[277223]|0)+k|0;d=i;h=s}}return}function U3(d,f,g){d=d|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;c[277226]=1106168;c[277225]=(a[1108928]|0)!=0?1393712:1106168;h=c[277230]|0;i=c[277231]|0;if(h>>>0>i>>>0){return}j=f>>>0<g>>>0;k=d;d=h;h=i;while(1){if(j){i=f;do{l=(i<<1)+k|0;if((a[(c[277219]|0)+l|0]|0)==0){m=e[c[277225]>>1]|0;n=c[277228]|0;o=(((m&63454)+(n&-2082)|0)>>>1)+(n&2081&m)|0;if((a[1108928]|0)==0){p=o&65535}else{p=(e[(c[277220]|0)+(o<<1)>>1]|(m^n)&2081)&65535}n=l+1|0;b[(c[277218]|0)+(n<<1)>>1]=p;b[(c[277218]|0)+(l<<1)>>1]=p;a[(c[277219]|0)+n|0]=1;a[(c[277219]|0)+l|0]=1}i=i+1|0;}while(i>>>0<g>>>0);q=c[277231]|0}else{q=h}i=d+1|0;if(i>>>0>q>>>0){break}else{k=(c[277223]|0)+k|0;d=i;h=q}}return}function U4(d,f,g){d=d|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;c[277226]=1106168;c[277225]=(a[1108928]|0)!=0?1393712:1106168;h=c[277230]|0;i=c[277231]|0;if(h>>>0>i>>>0){return}j=f>>>0<g>>>0;k=d;d=h;h=i;while(1){if(j){i=f;do{l=(i<<1)+k|0;if((a[(c[277219]|0)+l|0]|0)==0){do{if((a[1108928]|0)==0){m=b[c[277225]>>1]|0;n=m&65535;o=n&63454;if((a[(c[277215]|0)+l|0]&32)==0){p=c[277228]|0;q=(e[(c[277220]|0)+((((p&-2082)+o|0)>>>1)+(n&2081&p)<<1)>>1]|(p^n)&2081)&65535;break}else{n=b[(c[277213]|0)+(l<<1)>>1]|0;q=(((n&63454)+o|0)>>>1)+(n&m&2081)&65535;break}}else{m=e[c[277225]>>1]|0;n=(a[(c[277215]|0)+l|0]&32)==0;if(n){o=c[277228]|0;r=o;s=o&-2082}else{o=e[(c[277213]|0)+(l<<1)>>1]|0;r=o;s=o&63454}if(n){t=c[277228]|0}else{t=e[(c[277213]|0)+(l<<1)>>1]|0}q=((t^m)&2081|e[(c[277220]|0)+((m&2081&r)+((s+(m&63454)|0)>>>1)<<1)>>1])&65535}}while(0);m=l+1|0;b[(c[277218]|0)+(m<<1)>>1]=q;b[(c[277218]|0)+(l<<1)>>1]=q;a[(c[277219]|0)+m|0]=1;a[(c[277219]|0)+l|0]=1}i=i+1|0;}while(i>>>0<g>>>0);u=c[277231]|0}else{u=h}i=d+1|0;if(i>>>0>u>>>0){break}else{k=(c[277223]|0)+k|0;d=i;h=u}}return}function U5(d,e,f){d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;c[277226]=1106168;c[277225]=(a[1108928]|0)!=0?1393712:1106168;g=c[277230]|0;h=c[277231]|0;if(g>>>0>h>>>0){return}i=e>>>0<f>>>0;j=d;d=g;g=h;while(1){if(i){h=e;do{k=(h<<1)+j|0;if((a[(c[277219]|0)+k|0]|0)==0){l=b[c[277225]>>1]|0;if((a[(c[277215]|0)+k|0]&32)==0){m=c[277228]&65535}else{m=b[(c[277213]|0)+(k<<1)>>1]|0}n=l&-2048;o=m&-2048;p=(n&65535)>(o&65535)?n-o&65535:0;o=l&2016;n=m&2016;if((o&65535)>(n&65535)){q=(o-n&65535)+p&65535}else{q=p}p=l&31;l=m&31;if((p&65535)>(l&65535)){r=(p-l&65535)+q&65535}else{r=q}l=k+1|0;b[(c[277218]|0)+(l<<1)>>1]=r;b[(c[277218]|0)+(k<<1)>>1]=r;a[(c[277219]|0)+l|0]=1;a[(c[277219]|0)+k|0]=1}h=h+1|0;}while(h>>>0<f>>>0);s=c[277231]|0}else{s=g}h=d+1|0;if(h>>>0>s>>>0){break}else{j=(c[277223]|0)+j|0;d=h;g=s}}return}function U6(d,e,f){d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;c[277226]=1106168;c[277225]=(a[1108928]|0)!=0?1393712:1106168;g=c[277230]|0;h=c[277231]|0;if(g>>>0>h>>>0){return}i=e>>>0<f>>>0;j=d;d=g;g=h;while(1){if(i){h=e;do{k=(h<<1)+j|0;if((a[(c[277219]|0)+k|0]|0)==0){l=b[c[277225]>>1]|0;do{if((a[1108928]|0)==0){m=b[(c[277221]|0)+(((l&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{n=c[277228]&65535;o=l&-2048;p=n&-2048;q=(o&65535)>(p&65535)?o-p&65535:0;p=l&2016;o=n&2016;if((p&65535)>(o&65535)){r=(p-o&65535)+q&65535}else{r=q}q=l&31;o=n&31;if((q&65535)<=(o&65535)){m=r;break}m=(q-o&65535)+r&65535}}while(0);l=k+1|0;b[(c[277218]|0)+(l<<1)>>1]=m;b[(c[277218]|0)+(k<<1)>>1]=m;a[(c[277219]|0)+l|0]=1;a[(c[277219]|0)+k|0]=1}h=h+1|0;}while(h>>>0<f>>>0);s=c[277231]|0}else{s=g}h=d+1|0;if(h>>>0>s>>>0){break}else{j=(c[277223]|0)+j|0;d=h;g=s}}return}function U7(d,e,f){d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;c[277226]=1106168;c[277225]=(a[1108928]|0)!=0?1393712:1106168;g=c[277230]|0;h=c[277231]|0;if(g>>>0>h>>>0){return}i=e>>>0<f>>>0;j=d;d=g;g=h;while(1){if(i){h=e;do{k=(h<<1)+j|0;if((a[(c[277219]|0)+k|0]|0)==0){do{if((a[1108928]|0)==0){l=b[c[277225]>>1]|0;if((a[(c[277215]|0)+k|0]&32)!=0){m=b[(c[277221]|0)+((l&65535|67616)-(b[(c[277213]|0)+(k<<1)>>1]&63454)>>1<<1)>>1]|0;break}n=c[277228]&65535;o=l&-2048;p=n&-2048;q=(o&65535)>(p&65535)?o-p&65535:0;p=l&2016;o=n&2016;if((p&65535)>(o&65535)){r=(p-o&65535)+q&65535}else{r=q}q=l&31;l=n&31;if((q&65535)<=(l&65535)){m=r;break}m=(q-l&65535)+r&65535}else{l=b[c[277225]>>1]|0;if((a[(c[277215]|0)+k|0]&32)==0){s=c[277228]&65535}else{s=b[(c[277213]|0)+(k<<1)>>1]|0}q=l&-2048;n=s&-2048;o=(q&65535)>(n&65535)?q-n&65535:0;n=l&2016;q=s&2016;if((n&65535)>(q&65535)){t=(n-q&65535)+o&65535}else{t=o}o=l&31;l=s&31;if((o&65535)<=(l&65535)){m=t;break}m=(o-l&65535)+t&65535}}while(0);l=k+1|0;b[(c[277218]|0)+(l<<1)>>1]=m;b[(c[277218]|0)+(k<<1)>>1]=m;a[(c[277219]|0)+l|0]=1;a[(c[277219]|0)+k|0]=1}h=h+1|0;}while(h>>>0<f>>>0);u=c[277231]|0}else{u=g}h=d+1|0;if(h>>>0>u>>>0){break}else{j=(c[277223]|0)+j|0;d=h;g=u}}return}function U8(e,f,g,h,i,j){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;k=e&1023;l=c[348606]|0;m=(k<<l)+(c[348604]|0)|0;if((e&256|0)==0){n=m}else{n=(c[348602]|0)+m|0}m=n&65535;n=m>>>(l>>>0);l=(e&16384|0)!=0;o=n<<6;do{if(l){p=(c[348622]|0)+o|0;if((a[(c[348618]|0)+n|0]|0)!=0){q=p;break}r=fi[c[348636]&63](p,m,k)|0;a[(c[348618]|0)+n|0]=r;q=p}else{p=(c[348624]|0)+o|0;if((a[(c[348620]|0)+n|0]|0)!=0){q=p;break}r=fi[c[348638]&63](p,m,k)|0;a[(c[348620]|0)+n|0]=r;q=p}}while(0);if((a[(c[348620]|0)+n|0]|0)==2){return}if((a[1394464]|0)==0){s=1106168+((e>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){n=d[1044485]|0;c[276541]=7080+(n<<5);k=0;do{m=k<<1&2;o=k&2;p=k&4;r=0;do{b[1125528+(k<<9)+(r<<1)>>1]=d[(r>>>1&28|o)+(7080+(n<<5))|0]<<6|d[(r<<2&28|m)+(7080+(n<<5))|0]<<11|d[(r>>>3&24|p)+(7080+(n<<5))|0];r=r+1|0;}while(r>>>0<256);k=k+1|0;}while(k>>>0<8);a[1106089]=0}s=1125528+((e>>>10&7)<<9)|0}c[277226]=s;c[277225]=(a[1108928]|0)!=0?1393712:s;s=(d[1394504]|0)+(g<<1)|0;g=a[q+(((e&32768|0)==0?s:56-s|0)+(l?7-h|0:h))|0]|0;if(!(g<<24>>24!=0&(j|0)>0)){return}h=i-1|0;i=(h|0)>-1;l=g&255;g=j;j=f;while(1){if(i){f=h;do{s=(f<<1)+j|0;if((d[1108908]|0)>(d[(c[277219]|0)+s|0]|0)){e=b[(c[277225]|0)+(l<<1)>>1]|0;q=s+1|0;b[(c[277218]|0)+(q<<1)>>1]=e;b[(c[277218]|0)+(s<<1)>>1]=e;e=a[1108909]|0;a[(c[277219]|0)+q|0]=e;a[(c[277219]|0)+s|0]=e}f=f-1|0;}while((f|0)>-1)}f=g-1|0;if((f|0)>0){g=f;j=(c[277223]|0)+j|0}else{break}}return}function U9(f,g,h,i,j,k){f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;l=f&1023;m=c[348606]|0;n=(l<<m)+(c[348604]|0)|0;if((f&256|0)==0){o=n}else{o=(c[348602]|0)+n|0}n=o&65535;o=n>>>(m>>>0);m=(f&16384|0)!=0;p=o<<6;do{if(m){q=(c[348622]|0)+p|0;if((a[(c[348618]|0)+o|0]|0)!=0){r=q;break}s=fi[c[348636]&63](q,n,l)|0;a[(c[348618]|0)+o|0]=s;r=q}else{q=(c[348624]|0)+p|0;if((a[(c[348620]|0)+o|0]|0)!=0){r=q;break}s=fi[c[348638]&63](q,n,l)|0;a[(c[348620]|0)+o|0]=s;r=q}}while(0);if((a[(c[348620]|0)+o|0]|0)==2){return}if((a[1394464]|0)==0){t=1106168+((f>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){o=d[1044485]|0;c[276541]=7080+(o<<5);l=0;do{n=l<<1&2;p=l&2;q=l&4;s=0;do{b[1125528+(l<<9)+(s<<1)>>1]=d[(s>>>1&28|p)+(7080+(o<<5))|0]<<6|d[(s<<2&28|n)+(7080+(o<<5))|0]<<11|d[(s>>>3&24|q)+(7080+(o<<5))|0];s=s+1|0;}while(s>>>0<256);l=l+1|0;}while(l>>>0<8);a[1106089]=0}t=1125528+((f>>>10&7)<<9)|0}c[277226]=t;c[277225]=(a[1108928]|0)!=0?1393712:t;t=(d[1394504]|0)+(h<<1)|0;h=a[r+(((f&32768|0)==0?t:56-t|0)+(m?7-i|0:i))|0]|0;if(!(h<<24>>24!=0&(k|0)>0)){return}i=j-1|0;j=(i|0)>-1;m=h&255;h=k;k=g;while(1){if(j){g=i;do{t=(g<<1)+k|0;if((d[1108908]|0)>(d[(c[277219]|0)+t|0]|0)){f=e[(c[277225]|0)+(m<<1)>>1]|0;r=(a[(c[277215]|0)+t|0]&32)==0;if(r){l=c[277228]|0;u=l;v=l&-2082}else{l=e[(c[277213]|0)+(t<<1)>>1]|0;u=l;v=l&63454}if(r){w=c[277228]|0}else{w=e[(c[277213]|0)+(t<<1)>>1]|0}r=((w^f)&2081|e[(c[277220]|0)+((f&2081&u)+((v+(f&63454)|0)>>>1)<<1)>>1])&65535;f=t+1|0;b[(c[277218]|0)+(f<<1)>>1]=r;b[(c[277218]|0)+(t<<1)>>1]=r;r=a[1108909]|0;a[(c[277219]|0)+f|0]=r;a[(c[277219]|0)+t|0]=r}g=g-1|0;}while((g|0)>-1)}g=h-1|0;if((g|0)>0){h=g;k=(c[277223]|0)+k|0}else{break}}return}function Va(f,g,h,i,j,k){f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;l=f&1023;m=c[348606]|0;n=(l<<m)+(c[348604]|0)|0;if((f&256|0)==0){o=n}else{o=(c[348602]|0)+n|0}n=o&65535;o=n>>>(m>>>0);m=(f&16384|0)!=0;p=o<<6;do{if(m){q=(c[348622]|0)+p|0;if((a[(c[348618]|0)+o|0]|0)!=0){r=q;break}s=fi[c[348636]&63](q,n,l)|0;a[(c[348618]|0)+o|0]=s;r=q}else{q=(c[348624]|0)+p|0;if((a[(c[348620]|0)+o|0]|0)!=0){r=q;break}s=fi[c[348638]&63](q,n,l)|0;a[(c[348620]|0)+o|0]=s;r=q}}while(0);if((a[(c[348620]|0)+o|0]|0)==2){return}if((a[1394464]|0)==0){t=1106168+((f>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){o=d[1044485]|0;c[276541]=7080+(o<<5);l=0;do{n=l<<1&2;p=l&2;q=l&4;s=0;do{b[1125528+(l<<9)+(s<<1)>>1]=d[(s>>>1&28|p)+(7080+(o<<5))|0]<<6|d[(s<<2&28|n)+(7080+(o<<5))|0]<<11|d[(s>>>3&24|q)+(7080+(o<<5))|0];s=s+1|0;}while(s>>>0<256);l=l+1|0;}while(l>>>0<8);a[1106089]=0}t=1125528+((f>>>10&7)<<9)|0}c[277226]=t;c[277225]=(a[1108928]|0)!=0?1393712:t;t=(d[1394504]|0)+(h<<1)|0;h=a[r+(((f&32768|0)==0?t:56-t|0)+(m?7-i|0:i))|0]|0;if(!(h<<24>>24!=0&(k|0)>0)){return}i=j-1|0;j=(i|0)>-1;m=h&255;h=k;k=g;while(1){if(j){g=i;do{t=(g<<1)+k|0;if((d[1108908]|0)>(d[(c[277219]|0)+t|0]|0)){f=e[(c[277225]|0)+(m<<1)>>1]|0;r=c[277228]|0;l=(((f&63454)+(r&-2082)|0)>>>1)+(r&2081&f)|0;if((a[1108928]|0)==0){u=l&65535}else{u=(e[(c[277220]|0)+(l<<1)>>1]|(f^r)&2081)&65535}r=t+1|0;b[(c[277218]|0)+(r<<1)>>1]=u;b[(c[277218]|0)+(t<<1)>>1]=u;f=a[1108909]|0;a[(c[277219]|0)+r|0]=f;a[(c[277219]|0)+t|0]=f}g=g-1|0;}while((g|0)>-1)}g=h-1|0;if((g|0)>0){h=g;k=(c[277223]|0)+k|0}else{break}}return}function Vb(f,g,h,i,j,k){f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;l=f&1023;m=c[348606]|0;n=(l<<m)+(c[348604]|0)|0;if((f&256|0)==0){o=n}else{o=(c[348602]|0)+n|0}n=o&65535;o=n>>>(m>>>0);m=(f&16384|0)!=0;p=o<<6;do{if(m){q=(c[348622]|0)+p|0;if((a[(c[348618]|0)+o|0]|0)!=0){r=q;break}s=fi[c[348636]&63](q,n,l)|0;a[(c[348618]|0)+o|0]=s;r=q}else{q=(c[348624]|0)+p|0;if((a[(c[348620]|0)+o|0]|0)!=0){r=q;break}s=fi[c[348638]&63](q,n,l)|0;a[(c[348620]|0)+o|0]=s;r=q}}while(0);if((a[(c[348620]|0)+o|0]|0)==2){return}if((a[1394464]|0)==0){t=1106168+((f>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){o=d[1044485]|0;c[276541]=7080+(o<<5);l=0;do{n=l<<1&2;p=l&2;q=l&4;s=0;do{b[1125528+(l<<9)+(s<<1)>>1]=d[(s>>>1&28|p)+(7080+(o<<5))|0]<<6|d[(s<<2&28|n)+(7080+(o<<5))|0]<<11|d[(s>>>3&24|q)+(7080+(o<<5))|0];s=s+1|0;}while(s>>>0<256);l=l+1|0;}while(l>>>0<8);a[1106089]=0}t=1125528+((f>>>10&7)<<9)|0}c[277226]=t;c[277225]=(a[1108928]|0)!=0?1393712:t;t=(d[1394504]|0)+(h<<1)|0;h=a[r+(((f&32768|0)==0?t:56-t|0)+(m?7-i|0:i))|0]|0;if(!(h<<24>>24!=0&(k|0)>0)){return}i=j-1|0;j=(i|0)>-1;m=h&255;h=k;k=g;while(1){if(j){g=i;do{t=(g<<1)+k|0;if((d[1108908]|0)>(d[(c[277219]|0)+t|0]|0)){do{if((a[1108928]|0)==0){f=b[(c[277225]|0)+(m<<1)>>1]|0;r=f&65535;l=r&63454;if((a[(c[277215]|0)+t|0]&32)==0){o=c[277228]|0;u=(e[(c[277220]|0)+((((o&-2082)+l|0)>>>1)+(r&2081&o)<<1)>>1]|(o^r)&2081)&65535;break}else{r=b[(c[277213]|0)+(t<<1)>>1]|0;u=(((r&63454)+l|0)>>>1)+(r&f&2081)&65535;break}}else{f=e[(c[277225]|0)+(m<<1)>>1]|0;r=(a[(c[277215]|0)+t|0]&32)==0;if(r){l=c[277228]|0;v=l;w=l&-2082}else{l=e[(c[277213]|0)+(t<<1)>>1]|0;v=l;w=l&63454}if(r){x=c[277228]|0}else{x=e[(c[277213]|0)+(t<<1)>>1]|0}u=((x^f)&2081|e[(c[277220]|0)+((f&2081&v)+((w+(f&63454)|0)>>>1)<<1)>>1])&65535}}while(0);f=t+1|0;b[(c[277218]|0)+(f<<1)>>1]=u;b[(c[277218]|0)+(t<<1)>>1]=u;r=a[1108909]|0;a[(c[277219]|0)+f|0]=r;a[(c[277219]|0)+t|0]=r}g=g-1|0;}while((g|0)>-1)}g=h-1|0;if((g|0)>0){h=g;k=(c[277223]|0)+k|0}else{break}}return}function Vc(e,f,g,h,i,j){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;k=e&1023;l=c[348606]|0;m=(k<<l)+(c[348604]|0)|0;if((e&256|0)==0){n=m}else{n=(c[348602]|0)+m|0}m=n&65535;n=m>>>(l>>>0);l=(e&16384|0)!=0;o=n<<6;do{if(l){p=(c[348622]|0)+o|0;if((a[(c[348618]|0)+n|0]|0)!=0){q=p;break}r=fi[c[348636]&63](p,m,k)|0;a[(c[348618]|0)+n|0]=r;q=p}else{p=(c[348624]|0)+o|0;if((a[(c[348620]|0)+n|0]|0)!=0){q=p;break}r=fi[c[348638]&63](p,m,k)|0;a[(c[348620]|0)+n|0]=r;q=p}}while(0);if((a[(c[348620]|0)+n|0]|0)==2){return}if((a[1394464]|0)==0){s=1106168+((e>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){n=d[1044485]|0;c[276541]=7080+(n<<5);k=0;do{m=k<<1&2;o=k&2;p=k&4;r=0;do{b[1125528+(k<<9)+(r<<1)>>1]=d[(r>>>1&28|o)+(7080+(n<<5))|0]<<6|d[(r<<2&28|m)+(7080+(n<<5))|0]<<11|d[(r>>>3&24|p)+(7080+(n<<5))|0];r=r+1|0;}while(r>>>0<256);k=k+1|0;}while(k>>>0<8);a[1106089]=0}s=1125528+((e>>>10&7)<<9)|0}c[277226]=s;c[277225]=(a[1108928]|0)!=0?1393712:s;s=(d[1394504]|0)+(g<<1)|0;g=a[q+(((e&32768|0)==0?s:56-s|0)+(l?7-h|0:h))|0]|0;if(!(g<<24>>24!=0&(j|0)>0)){return}h=i-1|0;i=(h|0)>-1;l=g&255;g=j;j=f;while(1){if(i){f=h;do{s=(f<<1)+j|0;if((d[1108908]|0)>(d[(c[277219]|0)+s|0]|0)){e=b[(c[277225]|0)+(l<<1)>>1]|0;if((a[(c[277215]|0)+s|0]&32)==0){t=c[277228]&65535}else{t=b[(c[277213]|0)+(s<<1)>>1]|0}q=e&-2048;k=t&-2048;n=(q&65535)>(k&65535)?q-k&65535:0;k=e&2016;q=t&2016;if((k&65535)>(q&65535)){u=(k-q&65535)+n&65535}else{u=n}n=e&31;e=t&31;if((n&65535)>(e&65535)){v=(n-e&65535)+u&65535}else{v=u}e=s+1|0;b[(c[277218]|0)+(e<<1)>>1]=v;b[(c[277218]|0)+(s<<1)>>1]=v;n=a[1108909]|0;a[(c[277219]|0)+e|0]=n;a[(c[277219]|0)+s|0]=n}f=f-1|0;}while((f|0)>-1)}f=g-1|0;if((f|0)>0){g=f;j=(c[277223]|0)+j|0}else{break}}return}function Vd(e,f,g,h,i,j){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;k=e&1023;l=c[348606]|0;m=(k<<l)+(c[348604]|0)|0;if((e&256|0)==0){n=m}else{n=(c[348602]|0)+m|0}m=n&65535;n=m>>>(l>>>0);l=(e&16384|0)!=0;o=n<<6;do{if(l){p=(c[348622]|0)+o|0;if((a[(c[348618]|0)+n|0]|0)!=0){q=p;break}r=fi[c[348636]&63](p,m,k)|0;a[(c[348618]|0)+n|0]=r;q=p}else{p=(c[348624]|0)+o|0;if((a[(c[348620]|0)+n|0]|0)!=0){q=p;break}r=fi[c[348638]&63](p,m,k)|0;a[(c[348620]|0)+n|0]=r;q=p}}while(0);if((a[(c[348620]|0)+n|0]|0)==2){return}if((a[1394464]|0)==0){s=1106168+((e>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){n=d[1044485]|0;c[276541]=7080+(n<<5);k=0;do{m=k<<1&2;o=k&2;p=k&4;r=0;do{b[1125528+(k<<9)+(r<<1)>>1]=d[(r>>>1&28|o)+(7080+(n<<5))|0]<<6|d[(r<<2&28|m)+(7080+(n<<5))|0]<<11|d[(r>>>3&24|p)+(7080+(n<<5))|0];r=r+1|0;}while(r>>>0<256);k=k+1|0;}while(k>>>0<8);a[1106089]=0}s=1125528+((e>>>10&7)<<9)|0}c[277226]=s;c[277225]=(a[1108928]|0)!=0?1393712:s;s=(d[1394504]|0)+(g<<1)|0;g=a[q+(((e&32768|0)==0?s:56-s|0)+(l?7-h|0:h))|0]|0;if(!(g<<24>>24!=0&(j|0)>0)){return}h=i-1|0;i=(h|0)>-1;l=g&255;g=j;j=f;while(1){if(i){f=h;do{s=(f<<1)+j|0;if((d[1108908]|0)>(d[(c[277219]|0)+s|0]|0)){e=b[(c[277225]|0)+(l<<1)>>1]|0;do{if((a[1108928]|0)==0){t=b[(c[277221]|0)+(((e&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{q=c[277228]&65535;k=e&-2048;n=q&-2048;r=(k&65535)>(n&65535)?k-n&65535:0;n=e&2016;k=q&2016;if((n&65535)>(k&65535)){u=(n-k&65535)+r&65535}else{u=r}r=e&31;k=q&31;if((r&65535)<=(k&65535)){t=u;break}t=(r-k&65535)+u&65535}}while(0);e=s+1|0;b[(c[277218]|0)+(e<<1)>>1]=t;b[(c[277218]|0)+(s<<1)>>1]=t;k=a[1108909]|0;a[(c[277219]|0)+e|0]=k;a[(c[277219]|0)+s|0]=k}f=f-1|0;}while((f|0)>-1)}f=g-1|0;if((f|0)>0){g=f;j=(c[277223]|0)+j|0}else{break}}return}function Ve(e,f,g,h,i,j){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;k=e&1023;l=c[348606]|0;m=(k<<l)+(c[348604]|0)|0;if((e&256|0)==0){n=m}else{n=(c[348602]|0)+m|0}m=n&65535;n=m>>>(l>>>0);l=(e&16384|0)!=0;o=n<<6;do{if(l){p=(c[348622]|0)+o|0;if((a[(c[348618]|0)+n|0]|0)!=0){q=p;break}r=fi[c[348636]&63](p,m,k)|0;a[(c[348618]|0)+n|0]=r;q=p}else{p=(c[348624]|0)+o|0;if((a[(c[348620]|0)+n|0]|0)!=0){q=p;break}r=fi[c[348638]&63](p,m,k)|0;a[(c[348620]|0)+n|0]=r;q=p}}while(0);if((a[(c[348620]|0)+n|0]|0)==2){return}if((a[1394464]|0)==0){s=1106168+((e>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){n=d[1044485]|0;c[276541]=7080+(n<<5);k=0;do{m=k<<1&2;o=k&2;p=k&4;r=0;do{b[1125528+(k<<9)+(r<<1)>>1]=d[(r>>>1&28|o)+(7080+(n<<5))|0]<<6|d[(r<<2&28|m)+(7080+(n<<5))|0]<<11|d[(r>>>3&24|p)+(7080+(n<<5))|0];r=r+1|0;}while(r>>>0<256);k=k+1|0;}while(k>>>0<8);a[1106089]=0}s=1125528+((e>>>10&7)<<9)|0}c[277226]=s;c[277225]=(a[1108928]|0)!=0?1393712:s;s=(d[1394504]|0)+(g<<1)|0;g=a[q+(((e&32768|0)==0?s:56-s|0)+(l?7-h|0:h))|0]|0;if(!(g<<24>>24!=0&(j|0)>0)){return}h=i-1|0;i=(h|0)>-1;l=g&255;g=j;j=f;while(1){if(i){f=h;do{s=(f<<1)+j|0;if((d[1108908]|0)>(d[(c[277219]|0)+s|0]|0)){do{if((a[1108928]|0)==0){e=b[(c[277225]|0)+(l<<1)>>1]|0;if((a[(c[277215]|0)+s|0]&32)!=0){t=b[(c[277221]|0)+((e&65535|67616)-(b[(c[277213]|0)+(s<<1)>>1]&63454)>>1<<1)>>1]|0;break}q=c[277228]&65535;k=e&-2048;n=q&-2048;r=(k&65535)>(n&65535)?k-n&65535:0;n=e&2016;k=q&2016;if((n&65535)>(k&65535)){u=(n-k&65535)+r&65535}else{u=r}r=e&31;e=q&31;if((r&65535)<=(e&65535)){t=u;break}t=(r-e&65535)+u&65535}else{e=b[(c[277225]|0)+(l<<1)>>1]|0;if((a[(c[277215]|0)+s|0]&32)==0){v=c[277228]&65535}else{v=b[(c[277213]|0)+(s<<1)>>1]|0}r=e&-2048;q=v&-2048;k=(r&65535)>(q&65535)?r-q&65535:0;q=e&2016;r=v&2016;if((q&65535)>(r&65535)){w=(q-r&65535)+k&65535}else{w=k}k=e&31;e=v&31;if((k&65535)<=(e&65535)){t=w;break}t=(k-e&65535)+w&65535}}while(0);e=s+1|0;b[(c[277218]|0)+(e<<1)>>1]=t;b[(c[277218]|0)+(s<<1)>>1]=t;k=a[1108909]|0;a[(c[277219]|0)+e|0]=k;a[(c[277219]|0)+s|0]=k}f=f-1|0;}while((f|0)>-1)}f=g-1|0;if((f|0)>0){g=f;j=(c[277223]|0)+j|0}else{break}}return}function Vf(e,f,g,h,i,j){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;k=e&1023;l=c[348606]|0;m=(k<<l)+(c[348604]|0)|0;if((e&256|0)==0){n=m}else{n=(c[348602]|0)+m|0}m=n&65535;n=m>>>(l>>>0);l=(e&16384|0)!=0;o=n<<6;do{if(l){p=(c[348622]|0)+o|0;if((a[(c[348618]|0)+n|0]|0)!=0){q=p;break}r=fi[c[348636]&63](p,m,k)|0;a[(c[348618]|0)+n|0]=r;q=p}else{p=(c[348624]|0)+o|0;if((a[(c[348620]|0)+n|0]|0)!=0){q=p;break}r=fi[c[348638]&63](p,m,k)|0;a[(c[348620]|0)+n|0]=r;q=p}}while(0);if((a[(c[348620]|0)+n|0]|0)==2){return}if((a[1394464]|0)==0){s=1106168+((e>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){n=d[1044485]|0;c[276541]=7080+(n<<5);k=0;do{m=k<<1&2;o=k&2;p=k&4;r=0;do{b[1125528+(k<<9)+(r<<1)>>1]=d[(r>>>1&28|o)+(7080+(n<<5))|0]<<6|d[(r<<2&28|m)+(7080+(n<<5))|0]<<11|d[(r>>>3&24|p)+(7080+(n<<5))|0];r=r+1|0;}while(r>>>0<256);k=k+1|0;}while(k>>>0<8);a[1106089]=0}s=1125528+((e>>>10&7)<<9)|0}c[277226]=s;c[277225]=(a[1108928]|0)!=0?1393712:s;if((e&49152|0)==0){if((j|0)<=0){return}s=h&255;k=s-1&255;n=k<<24>>24==0;r=q+((d[1394504]|0)+(i<<1))|0;p=j;m=f;while(1){switch(g|0){case 6:{t=s;u=1040;break};case 7:{u=1044;break};case 1:{v=s;u=1020;break};case 3:{w=s;u=1028;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+m|0]|0)){o=a[r]|0;if(o<<24>>24==0){break}x=b[(c[277225]|0)+((o&255)<<1)>>1]|0;o=m+1|0;b[(c[277218]|0)+(o<<1)>>1]=x;b[(c[277218]|0)+(m<<1)>>1]=x;x=a[1108909]|0;a[(c[277219]|0)+o|0]=x;a[(c[277219]|0)+m|0]=x}}while(0);if(!n){v=k;u=1020}break};case 2:{y=s;u=1024;break};case 4:{z=s;u=1032;break};case 5:{A=s;u=1036;break};default:{}}if((u|0)==1020){u=0;x=m+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+x|0]|0)){o=a[r+1|0]|0;if(o<<24>>24==0){break}B=b[(c[277225]|0)+((o&255)<<1)>>1]|0;o=m+3|0;b[(c[277218]|0)+(o<<1)>>1]=B;b[(c[277218]|0)+(x<<1)>>1]=B;B=a[1108909]|0;a[(c[277219]|0)+o|0]=B;a[(c[277219]|0)+x|0]=B}}while(0);x=v-1&255;if(x<<24>>24!=0){y=x;u=1024}}if((u|0)==1024){u=0;x=m+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+x|0]|0)){B=a[r+2|0]|0;if(B<<24>>24==0){break}o=b[(c[277225]|0)+((B&255)<<1)>>1]|0;B=m+5|0;b[(c[277218]|0)+(B<<1)>>1]=o;b[(c[277218]|0)+(x<<1)>>1]=o;o=a[1108909]|0;a[(c[277219]|0)+B|0]=o;a[(c[277219]|0)+x|0]=o}}while(0);x=y-1&255;if(x<<24>>24!=0){w=x;u=1028}}if((u|0)==1028){u=0;x=m+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+x|0]|0)){o=a[r+3|0]|0;if(o<<24>>24==0){break}B=b[(c[277225]|0)+((o&255)<<1)>>1]|0;o=m+7|0;b[(c[277218]|0)+(o<<1)>>1]=B;b[(c[277218]|0)+(x<<1)>>1]=B;B=a[1108909]|0;a[(c[277219]|0)+o|0]=B;a[(c[277219]|0)+x|0]=B}}while(0);x=w-1&255;if(x<<24>>24!=0){z=x;u=1032}}if((u|0)==1032){u=0;x=m+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+x|0]|0)){B=a[r+4|0]|0;if(B<<24>>24==0){break}o=b[(c[277225]|0)+((B&255)<<1)>>1]|0;B=m+9|0;b[(c[277218]|0)+(B<<1)>>1]=o;b[(c[277218]|0)+(x<<1)>>1]=o;o=a[1108909]|0;a[(c[277219]|0)+B|0]=o;a[(c[277219]|0)+x|0]=o}}while(0);x=z-1&255;if(x<<24>>24!=0){A=x;u=1036}}if((u|0)==1036){u=0;x=m+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+x|0]|0)){o=a[r+5|0]|0;if(o<<24>>24==0){break}B=b[(c[277225]|0)+((o&255)<<1)>>1]|0;o=m+11|0;b[(c[277218]|0)+(o<<1)>>1]=B;b[(c[277218]|0)+(x<<1)>>1]=B;B=a[1108909]|0;a[(c[277219]|0)+o|0]=B;a[(c[277219]|0)+x|0]=B}}while(0);x=A-1&255;if(x<<24>>24!=0){t=x;u=1040}}if((u|0)==1040){u=0;x=m+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+x|0]|0)){B=a[r+6|0]|0;if(B<<24>>24==0){break}o=b[(c[277225]|0)+((B&255)<<1)>>1]|0;B=m+13|0;b[(c[277218]|0)+(B<<1)>>1]=o;b[(c[277218]|0)+(x<<1)>>1]=o;o=a[1108909]|0;a[(c[277219]|0)+B|0]=o;a[(c[277219]|0)+x|0]=o}}while(0);if(t<<24>>24!=1){u=1044}}do{if((u|0)==1044){u=0;x=m+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+x|0]|0)){break}o=a[r+7|0]|0;if(o<<24>>24==0){break}B=b[(c[277225]|0)+((o&255)<<1)>>1]|0;o=m+15|0;b[(c[277218]|0)+(o<<1)>>1]=B;b[(c[277218]|0)+(x<<1)>>1]=B;B=a[1108909]|0;a[(c[277219]|0)+o|0]=B;a[(c[277219]|0)+x|0]=B}}while(0);B=p-1|0;if((B|0)>0){r=r+16|0;p=B;m=(c[277223]|0)+m|0}else{break}}return}m=(d[1394504]|0)+(i<<1)|0;if((e&32768|0)==0){if((j|0)<=0){return}e=h&255;i=e-1&255;p=i<<24>>24==0;r=q+m|0;t=j;A=f;while(1){switch(g|0){case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+A|0]|0)){z=a[r+7|0]|0;if(z<<24>>24==0){break}w=b[(c[277225]|0)+((z&255)<<1)>>1]|0;z=A+1|0;b[(c[277218]|0)+(z<<1)>>1]=w;b[(c[277218]|0)+(A<<1)>>1]=w;w=a[1108909]|0;a[(c[277219]|0)+z|0]=w;a[(c[277219]|0)+A|0]=w}}while(0);if(!p){C=i;u=1056}break};case 1:{C=e;u=1056;break};case 2:{D=e;u=1060;break};case 3:{E=e;u=1064;break};case 4:{F=e;u=1068;break};case 5:{G=e;u=1072;break};case 6:{H=e;u=1076;break};case 7:{u=1080;break};default:{}}if((u|0)==1056){u=0;w=A+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+w|0]|0)){z=a[r+6|0]|0;if(z<<24>>24==0){break}y=b[(c[277225]|0)+((z&255)<<1)>>1]|0;z=A+3|0;b[(c[277218]|0)+(z<<1)>>1]=y;b[(c[277218]|0)+(w<<1)>>1]=y;y=a[1108909]|0;a[(c[277219]|0)+z|0]=y;a[(c[277219]|0)+w|0]=y}}while(0);w=C-1&255;if(w<<24>>24!=0){D=w;u=1060}}if((u|0)==1060){u=0;w=A+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+w|0]|0)){y=a[r+5|0]|0;if(y<<24>>24==0){break}z=b[(c[277225]|0)+((y&255)<<1)>>1]|0;y=A+5|0;b[(c[277218]|0)+(y<<1)>>1]=z;b[(c[277218]|0)+(w<<1)>>1]=z;z=a[1108909]|0;a[(c[277219]|0)+y|0]=z;a[(c[277219]|0)+w|0]=z}}while(0);w=D-1&255;if(w<<24>>24!=0){E=w;u=1064}}if((u|0)==1064){u=0;w=A+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+w|0]|0)){z=a[r+4|0]|0;if(z<<24>>24==0){break}y=b[(c[277225]|0)+((z&255)<<1)>>1]|0;z=A+7|0;b[(c[277218]|0)+(z<<1)>>1]=y;b[(c[277218]|0)+(w<<1)>>1]=y;y=a[1108909]|0;a[(c[277219]|0)+z|0]=y;a[(c[277219]|0)+w|0]=y}}while(0);w=E-1&255;if(w<<24>>24!=0){F=w;u=1068}}if((u|0)==1068){u=0;w=A+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+w|0]|0)){y=a[r+3|0]|0;if(y<<24>>24==0){break}z=b[(c[277225]|0)+((y&255)<<1)>>1]|0;y=A+9|0;b[(c[277218]|0)+(y<<1)>>1]=z;b[(c[277218]|0)+(w<<1)>>1]=z;z=a[1108909]|0;a[(c[277219]|0)+y|0]=z;a[(c[277219]|0)+w|0]=z}}while(0);w=F-1&255;if(w<<24>>24!=0){G=w;u=1072}}if((u|0)==1072){u=0;w=A+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+w|0]|0)){z=a[r+2|0]|0;if(z<<24>>24==0){break}y=b[(c[277225]|0)+((z&255)<<1)>>1]|0;z=A+11|0;b[(c[277218]|0)+(z<<1)>>1]=y;b[(c[277218]|0)+(w<<1)>>1]=y;y=a[1108909]|0;a[(c[277219]|0)+z|0]=y;a[(c[277219]|0)+w|0]=y}}while(0);w=G-1&255;if(w<<24>>24!=0){H=w;u=1076}}if((u|0)==1076){u=0;w=A+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+w|0]|0)){y=a[r+1|0]|0;if(y<<24>>24==0){break}z=b[(c[277225]|0)+((y&255)<<1)>>1]|0;y=A+13|0;b[(c[277218]|0)+(y<<1)>>1]=z;b[(c[277218]|0)+(w<<1)>>1]=z;z=a[1108909]|0;a[(c[277219]|0)+y|0]=z;a[(c[277219]|0)+w|0]=z}}while(0);if(H<<24>>24!=1){u=1080}}do{if((u|0)==1080){u=0;w=A+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+w|0]|0)){break}z=a[r]|0;if(z<<24>>24==0){break}y=b[(c[277225]|0)+((z&255)<<1)>>1]|0;z=A+15|0;b[(c[277218]|0)+(z<<1)>>1]=y;b[(c[277218]|0)+(w<<1)>>1]=y;y=a[1108909]|0;a[(c[277219]|0)+z|0]=y;a[(c[277219]|0)+w|0]=y}}while(0);y=t-1|0;if((y|0)>0){r=r+16|0;t=y;A=(c[277223]|0)+A|0}else{break}}return}A=q+(56-m)|0;m=(j|0)>0;if(l){if(!m){return}l=h&255;q=l-1&255;t=q<<24>>24==0;r=A;H=j;G=f;while(1){switch(g|0){case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+G|0]|0)){F=a[r+7|0]|0;if(F<<24>>24==0){break}E=b[(c[277225]|0)+((F&255)<<1)>>1]|0;F=G+1|0;b[(c[277218]|0)+(F<<1)>>1]=E;b[(c[277218]|0)+(G<<1)>>1]=E;E=a[1108909]|0;a[(c[277219]|0)+F|0]=E;a[(c[277219]|0)+G|0]=E}}while(0);if(!t){I=q;u=1127}break};case 1:{I=l;u=1127;break};case 2:{J=l;u=1131;break};case 3:{K=l;u=1135;break};case 4:{L=l;u=1139;break};case 5:{M=l;u=1143;break};case 6:{N=l;u=1147;break};case 7:{u=1151;break};default:{}}if((u|0)==1127){u=0;E=G+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+E|0]|0)){F=a[r+6|0]|0;if(F<<24>>24==0){break}D=b[(c[277225]|0)+((F&255)<<1)>>1]|0;F=G+3|0;b[(c[277218]|0)+(F<<1)>>1]=D;b[(c[277218]|0)+(E<<1)>>1]=D;D=a[1108909]|0;a[(c[277219]|0)+F|0]=D;a[(c[277219]|0)+E|0]=D}}while(0);E=I-1&255;if(E<<24>>24!=0){J=E;u=1131}}if((u|0)==1131){u=0;E=G+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+E|0]|0)){D=a[r+5|0]|0;if(D<<24>>24==0){break}F=b[(c[277225]|0)+((D&255)<<1)>>1]|0;D=G+5|0;b[(c[277218]|0)+(D<<1)>>1]=F;b[(c[277218]|0)+(E<<1)>>1]=F;F=a[1108909]|0;a[(c[277219]|0)+D|0]=F;a[(c[277219]|0)+E|0]=F}}while(0);E=J-1&255;if(E<<24>>24!=0){K=E;u=1135}}if((u|0)==1135){u=0;E=G+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+E|0]|0)){F=a[r+4|0]|0;if(F<<24>>24==0){break}D=b[(c[277225]|0)+((F&255)<<1)>>1]|0;F=G+7|0;b[(c[277218]|0)+(F<<1)>>1]=D;b[(c[277218]|0)+(E<<1)>>1]=D;D=a[1108909]|0;a[(c[277219]|0)+F|0]=D;a[(c[277219]|0)+E|0]=D}}while(0);E=K-1&255;if(E<<24>>24!=0){L=E;u=1139}}if((u|0)==1139){u=0;E=G+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+E|0]|0)){D=a[r+3|0]|0;if(D<<24>>24==0){break}F=b[(c[277225]|0)+((D&255)<<1)>>1]|0;D=G+9|0;b[(c[277218]|0)+(D<<1)>>1]=F;b[(c[277218]|0)+(E<<1)>>1]=F;F=a[1108909]|0;a[(c[277219]|0)+D|0]=F;a[(c[277219]|0)+E|0]=F}}while(0);E=L-1&255;if(E<<24>>24!=0){M=E;u=1143}}if((u|0)==1143){u=0;E=G+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+E|0]|0)){F=a[r+2|0]|0;if(F<<24>>24==0){break}D=b[(c[277225]|0)+((F&255)<<1)>>1]|0;F=G+11|0;b[(c[277218]|0)+(F<<1)>>1]=D;b[(c[277218]|0)+(E<<1)>>1]=D;D=a[1108909]|0;a[(c[277219]|0)+F|0]=D;a[(c[277219]|0)+E|0]=D}}while(0);E=M-1&255;if(E<<24>>24!=0){N=E;u=1147}}if((u|0)==1147){u=0;E=G+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+E|0]|0)){D=a[r+1|0]|0;if(D<<24>>24==0){break}F=b[(c[277225]|0)+((D&255)<<1)>>1]|0;D=G+13|0;b[(c[277218]|0)+(D<<1)>>1]=F;b[(c[277218]|0)+(E<<1)>>1]=F;F=a[1108909]|0;a[(c[277219]|0)+D|0]=F;a[(c[277219]|0)+E|0]=F}}while(0);if(N<<24>>24!=1){u=1151}}do{if((u|0)==1151){u=0;E=G+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+E|0]|0)){break}F=a[r]|0;if(F<<24>>24==0){break}D=b[(c[277225]|0)+((F&255)<<1)>>1]|0;F=G+15|0;b[(c[277218]|0)+(F<<1)>>1]=D;b[(c[277218]|0)+(E<<1)>>1]=D;D=a[1108909]|0;a[(c[277219]|0)+F|0]=D;a[(c[277219]|0)+E|0]=D}}while(0);D=H-1|0;if((D|0)>0){r=r-16|0;H=D;G=(c[277223]|0)+G|0}else{break}}return}else{if(!m){return}m=h&255;h=m-1&255;G=h<<24>>24==0;H=A;A=j;j=f;while(1){switch(g|0){case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+j|0]|0)){f=a[H]|0;if(f<<24>>24==0){break}r=b[(c[277225]|0)+((f&255)<<1)>>1]|0;f=j+1|0;b[(c[277218]|0)+(f<<1)>>1]=r;b[(c[277218]|0)+(j<<1)>>1]=r;r=a[1108909]|0;a[(c[277219]|0)+f|0]=r;a[(c[277219]|0)+j|0]=r}}while(0);if(!G){O=h;u=1094}break};case 1:{O=m;u=1094;break};case 2:{P=m;u=1098;break};case 3:{Q=m;u=1102;break};case 4:{R=m;u=1106;break};case 5:{S=m;u=1110;break};case 6:{T=m;u=1114;break};case 7:{u=1118;break};default:{}}if((u|0)==1094){u=0;r=j+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+r|0]|0)){f=a[H+1|0]|0;if(f<<24>>24==0){break}N=b[(c[277225]|0)+((f&255)<<1)>>1]|0;f=j+3|0;b[(c[277218]|0)+(f<<1)>>1]=N;b[(c[277218]|0)+(r<<1)>>1]=N;N=a[1108909]|0;a[(c[277219]|0)+f|0]=N;a[(c[277219]|0)+r|0]=N}}while(0);r=O-1&255;if(r<<24>>24!=0){P=r;u=1098}}if((u|0)==1098){u=0;r=j+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+r|0]|0)){N=a[H+2|0]|0;if(N<<24>>24==0){break}f=b[(c[277225]|0)+((N&255)<<1)>>1]|0;N=j+5|0;b[(c[277218]|0)+(N<<1)>>1]=f;b[(c[277218]|0)+(r<<1)>>1]=f;f=a[1108909]|0;a[(c[277219]|0)+N|0]=f;a[(c[277219]|0)+r|0]=f}}while(0);r=P-1&255;if(r<<24>>24!=0){Q=r;u=1102}}if((u|0)==1102){u=0;r=j+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+r|0]|0)){f=a[H+3|0]|0;if(f<<24>>24==0){break}N=b[(c[277225]|0)+((f&255)<<1)>>1]|0;f=j+7|0;b[(c[277218]|0)+(f<<1)>>1]=N;b[(c[277218]|0)+(r<<1)>>1]=N;N=a[1108909]|0;a[(c[277219]|0)+f|0]=N;a[(c[277219]|0)+r|0]=N}}while(0);r=Q-1&255;if(r<<24>>24!=0){R=r;u=1106}}if((u|0)==1106){u=0;r=j+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+r|0]|0)){N=a[H+4|0]|0;if(N<<24>>24==0){break}f=b[(c[277225]|0)+((N&255)<<1)>>1]|0;N=j+9|0;b[(c[277218]|0)+(N<<1)>>1]=f;b[(c[277218]|0)+(r<<1)>>1]=f;f=a[1108909]|0;a[(c[277219]|0)+N|0]=f;a[(c[277219]|0)+r|0]=f}}while(0);r=R-1&255;if(r<<24>>24!=0){S=r;u=1110}}if((u|0)==1110){u=0;r=j+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+r|0]|0)){f=a[H+5|0]|0;if(f<<24>>24==0){break}N=b[(c[277225]|0)+((f&255)<<1)>>1]|0;f=j+11|0;b[(c[277218]|0)+(f<<1)>>1]=N;b[(c[277218]|0)+(r<<1)>>1]=N;N=a[1108909]|0;a[(c[277219]|0)+f|0]=N;a[(c[277219]|0)+r|0]=N}}while(0);r=S-1&255;if(r<<24>>24!=0){T=r;u=1114}}if((u|0)==1114){u=0;r=j+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+r|0]|0)){N=a[H+6|0]|0;if(N<<24>>24==0){break}f=b[(c[277225]|0)+((N&255)<<1)>>1]|0;N=j+13|0;b[(c[277218]|0)+(N<<1)>>1]=f;b[(c[277218]|0)+(r<<1)>>1]=f;f=a[1108909]|0;a[(c[277219]|0)+N|0]=f;a[(c[277219]|0)+r|0]=f}}while(0);if(T<<24>>24!=1){u=1118}}do{if((u|0)==1118){u=0;r=j+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+r|0]|0)){break}f=a[H+7|0]|0;if(f<<24>>24==0){break}N=b[(c[277225]|0)+((f&255)<<1)>>1]|0;f=j+15|0;b[(c[277218]|0)+(f<<1)>>1]=N;b[(c[277218]|0)+(r<<1)>>1]=N;N=a[1108909]|0;a[(c[277219]|0)+f|0]=N;a[(c[277219]|0)+r|0]=N}}while(0);N=A-1|0;if((N|0)>0){H=H-16|0;A=N;j=(c[277223]|0)+j|0}else{break}}return}}function Vg(f,g,h,i,j,k){f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0;l=f&1023;m=c[348606]|0;n=(l<<m)+(c[348604]|0)|0;if((f&256|0)==0){o=n}else{o=(c[348602]|0)+n|0}n=o&65535;o=n>>>(m>>>0);m=(f&16384|0)!=0;p=o<<6;do{if(m){q=(c[348622]|0)+p|0;if((a[(c[348618]|0)+o|0]|0)!=0){r=q;break}s=fi[c[348636]&63](q,n,l)|0;a[(c[348618]|0)+o|0]=s;r=q}else{q=(c[348624]|0)+p|0;if((a[(c[348620]|0)+o|0]|0)!=0){r=q;break}s=fi[c[348638]&63](q,n,l)|0;a[(c[348620]|0)+o|0]=s;r=q}}while(0);if((a[(c[348620]|0)+o|0]|0)==2){return}if((a[1394464]|0)==0){t=1106168+((f>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){o=d[1044485]|0;c[276541]=7080+(o<<5);l=0;do{n=l<<1&2;p=l&2;q=l&4;s=0;do{b[1125528+(l<<9)+(s<<1)>>1]=d[(s>>>1&28|p)+(7080+(o<<5))|0]<<6|d[(s<<2&28|n)+(7080+(o<<5))|0]<<11|d[(s>>>3&24|q)+(7080+(o<<5))|0];s=s+1|0;}while(s>>>0<256);l=l+1|0;}while(l>>>0<8);a[1106089]=0}t=1125528+((f>>>10&7)<<9)|0}c[277226]=t;c[277225]=(a[1108928]|0)!=0?1393712:t;if((f&49152|0)==0){if((k|0)<=0){return}t=i&255;l=t-1&255;o=l<<24>>24==0;s=r+((d[1394504]|0)+(j<<1))|0;q=k;n=g;while(1){switch(h|0){case 5:{u=t;v=1236;break};case 6:{w=t;v=1246;break};case 7:{v=1256;break};case 4:{x=t;v=1226;break};case 1:{y=t;v=1196;break};case 2:{z=t;v=1206;break};case 3:{A=t;v=1216;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+n|0]|0)){p=a[s]|0;if(p<<24>>24==0){break}B=e[(c[277225]|0)+((p&255)<<1)>>1]|0;p=(a[(c[277215]|0)+n|0]&32)==0;if(p){C=c[277228]|0;D=C;E=C&-2082}else{C=e[(c[277213]|0)+(n<<1)>>1]|0;D=C;E=C&63454}if(p){F=c[277228]|0}else{F=e[(c[277213]|0)+(n<<1)>>1]|0}p=((F^B)&2081|e[(c[277220]|0)+((B&2081&D)+((E+(B&63454)|0)>>>1)<<1)>>1])&65535;B=n+1|0;b[(c[277218]|0)+(B<<1)>>1]=p;b[(c[277218]|0)+(n<<1)>>1]=p;p=a[1108909]|0;a[(c[277219]|0)+B|0]=p;a[(c[277219]|0)+n|0]=p}}while(0);if(!o){y=l;v=1196}break};default:{}}if((v|0)==1196){v=0;p=n+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){B=a[s+1|0]|0;if(B<<24>>24==0){break}C=e[(c[277225]|0)+((B&255)<<1)>>1]|0;B=(a[(c[277215]|0)+p|0]&32)==0;if(B){G=c[277228]|0;H=G;I=G&-2082}else{G=e[(c[277213]|0)+(p<<1)>>1]|0;H=G;I=G&63454}if(B){J=c[277228]|0}else{J=e[(c[277213]|0)+(p<<1)>>1]|0}B=((J^C)&2081|e[(c[277220]|0)+((C&2081&H)+((I+(C&63454)|0)>>>1)<<1)>>1])&65535;C=n+3|0;b[(c[277218]|0)+(C<<1)>>1]=B;b[(c[277218]|0)+(p<<1)>>1]=B;B=a[1108909]|0;a[(c[277219]|0)+C|0]=B;a[(c[277219]|0)+p|0]=B}}while(0);p=y-1&255;if(p<<24>>24!=0){z=p;v=1206}}if((v|0)==1206){v=0;p=n+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){B=a[s+2|0]|0;if(B<<24>>24==0){break}C=e[(c[277225]|0)+((B&255)<<1)>>1]|0;B=(a[(c[277215]|0)+p|0]&32)==0;if(B){G=c[277228]|0;K=G;L=G&-2082}else{G=e[(c[277213]|0)+(p<<1)>>1]|0;K=G;L=G&63454}if(B){M=c[277228]|0}else{M=e[(c[277213]|0)+(p<<1)>>1]|0}B=((M^C)&2081|e[(c[277220]|0)+((C&2081&K)+((L+(C&63454)|0)>>>1)<<1)>>1])&65535;C=n+5|0;b[(c[277218]|0)+(C<<1)>>1]=B;b[(c[277218]|0)+(p<<1)>>1]=B;B=a[1108909]|0;a[(c[277219]|0)+C|0]=B;a[(c[277219]|0)+p|0]=B}}while(0);p=z-1&255;if(p<<24>>24!=0){A=p;v=1216}}if((v|0)==1216){v=0;p=n+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){B=a[s+3|0]|0;if(B<<24>>24==0){break}C=e[(c[277225]|0)+((B&255)<<1)>>1]|0;B=(a[(c[277215]|0)+p|0]&32)==0;if(B){G=c[277228]|0;N=G;O=G&-2082}else{G=e[(c[277213]|0)+(p<<1)>>1]|0;N=G;O=G&63454}if(B){P=c[277228]|0}else{P=e[(c[277213]|0)+(p<<1)>>1]|0}B=((P^C)&2081|e[(c[277220]|0)+((C&2081&N)+((O+(C&63454)|0)>>>1)<<1)>>1])&65535;C=n+7|0;b[(c[277218]|0)+(C<<1)>>1]=B;b[(c[277218]|0)+(p<<1)>>1]=B;B=a[1108909]|0;a[(c[277219]|0)+C|0]=B;a[(c[277219]|0)+p|0]=B}}while(0);p=A-1&255;if(p<<24>>24!=0){x=p;v=1226}}if((v|0)==1226){v=0;p=n+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){B=a[s+4|0]|0;if(B<<24>>24==0){break}C=e[(c[277225]|0)+((B&255)<<1)>>1]|0;B=(a[(c[277215]|0)+p|0]&32)==0;if(B){G=c[277228]|0;Q=G;R=G&-2082}else{G=e[(c[277213]|0)+(p<<1)>>1]|0;Q=G;R=G&63454}if(B){S=c[277228]|0}else{S=e[(c[277213]|0)+(p<<1)>>1]|0}B=((S^C)&2081|e[(c[277220]|0)+((C&2081&Q)+((R+(C&63454)|0)>>>1)<<1)>>1])&65535;C=n+9|0;b[(c[277218]|0)+(C<<1)>>1]=B;b[(c[277218]|0)+(p<<1)>>1]=B;B=a[1108909]|0;a[(c[277219]|0)+C|0]=B;a[(c[277219]|0)+p|0]=B}}while(0);p=x-1&255;if(p<<24>>24!=0){u=p;v=1236}}if((v|0)==1236){v=0;p=n+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){B=a[s+5|0]|0;if(B<<24>>24==0){break}C=e[(c[277225]|0)+((B&255)<<1)>>1]|0;B=(a[(c[277215]|0)+p|0]&32)==0;if(B){G=c[277228]|0;T=G;U=G&-2082}else{G=e[(c[277213]|0)+(p<<1)>>1]|0;T=G;U=G&63454}if(B){V=c[277228]|0}else{V=e[(c[277213]|0)+(p<<1)>>1]|0}B=((V^C)&2081|e[(c[277220]|0)+((C&2081&T)+((U+(C&63454)|0)>>>1)<<1)>>1])&65535;C=n+11|0;b[(c[277218]|0)+(C<<1)>>1]=B;b[(c[277218]|0)+(p<<1)>>1]=B;B=a[1108909]|0;a[(c[277219]|0)+C|0]=B;a[(c[277219]|0)+p|0]=B}}while(0);p=u-1&255;if(p<<24>>24!=0){w=p;v=1246}}if((v|0)==1246){v=0;p=n+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){B=a[s+6|0]|0;if(B<<24>>24==0){break}C=e[(c[277225]|0)+((B&255)<<1)>>1]|0;B=(a[(c[277215]|0)+p|0]&32)==0;if(B){G=c[277228]|0;W=G;X=G&-2082}else{G=e[(c[277213]|0)+(p<<1)>>1]|0;W=G;X=G&63454}if(B){Y=c[277228]|0}else{Y=e[(c[277213]|0)+(p<<1)>>1]|0}B=((Y^C)&2081|e[(c[277220]|0)+((C&2081&W)+((X+(C&63454)|0)>>>1)<<1)>>1])&65535;C=n+13|0;b[(c[277218]|0)+(C<<1)>>1]=B;b[(c[277218]|0)+(p<<1)>>1]=B;B=a[1108909]|0;a[(c[277219]|0)+C|0]=B;a[(c[277219]|0)+p|0]=B}}while(0);if(w<<24>>24!=1){v=1256}}do{if((v|0)==1256){v=0;p=n+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+p|0]|0)){break}B=a[s+7|0]|0;if(B<<24>>24==0){break}C=e[(c[277225]|0)+((B&255)<<1)>>1]|0;B=(a[(c[277215]|0)+p|0]&32)==0;if(B){G=c[277228]|0;Z=G;_=G&-2082}else{G=e[(c[277213]|0)+(p<<1)>>1]|0;Z=G;_=G&63454}if(B){$=c[277228]|0}else{$=e[(c[277213]|0)+(p<<1)>>1]|0}B=(($^C)&2081|e[(c[277220]|0)+((C&2081&Z)+((_+(C&63454)|0)>>>1)<<1)>>1])&65535;C=n+15|0;b[(c[277218]|0)+(C<<1)>>1]=B;b[(c[277218]|0)+(p<<1)>>1]=B;B=a[1108909]|0;a[(c[277219]|0)+C|0]=B;a[(c[277219]|0)+p|0]=B}}while(0);B=q-1|0;if((B|0)>0){s=s+16|0;q=B;n=(c[277223]|0)+n|0}else{break}}return}n=(d[1394504]|0)+(j<<1)|0;if((f&32768|0)==0){if((k|0)<=0){return}f=i&255;j=f-1&255;q=j<<24>>24==0;s=r+n|0;_=k;Z=g;while(1){switch(h|0){case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+Z|0]|0)){$=a[s+7|0]|0;if($<<24>>24==0){break}w=e[(c[277225]|0)+(($&255)<<1)>>1]|0;$=(a[(c[277215]|0)+Z|0]&32)==0;if($){X=c[277228]|0;aa=X;ab=X&-2082}else{X=e[(c[277213]|0)+(Z<<1)>>1]|0;aa=X;ab=X&63454}if($){ac=c[277228]|0}else{ac=e[(c[277213]|0)+(Z<<1)>>1]|0}$=((ac^w)&2081|e[(c[277220]|0)+((w&2081&aa)+((ab+(w&63454)|0)>>>1)<<1)>>1])&65535;w=Z+1|0;b[(c[277218]|0)+(w<<1)>>1]=$;b[(c[277218]|0)+(Z<<1)>>1]=$;$=a[1108909]|0;a[(c[277219]|0)+w|0]=$;a[(c[277219]|0)+Z|0]=$}}while(0);if(!q){ad=j;v=1280}break};case 1:{ad=f;v=1280;break};case 6:{ae=f;v=1330;break};case 4:{af=f;v=1310;break};case 5:{ag=f;v=1320;break};case 7:{v=1340;break};case 2:{ah=f;v=1290;break};case 3:{ai=f;v=1300;break};default:{}}if((v|0)==1280){v=0;$=Z+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+$|0]|0)){w=a[s+6|0]|0;if(w<<24>>24==0){break}X=e[(c[277225]|0)+((w&255)<<1)>>1]|0;w=(a[(c[277215]|0)+$|0]&32)==0;if(w){W=c[277228]|0;aj=W;ak=W&-2082}else{W=e[(c[277213]|0)+($<<1)>>1]|0;aj=W;ak=W&63454}if(w){al=c[277228]|0}else{al=e[(c[277213]|0)+($<<1)>>1]|0}w=((al^X)&2081|e[(c[277220]|0)+((X&2081&aj)+((ak+(X&63454)|0)>>>1)<<1)>>1])&65535;X=Z+3|0;b[(c[277218]|0)+(X<<1)>>1]=w;b[(c[277218]|0)+($<<1)>>1]=w;w=a[1108909]|0;a[(c[277219]|0)+X|0]=w;a[(c[277219]|0)+$|0]=w}}while(0);$=ad-1&255;if($<<24>>24!=0){ah=$;v=1290}}if((v|0)==1290){v=0;$=Z+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+$|0]|0)){w=a[s+5|0]|0;if(w<<24>>24==0){break}X=e[(c[277225]|0)+((w&255)<<1)>>1]|0;w=(a[(c[277215]|0)+$|0]&32)==0;if(w){W=c[277228]|0;am=W;an=W&-2082}else{W=e[(c[277213]|0)+($<<1)>>1]|0;am=W;an=W&63454}if(w){ao=c[277228]|0}else{ao=e[(c[277213]|0)+($<<1)>>1]|0}w=((ao^X)&2081|e[(c[277220]|0)+((X&2081&am)+((an+(X&63454)|0)>>>1)<<1)>>1])&65535;X=Z+5|0;b[(c[277218]|0)+(X<<1)>>1]=w;b[(c[277218]|0)+($<<1)>>1]=w;w=a[1108909]|0;a[(c[277219]|0)+X|0]=w;a[(c[277219]|0)+$|0]=w}}while(0);$=ah-1&255;if($<<24>>24!=0){ai=$;v=1300}}if((v|0)==1300){v=0;$=Z+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+$|0]|0)){w=a[s+4|0]|0;if(w<<24>>24==0){break}X=e[(c[277225]|0)+((w&255)<<1)>>1]|0;w=(a[(c[277215]|0)+$|0]&32)==0;if(w){W=c[277228]|0;ap=W;aq=W&-2082}else{W=e[(c[277213]|0)+($<<1)>>1]|0;ap=W;aq=W&63454}if(w){ar=c[277228]|0}else{ar=e[(c[277213]|0)+($<<1)>>1]|0}w=((ar^X)&2081|e[(c[277220]|0)+((X&2081&ap)+((aq+(X&63454)|0)>>>1)<<1)>>1])&65535;X=Z+7|0;b[(c[277218]|0)+(X<<1)>>1]=w;b[(c[277218]|0)+($<<1)>>1]=w;w=a[1108909]|0;a[(c[277219]|0)+X|0]=w;a[(c[277219]|0)+$|0]=w}}while(0);$=ai-1&255;if($<<24>>24!=0){af=$;v=1310}}if((v|0)==1310){v=0;$=Z+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+$|0]|0)){w=a[s+3|0]|0;if(w<<24>>24==0){break}X=e[(c[277225]|0)+((w&255)<<1)>>1]|0;w=(a[(c[277215]|0)+$|0]&32)==0;if(w){W=c[277228]|0;as=W;at=W&-2082}else{W=e[(c[277213]|0)+($<<1)>>1]|0;as=W;at=W&63454}if(w){au=c[277228]|0}else{au=e[(c[277213]|0)+($<<1)>>1]|0}w=((au^X)&2081|e[(c[277220]|0)+((X&2081&as)+((at+(X&63454)|0)>>>1)<<1)>>1])&65535;X=Z+9|0;b[(c[277218]|0)+(X<<1)>>1]=w;b[(c[277218]|0)+($<<1)>>1]=w;w=a[1108909]|0;a[(c[277219]|0)+X|0]=w;a[(c[277219]|0)+$|0]=w}}while(0);$=af-1&255;if($<<24>>24!=0){ag=$;v=1320}}if((v|0)==1320){v=0;$=Z+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+$|0]|0)){w=a[s+2|0]|0;if(w<<24>>24==0){break}X=e[(c[277225]|0)+((w&255)<<1)>>1]|0;w=(a[(c[277215]|0)+$|0]&32)==0;if(w){W=c[277228]|0;av=W;aw=W&-2082}else{W=e[(c[277213]|0)+($<<1)>>1]|0;av=W;aw=W&63454}if(w){ax=c[277228]|0}else{ax=e[(c[277213]|0)+($<<1)>>1]|0}w=((ax^X)&2081|e[(c[277220]|0)+((X&2081&av)+((aw+(X&63454)|0)>>>1)<<1)>>1])&65535;X=Z+11|0;b[(c[277218]|0)+(X<<1)>>1]=w;b[(c[277218]|0)+($<<1)>>1]=w;w=a[1108909]|0;a[(c[277219]|0)+X|0]=w;a[(c[277219]|0)+$|0]=w}}while(0);$=ag-1&255;if($<<24>>24!=0){ae=$;v=1330}}if((v|0)==1330){v=0;$=Z+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+$|0]|0)){w=a[s+1|0]|0;if(w<<24>>24==0){break}X=e[(c[277225]|0)+((w&255)<<1)>>1]|0;w=(a[(c[277215]|0)+$|0]&32)==0;if(w){W=c[277228]|0;ay=W;az=W&-2082}else{W=e[(c[277213]|0)+($<<1)>>1]|0;ay=W;az=W&63454}if(w){aA=c[277228]|0}else{aA=e[(c[277213]|0)+($<<1)>>1]|0}w=((aA^X)&2081|e[(c[277220]|0)+((X&2081&ay)+((az+(X&63454)|0)>>>1)<<1)>>1])&65535;X=Z+13|0;b[(c[277218]|0)+(X<<1)>>1]=w;b[(c[277218]|0)+($<<1)>>1]=w;w=a[1108909]|0;a[(c[277219]|0)+X|0]=w;a[(c[277219]|0)+$|0]=w}}while(0);if(ae<<24>>24!=1){v=1340}}do{if((v|0)==1340){v=0;$=Z+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+$|0]|0)){break}w=a[s]|0;if(w<<24>>24==0){break}X=e[(c[277225]|0)+((w&255)<<1)>>1]|0;w=(a[(c[277215]|0)+$|0]&32)==0;if(w){W=c[277228]|0;aB=W;aC=W&-2082}else{W=e[(c[277213]|0)+($<<1)>>1]|0;aB=W;aC=W&63454}if(w){aD=c[277228]|0}else{aD=e[(c[277213]|0)+($<<1)>>1]|0}w=((aD^X)&2081|e[(c[277220]|0)+((X&2081&aB)+((aC+(X&63454)|0)>>>1)<<1)>>1])&65535;X=Z+15|0;b[(c[277218]|0)+(X<<1)>>1]=w;b[(c[277218]|0)+($<<1)>>1]=w;w=a[1108909]|0;a[(c[277219]|0)+X|0]=w;a[(c[277219]|0)+$|0]=w}}while(0);w=_-1|0;if((w|0)>0){s=s+16|0;_=w;Z=(c[277223]|0)+Z|0}else{break}}return}Z=r+(56-n)|0;n=(k|0)>0;if(m){if(!n){return}m=i&255;r=m-1&255;_=r<<24>>24==0;s=Z;aC=k;aB=g;while(1){switch(h|0){case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+aB|0]|0)){aD=a[s+7|0]|0;if(aD<<24>>24==0){break}ae=e[(c[277225]|0)+((aD&255)<<1)>>1]|0;aD=(a[(c[277215]|0)+aB|0]&32)==0;if(aD){az=c[277228]|0;aE=az;aF=az&-2082}else{az=e[(c[277213]|0)+(aB<<1)>>1]|0;aE=az;aF=az&63454}if(aD){aG=c[277228]|0}else{aG=e[(c[277213]|0)+(aB<<1)>>1]|0}aD=((aG^ae)&2081|e[(c[277220]|0)+((ae&2081&aE)+((aF+(ae&63454)|0)>>>1)<<1)>>1])&65535;ae=aB+1|0;b[(c[277218]|0)+(ae<<1)>>1]=aD;b[(c[277218]|0)+(aB<<1)>>1]=aD;aD=a[1108909]|0;a[(c[277219]|0)+ae|0]=aD;a[(c[277219]|0)+aB|0]=aD}}while(0);if(!_){aH=r;v=1447}break};case 1:{aH=m;v=1447;break};case 2:{aI=m;v=1457;break};case 3:{aJ=m;v=1467;break};case 4:{aK=m;v=1477;break};case 5:{aL=m;v=1487;break};case 6:{aM=m;v=1497;break};case 7:{v=1507;break};default:{}}if((v|0)==1447){v=0;aD=aB+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+aD|0]|0)){ae=a[s+6|0]|0;if(ae<<24>>24==0){break}az=e[(c[277225]|0)+((ae&255)<<1)>>1]|0;ae=(a[(c[277215]|0)+aD|0]&32)==0;if(ae){ay=c[277228]|0;aN=ay;aO=ay&-2082}else{ay=e[(c[277213]|0)+(aD<<1)>>1]|0;aN=ay;aO=ay&63454}if(ae){aP=c[277228]|0}else{aP=e[(c[277213]|0)+(aD<<1)>>1]|0}ae=((aP^az)&2081|e[(c[277220]|0)+((az&2081&aN)+((aO+(az&63454)|0)>>>1)<<1)>>1])&65535;az=aB+3|0;b[(c[277218]|0)+(az<<1)>>1]=ae;b[(c[277218]|0)+(aD<<1)>>1]=ae;ae=a[1108909]|0;a[(c[277219]|0)+az|0]=ae;a[(c[277219]|0)+aD|0]=ae}}while(0);aD=aH-1&255;if(aD<<24>>24!=0){aI=aD;v=1457}}if((v|0)==1457){v=0;aD=aB+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+aD|0]|0)){ae=a[s+5|0]|0;if(ae<<24>>24==0){break}az=e[(c[277225]|0)+((ae&255)<<1)>>1]|0;ae=(a[(c[277215]|0)+aD|0]&32)==0;if(ae){ay=c[277228]|0;aQ=ay;aR=ay&-2082}else{ay=e[(c[277213]|0)+(aD<<1)>>1]|0;aQ=ay;aR=ay&63454}if(ae){aS=c[277228]|0}else{aS=e[(c[277213]|0)+(aD<<1)>>1]|0}ae=((aS^az)&2081|e[(c[277220]|0)+((az&2081&aQ)+((aR+(az&63454)|0)>>>1)<<1)>>1])&65535;az=aB+5|0;b[(c[277218]|0)+(az<<1)>>1]=ae;b[(c[277218]|0)+(aD<<1)>>1]=ae;ae=a[1108909]|0;a[(c[277219]|0)+az|0]=ae;a[(c[277219]|0)+aD|0]=ae}}while(0);aD=aI-1&255;if(aD<<24>>24!=0){aJ=aD;v=1467}}if((v|0)==1467){v=0;aD=aB+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+aD|0]|0)){ae=a[s+4|0]|0;if(ae<<24>>24==0){break}az=e[(c[277225]|0)+((ae&255)<<1)>>1]|0;ae=(a[(c[277215]|0)+aD|0]&32)==0;if(ae){ay=c[277228]|0;aT=ay;aU=ay&-2082}else{ay=e[(c[277213]|0)+(aD<<1)>>1]|0;aT=ay;aU=ay&63454}if(ae){aV=c[277228]|0}else{aV=e[(c[277213]|0)+(aD<<1)>>1]|0}ae=((aV^az)&2081|e[(c[277220]|0)+((az&2081&aT)+((aU+(az&63454)|0)>>>1)<<1)>>1])&65535;az=aB+7|0;b[(c[277218]|0)+(az<<1)>>1]=ae;b[(c[277218]|0)+(aD<<1)>>1]=ae;ae=a[1108909]|0;a[(c[277219]|0)+az|0]=ae;a[(c[277219]|0)+aD|0]=ae}}while(0);aD=aJ-1&255;if(aD<<24>>24!=0){aK=aD;v=1477}}if((v|0)==1477){v=0;aD=aB+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+aD|0]|0)){ae=a[s+3|0]|0;if(ae<<24>>24==0){break}az=e[(c[277225]|0)+((ae&255)<<1)>>1]|0;ae=(a[(c[277215]|0)+aD|0]&32)==0;if(ae){ay=c[277228]|0;aW=ay;aX=ay&-2082}else{ay=e[(c[277213]|0)+(aD<<1)>>1]|0;aW=ay;aX=ay&63454}if(ae){aY=c[277228]|0}else{aY=e[(c[277213]|0)+(aD<<1)>>1]|0}ae=((aY^az)&2081|e[(c[277220]|0)+((az&2081&aW)+((aX+(az&63454)|0)>>>1)<<1)>>1])&65535;az=aB+9|0;b[(c[277218]|0)+(az<<1)>>1]=ae;b[(c[277218]|0)+(aD<<1)>>1]=ae;ae=a[1108909]|0;a[(c[277219]|0)+az|0]=ae;a[(c[277219]|0)+aD|0]=ae}}while(0);aD=aK-1&255;if(aD<<24>>24!=0){aL=aD;v=1487}}if((v|0)==1487){v=0;aD=aB+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+aD|0]|0)){ae=a[s+2|0]|0;if(ae<<24>>24==0){break}az=e[(c[277225]|0)+((ae&255)<<1)>>1]|0;ae=(a[(c[277215]|0)+aD|0]&32)==0;if(ae){ay=c[277228]|0;aZ=ay;a_=ay&-2082}else{ay=e[(c[277213]|0)+(aD<<1)>>1]|0;aZ=ay;a_=ay&63454}if(ae){a$=c[277228]|0}else{a$=e[(c[277213]|0)+(aD<<1)>>1]|0}ae=((a$^az)&2081|e[(c[277220]|0)+((az&2081&aZ)+((a_+(az&63454)|0)>>>1)<<1)>>1])&65535;az=aB+11|0;b[(c[277218]|0)+(az<<1)>>1]=ae;b[(c[277218]|0)+(aD<<1)>>1]=ae;ae=a[1108909]|0;a[(c[277219]|0)+az|0]=ae;a[(c[277219]|0)+aD|0]=ae}}while(0);aD=aL-1&255;if(aD<<24>>24!=0){aM=aD;v=1497}}if((v|0)==1497){v=0;aD=aB+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+aD|0]|0)){ae=a[s+1|0]|0;if(ae<<24>>24==0){break}az=e[(c[277225]|0)+((ae&255)<<1)>>1]|0;ae=(a[(c[277215]|0)+aD|0]&32)==0;if(ae){ay=c[277228]|0;a0=ay;a1=ay&-2082}else{ay=e[(c[277213]|0)+(aD<<1)>>1]|0;a0=ay;a1=ay&63454}if(ae){a2=c[277228]|0}else{a2=e[(c[277213]|0)+(aD<<1)>>1]|0}ae=((a2^az)&2081|e[(c[277220]|0)+((az&2081&a0)+((a1+(az&63454)|0)>>>1)<<1)>>1])&65535;az=aB+13|0;b[(c[277218]|0)+(az<<1)>>1]=ae;b[(c[277218]|0)+(aD<<1)>>1]=ae;ae=a[1108909]|0;a[(c[277219]|0)+az|0]=ae;a[(c[277219]|0)+aD|0]=ae}}while(0);if(aM<<24>>24!=1){v=1507}}do{if((v|0)==1507){v=0;aD=aB+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+aD|0]|0)){break}ae=a[s]|0;if(ae<<24>>24==0){break}az=e[(c[277225]|0)+((ae&255)<<1)>>1]|0;ae=(a[(c[277215]|0)+aD|0]&32)==0;if(ae){ay=c[277228]|0;a3=ay;a4=ay&-2082}else{ay=e[(c[277213]|0)+(aD<<1)>>1]|0;a3=ay;a4=ay&63454}if(ae){a5=c[277228]|0}else{a5=e[(c[277213]|0)+(aD<<1)>>1]|0}ae=((a5^az)&2081|e[(c[277220]|0)+((az&2081&a3)+((a4+(az&63454)|0)>>>1)<<1)>>1])&65535;az=aB+15|0;b[(c[277218]|0)+(az<<1)>>1]=ae;b[(c[277218]|0)+(aD<<1)>>1]=ae;ae=a[1108909]|0;a[(c[277219]|0)+az|0]=ae;a[(c[277219]|0)+aD|0]=ae}}while(0);ae=aC-1|0;if((ae|0)>0){s=s-16|0;aC=ae;aB=(c[277223]|0)+aB|0}else{break}}return}else{if(!n){return}n=i&255;i=n-1&255;aB=i<<24>>24==0;aC=Z;Z=k;k=g;while(1){switch(h|0){case 1:{a6=n;v=1366;break};case 2:{a7=n;v=1376;break};case 3:{a8=n;v=1386;break};case 4:{a9=n;v=1396;break};case 5:{ba=n;v=1406;break};case 6:{bb=n;v=1416;break};case 7:{v=1426;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+k|0]|0)){g=a[aC]|0;if(g<<24>>24==0){break}s=e[(c[277225]|0)+((g&255)<<1)>>1]|0;g=(a[(c[277215]|0)+k|0]&32)==0;if(g){a4=c[277228]|0;bc=a4;bd=a4&-2082}else{a4=e[(c[277213]|0)+(k<<1)>>1]|0;bc=a4;bd=a4&63454}if(g){be=c[277228]|0}else{be=e[(c[277213]|0)+(k<<1)>>1]|0}g=((be^s)&2081|e[(c[277220]|0)+((s&2081&bc)+((bd+(s&63454)|0)>>>1)<<1)>>1])&65535;s=k+1|0;b[(c[277218]|0)+(s<<1)>>1]=g;b[(c[277218]|0)+(k<<1)>>1]=g;g=a[1108909]|0;a[(c[277219]|0)+s|0]=g;a[(c[277219]|0)+k|0]=g}}while(0);if(!aB){a6=i;v=1366}break};default:{}}if((v|0)==1366){v=0;g=k+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+g|0]|0)){s=a[aC+1|0]|0;if(s<<24>>24==0){break}a4=e[(c[277225]|0)+((s&255)<<1)>>1]|0;s=(a[(c[277215]|0)+g|0]&32)==0;if(s){a3=c[277228]|0;bf=a3;bg=a3&-2082}else{a3=e[(c[277213]|0)+(g<<1)>>1]|0;bf=a3;bg=a3&63454}if(s){bh=c[277228]|0}else{bh=e[(c[277213]|0)+(g<<1)>>1]|0}s=((bh^a4)&2081|e[(c[277220]|0)+((a4&2081&bf)+((bg+(a4&63454)|0)>>>1)<<1)>>1])&65535;a4=k+3|0;b[(c[277218]|0)+(a4<<1)>>1]=s;b[(c[277218]|0)+(g<<1)>>1]=s;s=a[1108909]|0;a[(c[277219]|0)+a4|0]=s;a[(c[277219]|0)+g|0]=s}}while(0);g=a6-1&255;if(g<<24>>24!=0){a7=g;v=1376}}if((v|0)==1376){v=0;g=k+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+g|0]|0)){s=a[aC+2|0]|0;if(s<<24>>24==0){break}a4=e[(c[277225]|0)+((s&255)<<1)>>1]|0;s=(a[(c[277215]|0)+g|0]&32)==0;if(s){a3=c[277228]|0;bi=a3;bj=a3&-2082}else{a3=e[(c[277213]|0)+(g<<1)>>1]|0;bi=a3;bj=a3&63454}if(s){bk=c[277228]|0}else{bk=e[(c[277213]|0)+(g<<1)>>1]|0}s=((bk^a4)&2081|e[(c[277220]|0)+((a4&2081&bi)+((bj+(a4&63454)|0)>>>1)<<1)>>1])&65535;a4=k+5|0;b[(c[277218]|0)+(a4<<1)>>1]=s;b[(c[277218]|0)+(g<<1)>>1]=s;s=a[1108909]|0;a[(c[277219]|0)+a4|0]=s;a[(c[277219]|0)+g|0]=s}}while(0);g=a7-1&255;if(g<<24>>24!=0){a8=g;v=1386}}if((v|0)==1386){v=0;g=k+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+g|0]|0)){s=a[aC+3|0]|0;if(s<<24>>24==0){break}a4=e[(c[277225]|0)+((s&255)<<1)>>1]|0;s=(a[(c[277215]|0)+g|0]&32)==0;if(s){a3=c[277228]|0;bl=a3;bm=a3&-2082}else{a3=e[(c[277213]|0)+(g<<1)>>1]|0;bl=a3;bm=a3&63454}if(s){bn=c[277228]|0}else{bn=e[(c[277213]|0)+(g<<1)>>1]|0}s=((bn^a4)&2081|e[(c[277220]|0)+((a4&2081&bl)+((bm+(a4&63454)|0)>>>1)<<1)>>1])&65535;a4=k+7|0;b[(c[277218]|0)+(a4<<1)>>1]=s;b[(c[277218]|0)+(g<<1)>>1]=s;s=a[1108909]|0;a[(c[277219]|0)+a4|0]=s;a[(c[277219]|0)+g|0]=s}}while(0);g=a8-1&255;if(g<<24>>24!=0){a9=g;v=1396}}if((v|0)==1396){v=0;g=k+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+g|0]|0)){s=a[aC+4|0]|0;if(s<<24>>24==0){break}a4=e[(c[277225]|0)+((s&255)<<1)>>1]|0;s=(a[(c[277215]|0)+g|0]&32)==0;if(s){a3=c[277228]|0;bo=a3;bp=a3&-2082}else{a3=e[(c[277213]|0)+(g<<1)>>1]|0;bo=a3;bp=a3&63454}if(s){bq=c[277228]|0}else{bq=e[(c[277213]|0)+(g<<1)>>1]|0}s=((bq^a4)&2081|e[(c[277220]|0)+((a4&2081&bo)+((bp+(a4&63454)|0)>>>1)<<1)>>1])&65535;a4=k+9|0;b[(c[277218]|0)+(a4<<1)>>1]=s;b[(c[277218]|0)+(g<<1)>>1]=s;s=a[1108909]|0;a[(c[277219]|0)+a4|0]=s;a[(c[277219]|0)+g|0]=s}}while(0);g=a9-1&255;if(g<<24>>24!=0){ba=g;v=1406}}if((v|0)==1406){v=0;g=k+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+g|0]|0)){s=a[aC+5|0]|0;if(s<<24>>24==0){break}a4=e[(c[277225]|0)+((s&255)<<1)>>1]|0;s=(a[(c[277215]|0)+g|0]&32)==0;if(s){a3=c[277228]|0;br=a3;bs=a3&-2082}else{a3=e[(c[277213]|0)+(g<<1)>>1]|0;br=a3;bs=a3&63454}if(s){bt=c[277228]|0}else{bt=e[(c[277213]|0)+(g<<1)>>1]|0}s=((bt^a4)&2081|e[(c[277220]|0)+((a4&2081&br)+((bs+(a4&63454)|0)>>>1)<<1)>>1])&65535;a4=k+11|0;b[(c[277218]|0)+(a4<<1)>>1]=s;b[(c[277218]|0)+(g<<1)>>1]=s;s=a[1108909]|0;a[(c[277219]|0)+a4|0]=s;a[(c[277219]|0)+g|0]=s}}while(0);g=ba-1&255;if(g<<24>>24!=0){bb=g;v=1416}}if((v|0)==1416){v=0;g=k+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+g|0]|0)){s=a[aC+6|0]|0;if(s<<24>>24==0){break}a4=e[(c[277225]|0)+((s&255)<<1)>>1]|0;s=(a[(c[277215]|0)+g|0]&32)==0;if(s){a3=c[277228]|0;bu=a3;bv=a3&-2082}else{a3=e[(c[277213]|0)+(g<<1)>>1]|0;bu=a3;bv=a3&63454}if(s){bw=c[277228]|0}else{bw=e[(c[277213]|0)+(g<<1)>>1]|0}s=((bw^a4)&2081|e[(c[277220]|0)+((a4&2081&bu)+((bv+(a4&63454)|0)>>>1)<<1)>>1])&65535;a4=k+13|0;b[(c[277218]|0)+(a4<<1)>>1]=s;b[(c[277218]|0)+(g<<1)>>1]=s;s=a[1108909]|0;a[(c[277219]|0)+a4|0]=s;a[(c[277219]|0)+g|0]=s}}while(0);if(bb<<24>>24!=1){v=1426}}do{if((v|0)==1426){v=0;g=k+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+g|0]|0)){break}s=a[aC+7|0]|0;if(s<<24>>24==0){break}a4=e[(c[277225]|0)+((s&255)<<1)>>1]|0;s=(a[(c[277215]|0)+g|0]&32)==0;if(s){a3=c[277228]|0;bx=a3;by=a3&-2082}else{a3=e[(c[277213]|0)+(g<<1)>>1]|0;bx=a3;by=a3&63454}if(s){bz=c[277228]|0}else{bz=e[(c[277213]|0)+(g<<1)>>1]|0}s=((bz^a4)&2081|e[(c[277220]|0)+((a4&2081&bx)+((by+(a4&63454)|0)>>>1)<<1)>>1])&65535;a4=k+15|0;b[(c[277218]|0)+(a4<<1)>>1]=s;b[(c[277218]|0)+(g<<1)>>1]=s;s=a[1108909]|0;a[(c[277219]|0)+a4|0]=s;a[(c[277219]|0)+g|0]=s}}while(0);s=Z-1|0;if((s|0)>0){aC=aC-16|0;Z=s;k=(c[277223]|0)+k|0}else{break}}return}}function Vh(f,g,h,i,j,k){f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0;l=f&1023;m=c[348606]|0;n=(l<<m)+(c[348604]|0)|0;if((f&256|0)==0){o=n}else{o=(c[348602]|0)+n|0}n=o&65535;o=n>>>(m>>>0);m=(f&16384|0)!=0;p=o<<6;do{if(m){q=(c[348622]|0)+p|0;if((a[(c[348618]|0)+o|0]|0)!=0){r=q;break}s=fi[c[348636]&63](q,n,l)|0;a[(c[348618]|0)+o|0]=s;r=q}else{q=(c[348624]|0)+p|0;if((a[(c[348620]|0)+o|0]|0)!=0){r=q;break}s=fi[c[348638]&63](q,n,l)|0;a[(c[348620]|0)+o|0]=s;r=q}}while(0);if((a[(c[348620]|0)+o|0]|0)==2){return}if((a[1394464]|0)==0){t=1106168+((f>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){o=d[1044485]|0;c[276541]=7080+(o<<5);l=0;do{n=l<<1&2;p=l&2;q=l&4;s=0;do{b[1125528+(l<<9)+(s<<1)>>1]=d[(s>>>1&28|p)+(7080+(o<<5))|0]<<6|d[(s<<2&28|n)+(7080+(o<<5))|0]<<11|d[(s>>>3&24|q)+(7080+(o<<5))|0];s=s+1|0;}while(s>>>0<256);l=l+1|0;}while(l>>>0<8);a[1106089]=0}t=1125528+((f>>>10&7)<<9)|0}c[277226]=t;c[277225]=(a[1108928]|0)!=0?1393712:t;if((f&49152|0)==0){if((k|0)<=0){return}t=i&255;l=t-1&255;o=l<<24>>24==0;s=r+((d[1394504]|0)+(j<<1))|0;q=k;n=g;while(1){switch(h|0){case 6:{u=t;v=1584;break};case 7:{v=1590;break};case 3:{w=t;v=1566;break};case 2:{x=t;v=1560;break};case 1:{y=t;v=1554;break};case 4:{z=t;v=1572;break};case 5:{A=t;v=1578;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+n|0]|0)){p=a[s]|0;if(p<<24>>24==0){break}B=e[(c[277225]|0)+((p&255)<<1)>>1]|0;p=c[277228]|0;C=(((B&63454)+(p&-2082)|0)>>>1)+(p&2081&B)|0;if((a[1108928]|0)==0){D=C&65535}else{D=(e[(c[277220]|0)+(C<<1)>>1]|(B^p)&2081)&65535}p=n+1|0;b[(c[277218]|0)+(p<<1)>>1]=D;b[(c[277218]|0)+(n<<1)>>1]=D;B=a[1108909]|0;a[(c[277219]|0)+p|0]=B;a[(c[277219]|0)+n|0]=B}}while(0);if(!o){y=l;v=1554}break};default:{}}if((v|0)==1554){v=0;B=n+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+B|0]|0)){p=a[s+1|0]|0;if(p<<24>>24==0){break}C=e[(c[277225]|0)+((p&255)<<1)>>1]|0;p=c[277228]|0;E=(((C&63454)+(p&-2082)|0)>>>1)+(p&2081&C)|0;if((a[1108928]|0)==0){F=E&65535}else{F=(e[(c[277220]|0)+(E<<1)>>1]|(C^p)&2081)&65535}p=n+3|0;b[(c[277218]|0)+(p<<1)>>1]=F;b[(c[277218]|0)+(B<<1)>>1]=F;C=a[1108909]|0;a[(c[277219]|0)+p|0]=C;a[(c[277219]|0)+B|0]=C}}while(0);B=y-1&255;if(B<<24>>24!=0){x=B;v=1560}}if((v|0)==1560){v=0;B=n+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+B|0]|0)){C=a[s+2|0]|0;if(C<<24>>24==0){break}p=e[(c[277225]|0)+((C&255)<<1)>>1]|0;C=c[277228]|0;E=(((p&63454)+(C&-2082)|0)>>>1)+(C&2081&p)|0;if((a[1108928]|0)==0){G=E&65535}else{G=(e[(c[277220]|0)+(E<<1)>>1]|(p^C)&2081)&65535}C=n+5|0;b[(c[277218]|0)+(C<<1)>>1]=G;b[(c[277218]|0)+(B<<1)>>1]=G;p=a[1108909]|0;a[(c[277219]|0)+C|0]=p;a[(c[277219]|0)+B|0]=p}}while(0);B=x-1&255;if(B<<24>>24!=0){w=B;v=1566}}if((v|0)==1566){v=0;B=n+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+B|0]|0)){p=a[s+3|0]|0;if(p<<24>>24==0){break}C=e[(c[277225]|0)+((p&255)<<1)>>1]|0;p=c[277228]|0;E=(((C&63454)+(p&-2082)|0)>>>1)+(p&2081&C)|0;if((a[1108928]|0)==0){H=E&65535}else{H=(e[(c[277220]|0)+(E<<1)>>1]|(C^p)&2081)&65535}p=n+7|0;b[(c[277218]|0)+(p<<1)>>1]=H;b[(c[277218]|0)+(B<<1)>>1]=H;C=a[1108909]|0;a[(c[277219]|0)+p|0]=C;a[(c[277219]|0)+B|0]=C}}while(0);B=w-1&255;if(B<<24>>24!=0){z=B;v=1572}}if((v|0)==1572){v=0;B=n+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+B|0]|0)){C=a[s+4|0]|0;if(C<<24>>24==0){break}p=e[(c[277225]|0)+((C&255)<<1)>>1]|0;C=c[277228]|0;E=(((p&63454)+(C&-2082)|0)>>>1)+(C&2081&p)|0;if((a[1108928]|0)==0){I=E&65535}else{I=(e[(c[277220]|0)+(E<<1)>>1]|(p^C)&2081)&65535}C=n+9|0;b[(c[277218]|0)+(C<<1)>>1]=I;b[(c[277218]|0)+(B<<1)>>1]=I;p=a[1108909]|0;a[(c[277219]|0)+C|0]=p;a[(c[277219]|0)+B|0]=p}}while(0);B=z-1&255;if(B<<24>>24!=0){A=B;v=1578}}if((v|0)==1578){v=0;B=n+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+B|0]|0)){p=a[s+5|0]|0;if(p<<24>>24==0){break}C=e[(c[277225]|0)+((p&255)<<1)>>1]|0;p=c[277228]|0;E=(((C&63454)+(p&-2082)|0)>>>1)+(p&2081&C)|0;if((a[1108928]|0)==0){J=E&65535}else{J=(e[(c[277220]|0)+(E<<1)>>1]|(C^p)&2081)&65535}p=n+11|0;b[(c[277218]|0)+(p<<1)>>1]=J;b[(c[277218]|0)+(B<<1)>>1]=J;C=a[1108909]|0;a[(c[277219]|0)+p|0]=C;a[(c[277219]|0)+B|0]=C}}while(0);B=A-1&255;if(B<<24>>24!=0){u=B;v=1584}}if((v|0)==1584){v=0;B=n+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+B|0]|0)){C=a[s+6|0]|0;if(C<<24>>24==0){break}p=e[(c[277225]|0)+((C&255)<<1)>>1]|0;C=c[277228]|0;E=(((p&63454)+(C&-2082)|0)>>>1)+(C&2081&p)|0;if((a[1108928]|0)==0){K=E&65535}else{K=(e[(c[277220]|0)+(E<<1)>>1]|(p^C)&2081)&65535}C=n+13|0;b[(c[277218]|0)+(C<<1)>>1]=K;b[(c[277218]|0)+(B<<1)>>1]=K;p=a[1108909]|0;a[(c[277219]|0)+C|0]=p;a[(c[277219]|0)+B|0]=p}}while(0);if(u<<24>>24!=1){v=1590}}do{if((v|0)==1590){v=0;B=n+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+B|0]|0)){break}p=a[s+7|0]|0;if(p<<24>>24==0){break}C=e[(c[277225]|0)+((p&255)<<1)>>1]|0;p=c[277228]|0;E=(((C&63454)+(p&-2082)|0)>>>1)+(p&2081&C)|0;if((a[1108928]|0)==0){L=E&65535}else{L=(e[(c[277220]|0)+(E<<1)>>1]|(C^p)&2081)&65535}p=n+15|0;b[(c[277218]|0)+(p<<1)>>1]=L;b[(c[277218]|0)+(B<<1)>>1]=L;C=a[1108909]|0;a[(c[277219]|0)+p|0]=C;a[(c[277219]|0)+B|0]=C}}while(0);C=q-1|0;if((C|0)>0){s=s+16|0;q=C;n=(c[277223]|0)+n|0}else{break}}return}n=(d[1394504]|0)+(j<<1)|0;if((f&32768|0)==0){if((k|0)<=0){return}f=i&255;j=f-1&255;q=j<<24>>24==0;s=r+n|0;L=k;u=g;while(1){switch(h|0){case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+u|0]|0)){K=a[s+7|0]|0;if(K<<24>>24==0){break}A=e[(c[277225]|0)+((K&255)<<1)>>1]|0;K=c[277228]|0;J=(((A&63454)+(K&-2082)|0)>>>1)+(K&2081&A)|0;if((a[1108928]|0)==0){M=J&65535}else{M=(e[(c[277220]|0)+(J<<1)>>1]|(A^K)&2081)&65535}K=u+1|0;b[(c[277218]|0)+(K<<1)>>1]=M;b[(c[277218]|0)+(u<<1)>>1]=M;A=a[1108909]|0;a[(c[277219]|0)+K|0]=A;a[(c[277219]|0)+u|0]=A}}while(0);if(!q){N=j;v=1606}break};case 1:{N=f;v=1606;break};case 2:{O=f;v=1612;break};case 3:{P=f;v=1618;break};case 4:{Q=f;v=1624;break};case 5:{R=f;v=1630;break};case 6:{S=f;v=1636;break};case 7:{v=1642;break};default:{}}if((v|0)==1606){v=0;A=u+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+A|0]|0)){K=a[s+6|0]|0;if(K<<24>>24==0){break}J=e[(c[277225]|0)+((K&255)<<1)>>1]|0;K=c[277228]|0;z=(((J&63454)+(K&-2082)|0)>>>1)+(K&2081&J)|0;if((a[1108928]|0)==0){T=z&65535}else{T=(e[(c[277220]|0)+(z<<1)>>1]|(J^K)&2081)&65535}K=u+3|0;b[(c[277218]|0)+(K<<1)>>1]=T;b[(c[277218]|0)+(A<<1)>>1]=T;J=a[1108909]|0;a[(c[277219]|0)+K|0]=J;a[(c[277219]|0)+A|0]=J}}while(0);A=N-1&255;if(A<<24>>24!=0){O=A;v=1612}}if((v|0)==1612){v=0;A=u+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+A|0]|0)){J=a[s+5|0]|0;if(J<<24>>24==0){break}K=e[(c[277225]|0)+((J&255)<<1)>>1]|0;J=c[277228]|0;z=(((K&63454)+(J&-2082)|0)>>>1)+(J&2081&K)|0;if((a[1108928]|0)==0){U=z&65535}else{U=(e[(c[277220]|0)+(z<<1)>>1]|(K^J)&2081)&65535}J=u+5|0;b[(c[277218]|0)+(J<<1)>>1]=U;b[(c[277218]|0)+(A<<1)>>1]=U;K=a[1108909]|0;a[(c[277219]|0)+J|0]=K;a[(c[277219]|0)+A|0]=K}}while(0);A=O-1&255;if(A<<24>>24!=0){P=A;v=1618}}if((v|0)==1618){v=0;A=u+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+A|0]|0)){K=a[s+4|0]|0;if(K<<24>>24==0){break}J=e[(c[277225]|0)+((K&255)<<1)>>1]|0;K=c[277228]|0;z=(((J&63454)+(K&-2082)|0)>>>1)+(K&2081&J)|0;if((a[1108928]|0)==0){V=z&65535}else{V=(e[(c[277220]|0)+(z<<1)>>1]|(J^K)&2081)&65535}K=u+7|0;b[(c[277218]|0)+(K<<1)>>1]=V;b[(c[277218]|0)+(A<<1)>>1]=V;J=a[1108909]|0;a[(c[277219]|0)+K|0]=J;a[(c[277219]|0)+A|0]=J}}while(0);A=P-1&255;if(A<<24>>24!=0){Q=A;v=1624}}if((v|0)==1624){v=0;A=u+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+A|0]|0)){J=a[s+3|0]|0;if(J<<24>>24==0){break}K=e[(c[277225]|0)+((J&255)<<1)>>1]|0;J=c[277228]|0;z=(((K&63454)+(J&-2082)|0)>>>1)+(J&2081&K)|0;if((a[1108928]|0)==0){W=z&65535}else{W=(e[(c[277220]|0)+(z<<1)>>1]|(K^J)&2081)&65535}J=u+9|0;b[(c[277218]|0)+(J<<1)>>1]=W;b[(c[277218]|0)+(A<<1)>>1]=W;K=a[1108909]|0;a[(c[277219]|0)+J|0]=K;a[(c[277219]|0)+A|0]=K}}while(0);A=Q-1&255;if(A<<24>>24!=0){R=A;v=1630}}if((v|0)==1630){v=0;A=u+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+A|0]|0)){K=a[s+2|0]|0;if(K<<24>>24==0){break}J=e[(c[277225]|0)+((K&255)<<1)>>1]|0;K=c[277228]|0;z=(((J&63454)+(K&-2082)|0)>>>1)+(K&2081&J)|0;if((a[1108928]|0)==0){X=z&65535}else{X=(e[(c[277220]|0)+(z<<1)>>1]|(J^K)&2081)&65535}K=u+11|0;b[(c[277218]|0)+(K<<1)>>1]=X;b[(c[277218]|0)+(A<<1)>>1]=X;J=a[1108909]|0;a[(c[277219]|0)+K|0]=J;a[(c[277219]|0)+A|0]=J}}while(0);A=R-1&255;if(A<<24>>24!=0){S=A;v=1636}}if((v|0)==1636){v=0;A=u+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+A|0]|0)){J=a[s+1|0]|0;if(J<<24>>24==0){break}K=e[(c[277225]|0)+((J&255)<<1)>>1]|0;J=c[277228]|0;z=(((K&63454)+(J&-2082)|0)>>>1)+(J&2081&K)|0;if((a[1108928]|0)==0){Y=z&65535}else{Y=(e[(c[277220]|0)+(z<<1)>>1]|(K^J)&2081)&65535}J=u+13|0;b[(c[277218]|0)+(J<<1)>>1]=Y;b[(c[277218]|0)+(A<<1)>>1]=Y;K=a[1108909]|0;a[(c[277219]|0)+J|0]=K;a[(c[277219]|0)+A|0]=K}}while(0);if(S<<24>>24!=1){v=1642}}do{if((v|0)==1642){v=0;A=u+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+A|0]|0)){break}K=a[s]|0;if(K<<24>>24==0){break}J=e[(c[277225]|0)+((K&255)<<1)>>1]|0;K=c[277228]|0;z=(((J&63454)+(K&-2082)|0)>>>1)+(K&2081&J)|0;if((a[1108928]|0)==0){Z=z&65535}else{Z=(e[(c[277220]|0)+(z<<1)>>1]|(J^K)&2081)&65535}K=u+15|0;b[(c[277218]|0)+(K<<1)>>1]=Z;b[(c[277218]|0)+(A<<1)>>1]=Z;J=a[1108909]|0;a[(c[277219]|0)+K|0]=J;a[(c[277219]|0)+A|0]=J}}while(0);J=L-1|0;if((J|0)>0){s=s+16|0;L=J;u=(c[277223]|0)+u|0}else{break}}return}u=r+(56-n)|0;n=(k|0)>0;if(m){if(!n){return}m=i&255;r=m-1&255;L=r<<24>>24==0;s=u;Z=k;S=g;while(1){switch(h|0){case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+S|0]|0)){Y=a[s+7|0]|0;if(Y<<24>>24==0){break}R=e[(c[277225]|0)+((Y&255)<<1)>>1]|0;Y=c[277228]|0;X=(((R&63454)+(Y&-2082)|0)>>>1)+(Y&2081&R)|0;if((a[1108928]|0)==0){_=X&65535}else{_=(e[(c[277220]|0)+(X<<1)>>1]|(R^Y)&2081)&65535}Y=S+1|0;b[(c[277218]|0)+(Y<<1)>>1]=_;b[(c[277218]|0)+(S<<1)>>1]=_;R=a[1108909]|0;a[(c[277219]|0)+Y|0]=R;a[(c[277219]|0)+S|0]=R}}while(0);if(!L){$=r;v=1709}break};case 1:{$=m;v=1709;break};case 2:{aa=m;v=1715;break};case 3:{ab=m;v=1721;break};case 4:{ac=m;v=1727;break};case 5:{ad=m;v=1733;break};case 6:{ae=m;v=1739;break};case 7:{v=1745;break};default:{}}if((v|0)==1709){v=0;R=S+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+R|0]|0)){Y=a[s+6|0]|0;if(Y<<24>>24==0){break}X=e[(c[277225]|0)+((Y&255)<<1)>>1]|0;Y=c[277228]|0;Q=(((X&63454)+(Y&-2082)|0)>>>1)+(Y&2081&X)|0;if((a[1108928]|0)==0){af=Q&65535}else{af=(e[(c[277220]|0)+(Q<<1)>>1]|(X^Y)&2081)&65535}Y=S+3|0;b[(c[277218]|0)+(Y<<1)>>1]=af;b[(c[277218]|0)+(R<<1)>>1]=af;X=a[1108909]|0;a[(c[277219]|0)+Y|0]=X;a[(c[277219]|0)+R|0]=X}}while(0);R=$-1&255;if(R<<24>>24!=0){aa=R;v=1715}}if((v|0)==1715){v=0;R=S+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+R|0]|0)){X=a[s+5|0]|0;if(X<<24>>24==0){break}Y=e[(c[277225]|0)+((X&255)<<1)>>1]|0;X=c[277228]|0;Q=(((Y&63454)+(X&-2082)|0)>>>1)+(X&2081&Y)|0;if((a[1108928]|0)==0){ag=Q&65535}else{ag=(e[(c[277220]|0)+(Q<<1)>>1]|(Y^X)&2081)&65535}X=S+5|0;b[(c[277218]|0)+(X<<1)>>1]=ag;b[(c[277218]|0)+(R<<1)>>1]=ag;Y=a[1108909]|0;a[(c[277219]|0)+X|0]=Y;a[(c[277219]|0)+R|0]=Y}}while(0);R=aa-1&255;if(R<<24>>24!=0){ab=R;v=1721}}if((v|0)==1721){v=0;R=S+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+R|0]|0)){Y=a[s+4|0]|0;if(Y<<24>>24==0){break}X=e[(c[277225]|0)+((Y&255)<<1)>>1]|0;Y=c[277228]|0;Q=(((X&63454)+(Y&-2082)|0)>>>1)+(Y&2081&X)|0;if((a[1108928]|0)==0){ah=Q&65535}else{ah=(e[(c[277220]|0)+(Q<<1)>>1]|(X^Y)&2081)&65535}Y=S+7|0;b[(c[277218]|0)+(Y<<1)>>1]=ah;b[(c[277218]|0)+(R<<1)>>1]=ah;X=a[1108909]|0;a[(c[277219]|0)+Y|0]=X;a[(c[277219]|0)+R|0]=X}}while(0);R=ab-1&255;if(R<<24>>24!=0){ac=R;v=1727}}if((v|0)==1727){v=0;R=S+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+R|0]|0)){X=a[s+3|0]|0;if(X<<24>>24==0){break}Y=e[(c[277225]|0)+((X&255)<<1)>>1]|0;X=c[277228]|0;Q=(((Y&63454)+(X&-2082)|0)>>>1)+(X&2081&Y)|0;if((a[1108928]|0)==0){ai=Q&65535}else{ai=(e[(c[277220]|0)+(Q<<1)>>1]|(Y^X)&2081)&65535}X=S+9|0;b[(c[277218]|0)+(X<<1)>>1]=ai;b[(c[277218]|0)+(R<<1)>>1]=ai;Y=a[1108909]|0;a[(c[277219]|0)+X|0]=Y;a[(c[277219]|0)+R|0]=Y}}while(0);R=ac-1&255;if(R<<24>>24!=0){ad=R;v=1733}}if((v|0)==1733){v=0;R=S+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+R|0]|0)){Y=a[s+2|0]|0;if(Y<<24>>24==0){break}X=e[(c[277225]|0)+((Y&255)<<1)>>1]|0;Y=c[277228]|0;Q=(((X&63454)+(Y&-2082)|0)>>>1)+(Y&2081&X)|0;if((a[1108928]|0)==0){aj=Q&65535}else{aj=(e[(c[277220]|0)+(Q<<1)>>1]|(X^Y)&2081)&65535}Y=S+11|0;b[(c[277218]|0)+(Y<<1)>>1]=aj;b[(c[277218]|0)+(R<<1)>>1]=aj;X=a[1108909]|0;a[(c[277219]|0)+Y|0]=X;a[(c[277219]|0)+R|0]=X}}while(0);R=ad-1&255;if(R<<24>>24!=0){ae=R;v=1739}}if((v|0)==1739){v=0;R=S+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+R|0]|0)){X=a[s+1|0]|0;if(X<<24>>24==0){break}Y=e[(c[277225]|0)+((X&255)<<1)>>1]|0;X=c[277228]|0;Q=(((Y&63454)+(X&-2082)|0)>>>1)+(X&2081&Y)|0;if((a[1108928]|0)==0){ak=Q&65535}else{ak=(e[(c[277220]|0)+(Q<<1)>>1]|(Y^X)&2081)&65535}X=S+13|0;b[(c[277218]|0)+(X<<1)>>1]=ak;b[(c[277218]|0)+(R<<1)>>1]=ak;Y=a[1108909]|0;a[(c[277219]|0)+X|0]=Y;a[(c[277219]|0)+R|0]=Y}}while(0);if(ae<<24>>24!=1){v=1745}}do{if((v|0)==1745){v=0;R=S+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+R|0]|0)){break}Y=a[s]|0;if(Y<<24>>24==0){break}X=e[(c[277225]|0)+((Y&255)<<1)>>1]|0;Y=c[277228]|0;Q=(((X&63454)+(Y&-2082)|0)>>>1)+(Y&2081&X)|0;if((a[1108928]|0)==0){al=Q&65535}else{al=(e[(c[277220]|0)+(Q<<1)>>1]|(X^Y)&2081)&65535}Y=S+15|0;b[(c[277218]|0)+(Y<<1)>>1]=al;b[(c[277218]|0)+(R<<1)>>1]=al;X=a[1108909]|0;a[(c[277219]|0)+Y|0]=X;a[(c[277219]|0)+R|0]=X}}while(0);X=Z-1|0;if((X|0)>0){s=s-16|0;Z=X;S=(c[277223]|0)+S|0}else{break}}return}else{if(!n){return}n=i&255;i=n-1&255;S=i<<24>>24==0;Z=u;u=k;k=g;while(1){switch(h|0){case 3:{am=n;v=1672;break};case 4:{an=n;v=1678;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+k|0]|0)){g=a[Z]|0;if(g<<24>>24==0){break}s=e[(c[277225]|0)+((g&255)<<1)>>1]|0;g=c[277228]|0;al=(((s&63454)+(g&-2082)|0)>>>1)+(g&2081&s)|0;if((a[1108928]|0)==0){ao=al&65535}else{ao=(e[(c[277220]|0)+(al<<1)>>1]|(s^g)&2081)&65535}g=k+1|0;b[(c[277218]|0)+(g<<1)>>1]=ao;b[(c[277218]|0)+(k<<1)>>1]=ao;s=a[1108909]|0;a[(c[277219]|0)+g|0]=s;a[(c[277219]|0)+k|0]=s}}while(0);if(!S){ap=i;v=1660}break};case 1:{ap=n;v=1660;break};case 2:{aq=n;v=1666;break};case 5:{ar=n;v=1684;break};case 6:{as=n;v=1690;break};case 7:{v=1696;break};default:{}}if((v|0)==1660){v=0;s=k+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+s|0]|0)){g=a[Z+1|0]|0;if(g<<24>>24==0){break}al=e[(c[277225]|0)+((g&255)<<1)>>1]|0;g=c[277228]|0;ae=(((al&63454)+(g&-2082)|0)>>>1)+(g&2081&al)|0;if((a[1108928]|0)==0){at=ae&65535}else{at=(e[(c[277220]|0)+(ae<<1)>>1]|(al^g)&2081)&65535}g=k+3|0;b[(c[277218]|0)+(g<<1)>>1]=at;b[(c[277218]|0)+(s<<1)>>1]=at;al=a[1108909]|0;a[(c[277219]|0)+g|0]=al;a[(c[277219]|0)+s|0]=al}}while(0);s=ap-1&255;if(s<<24>>24!=0){aq=s;v=1666}}if((v|0)==1666){v=0;s=k+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+s|0]|0)){al=a[Z+2|0]|0;if(al<<24>>24==0){break}g=e[(c[277225]|0)+((al&255)<<1)>>1]|0;al=c[277228]|0;ae=(((g&63454)+(al&-2082)|0)>>>1)+(al&2081&g)|0;if((a[1108928]|0)==0){au=ae&65535}else{au=(e[(c[277220]|0)+(ae<<1)>>1]|(g^al)&2081)&65535}al=k+5|0;b[(c[277218]|0)+(al<<1)>>1]=au;b[(c[277218]|0)+(s<<1)>>1]=au;g=a[1108909]|0;a[(c[277219]|0)+al|0]=g;a[(c[277219]|0)+s|0]=g}}while(0);s=aq-1&255;if(s<<24>>24!=0){am=s;v=1672}}if((v|0)==1672){v=0;s=k+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+s|0]|0)){g=a[Z+3|0]|0;if(g<<24>>24==0){break}al=e[(c[277225]|0)+((g&255)<<1)>>1]|0;g=c[277228]|0;ae=(((al&63454)+(g&-2082)|0)>>>1)+(g&2081&al)|0;if((a[1108928]|0)==0){av=ae&65535}else{av=(e[(c[277220]|0)+(ae<<1)>>1]|(al^g)&2081)&65535}g=k+7|0;b[(c[277218]|0)+(g<<1)>>1]=av;b[(c[277218]|0)+(s<<1)>>1]=av;al=a[1108909]|0;a[(c[277219]|0)+g|0]=al;a[(c[277219]|0)+s|0]=al}}while(0);s=am-1&255;if(s<<24>>24!=0){an=s;v=1678}}if((v|0)==1678){v=0;s=k+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+s|0]|0)){al=a[Z+4|0]|0;if(al<<24>>24==0){break}g=e[(c[277225]|0)+((al&255)<<1)>>1]|0;al=c[277228]|0;ae=(((g&63454)+(al&-2082)|0)>>>1)+(al&2081&g)|0;if((a[1108928]|0)==0){aw=ae&65535}else{aw=(e[(c[277220]|0)+(ae<<1)>>1]|(g^al)&2081)&65535}al=k+9|0;b[(c[277218]|0)+(al<<1)>>1]=aw;b[(c[277218]|0)+(s<<1)>>1]=aw;g=a[1108909]|0;a[(c[277219]|0)+al|0]=g;a[(c[277219]|0)+s|0]=g}}while(0);s=an-1&255;if(s<<24>>24!=0){ar=s;v=1684}}if((v|0)==1684){v=0;s=k+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+s|0]|0)){g=a[Z+5|0]|0;if(g<<24>>24==0){break}al=e[(c[277225]|0)+((g&255)<<1)>>1]|0;g=c[277228]|0;ae=(((al&63454)+(g&-2082)|0)>>>1)+(g&2081&al)|0;if((a[1108928]|0)==0){ax=ae&65535}else{ax=(e[(c[277220]|0)+(ae<<1)>>1]|(al^g)&2081)&65535}g=k+11|0;b[(c[277218]|0)+(g<<1)>>1]=ax;b[(c[277218]|0)+(s<<1)>>1]=ax;al=a[1108909]|0;a[(c[277219]|0)+g|0]=al;a[(c[277219]|0)+s|0]=al}}while(0);s=ar-1&255;if(s<<24>>24!=0){as=s;v=1690}}if((v|0)==1690){v=0;s=k+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+s|0]|0)){al=a[Z+6|0]|0;if(al<<24>>24==0){break}g=e[(c[277225]|0)+((al&255)<<1)>>1]|0;al=c[277228]|0;ae=(((g&63454)+(al&-2082)|0)>>>1)+(al&2081&g)|0;if((a[1108928]|0)==0){ay=ae&65535}else{ay=(e[(c[277220]|0)+(ae<<1)>>1]|(g^al)&2081)&65535}al=k+13|0;b[(c[277218]|0)+(al<<1)>>1]=ay;b[(c[277218]|0)+(s<<1)>>1]=ay;g=a[1108909]|0;a[(c[277219]|0)+al|0]=g;a[(c[277219]|0)+s|0]=g}}while(0);if(as<<24>>24!=1){v=1696}}do{if((v|0)==1696){v=0;s=k+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+s|0]|0)){break}g=a[Z+7|0]|0;if(g<<24>>24==0){break}al=e[(c[277225]|0)+((g&255)<<1)>>1]|0;g=c[277228]|0;ae=(((al&63454)+(g&-2082)|0)>>>1)+(g&2081&al)|0;if((a[1108928]|0)==0){az=ae&65535}else{az=(e[(c[277220]|0)+(ae<<1)>>1]|(al^g)&2081)&65535}g=k+15|0;b[(c[277218]|0)+(g<<1)>>1]=az;b[(c[277218]|0)+(s<<1)>>1]=az;al=a[1108909]|0;a[(c[277219]|0)+g|0]=al;a[(c[277219]|0)+s|0]=al}}while(0);al=u-1|0;if((al|0)>0){Z=Z-16|0;u=al;k=(c[277223]|0)+k|0}else{break}}return}}function Vi(f,g,h,i,j,k){f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0;l=f&1023;m=c[348606]|0;n=(l<<m)+(c[348604]|0)|0;if((f&256|0)==0){o=n}else{o=(c[348602]|0)+n|0}n=o&65535;o=n>>>(m>>>0);m=(f&16384|0)!=0;p=o<<6;do{if(m){q=(c[348622]|0)+p|0;if((a[(c[348618]|0)+o|0]|0)!=0){r=q;break}s=fi[c[348636]&63](q,n,l)|0;a[(c[348618]|0)+o|0]=s;r=q}else{q=(c[348624]|0)+p|0;if((a[(c[348620]|0)+o|0]|0)!=0){r=q;break}s=fi[c[348638]&63](q,n,l)|0;a[(c[348620]|0)+o|0]=s;r=q}}while(0);if((a[(c[348620]|0)+o|0]|0)==2){return}if((a[1394464]|0)==0){t=1106168+((f>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){o=d[1044485]|0;c[276541]=7080+(o<<5);l=0;do{n=l<<1&2;p=l&2;q=l&4;s=0;do{b[1125528+(l<<9)+(s<<1)>>1]=d[(s>>>1&28|p)+(7080+(o<<5))|0]<<6|d[(s<<2&28|n)+(7080+(o<<5))|0]<<11|d[(s>>>3&24|q)+(7080+(o<<5))|0];s=s+1|0;}while(s>>>0<256);l=l+1|0;}while(l>>>0<8);a[1106089]=0}t=1125528+((f>>>10&7)<<9)|0}c[277226]=t;c[277225]=(a[1108928]|0)!=0?1393712:t;if((f&49152|0)==0){if((k|0)<=0){return}t=i&255;l=t-1&255;o=l<<24>>24==0;s=r+((d[1394504]|0)+(j<<1))|0;q=k;n=g;while(1){switch(h|0){case 4:{u=t;v=1842;break};case 5:{w=t;v=1857;break};case 1:{x=t;v=1797;break};case 2:{y=t;v=1812;break};case 6:{z=t;v=1872;break};case 7:{v=1887;break};case 3:{A=t;v=1827;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+n|0]|0)){p=a[s]|0;B=p&255;if(p<<24>>24==0){break}do{if((a[1108928]|0)==0){p=b[(c[277225]|0)+(B<<1)>>1]|0;C=p&65535;D=C&63454;if((a[(c[277215]|0)+n|0]&32)==0){E=c[277228]|0;F=(e[(c[277220]|0)+((((E&-2082)+D|0)>>>1)+(C&2081&E)<<1)>>1]|(E^C)&2081)&65535;break}else{C=b[(c[277213]|0)+(n<<1)>>1]|0;F=(((C&63454)+D|0)>>>1)+(C&p&2081)&65535;break}}else{p=e[(c[277225]|0)+(B<<1)>>1]|0;C=(a[(c[277215]|0)+n|0]&32)==0;if(C){D=c[277228]|0;G=D;H=D&-2082}else{D=e[(c[277213]|0)+(n<<1)>>1]|0;G=D;H=D&63454}if(C){I=c[277228]|0}else{I=e[(c[277213]|0)+(n<<1)>>1]|0}F=((I^p)&2081|e[(c[277220]|0)+((p&2081&G)+((H+(p&63454)|0)>>>1)<<1)>>1])&65535}}while(0);B=n+1|0;b[(c[277218]|0)+(B<<1)>>1]=F;b[(c[277218]|0)+(n<<1)>>1]=F;p=a[1108909]|0;a[(c[277219]|0)+B|0]=p;a[(c[277219]|0)+n|0]=p}}while(0);if(!o){x=l;v=1797}break};default:{}}if((v|0)==1797){v=0;p=n+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){B=a[s+1|0]|0;C=B&255;if(B<<24>>24==0){break}do{if((a[1108928]|0)==0){B=b[(c[277225]|0)+(C<<1)>>1]|0;D=B&65535;E=D&63454;if((a[(c[277215]|0)+p|0]&32)==0){J=c[277228]|0;K=(e[(c[277220]|0)+((((J&-2082)+E|0)>>>1)+(D&2081&J)<<1)>>1]|(J^D)&2081)&65535;break}else{D=b[(c[277213]|0)+(p<<1)>>1]|0;K=(((D&63454)+E|0)>>>1)+(D&B&2081)&65535;break}}else{B=e[(c[277225]|0)+(C<<1)>>1]|0;D=(a[(c[277215]|0)+p|0]&32)==0;if(D){E=c[277228]|0;L=E;M=E&-2082}else{E=e[(c[277213]|0)+(p<<1)>>1]|0;L=E;M=E&63454}if(D){N=c[277228]|0}else{N=e[(c[277213]|0)+(p<<1)>>1]|0}K=((N^B)&2081|e[(c[277220]|0)+((B&2081&L)+((M+(B&63454)|0)>>>1)<<1)>>1])&65535}}while(0);C=n+3|0;b[(c[277218]|0)+(C<<1)>>1]=K;b[(c[277218]|0)+(p<<1)>>1]=K;B=a[1108909]|0;a[(c[277219]|0)+C|0]=B;a[(c[277219]|0)+p|0]=B}}while(0);p=x-1&255;if(p<<24>>24!=0){y=p;v=1812}}if((v|0)==1812){v=0;p=n+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){B=a[s+2|0]|0;C=B&255;if(B<<24>>24==0){break}do{if((a[1108928]|0)==0){B=b[(c[277225]|0)+(C<<1)>>1]|0;D=B&65535;E=D&63454;if((a[(c[277215]|0)+p|0]&32)==0){J=c[277228]|0;O=(e[(c[277220]|0)+((((J&-2082)+E|0)>>>1)+(D&2081&J)<<1)>>1]|(J^D)&2081)&65535;break}else{D=b[(c[277213]|0)+(p<<1)>>1]|0;O=(((D&63454)+E|0)>>>1)+(D&B&2081)&65535;break}}else{B=e[(c[277225]|0)+(C<<1)>>1]|0;D=(a[(c[277215]|0)+p|0]&32)==0;if(D){E=c[277228]|0;P=E;Q=E&-2082}else{E=e[(c[277213]|0)+(p<<1)>>1]|0;P=E;Q=E&63454}if(D){R=c[277228]|0}else{R=e[(c[277213]|0)+(p<<1)>>1]|0}O=((R^B)&2081|e[(c[277220]|0)+((B&2081&P)+((Q+(B&63454)|0)>>>1)<<1)>>1])&65535}}while(0);C=n+5|0;b[(c[277218]|0)+(C<<1)>>1]=O;b[(c[277218]|0)+(p<<1)>>1]=O;B=a[1108909]|0;a[(c[277219]|0)+C|0]=B;a[(c[277219]|0)+p|0]=B}}while(0);p=y-1&255;if(p<<24>>24!=0){A=p;v=1827}}if((v|0)==1827){v=0;p=n+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){B=a[s+3|0]|0;C=B&255;if(B<<24>>24==0){break}do{if((a[1108928]|0)==0){B=b[(c[277225]|0)+(C<<1)>>1]|0;D=B&65535;E=D&63454;if((a[(c[277215]|0)+p|0]&32)==0){J=c[277228]|0;S=(e[(c[277220]|0)+((((J&-2082)+E|0)>>>1)+(D&2081&J)<<1)>>1]|(J^D)&2081)&65535;break}else{D=b[(c[277213]|0)+(p<<1)>>1]|0;S=(((D&63454)+E|0)>>>1)+(D&B&2081)&65535;break}}else{B=e[(c[277225]|0)+(C<<1)>>1]|0;D=(a[(c[277215]|0)+p|0]&32)==0;if(D){E=c[277228]|0;T=E;U=E&-2082}else{E=e[(c[277213]|0)+(p<<1)>>1]|0;T=E;U=E&63454}if(D){V=c[277228]|0}else{V=e[(c[277213]|0)+(p<<1)>>1]|0}S=((V^B)&2081|e[(c[277220]|0)+((B&2081&T)+((U+(B&63454)|0)>>>1)<<1)>>1])&65535}}while(0);C=n+7|0;b[(c[277218]|0)+(C<<1)>>1]=S;b[(c[277218]|0)+(p<<1)>>1]=S;B=a[1108909]|0;a[(c[277219]|0)+C|0]=B;a[(c[277219]|0)+p|0]=B}}while(0);p=A-1&255;if(p<<24>>24!=0){u=p;v=1842}}if((v|0)==1842){v=0;p=n+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){B=a[s+4|0]|0;C=B&255;if(B<<24>>24==0){break}do{if((a[1108928]|0)==0){B=b[(c[277225]|0)+(C<<1)>>1]|0;D=B&65535;E=D&63454;if((a[(c[277215]|0)+p|0]&32)==0){J=c[277228]|0;W=(e[(c[277220]|0)+((((J&-2082)+E|0)>>>1)+(D&2081&J)<<1)>>1]|(J^D)&2081)&65535;break}else{D=b[(c[277213]|0)+(p<<1)>>1]|0;W=(((D&63454)+E|0)>>>1)+(D&B&2081)&65535;break}}else{B=e[(c[277225]|0)+(C<<1)>>1]|0;D=(a[(c[277215]|0)+p|0]&32)==0;if(D){E=c[277228]|0;X=E;Y=E&-2082}else{E=e[(c[277213]|0)+(p<<1)>>1]|0;X=E;Y=E&63454}if(D){Z=c[277228]|0}else{Z=e[(c[277213]|0)+(p<<1)>>1]|0}W=((Z^B)&2081|e[(c[277220]|0)+((B&2081&X)+((Y+(B&63454)|0)>>>1)<<1)>>1])&65535}}while(0);C=n+9|0;b[(c[277218]|0)+(C<<1)>>1]=W;b[(c[277218]|0)+(p<<1)>>1]=W;B=a[1108909]|0;a[(c[277219]|0)+C|0]=B;a[(c[277219]|0)+p|0]=B}}while(0);p=u-1&255;if(p<<24>>24!=0){w=p;v=1857}}if((v|0)==1857){v=0;p=n+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){B=a[s+5|0]|0;C=B&255;if(B<<24>>24==0){break}do{if((a[1108928]|0)==0){B=b[(c[277225]|0)+(C<<1)>>1]|0;D=B&65535;E=D&63454;if((a[(c[277215]|0)+p|0]&32)==0){J=c[277228]|0;_=(e[(c[277220]|0)+((((J&-2082)+E|0)>>>1)+(D&2081&J)<<1)>>1]|(J^D)&2081)&65535;break}else{D=b[(c[277213]|0)+(p<<1)>>1]|0;_=(((D&63454)+E|0)>>>1)+(D&B&2081)&65535;break}}else{B=e[(c[277225]|0)+(C<<1)>>1]|0;D=(a[(c[277215]|0)+p|0]&32)==0;if(D){E=c[277228]|0;$=E;aa=E&-2082}else{E=e[(c[277213]|0)+(p<<1)>>1]|0;$=E;aa=E&63454}if(D){ab=c[277228]|0}else{ab=e[(c[277213]|0)+(p<<1)>>1]|0}_=((ab^B)&2081|e[(c[277220]|0)+((B&2081&$)+((aa+(B&63454)|0)>>>1)<<1)>>1])&65535}}while(0);C=n+11|0;b[(c[277218]|0)+(C<<1)>>1]=_;b[(c[277218]|0)+(p<<1)>>1]=_;B=a[1108909]|0;a[(c[277219]|0)+C|0]=B;a[(c[277219]|0)+p|0]=B}}while(0);p=w-1&255;if(p<<24>>24!=0){z=p;v=1872}}if((v|0)==1872){v=0;p=n+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){B=a[s+6|0]|0;C=B&255;if(B<<24>>24==0){break}do{if((a[1108928]|0)==0){B=b[(c[277225]|0)+(C<<1)>>1]|0;D=B&65535;E=D&63454;if((a[(c[277215]|0)+p|0]&32)==0){J=c[277228]|0;ac=(e[(c[277220]|0)+((((J&-2082)+E|0)>>>1)+(D&2081&J)<<1)>>1]|(J^D)&2081)&65535;break}else{D=b[(c[277213]|0)+(p<<1)>>1]|0;ac=(((D&63454)+E|0)>>>1)+(D&B&2081)&65535;break}}else{B=e[(c[277225]|0)+(C<<1)>>1]|0;D=(a[(c[277215]|0)+p|0]&32)==0;if(D){E=c[277228]|0;ad=E;ae=E&-2082}else{E=e[(c[277213]|0)+(p<<1)>>1]|0;ad=E;ae=E&63454}if(D){af=c[277228]|0}else{af=e[(c[277213]|0)+(p<<1)>>1]|0}ac=((af^B)&2081|e[(c[277220]|0)+((B&2081&ad)+((ae+(B&63454)|0)>>>1)<<1)>>1])&65535}}while(0);C=n+13|0;b[(c[277218]|0)+(C<<1)>>1]=ac;b[(c[277218]|0)+(p<<1)>>1]=ac;B=a[1108909]|0;a[(c[277219]|0)+C|0]=B;a[(c[277219]|0)+p|0]=B}}while(0);if(z<<24>>24!=1){v=1887}}do{if((v|0)==1887){v=0;p=n+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+p|0]|0)){break}B=a[s+7|0]|0;C=B&255;if(B<<24>>24==0){break}do{if((a[1108928]|0)==0){B=b[(c[277225]|0)+(C<<1)>>1]|0;D=B&65535;E=D&63454;if((a[(c[277215]|0)+p|0]&32)==0){J=c[277228]|0;ag=(e[(c[277220]|0)+((((J&-2082)+E|0)>>>1)+(D&2081&J)<<1)>>1]|(J^D)&2081)&65535;break}else{D=b[(c[277213]|0)+(p<<1)>>1]|0;ag=(((D&63454)+E|0)>>>1)+(D&B&2081)&65535;break}}else{B=e[(c[277225]|0)+(C<<1)>>1]|0;D=(a[(c[277215]|0)+p|0]&32)==0;if(D){E=c[277228]|0;ah=E;ai=E&-2082}else{E=e[(c[277213]|0)+(p<<1)>>1]|0;ah=E;ai=E&63454}if(D){aj=c[277228]|0}else{aj=e[(c[277213]|0)+(p<<1)>>1]|0}ag=((aj^B)&2081|e[(c[277220]|0)+((B&2081&ah)+((ai+(B&63454)|0)>>>1)<<1)>>1])&65535}}while(0);C=n+15|0;b[(c[277218]|0)+(C<<1)>>1]=ag;b[(c[277218]|0)+(p<<1)>>1]=ag;B=a[1108909]|0;a[(c[277219]|0)+C|0]=B;a[(c[277219]|0)+p|0]=B}}while(0);B=q-1|0;if((B|0)>0){s=s+16|0;q=B;n=(c[277223]|0)+n|0}else{break}}return}n=(d[1394504]|0)+(j<<1)|0;if((f&32768|0)==0){if((k|0)<=0){return}f=i&255;j=f-1&255;q=j<<24>>24==0;s=r+n|0;ag=k;ai=g;while(1){switch(h|0){case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+ai|0]|0)){ah=a[s+7|0]|0;aj=ah&255;if(ah<<24>>24==0){break}do{if((a[1108928]|0)==0){ah=b[(c[277225]|0)+(aj<<1)>>1]|0;z=ah&65535;ac=z&63454;if((a[(c[277215]|0)+ai|0]&32)==0){ae=c[277228]|0;ak=(e[(c[277220]|0)+((((ae&-2082)+ac|0)>>>1)+(z&2081&ae)<<1)>>1]|(ae^z)&2081)&65535;break}else{z=b[(c[277213]|0)+(ai<<1)>>1]|0;ak=(((z&63454)+ac|0)>>>1)+(z&ah&2081)&65535;break}}else{ah=e[(c[277225]|0)+(aj<<1)>>1]|0;z=(a[(c[277215]|0)+ai|0]&32)==0;if(z){ac=c[277228]|0;al=ac;am=ac&-2082}else{ac=e[(c[277213]|0)+(ai<<1)>>1]|0;al=ac;am=ac&63454}if(z){an=c[277228]|0}else{an=e[(c[277213]|0)+(ai<<1)>>1]|0}ak=((an^ah)&2081|e[(c[277220]|0)+((ah&2081&al)+((am+(ah&63454)|0)>>>1)<<1)>>1])&65535}}while(0);aj=ai+1|0;b[(c[277218]|0)+(aj<<1)>>1]=ak;b[(c[277218]|0)+(ai<<1)>>1]=ak;p=a[1108909]|0;a[(c[277219]|0)+aj|0]=p;a[(c[277219]|0)+ai|0]=p}}while(0);if(!q){ao=j;v=1921}break};case 7:{v=2011;break};case 3:{ap=f;v=1951;break};case 4:{aq=f;v=1966;break};case 5:{ar=f;v=1981;break};case 1:{ao=f;v=1921;break};case 2:{as=f;v=1936;break};case 6:{at=f;v=1996;break};default:{}}if((v|0)==1921){v=0;p=ai+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){aj=a[s+6|0]|0;ah=aj&255;if(aj<<24>>24==0){break}do{if((a[1108928]|0)==0){aj=b[(c[277225]|0)+(ah<<1)>>1]|0;z=aj&65535;ac=z&63454;if((a[(c[277215]|0)+p|0]&32)==0){ae=c[277228]|0;au=(e[(c[277220]|0)+((((ae&-2082)+ac|0)>>>1)+(z&2081&ae)<<1)>>1]|(ae^z)&2081)&65535;break}else{z=b[(c[277213]|0)+(p<<1)>>1]|0;au=(((z&63454)+ac|0)>>>1)+(z&aj&2081)&65535;break}}else{aj=e[(c[277225]|0)+(ah<<1)>>1]|0;z=(a[(c[277215]|0)+p|0]&32)==0;if(z){ac=c[277228]|0;av=ac;aw=ac&-2082}else{ac=e[(c[277213]|0)+(p<<1)>>1]|0;av=ac;aw=ac&63454}if(z){ax=c[277228]|0}else{ax=e[(c[277213]|0)+(p<<1)>>1]|0}au=((ax^aj)&2081|e[(c[277220]|0)+((aj&2081&av)+((aw+(aj&63454)|0)>>>1)<<1)>>1])&65535}}while(0);ah=ai+3|0;b[(c[277218]|0)+(ah<<1)>>1]=au;b[(c[277218]|0)+(p<<1)>>1]=au;aj=a[1108909]|0;a[(c[277219]|0)+ah|0]=aj;a[(c[277219]|0)+p|0]=aj}}while(0);p=ao-1&255;if(p<<24>>24!=0){as=p;v=1936}}if((v|0)==1936){v=0;p=ai+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){aj=a[s+5|0]|0;ah=aj&255;if(aj<<24>>24==0){break}do{if((a[1108928]|0)==0){aj=b[(c[277225]|0)+(ah<<1)>>1]|0;z=aj&65535;ac=z&63454;if((a[(c[277215]|0)+p|0]&32)==0){ae=c[277228]|0;ay=(e[(c[277220]|0)+((((ae&-2082)+ac|0)>>>1)+(z&2081&ae)<<1)>>1]|(ae^z)&2081)&65535;break}else{z=b[(c[277213]|0)+(p<<1)>>1]|0;ay=(((z&63454)+ac|0)>>>1)+(z&aj&2081)&65535;break}}else{aj=e[(c[277225]|0)+(ah<<1)>>1]|0;z=(a[(c[277215]|0)+p|0]&32)==0;if(z){ac=c[277228]|0;az=ac;aA=ac&-2082}else{ac=e[(c[277213]|0)+(p<<1)>>1]|0;az=ac;aA=ac&63454}if(z){aB=c[277228]|0}else{aB=e[(c[277213]|0)+(p<<1)>>1]|0}ay=((aB^aj)&2081|e[(c[277220]|0)+((aj&2081&az)+((aA+(aj&63454)|0)>>>1)<<1)>>1])&65535}}while(0);ah=ai+5|0;b[(c[277218]|0)+(ah<<1)>>1]=ay;b[(c[277218]|0)+(p<<1)>>1]=ay;aj=a[1108909]|0;a[(c[277219]|0)+ah|0]=aj;a[(c[277219]|0)+p|0]=aj}}while(0);p=as-1&255;if(p<<24>>24!=0){ap=p;v=1951}}if((v|0)==1951){v=0;p=ai+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){aj=a[s+4|0]|0;ah=aj&255;if(aj<<24>>24==0){break}do{if((a[1108928]|0)==0){aj=b[(c[277225]|0)+(ah<<1)>>1]|0;z=aj&65535;ac=z&63454;if((a[(c[277215]|0)+p|0]&32)==0){ae=c[277228]|0;aC=(e[(c[277220]|0)+((((ae&-2082)+ac|0)>>>1)+(z&2081&ae)<<1)>>1]|(ae^z)&2081)&65535;break}else{z=b[(c[277213]|0)+(p<<1)>>1]|0;aC=(((z&63454)+ac|0)>>>1)+(z&aj&2081)&65535;break}}else{aj=e[(c[277225]|0)+(ah<<1)>>1]|0;z=(a[(c[277215]|0)+p|0]&32)==0;if(z){ac=c[277228]|0;aD=ac;aE=ac&-2082}else{ac=e[(c[277213]|0)+(p<<1)>>1]|0;aD=ac;aE=ac&63454}if(z){aF=c[277228]|0}else{aF=e[(c[277213]|0)+(p<<1)>>1]|0}aC=((aF^aj)&2081|e[(c[277220]|0)+((aj&2081&aD)+((aE+(aj&63454)|0)>>>1)<<1)>>1])&65535}}while(0);ah=ai+7|0;b[(c[277218]|0)+(ah<<1)>>1]=aC;b[(c[277218]|0)+(p<<1)>>1]=aC;aj=a[1108909]|0;a[(c[277219]|0)+ah|0]=aj;a[(c[277219]|0)+p|0]=aj}}while(0);p=ap-1&255;if(p<<24>>24!=0){aq=p;v=1966}}if((v|0)==1966){v=0;p=ai+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){aj=a[s+3|0]|0;ah=aj&255;if(aj<<24>>24==0){break}do{if((a[1108928]|0)==0){aj=b[(c[277225]|0)+(ah<<1)>>1]|0;z=aj&65535;ac=z&63454;if((a[(c[277215]|0)+p|0]&32)==0){ae=c[277228]|0;aG=(e[(c[277220]|0)+((((ae&-2082)+ac|0)>>>1)+(z&2081&ae)<<1)>>1]|(ae^z)&2081)&65535;break}else{z=b[(c[277213]|0)+(p<<1)>>1]|0;aG=(((z&63454)+ac|0)>>>1)+(z&aj&2081)&65535;break}}else{aj=e[(c[277225]|0)+(ah<<1)>>1]|0;z=(a[(c[277215]|0)+p|0]&32)==0;if(z){ac=c[277228]|0;aH=ac;aI=ac&-2082}else{ac=e[(c[277213]|0)+(p<<1)>>1]|0;aH=ac;aI=ac&63454}if(z){aJ=c[277228]|0}else{aJ=e[(c[277213]|0)+(p<<1)>>1]|0}aG=((aJ^aj)&2081|e[(c[277220]|0)+((aj&2081&aH)+((aI+(aj&63454)|0)>>>1)<<1)>>1])&65535}}while(0);ah=ai+9|0;b[(c[277218]|0)+(ah<<1)>>1]=aG;b[(c[277218]|0)+(p<<1)>>1]=aG;aj=a[1108909]|0;a[(c[277219]|0)+ah|0]=aj;a[(c[277219]|0)+p|0]=aj}}while(0);p=aq-1&255;if(p<<24>>24!=0){ar=p;v=1981}}if((v|0)==1981){v=0;p=ai+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){aj=a[s+2|0]|0;ah=aj&255;if(aj<<24>>24==0){break}do{if((a[1108928]|0)==0){aj=b[(c[277225]|0)+(ah<<1)>>1]|0;z=aj&65535;ac=z&63454;if((a[(c[277215]|0)+p|0]&32)==0){ae=c[277228]|0;aK=(e[(c[277220]|0)+((((ae&-2082)+ac|0)>>>1)+(z&2081&ae)<<1)>>1]|(ae^z)&2081)&65535;break}else{z=b[(c[277213]|0)+(p<<1)>>1]|0;aK=(((z&63454)+ac|0)>>>1)+(z&aj&2081)&65535;break}}else{aj=e[(c[277225]|0)+(ah<<1)>>1]|0;z=(a[(c[277215]|0)+p|0]&32)==0;if(z){ac=c[277228]|0;aL=ac;aM=ac&-2082}else{ac=e[(c[277213]|0)+(p<<1)>>1]|0;aL=ac;aM=ac&63454}if(z){aN=c[277228]|0}else{aN=e[(c[277213]|0)+(p<<1)>>1]|0}aK=((aN^aj)&2081|e[(c[277220]|0)+((aj&2081&aL)+((aM+(aj&63454)|0)>>>1)<<1)>>1])&65535}}while(0);ah=ai+11|0;b[(c[277218]|0)+(ah<<1)>>1]=aK;b[(c[277218]|0)+(p<<1)>>1]=aK;aj=a[1108909]|0;a[(c[277219]|0)+ah|0]=aj;a[(c[277219]|0)+p|0]=aj}}while(0);p=ar-1&255;if(p<<24>>24!=0){at=p;v=1996}}if((v|0)==1996){v=0;p=ai+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){aj=a[s+1|0]|0;ah=aj&255;if(aj<<24>>24==0){break}do{if((a[1108928]|0)==0){aj=b[(c[277225]|0)+(ah<<1)>>1]|0;z=aj&65535;ac=z&63454;if((a[(c[277215]|0)+p|0]&32)==0){ae=c[277228]|0;aO=(e[(c[277220]|0)+((((ae&-2082)+ac|0)>>>1)+(z&2081&ae)<<1)>>1]|(ae^z)&2081)&65535;break}else{z=b[(c[277213]|0)+(p<<1)>>1]|0;aO=(((z&63454)+ac|0)>>>1)+(z&aj&2081)&65535;break}}else{aj=e[(c[277225]|0)+(ah<<1)>>1]|0;z=(a[(c[277215]|0)+p|0]&32)==0;if(z){ac=c[277228]|0;aP=ac;aQ=ac&-2082}else{ac=e[(c[277213]|0)+(p<<1)>>1]|0;aP=ac;aQ=ac&63454}if(z){aR=c[277228]|0}else{aR=e[(c[277213]|0)+(p<<1)>>1]|0}aO=((aR^aj)&2081|e[(c[277220]|0)+((aj&2081&aP)+((aQ+(aj&63454)|0)>>>1)<<1)>>1])&65535}}while(0);ah=ai+13|0;b[(c[277218]|0)+(ah<<1)>>1]=aO;b[(c[277218]|0)+(p<<1)>>1]=aO;aj=a[1108909]|0;a[(c[277219]|0)+ah|0]=aj;a[(c[277219]|0)+p|0]=aj}}while(0);if(at<<24>>24!=1){v=2011}}do{if((v|0)==2011){v=0;p=ai+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+p|0]|0)){break}aj=a[s]|0;ah=aj&255;if(aj<<24>>24==0){break}do{if((a[1108928]|0)==0){aj=b[(c[277225]|0)+(ah<<1)>>1]|0;z=aj&65535;ac=z&63454;if((a[(c[277215]|0)+p|0]&32)==0){ae=c[277228]|0;aS=(e[(c[277220]|0)+((((ae&-2082)+ac|0)>>>1)+(z&2081&ae)<<1)>>1]|(ae^z)&2081)&65535;break}else{z=b[(c[277213]|0)+(p<<1)>>1]|0;aS=(((z&63454)+ac|0)>>>1)+(z&aj&2081)&65535;break}}else{aj=e[(c[277225]|0)+(ah<<1)>>1]|0;z=(a[(c[277215]|0)+p|0]&32)==0;if(z){ac=c[277228]|0;aT=ac;aU=ac&-2082}else{ac=e[(c[277213]|0)+(p<<1)>>1]|0;aT=ac;aU=ac&63454}if(z){aV=c[277228]|0}else{aV=e[(c[277213]|0)+(p<<1)>>1]|0}aS=((aV^aj)&2081|e[(c[277220]|0)+((aj&2081&aT)+((aU+(aj&63454)|0)>>>1)<<1)>>1])&65535}}while(0);ah=ai+15|0;b[(c[277218]|0)+(ah<<1)>>1]=aS;b[(c[277218]|0)+(p<<1)>>1]=aS;aj=a[1108909]|0;a[(c[277219]|0)+ah|0]=aj;a[(c[277219]|0)+p|0]=aj}}while(0);aj=ag-1|0;if((aj|0)>0){s=s+16|0;ag=aj;ai=(c[277223]|0)+ai|0}else{break}}return}ai=r+(56-n)|0;n=(k|0)>0;if(m){if(!n){return}m=i&255;r=m-1&255;ag=r<<24>>24==0;s=ai;aS=k;aU=g;while(1){switch(h|0){case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+aU|0]|0)){aT=a[s+7|0]|0;aV=aT&255;if(aT<<24>>24==0){break}do{if((a[1108928]|0)==0){aT=b[(c[277225]|0)+(aV<<1)>>1]|0;at=aT&65535;aO=at&63454;if((a[(c[277215]|0)+aU|0]&32)==0){aQ=c[277228]|0;aW=(e[(c[277220]|0)+((((aQ&-2082)+aO|0)>>>1)+(at&2081&aQ)<<1)>>1]|(aQ^at)&2081)&65535;break}else{at=b[(c[277213]|0)+(aU<<1)>>1]|0;aW=(((at&63454)+aO|0)>>>1)+(at&aT&2081)&65535;break}}else{aT=e[(c[277225]|0)+(aV<<1)>>1]|0;at=(a[(c[277215]|0)+aU|0]&32)==0;if(at){aO=c[277228]|0;aX=aO;aY=aO&-2082}else{aO=e[(c[277213]|0)+(aU<<1)>>1]|0;aX=aO;aY=aO&63454}if(at){aZ=c[277228]|0}else{aZ=e[(c[277213]|0)+(aU<<1)>>1]|0}aW=((aZ^aT)&2081|e[(c[277220]|0)+((aT&2081&aX)+((aY+(aT&63454)|0)>>>1)<<1)>>1])&65535}}while(0);aV=aU+1|0;b[(c[277218]|0)+(aV<<1)>>1]=aW;b[(c[277218]|0)+(aU<<1)>>1]=aW;p=a[1108909]|0;a[(c[277219]|0)+aV|0]=p;a[(c[277219]|0)+aU|0]=p}}while(0);if(!ag){a_=r;v=2168}break};case 1:{a_=m;v=2168;break};case 2:{a$=m;v=2183;break};case 3:{a0=m;v=2198;break};case 4:{a1=m;v=2213;break};case 5:{a2=m;v=2228;break};case 6:{a3=m;v=2243;break};case 7:{v=2258;break};default:{}}if((v|0)==2168){v=0;p=aU+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){aV=a[s+6|0]|0;aT=aV&255;if(aV<<24>>24==0){break}do{if((a[1108928]|0)==0){aV=b[(c[277225]|0)+(aT<<1)>>1]|0;at=aV&65535;aO=at&63454;if((a[(c[277215]|0)+p|0]&32)==0){aQ=c[277228]|0;a4=(e[(c[277220]|0)+((((aQ&-2082)+aO|0)>>>1)+(at&2081&aQ)<<1)>>1]|(aQ^at)&2081)&65535;break}else{at=b[(c[277213]|0)+(p<<1)>>1]|0;a4=(((at&63454)+aO|0)>>>1)+(at&aV&2081)&65535;break}}else{aV=e[(c[277225]|0)+(aT<<1)>>1]|0;at=(a[(c[277215]|0)+p|0]&32)==0;if(at){aO=c[277228]|0;a5=aO;a6=aO&-2082}else{aO=e[(c[277213]|0)+(p<<1)>>1]|0;a5=aO;a6=aO&63454}if(at){a7=c[277228]|0}else{a7=e[(c[277213]|0)+(p<<1)>>1]|0}a4=((a7^aV)&2081|e[(c[277220]|0)+((aV&2081&a5)+((a6+(aV&63454)|0)>>>1)<<1)>>1])&65535}}while(0);aT=aU+3|0;b[(c[277218]|0)+(aT<<1)>>1]=a4;b[(c[277218]|0)+(p<<1)>>1]=a4;aV=a[1108909]|0;a[(c[277219]|0)+aT|0]=aV;a[(c[277219]|0)+p|0]=aV}}while(0);p=a_-1&255;if(p<<24>>24!=0){a$=p;v=2183}}if((v|0)==2183){v=0;p=aU+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){aV=a[s+5|0]|0;aT=aV&255;if(aV<<24>>24==0){break}do{if((a[1108928]|0)==0){aV=b[(c[277225]|0)+(aT<<1)>>1]|0;at=aV&65535;aO=at&63454;if((a[(c[277215]|0)+p|0]&32)==0){aQ=c[277228]|0;a8=(e[(c[277220]|0)+((((aQ&-2082)+aO|0)>>>1)+(at&2081&aQ)<<1)>>1]|(aQ^at)&2081)&65535;break}else{at=b[(c[277213]|0)+(p<<1)>>1]|0;a8=(((at&63454)+aO|0)>>>1)+(at&aV&2081)&65535;break}}else{aV=e[(c[277225]|0)+(aT<<1)>>1]|0;at=(a[(c[277215]|0)+p|0]&32)==0;if(at){aO=c[277228]|0;a9=aO;ba=aO&-2082}else{aO=e[(c[277213]|0)+(p<<1)>>1]|0;a9=aO;ba=aO&63454}if(at){bb=c[277228]|0}else{bb=e[(c[277213]|0)+(p<<1)>>1]|0}a8=((bb^aV)&2081|e[(c[277220]|0)+((aV&2081&a9)+((ba+(aV&63454)|0)>>>1)<<1)>>1])&65535}}while(0);aT=aU+5|0;b[(c[277218]|0)+(aT<<1)>>1]=a8;b[(c[277218]|0)+(p<<1)>>1]=a8;aV=a[1108909]|0;a[(c[277219]|0)+aT|0]=aV;a[(c[277219]|0)+p|0]=aV}}while(0);p=a$-1&255;if(p<<24>>24!=0){a0=p;v=2198}}if((v|0)==2198){v=0;p=aU+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){aV=a[s+4|0]|0;aT=aV&255;if(aV<<24>>24==0){break}do{if((a[1108928]|0)==0){aV=b[(c[277225]|0)+(aT<<1)>>1]|0;at=aV&65535;aO=at&63454;if((a[(c[277215]|0)+p|0]&32)==0){aQ=c[277228]|0;bc=(e[(c[277220]|0)+((((aQ&-2082)+aO|0)>>>1)+(at&2081&aQ)<<1)>>1]|(aQ^at)&2081)&65535;break}else{at=b[(c[277213]|0)+(p<<1)>>1]|0;bc=(((at&63454)+aO|0)>>>1)+(at&aV&2081)&65535;break}}else{aV=e[(c[277225]|0)+(aT<<1)>>1]|0;at=(a[(c[277215]|0)+p|0]&32)==0;if(at){aO=c[277228]|0;bd=aO;be=aO&-2082}else{aO=e[(c[277213]|0)+(p<<1)>>1]|0;bd=aO;be=aO&63454}if(at){bf=c[277228]|0}else{bf=e[(c[277213]|0)+(p<<1)>>1]|0}bc=((bf^aV)&2081|e[(c[277220]|0)+((aV&2081&bd)+((be+(aV&63454)|0)>>>1)<<1)>>1])&65535}}while(0);aT=aU+7|0;b[(c[277218]|0)+(aT<<1)>>1]=bc;b[(c[277218]|0)+(p<<1)>>1]=bc;aV=a[1108909]|0;a[(c[277219]|0)+aT|0]=aV;a[(c[277219]|0)+p|0]=aV}}while(0);p=a0-1&255;if(p<<24>>24!=0){a1=p;v=2213}}if((v|0)==2213){v=0;p=aU+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){aV=a[s+3|0]|0;aT=aV&255;if(aV<<24>>24==0){break}do{if((a[1108928]|0)==0){aV=b[(c[277225]|0)+(aT<<1)>>1]|0;at=aV&65535;aO=at&63454;if((a[(c[277215]|0)+p|0]&32)==0){aQ=c[277228]|0;bg=(e[(c[277220]|0)+((((aQ&-2082)+aO|0)>>>1)+(at&2081&aQ)<<1)>>1]|(aQ^at)&2081)&65535;break}else{at=b[(c[277213]|0)+(p<<1)>>1]|0;bg=(((at&63454)+aO|0)>>>1)+(at&aV&2081)&65535;break}}else{aV=e[(c[277225]|0)+(aT<<1)>>1]|0;at=(a[(c[277215]|0)+p|0]&32)==0;if(at){aO=c[277228]|0;bh=aO;bi=aO&-2082}else{aO=e[(c[277213]|0)+(p<<1)>>1]|0;bh=aO;bi=aO&63454}if(at){bj=c[277228]|0}else{bj=e[(c[277213]|0)+(p<<1)>>1]|0}bg=((bj^aV)&2081|e[(c[277220]|0)+((aV&2081&bh)+((bi+(aV&63454)|0)>>>1)<<1)>>1])&65535}}while(0);aT=aU+9|0;b[(c[277218]|0)+(aT<<1)>>1]=bg;b[(c[277218]|0)+(p<<1)>>1]=bg;aV=a[1108909]|0;a[(c[277219]|0)+aT|0]=aV;a[(c[277219]|0)+p|0]=aV}}while(0);p=a1-1&255;if(p<<24>>24!=0){a2=p;v=2228}}if((v|0)==2228){v=0;p=aU+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){aV=a[s+2|0]|0;aT=aV&255;if(aV<<24>>24==0){break}do{if((a[1108928]|0)==0){aV=b[(c[277225]|0)+(aT<<1)>>1]|0;at=aV&65535;aO=at&63454;if((a[(c[277215]|0)+p|0]&32)==0){aQ=c[277228]|0;bk=(e[(c[277220]|0)+((((aQ&-2082)+aO|0)>>>1)+(at&2081&aQ)<<1)>>1]|(aQ^at)&2081)&65535;break}else{at=b[(c[277213]|0)+(p<<1)>>1]|0;bk=(((at&63454)+aO|0)>>>1)+(at&aV&2081)&65535;break}}else{aV=e[(c[277225]|0)+(aT<<1)>>1]|0;at=(a[(c[277215]|0)+p|0]&32)==0;if(at){aO=c[277228]|0;bl=aO;bm=aO&-2082}else{aO=e[(c[277213]|0)+(p<<1)>>1]|0;bl=aO;bm=aO&63454}if(at){bn=c[277228]|0}else{bn=e[(c[277213]|0)+(p<<1)>>1]|0}bk=((bn^aV)&2081|e[(c[277220]|0)+((aV&2081&bl)+((bm+(aV&63454)|0)>>>1)<<1)>>1])&65535}}while(0);aT=aU+11|0;b[(c[277218]|0)+(aT<<1)>>1]=bk;b[(c[277218]|0)+(p<<1)>>1]=bk;aV=a[1108909]|0;a[(c[277219]|0)+aT|0]=aV;a[(c[277219]|0)+p|0]=aV}}while(0);p=a2-1&255;if(p<<24>>24!=0){a3=p;v=2243}}if((v|0)==2243){v=0;p=aU+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){aV=a[s+1|0]|0;aT=aV&255;if(aV<<24>>24==0){break}do{if((a[1108928]|0)==0){aV=b[(c[277225]|0)+(aT<<1)>>1]|0;at=aV&65535;aO=at&63454;if((a[(c[277215]|0)+p|0]&32)==0){aQ=c[277228]|0;bo=(e[(c[277220]|0)+((((aQ&-2082)+aO|0)>>>1)+(at&2081&aQ)<<1)>>1]|(aQ^at)&2081)&65535;break}else{at=b[(c[277213]|0)+(p<<1)>>1]|0;bo=(((at&63454)+aO|0)>>>1)+(at&aV&2081)&65535;break}}else{aV=e[(c[277225]|0)+(aT<<1)>>1]|0;at=(a[(c[277215]|0)+p|0]&32)==0;if(at){aO=c[277228]|0;bp=aO;bq=aO&-2082}else{aO=e[(c[277213]|0)+(p<<1)>>1]|0;bp=aO;bq=aO&63454}if(at){br=c[277228]|0}else{br=e[(c[277213]|0)+(p<<1)>>1]|0}bo=((br^aV)&2081|e[(c[277220]|0)+((aV&2081&bp)+((bq+(aV&63454)|0)>>>1)<<1)>>1])&65535}}while(0);aT=aU+13|0;b[(c[277218]|0)+(aT<<1)>>1]=bo;b[(c[277218]|0)+(p<<1)>>1]=bo;aV=a[1108909]|0;a[(c[277219]|0)+aT|0]=aV;a[(c[277219]|0)+p|0]=aV}}while(0);if(a3<<24>>24!=1){v=2258}}do{if((v|0)==2258){v=0;p=aU+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+p|0]|0)){break}aV=a[s]|0;aT=aV&255;if(aV<<24>>24==0){break}do{if((a[1108928]|0)==0){aV=b[(c[277225]|0)+(aT<<1)>>1]|0;at=aV&65535;aO=at&63454;if((a[(c[277215]|0)+p|0]&32)==0){aQ=c[277228]|0;bs=(e[(c[277220]|0)+((((aQ&-2082)+aO|0)>>>1)+(at&2081&aQ)<<1)>>1]|(aQ^at)&2081)&65535;break}else{at=b[(c[277213]|0)+(p<<1)>>1]|0;bs=(((at&63454)+aO|0)>>>1)+(at&aV&2081)&65535;break}}else{aV=e[(c[277225]|0)+(aT<<1)>>1]|0;at=(a[(c[277215]|0)+p|0]&32)==0;if(at){aO=c[277228]|0;bt=aO;bu=aO&-2082}else{aO=e[(c[277213]|0)+(p<<1)>>1]|0;bt=aO;bu=aO&63454}if(at){bv=c[277228]|0}else{bv=e[(c[277213]|0)+(p<<1)>>1]|0}bs=((bv^aV)&2081|e[(c[277220]|0)+((aV&2081&bt)+((bu+(aV&63454)|0)>>>1)<<1)>>1])&65535}}while(0);aT=aU+15|0;b[(c[277218]|0)+(aT<<1)>>1]=bs;b[(c[277218]|0)+(p<<1)>>1]=bs;aV=a[1108909]|0;a[(c[277219]|0)+aT|0]=aV;a[(c[277219]|0)+p|0]=aV}}while(0);aV=aS-1|0;if((aV|0)>0){s=s-16|0;aS=aV;aU=(c[277223]|0)+aU|0}else{break}}return}else{if(!n){return}n=i&255;i=n-1&255;aU=i<<24>>24==0;aS=ai;ai=k;k=g;while(1){switch(h|0){case 2:{bw=n;v=2062;break};case 3:{bx=n;v=2077;break};case 4:{by=n;v=2092;break};case 5:{bz=n;v=2107;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+k|0]|0)){g=a[aS]|0;s=g&255;if(g<<24>>24==0){break}do{if((a[1108928]|0)==0){g=b[(c[277225]|0)+(s<<1)>>1]|0;bs=g&65535;bu=bs&63454;if((a[(c[277215]|0)+k|0]&32)==0){bt=c[277228]|0;bA=(e[(c[277220]|0)+((((bt&-2082)+bu|0)>>>1)+(bs&2081&bt)<<1)>>1]|(bt^bs)&2081)&65535;break}else{bs=b[(c[277213]|0)+(k<<1)>>1]|0;bA=(((bs&63454)+bu|0)>>>1)+(bs&g&2081)&65535;break}}else{g=e[(c[277225]|0)+(s<<1)>>1]|0;bs=(a[(c[277215]|0)+k|0]&32)==0;if(bs){bu=c[277228]|0;bB=bu;bC=bu&-2082}else{bu=e[(c[277213]|0)+(k<<1)>>1]|0;bB=bu;bC=bu&63454}if(bs){bD=c[277228]|0}else{bD=e[(c[277213]|0)+(k<<1)>>1]|0}bA=((bD^g)&2081|e[(c[277220]|0)+((g&2081&bB)+((bC+(g&63454)|0)>>>1)<<1)>>1])&65535}}while(0);s=k+1|0;b[(c[277218]|0)+(s<<1)>>1]=bA;b[(c[277218]|0)+(k<<1)>>1]=bA;p=a[1108909]|0;a[(c[277219]|0)+s|0]=p;a[(c[277219]|0)+k|0]=p}}while(0);if(!aU){bE=i;v=2047}break};case 1:{bE=n;v=2047;break};case 6:{bF=n;v=2122;break};case 7:{v=2137;break};default:{}}if((v|0)==2047){v=0;p=k+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){s=a[aS+1|0]|0;g=s&255;if(s<<24>>24==0){break}do{if((a[1108928]|0)==0){s=b[(c[277225]|0)+(g<<1)>>1]|0;bs=s&65535;bu=bs&63454;if((a[(c[277215]|0)+p|0]&32)==0){bt=c[277228]|0;bG=(e[(c[277220]|0)+((((bt&-2082)+bu|0)>>>1)+(bs&2081&bt)<<1)>>1]|(bt^bs)&2081)&65535;break}else{bs=b[(c[277213]|0)+(p<<1)>>1]|0;bG=(((bs&63454)+bu|0)>>>1)+(bs&s&2081)&65535;break}}else{s=e[(c[277225]|0)+(g<<1)>>1]|0;bs=(a[(c[277215]|0)+p|0]&32)==0;if(bs){bu=c[277228]|0;bH=bu;bI=bu&-2082}else{bu=e[(c[277213]|0)+(p<<1)>>1]|0;bH=bu;bI=bu&63454}if(bs){bJ=c[277228]|0}else{bJ=e[(c[277213]|0)+(p<<1)>>1]|0}bG=((bJ^s)&2081|e[(c[277220]|0)+((s&2081&bH)+((bI+(s&63454)|0)>>>1)<<1)>>1])&65535}}while(0);g=k+3|0;b[(c[277218]|0)+(g<<1)>>1]=bG;b[(c[277218]|0)+(p<<1)>>1]=bG;s=a[1108909]|0;a[(c[277219]|0)+g|0]=s;a[(c[277219]|0)+p|0]=s}}while(0);p=bE-1&255;if(p<<24>>24!=0){bw=p;v=2062}}if((v|0)==2062){v=0;p=k+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){s=a[aS+2|0]|0;g=s&255;if(s<<24>>24==0){break}do{if((a[1108928]|0)==0){s=b[(c[277225]|0)+(g<<1)>>1]|0;bs=s&65535;bu=bs&63454;if((a[(c[277215]|0)+p|0]&32)==0){bt=c[277228]|0;bK=(e[(c[277220]|0)+((((bt&-2082)+bu|0)>>>1)+(bs&2081&bt)<<1)>>1]|(bt^bs)&2081)&65535;break}else{bs=b[(c[277213]|0)+(p<<1)>>1]|0;bK=(((bs&63454)+bu|0)>>>1)+(bs&s&2081)&65535;break}}else{s=e[(c[277225]|0)+(g<<1)>>1]|0;bs=(a[(c[277215]|0)+p|0]&32)==0;if(bs){bu=c[277228]|0;bL=bu;bM=bu&-2082}else{bu=e[(c[277213]|0)+(p<<1)>>1]|0;bL=bu;bM=bu&63454}if(bs){bN=c[277228]|0}else{bN=e[(c[277213]|0)+(p<<1)>>1]|0}bK=((bN^s)&2081|e[(c[277220]|0)+((s&2081&bL)+((bM+(s&63454)|0)>>>1)<<1)>>1])&65535}}while(0);g=k+5|0;b[(c[277218]|0)+(g<<1)>>1]=bK;b[(c[277218]|0)+(p<<1)>>1]=bK;s=a[1108909]|0;a[(c[277219]|0)+g|0]=s;a[(c[277219]|0)+p|0]=s}}while(0);p=bw-1&255;if(p<<24>>24!=0){bx=p;v=2077}}if((v|0)==2077){v=0;p=k+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){s=a[aS+3|0]|0;g=s&255;if(s<<24>>24==0){break}do{if((a[1108928]|0)==0){s=b[(c[277225]|0)+(g<<1)>>1]|0;bs=s&65535;bu=bs&63454;if((a[(c[277215]|0)+p|0]&32)==0){bt=c[277228]|0;bO=(e[(c[277220]|0)+((((bt&-2082)+bu|0)>>>1)+(bs&2081&bt)<<1)>>1]|(bt^bs)&2081)&65535;break}else{bs=b[(c[277213]|0)+(p<<1)>>1]|0;bO=(((bs&63454)+bu|0)>>>1)+(bs&s&2081)&65535;break}}else{s=e[(c[277225]|0)+(g<<1)>>1]|0;bs=(a[(c[277215]|0)+p|0]&32)==0;if(bs){bu=c[277228]|0;bP=bu;bQ=bu&-2082}else{bu=e[(c[277213]|0)+(p<<1)>>1]|0;bP=bu;bQ=bu&63454}if(bs){bR=c[277228]|0}else{bR=e[(c[277213]|0)+(p<<1)>>1]|0}bO=((bR^s)&2081|e[(c[277220]|0)+((s&2081&bP)+((bQ+(s&63454)|0)>>>1)<<1)>>1])&65535}}while(0);g=k+7|0;b[(c[277218]|0)+(g<<1)>>1]=bO;b[(c[277218]|0)+(p<<1)>>1]=bO;s=a[1108909]|0;a[(c[277219]|0)+g|0]=s;a[(c[277219]|0)+p|0]=s}}while(0);p=bx-1&255;if(p<<24>>24!=0){by=p;v=2092}}if((v|0)==2092){v=0;p=k+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){s=a[aS+4|0]|0;g=s&255;if(s<<24>>24==0){break}do{if((a[1108928]|0)==0){s=b[(c[277225]|0)+(g<<1)>>1]|0;bs=s&65535;bu=bs&63454;if((a[(c[277215]|0)+p|0]&32)==0){bt=c[277228]|0;bS=(e[(c[277220]|0)+((((bt&-2082)+bu|0)>>>1)+(bs&2081&bt)<<1)>>1]|(bt^bs)&2081)&65535;break}else{bs=b[(c[277213]|0)+(p<<1)>>1]|0;bS=(((bs&63454)+bu|0)>>>1)+(bs&s&2081)&65535;break}}else{s=e[(c[277225]|0)+(g<<1)>>1]|0;bs=(a[(c[277215]|0)+p|0]&32)==0;if(bs){bu=c[277228]|0;bT=bu;bU=bu&-2082}else{bu=e[(c[277213]|0)+(p<<1)>>1]|0;bT=bu;bU=bu&63454}if(bs){bV=c[277228]|0}else{bV=e[(c[277213]|0)+(p<<1)>>1]|0}bS=((bV^s)&2081|e[(c[277220]|0)+((s&2081&bT)+((bU+(s&63454)|0)>>>1)<<1)>>1])&65535}}while(0);g=k+9|0;b[(c[277218]|0)+(g<<1)>>1]=bS;b[(c[277218]|0)+(p<<1)>>1]=bS;s=a[1108909]|0;a[(c[277219]|0)+g|0]=s;a[(c[277219]|0)+p|0]=s}}while(0);p=by-1&255;if(p<<24>>24!=0){bz=p;v=2107}}if((v|0)==2107){v=0;p=k+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){s=a[aS+5|0]|0;g=s&255;if(s<<24>>24==0){break}do{if((a[1108928]|0)==0){s=b[(c[277225]|0)+(g<<1)>>1]|0;bs=s&65535;bu=bs&63454;if((a[(c[277215]|0)+p|0]&32)==0){bt=c[277228]|0;bW=(e[(c[277220]|0)+((((bt&-2082)+bu|0)>>>1)+(bs&2081&bt)<<1)>>1]|(bt^bs)&2081)&65535;break}else{bs=b[(c[277213]|0)+(p<<1)>>1]|0;bW=(((bs&63454)+bu|0)>>>1)+(bs&s&2081)&65535;break}}else{s=e[(c[277225]|0)+(g<<1)>>1]|0;bs=(a[(c[277215]|0)+p|0]&32)==0;if(bs){bu=c[277228]|0;bX=bu;bY=bu&-2082}else{bu=e[(c[277213]|0)+(p<<1)>>1]|0;bX=bu;bY=bu&63454}if(bs){bZ=c[277228]|0}else{bZ=e[(c[277213]|0)+(p<<1)>>1]|0}bW=((bZ^s)&2081|e[(c[277220]|0)+((s&2081&bX)+((bY+(s&63454)|0)>>>1)<<1)>>1])&65535}}while(0);g=k+11|0;b[(c[277218]|0)+(g<<1)>>1]=bW;b[(c[277218]|0)+(p<<1)>>1]=bW;s=a[1108909]|0;a[(c[277219]|0)+g|0]=s;a[(c[277219]|0)+p|0]=s}}while(0);p=bz-1&255;if(p<<24>>24!=0){bF=p;v=2122}}if((v|0)==2122){v=0;p=k+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){s=a[aS+6|0]|0;g=s&255;if(s<<24>>24==0){break}do{if((a[1108928]|0)==0){s=b[(c[277225]|0)+(g<<1)>>1]|0;bs=s&65535;bu=bs&63454;if((a[(c[277215]|0)+p|0]&32)==0){bt=c[277228]|0;b_=(e[(c[277220]|0)+((((bt&-2082)+bu|0)>>>1)+(bs&2081&bt)<<1)>>1]|(bt^bs)&2081)&65535;break}else{bs=b[(c[277213]|0)+(p<<1)>>1]|0;b_=(((bs&63454)+bu|0)>>>1)+(bs&s&2081)&65535;break}}else{s=e[(c[277225]|0)+(g<<1)>>1]|0;bs=(a[(c[277215]|0)+p|0]&32)==0;if(bs){bu=c[277228]|0;b$=bu;b0=bu&-2082}else{bu=e[(c[277213]|0)+(p<<1)>>1]|0;b$=bu;b0=bu&63454}if(bs){b1=c[277228]|0}else{b1=e[(c[277213]|0)+(p<<1)>>1]|0}b_=((b1^s)&2081|e[(c[277220]|0)+((s&2081&b$)+((b0+(s&63454)|0)>>>1)<<1)>>1])&65535}}while(0);g=k+13|0;b[(c[277218]|0)+(g<<1)>>1]=b_;b[(c[277218]|0)+(p<<1)>>1]=b_;s=a[1108909]|0;a[(c[277219]|0)+g|0]=s;a[(c[277219]|0)+p|0]=s}}while(0);if(bF<<24>>24!=1){v=2137}}do{if((v|0)==2137){v=0;p=k+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+p|0]|0)){break}s=a[aS+7|0]|0;g=s&255;if(s<<24>>24==0){break}do{if((a[1108928]|0)==0){s=b[(c[277225]|0)+(g<<1)>>1]|0;bs=s&65535;bu=bs&63454;if((a[(c[277215]|0)+p|0]&32)==0){bt=c[277228]|0;b2=(e[(c[277220]|0)+((((bt&-2082)+bu|0)>>>1)+(bs&2081&bt)<<1)>>1]|(bt^bs)&2081)&65535;break}else{bs=b[(c[277213]|0)+(p<<1)>>1]|0;b2=(((bs&63454)+bu|0)>>>1)+(bs&s&2081)&65535;break}}else{s=e[(c[277225]|0)+(g<<1)>>1]|0;bs=(a[(c[277215]|0)+p|0]&32)==0;if(bs){bu=c[277228]|0;b3=bu;b4=bu&-2082}else{bu=e[(c[277213]|0)+(p<<1)>>1]|0;b3=bu;b4=bu&63454}if(bs){b5=c[277228]|0}else{b5=e[(c[277213]|0)+(p<<1)>>1]|0}b2=((b5^s)&2081|e[(c[277220]|0)+((s&2081&b3)+((b4+(s&63454)|0)>>>1)<<1)>>1])&65535}}while(0);g=k+15|0;b[(c[277218]|0)+(g<<1)>>1]=b2;b[(c[277218]|0)+(p<<1)>>1]=b2;s=a[1108909]|0;a[(c[277219]|0)+g|0]=s;a[(c[277219]|0)+p|0]=s}}while(0);s=ai-1|0;if((s|0)>0){aS=aS-16|0;ai=s;k=(c[277223]|0)+k|0}else{break}}return}}function Vj(e,f,g,h,i,j){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0;k=e&1023;l=c[348606]|0;m=(k<<l)+(c[348604]|0)|0;if((e&256|0)==0){n=m}else{n=(c[348602]|0)+m|0}m=n&65535;n=m>>>(l>>>0);l=(e&16384|0)!=0;o=n<<6;do{if(l){p=(c[348622]|0)+o|0;if((a[(c[348618]|0)+n|0]|0)!=0){q=p;break}r=fi[c[348636]&63](p,m,k)|0;a[(c[348618]|0)+n|0]=r;q=p}else{p=(c[348624]|0)+o|0;if((a[(c[348620]|0)+n|0]|0)!=0){q=p;break}r=fi[c[348638]&63](p,m,k)|0;a[(c[348620]|0)+n|0]=r;q=p}}while(0);if((a[(c[348620]|0)+n|0]|0)==2){return}if((a[1394464]|0)==0){s=1106168+((e>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){n=d[1044485]|0;c[276541]=7080+(n<<5);k=0;do{m=k<<1&2;o=k&2;p=k&4;r=0;do{b[1125528+(k<<9)+(r<<1)>>1]=d[(r>>>1&28|o)+(7080+(n<<5))|0]<<6|d[(r<<2&28|m)+(7080+(n<<5))|0]<<11|d[(r>>>3&24|p)+(7080+(n<<5))|0];r=r+1|0;}while(r>>>0<256);k=k+1|0;}while(k>>>0<8);a[1106089]=0}s=1125528+((e>>>10&7)<<9)|0}c[277226]=s;c[277225]=(a[1108928]|0)!=0?1393712:s;if((e&49152|0)==0){if((j|0)<=0){return}s=h&255;k=s-1&255;n=k<<24>>24==0;r=q+((d[1394504]|0)+(i<<1))|0;p=j;m=f;while(1){switch(g|0){case 2:{t=s;u=2326;break};case 7:{u=2381;break};case 3:{v=s;u=2337;break};case 5:{w=s;u=2359;break};case 4:{x=s;u=2348;break};case 1:{y=s;u=2315;break};case 6:{z=s;u=2370;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+m|0]|0)){o=a[r]|0;if(o<<24>>24==0){break}A=b[(c[277225]|0)+((o&255)<<1)>>1]|0;if((a[(c[277215]|0)+m|0]&32)==0){B=c[277228]&65535}else{B=b[(c[277213]|0)+(m<<1)>>1]|0}o=A&-2048;C=B&-2048;D=(o&65535)>(C&65535)?o-C&65535:0;C=A&2016;o=B&2016;if((C&65535)>(o&65535)){E=(C-o&65535)+D&65535}else{E=D}D=A&31;A=B&31;if((D&65535)>(A&65535)){F=(D-A&65535)+E&65535}else{F=E}A=m+1|0;b[(c[277218]|0)+(A<<1)>>1]=F;b[(c[277218]|0)+(m<<1)>>1]=F;D=a[1108909]|0;a[(c[277219]|0)+A|0]=D;a[(c[277219]|0)+m|0]=D}}while(0);if(!n){y=k;u=2315}break};default:{}}if((u|0)==2315){u=0;D=m+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+D|0]|0)){A=a[r+1|0]|0;if(A<<24>>24==0){break}o=b[(c[277225]|0)+((A&255)<<1)>>1]|0;if((a[(c[277215]|0)+D|0]&32)==0){G=c[277228]&65535}else{G=b[(c[277213]|0)+(D<<1)>>1]|0}A=o&-2048;C=G&-2048;H=(A&65535)>(C&65535)?A-C&65535:0;C=o&2016;A=G&2016;if((C&65535)>(A&65535)){I=(C-A&65535)+H&65535}else{I=H}H=o&31;o=G&31;if((H&65535)>(o&65535)){J=(H-o&65535)+I&65535}else{J=I}o=m+3|0;b[(c[277218]|0)+(o<<1)>>1]=J;b[(c[277218]|0)+(D<<1)>>1]=J;H=a[1108909]|0;a[(c[277219]|0)+o|0]=H;a[(c[277219]|0)+D|0]=H}}while(0);D=y-1&255;if(D<<24>>24!=0){t=D;u=2326}}if((u|0)==2326){u=0;D=m+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+D|0]|0)){H=a[r+2|0]|0;if(H<<24>>24==0){break}o=b[(c[277225]|0)+((H&255)<<1)>>1]|0;if((a[(c[277215]|0)+D|0]&32)==0){K=c[277228]&65535}else{K=b[(c[277213]|0)+(D<<1)>>1]|0}H=o&-2048;A=K&-2048;C=(H&65535)>(A&65535)?H-A&65535:0;A=o&2016;H=K&2016;if((A&65535)>(H&65535)){L=(A-H&65535)+C&65535}else{L=C}C=o&31;o=K&31;if((C&65535)>(o&65535)){M=(C-o&65535)+L&65535}else{M=L}o=m+5|0;b[(c[277218]|0)+(o<<1)>>1]=M;b[(c[277218]|0)+(D<<1)>>1]=M;C=a[1108909]|0;a[(c[277219]|0)+o|0]=C;a[(c[277219]|0)+D|0]=C}}while(0);D=t-1&255;if(D<<24>>24!=0){v=D;u=2337}}if((u|0)==2337){u=0;D=m+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+D|0]|0)){C=a[r+3|0]|0;if(C<<24>>24==0){break}o=b[(c[277225]|0)+((C&255)<<1)>>1]|0;if((a[(c[277215]|0)+D|0]&32)==0){N=c[277228]&65535}else{N=b[(c[277213]|0)+(D<<1)>>1]|0}C=o&-2048;H=N&-2048;A=(C&65535)>(H&65535)?C-H&65535:0;H=o&2016;C=N&2016;if((H&65535)>(C&65535)){O=(H-C&65535)+A&65535}else{O=A}A=o&31;o=N&31;if((A&65535)>(o&65535)){P=(A-o&65535)+O&65535}else{P=O}o=m+7|0;b[(c[277218]|0)+(o<<1)>>1]=P;b[(c[277218]|0)+(D<<1)>>1]=P;A=a[1108909]|0;a[(c[277219]|0)+o|0]=A;a[(c[277219]|0)+D|0]=A}}while(0);D=v-1&255;if(D<<24>>24!=0){x=D;u=2348}}if((u|0)==2348){u=0;D=m+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+D|0]|0)){A=a[r+4|0]|0;if(A<<24>>24==0){break}o=b[(c[277225]|0)+((A&255)<<1)>>1]|0;if((a[(c[277215]|0)+D|0]&32)==0){Q=c[277228]&65535}else{Q=b[(c[277213]|0)+(D<<1)>>1]|0}A=o&-2048;C=Q&-2048;H=(A&65535)>(C&65535)?A-C&65535:0;C=o&2016;A=Q&2016;if((C&65535)>(A&65535)){R=(C-A&65535)+H&65535}else{R=H}H=o&31;o=Q&31;if((H&65535)>(o&65535)){S=(H-o&65535)+R&65535}else{S=R}o=m+9|0;b[(c[277218]|0)+(o<<1)>>1]=S;b[(c[277218]|0)+(D<<1)>>1]=S;H=a[1108909]|0;a[(c[277219]|0)+o|0]=H;a[(c[277219]|0)+D|0]=H}}while(0);D=x-1&255;if(D<<24>>24!=0){w=D;u=2359}}if((u|0)==2359){u=0;D=m+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+D|0]|0)){H=a[r+5|0]|0;if(H<<24>>24==0){break}o=b[(c[277225]|0)+((H&255)<<1)>>1]|0;if((a[(c[277215]|0)+D|0]&32)==0){T=c[277228]&65535}else{T=b[(c[277213]|0)+(D<<1)>>1]|0}H=o&-2048;A=T&-2048;C=(H&65535)>(A&65535)?H-A&65535:0;A=o&2016;H=T&2016;if((A&65535)>(H&65535)){U=(A-H&65535)+C&65535}else{U=C}C=o&31;o=T&31;if((C&65535)>(o&65535)){V=(C-o&65535)+U&65535}else{V=U}o=m+11|0;b[(c[277218]|0)+(o<<1)>>1]=V;b[(c[277218]|0)+(D<<1)>>1]=V;C=a[1108909]|0;a[(c[277219]|0)+o|0]=C;a[(c[277219]|0)+D|0]=C}}while(0);D=w-1&255;if(D<<24>>24!=0){z=D;u=2370}}if((u|0)==2370){u=0;D=m+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+D|0]|0)){C=a[r+6|0]|0;if(C<<24>>24==0){break}o=b[(c[277225]|0)+((C&255)<<1)>>1]|0;if((a[(c[277215]|0)+D|0]&32)==0){W=c[277228]&65535}else{W=b[(c[277213]|0)+(D<<1)>>1]|0}C=o&-2048;H=W&-2048;A=(C&65535)>(H&65535)?C-H&65535:0;H=o&2016;C=W&2016;if((H&65535)>(C&65535)){X=(H-C&65535)+A&65535}else{X=A}A=o&31;o=W&31;if((A&65535)>(o&65535)){Y=(A-o&65535)+X&65535}else{Y=X}o=m+13|0;b[(c[277218]|0)+(o<<1)>>1]=Y;b[(c[277218]|0)+(D<<1)>>1]=Y;A=a[1108909]|0;a[(c[277219]|0)+o|0]=A;a[(c[277219]|0)+D|0]=A}}while(0);if(z<<24>>24!=1){u=2381}}do{if((u|0)==2381){u=0;D=m+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+D|0]|0)){break}A=a[r+7|0]|0;if(A<<24>>24==0){break}o=b[(c[277225]|0)+((A&255)<<1)>>1]|0;if((a[(c[277215]|0)+D|0]&32)==0){Z=c[277228]&65535}else{Z=b[(c[277213]|0)+(D<<1)>>1]|0}A=o&-2048;C=Z&-2048;H=(A&65535)>(C&65535)?A-C&65535:0;C=o&2016;A=Z&2016;if((C&65535)>(A&65535)){_=(C-A&65535)+H&65535}else{_=H}H=o&31;o=Z&31;if((H&65535)>(o&65535)){$=(H-o&65535)+_&65535}else{$=_}o=m+15|0;b[(c[277218]|0)+(o<<1)>>1]=$;b[(c[277218]|0)+(D<<1)>>1]=$;H=a[1108909]|0;a[(c[277219]|0)+o|0]=H;a[(c[277219]|0)+D|0]=H}}while(0);H=p-1|0;if((H|0)>0){r=r+16|0;p=H;m=(c[277223]|0)+m|0}else{break}}return}m=(d[1394504]|0)+(i<<1)|0;if((e&32768|0)==0){if((j|0)<=0){return}e=h&255;i=e-1&255;p=i<<24>>24==0;r=q+m|0;$=j;_=f;while(1){switch(g|0){case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+_|0]|0)){Z=a[r+7|0]|0;if(Z<<24>>24==0){break}z=b[(c[277225]|0)+((Z&255)<<1)>>1]|0;if((a[(c[277215]|0)+_|0]&32)==0){aa=c[277228]&65535}else{aa=b[(c[277213]|0)+(_<<1)>>1]|0}Z=z&-2048;Y=aa&-2048;X=(Z&65535)>(Y&65535)?Z-Y&65535:0;Y=z&2016;Z=aa&2016;if((Y&65535)>(Z&65535)){ab=(Y-Z&65535)+X&65535}else{ab=X}X=z&31;z=aa&31;if((X&65535)>(z&65535)){ac=(X-z&65535)+ab&65535}else{ac=ab}z=_+1|0;b[(c[277218]|0)+(z<<1)>>1]=ac;b[(c[277218]|0)+(_<<1)>>1]=ac;X=a[1108909]|0;a[(c[277219]|0)+z|0]=X;a[(c[277219]|0)+_|0]=X}}while(0);if(!p){ad=i;u=2407}break};case 1:{ad=e;u=2407;break};case 2:{ae=e;u=2418;break};case 6:{af=e;u=2462;break};case 3:{ag=e;u=2429;break};case 7:{u=2473;break};case 4:{ah=e;u=2440;break};case 5:{ai=e;u=2451;break};default:{}}if((u|0)==2407){u=0;X=_+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+X|0]|0)){z=a[r+6|0]|0;if(z<<24>>24==0){break}Z=b[(c[277225]|0)+((z&255)<<1)>>1]|0;if((a[(c[277215]|0)+X|0]&32)==0){aj=c[277228]&65535}else{aj=b[(c[277213]|0)+(X<<1)>>1]|0}z=Z&-2048;Y=aj&-2048;W=(z&65535)>(Y&65535)?z-Y&65535:0;Y=Z&2016;z=aj&2016;if((Y&65535)>(z&65535)){ak=(Y-z&65535)+W&65535}else{ak=W}W=Z&31;Z=aj&31;if((W&65535)>(Z&65535)){al=(W-Z&65535)+ak&65535}else{al=ak}Z=_+3|0;b[(c[277218]|0)+(Z<<1)>>1]=al;b[(c[277218]|0)+(X<<1)>>1]=al;W=a[1108909]|0;a[(c[277219]|0)+Z|0]=W;a[(c[277219]|0)+X|0]=W}}while(0);X=ad-1&255;if(X<<24>>24!=0){ae=X;u=2418}}if((u|0)==2418){u=0;X=_+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+X|0]|0)){W=a[r+5|0]|0;if(W<<24>>24==0){break}Z=b[(c[277225]|0)+((W&255)<<1)>>1]|0;if((a[(c[277215]|0)+X|0]&32)==0){am=c[277228]&65535}else{am=b[(c[277213]|0)+(X<<1)>>1]|0}W=Z&-2048;z=am&-2048;Y=(W&65535)>(z&65535)?W-z&65535:0;z=Z&2016;W=am&2016;if((z&65535)>(W&65535)){an=(z-W&65535)+Y&65535}else{an=Y}Y=Z&31;Z=am&31;if((Y&65535)>(Z&65535)){ao=(Y-Z&65535)+an&65535}else{ao=an}Z=_+5|0;b[(c[277218]|0)+(Z<<1)>>1]=ao;b[(c[277218]|0)+(X<<1)>>1]=ao;Y=a[1108909]|0;a[(c[277219]|0)+Z|0]=Y;a[(c[277219]|0)+X|0]=Y}}while(0);X=ae-1&255;if(X<<24>>24!=0){ag=X;u=2429}}if((u|0)==2429){u=0;X=_+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+X|0]|0)){Y=a[r+4|0]|0;if(Y<<24>>24==0){break}Z=b[(c[277225]|0)+((Y&255)<<1)>>1]|0;if((a[(c[277215]|0)+X|0]&32)==0){ap=c[277228]&65535}else{ap=b[(c[277213]|0)+(X<<1)>>1]|0}Y=Z&-2048;W=ap&-2048;z=(Y&65535)>(W&65535)?Y-W&65535:0;W=Z&2016;Y=ap&2016;if((W&65535)>(Y&65535)){aq=(W-Y&65535)+z&65535}else{aq=z}z=Z&31;Z=ap&31;if((z&65535)>(Z&65535)){ar=(z-Z&65535)+aq&65535}else{ar=aq}Z=_+7|0;b[(c[277218]|0)+(Z<<1)>>1]=ar;b[(c[277218]|0)+(X<<1)>>1]=ar;z=a[1108909]|0;a[(c[277219]|0)+Z|0]=z;a[(c[277219]|0)+X|0]=z}}while(0);X=ag-1&255;if(X<<24>>24!=0){ah=X;u=2440}}if((u|0)==2440){u=0;X=_+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+X|0]|0)){z=a[r+3|0]|0;if(z<<24>>24==0){break}Z=b[(c[277225]|0)+((z&255)<<1)>>1]|0;if((a[(c[277215]|0)+X|0]&32)==0){as=c[277228]&65535}else{as=b[(c[277213]|0)+(X<<1)>>1]|0}z=Z&-2048;Y=as&-2048;W=(z&65535)>(Y&65535)?z-Y&65535:0;Y=Z&2016;z=as&2016;if((Y&65535)>(z&65535)){at=(Y-z&65535)+W&65535}else{at=W}W=Z&31;Z=as&31;if((W&65535)>(Z&65535)){au=(W-Z&65535)+at&65535}else{au=at}Z=_+9|0;b[(c[277218]|0)+(Z<<1)>>1]=au;b[(c[277218]|0)+(X<<1)>>1]=au;W=a[1108909]|0;a[(c[277219]|0)+Z|0]=W;a[(c[277219]|0)+X|0]=W}}while(0);X=ah-1&255;if(X<<24>>24!=0){ai=X;u=2451}}if((u|0)==2451){u=0;X=_+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+X|0]|0)){W=a[r+2|0]|0;if(W<<24>>24==0){break}Z=b[(c[277225]|0)+((W&255)<<1)>>1]|0;if((a[(c[277215]|0)+X|0]&32)==0){av=c[277228]&65535}else{av=b[(c[277213]|0)+(X<<1)>>1]|0}W=Z&-2048;z=av&-2048;Y=(W&65535)>(z&65535)?W-z&65535:0;z=Z&2016;W=av&2016;if((z&65535)>(W&65535)){aw=(z-W&65535)+Y&65535}else{aw=Y}Y=Z&31;Z=av&31;if((Y&65535)>(Z&65535)){ax=(Y-Z&65535)+aw&65535}else{ax=aw}Z=_+11|0;b[(c[277218]|0)+(Z<<1)>>1]=ax;b[(c[277218]|0)+(X<<1)>>1]=ax;Y=a[1108909]|0;a[(c[277219]|0)+Z|0]=Y;a[(c[277219]|0)+X|0]=Y}}while(0);X=ai-1&255;if(X<<24>>24!=0){af=X;u=2462}}if((u|0)==2462){u=0;X=_+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+X|0]|0)){Y=a[r+1|0]|0;if(Y<<24>>24==0){break}Z=b[(c[277225]|0)+((Y&255)<<1)>>1]|0;if((a[(c[277215]|0)+X|0]&32)==0){ay=c[277228]&65535}else{ay=b[(c[277213]|0)+(X<<1)>>1]|0}Y=Z&-2048;W=ay&-2048;z=(Y&65535)>(W&65535)?Y-W&65535:0;W=Z&2016;Y=ay&2016;if((W&65535)>(Y&65535)){az=(W-Y&65535)+z&65535}else{az=z}z=Z&31;Z=ay&31;if((z&65535)>(Z&65535)){aA=(z-Z&65535)+az&65535}else{aA=az}Z=_+13|0;b[(c[277218]|0)+(Z<<1)>>1]=aA;b[(c[277218]|0)+(X<<1)>>1]=aA;z=a[1108909]|0;a[(c[277219]|0)+Z|0]=z;a[(c[277219]|0)+X|0]=z}}while(0);if(af<<24>>24!=1){u=2473}}do{if((u|0)==2473){u=0;X=_+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+X|0]|0)){break}z=a[r]|0;if(z<<24>>24==0){break}Z=b[(c[277225]|0)+((z&255)<<1)>>1]|0;if((a[(c[277215]|0)+X|0]&32)==0){aB=c[277228]&65535}else{aB=b[(c[277213]|0)+(X<<1)>>1]|0}z=Z&-2048;Y=aB&-2048;W=(z&65535)>(Y&65535)?z-Y&65535:0;Y=Z&2016;z=aB&2016;if((Y&65535)>(z&65535)){aC=(Y-z&65535)+W&65535}else{aC=W}W=Z&31;Z=aB&31;if((W&65535)>(Z&65535)){aD=(W-Z&65535)+aC&65535}else{aD=aC}Z=_+15|0;b[(c[277218]|0)+(Z<<1)>>1]=aD;b[(c[277218]|0)+(X<<1)>>1]=aD;W=a[1108909]|0;a[(c[277219]|0)+Z|0]=W;a[(c[277219]|0)+X|0]=W}}while(0);W=$-1|0;if((W|0)>0){r=r+16|0;$=W;_=(c[277223]|0)+_|0}else{break}}return}_=q+(56-m)|0;m=(j|0)>0;if(l){if(!m){return}l=h&255;q=l-1&255;$=q<<24>>24==0;r=_;aD=j;aC=f;while(1){switch(g|0){case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+aC|0]|0)){aB=a[r+7|0]|0;if(aB<<24>>24==0){break}af=b[(c[277225]|0)+((aB&255)<<1)>>1]|0;if((a[(c[277215]|0)+aC|0]&32)==0){aE=c[277228]&65535}else{aE=b[(c[277213]|0)+(aC<<1)>>1]|0}aB=af&-2048;aA=aE&-2048;az=(aB&65535)>(aA&65535)?aB-aA&65535:0;aA=af&2016;aB=aE&2016;if((aA&65535)>(aB&65535)){aF=(aA-aB&65535)+az&65535}else{aF=az}az=af&31;af=aE&31;if((az&65535)>(af&65535)){aG=(az-af&65535)+aF&65535}else{aG=aF}af=aC+1|0;b[(c[277218]|0)+(af<<1)>>1]=aG;b[(c[277218]|0)+(aC<<1)>>1]=aG;az=a[1108909]|0;a[(c[277219]|0)+af|0]=az;a[(c[277219]|0)+aC|0]=az}}while(0);if(!$){aH=q;u=2590}break};case 1:{aH=l;u=2590;break};case 5:{aI=l;u=2634;break};case 6:{aJ=l;u=2645;break};case 7:{u=2656;break};case 2:{aK=l;u=2601;break};case 3:{aL=l;u=2612;break};case 4:{aM=l;u=2623;break};default:{}}if((u|0)==2590){u=0;az=aC+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+az|0]|0)){af=a[r+6|0]|0;if(af<<24>>24==0){break}aB=b[(c[277225]|0)+((af&255)<<1)>>1]|0;if((a[(c[277215]|0)+az|0]&32)==0){aN=c[277228]&65535}else{aN=b[(c[277213]|0)+(az<<1)>>1]|0}af=aB&-2048;aA=aN&-2048;ay=(af&65535)>(aA&65535)?af-aA&65535:0;aA=aB&2016;af=aN&2016;if((aA&65535)>(af&65535)){aO=(aA-af&65535)+ay&65535}else{aO=ay}ay=aB&31;aB=aN&31;if((ay&65535)>(aB&65535)){aP=(ay-aB&65535)+aO&65535}else{aP=aO}aB=aC+3|0;b[(c[277218]|0)+(aB<<1)>>1]=aP;b[(c[277218]|0)+(az<<1)>>1]=aP;ay=a[1108909]|0;a[(c[277219]|0)+aB|0]=ay;a[(c[277219]|0)+az|0]=ay}}while(0);az=aH-1&255;if(az<<24>>24!=0){aK=az;u=2601}}if((u|0)==2601){u=0;az=aC+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+az|0]|0)){ay=a[r+5|0]|0;if(ay<<24>>24==0){break}aB=b[(c[277225]|0)+((ay&255)<<1)>>1]|0;if((a[(c[277215]|0)+az|0]&32)==0){aQ=c[277228]&65535}else{aQ=b[(c[277213]|0)+(az<<1)>>1]|0}ay=aB&-2048;af=aQ&-2048;aA=(ay&65535)>(af&65535)?ay-af&65535:0;af=aB&2016;ay=aQ&2016;if((af&65535)>(ay&65535)){aR=(af-ay&65535)+aA&65535}else{aR=aA}aA=aB&31;aB=aQ&31;if((aA&65535)>(aB&65535)){aS=(aA-aB&65535)+aR&65535}else{aS=aR}aB=aC+5|0;b[(c[277218]|0)+(aB<<1)>>1]=aS;b[(c[277218]|0)+(az<<1)>>1]=aS;aA=a[1108909]|0;a[(c[277219]|0)+aB|0]=aA;a[(c[277219]|0)+az|0]=aA}}while(0);az=aK-1&255;if(az<<24>>24!=0){aL=az;u=2612}}if((u|0)==2612){u=0;az=aC+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+az|0]|0)){aA=a[r+4|0]|0;if(aA<<24>>24==0){break}aB=b[(c[277225]|0)+((aA&255)<<1)>>1]|0;if((a[(c[277215]|0)+az|0]&32)==0){aT=c[277228]&65535}else{aT=b[(c[277213]|0)+(az<<1)>>1]|0}aA=aB&-2048;ay=aT&-2048;af=(aA&65535)>(ay&65535)?aA-ay&65535:0;ay=aB&2016;aA=aT&2016;if((ay&65535)>(aA&65535)){aU=(ay-aA&65535)+af&65535}else{aU=af}af=aB&31;aB=aT&31;if((af&65535)>(aB&65535)){aV=(af-aB&65535)+aU&65535}else{aV=aU}aB=aC+7|0;b[(c[277218]|0)+(aB<<1)>>1]=aV;b[(c[277218]|0)+(az<<1)>>1]=aV;af=a[1108909]|0;a[(c[277219]|0)+aB|0]=af;a[(c[277219]|0)+az|0]=af}}while(0);az=aL-1&255;if(az<<24>>24!=0){aM=az;u=2623}}if((u|0)==2623){u=0;az=aC+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+az|0]|0)){af=a[r+3|0]|0;if(af<<24>>24==0){break}aB=b[(c[277225]|0)+((af&255)<<1)>>1]|0;if((a[(c[277215]|0)+az|0]&32)==0){aW=c[277228]&65535}else{aW=b[(c[277213]|0)+(az<<1)>>1]|0}af=aB&-2048;aA=aW&-2048;ay=(af&65535)>(aA&65535)?af-aA&65535:0;aA=aB&2016;af=aW&2016;if((aA&65535)>(af&65535)){aX=(aA-af&65535)+ay&65535}else{aX=ay}ay=aB&31;aB=aW&31;if((ay&65535)>(aB&65535)){aY=(ay-aB&65535)+aX&65535}else{aY=aX}aB=aC+9|0;b[(c[277218]|0)+(aB<<1)>>1]=aY;b[(c[277218]|0)+(az<<1)>>1]=aY;ay=a[1108909]|0;a[(c[277219]|0)+aB|0]=ay;a[(c[277219]|0)+az|0]=ay}}while(0);az=aM-1&255;if(az<<24>>24!=0){aI=az;u=2634}}if((u|0)==2634){u=0;az=aC+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+az|0]|0)){ay=a[r+2|0]|0;if(ay<<24>>24==0){break}aB=b[(c[277225]|0)+((ay&255)<<1)>>1]|0;if((a[(c[277215]|0)+az|0]&32)==0){aZ=c[277228]&65535}else{aZ=b[(c[277213]|0)+(az<<1)>>1]|0}ay=aB&-2048;af=aZ&-2048;aA=(ay&65535)>(af&65535)?ay-af&65535:0;af=aB&2016;ay=aZ&2016;if((af&65535)>(ay&65535)){a_=(af-ay&65535)+aA&65535}else{a_=aA}aA=aB&31;aB=aZ&31;if((aA&65535)>(aB&65535)){a$=(aA-aB&65535)+a_&65535}else{a$=a_}aB=aC+11|0;b[(c[277218]|0)+(aB<<1)>>1]=a$;b[(c[277218]|0)+(az<<1)>>1]=a$;aA=a[1108909]|0;a[(c[277219]|0)+aB|0]=aA;a[(c[277219]|0)+az|0]=aA}}while(0);az=aI-1&255;if(az<<24>>24!=0){aJ=az;u=2645}}if((u|0)==2645){u=0;az=aC+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+az|0]|0)){aA=a[r+1|0]|0;if(aA<<24>>24==0){break}aB=b[(c[277225]|0)+((aA&255)<<1)>>1]|0;if((a[(c[277215]|0)+az|0]&32)==0){a0=c[277228]&65535}else{a0=b[(c[277213]|0)+(az<<1)>>1]|0}aA=aB&-2048;ay=a0&-2048;af=(aA&65535)>(ay&65535)?aA-ay&65535:0;ay=aB&2016;aA=a0&2016;if((ay&65535)>(aA&65535)){a1=(ay-aA&65535)+af&65535}else{a1=af}af=aB&31;aB=a0&31;if((af&65535)>(aB&65535)){a2=(af-aB&65535)+a1&65535}else{a2=a1}aB=aC+13|0;b[(c[277218]|0)+(aB<<1)>>1]=a2;b[(c[277218]|0)+(az<<1)>>1]=a2;af=a[1108909]|0;a[(c[277219]|0)+aB|0]=af;a[(c[277219]|0)+az|0]=af}}while(0);if(aJ<<24>>24!=1){u=2656}}do{if((u|0)==2656){u=0;az=aC+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+az|0]|0)){break}af=a[r]|0;if(af<<24>>24==0){break}aB=b[(c[277225]|0)+((af&255)<<1)>>1]|0;if((a[(c[277215]|0)+az|0]&32)==0){a3=c[277228]&65535}else{a3=b[(c[277213]|0)+(az<<1)>>1]|0}af=aB&-2048;aA=a3&-2048;ay=(af&65535)>(aA&65535)?af-aA&65535:0;aA=aB&2016;af=a3&2016;if((aA&65535)>(af&65535)){a4=(aA-af&65535)+ay&65535}else{a4=ay}ay=aB&31;aB=a3&31;if((ay&65535)>(aB&65535)){a5=(ay-aB&65535)+a4&65535}else{a5=a4}aB=aC+15|0;b[(c[277218]|0)+(aB<<1)>>1]=a5;b[(c[277218]|0)+(az<<1)>>1]=a5;ay=a[1108909]|0;a[(c[277219]|0)+aB|0]=ay;a[(c[277219]|0)+az|0]=ay}}while(0);ay=aD-1|0;if((ay|0)>0){r=r-16|0;aD=ay;aC=(c[277223]|0)+aC|0}else{break}}return}else{if(!m){return}m=h&255;h=m-1&255;aC=h<<24>>24==0;aD=_;_=j;j=f;while(1){switch(g|0){case 1:{a6=m;u=2501;break};case 4:{a7=m;u=2534;break};case 5:{a8=m;u=2545;break};case 3:{a9=m;u=2523;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+j|0]|0)){f=a[aD]|0;if(f<<24>>24==0){break}r=b[(c[277225]|0)+((f&255)<<1)>>1]|0;if((a[(c[277215]|0)+j|0]&32)==0){ba=c[277228]&65535}else{ba=b[(c[277213]|0)+(j<<1)>>1]|0}f=r&-2048;a5=ba&-2048;a4=(f&65535)>(a5&65535)?f-a5&65535:0;a5=r&2016;f=ba&2016;if((a5&65535)>(f&65535)){bb=(a5-f&65535)+a4&65535}else{bb=a4}a4=r&31;r=ba&31;if((a4&65535)>(r&65535)){bc=(a4-r&65535)+bb&65535}else{bc=bb}r=j+1|0;b[(c[277218]|0)+(r<<1)>>1]=bc;b[(c[277218]|0)+(j<<1)>>1]=bc;a4=a[1108909]|0;a[(c[277219]|0)+r|0]=a4;a[(c[277219]|0)+j|0]=a4}}while(0);if(!aC){a6=h;u=2501}break};case 2:{bd=m;u=2512;break};case 6:{be=m;u=2556;break};case 7:{u=2567;break};default:{}}if((u|0)==2501){u=0;a4=j+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+a4|0]|0)){r=a[aD+1|0]|0;if(r<<24>>24==0){break}f=b[(c[277225]|0)+((r&255)<<1)>>1]|0;if((a[(c[277215]|0)+a4|0]&32)==0){bf=c[277228]&65535}else{bf=b[(c[277213]|0)+(a4<<1)>>1]|0}r=f&-2048;a5=bf&-2048;a3=(r&65535)>(a5&65535)?r-a5&65535:0;a5=f&2016;r=bf&2016;if((a5&65535)>(r&65535)){bg=(a5-r&65535)+a3&65535}else{bg=a3}a3=f&31;f=bf&31;if((a3&65535)>(f&65535)){bh=(a3-f&65535)+bg&65535}else{bh=bg}f=j+3|0;b[(c[277218]|0)+(f<<1)>>1]=bh;b[(c[277218]|0)+(a4<<1)>>1]=bh;a3=a[1108909]|0;a[(c[277219]|0)+f|0]=a3;a[(c[277219]|0)+a4|0]=a3}}while(0);a4=a6-1&255;if(a4<<24>>24!=0){bd=a4;u=2512}}if((u|0)==2512){u=0;a4=j+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+a4|0]|0)){a3=a[aD+2|0]|0;if(a3<<24>>24==0){break}f=b[(c[277225]|0)+((a3&255)<<1)>>1]|0;if((a[(c[277215]|0)+a4|0]&32)==0){bi=c[277228]&65535}else{bi=b[(c[277213]|0)+(a4<<1)>>1]|0}a3=f&-2048;r=bi&-2048;a5=(a3&65535)>(r&65535)?a3-r&65535:0;r=f&2016;a3=bi&2016;if((r&65535)>(a3&65535)){bj=(r-a3&65535)+a5&65535}else{bj=a5}a5=f&31;f=bi&31;if((a5&65535)>(f&65535)){bk=(a5-f&65535)+bj&65535}else{bk=bj}f=j+5|0;b[(c[277218]|0)+(f<<1)>>1]=bk;b[(c[277218]|0)+(a4<<1)>>1]=bk;a5=a[1108909]|0;a[(c[277219]|0)+f|0]=a5;a[(c[277219]|0)+a4|0]=a5}}while(0);a4=bd-1&255;if(a4<<24>>24!=0){a9=a4;u=2523}}if((u|0)==2523){u=0;a4=j+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+a4|0]|0)){a5=a[aD+3|0]|0;if(a5<<24>>24==0){break}f=b[(c[277225]|0)+((a5&255)<<1)>>1]|0;if((a[(c[277215]|0)+a4|0]&32)==0){bl=c[277228]&65535}else{bl=b[(c[277213]|0)+(a4<<1)>>1]|0}a5=f&-2048;a3=bl&-2048;r=(a5&65535)>(a3&65535)?a5-a3&65535:0;a3=f&2016;a5=bl&2016;if((a3&65535)>(a5&65535)){bm=(a3-a5&65535)+r&65535}else{bm=r}r=f&31;f=bl&31;if((r&65535)>(f&65535)){bn=(r-f&65535)+bm&65535}else{bn=bm}f=j+7|0;b[(c[277218]|0)+(f<<1)>>1]=bn;b[(c[277218]|0)+(a4<<1)>>1]=bn;r=a[1108909]|0;a[(c[277219]|0)+f|0]=r;a[(c[277219]|0)+a4|0]=r}}while(0);a4=a9-1&255;if(a4<<24>>24!=0){a7=a4;u=2534}}if((u|0)==2534){u=0;a4=j+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+a4|0]|0)){r=a[aD+4|0]|0;if(r<<24>>24==0){break}f=b[(c[277225]|0)+((r&255)<<1)>>1]|0;if((a[(c[277215]|0)+a4|0]&32)==0){bo=c[277228]&65535}else{bo=b[(c[277213]|0)+(a4<<1)>>1]|0}r=f&-2048;a5=bo&-2048;a3=(r&65535)>(a5&65535)?r-a5&65535:0;a5=f&2016;r=bo&2016;if((a5&65535)>(r&65535)){bp=(a5-r&65535)+a3&65535}else{bp=a3}a3=f&31;f=bo&31;if((a3&65535)>(f&65535)){bq=(a3-f&65535)+bp&65535}else{bq=bp}f=j+9|0;b[(c[277218]|0)+(f<<1)>>1]=bq;b[(c[277218]|0)+(a4<<1)>>1]=bq;a3=a[1108909]|0;a[(c[277219]|0)+f|0]=a3;a[(c[277219]|0)+a4|0]=a3}}while(0);a4=a7-1&255;if(a4<<24>>24!=0){a8=a4;u=2545}}if((u|0)==2545){u=0;a4=j+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+a4|0]|0)){a3=a[aD+5|0]|0;if(a3<<24>>24==0){break}f=b[(c[277225]|0)+((a3&255)<<1)>>1]|0;if((a[(c[277215]|0)+a4|0]&32)==0){br=c[277228]&65535}else{br=b[(c[277213]|0)+(a4<<1)>>1]|0}a3=f&-2048;r=br&-2048;a5=(a3&65535)>(r&65535)?a3-r&65535:0;r=f&2016;a3=br&2016;if((r&65535)>(a3&65535)){bs=(r-a3&65535)+a5&65535}else{bs=a5}a5=f&31;f=br&31;if((a5&65535)>(f&65535)){bt=(a5-f&65535)+bs&65535}else{bt=bs}f=j+11|0;b[(c[277218]|0)+(f<<1)>>1]=bt;b[(c[277218]|0)+(a4<<1)>>1]=bt;a5=a[1108909]|0;a[(c[277219]|0)+f|0]=a5;a[(c[277219]|0)+a4|0]=a5}}while(0);a4=a8-1&255;if(a4<<24>>24!=0){be=a4;u=2556}}if((u|0)==2556){u=0;a4=j+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+a4|0]|0)){a5=a[aD+6|0]|0;if(a5<<24>>24==0){break}f=b[(c[277225]|0)+((a5&255)<<1)>>1]|0;if((a[(c[277215]|0)+a4|0]&32)==0){bu=c[277228]&65535}else{bu=b[(c[277213]|0)+(a4<<1)>>1]|0}a5=f&-2048;a3=bu&-2048;r=(a5&65535)>(a3&65535)?a5-a3&65535:0;a3=f&2016;a5=bu&2016;if((a3&65535)>(a5&65535)){bv=(a3-a5&65535)+r&65535}else{bv=r}r=f&31;f=bu&31;if((r&65535)>(f&65535)){bw=(r-f&65535)+bv&65535}else{bw=bv}f=j+13|0;b[(c[277218]|0)+(f<<1)>>1]=bw;b[(c[277218]|0)+(a4<<1)>>1]=bw;r=a[1108909]|0;a[(c[277219]|0)+f|0]=r;a[(c[277219]|0)+a4|0]=r}}while(0);if(be<<24>>24!=1){u=2567}}do{if((u|0)==2567){u=0;a4=j+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+a4|0]|0)){break}r=a[aD+7|0]|0;if(r<<24>>24==0){break}f=b[(c[277225]|0)+((r&255)<<1)>>1]|0;if((a[(c[277215]|0)+a4|0]&32)==0){bx=c[277228]&65535}else{bx=b[(c[277213]|0)+(a4<<1)>>1]|0}r=f&-2048;a5=bx&-2048;a3=(r&65535)>(a5&65535)?r-a5&65535:0;a5=f&2016;r=bx&2016;if((a5&65535)>(r&65535)){by=(a5-r&65535)+a3&65535}else{by=a3}a3=f&31;f=bx&31;if((a3&65535)>(f&65535)){bz=(a3-f&65535)+by&65535}else{bz=by}f=j+15|0;b[(c[277218]|0)+(f<<1)>>1]=bz;b[(c[277218]|0)+(a4<<1)>>1]=bz;a3=a[1108909]|0;a[(c[277219]|0)+f|0]=a3;a[(c[277219]|0)+a4|0]=a3}}while(0);a3=_-1|0;if((a3|0)>0){aD=aD-16|0;_=a3;j=(c[277223]|0)+j|0}else{break}}return}}function Vk(e,f,g,h,i,j){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0;k=e&1023;l=c[348606]|0;m=(k<<l)+(c[348604]|0)|0;if((e&256|0)==0){n=m}else{n=(c[348602]|0)+m|0}m=n&65535;n=m>>>(l>>>0);l=(e&16384|0)!=0;o=n<<6;do{if(l){p=(c[348622]|0)+o|0;if((a[(c[348618]|0)+n|0]|0)!=0){q=p;break}r=fi[c[348636]&63](p,m,k)|0;a[(c[348618]|0)+n|0]=r;q=p}else{p=(c[348624]|0)+o|0;if((a[(c[348620]|0)+n|0]|0)!=0){q=p;break}r=fi[c[348638]&63](p,m,k)|0;a[(c[348620]|0)+n|0]=r;q=p}}while(0);if((a[(c[348620]|0)+n|0]|0)==2){return}if((a[1394464]|0)==0){s=1106168+((e>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){n=d[1044485]|0;c[276541]=7080+(n<<5);k=0;do{m=k<<1&2;o=k&2;p=k&4;r=0;do{b[1125528+(k<<9)+(r<<1)>>1]=d[(r>>>1&28|o)+(7080+(n<<5))|0]<<6|d[(r<<2&28|m)+(7080+(n<<5))|0]<<11|d[(r>>>3&24|p)+(7080+(n<<5))|0];r=r+1|0;}while(r>>>0<256);k=k+1|0;}while(k>>>0<8);a[1106089]=0}s=1125528+((e>>>10&7)<<9)|0}c[277226]=s;c[277225]=(a[1108928]|0)!=0?1393712:s;if((e&49152|0)==0){if((j|0)<=0){return}s=h&255;k=s-1&255;n=k<<24>>24==0;r=q+((d[1394504]|0)+(i<<1))|0;p=j;m=f;while(1){switch(g|0){case 2:{t=s;u=2718;break};case 3:{v=s;u=2728;break};case 7:{u=2768;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+m|0]|0)){o=a[r]|0;if(o<<24>>24==0){break}w=b[(c[277225]|0)+((o&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){x=b[(c[277221]|0)+(((w&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{o=c[277228]&65535;y=w&-2048;z=o&-2048;A=(y&65535)>(z&65535)?y-z&65535:0;z=w&2016;y=o&2016;if((z&65535)>(y&65535)){B=(z-y&65535)+A&65535}else{B=A}A=w&31;y=o&31;if((A&65535)<=(y&65535)){x=B;break}x=(A-y&65535)+B&65535}}while(0);w=m+1|0;b[(c[277218]|0)+(w<<1)>>1]=x;b[(c[277218]|0)+(m<<1)>>1]=x;y=a[1108909]|0;a[(c[277219]|0)+w|0]=y;a[(c[277219]|0)+m|0]=y}}while(0);if(!n){C=k;u=2708}break};case 4:{D=s;u=2738;break};case 1:{C=s;u=2708;break};case 5:{E=s;u=2748;break};case 6:{F=s;u=2758;break};default:{}}if((u|0)==2708){u=0;y=m+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+y|0]|0)){w=a[r+1|0]|0;if(w<<24>>24==0){break}A=b[(c[277225]|0)+((w&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){G=b[(c[277221]|0)+(((A&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{w=c[277228]&65535;o=A&-2048;z=w&-2048;H=(o&65535)>(z&65535)?o-z&65535:0;z=A&2016;o=w&2016;if((z&65535)>(o&65535)){I=(z-o&65535)+H&65535}else{I=H}H=A&31;o=w&31;if((H&65535)<=(o&65535)){G=I;break}G=(H-o&65535)+I&65535}}while(0);A=m+3|0;b[(c[277218]|0)+(A<<1)>>1]=G;b[(c[277218]|0)+(y<<1)>>1]=G;o=a[1108909]|0;a[(c[277219]|0)+A|0]=o;a[(c[277219]|0)+y|0]=o}}while(0);y=C-1&255;if(y<<24>>24!=0){t=y;u=2718}}if((u|0)==2718){u=0;y=m+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+y|0]|0)){o=a[r+2|0]|0;if(o<<24>>24==0){break}A=b[(c[277225]|0)+((o&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){J=b[(c[277221]|0)+(((A&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{o=c[277228]&65535;H=A&-2048;w=o&-2048;z=(H&65535)>(w&65535)?H-w&65535:0;w=A&2016;H=o&2016;if((w&65535)>(H&65535)){K=(w-H&65535)+z&65535}else{K=z}z=A&31;H=o&31;if((z&65535)<=(H&65535)){J=K;break}J=(z-H&65535)+K&65535}}while(0);A=m+5|0;b[(c[277218]|0)+(A<<1)>>1]=J;b[(c[277218]|0)+(y<<1)>>1]=J;H=a[1108909]|0;a[(c[277219]|0)+A|0]=H;a[(c[277219]|0)+y|0]=H}}while(0);y=t-1&255;if(y<<24>>24!=0){v=y;u=2728}}if((u|0)==2728){u=0;y=m+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+y|0]|0)){H=a[r+3|0]|0;if(H<<24>>24==0){break}A=b[(c[277225]|0)+((H&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){L=b[(c[277221]|0)+(((A&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{H=c[277228]&65535;z=A&-2048;o=H&-2048;w=(z&65535)>(o&65535)?z-o&65535:0;o=A&2016;z=H&2016;if((o&65535)>(z&65535)){M=(o-z&65535)+w&65535}else{M=w}w=A&31;z=H&31;if((w&65535)<=(z&65535)){L=M;break}L=(w-z&65535)+M&65535}}while(0);A=m+7|0;b[(c[277218]|0)+(A<<1)>>1]=L;b[(c[277218]|0)+(y<<1)>>1]=L;z=a[1108909]|0;a[(c[277219]|0)+A|0]=z;a[(c[277219]|0)+y|0]=z}}while(0);y=v-1&255;if(y<<24>>24!=0){D=y;u=2738}}if((u|0)==2738){u=0;y=m+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+y|0]|0)){z=a[r+4|0]|0;if(z<<24>>24==0){break}A=b[(c[277225]|0)+((z&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){N=b[(c[277221]|0)+(((A&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{z=c[277228]&65535;w=A&-2048;H=z&-2048;o=(w&65535)>(H&65535)?w-H&65535:0;H=A&2016;w=z&2016;if((H&65535)>(w&65535)){O=(H-w&65535)+o&65535}else{O=o}o=A&31;w=z&31;if((o&65535)<=(w&65535)){N=O;break}N=(o-w&65535)+O&65535}}while(0);A=m+9|0;b[(c[277218]|0)+(A<<1)>>1]=N;b[(c[277218]|0)+(y<<1)>>1]=N;w=a[1108909]|0;a[(c[277219]|0)+A|0]=w;a[(c[277219]|0)+y|0]=w}}while(0);y=D-1&255;if(y<<24>>24!=0){E=y;u=2748}}if((u|0)==2748){u=0;y=m+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+y|0]|0)){w=a[r+5|0]|0;if(w<<24>>24==0){break}A=b[(c[277225]|0)+((w&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){P=b[(c[277221]|0)+(((A&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{w=c[277228]&65535;o=A&-2048;z=w&-2048;H=(o&65535)>(z&65535)?o-z&65535:0;z=A&2016;o=w&2016;if((z&65535)>(o&65535)){Q=(z-o&65535)+H&65535}else{Q=H}H=A&31;o=w&31;if((H&65535)<=(o&65535)){P=Q;break}P=(H-o&65535)+Q&65535}}while(0);A=m+11|0;b[(c[277218]|0)+(A<<1)>>1]=P;b[(c[277218]|0)+(y<<1)>>1]=P;o=a[1108909]|0;a[(c[277219]|0)+A|0]=o;a[(c[277219]|0)+y|0]=o}}while(0);y=E-1&255;if(y<<24>>24!=0){F=y;u=2758}}if((u|0)==2758){u=0;y=m+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+y|0]|0)){o=a[r+6|0]|0;if(o<<24>>24==0){break}A=b[(c[277225]|0)+((o&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){R=b[(c[277221]|0)+(((A&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{o=c[277228]&65535;H=A&-2048;w=o&-2048;z=(H&65535)>(w&65535)?H-w&65535:0;w=A&2016;H=o&2016;if((w&65535)>(H&65535)){S=(w-H&65535)+z&65535}else{S=z}z=A&31;H=o&31;if((z&65535)<=(H&65535)){R=S;break}R=(z-H&65535)+S&65535}}while(0);A=m+13|0;b[(c[277218]|0)+(A<<1)>>1]=R;b[(c[277218]|0)+(y<<1)>>1]=R;H=a[1108909]|0;a[(c[277219]|0)+A|0]=H;a[(c[277219]|0)+y|0]=H}}while(0);if(F<<24>>24!=1){u=2768}}do{if((u|0)==2768){u=0;y=m+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+y|0]|0)){break}H=a[r+7|0]|0;if(H<<24>>24==0){break}A=b[(c[277225]|0)+((H&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){T=b[(c[277221]|0)+(((A&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{H=c[277228]&65535;z=A&-2048;o=H&-2048;w=(z&65535)>(o&65535)?z-o&65535:0;o=A&2016;z=H&2016;if((o&65535)>(z&65535)){U=(o-z&65535)+w&65535}else{U=w}w=A&31;z=H&31;if((w&65535)<=(z&65535)){T=U;break}T=(w-z&65535)+U&65535}}while(0);A=m+15|0;b[(c[277218]|0)+(A<<1)>>1]=T;b[(c[277218]|0)+(y<<1)>>1]=T;z=a[1108909]|0;a[(c[277219]|0)+A|0]=z;a[(c[277219]|0)+y|0]=z}}while(0);z=p-1|0;if((z|0)>0){r=r+16|0;p=z;m=(c[277223]|0)+m|0}else{break}}return}m=(d[1394504]|0)+(i<<1)|0;if((e&32768|0)==0){if((j|0)<=0){return}e=h&255;i=e-1&255;p=i<<24>>24==0;r=q+m|0;T=j;U=f;while(1){switch(g|0){case 1:{V=e;u=2792;break};case 2:{W=e;u=2802;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+U|0]|0)){F=a[r+7|0]|0;if(F<<24>>24==0){break}R=b[(c[277225]|0)+((F&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){X=b[(c[277221]|0)+(((R&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{F=c[277228]&65535;S=R&-2048;E=F&-2048;P=(S&65535)>(E&65535)?S-E&65535:0;E=R&2016;S=F&2016;if((E&65535)>(S&65535)){Y=(E-S&65535)+P&65535}else{Y=P}P=R&31;S=F&31;if((P&65535)<=(S&65535)){X=Y;break}X=(P-S&65535)+Y&65535}}while(0);R=U+1|0;b[(c[277218]|0)+(R<<1)>>1]=X;b[(c[277218]|0)+(U<<1)>>1]=X;y=a[1108909]|0;a[(c[277219]|0)+R|0]=y;a[(c[277219]|0)+U|0]=y}}while(0);if(!p){V=i;u=2792}break};case 3:{Z=e;u=2812;break};case 4:{_=e;u=2822;break};case 5:{$=e;u=2832;break};case 7:{u=2852;break};case 6:{aa=e;u=2842;break};default:{}}if((u|0)==2792){u=0;y=U+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+y|0]|0)){R=a[r+6|0]|0;if(R<<24>>24==0){break}S=b[(c[277225]|0)+((R&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){ab=b[(c[277221]|0)+(((S&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{R=c[277228]&65535;P=S&-2048;F=R&-2048;E=(P&65535)>(F&65535)?P-F&65535:0;F=S&2016;P=R&2016;if((F&65535)>(P&65535)){ac=(F-P&65535)+E&65535}else{ac=E}E=S&31;P=R&31;if((E&65535)<=(P&65535)){ab=ac;break}ab=(E-P&65535)+ac&65535}}while(0);S=U+3|0;b[(c[277218]|0)+(S<<1)>>1]=ab;b[(c[277218]|0)+(y<<1)>>1]=ab;P=a[1108909]|0;a[(c[277219]|0)+S|0]=P;a[(c[277219]|0)+y|0]=P}}while(0);y=V-1&255;if(y<<24>>24!=0){W=y;u=2802}}if((u|0)==2802){u=0;y=U+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+y|0]|0)){P=a[r+5|0]|0;if(P<<24>>24==0){break}S=b[(c[277225]|0)+((P&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){ad=b[(c[277221]|0)+(((S&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{P=c[277228]&65535;E=S&-2048;R=P&-2048;F=(E&65535)>(R&65535)?E-R&65535:0;R=S&2016;E=P&2016;if((R&65535)>(E&65535)){ae=(R-E&65535)+F&65535}else{ae=F}F=S&31;E=P&31;if((F&65535)<=(E&65535)){ad=ae;break}ad=(F-E&65535)+ae&65535}}while(0);S=U+5|0;b[(c[277218]|0)+(S<<1)>>1]=ad;b[(c[277218]|0)+(y<<1)>>1]=ad;E=a[1108909]|0;a[(c[277219]|0)+S|0]=E;a[(c[277219]|0)+y|0]=E}}while(0);y=W-1&255;if(y<<24>>24!=0){Z=y;u=2812}}if((u|0)==2812){u=0;y=U+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+y|0]|0)){E=a[r+4|0]|0;if(E<<24>>24==0){break}S=b[(c[277225]|0)+((E&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){af=b[(c[277221]|0)+(((S&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{E=c[277228]&65535;F=S&-2048;P=E&-2048;R=(F&65535)>(P&65535)?F-P&65535:0;P=S&2016;F=E&2016;if((P&65535)>(F&65535)){ag=(P-F&65535)+R&65535}else{ag=R}R=S&31;F=E&31;if((R&65535)<=(F&65535)){af=ag;break}af=(R-F&65535)+ag&65535}}while(0);S=U+7|0;b[(c[277218]|0)+(S<<1)>>1]=af;b[(c[277218]|0)+(y<<1)>>1]=af;F=a[1108909]|0;a[(c[277219]|0)+S|0]=F;a[(c[277219]|0)+y|0]=F}}while(0);y=Z-1&255;if(y<<24>>24!=0){_=y;u=2822}}if((u|0)==2822){u=0;y=U+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+y|0]|0)){F=a[r+3|0]|0;if(F<<24>>24==0){break}S=b[(c[277225]|0)+((F&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){ah=b[(c[277221]|0)+(((S&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{F=c[277228]&65535;R=S&-2048;E=F&-2048;P=(R&65535)>(E&65535)?R-E&65535:0;E=S&2016;R=F&2016;if((E&65535)>(R&65535)){ai=(E-R&65535)+P&65535}else{ai=P}P=S&31;R=F&31;if((P&65535)<=(R&65535)){ah=ai;break}ah=(P-R&65535)+ai&65535}}while(0);S=U+9|0;b[(c[277218]|0)+(S<<1)>>1]=ah;b[(c[277218]|0)+(y<<1)>>1]=ah;R=a[1108909]|0;a[(c[277219]|0)+S|0]=R;a[(c[277219]|0)+y|0]=R}}while(0);y=_-1&255;if(y<<24>>24!=0){$=y;u=2832}}if((u|0)==2832){u=0;y=U+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+y|0]|0)){R=a[r+2|0]|0;if(R<<24>>24==0){break}S=b[(c[277225]|0)+((R&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aj=b[(c[277221]|0)+(((S&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{R=c[277228]&65535;P=S&-2048;F=R&-2048;E=(P&65535)>(F&65535)?P-F&65535:0;F=S&2016;P=R&2016;if((F&65535)>(P&65535)){ak=(F-P&65535)+E&65535}else{ak=E}E=S&31;P=R&31;if((E&65535)<=(P&65535)){aj=ak;break}aj=(E-P&65535)+ak&65535}}while(0);S=U+11|0;b[(c[277218]|0)+(S<<1)>>1]=aj;b[(c[277218]|0)+(y<<1)>>1]=aj;P=a[1108909]|0;a[(c[277219]|0)+S|0]=P;a[(c[277219]|0)+y|0]=P}}while(0);y=$-1&255;if(y<<24>>24!=0){aa=y;u=2842}}if((u|0)==2842){u=0;y=U+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+y|0]|0)){P=a[r+1|0]|0;if(P<<24>>24==0){break}S=b[(c[277225]|0)+((P&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){al=b[(c[277221]|0)+(((S&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{P=c[277228]&65535;E=S&-2048;R=P&-2048;F=(E&65535)>(R&65535)?E-R&65535:0;R=S&2016;E=P&2016;if((R&65535)>(E&65535)){am=(R-E&65535)+F&65535}else{am=F}F=S&31;E=P&31;if((F&65535)<=(E&65535)){al=am;break}al=(F-E&65535)+am&65535}}while(0);S=U+13|0;b[(c[277218]|0)+(S<<1)>>1]=al;b[(c[277218]|0)+(y<<1)>>1]=al;E=a[1108909]|0;a[(c[277219]|0)+S|0]=E;a[(c[277219]|0)+y|0]=E}}while(0);if(aa<<24>>24!=1){u=2852}}do{if((u|0)==2852){u=0;y=U+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+y|0]|0)){break}E=a[r]|0;if(E<<24>>24==0){break}S=b[(c[277225]|0)+((E&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){an=b[(c[277221]|0)+(((S&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{E=c[277228]&65535;F=S&-2048;P=E&-2048;R=(F&65535)>(P&65535)?F-P&65535:0;P=S&2016;F=E&2016;if((P&65535)>(F&65535)){ao=(P-F&65535)+R&65535}else{ao=R}R=S&31;F=E&31;if((R&65535)<=(F&65535)){an=ao;break}an=(R-F&65535)+ao&65535}}while(0);S=U+15|0;b[(c[277218]|0)+(S<<1)>>1]=an;b[(c[277218]|0)+(y<<1)>>1]=an;F=a[1108909]|0;a[(c[277219]|0)+S|0]=F;a[(c[277219]|0)+y|0]=F}}while(0);F=T-1|0;if((F|0)>0){r=r+16|0;T=F;U=(c[277223]|0)+U|0}else{break}}return}U=q+(56-m)|0;m=(j|0)>0;if(l){if(!m){return}l=h&255;q=l-1&255;T=q<<24>>24==0;r=U;an=j;ao=f;while(1){switch(g|0){case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+ao|0]|0)){aa=a[r+7|0]|0;if(aa<<24>>24==0){break}al=b[(c[277225]|0)+((aa&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){ap=b[(c[277221]|0)+(((al&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{aa=c[277228]&65535;am=al&-2048;$=aa&-2048;aj=(am&65535)>($&65535)?am-$&65535:0;$=al&2016;am=aa&2016;if(($&65535)>(am&65535)){aq=($-am&65535)+aj&65535}else{aq=aj}aj=al&31;am=aa&31;if((aj&65535)<=(am&65535)){ap=aq;break}ap=(aj-am&65535)+aq&65535}}while(0);al=ao+1|0;b[(c[277218]|0)+(al<<1)>>1]=ap;b[(c[277218]|0)+(ao<<1)>>1]=ap;y=a[1108909]|0;a[(c[277219]|0)+al|0]=y;a[(c[277219]|0)+ao|0]=y}}while(0);if(!T){ar=q;u=2959}break};case 1:{ar=l;u=2959;break};case 2:{as=l;u=2969;break};case 3:{at=l;u=2979;break};case 4:{au=l;u=2989;break};case 5:{av=l;u=2999;break};case 6:{aw=l;u=3009;break};case 7:{u=3019;break};default:{}}if((u|0)==2959){u=0;y=ao+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+y|0]|0)){al=a[r+6|0]|0;if(al<<24>>24==0){break}am=b[(c[277225]|0)+((al&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){ax=b[(c[277221]|0)+(((am&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{al=c[277228]&65535;aj=am&-2048;aa=al&-2048;$=(aj&65535)>(aa&65535)?aj-aa&65535:0;aa=am&2016;aj=al&2016;if((aa&65535)>(aj&65535)){ay=(aa-aj&65535)+$&65535}else{ay=$}$=am&31;aj=al&31;if(($&65535)<=(aj&65535)){ax=ay;break}ax=($-aj&65535)+ay&65535}}while(0);am=ao+3|0;b[(c[277218]|0)+(am<<1)>>1]=ax;b[(c[277218]|0)+(y<<1)>>1]=ax;aj=a[1108909]|0;a[(c[277219]|0)+am|0]=aj;a[(c[277219]|0)+y|0]=aj}}while(0);y=ar-1&255;if(y<<24>>24!=0){as=y;u=2969}}if((u|0)==2969){u=0;y=ao+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+y|0]|0)){aj=a[r+5|0]|0;if(aj<<24>>24==0){break}am=b[(c[277225]|0)+((aj&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){az=b[(c[277221]|0)+(((am&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{aj=c[277228]&65535;$=am&-2048;al=aj&-2048;aa=($&65535)>(al&65535)?$-al&65535:0;al=am&2016;$=aj&2016;if((al&65535)>($&65535)){aA=(al-$&65535)+aa&65535}else{aA=aa}aa=am&31;$=aj&31;if((aa&65535)<=($&65535)){az=aA;break}az=(aa-$&65535)+aA&65535}}while(0);am=ao+5|0;b[(c[277218]|0)+(am<<1)>>1]=az;b[(c[277218]|0)+(y<<1)>>1]=az;$=a[1108909]|0;a[(c[277219]|0)+am|0]=$;a[(c[277219]|0)+y|0]=$}}while(0);y=as-1&255;if(y<<24>>24!=0){at=y;u=2979}}if((u|0)==2979){u=0;y=ao+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+y|0]|0)){$=a[r+4|0]|0;if($<<24>>24==0){break}am=b[(c[277225]|0)+(($&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aB=b[(c[277221]|0)+(((am&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{$=c[277228]&65535;aa=am&-2048;aj=$&-2048;al=(aa&65535)>(aj&65535)?aa-aj&65535:0;aj=am&2016;aa=$&2016;if((aj&65535)>(aa&65535)){aC=(aj-aa&65535)+al&65535}else{aC=al}al=am&31;aa=$&31;if((al&65535)<=(aa&65535)){aB=aC;break}aB=(al-aa&65535)+aC&65535}}while(0);am=ao+7|0;b[(c[277218]|0)+(am<<1)>>1]=aB;b[(c[277218]|0)+(y<<1)>>1]=aB;aa=a[1108909]|0;a[(c[277219]|0)+am|0]=aa;a[(c[277219]|0)+y|0]=aa}}while(0);y=at-1&255;if(y<<24>>24!=0){au=y;u=2989}}if((u|0)==2989){u=0;y=ao+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+y|0]|0)){aa=a[r+3|0]|0;if(aa<<24>>24==0){break}am=b[(c[277225]|0)+((aa&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aD=b[(c[277221]|0)+(((am&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{aa=c[277228]&65535;al=am&-2048;$=aa&-2048;aj=(al&65535)>($&65535)?al-$&65535:0;$=am&2016;al=aa&2016;if(($&65535)>(al&65535)){aE=($-al&65535)+aj&65535}else{aE=aj}aj=am&31;al=aa&31;if((aj&65535)<=(al&65535)){aD=aE;break}aD=(aj-al&65535)+aE&65535}}while(0);am=ao+9|0;b[(c[277218]|0)+(am<<1)>>1]=aD;b[(c[277218]|0)+(y<<1)>>1]=aD;al=a[1108909]|0;a[(c[277219]|0)+am|0]=al;a[(c[277219]|0)+y|0]=al}}while(0);y=au-1&255;if(y<<24>>24!=0){av=y;u=2999}}if((u|0)==2999){u=0;y=ao+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+y|0]|0)){al=a[r+2|0]|0;if(al<<24>>24==0){break}am=b[(c[277225]|0)+((al&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aF=b[(c[277221]|0)+(((am&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{al=c[277228]&65535;aj=am&-2048;aa=al&-2048;$=(aj&65535)>(aa&65535)?aj-aa&65535:0;aa=am&2016;aj=al&2016;if((aa&65535)>(aj&65535)){aG=(aa-aj&65535)+$&65535}else{aG=$}$=am&31;aj=al&31;if(($&65535)<=(aj&65535)){aF=aG;break}aF=($-aj&65535)+aG&65535}}while(0);am=ao+11|0;b[(c[277218]|0)+(am<<1)>>1]=aF;b[(c[277218]|0)+(y<<1)>>1]=aF;aj=a[1108909]|0;a[(c[277219]|0)+am|0]=aj;a[(c[277219]|0)+y|0]=aj}}while(0);y=av-1&255;if(y<<24>>24!=0){aw=y;u=3009}}if((u|0)==3009){u=0;y=ao+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+y|0]|0)){aj=a[r+1|0]|0;if(aj<<24>>24==0){break}am=b[(c[277225]|0)+((aj&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aH=b[(c[277221]|0)+(((am&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{aj=c[277228]&65535;$=am&-2048;al=aj&-2048;aa=($&65535)>(al&65535)?$-al&65535:0;al=am&2016;$=aj&2016;if((al&65535)>($&65535)){aI=(al-$&65535)+aa&65535}else{aI=aa}aa=am&31;$=aj&31;if((aa&65535)<=($&65535)){aH=aI;break}aH=(aa-$&65535)+aI&65535}}while(0);am=ao+13|0;b[(c[277218]|0)+(am<<1)>>1]=aH;b[(c[277218]|0)+(y<<1)>>1]=aH;$=a[1108909]|0;a[(c[277219]|0)+am|0]=$;a[(c[277219]|0)+y|0]=$}}while(0);if(aw<<24>>24!=1){u=3019}}do{if((u|0)==3019){u=0;y=ao+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+y|0]|0)){break}$=a[r]|0;if($<<24>>24==0){break}am=b[(c[277225]|0)+(($&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aJ=b[(c[277221]|0)+(((am&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{$=c[277228]&65535;aa=am&-2048;aj=$&-2048;al=(aa&65535)>(aj&65535)?aa-aj&65535:0;aj=am&2016;aa=$&2016;if((aj&65535)>(aa&65535)){aK=(aj-aa&65535)+al&65535}else{aK=al}al=am&31;aa=$&31;if((al&65535)<=(aa&65535)){aJ=aK;break}aJ=(al-aa&65535)+aK&65535}}while(0);am=ao+15|0;b[(c[277218]|0)+(am<<1)>>1]=aJ;b[(c[277218]|0)+(y<<1)>>1]=aJ;aa=a[1108909]|0;a[(c[277219]|0)+am|0]=aa;a[(c[277219]|0)+y|0]=aa}}while(0);aa=an-1|0;if((aa|0)>0){r=r-16|0;an=aa;ao=(c[277223]|0)+ao|0}else{break}}return}else{if(!m){return}m=h&255;h=m-1&255;ao=h<<24>>24==0;an=U;U=j;j=f;while(1){switch(g|0){case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+j|0]|0)){f=a[an]|0;if(f<<24>>24==0){break}r=b[(c[277225]|0)+((f&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aL=b[(c[277221]|0)+(((r&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{f=c[277228]&65535;aJ=r&-2048;aK=f&-2048;aw=(aJ&65535)>(aK&65535)?aJ-aK&65535:0;aK=r&2016;aJ=f&2016;if((aK&65535)>(aJ&65535)){aM=(aK-aJ&65535)+aw&65535}else{aM=aw}aw=r&31;aJ=f&31;if((aw&65535)<=(aJ&65535)){aL=aM;break}aL=(aw-aJ&65535)+aM&65535}}while(0);r=j+1|0;b[(c[277218]|0)+(r<<1)>>1]=aL;b[(c[277218]|0)+(j<<1)>>1]=aL;y=a[1108909]|0;a[(c[277219]|0)+r|0]=y;a[(c[277219]|0)+j|0]=y}}while(0);if(!ao){aN=h;u=2878}break};case 1:{aN=m;u=2878;break};case 7:{u=2938;break};case 5:{aO=m;u=2918;break};case 6:{aP=m;u=2928;break};case 2:{aQ=m;u=2888;break};case 3:{aR=m;u=2898;break};case 4:{aS=m;u=2908;break};default:{}}if((u|0)==2878){u=0;y=j+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+y|0]|0)){r=a[an+1|0]|0;if(r<<24>>24==0){break}aJ=b[(c[277225]|0)+((r&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aT=b[(c[277221]|0)+(((aJ&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{r=c[277228]&65535;aw=aJ&-2048;f=r&-2048;aK=(aw&65535)>(f&65535)?aw-f&65535:0;f=aJ&2016;aw=r&2016;if((f&65535)>(aw&65535)){aU=(f-aw&65535)+aK&65535}else{aU=aK}aK=aJ&31;aw=r&31;if((aK&65535)<=(aw&65535)){aT=aU;break}aT=(aK-aw&65535)+aU&65535}}while(0);aJ=j+3|0;b[(c[277218]|0)+(aJ<<1)>>1]=aT;b[(c[277218]|0)+(y<<1)>>1]=aT;aw=a[1108909]|0;a[(c[277219]|0)+aJ|0]=aw;a[(c[277219]|0)+y|0]=aw}}while(0);y=aN-1&255;if(y<<24>>24!=0){aQ=y;u=2888}}if((u|0)==2888){u=0;y=j+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+y|0]|0)){aw=a[an+2|0]|0;if(aw<<24>>24==0){break}aJ=b[(c[277225]|0)+((aw&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aV=b[(c[277221]|0)+(((aJ&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{aw=c[277228]&65535;aK=aJ&-2048;r=aw&-2048;f=(aK&65535)>(r&65535)?aK-r&65535:0;r=aJ&2016;aK=aw&2016;if((r&65535)>(aK&65535)){aW=(r-aK&65535)+f&65535}else{aW=f}f=aJ&31;aK=aw&31;if((f&65535)<=(aK&65535)){aV=aW;break}aV=(f-aK&65535)+aW&65535}}while(0);aJ=j+5|0;b[(c[277218]|0)+(aJ<<1)>>1]=aV;b[(c[277218]|0)+(y<<1)>>1]=aV;aK=a[1108909]|0;a[(c[277219]|0)+aJ|0]=aK;a[(c[277219]|0)+y|0]=aK}}while(0);y=aQ-1&255;if(y<<24>>24!=0){aR=y;u=2898}}if((u|0)==2898){u=0;y=j+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+y|0]|0)){aK=a[an+3|0]|0;if(aK<<24>>24==0){break}aJ=b[(c[277225]|0)+((aK&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aX=b[(c[277221]|0)+(((aJ&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{aK=c[277228]&65535;f=aJ&-2048;aw=aK&-2048;r=(f&65535)>(aw&65535)?f-aw&65535:0;aw=aJ&2016;f=aK&2016;if((aw&65535)>(f&65535)){aY=(aw-f&65535)+r&65535}else{aY=r}r=aJ&31;f=aK&31;if((r&65535)<=(f&65535)){aX=aY;break}aX=(r-f&65535)+aY&65535}}while(0);aJ=j+7|0;b[(c[277218]|0)+(aJ<<1)>>1]=aX;b[(c[277218]|0)+(y<<1)>>1]=aX;f=a[1108909]|0;a[(c[277219]|0)+aJ|0]=f;a[(c[277219]|0)+y|0]=f}}while(0);y=aR-1&255;if(y<<24>>24!=0){aS=y;u=2908}}if((u|0)==2908){u=0;y=j+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+y|0]|0)){f=a[an+4|0]|0;if(f<<24>>24==0){break}aJ=b[(c[277225]|0)+((f&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aZ=b[(c[277221]|0)+(((aJ&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{f=c[277228]&65535;r=aJ&-2048;aK=f&-2048;aw=(r&65535)>(aK&65535)?r-aK&65535:0;aK=aJ&2016;r=f&2016;if((aK&65535)>(r&65535)){a_=(aK-r&65535)+aw&65535}else{a_=aw}aw=aJ&31;r=f&31;if((aw&65535)<=(r&65535)){aZ=a_;break}aZ=(aw-r&65535)+a_&65535}}while(0);aJ=j+9|0;b[(c[277218]|0)+(aJ<<1)>>1]=aZ;b[(c[277218]|0)+(y<<1)>>1]=aZ;r=a[1108909]|0;a[(c[277219]|0)+aJ|0]=r;a[(c[277219]|0)+y|0]=r}}while(0);y=aS-1&255;if(y<<24>>24!=0){aO=y;u=2918}}if((u|0)==2918){u=0;y=j+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+y|0]|0)){r=a[an+5|0]|0;if(r<<24>>24==0){break}aJ=b[(c[277225]|0)+((r&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){a$=b[(c[277221]|0)+(((aJ&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{r=c[277228]&65535;aw=aJ&-2048;f=r&-2048;aK=(aw&65535)>(f&65535)?aw-f&65535:0;f=aJ&2016;aw=r&2016;if((f&65535)>(aw&65535)){a0=(f-aw&65535)+aK&65535}else{a0=aK}aK=aJ&31;aw=r&31;if((aK&65535)<=(aw&65535)){a$=a0;break}a$=(aK-aw&65535)+a0&65535}}while(0);aJ=j+11|0;b[(c[277218]|0)+(aJ<<1)>>1]=a$;b[(c[277218]|0)+(y<<1)>>1]=a$;aw=a[1108909]|0;a[(c[277219]|0)+aJ|0]=aw;a[(c[277219]|0)+y|0]=aw}}while(0);y=aO-1&255;if(y<<24>>24!=0){aP=y;u=2928}}if((u|0)==2928){u=0;y=j+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+y|0]|0)){aw=a[an+6|0]|0;if(aw<<24>>24==0){break}aJ=b[(c[277225]|0)+((aw&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){a1=b[(c[277221]|0)+(((aJ&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{aw=c[277228]&65535;aK=aJ&-2048;r=aw&-2048;f=(aK&65535)>(r&65535)?aK-r&65535:0;r=aJ&2016;aK=aw&2016;if((r&65535)>(aK&65535)){a2=(r-aK&65535)+f&65535}else{a2=f}f=aJ&31;aK=aw&31;if((f&65535)<=(aK&65535)){a1=a2;break}a1=(f-aK&65535)+a2&65535}}while(0);aJ=j+13|0;b[(c[277218]|0)+(aJ<<1)>>1]=a1;b[(c[277218]|0)+(y<<1)>>1]=a1;aK=a[1108909]|0;a[(c[277219]|0)+aJ|0]=aK;a[(c[277219]|0)+y|0]=aK}}while(0);if(aP<<24>>24!=1){u=2938}}do{if((u|0)==2938){u=0;y=j+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+y|0]|0)){break}aK=a[an+7|0]|0;if(aK<<24>>24==0){break}aJ=b[(c[277225]|0)+((aK&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){a3=b[(c[277221]|0)+(((aJ&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{aK=c[277228]&65535;f=aJ&-2048;aw=aK&-2048;r=(f&65535)>(aw&65535)?f-aw&65535:0;aw=aJ&2016;f=aK&2016;if((aw&65535)>(f&65535)){a4=(aw-f&65535)+r&65535}else{a4=r}r=aJ&31;f=aK&31;if((r&65535)<=(f&65535)){a3=a4;break}a3=(r-f&65535)+a4&65535}}while(0);aJ=j+15|0;b[(c[277218]|0)+(aJ<<1)>>1]=a3;b[(c[277218]|0)+(y<<1)>>1]=a3;f=a[1108909]|0;a[(c[277219]|0)+aJ|0]=f;a[(c[277219]|0)+y|0]=f}}while(0);f=U-1|0;if((f|0)>0){an=an-16|0;U=f;j=(c[277223]|0)+j|0}else{break}}return}}function Vl(e,f,g,h,i,j){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0;k=e&1023;l=c[348606]|0;m=(k<<l)+(c[348604]|0)|0;if((e&256|0)==0){n=m}else{n=(c[348602]|0)+m|0}m=n&65535;n=m>>>(l>>>0);l=(e&16384|0)!=0;o=n<<6;do{if(l){p=(c[348622]|0)+o|0;if((a[(c[348618]|0)+n|0]|0)!=0){q=p;break}r=fi[c[348636]&63](p,m,k)|0;a[(c[348618]|0)+n|0]=r;q=p}else{p=(c[348624]|0)+o|0;if((a[(c[348620]|0)+n|0]|0)!=0){q=p;break}r=fi[c[348638]&63](p,m,k)|0;a[(c[348620]|0)+n|0]=r;q=p}}while(0);if((a[(c[348620]|0)+n|0]|0)==2){return}if((a[1394464]|0)==0){s=1106168+((e>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){n=d[1044485]|0;c[276541]=7080+(n<<5);k=0;do{m=k<<1&2;o=k&2;p=k&4;r=0;do{b[1125528+(k<<9)+(r<<1)>>1]=d[(r>>>1&28|o)+(7080+(n<<5))|0]<<6|d[(r<<2&28|m)+(7080+(n<<5))|0]<<11|d[(r>>>3&24|p)+(7080+(n<<5))|0];r=r+1|0;}while(r>>>0<256);k=k+1|0;}while(k>>>0<8);a[1106089]=0}s=1125528+((e>>>10&7)<<9)|0}c[277226]=s;c[277225]=(a[1108928]|0)!=0?1393712:s;if((e&49152|0)==0){if((j|0)<=0){return}s=h&255;k=s-1&255;n=k<<24>>24==0;r=q+((d[1394504]|0)+(i<<1))|0;p=j;m=f;while(1){switch(g|0){case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+m|0]|0)){o=a[r]|0;t=o&255;if(o<<24>>24==0){break}do{if((a[1108928]|0)==0){o=b[(c[277225]|0)+(t<<1)>>1]|0;if((a[(c[277215]|0)+m|0]&32)!=0){u=b[(c[277221]|0)+((o&65535|67616)-(b[(c[277213]|0)+(m<<1)>>1]&63454)>>1<<1)>>1]|0;break}v=c[277228]&65535;w=o&-2048;x=v&-2048;y=(w&65535)>(x&65535)?w-x&65535:0;x=o&2016;w=v&2016;if((x&65535)>(w&65535)){z=(x-w&65535)+y&65535}else{z=y}y=o&31;o=v&31;if((y&65535)<=(o&65535)){u=z;break}u=(y-o&65535)+z&65535}else{o=b[(c[277225]|0)+(t<<1)>>1]|0;if((a[(c[277215]|0)+m|0]&32)==0){A=c[277228]&65535}else{A=b[(c[277213]|0)+(m<<1)>>1]|0}y=o&-2048;v=A&-2048;w=(y&65535)>(v&65535)?y-v&65535:0;v=o&2016;y=A&2016;if((v&65535)>(y&65535)){B=(v-y&65535)+w&65535}else{B=w}w=o&31;o=A&31;if((w&65535)<=(o&65535)){u=B;break}u=(w-o&65535)+B&65535}}while(0);t=m+1|0;b[(c[277218]|0)+(t<<1)>>1]=u;b[(c[277218]|0)+(m<<1)>>1]=u;o=a[1108909]|0;a[(c[277219]|0)+t|0]=o;a[(c[277219]|0)+m|0]=o}}while(0);if(!n){C=k;D=3078}break};case 1:{C=s;D=3078;break};case 2:{E=s;D=3096;break};case 3:{F=s;D=3114;break};case 4:{G=s;D=3132;break};case 5:{H=s;D=3150;break};case 6:{I=s;D=3168;break};case 7:{D=3186;break};default:{}}if((D|0)==3078){D=0;o=m+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){t=a[r+1|0]|0;w=t&255;if(t<<24>>24==0){break}do{if((a[1108928]|0)==0){t=b[(c[277225]|0)+(w<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){J=b[(c[277221]|0)+((t&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}y=c[277228]&65535;v=t&-2048;x=y&-2048;K=(v&65535)>(x&65535)?v-x&65535:0;x=t&2016;v=y&2016;if((x&65535)>(v&65535)){L=(x-v&65535)+K&65535}else{L=K}K=t&31;t=y&31;if((K&65535)<=(t&65535)){J=L;break}J=(K-t&65535)+L&65535}else{t=b[(c[277225]|0)+(w<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){M=c[277228]&65535}else{M=b[(c[277213]|0)+(o<<1)>>1]|0}K=t&-2048;y=M&-2048;v=(K&65535)>(y&65535)?K-y&65535:0;y=t&2016;K=M&2016;if((y&65535)>(K&65535)){N=(y-K&65535)+v&65535}else{N=v}v=t&31;t=M&31;if((v&65535)<=(t&65535)){J=N;break}J=(v-t&65535)+N&65535}}while(0);w=m+3|0;b[(c[277218]|0)+(w<<1)>>1]=J;b[(c[277218]|0)+(o<<1)>>1]=J;t=a[1108909]|0;a[(c[277219]|0)+w|0]=t;a[(c[277219]|0)+o|0]=t}}while(0);o=C-1&255;if(o<<24>>24!=0){E=o;D=3096}}if((D|0)==3096){D=0;o=m+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){t=a[r+2|0]|0;w=t&255;if(t<<24>>24==0){break}do{if((a[1108928]|0)==0){t=b[(c[277225]|0)+(w<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){O=b[(c[277221]|0)+((t&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}v=c[277228]&65535;K=t&-2048;y=v&-2048;x=(K&65535)>(y&65535)?K-y&65535:0;y=t&2016;K=v&2016;if((y&65535)>(K&65535)){P=(y-K&65535)+x&65535}else{P=x}x=t&31;t=v&31;if((x&65535)<=(t&65535)){O=P;break}O=(x-t&65535)+P&65535}else{t=b[(c[277225]|0)+(w<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){Q=c[277228]&65535}else{Q=b[(c[277213]|0)+(o<<1)>>1]|0}x=t&-2048;v=Q&-2048;K=(x&65535)>(v&65535)?x-v&65535:0;v=t&2016;x=Q&2016;if((v&65535)>(x&65535)){R=(v-x&65535)+K&65535}else{R=K}K=t&31;t=Q&31;if((K&65535)<=(t&65535)){O=R;break}O=(K-t&65535)+R&65535}}while(0);w=m+5|0;b[(c[277218]|0)+(w<<1)>>1]=O;b[(c[277218]|0)+(o<<1)>>1]=O;t=a[1108909]|0;a[(c[277219]|0)+w|0]=t;a[(c[277219]|0)+o|0]=t}}while(0);o=E-1&255;if(o<<24>>24!=0){F=o;D=3114}}if((D|0)==3114){D=0;o=m+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){t=a[r+3|0]|0;w=t&255;if(t<<24>>24==0){break}do{if((a[1108928]|0)==0){t=b[(c[277225]|0)+(w<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){S=b[(c[277221]|0)+((t&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}K=c[277228]&65535;x=t&-2048;v=K&-2048;y=(x&65535)>(v&65535)?x-v&65535:0;v=t&2016;x=K&2016;if((v&65535)>(x&65535)){T=(v-x&65535)+y&65535}else{T=y}y=t&31;t=K&31;if((y&65535)<=(t&65535)){S=T;break}S=(y-t&65535)+T&65535}else{t=b[(c[277225]|0)+(w<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){U=c[277228]&65535}else{U=b[(c[277213]|0)+(o<<1)>>1]|0}y=t&-2048;K=U&-2048;x=(y&65535)>(K&65535)?y-K&65535:0;K=t&2016;y=U&2016;if((K&65535)>(y&65535)){V=(K-y&65535)+x&65535}else{V=x}x=t&31;t=U&31;if((x&65535)<=(t&65535)){S=V;break}S=(x-t&65535)+V&65535}}while(0);w=m+7|0;b[(c[277218]|0)+(w<<1)>>1]=S;b[(c[277218]|0)+(o<<1)>>1]=S;t=a[1108909]|0;a[(c[277219]|0)+w|0]=t;a[(c[277219]|0)+o|0]=t}}while(0);o=F-1&255;if(o<<24>>24!=0){G=o;D=3132}}if((D|0)==3132){D=0;o=m+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){t=a[r+4|0]|0;w=t&255;if(t<<24>>24==0){break}do{if((a[1108928]|0)==0){t=b[(c[277225]|0)+(w<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){W=b[(c[277221]|0)+((t&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}x=c[277228]&65535;y=t&-2048;K=x&-2048;v=(y&65535)>(K&65535)?y-K&65535:0;K=t&2016;y=x&2016;if((K&65535)>(y&65535)){X=(K-y&65535)+v&65535}else{X=v}v=t&31;t=x&31;if((v&65535)<=(t&65535)){W=X;break}W=(v-t&65535)+X&65535}else{t=b[(c[277225]|0)+(w<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){Y=c[277228]&65535}else{Y=b[(c[277213]|0)+(o<<1)>>1]|0}v=t&-2048;x=Y&-2048;y=(v&65535)>(x&65535)?v-x&65535:0;x=t&2016;v=Y&2016;if((x&65535)>(v&65535)){Z=(x-v&65535)+y&65535}else{Z=y}y=t&31;t=Y&31;if((y&65535)<=(t&65535)){W=Z;break}W=(y-t&65535)+Z&65535}}while(0);w=m+9|0;b[(c[277218]|0)+(w<<1)>>1]=W;b[(c[277218]|0)+(o<<1)>>1]=W;t=a[1108909]|0;a[(c[277219]|0)+w|0]=t;a[(c[277219]|0)+o|0]=t}}while(0);o=G-1&255;if(o<<24>>24!=0){H=o;D=3150}}if((D|0)==3150){D=0;o=m+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){t=a[r+5|0]|0;w=t&255;if(t<<24>>24==0){break}do{if((a[1108928]|0)==0){t=b[(c[277225]|0)+(w<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){_=b[(c[277221]|0)+((t&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}y=c[277228]&65535;v=t&-2048;x=y&-2048;K=(v&65535)>(x&65535)?v-x&65535:0;x=t&2016;v=y&2016;if((x&65535)>(v&65535)){$=(x-v&65535)+K&65535}else{$=K}K=t&31;t=y&31;if((K&65535)<=(t&65535)){_=$;break}_=(K-t&65535)+$&65535}else{t=b[(c[277225]|0)+(w<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){aa=c[277228]&65535}else{aa=b[(c[277213]|0)+(o<<1)>>1]|0}K=t&-2048;y=aa&-2048;v=(K&65535)>(y&65535)?K-y&65535:0;y=t&2016;K=aa&2016;if((y&65535)>(K&65535)){ab=(y-K&65535)+v&65535}else{ab=v}v=t&31;t=aa&31;if((v&65535)<=(t&65535)){_=ab;break}_=(v-t&65535)+ab&65535}}while(0);w=m+11|0;b[(c[277218]|0)+(w<<1)>>1]=_;b[(c[277218]|0)+(o<<1)>>1]=_;t=a[1108909]|0;a[(c[277219]|0)+w|0]=t;a[(c[277219]|0)+o|0]=t}}while(0);o=H-1&255;if(o<<24>>24!=0){I=o;D=3168}}if((D|0)==3168){D=0;o=m+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){t=a[r+6|0]|0;w=t&255;if(t<<24>>24==0){break}do{if((a[1108928]|0)==0){t=b[(c[277225]|0)+(w<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){ac=b[(c[277221]|0)+((t&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}v=c[277228]&65535;K=t&-2048;y=v&-2048;x=(K&65535)>(y&65535)?K-y&65535:0;y=t&2016;K=v&2016;if((y&65535)>(K&65535)){ad=(y-K&65535)+x&65535}else{ad=x}x=t&31;t=v&31;if((x&65535)<=(t&65535)){ac=ad;break}ac=(x-t&65535)+ad&65535}else{t=b[(c[277225]|0)+(w<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){ae=c[277228]&65535}else{ae=b[(c[277213]|0)+(o<<1)>>1]|0}x=t&-2048;v=ae&-2048;K=(x&65535)>(v&65535)?x-v&65535:0;v=t&2016;x=ae&2016;if((v&65535)>(x&65535)){af=(v-x&65535)+K&65535}else{af=K}K=t&31;t=ae&31;if((K&65535)<=(t&65535)){ac=af;break}ac=(K-t&65535)+af&65535}}while(0);w=m+13|0;b[(c[277218]|0)+(w<<1)>>1]=ac;b[(c[277218]|0)+(o<<1)>>1]=ac;t=a[1108909]|0;a[(c[277219]|0)+w|0]=t;a[(c[277219]|0)+o|0]=t}}while(0);if(I<<24>>24!=1){D=3186}}do{if((D|0)==3186){D=0;o=m+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+o|0]|0)){break}t=a[r+7|0]|0;w=t&255;if(t<<24>>24==0){break}do{if((a[1108928]|0)==0){t=b[(c[277225]|0)+(w<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){ag=b[(c[277221]|0)+((t&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}K=c[277228]&65535;x=t&-2048;v=K&-2048;y=(x&65535)>(v&65535)?x-v&65535:0;v=t&2016;x=K&2016;if((v&65535)>(x&65535)){ah=(v-x&65535)+y&65535}else{ah=y}y=t&31;t=K&31;if((y&65535)<=(t&65535)){ag=ah;break}ag=(y-t&65535)+ah&65535}else{t=b[(c[277225]|0)+(w<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){ai=c[277228]&65535}else{ai=b[(c[277213]|0)+(o<<1)>>1]|0}y=t&-2048;K=ai&-2048;x=(y&65535)>(K&65535)?y-K&65535:0;K=t&2016;y=ai&2016;if((K&65535)>(y&65535)){aj=(K-y&65535)+x&65535}else{aj=x}x=t&31;t=ai&31;if((x&65535)<=(t&65535)){ag=aj;break}ag=(x-t&65535)+aj&65535}}while(0);w=m+15|0;b[(c[277218]|0)+(w<<1)>>1]=ag;b[(c[277218]|0)+(o<<1)>>1]=ag;t=a[1108909]|0;a[(c[277219]|0)+w|0]=t;a[(c[277219]|0)+o|0]=t}}while(0);t=p-1|0;if((t|0)>0){r=r+16|0;p=t;m=(c[277223]|0)+m|0}else{break}}return}m=(d[1394504]|0)+(i<<1)|0;if((e&32768|0)==0){if((j|0)<=0){return}e=h&255;i=e-1&255;p=i<<24>>24==0;r=q+m|0;ag=j;aj=f;while(1){switch(g|0){case 3:{ak=e;D=3262;break};case 5:{al=e;D=3298;break};case 7:{D=3334;break};case 2:{am=e;D=3244;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+aj|0]|0)){ai=a[r+7|0]|0;ah=ai&255;if(ai<<24>>24==0){break}do{if((a[1108928]|0)==0){ai=b[(c[277225]|0)+(ah<<1)>>1]|0;if((a[(c[277215]|0)+aj|0]&32)!=0){an=b[(c[277221]|0)+((ai&65535|67616)-(b[(c[277213]|0)+(aj<<1)>>1]&63454)>>1<<1)>>1]|0;break}I=c[277228]&65535;ac=ai&-2048;af=I&-2048;ae=(ac&65535)>(af&65535)?ac-af&65535:0;af=ai&2016;ac=I&2016;if((af&65535)>(ac&65535)){ao=(af-ac&65535)+ae&65535}else{ao=ae}ae=ai&31;ai=I&31;if((ae&65535)<=(ai&65535)){an=ao;break}an=(ae-ai&65535)+ao&65535}else{ai=b[(c[277225]|0)+(ah<<1)>>1]|0;if((a[(c[277215]|0)+aj|0]&32)==0){ap=c[277228]&65535}else{ap=b[(c[277213]|0)+(aj<<1)>>1]|0}ae=ai&-2048;I=ap&-2048;ac=(ae&65535)>(I&65535)?ae-I&65535:0;I=ai&2016;ae=ap&2016;if((I&65535)>(ae&65535)){aq=(I-ae&65535)+ac&65535}else{aq=ac}ac=ai&31;ai=ap&31;if((ac&65535)<=(ai&65535)){an=aq;break}an=(ac-ai&65535)+aq&65535}}while(0);ah=aj+1|0;b[(c[277218]|0)+(ah<<1)>>1]=an;b[(c[277218]|0)+(aj<<1)>>1]=an;o=a[1108909]|0;a[(c[277219]|0)+ah|0]=o;a[(c[277219]|0)+aj|0]=o}}while(0);if(!p){ar=i;D=3226}break};case 4:{as=e;D=3280;break};case 1:{ar=e;D=3226;break};case 6:{at=e;D=3316;break};default:{}}if((D|0)==3226){D=0;o=aj+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){ah=a[r+6|0]|0;ai=ah&255;if(ah<<24>>24==0){break}do{if((a[1108928]|0)==0){ah=b[(c[277225]|0)+(ai<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){au=b[(c[277221]|0)+((ah&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}ac=c[277228]&65535;ae=ah&-2048;I=ac&-2048;af=(ae&65535)>(I&65535)?ae-I&65535:0;I=ah&2016;ae=ac&2016;if((I&65535)>(ae&65535)){av=(I-ae&65535)+af&65535}else{av=af}af=ah&31;ah=ac&31;if((af&65535)<=(ah&65535)){au=av;break}au=(af-ah&65535)+av&65535}else{ah=b[(c[277225]|0)+(ai<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){aw=c[277228]&65535}else{aw=b[(c[277213]|0)+(o<<1)>>1]|0}af=ah&-2048;ac=aw&-2048;ae=(af&65535)>(ac&65535)?af-ac&65535:0;ac=ah&2016;af=aw&2016;if((ac&65535)>(af&65535)){ax=(ac-af&65535)+ae&65535}else{ax=ae}ae=ah&31;ah=aw&31;if((ae&65535)<=(ah&65535)){au=ax;break}au=(ae-ah&65535)+ax&65535}}while(0);ai=aj+3|0;b[(c[277218]|0)+(ai<<1)>>1]=au;b[(c[277218]|0)+(o<<1)>>1]=au;ah=a[1108909]|0;a[(c[277219]|0)+ai|0]=ah;a[(c[277219]|0)+o|0]=ah}}while(0);o=ar-1&255;if(o<<24>>24!=0){am=o;D=3244}}if((D|0)==3244){D=0;o=aj+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){ah=a[r+5|0]|0;ai=ah&255;if(ah<<24>>24==0){break}do{if((a[1108928]|0)==0){ah=b[(c[277225]|0)+(ai<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){ay=b[(c[277221]|0)+((ah&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}ae=c[277228]&65535;af=ah&-2048;ac=ae&-2048;I=(af&65535)>(ac&65535)?af-ac&65535:0;ac=ah&2016;af=ae&2016;if((ac&65535)>(af&65535)){az=(ac-af&65535)+I&65535}else{az=I}I=ah&31;ah=ae&31;if((I&65535)<=(ah&65535)){ay=az;break}ay=(I-ah&65535)+az&65535}else{ah=b[(c[277225]|0)+(ai<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){aA=c[277228]&65535}else{aA=b[(c[277213]|0)+(o<<1)>>1]|0}I=ah&-2048;ae=aA&-2048;af=(I&65535)>(ae&65535)?I-ae&65535:0;ae=ah&2016;I=aA&2016;if((ae&65535)>(I&65535)){aB=(ae-I&65535)+af&65535}else{aB=af}af=ah&31;ah=aA&31;if((af&65535)<=(ah&65535)){ay=aB;break}ay=(af-ah&65535)+aB&65535}}while(0);ai=aj+5|0;b[(c[277218]|0)+(ai<<1)>>1]=ay;b[(c[277218]|0)+(o<<1)>>1]=ay;ah=a[1108909]|0;a[(c[277219]|0)+ai|0]=ah;a[(c[277219]|0)+o|0]=ah}}while(0);o=am-1&255;if(o<<24>>24!=0){ak=o;D=3262}}if((D|0)==3262){D=0;o=aj+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){ah=a[r+4|0]|0;ai=ah&255;if(ah<<24>>24==0){break}do{if((a[1108928]|0)==0){ah=b[(c[277225]|0)+(ai<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){aC=b[(c[277221]|0)+((ah&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}af=c[277228]&65535;I=ah&-2048;ae=af&-2048;ac=(I&65535)>(ae&65535)?I-ae&65535:0;ae=ah&2016;I=af&2016;if((ae&65535)>(I&65535)){aD=(ae-I&65535)+ac&65535}else{aD=ac}ac=ah&31;ah=af&31;if((ac&65535)<=(ah&65535)){aC=aD;break}aC=(ac-ah&65535)+aD&65535}else{ah=b[(c[277225]|0)+(ai<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){aE=c[277228]&65535}else{aE=b[(c[277213]|0)+(o<<1)>>1]|0}ac=ah&-2048;af=aE&-2048;I=(ac&65535)>(af&65535)?ac-af&65535:0;af=ah&2016;ac=aE&2016;if((af&65535)>(ac&65535)){aF=(af-ac&65535)+I&65535}else{aF=I}I=ah&31;ah=aE&31;if((I&65535)<=(ah&65535)){aC=aF;break}aC=(I-ah&65535)+aF&65535}}while(0);ai=aj+7|0;b[(c[277218]|0)+(ai<<1)>>1]=aC;b[(c[277218]|0)+(o<<1)>>1]=aC;ah=a[1108909]|0;a[(c[277219]|0)+ai|0]=ah;a[(c[277219]|0)+o|0]=ah}}while(0);o=ak-1&255;if(o<<24>>24!=0){as=o;D=3280}}if((D|0)==3280){D=0;o=aj+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){ah=a[r+3|0]|0;ai=ah&255;if(ah<<24>>24==0){break}do{if((a[1108928]|0)==0){ah=b[(c[277225]|0)+(ai<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){aG=b[(c[277221]|0)+((ah&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}I=c[277228]&65535;ac=ah&-2048;af=I&-2048;ae=(ac&65535)>(af&65535)?ac-af&65535:0;af=ah&2016;ac=I&2016;if((af&65535)>(ac&65535)){aH=(af-ac&65535)+ae&65535}else{aH=ae}ae=ah&31;ah=I&31;if((ae&65535)<=(ah&65535)){aG=aH;break}aG=(ae-ah&65535)+aH&65535}else{ah=b[(c[277225]|0)+(ai<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){aI=c[277228]&65535}else{aI=b[(c[277213]|0)+(o<<1)>>1]|0}ae=ah&-2048;I=aI&-2048;ac=(ae&65535)>(I&65535)?ae-I&65535:0;I=ah&2016;ae=aI&2016;if((I&65535)>(ae&65535)){aJ=(I-ae&65535)+ac&65535}else{aJ=ac}ac=ah&31;ah=aI&31;if((ac&65535)<=(ah&65535)){aG=aJ;break}aG=(ac-ah&65535)+aJ&65535}}while(0);ai=aj+9|0;b[(c[277218]|0)+(ai<<1)>>1]=aG;b[(c[277218]|0)+(o<<1)>>1]=aG;ah=a[1108909]|0;a[(c[277219]|0)+ai|0]=ah;a[(c[277219]|0)+o|0]=ah}}while(0);o=as-1&255;if(o<<24>>24!=0){al=o;D=3298}}if((D|0)==3298){D=0;o=aj+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){ah=a[r+2|0]|0;ai=ah&255;if(ah<<24>>24==0){break}do{if((a[1108928]|0)==0){ah=b[(c[277225]|0)+(ai<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){aK=b[(c[277221]|0)+((ah&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}ac=c[277228]&65535;ae=ah&-2048;I=ac&-2048;af=(ae&65535)>(I&65535)?ae-I&65535:0;I=ah&2016;ae=ac&2016;if((I&65535)>(ae&65535)){aL=(I-ae&65535)+af&65535}else{aL=af}af=ah&31;ah=ac&31;if((af&65535)<=(ah&65535)){aK=aL;break}aK=(af-ah&65535)+aL&65535}else{ah=b[(c[277225]|0)+(ai<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){aM=c[277228]&65535}else{aM=b[(c[277213]|0)+(o<<1)>>1]|0}af=ah&-2048;ac=aM&-2048;ae=(af&65535)>(ac&65535)?af-ac&65535:0;ac=ah&2016;af=aM&2016;if((ac&65535)>(af&65535)){aN=(ac-af&65535)+ae&65535}else{aN=ae}ae=ah&31;ah=aM&31;if((ae&65535)<=(ah&65535)){aK=aN;break}aK=(ae-ah&65535)+aN&65535}}while(0);ai=aj+11|0;b[(c[277218]|0)+(ai<<1)>>1]=aK;b[(c[277218]|0)+(o<<1)>>1]=aK;ah=a[1108909]|0;a[(c[277219]|0)+ai|0]=ah;a[(c[277219]|0)+o|0]=ah}}while(0);o=al-1&255;if(o<<24>>24!=0){at=o;D=3316}}if((D|0)==3316){D=0;o=aj+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){ah=a[r+1|0]|0;ai=ah&255;if(ah<<24>>24==0){break}do{if((a[1108928]|0)==0){ah=b[(c[277225]|0)+(ai<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){aO=b[(c[277221]|0)+((ah&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}ae=c[277228]&65535;af=ah&-2048;ac=ae&-2048;I=(af&65535)>(ac&65535)?af-ac&65535:0;ac=ah&2016;af=ae&2016;if((ac&65535)>(af&65535)){aP=(ac-af&65535)+I&65535}else{aP=I}I=ah&31;ah=ae&31;if((I&65535)<=(ah&65535)){aO=aP;break}aO=(I-ah&65535)+aP&65535}else{ah=b[(c[277225]|0)+(ai<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){aQ=c[277228]&65535}else{aQ=b[(c[277213]|0)+(o<<1)>>1]|0}I=ah&-2048;ae=aQ&-2048;af=(I&65535)>(ae&65535)?I-ae&65535:0;ae=ah&2016;I=aQ&2016;if((ae&65535)>(I&65535)){aR=(ae-I&65535)+af&65535}else{aR=af}af=ah&31;ah=aQ&31;if((af&65535)<=(ah&65535)){aO=aR;break}aO=(af-ah&65535)+aR&65535}}while(0);ai=aj+13|0;b[(c[277218]|0)+(ai<<1)>>1]=aO;b[(c[277218]|0)+(o<<1)>>1]=aO;ah=a[1108909]|0;a[(c[277219]|0)+ai|0]=ah;a[(c[277219]|0)+o|0]=ah}}while(0);if(at<<24>>24!=1){D=3334}}do{if((D|0)==3334){D=0;o=aj+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+o|0]|0)){break}ah=a[r]|0;ai=ah&255;if(ah<<24>>24==0){break}do{if((a[1108928]|0)==0){ah=b[(c[277225]|0)+(ai<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){aS=b[(c[277221]|0)+((ah&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}af=c[277228]&65535;I=ah&-2048;ae=af&-2048;ac=(I&65535)>(ae&65535)?I-ae&65535:0;ae=ah&2016;I=af&2016;if((ae&65535)>(I&65535)){aT=(ae-I&65535)+ac&65535}else{aT=ac}ac=ah&31;ah=af&31;if((ac&65535)<=(ah&65535)){aS=aT;break}aS=(ac-ah&65535)+aT&65535}else{ah=b[(c[277225]|0)+(ai<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){aU=c[277228]&65535}else{aU=b[(c[277213]|0)+(o<<1)>>1]|0}ac=ah&-2048;af=aU&-2048;I=(ac&65535)>(af&65535)?ac-af&65535:0;af=ah&2016;ac=aU&2016;if((af&65535)>(ac&65535)){aV=(af-ac&65535)+I&65535}else{aV=I}I=ah&31;ah=aU&31;if((I&65535)<=(ah&65535)){aS=aV;break}aS=(I-ah&65535)+aV&65535}}while(0);ai=aj+15|0;b[(c[277218]|0)+(ai<<1)>>1]=aS;b[(c[277218]|0)+(o<<1)>>1]=aS;ah=a[1108909]|0;a[(c[277219]|0)+ai|0]=ah;a[(c[277219]|0)+o|0]=ah}}while(0);ah=ag-1|0;if((ah|0)>0){r=r+16|0;ag=ah;aj=(c[277223]|0)+aj|0}else{break}}return}aj=q+(56-m)|0;m=(j|0)>0;if(l){if(!m){return}l=h&255;q=l-1&255;ag=q<<24>>24==0;r=aj;aS=j;aV=f;while(1){switch(g|0){case 3:{aW=l;D=3557;break};case 5:{aX=l;D=3593;break};case 1:{aY=l;D=3521;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+aV|0]|0)){aU=a[r+7|0]|0;aT=aU&255;if(aU<<24>>24==0){break}do{if((a[1108928]|0)==0){aU=b[(c[277225]|0)+(aT<<1)>>1]|0;if((a[(c[277215]|0)+aV|0]&32)!=0){aZ=b[(c[277221]|0)+((aU&65535|67616)-(b[(c[277213]|0)+(aV<<1)>>1]&63454)>>1<<1)>>1]|0;break}at=c[277228]&65535;aO=aU&-2048;aR=at&-2048;aQ=(aO&65535)>(aR&65535)?aO-aR&65535:0;aR=aU&2016;aO=at&2016;if((aR&65535)>(aO&65535)){a_=(aR-aO&65535)+aQ&65535}else{a_=aQ}aQ=aU&31;aU=at&31;if((aQ&65535)<=(aU&65535)){aZ=a_;break}aZ=(aQ-aU&65535)+a_&65535}else{aU=b[(c[277225]|0)+(aT<<1)>>1]|0;if((a[(c[277215]|0)+aV|0]&32)==0){a$=c[277228]&65535}else{a$=b[(c[277213]|0)+(aV<<1)>>1]|0}aQ=aU&-2048;at=a$&-2048;aO=(aQ&65535)>(at&65535)?aQ-at&65535:0;at=aU&2016;aQ=a$&2016;if((at&65535)>(aQ&65535)){a0=(at-aQ&65535)+aO&65535}else{a0=aO}aO=aU&31;aU=a$&31;if((aO&65535)<=(aU&65535)){aZ=a0;break}aZ=(aO-aU&65535)+a0&65535}}while(0);aT=aV+1|0;b[(c[277218]|0)+(aT<<1)>>1]=aZ;b[(c[277218]|0)+(aV<<1)>>1]=aZ;o=a[1108909]|0;a[(c[277219]|0)+aT|0]=o;a[(c[277219]|0)+aV|0]=o}}while(0);if(!ag){aY=q;D=3521}break};case 6:{a1=l;D=3611;break};case 4:{a2=l;D=3575;break};case 7:{D=3629;break};case 2:{a3=l;D=3539;break};default:{}}if((D|0)==3521){D=0;o=aV+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){aT=a[r+6|0]|0;aU=aT&255;if(aT<<24>>24==0){break}do{if((a[1108928]|0)==0){aT=b[(c[277225]|0)+(aU<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){a4=b[(c[277221]|0)+((aT&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}aO=c[277228]&65535;aQ=aT&-2048;at=aO&-2048;aR=(aQ&65535)>(at&65535)?aQ-at&65535:0;at=aT&2016;aQ=aO&2016;if((at&65535)>(aQ&65535)){a5=(at-aQ&65535)+aR&65535}else{a5=aR}aR=aT&31;aT=aO&31;if((aR&65535)<=(aT&65535)){a4=a5;break}a4=(aR-aT&65535)+a5&65535}else{aT=b[(c[277225]|0)+(aU<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){a6=c[277228]&65535}else{a6=b[(c[277213]|0)+(o<<1)>>1]|0}aR=aT&-2048;aO=a6&-2048;aQ=(aR&65535)>(aO&65535)?aR-aO&65535:0;aO=aT&2016;aR=a6&2016;if((aO&65535)>(aR&65535)){a7=(aO-aR&65535)+aQ&65535}else{a7=aQ}aQ=aT&31;aT=a6&31;if((aQ&65535)<=(aT&65535)){a4=a7;break}a4=(aQ-aT&65535)+a7&65535}}while(0);aU=aV+3|0;b[(c[277218]|0)+(aU<<1)>>1]=a4;b[(c[277218]|0)+(o<<1)>>1]=a4;aT=a[1108909]|0;a[(c[277219]|0)+aU|0]=aT;a[(c[277219]|0)+o|0]=aT}}while(0);o=aY-1&255;if(o<<24>>24!=0){a3=o;D=3539}}if((D|0)==3539){D=0;o=aV+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){aT=a[r+5|0]|0;aU=aT&255;if(aT<<24>>24==0){break}do{if((a[1108928]|0)==0){aT=b[(c[277225]|0)+(aU<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){a8=b[(c[277221]|0)+((aT&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}aQ=c[277228]&65535;aR=aT&-2048;aO=aQ&-2048;at=(aR&65535)>(aO&65535)?aR-aO&65535:0;aO=aT&2016;aR=aQ&2016;if((aO&65535)>(aR&65535)){a9=(aO-aR&65535)+at&65535}else{a9=at}at=aT&31;aT=aQ&31;if((at&65535)<=(aT&65535)){a8=a9;break}a8=(at-aT&65535)+a9&65535}else{aT=b[(c[277225]|0)+(aU<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){ba=c[277228]&65535}else{ba=b[(c[277213]|0)+(o<<1)>>1]|0}at=aT&-2048;aQ=ba&-2048;aR=(at&65535)>(aQ&65535)?at-aQ&65535:0;aQ=aT&2016;at=ba&2016;if((aQ&65535)>(at&65535)){bb=(aQ-at&65535)+aR&65535}else{bb=aR}aR=aT&31;aT=ba&31;if((aR&65535)<=(aT&65535)){a8=bb;break}a8=(aR-aT&65535)+bb&65535}}while(0);aU=aV+5|0;b[(c[277218]|0)+(aU<<1)>>1]=a8;b[(c[277218]|0)+(o<<1)>>1]=a8;aT=a[1108909]|0;a[(c[277219]|0)+aU|0]=aT;a[(c[277219]|0)+o|0]=aT}}while(0);o=a3-1&255;if(o<<24>>24!=0){aW=o;D=3557}}if((D|0)==3557){D=0;o=aV+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){aT=a[r+4|0]|0;aU=aT&255;if(aT<<24>>24==0){break}do{if((a[1108928]|0)==0){aT=b[(c[277225]|0)+(aU<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){bc=b[(c[277221]|0)+((aT&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}aR=c[277228]&65535;at=aT&-2048;aQ=aR&-2048;aO=(at&65535)>(aQ&65535)?at-aQ&65535:0;aQ=aT&2016;at=aR&2016;if((aQ&65535)>(at&65535)){bd=(aQ-at&65535)+aO&65535}else{bd=aO}aO=aT&31;aT=aR&31;if((aO&65535)<=(aT&65535)){bc=bd;break}bc=(aO-aT&65535)+bd&65535}else{aT=b[(c[277225]|0)+(aU<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){be=c[277228]&65535}else{be=b[(c[277213]|0)+(o<<1)>>1]|0}aO=aT&-2048;aR=be&-2048;at=(aO&65535)>(aR&65535)?aO-aR&65535:0;aR=aT&2016;aO=be&2016;if((aR&65535)>(aO&65535)){bf=(aR-aO&65535)+at&65535}else{bf=at}at=aT&31;aT=be&31;if((at&65535)<=(aT&65535)){bc=bf;break}bc=(at-aT&65535)+bf&65535}}while(0);aU=aV+7|0;b[(c[277218]|0)+(aU<<1)>>1]=bc;b[(c[277218]|0)+(o<<1)>>1]=bc;aT=a[1108909]|0;a[(c[277219]|0)+aU|0]=aT;a[(c[277219]|0)+o|0]=aT}}while(0);o=aW-1&255;if(o<<24>>24!=0){a2=o;D=3575}}if((D|0)==3575){D=0;o=aV+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){aT=a[r+3|0]|0;aU=aT&255;if(aT<<24>>24==0){break}do{if((a[1108928]|0)==0){aT=b[(c[277225]|0)+(aU<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){bg=b[(c[277221]|0)+((aT&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}at=c[277228]&65535;aO=aT&-2048;aR=at&-2048;aQ=(aO&65535)>(aR&65535)?aO-aR&65535:0;aR=aT&2016;aO=at&2016;if((aR&65535)>(aO&65535)){bh=(aR-aO&65535)+aQ&65535}else{bh=aQ}aQ=aT&31;aT=at&31;if((aQ&65535)<=(aT&65535)){bg=bh;break}bg=(aQ-aT&65535)+bh&65535}else{aT=b[(c[277225]|0)+(aU<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){bi=c[277228]&65535}else{bi=b[(c[277213]|0)+(o<<1)>>1]|0}aQ=aT&-2048;at=bi&-2048;aO=(aQ&65535)>(at&65535)?aQ-at&65535:0;at=aT&2016;aQ=bi&2016;if((at&65535)>(aQ&65535)){bj=(at-aQ&65535)+aO&65535}else{bj=aO}aO=aT&31;aT=bi&31;if((aO&65535)<=(aT&65535)){bg=bj;break}bg=(aO-aT&65535)+bj&65535}}while(0);aU=aV+9|0;b[(c[277218]|0)+(aU<<1)>>1]=bg;b[(c[277218]|0)+(o<<1)>>1]=bg;aT=a[1108909]|0;a[(c[277219]|0)+aU|0]=aT;a[(c[277219]|0)+o|0]=aT}}while(0);o=a2-1&255;if(o<<24>>24!=0){aX=o;D=3593}}if((D|0)==3593){D=0;o=aV+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){aT=a[r+2|0]|0;aU=aT&255;if(aT<<24>>24==0){break}do{if((a[1108928]|0)==0){aT=b[(c[277225]|0)+(aU<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){bk=b[(c[277221]|0)+((aT&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}aO=c[277228]&65535;aQ=aT&-2048;at=aO&-2048;aR=(aQ&65535)>(at&65535)?aQ-at&65535:0;at=aT&2016;aQ=aO&2016;if((at&65535)>(aQ&65535)){bl=(at-aQ&65535)+aR&65535}else{bl=aR}aR=aT&31;aT=aO&31;if((aR&65535)<=(aT&65535)){bk=bl;break}bk=(aR-aT&65535)+bl&65535}else{aT=b[(c[277225]|0)+(aU<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){bm=c[277228]&65535}else{bm=b[(c[277213]|0)+(o<<1)>>1]|0}aR=aT&-2048;aO=bm&-2048;aQ=(aR&65535)>(aO&65535)?aR-aO&65535:0;aO=aT&2016;aR=bm&2016;if((aO&65535)>(aR&65535)){bn=(aO-aR&65535)+aQ&65535}else{bn=aQ}aQ=aT&31;aT=bm&31;if((aQ&65535)<=(aT&65535)){bk=bn;break}bk=(aQ-aT&65535)+bn&65535}}while(0);aU=aV+11|0;b[(c[277218]|0)+(aU<<1)>>1]=bk;b[(c[277218]|0)+(o<<1)>>1]=bk;aT=a[1108909]|0;a[(c[277219]|0)+aU|0]=aT;a[(c[277219]|0)+o|0]=aT}}while(0);o=aX-1&255;if(o<<24>>24!=0){a1=o;D=3611}}if((D|0)==3611){D=0;o=aV+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){aT=a[r+1|0]|0;aU=aT&255;if(aT<<24>>24==0){break}do{if((a[1108928]|0)==0){aT=b[(c[277225]|0)+(aU<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){bo=b[(c[277221]|0)+((aT&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}aQ=c[277228]&65535;aR=aT&-2048;aO=aQ&-2048;at=(aR&65535)>(aO&65535)?aR-aO&65535:0;aO=aT&2016;aR=aQ&2016;if((aO&65535)>(aR&65535)){bp=(aO-aR&65535)+at&65535}else{bp=at}at=aT&31;aT=aQ&31;if((at&65535)<=(aT&65535)){bo=bp;break}bo=(at-aT&65535)+bp&65535}else{aT=b[(c[277225]|0)+(aU<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){bq=c[277228]&65535}else{bq=b[(c[277213]|0)+(o<<1)>>1]|0}at=aT&-2048;aQ=bq&-2048;aR=(at&65535)>(aQ&65535)?at-aQ&65535:0;aQ=aT&2016;at=bq&2016;if((aQ&65535)>(at&65535)){br=(aQ-at&65535)+aR&65535}else{br=aR}aR=aT&31;aT=bq&31;if((aR&65535)<=(aT&65535)){bo=br;break}bo=(aR-aT&65535)+br&65535}}while(0);aU=aV+13|0;b[(c[277218]|0)+(aU<<1)>>1]=bo;b[(c[277218]|0)+(o<<1)>>1]=bo;aT=a[1108909]|0;a[(c[277219]|0)+aU|0]=aT;a[(c[277219]|0)+o|0]=aT}}while(0);if(a1<<24>>24!=1){D=3629}}do{if((D|0)==3629){D=0;o=aV+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+o|0]|0)){break}aT=a[r]|0;aU=aT&255;if(aT<<24>>24==0){break}do{if((a[1108928]|0)==0){aT=b[(c[277225]|0)+(aU<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){bs=b[(c[277221]|0)+((aT&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}aR=c[277228]&65535;at=aT&-2048;aQ=aR&-2048;aO=(at&65535)>(aQ&65535)?at-aQ&65535:0;aQ=aT&2016;at=aR&2016;if((aQ&65535)>(at&65535)){bt=(aQ-at&65535)+aO&65535}else{bt=aO}aO=aT&31;aT=aR&31;if((aO&65535)<=(aT&65535)){bs=bt;break}bs=(aO-aT&65535)+bt&65535}else{aT=b[(c[277225]|0)+(aU<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){bu=c[277228]&65535}else{bu=b[(c[277213]|0)+(o<<1)>>1]|0}aO=aT&-2048;aR=bu&-2048;at=(aO&65535)>(aR&65535)?aO-aR&65535:0;aR=aT&2016;aO=bu&2016;if((aR&65535)>(aO&65535)){bv=(aR-aO&65535)+at&65535}else{bv=at}at=aT&31;aT=bu&31;if((at&65535)<=(aT&65535)){bs=bv;break}bs=(at-aT&65535)+bv&65535}}while(0);aU=aV+15|0;b[(c[277218]|0)+(aU<<1)>>1]=bs;b[(c[277218]|0)+(o<<1)>>1]=bs;aT=a[1108909]|0;a[(c[277219]|0)+aU|0]=aT;a[(c[277219]|0)+o|0]=aT}}while(0);aT=aS-1|0;if((aT|0)>0){r=r-16|0;aS=aT;aV=(c[277223]|0)+aV|0}else{break}}return}else{if(!m){return}m=h&255;h=m-1&255;aV=h<<24>>24==0;aS=aj;aj=j;j=f;while(1){switch(g|0){case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+j|0]|0)){f=a[aS]|0;r=f&255;if(f<<24>>24==0){break}do{if((a[1108928]|0)==0){f=b[(c[277225]|0)+(r<<1)>>1]|0;if((a[(c[277215]|0)+j|0]&32)!=0){bw=b[(c[277221]|0)+((f&65535|67616)-(b[(c[277213]|0)+(j<<1)>>1]&63454)>>1<<1)>>1]|0;break}bs=c[277228]&65535;bv=f&-2048;bu=bs&-2048;bt=(bv&65535)>(bu&65535)?bv-bu&65535:0;bu=f&2016;bv=bs&2016;if((bu&65535)>(bv&65535)){bx=(bu-bv&65535)+bt&65535}else{bx=bt}bt=f&31;f=bs&31;if((bt&65535)<=(f&65535)){bw=bx;break}bw=(bt-f&65535)+bx&65535}else{f=b[(c[277225]|0)+(r<<1)>>1]|0;if((a[(c[277215]|0)+j|0]&32)==0){by=c[277228]&65535}else{by=b[(c[277213]|0)+(j<<1)>>1]|0}bt=f&-2048;bs=by&-2048;bv=(bt&65535)>(bs&65535)?bt-bs&65535:0;bs=f&2016;bt=by&2016;if((bs&65535)>(bt&65535)){bz=(bs-bt&65535)+bv&65535}else{bz=bv}bv=f&31;f=by&31;if((bv&65535)<=(f&65535)){bw=bz;break}bw=(bv-f&65535)+bz&65535}}while(0);r=j+1|0;b[(c[277218]|0)+(r<<1)>>1]=bw;b[(c[277218]|0)+(j<<1)>>1]=bw;o=a[1108909]|0;a[(c[277219]|0)+r|0]=o;a[(c[277219]|0)+j|0]=o}}while(0);if(!aV){bA=h;D=3376}break};case 6:{bB=m;D=3466;break};case 7:{D=3484;break};case 5:{bC=m;D=3448;break};case 3:{bD=m;D=3412;break};case 2:{bE=m;D=3394;break};case 1:{bA=m;D=3376;break};case 4:{bF=m;D=3430;break};default:{}}if((D|0)==3376){D=0;o=j+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){r=a[aS+1|0]|0;f=r&255;if(r<<24>>24==0){break}do{if((a[1108928]|0)==0){r=b[(c[277225]|0)+(f<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){bG=b[(c[277221]|0)+((r&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}bv=c[277228]&65535;bt=r&-2048;bs=bv&-2048;bu=(bt&65535)>(bs&65535)?bt-bs&65535:0;bs=r&2016;bt=bv&2016;if((bs&65535)>(bt&65535)){bH=(bs-bt&65535)+bu&65535}else{bH=bu}bu=r&31;r=bv&31;if((bu&65535)<=(r&65535)){bG=bH;break}bG=(bu-r&65535)+bH&65535}else{r=b[(c[277225]|0)+(f<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){bI=c[277228]&65535}else{bI=b[(c[277213]|0)+(o<<1)>>1]|0}bu=r&-2048;bv=bI&-2048;bt=(bu&65535)>(bv&65535)?bu-bv&65535:0;bv=r&2016;bu=bI&2016;if((bv&65535)>(bu&65535)){bJ=(bv-bu&65535)+bt&65535}else{bJ=bt}bt=r&31;r=bI&31;if((bt&65535)<=(r&65535)){bG=bJ;break}bG=(bt-r&65535)+bJ&65535}}while(0);f=j+3|0;b[(c[277218]|0)+(f<<1)>>1]=bG;b[(c[277218]|0)+(o<<1)>>1]=bG;r=a[1108909]|0;a[(c[277219]|0)+f|0]=r;a[(c[277219]|0)+o|0]=r}}while(0);o=bA-1&255;if(o<<24>>24!=0){bE=o;D=3394}}if((D|0)==3394){D=0;o=j+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){r=a[aS+2|0]|0;f=r&255;if(r<<24>>24==0){break}do{if((a[1108928]|0)==0){r=b[(c[277225]|0)+(f<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){bK=b[(c[277221]|0)+((r&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}bt=c[277228]&65535;bu=r&-2048;bv=bt&-2048;bs=(bu&65535)>(bv&65535)?bu-bv&65535:0;bv=r&2016;bu=bt&2016;if((bv&65535)>(bu&65535)){bL=(bv-bu&65535)+bs&65535}else{bL=bs}bs=r&31;r=bt&31;if((bs&65535)<=(r&65535)){bK=bL;break}bK=(bs-r&65535)+bL&65535}else{r=b[(c[277225]|0)+(f<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){bM=c[277228]&65535}else{bM=b[(c[277213]|0)+(o<<1)>>1]|0}bs=r&-2048;bt=bM&-2048;bu=(bs&65535)>(bt&65535)?bs-bt&65535:0;bt=r&2016;bs=bM&2016;if((bt&65535)>(bs&65535)){bN=(bt-bs&65535)+bu&65535}else{bN=bu}bu=r&31;r=bM&31;if((bu&65535)<=(r&65535)){bK=bN;break}bK=(bu-r&65535)+bN&65535}}while(0);f=j+5|0;b[(c[277218]|0)+(f<<1)>>1]=bK;b[(c[277218]|0)+(o<<1)>>1]=bK;r=a[1108909]|0;a[(c[277219]|0)+f|0]=r;a[(c[277219]|0)+o|0]=r}}while(0);o=bE-1&255;if(o<<24>>24!=0){bD=o;D=3412}}if((D|0)==3412){D=0;o=j+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){r=a[aS+3|0]|0;f=r&255;if(r<<24>>24==0){break}do{if((a[1108928]|0)==0){r=b[(c[277225]|0)+(f<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){bO=b[(c[277221]|0)+((r&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}bu=c[277228]&65535;bs=r&-2048;bt=bu&-2048;bv=(bs&65535)>(bt&65535)?bs-bt&65535:0;bt=r&2016;bs=bu&2016;if((bt&65535)>(bs&65535)){bP=(bt-bs&65535)+bv&65535}else{bP=bv}bv=r&31;r=bu&31;if((bv&65535)<=(r&65535)){bO=bP;break}bO=(bv-r&65535)+bP&65535}else{r=b[(c[277225]|0)+(f<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){bQ=c[277228]&65535}else{bQ=b[(c[277213]|0)+(o<<1)>>1]|0}bv=r&-2048;bu=bQ&-2048;bs=(bv&65535)>(bu&65535)?bv-bu&65535:0;bu=r&2016;bv=bQ&2016;if((bu&65535)>(bv&65535)){bR=(bu-bv&65535)+bs&65535}else{bR=bs}bs=r&31;r=bQ&31;if((bs&65535)<=(r&65535)){bO=bR;break}bO=(bs-r&65535)+bR&65535}}while(0);f=j+7|0;b[(c[277218]|0)+(f<<1)>>1]=bO;b[(c[277218]|0)+(o<<1)>>1]=bO;r=a[1108909]|0;a[(c[277219]|0)+f|0]=r;a[(c[277219]|0)+o|0]=r}}while(0);o=bD-1&255;if(o<<24>>24!=0){bF=o;D=3430}}if((D|0)==3430){D=0;o=j+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){r=a[aS+4|0]|0;f=r&255;if(r<<24>>24==0){break}do{if((a[1108928]|0)==0){r=b[(c[277225]|0)+(f<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){bS=b[(c[277221]|0)+((r&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}bs=c[277228]&65535;bv=r&-2048;bu=bs&-2048;bt=(bv&65535)>(bu&65535)?bv-bu&65535:0;bu=r&2016;bv=bs&2016;if((bu&65535)>(bv&65535)){bT=(bu-bv&65535)+bt&65535}else{bT=bt}bt=r&31;r=bs&31;if((bt&65535)<=(r&65535)){bS=bT;break}bS=(bt-r&65535)+bT&65535}else{r=b[(c[277225]|0)+(f<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){bU=c[277228]&65535}else{bU=b[(c[277213]|0)+(o<<1)>>1]|0}bt=r&-2048;bs=bU&-2048;bv=(bt&65535)>(bs&65535)?bt-bs&65535:0;bs=r&2016;bt=bU&2016;if((bs&65535)>(bt&65535)){bV=(bs-bt&65535)+bv&65535}else{bV=bv}bv=r&31;r=bU&31;if((bv&65535)<=(r&65535)){bS=bV;break}bS=(bv-r&65535)+bV&65535}}while(0);f=j+9|0;b[(c[277218]|0)+(f<<1)>>1]=bS;b[(c[277218]|0)+(o<<1)>>1]=bS;r=a[1108909]|0;a[(c[277219]|0)+f|0]=r;a[(c[277219]|0)+o|0]=r}}while(0);o=bF-1&255;if(o<<24>>24!=0){bC=o;D=3448}}if((D|0)==3448){D=0;o=j+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){r=a[aS+5|0]|0;f=r&255;if(r<<24>>24==0){break}do{if((a[1108928]|0)==0){r=b[(c[277225]|0)+(f<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){bW=b[(c[277221]|0)+((r&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}bv=c[277228]&65535;bt=r&-2048;bs=bv&-2048;bu=(bt&65535)>(bs&65535)?bt-bs&65535:0;bs=r&2016;bt=bv&2016;if((bs&65535)>(bt&65535)){bX=(bs-bt&65535)+bu&65535}else{bX=bu}bu=r&31;r=bv&31;if((bu&65535)<=(r&65535)){bW=bX;break}bW=(bu-r&65535)+bX&65535}else{r=b[(c[277225]|0)+(f<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){bY=c[277228]&65535}else{bY=b[(c[277213]|0)+(o<<1)>>1]|0}bu=r&-2048;bv=bY&-2048;bt=(bu&65535)>(bv&65535)?bu-bv&65535:0;bv=r&2016;bu=bY&2016;if((bv&65535)>(bu&65535)){bZ=(bv-bu&65535)+bt&65535}else{bZ=bt}bt=r&31;r=bY&31;if((bt&65535)<=(r&65535)){bW=bZ;break}bW=(bt-r&65535)+bZ&65535}}while(0);f=j+11|0;b[(c[277218]|0)+(f<<1)>>1]=bW;b[(c[277218]|0)+(o<<1)>>1]=bW;r=a[1108909]|0;a[(c[277219]|0)+f|0]=r;a[(c[277219]|0)+o|0]=r}}while(0);o=bC-1&255;if(o<<24>>24!=0){bB=o;D=3466}}if((D|0)==3466){D=0;o=j+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){r=a[aS+6|0]|0;f=r&255;if(r<<24>>24==0){break}do{if((a[1108928]|0)==0){r=b[(c[277225]|0)+(f<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){b_=b[(c[277221]|0)+((r&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}bt=c[277228]&65535;bu=r&-2048;bv=bt&-2048;bs=(bu&65535)>(bv&65535)?bu-bv&65535:0;bv=r&2016;bu=bt&2016;if((bv&65535)>(bu&65535)){b$=(bv-bu&65535)+bs&65535}else{b$=bs}bs=r&31;r=bt&31;if((bs&65535)<=(r&65535)){b_=b$;break}b_=(bs-r&65535)+b$&65535}else{r=b[(c[277225]|0)+(f<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){b0=c[277228]&65535}else{b0=b[(c[277213]|0)+(o<<1)>>1]|0}bs=r&-2048;bt=b0&-2048;bu=(bs&65535)>(bt&65535)?bs-bt&65535:0;bt=r&2016;bs=b0&2016;if((bt&65535)>(bs&65535)){b1=(bt-bs&65535)+bu&65535}else{b1=bu}bu=r&31;r=b0&31;if((bu&65535)<=(r&65535)){b_=b1;break}b_=(bu-r&65535)+b1&65535}}while(0);f=j+13|0;b[(c[277218]|0)+(f<<1)>>1]=b_;b[(c[277218]|0)+(o<<1)>>1]=b_;r=a[1108909]|0;a[(c[277219]|0)+f|0]=r;a[(c[277219]|0)+o|0]=r}}while(0);if(bB<<24>>24!=1){D=3484}}do{if((D|0)==3484){D=0;o=j+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+o|0]|0)){break}r=a[aS+7|0]|0;f=r&255;if(r<<24>>24==0){break}do{if((a[1108928]|0)==0){r=b[(c[277225]|0)+(f<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){b2=b[(c[277221]|0)+((r&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}bu=c[277228]&65535;bs=r&-2048;bt=bu&-2048;bv=(bs&65535)>(bt&65535)?bs-bt&65535:0;bt=r&2016;bs=bu&2016;if((bt&65535)>(bs&65535)){b3=(bt-bs&65535)+bv&65535}else{b3=bv}bv=r&31;r=bu&31;if((bv&65535)<=(r&65535)){b2=b3;break}b2=(bv-r&65535)+b3&65535}else{r=b[(c[277225]|0)+(f<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){b4=c[277228]&65535}else{b4=b[(c[277213]|0)+(o<<1)>>1]|0}bv=r&-2048;bu=b4&-2048;bs=(bv&65535)>(bu&65535)?bv-bu&65535:0;bu=r&2016;bv=b4&2016;if((bu&65535)>(bv&65535)){b5=(bu-bv&65535)+bs&65535}else{b5=bs}bs=r&31;r=b4&31;if((bs&65535)<=(r&65535)){b2=b5;break}b2=(bs-r&65535)+b5&65535}}while(0);f=j+15|0;b[(c[277218]|0)+(f<<1)>>1]=b2;b[(c[277218]|0)+(o<<1)>>1]=b2;r=a[1108909]|0;a[(c[277219]|0)+f|0]=r;a[(c[277219]|0)+o|0]=r}}while(0);r=aj-1|0;if((r|0)>0){aS=aS-16|0;aj=r;j=(c[277223]|0)+j|0}else{break}}return}}function Vm(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0;i=e&1023;j=c[348606]|0;k=(i<<j)+(c[348604]|0)|0;if((e&256|0)==0){l=k}else{l=(c[348602]|0)+k|0}k=l&65535;l=k>>>(j>>>0);j=(e&16384|0)!=0;m=l<<6;do{if(j){n=(c[348622]|0)+m|0;if((a[(c[348618]|0)+l|0]|0)!=0){o=n;break}p=fi[c[348636]&63](n,k,i)|0;a[(c[348618]|0)+l|0]=p;o=n}else{n=(c[348624]|0)+m|0;if((a[(c[348620]|0)+l|0]|0)!=0){o=n;break}p=fi[c[348638]&63](n,k,i)|0;a[(c[348620]|0)+l|0]=p;o=n}}while(0);if((a[(c[348620]|0)+l|0]|0)==2){return}if((a[1394464]|0)==0){q=1106168+((e>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){l=d[1044485]|0;c[276541]=7080+(l<<5);i=0;do{k=i<<1&2;m=i&2;n=i&4;p=0;do{b[1125528+(i<<9)+(p<<1)>>1]=d[(p>>>1&28|m)+(7080+(l<<5))|0]<<6|d[(p<<2&28|k)+(7080+(l<<5))|0]<<11|d[(p>>>3&24|n)+(7080+(l<<5))|0];p=p+1|0;}while(p>>>0<256);i=i+1|0;}while(i>>>0<8);a[1106089]=0}q=1125528+((e>>>10&7)<<9)|0}c[277226]=q;c[277225]=(a[1108928]|0)!=0?1393712:q;if((e&49152|0)==0){if((h|0)<=0){return}q=o+((d[1394504]|0)+(g<<1))|0;i=h;l=f;while(1){p=a[1108908]|0;n=c[277219]|0;do{if((p&255)>(d[n+l|0]|0)){k=a[q]|0;if(k<<24>>24==0){r=p;s=n;break}m=b[(c[277225]|0)+((k&255)<<1)>>1]|0;k=l+1|0;b[(c[277218]|0)+(k<<1)>>1]=m;b[(c[277218]|0)+(l<<1)>>1]=m;m=a[1108909]|0;a[(c[277219]|0)+k|0]=m;a[(c[277219]|0)+l|0]=m;r=a[1108908]|0;s=c[277219]|0}else{r=p;s=n}}while(0);n=l+2|0;do{if((r&255)>(d[s+n|0]|0)){p=a[q+1|0]|0;if(p<<24>>24==0){t=r;u=s;break}m=b[(c[277225]|0)+((p&255)<<1)>>1]|0;p=l+3|0;b[(c[277218]|0)+(p<<1)>>1]=m;b[(c[277218]|0)+(n<<1)>>1]=m;m=a[1108909]|0;a[(c[277219]|0)+p|0]=m;a[(c[277219]|0)+n|0]=m;t=a[1108908]|0;u=c[277219]|0}else{t=r;u=s}}while(0);n=l+4|0;do{if((t&255)>(d[u+n|0]|0)){m=a[q+2|0]|0;if(m<<24>>24==0){v=t;w=u;break}p=b[(c[277225]|0)+((m&255)<<1)>>1]|0;m=l+5|0;b[(c[277218]|0)+(m<<1)>>1]=p;b[(c[277218]|0)+(n<<1)>>1]=p;p=a[1108909]|0;a[(c[277219]|0)+m|0]=p;a[(c[277219]|0)+n|0]=p;v=a[1108908]|0;w=c[277219]|0}else{v=t;w=u}}while(0);n=l+6|0;do{if((v&255)>(d[w+n|0]|0)){p=a[q+3|0]|0;if(p<<24>>24==0){x=v;y=w;break}m=b[(c[277225]|0)+((p&255)<<1)>>1]|0;p=l+7|0;b[(c[277218]|0)+(p<<1)>>1]=m;b[(c[277218]|0)+(n<<1)>>1]=m;m=a[1108909]|0;a[(c[277219]|0)+p|0]=m;a[(c[277219]|0)+n|0]=m;x=a[1108908]|0;y=c[277219]|0}else{x=v;y=w}}while(0);n=l+8|0;do{if((x&255)>(d[y+n|0]|0)){m=a[q+4|0]|0;if(m<<24>>24==0){z=x;A=y;break}p=b[(c[277225]|0)+((m&255)<<1)>>1]|0;m=l+9|0;b[(c[277218]|0)+(m<<1)>>1]=p;b[(c[277218]|0)+(n<<1)>>1]=p;p=a[1108909]|0;a[(c[277219]|0)+m|0]=p;a[(c[277219]|0)+n|0]=p;z=a[1108908]|0;A=c[277219]|0}else{z=x;A=y}}while(0);n=l+10|0;do{if((z&255)>(d[A+n|0]|0)){p=a[q+5|0]|0;if(p<<24>>24==0){B=z;C=A;break}m=b[(c[277225]|0)+((p&255)<<1)>>1]|0;p=l+11|0;b[(c[277218]|0)+(p<<1)>>1]=m;b[(c[277218]|0)+(n<<1)>>1]=m;m=a[1108909]|0;a[(c[277219]|0)+p|0]=m;a[(c[277219]|0)+n|0]=m;B=a[1108908]|0;C=c[277219]|0}else{B=z;C=A}}while(0);n=l+12|0;do{if((B&255)>(d[C+n|0]|0)){m=a[q+6|0]|0;if(m<<24>>24==0){D=B;E=C;break}p=b[(c[277225]|0)+((m&255)<<1)>>1]|0;m=l+13|0;b[(c[277218]|0)+(m<<1)>>1]=p;b[(c[277218]|0)+(n<<1)>>1]=p;p=a[1108909]|0;a[(c[277219]|0)+m|0]=p;a[(c[277219]|0)+n|0]=p;D=a[1108908]|0;E=c[277219]|0}else{D=B;E=C}}while(0);n=l+14|0;do{if((D&255)>(d[E+n|0]|0)){p=a[q+7|0]|0;if(p<<24>>24==0){break}m=b[(c[277225]|0)+((p&255)<<1)>>1]|0;p=l+15|0;b[(c[277218]|0)+(p<<1)>>1]=m;b[(c[277218]|0)+(n<<1)>>1]=m;m=a[1108909]|0;a[(c[277219]|0)+p|0]=m;a[(c[277219]|0)+n|0]=m}}while(0);n=i-1|0;if((n|0)<=0){break}q=q+16|0;i=n;l=(c[277223]|0)+l|0}return}l=(d[1394504]|0)+(g<<1)|0;if((e&32768|0)==0){if((h|0)<=0){return}e=o+l|0;g=h;i=f;while(1){q=a[1108908]|0;E=c[277219]|0;do{if((q&255)>(d[E+i|0]|0)){D=a[e+7|0]|0;if(D<<24>>24==0){F=q;G=E;break}C=b[(c[277225]|0)+((D&255)<<1)>>1]|0;D=i+1|0;b[(c[277218]|0)+(D<<1)>>1]=C;b[(c[277218]|0)+(i<<1)>>1]=C;C=a[1108909]|0;a[(c[277219]|0)+D|0]=C;a[(c[277219]|0)+i|0]=C;F=a[1108908]|0;G=c[277219]|0}else{F=q;G=E}}while(0);E=i+2|0;do{if((F&255)>(d[G+E|0]|0)){q=a[e+6|0]|0;if(q<<24>>24==0){H=F;I=G;break}C=b[(c[277225]|0)+((q&255)<<1)>>1]|0;q=i+3|0;b[(c[277218]|0)+(q<<1)>>1]=C;b[(c[277218]|0)+(E<<1)>>1]=C;C=a[1108909]|0;a[(c[277219]|0)+q|0]=C;a[(c[277219]|0)+E|0]=C;H=a[1108908]|0;I=c[277219]|0}else{H=F;I=G}}while(0);E=i+4|0;do{if((H&255)>(d[I+E|0]|0)){C=a[e+5|0]|0;if(C<<24>>24==0){J=H;K=I;break}q=b[(c[277225]|0)+((C&255)<<1)>>1]|0;C=i+5|0;b[(c[277218]|0)+(C<<1)>>1]=q;b[(c[277218]|0)+(E<<1)>>1]=q;q=a[1108909]|0;a[(c[277219]|0)+C|0]=q;a[(c[277219]|0)+E|0]=q;J=a[1108908]|0;K=c[277219]|0}else{J=H;K=I}}while(0);E=i+6|0;do{if((J&255)>(d[K+E|0]|0)){q=a[e+4|0]|0;if(q<<24>>24==0){L=J;M=K;break}C=b[(c[277225]|0)+((q&255)<<1)>>1]|0;q=i+7|0;b[(c[277218]|0)+(q<<1)>>1]=C;b[(c[277218]|0)+(E<<1)>>1]=C;C=a[1108909]|0;a[(c[277219]|0)+q|0]=C;a[(c[277219]|0)+E|0]=C;L=a[1108908]|0;M=c[277219]|0}else{L=J;M=K}}while(0);E=i+8|0;do{if((L&255)>(d[M+E|0]|0)){C=a[e+3|0]|0;if(C<<24>>24==0){N=L;O=M;break}q=b[(c[277225]|0)+((C&255)<<1)>>1]|0;C=i+9|0;b[(c[277218]|0)+(C<<1)>>1]=q;b[(c[277218]|0)+(E<<1)>>1]=q;q=a[1108909]|0;a[(c[277219]|0)+C|0]=q;a[(c[277219]|0)+E|0]=q;N=a[1108908]|0;O=c[277219]|0}else{N=L;O=M}}while(0);E=i+10|0;do{if((N&255)>(d[O+E|0]|0)){q=a[e+2|0]|0;if(q<<24>>24==0){P=N;Q=O;break}C=b[(c[277225]|0)+((q&255)<<1)>>1]|0;q=i+11|0;b[(c[277218]|0)+(q<<1)>>1]=C;b[(c[277218]|0)+(E<<1)>>1]=C;C=a[1108909]|0;a[(c[277219]|0)+q|0]=C;a[(c[277219]|0)+E|0]=C;P=a[1108908]|0;Q=c[277219]|0}else{P=N;Q=O}}while(0);E=i+12|0;do{if((P&255)>(d[Q+E|0]|0)){C=a[e+1|0]|0;if(C<<24>>24==0){R=P;S=Q;break}q=b[(c[277225]|0)+((C&255)<<1)>>1]|0;C=i+13|0;b[(c[277218]|0)+(C<<1)>>1]=q;b[(c[277218]|0)+(E<<1)>>1]=q;q=a[1108909]|0;a[(c[277219]|0)+C|0]=q;a[(c[277219]|0)+E|0]=q;R=a[1108908]|0;S=c[277219]|0}else{R=P;S=Q}}while(0);E=i+14|0;do{if((R&255)>(d[S+E|0]|0)){q=a[e]|0;if(q<<24>>24==0){break}C=b[(c[277225]|0)+((q&255)<<1)>>1]|0;q=i+15|0;b[(c[277218]|0)+(q<<1)>>1]=C;b[(c[277218]|0)+(E<<1)>>1]=C;C=a[1108909]|0;a[(c[277219]|0)+q|0]=C;a[(c[277219]|0)+E|0]=C}}while(0);E=g-1|0;if((E|0)<=0){break}e=e+16|0;g=E;i=(c[277223]|0)+i|0}return}i=o+(56-l)|0;l=(h|0)>0;if(j){if(l){T=i;U=h;V=f}else{return}while(1){j=a[1108908]|0;o=c[277219]|0;do{if((j&255)>(d[o+V|0]|0)){g=a[T+7|0]|0;if(g<<24>>24==0){W=j;X=o;break}e=b[(c[277225]|0)+((g&255)<<1)>>1]|0;g=V+1|0;b[(c[277218]|0)+(g<<1)>>1]=e;b[(c[277218]|0)+(V<<1)>>1]=e;e=a[1108909]|0;a[(c[277219]|0)+g|0]=e;a[(c[277219]|0)+V|0]=e;W=a[1108908]|0;X=c[277219]|0}else{W=j;X=o}}while(0);o=V+2|0;do{if((W&255)>(d[X+o|0]|0)){j=a[T+6|0]|0;if(j<<24>>24==0){Y=W;Z=X;break}e=b[(c[277225]|0)+((j&255)<<1)>>1]|0;j=V+3|0;b[(c[277218]|0)+(j<<1)>>1]=e;b[(c[277218]|0)+(o<<1)>>1]=e;e=a[1108909]|0;a[(c[277219]|0)+j|0]=e;a[(c[277219]|0)+o|0]=e;Y=a[1108908]|0;Z=c[277219]|0}else{Y=W;Z=X}}while(0);o=V+4|0;do{if((Y&255)>(d[Z+o|0]|0)){e=a[T+5|0]|0;if(e<<24>>24==0){_=Y;$=Z;break}j=b[(c[277225]|0)+((e&255)<<1)>>1]|0;e=V+5|0;b[(c[277218]|0)+(e<<1)>>1]=j;b[(c[277218]|0)+(o<<1)>>1]=j;j=a[1108909]|0;a[(c[277219]|0)+e|0]=j;a[(c[277219]|0)+o|0]=j;_=a[1108908]|0;$=c[277219]|0}else{_=Y;$=Z}}while(0);o=V+6|0;do{if((_&255)>(d[$+o|0]|0)){j=a[T+4|0]|0;if(j<<24>>24==0){aa=_;ab=$;break}e=b[(c[277225]|0)+((j&255)<<1)>>1]|0;j=V+7|0;b[(c[277218]|0)+(j<<1)>>1]=e;b[(c[277218]|0)+(o<<1)>>1]=e;e=a[1108909]|0;a[(c[277219]|0)+j|0]=e;a[(c[277219]|0)+o|0]=e;aa=a[1108908]|0;ab=c[277219]|0}else{aa=_;ab=$}}while(0);o=V+8|0;do{if((aa&255)>(d[ab+o|0]|0)){e=a[T+3|0]|0;if(e<<24>>24==0){ac=aa;ad=ab;break}j=b[(c[277225]|0)+((e&255)<<1)>>1]|0;e=V+9|0;b[(c[277218]|0)+(e<<1)>>1]=j;b[(c[277218]|0)+(o<<1)>>1]=j;j=a[1108909]|0;a[(c[277219]|0)+e|0]=j;a[(c[277219]|0)+o|0]=j;ac=a[1108908]|0;ad=c[277219]|0}else{ac=aa;ad=ab}}while(0);o=V+10|0;do{if((ac&255)>(d[ad+o|0]|0)){j=a[T+2|0]|0;if(j<<24>>24==0){ae=ac;af=ad;break}e=b[(c[277225]|0)+((j&255)<<1)>>1]|0;j=V+11|0;b[(c[277218]|0)+(j<<1)>>1]=e;b[(c[277218]|0)+(o<<1)>>1]=e;e=a[1108909]|0;a[(c[277219]|0)+j|0]=e;a[(c[277219]|0)+o|0]=e;ae=a[1108908]|0;af=c[277219]|0}else{ae=ac;af=ad}}while(0);o=V+12|0;do{if((ae&255)>(d[af+o|0]|0)){e=a[T+1|0]|0;if(e<<24>>24==0){ag=ae;ah=af;break}j=b[(c[277225]|0)+((e&255)<<1)>>1]|0;e=V+13|0;b[(c[277218]|0)+(e<<1)>>1]=j;b[(c[277218]|0)+(o<<1)>>1]=j;j=a[1108909]|0;a[(c[277219]|0)+e|0]=j;a[(c[277219]|0)+o|0]=j;ag=a[1108908]|0;ah=c[277219]|0}else{ag=ae;ah=af}}while(0);o=V+14|0;do{if((ag&255)>(d[ah+o|0]|0)){j=a[T]|0;if(j<<24>>24==0){break}e=b[(c[277225]|0)+((j&255)<<1)>>1]|0;j=V+15|0;b[(c[277218]|0)+(j<<1)>>1]=e;b[(c[277218]|0)+(o<<1)>>1]=e;e=a[1108909]|0;a[(c[277219]|0)+j|0]=e;a[(c[277219]|0)+o|0]=e}}while(0);o=U-1|0;if((o|0)<=0){break}T=T-16|0;U=o;V=(c[277223]|0)+V|0}return}else{if(l){ai=i;aj=h;ak=f}else{return}while(1){f=a[1108908]|0;h=c[277219]|0;do{if((f&255)>(d[h+ak|0]|0)){i=a[ai]|0;if(i<<24>>24==0){al=f;am=h;break}l=b[(c[277225]|0)+((i&255)<<1)>>1]|0;i=ak+1|0;b[(c[277218]|0)+(i<<1)>>1]=l;b[(c[277218]|0)+(ak<<1)>>1]=l;l=a[1108909]|0;a[(c[277219]|0)+i|0]=l;a[(c[277219]|0)+ak|0]=l;al=a[1108908]|0;am=c[277219]|0}else{al=f;am=h}}while(0);h=ak+2|0;do{if((al&255)>(d[am+h|0]|0)){f=a[ai+1|0]|0;if(f<<24>>24==0){an=al;ao=am;break}l=b[(c[277225]|0)+((f&255)<<1)>>1]|0;f=ak+3|0;b[(c[277218]|0)+(f<<1)>>1]=l;b[(c[277218]|0)+(h<<1)>>1]=l;l=a[1108909]|0;a[(c[277219]|0)+f|0]=l;a[(c[277219]|0)+h|0]=l;an=a[1108908]|0;ao=c[277219]|0}else{an=al;ao=am}}while(0);h=ak+4|0;do{if((an&255)>(d[ao+h|0]|0)){l=a[ai+2|0]|0;if(l<<24>>24==0){ap=an;aq=ao;break}f=b[(c[277225]|0)+((l&255)<<1)>>1]|0;l=ak+5|0;b[(c[277218]|0)+(l<<1)>>1]=f;b[(c[277218]|0)+(h<<1)>>1]=f;f=a[1108909]|0;a[(c[277219]|0)+l|0]=f;a[(c[277219]|0)+h|0]=f;ap=a[1108908]|0;aq=c[277219]|0}else{ap=an;aq=ao}}while(0);h=ak+6|0;do{if((ap&255)>(d[aq+h|0]|0)){f=a[ai+3|0]|0;if(f<<24>>24==0){ar=ap;as=aq;break}l=b[(c[277225]|0)+((f&255)<<1)>>1]|0;f=ak+7|0;b[(c[277218]|0)+(f<<1)>>1]=l;b[(c[277218]|0)+(h<<1)>>1]=l;l=a[1108909]|0;a[(c[277219]|0)+f|0]=l;a[(c[277219]|0)+h|0]=l;ar=a[1108908]|0;as=c[277219]|0}else{ar=ap;as=aq}}while(0);h=ak+8|0;do{if((ar&255)>(d[as+h|0]|0)){l=a[ai+4|0]|0;if(l<<24>>24==0){at=ar;au=as;break}f=b[(c[277225]|0)+((l&255)<<1)>>1]|0;l=ak+9|0;b[(c[277218]|0)+(l<<1)>>1]=f;b[(c[277218]|0)+(h<<1)>>1]=f;f=a[1108909]|0;a[(c[277219]|0)+l|0]=f;a[(c[277219]|0)+h|0]=f;at=a[1108908]|0;au=c[277219]|0}else{at=ar;au=as}}while(0);h=ak+10|0;do{if((at&255)>(d[au+h|0]|0)){f=a[ai+5|0]|0;if(f<<24>>24==0){av=at;aw=au;break}l=b[(c[277225]|0)+((f&255)<<1)>>1]|0;f=ak+11|0;b[(c[277218]|0)+(f<<1)>>1]=l;b[(c[277218]|0)+(h<<1)>>1]=l;l=a[1108909]|0;a[(c[277219]|0)+f|0]=l;a[(c[277219]|0)+h|0]=l;av=a[1108908]|0;aw=c[277219]|0}else{av=at;aw=au}}while(0);h=ak+12|0;do{if((av&255)>(d[aw+h|0]|0)){l=a[ai+6|0]|0;if(l<<24>>24==0){ax=av;ay=aw;break}f=b[(c[277225]|0)+((l&255)<<1)>>1]|0;l=ak+13|0;b[(c[277218]|0)+(l<<1)>>1]=f;b[(c[277218]|0)+(h<<1)>>1]=f;f=a[1108909]|0;a[(c[277219]|0)+l|0]=f;a[(c[277219]|0)+h|0]=f;ax=a[1108908]|0;ay=c[277219]|0}else{ax=av;ay=aw}}while(0);h=ak+14|0;do{if((ax&255)>(d[ay+h|0]|0)){f=a[ai+7|0]|0;if(f<<24>>24==0){break}l=b[(c[277225]|0)+((f&255)<<1)>>1]|0;f=ak+15|0;b[(c[277218]|0)+(f<<1)>>1]=l;b[(c[277218]|0)+(h<<1)>>1]=l;l=a[1108909]|0;a[(c[277219]|0)+f|0]=l;a[(c[277219]|0)+h|0]=l}}while(0);h=aj-1|0;if((h|0)<=0){break}ai=ai-16|0;aj=h;ak=(c[277223]|0)+ak|0}return}}
function Vn(f,g,h,i){f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0;j=f&1023;k=c[348606]|0;l=(j<<k)+(c[348604]|0)|0;if((f&256|0)==0){m=l}else{m=(c[348602]|0)+l|0}l=m&65535;m=l>>>(k>>>0);k=(f&16384|0)!=0;n=m<<6;do{if(k){o=(c[348622]|0)+n|0;if((a[(c[348618]|0)+m|0]|0)!=0){p=o;break}q=fi[c[348636]&63](o,l,j)|0;a[(c[348618]|0)+m|0]=q;p=o}else{o=(c[348624]|0)+n|0;if((a[(c[348620]|0)+m|0]|0)!=0){p=o;break}q=fi[c[348638]&63](o,l,j)|0;a[(c[348620]|0)+m|0]=q;p=o}}while(0);if((a[(c[348620]|0)+m|0]|0)==2){return}if((a[1394464]|0)==0){r=1106168+((f>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){m=d[1044485]|0;c[276541]=7080+(m<<5);j=0;do{l=j<<1&2;n=j&2;o=j&4;q=0;do{b[1125528+(j<<9)+(q<<1)>>1]=d[(q>>>1&28|n)+(7080+(m<<5))|0]<<6|d[(q<<2&28|l)+(7080+(m<<5))|0]<<11|d[(q>>>3&24|o)+(7080+(m<<5))|0];q=q+1|0;}while(q>>>0<256);j=j+1|0;}while(j>>>0<8);a[1106089]=0}r=1125528+((f>>>10&7)<<9)|0}c[277226]=r;c[277225]=(a[1108928]|0)!=0?1393712:r;if((f&49152|0)==0){if((i|0)<=0){return}r=p+((d[1394504]|0)+(h<<1))|0;j=i;m=g;while(1){q=a[1108908]|0;o=c[277219]|0;do{if((q&255)>(d[o+m|0]|0)){l=a[r]|0;if(l<<24>>24==0){s=q;t=o;break}n=e[(c[277225]|0)+((l&255)<<1)>>1]|0;l=(a[(c[277215]|0)+m|0]&32)==0;if(l){u=c[277228]|0;v=u;w=u&-2082}else{u=e[(c[277213]|0)+(m<<1)>>1]|0;v=u;w=u&63454}if(l){x=c[277228]|0}else{x=e[(c[277213]|0)+(m<<1)>>1]|0}l=((x^n)&2081|e[(c[277220]|0)+((n&2081&v)+((w+(n&63454)|0)>>>1)<<1)>>1])&65535;n=m+1|0;b[(c[277218]|0)+(n<<1)>>1]=l;b[(c[277218]|0)+(m<<1)>>1]=l;l=a[1108909]|0;a[(c[277219]|0)+n|0]=l;a[(c[277219]|0)+m|0]=l;s=a[1108908]|0;t=c[277219]|0}else{s=q;t=o}}while(0);o=m+2|0;do{if((s&255)>(d[t+o|0]|0)){q=a[r+1|0]|0;if(q<<24>>24==0){y=s;z=t;break}l=e[(c[277225]|0)+((q&255)<<1)>>1]|0;q=(a[(c[277215]|0)+o|0]&32)==0;if(q){n=c[277228]|0;A=n;B=n&-2082}else{n=e[(c[277213]|0)+(o<<1)>>1]|0;A=n;B=n&63454}if(q){C=c[277228]|0}else{C=e[(c[277213]|0)+(o<<1)>>1]|0}q=((C^l)&2081|e[(c[277220]|0)+((l&2081&A)+((B+(l&63454)|0)>>>1)<<1)>>1])&65535;l=m+3|0;b[(c[277218]|0)+(l<<1)>>1]=q;b[(c[277218]|0)+(o<<1)>>1]=q;q=a[1108909]|0;a[(c[277219]|0)+l|0]=q;a[(c[277219]|0)+o|0]=q;y=a[1108908]|0;z=c[277219]|0}else{y=s;z=t}}while(0);o=m+4|0;do{if((y&255)>(d[z+o|0]|0)){q=a[r+2|0]|0;if(q<<24>>24==0){D=y;E=z;break}l=e[(c[277225]|0)+((q&255)<<1)>>1]|0;q=(a[(c[277215]|0)+o|0]&32)==0;if(q){n=c[277228]|0;F=n;G=n&-2082}else{n=e[(c[277213]|0)+(o<<1)>>1]|0;F=n;G=n&63454}if(q){H=c[277228]|0}else{H=e[(c[277213]|0)+(o<<1)>>1]|0}q=((H^l)&2081|e[(c[277220]|0)+((l&2081&F)+((G+(l&63454)|0)>>>1)<<1)>>1])&65535;l=m+5|0;b[(c[277218]|0)+(l<<1)>>1]=q;b[(c[277218]|0)+(o<<1)>>1]=q;q=a[1108909]|0;a[(c[277219]|0)+l|0]=q;a[(c[277219]|0)+o|0]=q;D=a[1108908]|0;E=c[277219]|0}else{D=y;E=z}}while(0);o=m+6|0;do{if((D&255)>(d[E+o|0]|0)){q=a[r+3|0]|0;if(q<<24>>24==0){I=D;J=E;break}l=e[(c[277225]|0)+((q&255)<<1)>>1]|0;q=(a[(c[277215]|0)+o|0]&32)==0;if(q){n=c[277228]|0;K=n;L=n&-2082}else{n=e[(c[277213]|0)+(o<<1)>>1]|0;K=n;L=n&63454}if(q){M=c[277228]|0}else{M=e[(c[277213]|0)+(o<<1)>>1]|0}q=((M^l)&2081|e[(c[277220]|0)+((l&2081&K)+((L+(l&63454)|0)>>>1)<<1)>>1])&65535;l=m+7|0;b[(c[277218]|0)+(l<<1)>>1]=q;b[(c[277218]|0)+(o<<1)>>1]=q;q=a[1108909]|0;a[(c[277219]|0)+l|0]=q;a[(c[277219]|0)+o|0]=q;I=a[1108908]|0;J=c[277219]|0}else{I=D;J=E}}while(0);o=m+8|0;do{if((I&255)>(d[J+o|0]|0)){q=a[r+4|0]|0;if(q<<24>>24==0){N=I;O=J;break}l=e[(c[277225]|0)+((q&255)<<1)>>1]|0;q=(a[(c[277215]|0)+o|0]&32)==0;if(q){n=c[277228]|0;P=n;Q=n&-2082}else{n=e[(c[277213]|0)+(o<<1)>>1]|0;P=n;Q=n&63454}if(q){R=c[277228]|0}else{R=e[(c[277213]|0)+(o<<1)>>1]|0}q=((R^l)&2081|e[(c[277220]|0)+((l&2081&P)+((Q+(l&63454)|0)>>>1)<<1)>>1])&65535;l=m+9|0;b[(c[277218]|0)+(l<<1)>>1]=q;b[(c[277218]|0)+(o<<1)>>1]=q;q=a[1108909]|0;a[(c[277219]|0)+l|0]=q;a[(c[277219]|0)+o|0]=q;N=a[1108908]|0;O=c[277219]|0}else{N=I;O=J}}while(0);o=m+10|0;do{if((N&255)>(d[O+o|0]|0)){q=a[r+5|0]|0;if(q<<24>>24==0){S=N;T=O;break}l=e[(c[277225]|0)+((q&255)<<1)>>1]|0;q=(a[(c[277215]|0)+o|0]&32)==0;if(q){n=c[277228]|0;U=n;V=n&-2082}else{n=e[(c[277213]|0)+(o<<1)>>1]|0;U=n;V=n&63454}if(q){W=c[277228]|0}else{W=e[(c[277213]|0)+(o<<1)>>1]|0}q=((W^l)&2081|e[(c[277220]|0)+((l&2081&U)+((V+(l&63454)|0)>>>1)<<1)>>1])&65535;l=m+11|0;b[(c[277218]|0)+(l<<1)>>1]=q;b[(c[277218]|0)+(o<<1)>>1]=q;q=a[1108909]|0;a[(c[277219]|0)+l|0]=q;a[(c[277219]|0)+o|0]=q;S=a[1108908]|0;T=c[277219]|0}else{S=N;T=O}}while(0);o=m+12|0;do{if((S&255)>(d[T+o|0]|0)){q=a[r+6|0]|0;if(q<<24>>24==0){X=S;Y=T;break}l=e[(c[277225]|0)+((q&255)<<1)>>1]|0;q=(a[(c[277215]|0)+o|0]&32)==0;if(q){n=c[277228]|0;Z=n;_=n&-2082}else{n=e[(c[277213]|0)+(o<<1)>>1]|0;Z=n;_=n&63454}if(q){$=c[277228]|0}else{$=e[(c[277213]|0)+(o<<1)>>1]|0}q=(($^l)&2081|e[(c[277220]|0)+((l&2081&Z)+((_+(l&63454)|0)>>>1)<<1)>>1])&65535;l=m+13|0;b[(c[277218]|0)+(l<<1)>>1]=q;b[(c[277218]|0)+(o<<1)>>1]=q;q=a[1108909]|0;a[(c[277219]|0)+l|0]=q;a[(c[277219]|0)+o|0]=q;X=a[1108908]|0;Y=c[277219]|0}else{X=S;Y=T}}while(0);o=m+14|0;do{if((X&255)>(d[Y+o|0]|0)){q=a[r+7|0]|0;if(q<<24>>24==0){break}l=e[(c[277225]|0)+((q&255)<<1)>>1]|0;q=(a[(c[277215]|0)+o|0]&32)==0;if(q){n=c[277228]|0;aa=n;ab=n&-2082}else{n=e[(c[277213]|0)+(o<<1)>>1]|0;aa=n;ab=n&63454}if(q){ac=c[277228]|0}else{ac=e[(c[277213]|0)+(o<<1)>>1]|0}q=((ac^l)&2081|e[(c[277220]|0)+((l&2081&aa)+((ab+(l&63454)|0)>>>1)<<1)>>1])&65535;l=m+15|0;b[(c[277218]|0)+(l<<1)>>1]=q;b[(c[277218]|0)+(o<<1)>>1]=q;q=a[1108909]|0;a[(c[277219]|0)+l|0]=q;a[(c[277219]|0)+o|0]=q}}while(0);o=j-1|0;if((o|0)<=0){break}r=r+16|0;j=o;m=(c[277223]|0)+m|0}return}m=(d[1394504]|0)+(h<<1)|0;if((f&32768|0)==0){if((i|0)<=0){return}f=p+m|0;h=i;j=g;while(1){r=a[1108908]|0;ab=c[277219]|0;do{if((r&255)>(d[ab+j|0]|0)){aa=a[f+7|0]|0;if(aa<<24>>24==0){ad=r;ae=ab;break}ac=e[(c[277225]|0)+((aa&255)<<1)>>1]|0;aa=(a[(c[277215]|0)+j|0]&32)==0;if(aa){Y=c[277228]|0;af=Y;ag=Y&-2082}else{Y=e[(c[277213]|0)+(j<<1)>>1]|0;af=Y;ag=Y&63454}if(aa){ah=c[277228]|0}else{ah=e[(c[277213]|0)+(j<<1)>>1]|0}aa=((ah^ac)&2081|e[(c[277220]|0)+((ac&2081&af)+((ag+(ac&63454)|0)>>>1)<<1)>>1])&65535;ac=j+1|0;b[(c[277218]|0)+(ac<<1)>>1]=aa;b[(c[277218]|0)+(j<<1)>>1]=aa;aa=a[1108909]|0;a[(c[277219]|0)+ac|0]=aa;a[(c[277219]|0)+j|0]=aa;ad=a[1108908]|0;ae=c[277219]|0}else{ad=r;ae=ab}}while(0);ab=j+2|0;do{if((ad&255)>(d[ae+ab|0]|0)){r=a[f+6|0]|0;if(r<<24>>24==0){ai=ad;aj=ae;break}aa=e[(c[277225]|0)+((r&255)<<1)>>1]|0;r=(a[(c[277215]|0)+ab|0]&32)==0;if(r){ac=c[277228]|0;ak=ac;al=ac&-2082}else{ac=e[(c[277213]|0)+(ab<<1)>>1]|0;ak=ac;al=ac&63454}if(r){am=c[277228]|0}else{am=e[(c[277213]|0)+(ab<<1)>>1]|0}r=((am^aa)&2081|e[(c[277220]|0)+((aa&2081&ak)+((al+(aa&63454)|0)>>>1)<<1)>>1])&65535;aa=j+3|0;b[(c[277218]|0)+(aa<<1)>>1]=r;b[(c[277218]|0)+(ab<<1)>>1]=r;r=a[1108909]|0;a[(c[277219]|0)+aa|0]=r;a[(c[277219]|0)+ab|0]=r;ai=a[1108908]|0;aj=c[277219]|0}else{ai=ad;aj=ae}}while(0);ab=j+4|0;do{if((ai&255)>(d[aj+ab|0]|0)){r=a[f+5|0]|0;if(r<<24>>24==0){an=ai;ao=aj;break}aa=e[(c[277225]|0)+((r&255)<<1)>>1]|0;r=(a[(c[277215]|0)+ab|0]&32)==0;if(r){ac=c[277228]|0;ap=ac;aq=ac&-2082}else{ac=e[(c[277213]|0)+(ab<<1)>>1]|0;ap=ac;aq=ac&63454}if(r){ar=c[277228]|0}else{ar=e[(c[277213]|0)+(ab<<1)>>1]|0}r=((ar^aa)&2081|e[(c[277220]|0)+((aa&2081&ap)+((aq+(aa&63454)|0)>>>1)<<1)>>1])&65535;aa=j+5|0;b[(c[277218]|0)+(aa<<1)>>1]=r;b[(c[277218]|0)+(ab<<1)>>1]=r;r=a[1108909]|0;a[(c[277219]|0)+aa|0]=r;a[(c[277219]|0)+ab|0]=r;an=a[1108908]|0;ao=c[277219]|0}else{an=ai;ao=aj}}while(0);ab=j+6|0;do{if((an&255)>(d[ao+ab|0]|0)){r=a[f+4|0]|0;if(r<<24>>24==0){as=an;at=ao;break}aa=e[(c[277225]|0)+((r&255)<<1)>>1]|0;r=(a[(c[277215]|0)+ab|0]&32)==0;if(r){ac=c[277228]|0;au=ac;av=ac&-2082}else{ac=e[(c[277213]|0)+(ab<<1)>>1]|0;au=ac;av=ac&63454}if(r){aw=c[277228]|0}else{aw=e[(c[277213]|0)+(ab<<1)>>1]|0}r=((aw^aa)&2081|e[(c[277220]|0)+((aa&2081&au)+((av+(aa&63454)|0)>>>1)<<1)>>1])&65535;aa=j+7|0;b[(c[277218]|0)+(aa<<1)>>1]=r;b[(c[277218]|0)+(ab<<1)>>1]=r;r=a[1108909]|0;a[(c[277219]|0)+aa|0]=r;a[(c[277219]|0)+ab|0]=r;as=a[1108908]|0;at=c[277219]|0}else{as=an;at=ao}}while(0);ab=j+8|0;do{if((as&255)>(d[at+ab|0]|0)){r=a[f+3|0]|0;if(r<<24>>24==0){ax=as;ay=at;break}aa=e[(c[277225]|0)+((r&255)<<1)>>1]|0;r=(a[(c[277215]|0)+ab|0]&32)==0;if(r){ac=c[277228]|0;az=ac;aA=ac&-2082}else{ac=e[(c[277213]|0)+(ab<<1)>>1]|0;az=ac;aA=ac&63454}if(r){aB=c[277228]|0}else{aB=e[(c[277213]|0)+(ab<<1)>>1]|0}r=((aB^aa)&2081|e[(c[277220]|0)+((aa&2081&az)+((aA+(aa&63454)|0)>>>1)<<1)>>1])&65535;aa=j+9|0;b[(c[277218]|0)+(aa<<1)>>1]=r;b[(c[277218]|0)+(ab<<1)>>1]=r;r=a[1108909]|0;a[(c[277219]|0)+aa|0]=r;a[(c[277219]|0)+ab|0]=r;ax=a[1108908]|0;ay=c[277219]|0}else{ax=as;ay=at}}while(0);ab=j+10|0;do{if((ax&255)>(d[ay+ab|0]|0)){r=a[f+2|0]|0;if(r<<24>>24==0){aC=ax;aD=ay;break}aa=e[(c[277225]|0)+((r&255)<<1)>>1]|0;r=(a[(c[277215]|0)+ab|0]&32)==0;if(r){ac=c[277228]|0;aE=ac;aF=ac&-2082}else{ac=e[(c[277213]|0)+(ab<<1)>>1]|0;aE=ac;aF=ac&63454}if(r){aG=c[277228]|0}else{aG=e[(c[277213]|0)+(ab<<1)>>1]|0}r=((aG^aa)&2081|e[(c[277220]|0)+((aa&2081&aE)+((aF+(aa&63454)|0)>>>1)<<1)>>1])&65535;aa=j+11|0;b[(c[277218]|0)+(aa<<1)>>1]=r;b[(c[277218]|0)+(ab<<1)>>1]=r;r=a[1108909]|0;a[(c[277219]|0)+aa|0]=r;a[(c[277219]|0)+ab|0]=r;aC=a[1108908]|0;aD=c[277219]|0}else{aC=ax;aD=ay}}while(0);ab=j+12|0;do{if((aC&255)>(d[aD+ab|0]|0)){r=a[f+1|0]|0;if(r<<24>>24==0){aH=aC;aI=aD;break}aa=e[(c[277225]|0)+((r&255)<<1)>>1]|0;r=(a[(c[277215]|0)+ab|0]&32)==0;if(r){ac=c[277228]|0;aJ=ac;aK=ac&-2082}else{ac=e[(c[277213]|0)+(ab<<1)>>1]|0;aJ=ac;aK=ac&63454}if(r){aL=c[277228]|0}else{aL=e[(c[277213]|0)+(ab<<1)>>1]|0}r=((aL^aa)&2081|e[(c[277220]|0)+((aa&2081&aJ)+((aK+(aa&63454)|0)>>>1)<<1)>>1])&65535;aa=j+13|0;b[(c[277218]|0)+(aa<<1)>>1]=r;b[(c[277218]|0)+(ab<<1)>>1]=r;r=a[1108909]|0;a[(c[277219]|0)+aa|0]=r;a[(c[277219]|0)+ab|0]=r;aH=a[1108908]|0;aI=c[277219]|0}else{aH=aC;aI=aD}}while(0);ab=j+14|0;do{if((aH&255)>(d[aI+ab|0]|0)){r=a[f]|0;if(r<<24>>24==0){break}aa=e[(c[277225]|0)+((r&255)<<1)>>1]|0;r=(a[(c[277215]|0)+ab|0]&32)==0;if(r){ac=c[277228]|0;aM=ac;aN=ac&-2082}else{ac=e[(c[277213]|0)+(ab<<1)>>1]|0;aM=ac;aN=ac&63454}if(r){aO=c[277228]|0}else{aO=e[(c[277213]|0)+(ab<<1)>>1]|0}r=((aO^aa)&2081|e[(c[277220]|0)+((aa&2081&aM)+((aN+(aa&63454)|0)>>>1)<<1)>>1])&65535;aa=j+15|0;b[(c[277218]|0)+(aa<<1)>>1]=r;b[(c[277218]|0)+(ab<<1)>>1]=r;r=a[1108909]|0;a[(c[277219]|0)+aa|0]=r;a[(c[277219]|0)+ab|0]=r}}while(0);ab=h-1|0;if((ab|0)<=0){break}f=f+16|0;h=ab;j=(c[277223]|0)+j|0}return}j=p+(56-m)|0;m=(i|0)>0;if(k){if(m){aP=j;aQ=i;aR=g}else{return}while(1){k=a[1108908]|0;p=c[277219]|0;do{if((k&255)>(d[p+aR|0]|0)){h=a[aP+7|0]|0;if(h<<24>>24==0){aS=k;aT=p;break}f=e[(c[277225]|0)+((h&255)<<1)>>1]|0;h=(a[(c[277215]|0)+aR|0]&32)==0;if(h){aN=c[277228]|0;aU=aN;aV=aN&-2082}else{aN=e[(c[277213]|0)+(aR<<1)>>1]|0;aU=aN;aV=aN&63454}if(h){aW=c[277228]|0}else{aW=e[(c[277213]|0)+(aR<<1)>>1]|0}h=((aW^f)&2081|e[(c[277220]|0)+((f&2081&aU)+((aV+(f&63454)|0)>>>1)<<1)>>1])&65535;f=aR+1|0;b[(c[277218]|0)+(f<<1)>>1]=h;b[(c[277218]|0)+(aR<<1)>>1]=h;h=a[1108909]|0;a[(c[277219]|0)+f|0]=h;a[(c[277219]|0)+aR|0]=h;aS=a[1108908]|0;aT=c[277219]|0}else{aS=k;aT=p}}while(0);p=aR+2|0;do{if((aS&255)>(d[aT+p|0]|0)){k=a[aP+6|0]|0;if(k<<24>>24==0){aX=aS;aY=aT;break}h=e[(c[277225]|0)+((k&255)<<1)>>1]|0;k=(a[(c[277215]|0)+p|0]&32)==0;if(k){f=c[277228]|0;aZ=f;a_=f&-2082}else{f=e[(c[277213]|0)+(p<<1)>>1]|0;aZ=f;a_=f&63454}if(k){a$=c[277228]|0}else{a$=e[(c[277213]|0)+(p<<1)>>1]|0}k=((a$^h)&2081|e[(c[277220]|0)+((h&2081&aZ)+((a_+(h&63454)|0)>>>1)<<1)>>1])&65535;h=aR+3|0;b[(c[277218]|0)+(h<<1)>>1]=k;b[(c[277218]|0)+(p<<1)>>1]=k;k=a[1108909]|0;a[(c[277219]|0)+h|0]=k;a[(c[277219]|0)+p|0]=k;aX=a[1108908]|0;aY=c[277219]|0}else{aX=aS;aY=aT}}while(0);p=aR+4|0;do{if((aX&255)>(d[aY+p|0]|0)){k=a[aP+5|0]|0;if(k<<24>>24==0){a0=aX;a1=aY;break}h=e[(c[277225]|0)+((k&255)<<1)>>1]|0;k=(a[(c[277215]|0)+p|0]&32)==0;if(k){f=c[277228]|0;a2=f;a3=f&-2082}else{f=e[(c[277213]|0)+(p<<1)>>1]|0;a2=f;a3=f&63454}if(k){a4=c[277228]|0}else{a4=e[(c[277213]|0)+(p<<1)>>1]|0}k=((a4^h)&2081|e[(c[277220]|0)+((h&2081&a2)+((a3+(h&63454)|0)>>>1)<<1)>>1])&65535;h=aR+5|0;b[(c[277218]|0)+(h<<1)>>1]=k;b[(c[277218]|0)+(p<<1)>>1]=k;k=a[1108909]|0;a[(c[277219]|0)+h|0]=k;a[(c[277219]|0)+p|0]=k;a0=a[1108908]|0;a1=c[277219]|0}else{a0=aX;a1=aY}}while(0);p=aR+6|0;do{if((a0&255)>(d[a1+p|0]|0)){k=a[aP+4|0]|0;if(k<<24>>24==0){a5=a0;a6=a1;break}h=e[(c[277225]|0)+((k&255)<<1)>>1]|0;k=(a[(c[277215]|0)+p|0]&32)==0;if(k){f=c[277228]|0;a7=f;a8=f&-2082}else{f=e[(c[277213]|0)+(p<<1)>>1]|0;a7=f;a8=f&63454}if(k){a9=c[277228]|0}else{a9=e[(c[277213]|0)+(p<<1)>>1]|0}k=((a9^h)&2081|e[(c[277220]|0)+((h&2081&a7)+((a8+(h&63454)|0)>>>1)<<1)>>1])&65535;h=aR+7|0;b[(c[277218]|0)+(h<<1)>>1]=k;b[(c[277218]|0)+(p<<1)>>1]=k;k=a[1108909]|0;a[(c[277219]|0)+h|0]=k;a[(c[277219]|0)+p|0]=k;a5=a[1108908]|0;a6=c[277219]|0}else{a5=a0;a6=a1}}while(0);p=aR+8|0;do{if((a5&255)>(d[a6+p|0]|0)){k=a[aP+3|0]|0;if(k<<24>>24==0){ba=a5;bb=a6;break}h=e[(c[277225]|0)+((k&255)<<1)>>1]|0;k=(a[(c[277215]|0)+p|0]&32)==0;if(k){f=c[277228]|0;bc=f;bd=f&-2082}else{f=e[(c[277213]|0)+(p<<1)>>1]|0;bc=f;bd=f&63454}if(k){be=c[277228]|0}else{be=e[(c[277213]|0)+(p<<1)>>1]|0}k=((be^h)&2081|e[(c[277220]|0)+((h&2081&bc)+((bd+(h&63454)|0)>>>1)<<1)>>1])&65535;h=aR+9|0;b[(c[277218]|0)+(h<<1)>>1]=k;b[(c[277218]|0)+(p<<1)>>1]=k;k=a[1108909]|0;a[(c[277219]|0)+h|0]=k;a[(c[277219]|0)+p|0]=k;ba=a[1108908]|0;bb=c[277219]|0}else{ba=a5;bb=a6}}while(0);p=aR+10|0;do{if((ba&255)>(d[bb+p|0]|0)){k=a[aP+2|0]|0;if(k<<24>>24==0){bf=ba;bg=bb;break}h=e[(c[277225]|0)+((k&255)<<1)>>1]|0;k=(a[(c[277215]|0)+p|0]&32)==0;if(k){f=c[277228]|0;bh=f;bi=f&-2082}else{f=e[(c[277213]|0)+(p<<1)>>1]|0;bh=f;bi=f&63454}if(k){bj=c[277228]|0}else{bj=e[(c[277213]|0)+(p<<1)>>1]|0}k=((bj^h)&2081|e[(c[277220]|0)+((h&2081&bh)+((bi+(h&63454)|0)>>>1)<<1)>>1])&65535;h=aR+11|0;b[(c[277218]|0)+(h<<1)>>1]=k;b[(c[277218]|0)+(p<<1)>>1]=k;k=a[1108909]|0;a[(c[277219]|0)+h|0]=k;a[(c[277219]|0)+p|0]=k;bf=a[1108908]|0;bg=c[277219]|0}else{bf=ba;bg=bb}}while(0);p=aR+12|0;do{if((bf&255)>(d[bg+p|0]|0)){k=a[aP+1|0]|0;if(k<<24>>24==0){bk=bf;bl=bg;break}h=e[(c[277225]|0)+((k&255)<<1)>>1]|0;k=(a[(c[277215]|0)+p|0]&32)==0;if(k){f=c[277228]|0;bm=f;bn=f&-2082}else{f=e[(c[277213]|0)+(p<<1)>>1]|0;bm=f;bn=f&63454}if(k){bo=c[277228]|0}else{bo=e[(c[277213]|0)+(p<<1)>>1]|0}k=((bo^h)&2081|e[(c[277220]|0)+((h&2081&bm)+((bn+(h&63454)|0)>>>1)<<1)>>1])&65535;h=aR+13|0;b[(c[277218]|0)+(h<<1)>>1]=k;b[(c[277218]|0)+(p<<1)>>1]=k;k=a[1108909]|0;a[(c[277219]|0)+h|0]=k;a[(c[277219]|0)+p|0]=k;bk=a[1108908]|0;bl=c[277219]|0}else{bk=bf;bl=bg}}while(0);p=aR+14|0;do{if((bk&255)>(d[bl+p|0]|0)){k=a[aP]|0;if(k<<24>>24==0){break}h=e[(c[277225]|0)+((k&255)<<1)>>1]|0;k=(a[(c[277215]|0)+p|0]&32)==0;if(k){f=c[277228]|0;bp=f;bq=f&-2082}else{f=e[(c[277213]|0)+(p<<1)>>1]|0;bp=f;bq=f&63454}if(k){br=c[277228]|0}else{br=e[(c[277213]|0)+(p<<1)>>1]|0}k=((br^h)&2081|e[(c[277220]|0)+((h&2081&bp)+((bq+(h&63454)|0)>>>1)<<1)>>1])&65535;h=aR+15|0;b[(c[277218]|0)+(h<<1)>>1]=k;b[(c[277218]|0)+(p<<1)>>1]=k;k=a[1108909]|0;a[(c[277219]|0)+h|0]=k;a[(c[277219]|0)+p|0]=k}}while(0);p=aQ-1|0;if((p|0)<=0){break}aP=aP-16|0;aQ=p;aR=(c[277223]|0)+aR|0}return}else{if(m){bs=j;bt=i;bu=g}else{return}while(1){g=a[1108908]|0;i=c[277219]|0;do{if((g&255)>(d[i+bu|0]|0)){j=a[bs]|0;if(j<<24>>24==0){bv=g;bw=i;break}m=e[(c[277225]|0)+((j&255)<<1)>>1]|0;j=(a[(c[277215]|0)+bu|0]&32)==0;if(j){aR=c[277228]|0;bx=aR;by=aR&-2082}else{aR=e[(c[277213]|0)+(bu<<1)>>1]|0;bx=aR;by=aR&63454}if(j){bz=c[277228]|0}else{bz=e[(c[277213]|0)+(bu<<1)>>1]|0}j=((bz^m)&2081|e[(c[277220]|0)+((m&2081&bx)+((by+(m&63454)|0)>>>1)<<1)>>1])&65535;m=bu+1|0;b[(c[277218]|0)+(m<<1)>>1]=j;b[(c[277218]|0)+(bu<<1)>>1]=j;j=a[1108909]|0;a[(c[277219]|0)+m|0]=j;a[(c[277219]|0)+bu|0]=j;bv=a[1108908]|0;bw=c[277219]|0}else{bv=g;bw=i}}while(0);i=bu+2|0;do{if((bv&255)>(d[bw+i|0]|0)){g=a[bs+1|0]|0;if(g<<24>>24==0){bA=bv;bB=bw;break}j=e[(c[277225]|0)+((g&255)<<1)>>1]|0;g=(a[(c[277215]|0)+i|0]&32)==0;if(g){m=c[277228]|0;bC=m;bD=m&-2082}else{m=e[(c[277213]|0)+(i<<1)>>1]|0;bC=m;bD=m&63454}if(g){bE=c[277228]|0}else{bE=e[(c[277213]|0)+(i<<1)>>1]|0}g=((bE^j)&2081|e[(c[277220]|0)+((j&2081&bC)+((bD+(j&63454)|0)>>>1)<<1)>>1])&65535;j=bu+3|0;b[(c[277218]|0)+(j<<1)>>1]=g;b[(c[277218]|0)+(i<<1)>>1]=g;g=a[1108909]|0;a[(c[277219]|0)+j|0]=g;a[(c[277219]|0)+i|0]=g;bA=a[1108908]|0;bB=c[277219]|0}else{bA=bv;bB=bw}}while(0);i=bu+4|0;do{if((bA&255)>(d[bB+i|0]|0)){g=a[bs+2|0]|0;if(g<<24>>24==0){bF=bA;bG=bB;break}j=e[(c[277225]|0)+((g&255)<<1)>>1]|0;g=(a[(c[277215]|0)+i|0]&32)==0;if(g){m=c[277228]|0;bH=m;bI=m&-2082}else{m=e[(c[277213]|0)+(i<<1)>>1]|0;bH=m;bI=m&63454}if(g){bJ=c[277228]|0}else{bJ=e[(c[277213]|0)+(i<<1)>>1]|0}g=((bJ^j)&2081|e[(c[277220]|0)+((j&2081&bH)+((bI+(j&63454)|0)>>>1)<<1)>>1])&65535;j=bu+5|0;b[(c[277218]|0)+(j<<1)>>1]=g;b[(c[277218]|0)+(i<<1)>>1]=g;g=a[1108909]|0;a[(c[277219]|0)+j|0]=g;a[(c[277219]|0)+i|0]=g;bF=a[1108908]|0;bG=c[277219]|0}else{bF=bA;bG=bB}}while(0);i=bu+6|0;do{if((bF&255)>(d[bG+i|0]|0)){g=a[bs+3|0]|0;if(g<<24>>24==0){bK=bF;bL=bG;break}j=e[(c[277225]|0)+((g&255)<<1)>>1]|0;g=(a[(c[277215]|0)+i|0]&32)==0;if(g){m=c[277228]|0;bM=m;bN=m&-2082}else{m=e[(c[277213]|0)+(i<<1)>>1]|0;bM=m;bN=m&63454}if(g){bO=c[277228]|0}else{bO=e[(c[277213]|0)+(i<<1)>>1]|0}g=((bO^j)&2081|e[(c[277220]|0)+((j&2081&bM)+((bN+(j&63454)|0)>>>1)<<1)>>1])&65535;j=bu+7|0;b[(c[277218]|0)+(j<<1)>>1]=g;b[(c[277218]|0)+(i<<1)>>1]=g;g=a[1108909]|0;a[(c[277219]|0)+j|0]=g;a[(c[277219]|0)+i|0]=g;bK=a[1108908]|0;bL=c[277219]|0}else{bK=bF;bL=bG}}while(0);i=bu+8|0;do{if((bK&255)>(d[bL+i|0]|0)){g=a[bs+4|0]|0;if(g<<24>>24==0){bP=bK;bQ=bL;break}j=e[(c[277225]|0)+((g&255)<<1)>>1]|0;g=(a[(c[277215]|0)+i|0]&32)==0;if(g){m=c[277228]|0;bR=m;bS=m&-2082}else{m=e[(c[277213]|0)+(i<<1)>>1]|0;bR=m;bS=m&63454}if(g){bT=c[277228]|0}else{bT=e[(c[277213]|0)+(i<<1)>>1]|0}g=((bT^j)&2081|e[(c[277220]|0)+((j&2081&bR)+((bS+(j&63454)|0)>>>1)<<1)>>1])&65535;j=bu+9|0;b[(c[277218]|0)+(j<<1)>>1]=g;b[(c[277218]|0)+(i<<1)>>1]=g;g=a[1108909]|0;a[(c[277219]|0)+j|0]=g;a[(c[277219]|0)+i|0]=g;bP=a[1108908]|0;bQ=c[277219]|0}else{bP=bK;bQ=bL}}while(0);i=bu+10|0;do{if((bP&255)>(d[bQ+i|0]|0)){g=a[bs+5|0]|0;if(g<<24>>24==0){bU=bP;bV=bQ;break}j=e[(c[277225]|0)+((g&255)<<1)>>1]|0;g=(a[(c[277215]|0)+i|0]&32)==0;if(g){m=c[277228]|0;bW=m;bX=m&-2082}else{m=e[(c[277213]|0)+(i<<1)>>1]|0;bW=m;bX=m&63454}if(g){bY=c[277228]|0}else{bY=e[(c[277213]|0)+(i<<1)>>1]|0}g=((bY^j)&2081|e[(c[277220]|0)+((j&2081&bW)+((bX+(j&63454)|0)>>>1)<<1)>>1])&65535;j=bu+11|0;b[(c[277218]|0)+(j<<1)>>1]=g;b[(c[277218]|0)+(i<<1)>>1]=g;g=a[1108909]|0;a[(c[277219]|0)+j|0]=g;a[(c[277219]|0)+i|0]=g;bU=a[1108908]|0;bV=c[277219]|0}else{bU=bP;bV=bQ}}while(0);i=bu+12|0;do{if((bU&255)>(d[bV+i|0]|0)){g=a[bs+6|0]|0;if(g<<24>>24==0){bZ=bU;b_=bV;break}j=e[(c[277225]|0)+((g&255)<<1)>>1]|0;g=(a[(c[277215]|0)+i|0]&32)==0;if(g){m=c[277228]|0;b$=m;b0=m&-2082}else{m=e[(c[277213]|0)+(i<<1)>>1]|0;b$=m;b0=m&63454}if(g){b1=c[277228]|0}else{b1=e[(c[277213]|0)+(i<<1)>>1]|0}g=((b1^j)&2081|e[(c[277220]|0)+((j&2081&b$)+((b0+(j&63454)|0)>>>1)<<1)>>1])&65535;j=bu+13|0;b[(c[277218]|0)+(j<<1)>>1]=g;b[(c[277218]|0)+(i<<1)>>1]=g;g=a[1108909]|0;a[(c[277219]|0)+j|0]=g;a[(c[277219]|0)+i|0]=g;bZ=a[1108908]|0;b_=c[277219]|0}else{bZ=bU;b_=bV}}while(0);i=bu+14|0;do{if((bZ&255)>(d[b_+i|0]|0)){g=a[bs+7|0]|0;if(g<<24>>24==0){break}j=e[(c[277225]|0)+((g&255)<<1)>>1]|0;g=(a[(c[277215]|0)+i|0]&32)==0;if(g){m=c[277228]|0;b2=m;b3=m&-2082}else{m=e[(c[277213]|0)+(i<<1)>>1]|0;b2=m;b3=m&63454}if(g){b4=c[277228]|0}else{b4=e[(c[277213]|0)+(i<<1)>>1]|0}g=((b4^j)&2081|e[(c[277220]|0)+((j&2081&b2)+((b3+(j&63454)|0)>>>1)<<1)>>1])&65535;j=bu+15|0;b[(c[277218]|0)+(j<<1)>>1]=g;b[(c[277218]|0)+(i<<1)>>1]=g;g=a[1108909]|0;a[(c[277219]|0)+j|0]=g;a[(c[277219]|0)+i|0]=g}}while(0);i=bt-1|0;if((i|0)<=0){break}bs=bs-16|0;bt=i;bu=(c[277223]|0)+bu|0}return}}function Vo(f,g,h,i){f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0;j=f&1023;k=c[348606]|0;l=(j<<k)+(c[348604]|0)|0;if((f&256|0)==0){m=l}else{m=(c[348602]|0)+l|0}l=m&65535;m=l>>>(k>>>0);k=(f&16384|0)!=0;n=m<<6;do{if(k){o=(c[348622]|0)+n|0;if((a[(c[348618]|0)+m|0]|0)!=0){p=o;break}q=fi[c[348636]&63](o,l,j)|0;a[(c[348618]|0)+m|0]=q;p=o}else{o=(c[348624]|0)+n|0;if((a[(c[348620]|0)+m|0]|0)!=0){p=o;break}q=fi[c[348638]&63](o,l,j)|0;a[(c[348620]|0)+m|0]=q;p=o}}while(0);if((a[(c[348620]|0)+m|0]|0)==2){return}if((a[1394464]|0)==0){r=1106168+((f>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){m=d[1044485]|0;c[276541]=7080+(m<<5);j=0;do{l=j<<1&2;n=j&2;o=j&4;q=0;do{b[1125528+(j<<9)+(q<<1)>>1]=d[(q>>>1&28|n)+(7080+(m<<5))|0]<<6|d[(q<<2&28|l)+(7080+(m<<5))|0]<<11|d[(q>>>3&24|o)+(7080+(m<<5))|0];q=q+1|0;}while(q>>>0<256);j=j+1|0;}while(j>>>0<8);a[1106089]=0}r=1125528+((f>>>10&7)<<9)|0}c[277226]=r;c[277225]=(a[1108928]|0)!=0?1393712:r;if((f&49152|0)==0){if((i|0)<=0){return}r=p+((d[1394504]|0)+(h<<1))|0;j=i;m=g;while(1){q=a[1108908]|0;o=c[277219]|0;do{if((q&255)>(d[o+m|0]|0)){l=a[r]|0;if(l<<24>>24==0){s=q;t=o;break}n=e[(c[277225]|0)+((l&255)<<1)>>1]|0;l=c[277228]|0;u=(((n&63454)+(l&-2082)|0)>>>1)+(l&2081&n)|0;if((a[1108928]|0)==0){v=u&65535}else{v=(e[(c[277220]|0)+(u<<1)>>1]|(n^l)&2081)&65535}l=m+1|0;b[(c[277218]|0)+(l<<1)>>1]=v;b[(c[277218]|0)+(m<<1)>>1]=v;n=a[1108909]|0;a[(c[277219]|0)+l|0]=n;a[(c[277219]|0)+m|0]=n;s=a[1108908]|0;t=c[277219]|0}else{s=q;t=o}}while(0);o=m+2|0;do{if((s&255)>(d[t+o|0]|0)){q=a[r+1|0]|0;if(q<<24>>24==0){w=s;x=t;break}n=e[(c[277225]|0)+((q&255)<<1)>>1]|0;q=c[277228]|0;l=(((n&63454)+(q&-2082)|0)>>>1)+(q&2081&n)|0;if((a[1108928]|0)==0){y=l&65535}else{y=(e[(c[277220]|0)+(l<<1)>>1]|(n^q)&2081)&65535}q=m+3|0;b[(c[277218]|0)+(q<<1)>>1]=y;b[(c[277218]|0)+(o<<1)>>1]=y;n=a[1108909]|0;a[(c[277219]|0)+q|0]=n;a[(c[277219]|0)+o|0]=n;w=a[1108908]|0;x=c[277219]|0}else{w=s;x=t}}while(0);o=m+4|0;do{if((w&255)>(d[x+o|0]|0)){n=a[r+2|0]|0;if(n<<24>>24==0){z=w;A=x;break}q=e[(c[277225]|0)+((n&255)<<1)>>1]|0;n=c[277228]|0;l=(((q&63454)+(n&-2082)|0)>>>1)+(n&2081&q)|0;if((a[1108928]|0)==0){B=l&65535}else{B=(e[(c[277220]|0)+(l<<1)>>1]|(q^n)&2081)&65535}n=m+5|0;b[(c[277218]|0)+(n<<1)>>1]=B;b[(c[277218]|0)+(o<<1)>>1]=B;q=a[1108909]|0;a[(c[277219]|0)+n|0]=q;a[(c[277219]|0)+o|0]=q;z=a[1108908]|0;A=c[277219]|0}else{z=w;A=x}}while(0);o=m+6|0;do{if((z&255)>(d[A+o|0]|0)){q=a[r+3|0]|0;if(q<<24>>24==0){C=z;D=A;break}n=e[(c[277225]|0)+((q&255)<<1)>>1]|0;q=c[277228]|0;l=(((n&63454)+(q&-2082)|0)>>>1)+(q&2081&n)|0;if((a[1108928]|0)==0){E=l&65535}else{E=(e[(c[277220]|0)+(l<<1)>>1]|(n^q)&2081)&65535}q=m+7|0;b[(c[277218]|0)+(q<<1)>>1]=E;b[(c[277218]|0)+(o<<1)>>1]=E;n=a[1108909]|0;a[(c[277219]|0)+q|0]=n;a[(c[277219]|0)+o|0]=n;C=a[1108908]|0;D=c[277219]|0}else{C=z;D=A}}while(0);o=m+8|0;do{if((C&255)>(d[D+o|0]|0)){n=a[r+4|0]|0;if(n<<24>>24==0){F=C;G=D;break}q=e[(c[277225]|0)+((n&255)<<1)>>1]|0;n=c[277228]|0;l=(((q&63454)+(n&-2082)|0)>>>1)+(n&2081&q)|0;if((a[1108928]|0)==0){H=l&65535}else{H=(e[(c[277220]|0)+(l<<1)>>1]|(q^n)&2081)&65535}n=m+9|0;b[(c[277218]|0)+(n<<1)>>1]=H;b[(c[277218]|0)+(o<<1)>>1]=H;q=a[1108909]|0;a[(c[277219]|0)+n|0]=q;a[(c[277219]|0)+o|0]=q;F=a[1108908]|0;G=c[277219]|0}else{F=C;G=D}}while(0);o=m+10|0;do{if((F&255)>(d[G+o|0]|0)){q=a[r+5|0]|0;if(q<<24>>24==0){I=F;J=G;break}n=e[(c[277225]|0)+((q&255)<<1)>>1]|0;q=c[277228]|0;l=(((n&63454)+(q&-2082)|0)>>>1)+(q&2081&n)|0;if((a[1108928]|0)==0){K=l&65535}else{K=(e[(c[277220]|0)+(l<<1)>>1]|(n^q)&2081)&65535}q=m+11|0;b[(c[277218]|0)+(q<<1)>>1]=K;b[(c[277218]|0)+(o<<1)>>1]=K;n=a[1108909]|0;a[(c[277219]|0)+q|0]=n;a[(c[277219]|0)+o|0]=n;I=a[1108908]|0;J=c[277219]|0}else{I=F;J=G}}while(0);o=m+12|0;do{if((I&255)>(d[J+o|0]|0)){n=a[r+6|0]|0;if(n<<24>>24==0){L=I;M=J;break}q=e[(c[277225]|0)+((n&255)<<1)>>1]|0;n=c[277228]|0;l=(((q&63454)+(n&-2082)|0)>>>1)+(n&2081&q)|0;if((a[1108928]|0)==0){N=l&65535}else{N=(e[(c[277220]|0)+(l<<1)>>1]|(q^n)&2081)&65535}n=m+13|0;b[(c[277218]|0)+(n<<1)>>1]=N;b[(c[277218]|0)+(o<<1)>>1]=N;q=a[1108909]|0;a[(c[277219]|0)+n|0]=q;a[(c[277219]|0)+o|0]=q;L=a[1108908]|0;M=c[277219]|0}else{L=I;M=J}}while(0);o=m+14|0;do{if((L&255)>(d[M+o|0]|0)){q=a[r+7|0]|0;if(q<<24>>24==0){break}n=e[(c[277225]|0)+((q&255)<<1)>>1]|0;q=c[277228]|0;l=(((n&63454)+(q&-2082)|0)>>>1)+(q&2081&n)|0;if((a[1108928]|0)==0){O=l&65535}else{O=(e[(c[277220]|0)+(l<<1)>>1]|(n^q)&2081)&65535}q=m+15|0;b[(c[277218]|0)+(q<<1)>>1]=O;b[(c[277218]|0)+(o<<1)>>1]=O;n=a[1108909]|0;a[(c[277219]|0)+q|0]=n;a[(c[277219]|0)+o|0]=n}}while(0);o=j-1|0;if((o|0)<=0){break}r=r+16|0;j=o;m=(c[277223]|0)+m|0}return}m=(d[1394504]|0)+(h<<1)|0;if((f&32768|0)==0){if((i|0)<=0){return}f=p+m|0;h=i;j=g;while(1){r=a[1108908]|0;O=c[277219]|0;do{if((r&255)>(d[O+j|0]|0)){M=a[f+7|0]|0;if(M<<24>>24==0){P=r;Q=O;break}L=e[(c[277225]|0)+((M&255)<<1)>>1]|0;M=c[277228]|0;J=(((L&63454)+(M&-2082)|0)>>>1)+(M&2081&L)|0;if((a[1108928]|0)==0){R=J&65535}else{R=(e[(c[277220]|0)+(J<<1)>>1]|(L^M)&2081)&65535}M=j+1|0;b[(c[277218]|0)+(M<<1)>>1]=R;b[(c[277218]|0)+(j<<1)>>1]=R;L=a[1108909]|0;a[(c[277219]|0)+M|0]=L;a[(c[277219]|0)+j|0]=L;P=a[1108908]|0;Q=c[277219]|0}else{P=r;Q=O}}while(0);O=j+2|0;do{if((P&255)>(d[Q+O|0]|0)){r=a[f+6|0]|0;if(r<<24>>24==0){S=P;T=Q;break}L=e[(c[277225]|0)+((r&255)<<1)>>1]|0;r=c[277228]|0;M=(((L&63454)+(r&-2082)|0)>>>1)+(r&2081&L)|0;if((a[1108928]|0)==0){U=M&65535}else{U=(e[(c[277220]|0)+(M<<1)>>1]|(L^r)&2081)&65535}r=j+3|0;b[(c[277218]|0)+(r<<1)>>1]=U;b[(c[277218]|0)+(O<<1)>>1]=U;L=a[1108909]|0;a[(c[277219]|0)+r|0]=L;a[(c[277219]|0)+O|0]=L;S=a[1108908]|0;T=c[277219]|0}else{S=P;T=Q}}while(0);O=j+4|0;do{if((S&255)>(d[T+O|0]|0)){L=a[f+5|0]|0;if(L<<24>>24==0){V=S;W=T;break}r=e[(c[277225]|0)+((L&255)<<1)>>1]|0;L=c[277228]|0;M=(((r&63454)+(L&-2082)|0)>>>1)+(L&2081&r)|0;if((a[1108928]|0)==0){X=M&65535}else{X=(e[(c[277220]|0)+(M<<1)>>1]|(r^L)&2081)&65535}L=j+5|0;b[(c[277218]|0)+(L<<1)>>1]=X;b[(c[277218]|0)+(O<<1)>>1]=X;r=a[1108909]|0;a[(c[277219]|0)+L|0]=r;a[(c[277219]|0)+O|0]=r;V=a[1108908]|0;W=c[277219]|0}else{V=S;W=T}}while(0);O=j+6|0;do{if((V&255)>(d[W+O|0]|0)){r=a[f+4|0]|0;if(r<<24>>24==0){Y=V;Z=W;break}L=e[(c[277225]|0)+((r&255)<<1)>>1]|0;r=c[277228]|0;M=(((L&63454)+(r&-2082)|0)>>>1)+(r&2081&L)|0;if((a[1108928]|0)==0){_=M&65535}else{_=(e[(c[277220]|0)+(M<<1)>>1]|(L^r)&2081)&65535}r=j+7|0;b[(c[277218]|0)+(r<<1)>>1]=_;b[(c[277218]|0)+(O<<1)>>1]=_;L=a[1108909]|0;a[(c[277219]|0)+r|0]=L;a[(c[277219]|0)+O|0]=L;Y=a[1108908]|0;Z=c[277219]|0}else{Y=V;Z=W}}while(0);O=j+8|0;do{if((Y&255)>(d[Z+O|0]|0)){L=a[f+3|0]|0;if(L<<24>>24==0){$=Y;aa=Z;break}r=e[(c[277225]|0)+((L&255)<<1)>>1]|0;L=c[277228]|0;M=(((r&63454)+(L&-2082)|0)>>>1)+(L&2081&r)|0;if((a[1108928]|0)==0){ab=M&65535}else{ab=(e[(c[277220]|0)+(M<<1)>>1]|(r^L)&2081)&65535}L=j+9|0;b[(c[277218]|0)+(L<<1)>>1]=ab;b[(c[277218]|0)+(O<<1)>>1]=ab;r=a[1108909]|0;a[(c[277219]|0)+L|0]=r;a[(c[277219]|0)+O|0]=r;$=a[1108908]|0;aa=c[277219]|0}else{$=Y;aa=Z}}while(0);O=j+10|0;do{if(($&255)>(d[aa+O|0]|0)){r=a[f+2|0]|0;if(r<<24>>24==0){ac=$;ad=aa;break}L=e[(c[277225]|0)+((r&255)<<1)>>1]|0;r=c[277228]|0;M=(((L&63454)+(r&-2082)|0)>>>1)+(r&2081&L)|0;if((a[1108928]|0)==0){ae=M&65535}else{ae=(e[(c[277220]|0)+(M<<1)>>1]|(L^r)&2081)&65535}r=j+11|0;b[(c[277218]|0)+(r<<1)>>1]=ae;b[(c[277218]|0)+(O<<1)>>1]=ae;L=a[1108909]|0;a[(c[277219]|0)+r|0]=L;a[(c[277219]|0)+O|0]=L;ac=a[1108908]|0;ad=c[277219]|0}else{ac=$;ad=aa}}while(0);O=j+12|0;do{if((ac&255)>(d[ad+O|0]|0)){L=a[f+1|0]|0;if(L<<24>>24==0){af=ac;ag=ad;break}r=e[(c[277225]|0)+((L&255)<<1)>>1]|0;L=c[277228]|0;M=(((r&63454)+(L&-2082)|0)>>>1)+(L&2081&r)|0;if((a[1108928]|0)==0){ah=M&65535}else{ah=(e[(c[277220]|0)+(M<<1)>>1]|(r^L)&2081)&65535}L=j+13|0;b[(c[277218]|0)+(L<<1)>>1]=ah;b[(c[277218]|0)+(O<<1)>>1]=ah;r=a[1108909]|0;a[(c[277219]|0)+L|0]=r;a[(c[277219]|0)+O|0]=r;af=a[1108908]|0;ag=c[277219]|0}else{af=ac;ag=ad}}while(0);O=j+14|0;do{if((af&255)>(d[ag+O|0]|0)){r=a[f]|0;if(r<<24>>24==0){break}L=e[(c[277225]|0)+((r&255)<<1)>>1]|0;r=c[277228]|0;M=(((L&63454)+(r&-2082)|0)>>>1)+(r&2081&L)|0;if((a[1108928]|0)==0){ai=M&65535}else{ai=(e[(c[277220]|0)+(M<<1)>>1]|(L^r)&2081)&65535}r=j+15|0;b[(c[277218]|0)+(r<<1)>>1]=ai;b[(c[277218]|0)+(O<<1)>>1]=ai;L=a[1108909]|0;a[(c[277219]|0)+r|0]=L;a[(c[277219]|0)+O|0]=L}}while(0);O=h-1|0;if((O|0)<=0){break}f=f+16|0;h=O;j=(c[277223]|0)+j|0}return}j=p+(56-m)|0;m=(i|0)>0;if(k){if(m){aj=j;ak=i;al=g}else{return}while(1){k=a[1108908]|0;p=c[277219]|0;do{if((k&255)>(d[p+al|0]|0)){h=a[aj+7|0]|0;if(h<<24>>24==0){am=k;an=p;break}f=e[(c[277225]|0)+((h&255)<<1)>>1]|0;h=c[277228]|0;ai=(((f&63454)+(h&-2082)|0)>>>1)+(h&2081&f)|0;if((a[1108928]|0)==0){ao=ai&65535}else{ao=(e[(c[277220]|0)+(ai<<1)>>1]|(f^h)&2081)&65535}h=al+1|0;b[(c[277218]|0)+(h<<1)>>1]=ao;b[(c[277218]|0)+(al<<1)>>1]=ao;f=a[1108909]|0;a[(c[277219]|0)+h|0]=f;a[(c[277219]|0)+al|0]=f;am=a[1108908]|0;an=c[277219]|0}else{am=k;an=p}}while(0);p=al+2|0;do{if((am&255)>(d[an+p|0]|0)){k=a[aj+6|0]|0;if(k<<24>>24==0){ap=am;aq=an;break}f=e[(c[277225]|0)+((k&255)<<1)>>1]|0;k=c[277228]|0;h=(((f&63454)+(k&-2082)|0)>>>1)+(k&2081&f)|0;if((a[1108928]|0)==0){ar=h&65535}else{ar=(e[(c[277220]|0)+(h<<1)>>1]|(f^k)&2081)&65535}k=al+3|0;b[(c[277218]|0)+(k<<1)>>1]=ar;b[(c[277218]|0)+(p<<1)>>1]=ar;f=a[1108909]|0;a[(c[277219]|0)+k|0]=f;a[(c[277219]|0)+p|0]=f;ap=a[1108908]|0;aq=c[277219]|0}else{ap=am;aq=an}}while(0);p=al+4|0;do{if((ap&255)>(d[aq+p|0]|0)){f=a[aj+5|0]|0;if(f<<24>>24==0){as=ap;at=aq;break}k=e[(c[277225]|0)+((f&255)<<1)>>1]|0;f=c[277228]|0;h=(((k&63454)+(f&-2082)|0)>>>1)+(f&2081&k)|0;if((a[1108928]|0)==0){au=h&65535}else{au=(e[(c[277220]|0)+(h<<1)>>1]|(k^f)&2081)&65535}f=al+5|0;b[(c[277218]|0)+(f<<1)>>1]=au;b[(c[277218]|0)+(p<<1)>>1]=au;k=a[1108909]|0;a[(c[277219]|0)+f|0]=k;a[(c[277219]|0)+p|0]=k;as=a[1108908]|0;at=c[277219]|0}else{as=ap;at=aq}}while(0);p=al+6|0;do{if((as&255)>(d[at+p|0]|0)){k=a[aj+4|0]|0;if(k<<24>>24==0){av=as;aw=at;break}f=e[(c[277225]|0)+((k&255)<<1)>>1]|0;k=c[277228]|0;h=(((f&63454)+(k&-2082)|0)>>>1)+(k&2081&f)|0;if((a[1108928]|0)==0){ax=h&65535}else{ax=(e[(c[277220]|0)+(h<<1)>>1]|(f^k)&2081)&65535}k=al+7|0;b[(c[277218]|0)+(k<<1)>>1]=ax;b[(c[277218]|0)+(p<<1)>>1]=ax;f=a[1108909]|0;a[(c[277219]|0)+k|0]=f;a[(c[277219]|0)+p|0]=f;av=a[1108908]|0;aw=c[277219]|0}else{av=as;aw=at}}while(0);p=al+8|0;do{if((av&255)>(d[aw+p|0]|0)){f=a[aj+3|0]|0;if(f<<24>>24==0){ay=av;az=aw;break}k=e[(c[277225]|0)+((f&255)<<1)>>1]|0;f=c[277228]|0;h=(((k&63454)+(f&-2082)|0)>>>1)+(f&2081&k)|0;if((a[1108928]|0)==0){aA=h&65535}else{aA=(e[(c[277220]|0)+(h<<1)>>1]|(k^f)&2081)&65535}f=al+9|0;b[(c[277218]|0)+(f<<1)>>1]=aA;b[(c[277218]|0)+(p<<1)>>1]=aA;k=a[1108909]|0;a[(c[277219]|0)+f|0]=k;a[(c[277219]|0)+p|0]=k;ay=a[1108908]|0;az=c[277219]|0}else{ay=av;az=aw}}while(0);p=al+10|0;do{if((ay&255)>(d[az+p|0]|0)){k=a[aj+2|0]|0;if(k<<24>>24==0){aB=ay;aC=az;break}f=e[(c[277225]|0)+((k&255)<<1)>>1]|0;k=c[277228]|0;h=(((f&63454)+(k&-2082)|0)>>>1)+(k&2081&f)|0;if((a[1108928]|0)==0){aD=h&65535}else{aD=(e[(c[277220]|0)+(h<<1)>>1]|(f^k)&2081)&65535}k=al+11|0;b[(c[277218]|0)+(k<<1)>>1]=aD;b[(c[277218]|0)+(p<<1)>>1]=aD;f=a[1108909]|0;a[(c[277219]|0)+k|0]=f;a[(c[277219]|0)+p|0]=f;aB=a[1108908]|0;aC=c[277219]|0}else{aB=ay;aC=az}}while(0);p=al+12|0;do{if((aB&255)>(d[aC+p|0]|0)){f=a[aj+1|0]|0;if(f<<24>>24==0){aE=aB;aF=aC;break}k=e[(c[277225]|0)+((f&255)<<1)>>1]|0;f=c[277228]|0;h=(((k&63454)+(f&-2082)|0)>>>1)+(f&2081&k)|0;if((a[1108928]|0)==0){aG=h&65535}else{aG=(e[(c[277220]|0)+(h<<1)>>1]|(k^f)&2081)&65535}f=al+13|0;b[(c[277218]|0)+(f<<1)>>1]=aG;b[(c[277218]|0)+(p<<1)>>1]=aG;k=a[1108909]|0;a[(c[277219]|0)+f|0]=k;a[(c[277219]|0)+p|0]=k;aE=a[1108908]|0;aF=c[277219]|0}else{aE=aB;aF=aC}}while(0);p=al+14|0;do{if((aE&255)>(d[aF+p|0]|0)){k=a[aj]|0;if(k<<24>>24==0){break}f=e[(c[277225]|0)+((k&255)<<1)>>1]|0;k=c[277228]|0;h=(((f&63454)+(k&-2082)|0)>>>1)+(k&2081&f)|0;if((a[1108928]|0)==0){aH=h&65535}else{aH=(e[(c[277220]|0)+(h<<1)>>1]|(f^k)&2081)&65535}k=al+15|0;b[(c[277218]|0)+(k<<1)>>1]=aH;b[(c[277218]|0)+(p<<1)>>1]=aH;f=a[1108909]|0;a[(c[277219]|0)+k|0]=f;a[(c[277219]|0)+p|0]=f}}while(0);p=ak-1|0;if((p|0)<=0){break}aj=aj-16|0;ak=p;al=(c[277223]|0)+al|0}return}else{if(m){aI=j;aJ=i;aK=g}else{return}while(1){g=a[1108908]|0;i=c[277219]|0;do{if((g&255)>(d[i+aK|0]|0)){j=a[aI]|0;if(j<<24>>24==0){aL=g;aM=i;break}m=e[(c[277225]|0)+((j&255)<<1)>>1]|0;j=c[277228]|0;al=(((m&63454)+(j&-2082)|0)>>>1)+(j&2081&m)|0;if((a[1108928]|0)==0){aN=al&65535}else{aN=(e[(c[277220]|0)+(al<<1)>>1]|(m^j)&2081)&65535}j=aK+1|0;b[(c[277218]|0)+(j<<1)>>1]=aN;b[(c[277218]|0)+(aK<<1)>>1]=aN;m=a[1108909]|0;a[(c[277219]|0)+j|0]=m;a[(c[277219]|0)+aK|0]=m;aL=a[1108908]|0;aM=c[277219]|0}else{aL=g;aM=i}}while(0);i=aK+2|0;do{if((aL&255)>(d[aM+i|0]|0)){g=a[aI+1|0]|0;if(g<<24>>24==0){aO=aL;aP=aM;break}m=e[(c[277225]|0)+((g&255)<<1)>>1]|0;g=c[277228]|0;j=(((m&63454)+(g&-2082)|0)>>>1)+(g&2081&m)|0;if((a[1108928]|0)==0){aQ=j&65535}else{aQ=(e[(c[277220]|0)+(j<<1)>>1]|(m^g)&2081)&65535}g=aK+3|0;b[(c[277218]|0)+(g<<1)>>1]=aQ;b[(c[277218]|0)+(i<<1)>>1]=aQ;m=a[1108909]|0;a[(c[277219]|0)+g|0]=m;a[(c[277219]|0)+i|0]=m;aO=a[1108908]|0;aP=c[277219]|0}else{aO=aL;aP=aM}}while(0);i=aK+4|0;do{if((aO&255)>(d[aP+i|0]|0)){m=a[aI+2|0]|0;if(m<<24>>24==0){aR=aO;aS=aP;break}g=e[(c[277225]|0)+((m&255)<<1)>>1]|0;m=c[277228]|0;j=(((g&63454)+(m&-2082)|0)>>>1)+(m&2081&g)|0;if((a[1108928]|0)==0){aT=j&65535}else{aT=(e[(c[277220]|0)+(j<<1)>>1]|(g^m)&2081)&65535}m=aK+5|0;b[(c[277218]|0)+(m<<1)>>1]=aT;b[(c[277218]|0)+(i<<1)>>1]=aT;g=a[1108909]|0;a[(c[277219]|0)+m|0]=g;a[(c[277219]|0)+i|0]=g;aR=a[1108908]|0;aS=c[277219]|0}else{aR=aO;aS=aP}}while(0);i=aK+6|0;do{if((aR&255)>(d[aS+i|0]|0)){g=a[aI+3|0]|0;if(g<<24>>24==0){aU=aR;aV=aS;break}m=e[(c[277225]|0)+((g&255)<<1)>>1]|0;g=c[277228]|0;j=(((m&63454)+(g&-2082)|0)>>>1)+(g&2081&m)|0;if((a[1108928]|0)==0){aW=j&65535}else{aW=(e[(c[277220]|0)+(j<<1)>>1]|(m^g)&2081)&65535}g=aK+7|0;b[(c[277218]|0)+(g<<1)>>1]=aW;b[(c[277218]|0)+(i<<1)>>1]=aW;m=a[1108909]|0;a[(c[277219]|0)+g|0]=m;a[(c[277219]|0)+i|0]=m;aU=a[1108908]|0;aV=c[277219]|0}else{aU=aR;aV=aS}}while(0);i=aK+8|0;do{if((aU&255)>(d[aV+i|0]|0)){m=a[aI+4|0]|0;if(m<<24>>24==0){aX=aU;aY=aV;break}g=e[(c[277225]|0)+((m&255)<<1)>>1]|0;m=c[277228]|0;j=(((g&63454)+(m&-2082)|0)>>>1)+(m&2081&g)|0;if((a[1108928]|0)==0){aZ=j&65535}else{aZ=(e[(c[277220]|0)+(j<<1)>>1]|(g^m)&2081)&65535}m=aK+9|0;b[(c[277218]|0)+(m<<1)>>1]=aZ;b[(c[277218]|0)+(i<<1)>>1]=aZ;g=a[1108909]|0;a[(c[277219]|0)+m|0]=g;a[(c[277219]|0)+i|0]=g;aX=a[1108908]|0;aY=c[277219]|0}else{aX=aU;aY=aV}}while(0);i=aK+10|0;do{if((aX&255)>(d[aY+i|0]|0)){g=a[aI+5|0]|0;if(g<<24>>24==0){a_=aX;a$=aY;break}m=e[(c[277225]|0)+((g&255)<<1)>>1]|0;g=c[277228]|0;j=(((m&63454)+(g&-2082)|0)>>>1)+(g&2081&m)|0;if((a[1108928]|0)==0){a0=j&65535}else{a0=(e[(c[277220]|0)+(j<<1)>>1]|(m^g)&2081)&65535}g=aK+11|0;b[(c[277218]|0)+(g<<1)>>1]=a0;b[(c[277218]|0)+(i<<1)>>1]=a0;m=a[1108909]|0;a[(c[277219]|0)+g|0]=m;a[(c[277219]|0)+i|0]=m;a_=a[1108908]|0;a$=c[277219]|0}else{a_=aX;a$=aY}}while(0);i=aK+12|0;do{if((a_&255)>(d[a$+i|0]|0)){m=a[aI+6|0]|0;if(m<<24>>24==0){a1=a_;a2=a$;break}g=e[(c[277225]|0)+((m&255)<<1)>>1]|0;m=c[277228]|0;j=(((g&63454)+(m&-2082)|0)>>>1)+(m&2081&g)|0;if((a[1108928]|0)==0){a3=j&65535}else{a3=(e[(c[277220]|0)+(j<<1)>>1]|(g^m)&2081)&65535}m=aK+13|0;b[(c[277218]|0)+(m<<1)>>1]=a3;b[(c[277218]|0)+(i<<1)>>1]=a3;g=a[1108909]|0;a[(c[277219]|0)+m|0]=g;a[(c[277219]|0)+i|0]=g;a1=a[1108908]|0;a2=c[277219]|0}else{a1=a_;a2=a$}}while(0);i=aK+14|0;do{if((a1&255)>(d[a2+i|0]|0)){g=a[aI+7|0]|0;if(g<<24>>24==0){break}m=e[(c[277225]|0)+((g&255)<<1)>>1]|0;g=c[277228]|0;j=(((m&63454)+(g&-2082)|0)>>>1)+(g&2081&m)|0;if((a[1108928]|0)==0){a4=j&65535}else{a4=(e[(c[277220]|0)+(j<<1)>>1]|(m^g)&2081)&65535}g=aK+15|0;b[(c[277218]|0)+(g<<1)>>1]=a4;b[(c[277218]|0)+(i<<1)>>1]=a4;m=a[1108909]|0;a[(c[277219]|0)+g|0]=m;a[(c[277219]|0)+i|0]=m}}while(0);i=aJ-1|0;if((i|0)<=0){break}aI=aI-16|0;aJ=i;aK=(c[277223]|0)+aK|0}return}}function Vp(f,g,h,i){f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0,cf=0,cg=0,ch=0,ci=0,cj=0,ck=0,cl=0,cm=0,cn=0,co=0,cp=0,cq=0,cr=0,cs=0,ct=0,cu=0,cv=0,cw=0,cx=0,cy=0,cz=0,cA=0,cB=0,cC=0;j=f&1023;k=c[348606]|0;l=(j<<k)+(c[348604]|0)|0;if((f&256|0)==0){m=l}else{m=(c[348602]|0)+l|0}l=m&65535;m=l>>>(k>>>0);k=(f&16384|0)!=0;n=m<<6;do{if(k){o=(c[348622]|0)+n|0;if((a[(c[348618]|0)+m|0]|0)!=0){p=o;break}q=fi[c[348636]&63](o,l,j)|0;a[(c[348618]|0)+m|0]=q;p=o}else{o=(c[348624]|0)+n|0;if((a[(c[348620]|0)+m|0]|0)!=0){p=o;break}q=fi[c[348638]&63](o,l,j)|0;a[(c[348620]|0)+m|0]=q;p=o}}while(0);if((a[(c[348620]|0)+m|0]|0)==2){return}if((a[1394464]|0)==0){r=1106168+((f>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){m=d[1044485]|0;c[276541]=7080+(m<<5);j=0;do{l=j<<1&2;n=j&2;o=j&4;q=0;do{b[1125528+(j<<9)+(q<<1)>>1]=d[(q>>>1&28|n)+(7080+(m<<5))|0]<<6|d[(q<<2&28|l)+(7080+(m<<5))|0]<<11|d[(q>>>3&24|o)+(7080+(m<<5))|0];q=q+1|0;}while(q>>>0<256);j=j+1|0;}while(j>>>0<8);a[1106089]=0}r=1125528+((f>>>10&7)<<9)|0}c[277226]=r;c[277225]=(a[1108928]|0)!=0?1393712:r;if((f&49152|0)==0){if((i|0)<=0){return}r=p+((d[1394504]|0)+(h<<1))|0;j=i;m=g;while(1){q=a[1108908]|0;o=c[277219]|0;do{if((q&255)>(d[o+m|0]|0)){l=a[r]|0;n=l&255;if(l<<24>>24==0){s=q;t=o;break}do{if((a[1108928]|0)==0){l=b[(c[277225]|0)+(n<<1)>>1]|0;u=l&65535;v=u&63454;if((a[(c[277215]|0)+m|0]&32)==0){w=c[277228]|0;x=(e[(c[277220]|0)+((((w&-2082)+v|0)>>>1)+(u&2081&w)<<1)>>1]|(w^u)&2081)&65535;break}else{u=b[(c[277213]|0)+(m<<1)>>1]|0;x=(((u&63454)+v|0)>>>1)+(u&l&2081)&65535;break}}else{l=e[(c[277225]|0)+(n<<1)>>1]|0;u=(a[(c[277215]|0)+m|0]&32)==0;if(u){v=c[277228]|0;y=v;z=v&-2082}else{v=e[(c[277213]|0)+(m<<1)>>1]|0;y=v;z=v&63454}if(u){A=c[277228]|0}else{A=e[(c[277213]|0)+(m<<1)>>1]|0}x=((A^l)&2081|e[(c[277220]|0)+((l&2081&y)+((z+(l&63454)|0)>>>1)<<1)>>1])&65535}}while(0);n=m+1|0;b[(c[277218]|0)+(n<<1)>>1]=x;b[(c[277218]|0)+(m<<1)>>1]=x;l=a[1108909]|0;a[(c[277219]|0)+n|0]=l;a[(c[277219]|0)+m|0]=l;s=a[1108908]|0;t=c[277219]|0}else{s=q;t=o}}while(0);o=m+2|0;do{if((s&255)>(d[t+o|0]|0)){q=a[r+1|0]|0;l=q&255;if(q<<24>>24==0){B=s;C=t;break}do{if((a[1108928]|0)==0){q=b[(c[277225]|0)+(l<<1)>>1]|0;n=q&65535;u=n&63454;if((a[(c[277215]|0)+o|0]&32)==0){v=c[277228]|0;D=(e[(c[277220]|0)+((((v&-2082)+u|0)>>>1)+(n&2081&v)<<1)>>1]|(v^n)&2081)&65535;break}else{n=b[(c[277213]|0)+(o<<1)>>1]|0;D=(((n&63454)+u|0)>>>1)+(n&q&2081)&65535;break}}else{q=e[(c[277225]|0)+(l<<1)>>1]|0;n=(a[(c[277215]|0)+o|0]&32)==0;if(n){u=c[277228]|0;E=u;F=u&-2082}else{u=e[(c[277213]|0)+(o<<1)>>1]|0;E=u;F=u&63454}if(n){G=c[277228]|0}else{G=e[(c[277213]|0)+(o<<1)>>1]|0}D=((G^q)&2081|e[(c[277220]|0)+((q&2081&E)+((F+(q&63454)|0)>>>1)<<1)>>1])&65535}}while(0);l=m+3|0;b[(c[277218]|0)+(l<<1)>>1]=D;b[(c[277218]|0)+(o<<1)>>1]=D;q=a[1108909]|0;a[(c[277219]|0)+l|0]=q;a[(c[277219]|0)+o|0]=q;B=a[1108908]|0;C=c[277219]|0}else{B=s;C=t}}while(0);o=m+4|0;do{if((B&255)>(d[C+o|0]|0)){q=a[r+2|0]|0;l=q&255;if(q<<24>>24==0){H=B;I=C;break}do{if((a[1108928]|0)==0){q=b[(c[277225]|0)+(l<<1)>>1]|0;n=q&65535;u=n&63454;if((a[(c[277215]|0)+o|0]&32)==0){v=c[277228]|0;J=(e[(c[277220]|0)+((((v&-2082)+u|0)>>>1)+(n&2081&v)<<1)>>1]|(v^n)&2081)&65535;break}else{n=b[(c[277213]|0)+(o<<1)>>1]|0;J=(((n&63454)+u|0)>>>1)+(n&q&2081)&65535;break}}else{q=e[(c[277225]|0)+(l<<1)>>1]|0;n=(a[(c[277215]|0)+o|0]&32)==0;if(n){u=c[277228]|0;K=u;L=u&-2082}else{u=e[(c[277213]|0)+(o<<1)>>1]|0;K=u;L=u&63454}if(n){M=c[277228]|0}else{M=e[(c[277213]|0)+(o<<1)>>1]|0}J=((M^q)&2081|e[(c[277220]|0)+((q&2081&K)+((L+(q&63454)|0)>>>1)<<1)>>1])&65535}}while(0);l=m+5|0;b[(c[277218]|0)+(l<<1)>>1]=J;b[(c[277218]|0)+(o<<1)>>1]=J;q=a[1108909]|0;a[(c[277219]|0)+l|0]=q;a[(c[277219]|0)+o|0]=q;H=a[1108908]|0;I=c[277219]|0}else{H=B;I=C}}while(0);o=m+6|0;do{if((H&255)>(d[I+o|0]|0)){q=a[r+3|0]|0;l=q&255;if(q<<24>>24==0){N=H;O=I;break}do{if((a[1108928]|0)==0){q=b[(c[277225]|0)+(l<<1)>>1]|0;n=q&65535;u=n&63454;if((a[(c[277215]|0)+o|0]&32)==0){v=c[277228]|0;P=(e[(c[277220]|0)+((((v&-2082)+u|0)>>>1)+(n&2081&v)<<1)>>1]|(v^n)&2081)&65535;break}else{n=b[(c[277213]|0)+(o<<1)>>1]|0;P=(((n&63454)+u|0)>>>1)+(n&q&2081)&65535;break}}else{q=e[(c[277225]|0)+(l<<1)>>1]|0;n=(a[(c[277215]|0)+o|0]&32)==0;if(n){u=c[277228]|0;Q=u;R=u&-2082}else{u=e[(c[277213]|0)+(o<<1)>>1]|0;Q=u;R=u&63454}if(n){S=c[277228]|0}else{S=e[(c[277213]|0)+(o<<1)>>1]|0}P=((S^q)&2081|e[(c[277220]|0)+((q&2081&Q)+((R+(q&63454)|0)>>>1)<<1)>>1])&65535}}while(0);l=m+7|0;b[(c[277218]|0)+(l<<1)>>1]=P;b[(c[277218]|0)+(o<<1)>>1]=P;q=a[1108909]|0;a[(c[277219]|0)+l|0]=q;a[(c[277219]|0)+o|0]=q;N=a[1108908]|0;O=c[277219]|0}else{N=H;O=I}}while(0);o=m+8|0;do{if((N&255)>(d[O+o|0]|0)){q=a[r+4|0]|0;l=q&255;if(q<<24>>24==0){T=N;U=O;break}do{if((a[1108928]|0)==0){q=b[(c[277225]|0)+(l<<1)>>1]|0;n=q&65535;u=n&63454;if((a[(c[277215]|0)+o|0]&32)==0){v=c[277228]|0;V=(e[(c[277220]|0)+((((v&-2082)+u|0)>>>1)+(n&2081&v)<<1)>>1]|(v^n)&2081)&65535;break}else{n=b[(c[277213]|0)+(o<<1)>>1]|0;V=(((n&63454)+u|0)>>>1)+(n&q&2081)&65535;break}}else{q=e[(c[277225]|0)+(l<<1)>>1]|0;n=(a[(c[277215]|0)+o|0]&32)==0;if(n){u=c[277228]|0;W=u;X=u&-2082}else{u=e[(c[277213]|0)+(o<<1)>>1]|0;W=u;X=u&63454}if(n){Y=c[277228]|0}else{Y=e[(c[277213]|0)+(o<<1)>>1]|0}V=((Y^q)&2081|e[(c[277220]|0)+((q&2081&W)+((X+(q&63454)|0)>>>1)<<1)>>1])&65535}}while(0);l=m+9|0;b[(c[277218]|0)+(l<<1)>>1]=V;b[(c[277218]|0)+(o<<1)>>1]=V;q=a[1108909]|0;a[(c[277219]|0)+l|0]=q;a[(c[277219]|0)+o|0]=q;T=a[1108908]|0;U=c[277219]|0}else{T=N;U=O}}while(0);o=m+10|0;do{if((T&255)>(d[U+o|0]|0)){q=a[r+5|0]|0;l=q&255;if(q<<24>>24==0){Z=T;_=U;break}do{if((a[1108928]|0)==0){q=b[(c[277225]|0)+(l<<1)>>1]|0;n=q&65535;u=n&63454;if((a[(c[277215]|0)+o|0]&32)==0){v=c[277228]|0;$=(e[(c[277220]|0)+((((v&-2082)+u|0)>>>1)+(n&2081&v)<<1)>>1]|(v^n)&2081)&65535;break}else{n=b[(c[277213]|0)+(o<<1)>>1]|0;$=(((n&63454)+u|0)>>>1)+(n&q&2081)&65535;break}}else{q=e[(c[277225]|0)+(l<<1)>>1]|0;n=(a[(c[277215]|0)+o|0]&32)==0;if(n){u=c[277228]|0;aa=u;ab=u&-2082}else{u=e[(c[277213]|0)+(o<<1)>>1]|0;aa=u;ab=u&63454}if(n){ac=c[277228]|0}else{ac=e[(c[277213]|0)+(o<<1)>>1]|0}$=((ac^q)&2081|e[(c[277220]|0)+((q&2081&aa)+((ab+(q&63454)|0)>>>1)<<1)>>1])&65535}}while(0);l=m+11|0;b[(c[277218]|0)+(l<<1)>>1]=$;b[(c[277218]|0)+(o<<1)>>1]=$;q=a[1108909]|0;a[(c[277219]|0)+l|0]=q;a[(c[277219]|0)+o|0]=q;Z=a[1108908]|0;_=c[277219]|0}else{Z=T;_=U}}while(0);o=m+12|0;do{if((Z&255)>(d[_+o|0]|0)){q=a[r+6|0]|0;l=q&255;if(q<<24>>24==0){ad=Z;ae=_;break}do{if((a[1108928]|0)==0){q=b[(c[277225]|0)+(l<<1)>>1]|0;n=q&65535;u=n&63454;if((a[(c[277215]|0)+o|0]&32)==0){v=c[277228]|0;af=(e[(c[277220]|0)+((((v&-2082)+u|0)>>>1)+(n&2081&v)<<1)>>1]|(v^n)&2081)&65535;break}else{n=b[(c[277213]|0)+(o<<1)>>1]|0;af=(((n&63454)+u|0)>>>1)+(n&q&2081)&65535;break}}else{q=e[(c[277225]|0)+(l<<1)>>1]|0;n=(a[(c[277215]|0)+o|0]&32)==0;if(n){u=c[277228]|0;ag=u;ah=u&-2082}else{u=e[(c[277213]|0)+(o<<1)>>1]|0;ag=u;ah=u&63454}if(n){ai=c[277228]|0}else{ai=e[(c[277213]|0)+(o<<1)>>1]|0}af=((ai^q)&2081|e[(c[277220]|0)+((q&2081&ag)+((ah+(q&63454)|0)>>>1)<<1)>>1])&65535}}while(0);l=m+13|0;b[(c[277218]|0)+(l<<1)>>1]=af;b[(c[277218]|0)+(o<<1)>>1]=af;q=a[1108909]|0;a[(c[277219]|0)+l|0]=q;a[(c[277219]|0)+o|0]=q;ad=a[1108908]|0;ae=c[277219]|0}else{ad=Z;ae=_}}while(0);o=m+14|0;do{if((ad&255)>(d[ae+o|0]|0)){q=a[r+7|0]|0;l=q&255;if(q<<24>>24==0){break}do{if((a[1108928]|0)==0){q=b[(c[277225]|0)+(l<<1)>>1]|0;n=q&65535;u=n&63454;if((a[(c[277215]|0)+o|0]&32)==0){v=c[277228]|0;aj=(e[(c[277220]|0)+((((v&-2082)+u|0)>>>1)+(n&2081&v)<<1)>>1]|(v^n)&2081)&65535;break}else{n=b[(c[277213]|0)+(o<<1)>>1]|0;aj=(((n&63454)+u|0)>>>1)+(n&q&2081)&65535;break}}else{q=e[(c[277225]|0)+(l<<1)>>1]|0;n=(a[(c[277215]|0)+o|0]&32)==0;if(n){u=c[277228]|0;ak=u;al=u&-2082}else{u=e[(c[277213]|0)+(o<<1)>>1]|0;ak=u;al=u&63454}if(n){am=c[277228]|0}else{am=e[(c[277213]|0)+(o<<1)>>1]|0}aj=((am^q)&2081|e[(c[277220]|0)+((q&2081&ak)+((al+(q&63454)|0)>>>1)<<1)>>1])&65535}}while(0);l=m+15|0;b[(c[277218]|0)+(l<<1)>>1]=aj;b[(c[277218]|0)+(o<<1)>>1]=aj;q=a[1108909]|0;a[(c[277219]|0)+l|0]=q;a[(c[277219]|0)+o|0]=q}}while(0);o=j-1|0;if((o|0)<=0){break}r=r+16|0;j=o;m=(c[277223]|0)+m|0}return}m=(d[1394504]|0)+(h<<1)|0;if((f&32768|0)==0){if((i|0)<=0){return}f=p+m|0;h=i;j=g;while(1){r=a[1108908]|0;aj=c[277219]|0;do{if((r&255)>(d[aj+j|0]|0)){al=a[f+7|0]|0;ak=al&255;if(al<<24>>24==0){an=r;ao=aj;break}do{if((a[1108928]|0)==0){al=b[(c[277225]|0)+(ak<<1)>>1]|0;am=al&65535;ae=am&63454;if((a[(c[277215]|0)+j|0]&32)==0){ad=c[277228]|0;ap=(e[(c[277220]|0)+((((ad&-2082)+ae|0)>>>1)+(am&2081&ad)<<1)>>1]|(ad^am)&2081)&65535;break}else{am=b[(c[277213]|0)+(j<<1)>>1]|0;ap=(((am&63454)+ae|0)>>>1)+(am&al&2081)&65535;break}}else{al=e[(c[277225]|0)+(ak<<1)>>1]|0;am=(a[(c[277215]|0)+j|0]&32)==0;if(am){ae=c[277228]|0;aq=ae;ar=ae&-2082}else{ae=e[(c[277213]|0)+(j<<1)>>1]|0;aq=ae;ar=ae&63454}if(am){as=c[277228]|0}else{as=e[(c[277213]|0)+(j<<1)>>1]|0}ap=((as^al)&2081|e[(c[277220]|0)+((al&2081&aq)+((ar+(al&63454)|0)>>>1)<<1)>>1])&65535}}while(0);ak=j+1|0;b[(c[277218]|0)+(ak<<1)>>1]=ap;b[(c[277218]|0)+(j<<1)>>1]=ap;al=a[1108909]|0;a[(c[277219]|0)+ak|0]=al;a[(c[277219]|0)+j|0]=al;an=a[1108908]|0;ao=c[277219]|0}else{an=r;ao=aj}}while(0);aj=j+2|0;do{if((an&255)>(d[ao+aj|0]|0)){r=a[f+6|0]|0;al=r&255;if(r<<24>>24==0){at=an;au=ao;break}do{if((a[1108928]|0)==0){r=b[(c[277225]|0)+(al<<1)>>1]|0;ak=r&65535;am=ak&63454;if((a[(c[277215]|0)+aj|0]&32)==0){ae=c[277228]|0;av=(e[(c[277220]|0)+((((ae&-2082)+am|0)>>>1)+(ak&2081&ae)<<1)>>1]|(ae^ak)&2081)&65535;break}else{ak=b[(c[277213]|0)+(aj<<1)>>1]|0;av=(((ak&63454)+am|0)>>>1)+(ak&r&2081)&65535;break}}else{r=e[(c[277225]|0)+(al<<1)>>1]|0;ak=(a[(c[277215]|0)+aj|0]&32)==0;if(ak){am=c[277228]|0;aw=am;ax=am&-2082}else{am=e[(c[277213]|0)+(aj<<1)>>1]|0;aw=am;ax=am&63454}if(ak){ay=c[277228]|0}else{ay=e[(c[277213]|0)+(aj<<1)>>1]|0}av=((ay^r)&2081|e[(c[277220]|0)+((r&2081&aw)+((ax+(r&63454)|0)>>>1)<<1)>>1])&65535}}while(0);al=j+3|0;b[(c[277218]|0)+(al<<1)>>1]=av;b[(c[277218]|0)+(aj<<1)>>1]=av;r=a[1108909]|0;a[(c[277219]|0)+al|0]=r;a[(c[277219]|0)+aj|0]=r;at=a[1108908]|0;au=c[277219]|0}else{at=an;au=ao}}while(0);aj=j+4|0;do{if((at&255)>(d[au+aj|0]|0)){r=a[f+5|0]|0;al=r&255;if(r<<24>>24==0){az=at;aA=au;break}do{if((a[1108928]|0)==0){r=b[(c[277225]|0)+(al<<1)>>1]|0;ak=r&65535;am=ak&63454;if((a[(c[277215]|0)+aj|0]&32)==0){ae=c[277228]|0;aB=(e[(c[277220]|0)+((((ae&-2082)+am|0)>>>1)+(ak&2081&ae)<<1)>>1]|(ae^ak)&2081)&65535;break}else{ak=b[(c[277213]|0)+(aj<<1)>>1]|0;aB=(((ak&63454)+am|0)>>>1)+(ak&r&2081)&65535;break}}else{r=e[(c[277225]|0)+(al<<1)>>1]|0;ak=(a[(c[277215]|0)+aj|0]&32)==0;if(ak){am=c[277228]|0;aC=am;aD=am&-2082}else{am=e[(c[277213]|0)+(aj<<1)>>1]|0;aC=am;aD=am&63454}if(ak){aE=c[277228]|0}else{aE=e[(c[277213]|0)+(aj<<1)>>1]|0}aB=((aE^r)&2081|e[(c[277220]|0)+((r&2081&aC)+((aD+(r&63454)|0)>>>1)<<1)>>1])&65535}}while(0);al=j+5|0;b[(c[277218]|0)+(al<<1)>>1]=aB;b[(c[277218]|0)+(aj<<1)>>1]=aB;r=a[1108909]|0;a[(c[277219]|0)+al|0]=r;a[(c[277219]|0)+aj|0]=r;az=a[1108908]|0;aA=c[277219]|0}else{az=at;aA=au}}while(0);aj=j+6|0;do{if((az&255)>(d[aA+aj|0]|0)){r=a[f+4|0]|0;al=r&255;if(r<<24>>24==0){aF=az;aG=aA;break}do{if((a[1108928]|0)==0){r=b[(c[277225]|0)+(al<<1)>>1]|0;ak=r&65535;am=ak&63454;if((a[(c[277215]|0)+aj|0]&32)==0){ae=c[277228]|0;aH=(e[(c[277220]|0)+((((ae&-2082)+am|0)>>>1)+(ak&2081&ae)<<1)>>1]|(ae^ak)&2081)&65535;break}else{ak=b[(c[277213]|0)+(aj<<1)>>1]|0;aH=(((ak&63454)+am|0)>>>1)+(ak&r&2081)&65535;break}}else{r=e[(c[277225]|0)+(al<<1)>>1]|0;ak=(a[(c[277215]|0)+aj|0]&32)==0;if(ak){am=c[277228]|0;aI=am;aJ=am&-2082}else{am=e[(c[277213]|0)+(aj<<1)>>1]|0;aI=am;aJ=am&63454}if(ak){aK=c[277228]|0}else{aK=e[(c[277213]|0)+(aj<<1)>>1]|0}aH=((aK^r)&2081|e[(c[277220]|0)+((r&2081&aI)+((aJ+(r&63454)|0)>>>1)<<1)>>1])&65535}}while(0);al=j+7|0;b[(c[277218]|0)+(al<<1)>>1]=aH;b[(c[277218]|0)+(aj<<1)>>1]=aH;r=a[1108909]|0;a[(c[277219]|0)+al|0]=r;a[(c[277219]|0)+aj|0]=r;aF=a[1108908]|0;aG=c[277219]|0}else{aF=az;aG=aA}}while(0);aj=j+8|0;do{if((aF&255)>(d[aG+aj|0]|0)){r=a[f+3|0]|0;al=r&255;if(r<<24>>24==0){aL=aF;aM=aG;break}do{if((a[1108928]|0)==0){r=b[(c[277225]|0)+(al<<1)>>1]|0;ak=r&65535;am=ak&63454;if((a[(c[277215]|0)+aj|0]&32)==0){ae=c[277228]|0;aN=(e[(c[277220]|0)+((((ae&-2082)+am|0)>>>1)+(ak&2081&ae)<<1)>>1]|(ae^ak)&2081)&65535;break}else{ak=b[(c[277213]|0)+(aj<<1)>>1]|0;aN=(((ak&63454)+am|0)>>>1)+(ak&r&2081)&65535;break}}else{r=e[(c[277225]|0)+(al<<1)>>1]|0;ak=(a[(c[277215]|0)+aj|0]&32)==0;if(ak){am=c[277228]|0;aO=am;aP=am&-2082}else{am=e[(c[277213]|0)+(aj<<1)>>1]|0;aO=am;aP=am&63454}if(ak){aQ=c[277228]|0}else{aQ=e[(c[277213]|0)+(aj<<1)>>1]|0}aN=((aQ^r)&2081|e[(c[277220]|0)+((r&2081&aO)+((aP+(r&63454)|0)>>>1)<<1)>>1])&65535}}while(0);al=j+9|0;b[(c[277218]|0)+(al<<1)>>1]=aN;b[(c[277218]|0)+(aj<<1)>>1]=aN;r=a[1108909]|0;a[(c[277219]|0)+al|0]=r;a[(c[277219]|0)+aj|0]=r;aL=a[1108908]|0;aM=c[277219]|0}else{aL=aF;aM=aG}}while(0);aj=j+10|0;do{if((aL&255)>(d[aM+aj|0]|0)){r=a[f+2|0]|0;al=r&255;if(r<<24>>24==0){aR=aL;aS=aM;break}do{if((a[1108928]|0)==0){r=b[(c[277225]|0)+(al<<1)>>1]|0;ak=r&65535;am=ak&63454;if((a[(c[277215]|0)+aj|0]&32)==0){ae=c[277228]|0;aT=(e[(c[277220]|0)+((((ae&-2082)+am|0)>>>1)+(ak&2081&ae)<<1)>>1]|(ae^ak)&2081)&65535;break}else{ak=b[(c[277213]|0)+(aj<<1)>>1]|0;aT=(((ak&63454)+am|0)>>>1)+(ak&r&2081)&65535;break}}else{r=e[(c[277225]|0)+(al<<1)>>1]|0;ak=(a[(c[277215]|0)+aj|0]&32)==0;if(ak){am=c[277228]|0;aU=am;aV=am&-2082}else{am=e[(c[277213]|0)+(aj<<1)>>1]|0;aU=am;aV=am&63454}if(ak){aW=c[277228]|0}else{aW=e[(c[277213]|0)+(aj<<1)>>1]|0}aT=((aW^r)&2081|e[(c[277220]|0)+((r&2081&aU)+((aV+(r&63454)|0)>>>1)<<1)>>1])&65535}}while(0);al=j+11|0;b[(c[277218]|0)+(al<<1)>>1]=aT;b[(c[277218]|0)+(aj<<1)>>1]=aT;r=a[1108909]|0;a[(c[277219]|0)+al|0]=r;a[(c[277219]|0)+aj|0]=r;aR=a[1108908]|0;aS=c[277219]|0}else{aR=aL;aS=aM}}while(0);aj=j+12|0;do{if((aR&255)>(d[aS+aj|0]|0)){r=a[f+1|0]|0;al=r&255;if(r<<24>>24==0){aX=aR;aY=aS;break}do{if((a[1108928]|0)==0){r=b[(c[277225]|0)+(al<<1)>>1]|0;ak=r&65535;am=ak&63454;if((a[(c[277215]|0)+aj|0]&32)==0){ae=c[277228]|0;aZ=(e[(c[277220]|0)+((((ae&-2082)+am|0)>>>1)+(ak&2081&ae)<<1)>>1]|(ae^ak)&2081)&65535;break}else{ak=b[(c[277213]|0)+(aj<<1)>>1]|0;aZ=(((ak&63454)+am|0)>>>1)+(ak&r&2081)&65535;break}}else{r=e[(c[277225]|0)+(al<<1)>>1]|0;ak=(a[(c[277215]|0)+aj|0]&32)==0;if(ak){am=c[277228]|0;a_=am;a$=am&-2082}else{am=e[(c[277213]|0)+(aj<<1)>>1]|0;a_=am;a$=am&63454}if(ak){a0=c[277228]|0}else{a0=e[(c[277213]|0)+(aj<<1)>>1]|0}aZ=((a0^r)&2081|e[(c[277220]|0)+((r&2081&a_)+((a$+(r&63454)|0)>>>1)<<1)>>1])&65535}}while(0);al=j+13|0;b[(c[277218]|0)+(al<<1)>>1]=aZ;b[(c[277218]|0)+(aj<<1)>>1]=aZ;r=a[1108909]|0;a[(c[277219]|0)+al|0]=r;a[(c[277219]|0)+aj|0]=r;aX=a[1108908]|0;aY=c[277219]|0}else{aX=aR;aY=aS}}while(0);aj=j+14|0;do{if((aX&255)>(d[aY+aj|0]|0)){r=a[f]|0;al=r&255;if(r<<24>>24==0){break}do{if((a[1108928]|0)==0){r=b[(c[277225]|0)+(al<<1)>>1]|0;ak=r&65535;am=ak&63454;if((a[(c[277215]|0)+aj|0]&32)==0){ae=c[277228]|0;a1=(e[(c[277220]|0)+((((ae&-2082)+am|0)>>>1)+(ak&2081&ae)<<1)>>1]|(ae^ak)&2081)&65535;break}else{ak=b[(c[277213]|0)+(aj<<1)>>1]|0;a1=(((ak&63454)+am|0)>>>1)+(ak&r&2081)&65535;break}}else{r=e[(c[277225]|0)+(al<<1)>>1]|0;ak=(a[(c[277215]|0)+aj|0]&32)==0;if(ak){am=c[277228]|0;a2=am;a3=am&-2082}else{am=e[(c[277213]|0)+(aj<<1)>>1]|0;a2=am;a3=am&63454}if(ak){a4=c[277228]|0}else{a4=e[(c[277213]|0)+(aj<<1)>>1]|0}a1=((a4^r)&2081|e[(c[277220]|0)+((r&2081&a2)+((a3+(r&63454)|0)>>>1)<<1)>>1])&65535}}while(0);al=j+15|0;b[(c[277218]|0)+(al<<1)>>1]=a1;b[(c[277218]|0)+(aj<<1)>>1]=a1;r=a[1108909]|0;a[(c[277219]|0)+al|0]=r;a[(c[277219]|0)+aj|0]=r}}while(0);aj=h-1|0;if((aj|0)<=0){break}f=f+16|0;h=aj;j=(c[277223]|0)+j|0}return}j=p+(56-m)|0;m=(i|0)>0;if(k){if(m){a5=j;a6=i;a7=g}else{return}while(1){k=a[1108908]|0;p=c[277219]|0;do{if((k&255)>(d[p+a7|0]|0)){h=a[a5+7|0]|0;f=h&255;if(h<<24>>24==0){a8=k;a9=p;break}do{if((a[1108928]|0)==0){h=b[(c[277225]|0)+(f<<1)>>1]|0;a1=h&65535;a3=a1&63454;if((a[(c[277215]|0)+a7|0]&32)==0){a2=c[277228]|0;ba=(e[(c[277220]|0)+((((a2&-2082)+a3|0)>>>1)+(a1&2081&a2)<<1)>>1]|(a2^a1)&2081)&65535;break}else{a1=b[(c[277213]|0)+(a7<<1)>>1]|0;ba=(((a1&63454)+a3|0)>>>1)+(a1&h&2081)&65535;break}}else{h=e[(c[277225]|0)+(f<<1)>>1]|0;a1=(a[(c[277215]|0)+a7|0]&32)==0;if(a1){a3=c[277228]|0;bb=a3;bc=a3&-2082}else{a3=e[(c[277213]|0)+(a7<<1)>>1]|0;bb=a3;bc=a3&63454}if(a1){bd=c[277228]|0}else{bd=e[(c[277213]|0)+(a7<<1)>>1]|0}ba=((bd^h)&2081|e[(c[277220]|0)+((h&2081&bb)+((bc+(h&63454)|0)>>>1)<<1)>>1])&65535}}while(0);f=a7+1|0;b[(c[277218]|0)+(f<<1)>>1]=ba;b[(c[277218]|0)+(a7<<1)>>1]=ba;h=a[1108909]|0;a[(c[277219]|0)+f|0]=h;a[(c[277219]|0)+a7|0]=h;a8=a[1108908]|0;a9=c[277219]|0}else{a8=k;a9=p}}while(0);p=a7+2|0;do{if((a8&255)>(d[a9+p|0]|0)){k=a[a5+6|0]|0;h=k&255;if(k<<24>>24==0){be=a8;bf=a9;break}do{if((a[1108928]|0)==0){k=b[(c[277225]|0)+(h<<1)>>1]|0;f=k&65535;a1=f&63454;if((a[(c[277215]|0)+p|0]&32)==0){a3=c[277228]|0;bg=(e[(c[277220]|0)+((((a3&-2082)+a1|0)>>>1)+(f&2081&a3)<<1)>>1]|(a3^f)&2081)&65535;break}else{f=b[(c[277213]|0)+(p<<1)>>1]|0;bg=(((f&63454)+a1|0)>>>1)+(f&k&2081)&65535;break}}else{k=e[(c[277225]|0)+(h<<1)>>1]|0;f=(a[(c[277215]|0)+p|0]&32)==0;if(f){a1=c[277228]|0;bh=a1;bi=a1&-2082}else{a1=e[(c[277213]|0)+(p<<1)>>1]|0;bh=a1;bi=a1&63454}if(f){bj=c[277228]|0}else{bj=e[(c[277213]|0)+(p<<1)>>1]|0}bg=((bj^k)&2081|e[(c[277220]|0)+((k&2081&bh)+((bi+(k&63454)|0)>>>1)<<1)>>1])&65535}}while(0);h=a7+3|0;b[(c[277218]|0)+(h<<1)>>1]=bg;b[(c[277218]|0)+(p<<1)>>1]=bg;k=a[1108909]|0;a[(c[277219]|0)+h|0]=k;a[(c[277219]|0)+p|0]=k;be=a[1108908]|0;bf=c[277219]|0}else{be=a8;bf=a9}}while(0);p=a7+4|0;do{if((be&255)>(d[bf+p|0]|0)){k=a[a5+5|0]|0;h=k&255;if(k<<24>>24==0){bk=be;bl=bf;break}do{if((a[1108928]|0)==0){k=b[(c[277225]|0)+(h<<1)>>1]|0;f=k&65535;a1=f&63454;if((a[(c[277215]|0)+p|0]&32)==0){a3=c[277228]|0;bm=(e[(c[277220]|0)+((((a3&-2082)+a1|0)>>>1)+(f&2081&a3)<<1)>>1]|(a3^f)&2081)&65535;break}else{f=b[(c[277213]|0)+(p<<1)>>1]|0;bm=(((f&63454)+a1|0)>>>1)+(f&k&2081)&65535;break}}else{k=e[(c[277225]|0)+(h<<1)>>1]|0;f=(a[(c[277215]|0)+p|0]&32)==0;if(f){a1=c[277228]|0;bn=a1;bo=a1&-2082}else{a1=e[(c[277213]|0)+(p<<1)>>1]|0;bn=a1;bo=a1&63454}if(f){bp=c[277228]|0}else{bp=e[(c[277213]|0)+(p<<1)>>1]|0}bm=((bp^k)&2081|e[(c[277220]|0)+((k&2081&bn)+((bo+(k&63454)|0)>>>1)<<1)>>1])&65535}}while(0);h=a7+5|0;b[(c[277218]|0)+(h<<1)>>1]=bm;b[(c[277218]|0)+(p<<1)>>1]=bm;k=a[1108909]|0;a[(c[277219]|0)+h|0]=k;a[(c[277219]|0)+p|0]=k;bk=a[1108908]|0;bl=c[277219]|0}else{bk=be;bl=bf}}while(0);p=a7+6|0;do{if((bk&255)>(d[bl+p|0]|0)){k=a[a5+4|0]|0;h=k&255;if(k<<24>>24==0){bq=bk;br=bl;break}do{if((a[1108928]|0)==0){k=b[(c[277225]|0)+(h<<1)>>1]|0;f=k&65535;a1=f&63454;if((a[(c[277215]|0)+p|0]&32)==0){a3=c[277228]|0;bs=(e[(c[277220]|0)+((((a3&-2082)+a1|0)>>>1)+(f&2081&a3)<<1)>>1]|(a3^f)&2081)&65535;break}else{f=b[(c[277213]|0)+(p<<1)>>1]|0;bs=(((f&63454)+a1|0)>>>1)+(f&k&2081)&65535;break}}else{k=e[(c[277225]|0)+(h<<1)>>1]|0;f=(a[(c[277215]|0)+p|0]&32)==0;if(f){a1=c[277228]|0;bt=a1;bu=a1&-2082}else{a1=e[(c[277213]|0)+(p<<1)>>1]|0;bt=a1;bu=a1&63454}if(f){bv=c[277228]|0}else{bv=e[(c[277213]|0)+(p<<1)>>1]|0}bs=((bv^k)&2081|e[(c[277220]|0)+((k&2081&bt)+((bu+(k&63454)|0)>>>1)<<1)>>1])&65535}}while(0);h=a7+7|0;b[(c[277218]|0)+(h<<1)>>1]=bs;b[(c[277218]|0)+(p<<1)>>1]=bs;k=a[1108909]|0;a[(c[277219]|0)+h|0]=k;a[(c[277219]|0)+p|0]=k;bq=a[1108908]|0;br=c[277219]|0}else{bq=bk;br=bl}}while(0);p=a7+8|0;do{if((bq&255)>(d[br+p|0]|0)){k=a[a5+3|0]|0;h=k&255;if(k<<24>>24==0){bw=bq;bx=br;break}do{if((a[1108928]|0)==0){k=b[(c[277225]|0)+(h<<1)>>1]|0;f=k&65535;a1=f&63454;if((a[(c[277215]|0)+p|0]&32)==0){a3=c[277228]|0;by=(e[(c[277220]|0)+((((a3&-2082)+a1|0)>>>1)+(f&2081&a3)<<1)>>1]|(a3^f)&2081)&65535;break}else{f=b[(c[277213]|0)+(p<<1)>>1]|0;by=(((f&63454)+a1|0)>>>1)+(f&k&2081)&65535;break}}else{k=e[(c[277225]|0)+(h<<1)>>1]|0;f=(a[(c[277215]|0)+p|0]&32)==0;if(f){a1=c[277228]|0;bz=a1;bA=a1&-2082}else{a1=e[(c[277213]|0)+(p<<1)>>1]|0;bz=a1;bA=a1&63454}if(f){bB=c[277228]|0}else{bB=e[(c[277213]|0)+(p<<1)>>1]|0}by=((bB^k)&2081|e[(c[277220]|0)+((k&2081&bz)+((bA+(k&63454)|0)>>>1)<<1)>>1])&65535}}while(0);h=a7+9|0;b[(c[277218]|0)+(h<<1)>>1]=by;b[(c[277218]|0)+(p<<1)>>1]=by;k=a[1108909]|0;a[(c[277219]|0)+h|0]=k;a[(c[277219]|0)+p|0]=k;bw=a[1108908]|0;bx=c[277219]|0}else{bw=bq;bx=br}}while(0);p=a7+10|0;do{if((bw&255)>(d[bx+p|0]|0)){k=a[a5+2|0]|0;h=k&255;if(k<<24>>24==0){bC=bw;bD=bx;break}do{if((a[1108928]|0)==0){k=b[(c[277225]|0)+(h<<1)>>1]|0;f=k&65535;a1=f&63454;if((a[(c[277215]|0)+p|0]&32)==0){a3=c[277228]|0;bE=(e[(c[277220]|0)+((((a3&-2082)+a1|0)>>>1)+(f&2081&a3)<<1)>>1]|(a3^f)&2081)&65535;break}else{f=b[(c[277213]|0)+(p<<1)>>1]|0;bE=(((f&63454)+a1|0)>>>1)+(f&k&2081)&65535;break}}else{k=e[(c[277225]|0)+(h<<1)>>1]|0;f=(a[(c[277215]|0)+p|0]&32)==0;if(f){a1=c[277228]|0;bF=a1;bG=a1&-2082}else{a1=e[(c[277213]|0)+(p<<1)>>1]|0;bF=a1;bG=a1&63454}if(f){bH=c[277228]|0}else{bH=e[(c[277213]|0)+(p<<1)>>1]|0}bE=((bH^k)&2081|e[(c[277220]|0)+((k&2081&bF)+((bG+(k&63454)|0)>>>1)<<1)>>1])&65535}}while(0);h=a7+11|0;b[(c[277218]|0)+(h<<1)>>1]=bE;b[(c[277218]|0)+(p<<1)>>1]=bE;k=a[1108909]|0;a[(c[277219]|0)+h|0]=k;a[(c[277219]|0)+p|0]=k;bC=a[1108908]|0;bD=c[277219]|0}else{bC=bw;bD=bx}}while(0);p=a7+12|0;do{if((bC&255)>(d[bD+p|0]|0)){k=a[a5+1|0]|0;h=k&255;if(k<<24>>24==0){bI=bC;bJ=bD;break}do{if((a[1108928]|0)==0){k=b[(c[277225]|0)+(h<<1)>>1]|0;f=k&65535;a1=f&63454;if((a[(c[277215]|0)+p|0]&32)==0){a3=c[277228]|0;bK=(e[(c[277220]|0)+((((a3&-2082)+a1|0)>>>1)+(f&2081&a3)<<1)>>1]|(a3^f)&2081)&65535;break}else{f=b[(c[277213]|0)+(p<<1)>>1]|0;bK=(((f&63454)+a1|0)>>>1)+(f&k&2081)&65535;break}}else{k=e[(c[277225]|0)+(h<<1)>>1]|0;f=(a[(c[277215]|0)+p|0]&32)==0;if(f){a1=c[277228]|0;bL=a1;bM=a1&-2082}else{a1=e[(c[277213]|0)+(p<<1)>>1]|0;bL=a1;bM=a1&63454}if(f){bN=c[277228]|0}else{bN=e[(c[277213]|0)+(p<<1)>>1]|0}bK=((bN^k)&2081|e[(c[277220]|0)+((k&2081&bL)+((bM+(k&63454)|0)>>>1)<<1)>>1])&65535}}while(0);h=a7+13|0;b[(c[277218]|0)+(h<<1)>>1]=bK;b[(c[277218]|0)+(p<<1)>>1]=bK;k=a[1108909]|0;a[(c[277219]|0)+h|0]=k;a[(c[277219]|0)+p|0]=k;bI=a[1108908]|0;bJ=c[277219]|0}else{bI=bC;bJ=bD}}while(0);p=a7+14|0;do{if((bI&255)>(d[bJ+p|0]|0)){k=a[a5]|0;h=k&255;if(k<<24>>24==0){break}do{if((a[1108928]|0)==0){k=b[(c[277225]|0)+(h<<1)>>1]|0;f=k&65535;a1=f&63454;if((a[(c[277215]|0)+p|0]&32)==0){a3=c[277228]|0;bO=(e[(c[277220]|0)+((((a3&-2082)+a1|0)>>>1)+(f&2081&a3)<<1)>>1]|(a3^f)&2081)&65535;break}else{f=b[(c[277213]|0)+(p<<1)>>1]|0;bO=(((f&63454)+a1|0)>>>1)+(f&k&2081)&65535;break}}else{k=e[(c[277225]|0)+(h<<1)>>1]|0;f=(a[(c[277215]|0)+p|0]&32)==0;if(f){a1=c[277228]|0;bP=a1;bQ=a1&-2082}else{a1=e[(c[277213]|0)+(p<<1)>>1]|0;bP=a1;bQ=a1&63454}if(f){bR=c[277228]|0}else{bR=e[(c[277213]|0)+(p<<1)>>1]|0}bO=((bR^k)&2081|e[(c[277220]|0)+((k&2081&bP)+((bQ+(k&63454)|0)>>>1)<<1)>>1])&65535}}while(0);h=a7+15|0;b[(c[277218]|0)+(h<<1)>>1]=bO;b[(c[277218]|0)+(p<<1)>>1]=bO;k=a[1108909]|0;a[(c[277219]|0)+h|0]=k;a[(c[277219]|0)+p|0]=k}}while(0);p=a6-1|0;if((p|0)<=0){break}a5=a5-16|0;a6=p;a7=(c[277223]|0)+a7|0}return}else{if(m){bS=j;bT=i;bU=g}else{return}while(1){g=a[1108908]|0;i=c[277219]|0;do{if((g&255)>(d[i+bU|0]|0)){j=a[bS]|0;m=j&255;if(j<<24>>24==0){bV=g;bW=i;break}do{if((a[1108928]|0)==0){j=b[(c[277225]|0)+(m<<1)>>1]|0;a7=j&65535;a6=a7&63454;if((a[(c[277215]|0)+bU|0]&32)==0){a5=c[277228]|0;bX=(e[(c[277220]|0)+((((a5&-2082)+a6|0)>>>1)+(a7&2081&a5)<<1)>>1]|(a5^a7)&2081)&65535;break}else{a7=b[(c[277213]|0)+(bU<<1)>>1]|0;bX=(((a7&63454)+a6|0)>>>1)+(a7&j&2081)&65535;break}}else{j=e[(c[277225]|0)+(m<<1)>>1]|0;a7=(a[(c[277215]|0)+bU|0]&32)==0;if(a7){a6=c[277228]|0;bY=a6;bZ=a6&-2082}else{a6=e[(c[277213]|0)+(bU<<1)>>1]|0;bY=a6;bZ=a6&63454}if(a7){b_=c[277228]|0}else{b_=e[(c[277213]|0)+(bU<<1)>>1]|0}bX=((b_^j)&2081|e[(c[277220]|0)+((j&2081&bY)+((bZ+(j&63454)|0)>>>1)<<1)>>1])&65535}}while(0);m=bU+1|0;b[(c[277218]|0)+(m<<1)>>1]=bX;b[(c[277218]|0)+(bU<<1)>>1]=bX;j=a[1108909]|0;a[(c[277219]|0)+m|0]=j;a[(c[277219]|0)+bU|0]=j;bV=a[1108908]|0;bW=c[277219]|0}else{bV=g;bW=i}}while(0);i=bU+2|0;do{if((bV&255)>(d[bW+i|0]|0)){g=a[bS+1|0]|0;j=g&255;if(g<<24>>24==0){b$=bV;b0=bW;break}do{if((a[1108928]|0)==0){g=b[(c[277225]|0)+(j<<1)>>1]|0;m=g&65535;a7=m&63454;if((a[(c[277215]|0)+i|0]&32)==0){a6=c[277228]|0;b1=(e[(c[277220]|0)+((((a6&-2082)+a7|0)>>>1)+(m&2081&a6)<<1)>>1]|(a6^m)&2081)&65535;break}else{m=b[(c[277213]|0)+(i<<1)>>1]|0;b1=(((m&63454)+a7|0)>>>1)+(m&g&2081)&65535;break}}else{g=e[(c[277225]|0)+(j<<1)>>1]|0;m=(a[(c[277215]|0)+i|0]&32)==0;if(m){a7=c[277228]|0;b2=a7;b3=a7&-2082}else{a7=e[(c[277213]|0)+(i<<1)>>1]|0;b2=a7;b3=a7&63454}if(m){b4=c[277228]|0}else{b4=e[(c[277213]|0)+(i<<1)>>1]|0}b1=((b4^g)&2081|e[(c[277220]|0)+((g&2081&b2)+((b3+(g&63454)|0)>>>1)<<1)>>1])&65535}}while(0);j=bU+3|0;b[(c[277218]|0)+(j<<1)>>1]=b1;b[(c[277218]|0)+(i<<1)>>1]=b1;g=a[1108909]|0;a[(c[277219]|0)+j|0]=g;a[(c[277219]|0)+i|0]=g;b$=a[1108908]|0;b0=c[277219]|0}else{b$=bV;b0=bW}}while(0);i=bU+4|0;do{if((b$&255)>(d[b0+i|0]|0)){g=a[bS+2|0]|0;j=g&255;if(g<<24>>24==0){b5=b$;b6=b0;break}do{if((a[1108928]|0)==0){g=b[(c[277225]|0)+(j<<1)>>1]|0;m=g&65535;a7=m&63454;if((a[(c[277215]|0)+i|0]&32)==0){a6=c[277228]|0;b7=(e[(c[277220]|0)+((((a6&-2082)+a7|0)>>>1)+(m&2081&a6)<<1)>>1]|(a6^m)&2081)&65535;break}else{m=b[(c[277213]|0)+(i<<1)>>1]|0;b7=(((m&63454)+a7|0)>>>1)+(m&g&2081)&65535;break}}else{g=e[(c[277225]|0)+(j<<1)>>1]|0;m=(a[(c[277215]|0)+i|0]&32)==0;if(m){a7=c[277228]|0;b8=a7;b9=a7&-2082}else{a7=e[(c[277213]|0)+(i<<1)>>1]|0;b8=a7;b9=a7&63454}if(m){ca=c[277228]|0}else{ca=e[(c[277213]|0)+(i<<1)>>1]|0}b7=((ca^g)&2081|e[(c[277220]|0)+((g&2081&b8)+((b9+(g&63454)|0)>>>1)<<1)>>1])&65535}}while(0);j=bU+5|0;b[(c[277218]|0)+(j<<1)>>1]=b7;b[(c[277218]|0)+(i<<1)>>1]=b7;g=a[1108909]|0;a[(c[277219]|0)+j|0]=g;a[(c[277219]|0)+i|0]=g;b5=a[1108908]|0;b6=c[277219]|0}else{b5=b$;b6=b0}}while(0);i=bU+6|0;do{if((b5&255)>(d[b6+i|0]|0)){g=a[bS+3|0]|0;j=g&255;if(g<<24>>24==0){cb=b5;cc=b6;break}do{if((a[1108928]|0)==0){g=b[(c[277225]|0)+(j<<1)>>1]|0;m=g&65535;a7=m&63454;if((a[(c[277215]|0)+i|0]&32)==0){a6=c[277228]|0;cd=(e[(c[277220]|0)+((((a6&-2082)+a7|0)>>>1)+(m&2081&a6)<<1)>>1]|(a6^m)&2081)&65535;break}else{m=b[(c[277213]|0)+(i<<1)>>1]|0;cd=(((m&63454)+a7|0)>>>1)+(m&g&2081)&65535;break}}else{g=e[(c[277225]|0)+(j<<1)>>1]|0;m=(a[(c[277215]|0)+i|0]&32)==0;if(m){a7=c[277228]|0;ce=a7;cf=a7&-2082}else{a7=e[(c[277213]|0)+(i<<1)>>1]|0;ce=a7;cf=a7&63454}if(m){cg=c[277228]|0}else{cg=e[(c[277213]|0)+(i<<1)>>1]|0}cd=((cg^g)&2081|e[(c[277220]|0)+((g&2081&ce)+((cf+(g&63454)|0)>>>1)<<1)>>1])&65535}}while(0);j=bU+7|0;b[(c[277218]|0)+(j<<1)>>1]=cd;b[(c[277218]|0)+(i<<1)>>1]=cd;g=a[1108909]|0;a[(c[277219]|0)+j|0]=g;a[(c[277219]|0)+i|0]=g;cb=a[1108908]|0;cc=c[277219]|0}else{cb=b5;cc=b6}}while(0);i=bU+8|0;do{if((cb&255)>(d[cc+i|0]|0)){g=a[bS+4|0]|0;j=g&255;if(g<<24>>24==0){ch=cb;ci=cc;break}do{if((a[1108928]|0)==0){g=b[(c[277225]|0)+(j<<1)>>1]|0;m=g&65535;a7=m&63454;if((a[(c[277215]|0)+i|0]&32)==0){a6=c[277228]|0;cj=(e[(c[277220]|0)+((((a6&-2082)+a7|0)>>>1)+(m&2081&a6)<<1)>>1]|(a6^m)&2081)&65535;break}else{m=b[(c[277213]|0)+(i<<1)>>1]|0;cj=(((m&63454)+a7|0)>>>1)+(m&g&2081)&65535;break}}else{g=e[(c[277225]|0)+(j<<1)>>1]|0;m=(a[(c[277215]|0)+i|0]&32)==0;if(m){a7=c[277228]|0;ck=a7;cl=a7&-2082}else{a7=e[(c[277213]|0)+(i<<1)>>1]|0;ck=a7;cl=a7&63454}if(m){cm=c[277228]|0}else{cm=e[(c[277213]|0)+(i<<1)>>1]|0}cj=((cm^g)&2081|e[(c[277220]|0)+((g&2081&ck)+((cl+(g&63454)|0)>>>1)<<1)>>1])&65535}}while(0);j=bU+9|0;b[(c[277218]|0)+(j<<1)>>1]=cj;b[(c[277218]|0)+(i<<1)>>1]=cj;g=a[1108909]|0;a[(c[277219]|0)+j|0]=g;a[(c[277219]|0)+i|0]=g;ch=a[1108908]|0;ci=c[277219]|0}else{ch=cb;ci=cc}}while(0);i=bU+10|0;do{if((ch&255)>(d[ci+i|0]|0)){g=a[bS+5|0]|0;j=g&255;if(g<<24>>24==0){cn=ch;co=ci;break}do{if((a[1108928]|0)==0){g=b[(c[277225]|0)+(j<<1)>>1]|0;m=g&65535;a7=m&63454;if((a[(c[277215]|0)+i|0]&32)==0){a6=c[277228]|0;cp=(e[(c[277220]|0)+((((a6&-2082)+a7|0)>>>1)+(m&2081&a6)<<1)>>1]|(a6^m)&2081)&65535;break}else{m=b[(c[277213]|0)+(i<<1)>>1]|0;cp=(((m&63454)+a7|0)>>>1)+(m&g&2081)&65535;break}}else{g=e[(c[277225]|0)+(j<<1)>>1]|0;m=(a[(c[277215]|0)+i|0]&32)==0;if(m){a7=c[277228]|0;cq=a7;cr=a7&-2082}else{a7=e[(c[277213]|0)+(i<<1)>>1]|0;cq=a7;cr=a7&63454}if(m){cs=c[277228]|0}else{cs=e[(c[277213]|0)+(i<<1)>>1]|0}cp=((cs^g)&2081|e[(c[277220]|0)+((g&2081&cq)+((cr+(g&63454)|0)>>>1)<<1)>>1])&65535}}while(0);j=bU+11|0;b[(c[277218]|0)+(j<<1)>>1]=cp;b[(c[277218]|0)+(i<<1)>>1]=cp;g=a[1108909]|0;a[(c[277219]|0)+j|0]=g;a[(c[277219]|0)+i|0]=g;cn=a[1108908]|0;co=c[277219]|0}else{cn=ch;co=ci}}while(0);i=bU+12|0;do{if((cn&255)>(d[co+i|0]|0)){g=a[bS+6|0]|0;j=g&255;if(g<<24>>24==0){ct=cn;cu=co;break}do{if((a[1108928]|0)==0){g=b[(c[277225]|0)+(j<<1)>>1]|0;m=g&65535;a7=m&63454;if((a[(c[277215]|0)+i|0]&32)==0){a6=c[277228]|0;cv=(e[(c[277220]|0)+((((a6&-2082)+a7|0)>>>1)+(m&2081&a6)<<1)>>1]|(a6^m)&2081)&65535;break}else{m=b[(c[277213]|0)+(i<<1)>>1]|0;cv=(((m&63454)+a7|0)>>>1)+(m&g&2081)&65535;break}}else{g=e[(c[277225]|0)+(j<<1)>>1]|0;m=(a[(c[277215]|0)+i|0]&32)==0;if(m){a7=c[277228]|0;cw=a7;cx=a7&-2082}else{a7=e[(c[277213]|0)+(i<<1)>>1]|0;cw=a7;cx=a7&63454}if(m){cy=c[277228]|0}else{cy=e[(c[277213]|0)+(i<<1)>>1]|0}cv=((cy^g)&2081|e[(c[277220]|0)+((g&2081&cw)+((cx+(g&63454)|0)>>>1)<<1)>>1])&65535}}while(0);j=bU+13|0;b[(c[277218]|0)+(j<<1)>>1]=cv;b[(c[277218]|0)+(i<<1)>>1]=cv;g=a[1108909]|0;a[(c[277219]|0)+j|0]=g;a[(c[277219]|0)+i|0]=g;ct=a[1108908]|0;cu=c[277219]|0}else{ct=cn;cu=co}}while(0);i=bU+14|0;do{if((ct&255)>(d[cu+i|0]|0)){g=a[bS+7|0]|0;j=g&255;if(g<<24>>24==0){break}do{if((a[1108928]|0)==0){g=b[(c[277225]|0)+(j<<1)>>1]|0;m=g&65535;a7=m&63454;if((a[(c[277215]|0)+i|0]&32)==0){a6=c[277228]|0;cz=(e[(c[277220]|0)+((((a6&-2082)+a7|0)>>>1)+(m&2081&a6)<<1)>>1]|(a6^m)&2081)&65535;break}else{m=b[(c[277213]|0)+(i<<1)>>1]|0;cz=(((m&63454)+a7|0)>>>1)+(m&g&2081)&65535;break}}else{g=e[(c[277225]|0)+(j<<1)>>1]|0;m=(a[(c[277215]|0)+i|0]&32)==0;if(m){a7=c[277228]|0;cA=a7;cB=a7&-2082}else{a7=e[(c[277213]|0)+(i<<1)>>1]|0;cA=a7;cB=a7&63454}if(m){cC=c[277228]|0}else{cC=e[(c[277213]|0)+(i<<1)>>1]|0}cz=((cC^g)&2081|e[(c[277220]|0)+((g&2081&cA)+((cB+(g&63454)|0)>>>1)<<1)>>1])&65535}}while(0);j=bU+15|0;b[(c[277218]|0)+(j<<1)>>1]=cz;b[(c[277218]|0)+(i<<1)>>1]=cz;g=a[1108909]|0;a[(c[277219]|0)+j|0]=g;a[(c[277219]|0)+i|0]=g}}while(0);i=bT-1|0;if((i|0)<=0){break}bS=bS-16|0;bT=i;bU=(c[277223]|0)+bU|0}return}}function Vq(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0;i=e&1023;j=c[348606]|0;k=(i<<j)+(c[348604]|0)|0;if((e&256|0)==0){l=k}else{l=(c[348602]|0)+k|0}k=l&65535;l=k>>>(j>>>0);j=(e&16384|0)!=0;m=l<<6;do{if(j){n=(c[348622]|0)+m|0;if((a[(c[348618]|0)+l|0]|0)!=0){o=n;break}p=fi[c[348636]&63](n,k,i)|0;a[(c[348618]|0)+l|0]=p;o=n}else{n=(c[348624]|0)+m|0;if((a[(c[348620]|0)+l|0]|0)!=0){o=n;break}p=fi[c[348638]&63](n,k,i)|0;a[(c[348620]|0)+l|0]=p;o=n}}while(0);if((a[(c[348620]|0)+l|0]|0)==2){return}if((a[1394464]|0)==0){q=1106168+((e>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){l=d[1044485]|0;c[276541]=7080+(l<<5);i=0;do{k=i<<1&2;m=i&2;n=i&4;p=0;do{b[1125528+(i<<9)+(p<<1)>>1]=d[(p>>>1&28|m)+(7080+(l<<5))|0]<<6|d[(p<<2&28|k)+(7080+(l<<5))|0]<<11|d[(p>>>3&24|n)+(7080+(l<<5))|0];p=p+1|0;}while(p>>>0<256);i=i+1|0;}while(i>>>0<8);a[1106089]=0}q=1125528+((e>>>10&7)<<9)|0}c[277226]=q;c[277225]=(a[1108928]|0)!=0?1393712:q;if((e&49152|0)==0){if((h|0)<=0){return}q=o+((d[1394504]|0)+(g<<1))|0;i=h;l=f;while(1){p=a[1108908]|0;n=c[277219]|0;do{if((p&255)>(d[n+l|0]|0)){k=a[q]|0;if(k<<24>>24==0){r=p;s=n;break}m=b[(c[277225]|0)+((k&255)<<1)>>1]|0;if((a[(c[277215]|0)+l|0]&32)==0){t=c[277228]&65535}else{t=b[(c[277213]|0)+(l<<1)>>1]|0}k=m&-2048;u=t&-2048;v=(k&65535)>(u&65535)?k-u&65535:0;u=m&2016;k=t&2016;if((u&65535)>(k&65535)){w=(u-k&65535)+v&65535}else{w=v}v=m&31;m=t&31;if((v&65535)>(m&65535)){x=(v-m&65535)+w&65535}else{x=w}m=l+1|0;b[(c[277218]|0)+(m<<1)>>1]=x;b[(c[277218]|0)+(l<<1)>>1]=x;v=a[1108909]|0;a[(c[277219]|0)+m|0]=v;a[(c[277219]|0)+l|0]=v;r=a[1108908]|0;s=c[277219]|0}else{r=p;s=n}}while(0);n=l+2|0;do{if((r&255)>(d[s+n|0]|0)){p=a[q+1|0]|0;if(p<<24>>24==0){y=r;z=s;break}v=b[(c[277225]|0)+((p&255)<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)==0){A=c[277228]&65535}else{A=b[(c[277213]|0)+(n<<1)>>1]|0}p=v&-2048;m=A&-2048;k=(p&65535)>(m&65535)?p-m&65535:0;m=v&2016;p=A&2016;if((m&65535)>(p&65535)){B=(m-p&65535)+k&65535}else{B=k}k=v&31;v=A&31;if((k&65535)>(v&65535)){C=(k-v&65535)+B&65535}else{C=B}v=l+3|0;b[(c[277218]|0)+(v<<1)>>1]=C;b[(c[277218]|0)+(n<<1)>>1]=C;k=a[1108909]|0;a[(c[277219]|0)+v|0]=k;a[(c[277219]|0)+n|0]=k;y=a[1108908]|0;z=c[277219]|0}else{y=r;z=s}}while(0);n=l+4|0;do{if((y&255)>(d[z+n|0]|0)){k=a[q+2|0]|0;if(k<<24>>24==0){D=y;E=z;break}v=b[(c[277225]|0)+((k&255)<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)==0){F=c[277228]&65535}else{F=b[(c[277213]|0)+(n<<1)>>1]|0}k=v&-2048;p=F&-2048;m=(k&65535)>(p&65535)?k-p&65535:0;p=v&2016;k=F&2016;if((p&65535)>(k&65535)){G=(p-k&65535)+m&65535}else{G=m}m=v&31;v=F&31;if((m&65535)>(v&65535)){H=(m-v&65535)+G&65535}else{H=G}v=l+5|0;b[(c[277218]|0)+(v<<1)>>1]=H;b[(c[277218]|0)+(n<<1)>>1]=H;m=a[1108909]|0;a[(c[277219]|0)+v|0]=m;a[(c[277219]|0)+n|0]=m;D=a[1108908]|0;E=c[277219]|0}else{D=y;E=z}}while(0);n=l+6|0;do{if((D&255)>(d[E+n|0]|0)){m=a[q+3|0]|0;if(m<<24>>24==0){I=D;J=E;break}v=b[(c[277225]|0)+((m&255)<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)==0){K=c[277228]&65535}else{K=b[(c[277213]|0)+(n<<1)>>1]|0}m=v&-2048;k=K&-2048;p=(m&65535)>(k&65535)?m-k&65535:0;k=v&2016;m=K&2016;if((k&65535)>(m&65535)){L=(k-m&65535)+p&65535}else{L=p}p=v&31;v=K&31;if((p&65535)>(v&65535)){M=(p-v&65535)+L&65535}else{M=L}v=l+7|0;b[(c[277218]|0)+(v<<1)>>1]=M;b[(c[277218]|0)+(n<<1)>>1]=M;p=a[1108909]|0;a[(c[277219]|0)+v|0]=p;a[(c[277219]|0)+n|0]=p;I=a[1108908]|0;J=c[277219]|0}else{I=D;J=E}}while(0);n=l+8|0;do{if((I&255)>(d[J+n|0]|0)){p=a[q+4|0]|0;if(p<<24>>24==0){N=I;O=J;break}v=b[(c[277225]|0)+((p&255)<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)==0){P=c[277228]&65535}else{P=b[(c[277213]|0)+(n<<1)>>1]|0}p=v&-2048;m=P&-2048;k=(p&65535)>(m&65535)?p-m&65535:0;m=v&2016;p=P&2016;if((m&65535)>(p&65535)){Q=(m-p&65535)+k&65535}else{Q=k}k=v&31;v=P&31;if((k&65535)>(v&65535)){R=(k-v&65535)+Q&65535}else{R=Q}v=l+9|0;b[(c[277218]|0)+(v<<1)>>1]=R;b[(c[277218]|0)+(n<<1)>>1]=R;k=a[1108909]|0;a[(c[277219]|0)+v|0]=k;a[(c[277219]|0)+n|0]=k;N=a[1108908]|0;O=c[277219]|0}else{N=I;O=J}}while(0);n=l+10|0;do{if((N&255)>(d[O+n|0]|0)){k=a[q+5|0]|0;if(k<<24>>24==0){S=N;T=O;break}v=b[(c[277225]|0)+((k&255)<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)==0){U=c[277228]&65535}else{U=b[(c[277213]|0)+(n<<1)>>1]|0}k=v&-2048;p=U&-2048;m=(k&65535)>(p&65535)?k-p&65535:0;p=v&2016;k=U&2016;if((p&65535)>(k&65535)){V=(p-k&65535)+m&65535}else{V=m}m=v&31;v=U&31;if((m&65535)>(v&65535)){W=(m-v&65535)+V&65535}else{W=V}v=l+11|0;b[(c[277218]|0)+(v<<1)>>1]=W;b[(c[277218]|0)+(n<<1)>>1]=W;m=a[1108909]|0;a[(c[277219]|0)+v|0]=m;a[(c[277219]|0)+n|0]=m;S=a[1108908]|0;T=c[277219]|0}else{S=N;T=O}}while(0);n=l+12|0;do{if((S&255)>(d[T+n|0]|0)){m=a[q+6|0]|0;if(m<<24>>24==0){X=S;Y=T;break}v=b[(c[277225]|0)+((m&255)<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)==0){Z=c[277228]&65535}else{Z=b[(c[277213]|0)+(n<<1)>>1]|0}m=v&-2048;k=Z&-2048;p=(m&65535)>(k&65535)?m-k&65535:0;k=v&2016;m=Z&2016;if((k&65535)>(m&65535)){_=(k-m&65535)+p&65535}else{_=p}p=v&31;v=Z&31;if((p&65535)>(v&65535)){$=(p-v&65535)+_&65535}else{$=_}v=l+13|0;b[(c[277218]|0)+(v<<1)>>1]=$;b[(c[277218]|0)+(n<<1)>>1]=$;p=a[1108909]|0;a[(c[277219]|0)+v|0]=p;a[(c[277219]|0)+n|0]=p;X=a[1108908]|0;Y=c[277219]|0}else{X=S;Y=T}}while(0);n=l+14|0;do{if((X&255)>(d[Y+n|0]|0)){p=a[q+7|0]|0;if(p<<24>>24==0){break}v=b[(c[277225]|0)+((p&255)<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)==0){aa=c[277228]&65535}else{aa=b[(c[277213]|0)+(n<<1)>>1]|0}p=v&-2048;m=aa&-2048;k=(p&65535)>(m&65535)?p-m&65535:0;m=v&2016;p=aa&2016;if((m&65535)>(p&65535)){ab=(m-p&65535)+k&65535}else{ab=k}k=v&31;v=aa&31;if((k&65535)>(v&65535)){ac=(k-v&65535)+ab&65535}else{ac=ab}v=l+15|0;b[(c[277218]|0)+(v<<1)>>1]=ac;b[(c[277218]|0)+(n<<1)>>1]=ac;k=a[1108909]|0;a[(c[277219]|0)+v|0]=k;a[(c[277219]|0)+n|0]=k}}while(0);n=i-1|0;if((n|0)<=0){break}q=q+16|0;i=n;l=(c[277223]|0)+l|0}return}l=(d[1394504]|0)+(g<<1)|0;if((e&32768|0)==0){if((h|0)<=0){return}e=o+l|0;g=h;i=f;while(1){q=a[1108908]|0;ac=c[277219]|0;do{if((q&255)>(d[ac+i|0]|0)){ab=a[e+7|0]|0;if(ab<<24>>24==0){ad=q;ae=ac;break}aa=b[(c[277225]|0)+((ab&255)<<1)>>1]|0;if((a[(c[277215]|0)+i|0]&32)==0){af=c[277228]&65535}else{af=b[(c[277213]|0)+(i<<1)>>1]|0}ab=aa&-2048;Y=af&-2048;X=(ab&65535)>(Y&65535)?ab-Y&65535:0;Y=aa&2016;ab=af&2016;if((Y&65535)>(ab&65535)){ag=(Y-ab&65535)+X&65535}else{ag=X}X=aa&31;aa=af&31;if((X&65535)>(aa&65535)){ah=(X-aa&65535)+ag&65535}else{ah=ag}aa=i+1|0;b[(c[277218]|0)+(aa<<1)>>1]=ah;b[(c[277218]|0)+(i<<1)>>1]=ah;X=a[1108909]|0;a[(c[277219]|0)+aa|0]=X;a[(c[277219]|0)+i|0]=X;ad=a[1108908]|0;ae=c[277219]|0}else{ad=q;ae=ac}}while(0);ac=i+2|0;do{if((ad&255)>(d[ae+ac|0]|0)){q=a[e+6|0]|0;if(q<<24>>24==0){ai=ad;aj=ae;break}X=b[(c[277225]|0)+((q&255)<<1)>>1]|0;if((a[(c[277215]|0)+ac|0]&32)==0){ak=c[277228]&65535}else{ak=b[(c[277213]|0)+(ac<<1)>>1]|0}q=X&-2048;aa=ak&-2048;ab=(q&65535)>(aa&65535)?q-aa&65535:0;aa=X&2016;q=ak&2016;if((aa&65535)>(q&65535)){al=(aa-q&65535)+ab&65535}else{al=ab}ab=X&31;X=ak&31;if((ab&65535)>(X&65535)){am=(ab-X&65535)+al&65535}else{am=al}X=i+3|0;b[(c[277218]|0)+(X<<1)>>1]=am;b[(c[277218]|0)+(ac<<1)>>1]=am;ab=a[1108909]|0;a[(c[277219]|0)+X|0]=ab;a[(c[277219]|0)+ac|0]=ab;ai=a[1108908]|0;aj=c[277219]|0}else{ai=ad;aj=ae}}while(0);ac=i+4|0;do{if((ai&255)>(d[aj+ac|0]|0)){ab=a[e+5|0]|0;if(ab<<24>>24==0){an=ai;ao=aj;break}X=b[(c[277225]|0)+((ab&255)<<1)>>1]|0;if((a[(c[277215]|0)+ac|0]&32)==0){ap=c[277228]&65535}else{ap=b[(c[277213]|0)+(ac<<1)>>1]|0}ab=X&-2048;q=ap&-2048;aa=(ab&65535)>(q&65535)?ab-q&65535:0;q=X&2016;ab=ap&2016;if((q&65535)>(ab&65535)){aq=(q-ab&65535)+aa&65535}else{aq=aa}aa=X&31;X=ap&31;if((aa&65535)>(X&65535)){ar=(aa-X&65535)+aq&65535}else{ar=aq}X=i+5|0;b[(c[277218]|0)+(X<<1)>>1]=ar;b[(c[277218]|0)+(ac<<1)>>1]=ar;aa=a[1108909]|0;a[(c[277219]|0)+X|0]=aa;a[(c[277219]|0)+ac|0]=aa;an=a[1108908]|0;ao=c[277219]|0}else{an=ai;ao=aj}}while(0);ac=i+6|0;do{if((an&255)>(d[ao+ac|0]|0)){aa=a[e+4|0]|0;if(aa<<24>>24==0){as=an;at=ao;break}X=b[(c[277225]|0)+((aa&255)<<1)>>1]|0;if((a[(c[277215]|0)+ac|0]&32)==0){au=c[277228]&65535}else{au=b[(c[277213]|0)+(ac<<1)>>1]|0}aa=X&-2048;ab=au&-2048;q=(aa&65535)>(ab&65535)?aa-ab&65535:0;ab=X&2016;aa=au&2016;if((ab&65535)>(aa&65535)){av=(ab-aa&65535)+q&65535}else{av=q}q=X&31;X=au&31;if((q&65535)>(X&65535)){aw=(q-X&65535)+av&65535}else{aw=av}X=i+7|0;b[(c[277218]|0)+(X<<1)>>1]=aw;b[(c[277218]|0)+(ac<<1)>>1]=aw;q=a[1108909]|0;a[(c[277219]|0)+X|0]=q;a[(c[277219]|0)+ac|0]=q;as=a[1108908]|0;at=c[277219]|0}else{as=an;at=ao}}while(0);ac=i+8|0;do{if((as&255)>(d[at+ac|0]|0)){q=a[e+3|0]|0;if(q<<24>>24==0){ax=as;ay=at;break}X=b[(c[277225]|0)+((q&255)<<1)>>1]|0;if((a[(c[277215]|0)+ac|0]&32)==0){az=c[277228]&65535}else{az=b[(c[277213]|0)+(ac<<1)>>1]|0}q=X&-2048;aa=az&-2048;ab=(q&65535)>(aa&65535)?q-aa&65535:0;aa=X&2016;q=az&2016;if((aa&65535)>(q&65535)){aA=(aa-q&65535)+ab&65535}else{aA=ab}ab=X&31;X=az&31;if((ab&65535)>(X&65535)){aB=(ab-X&65535)+aA&65535}else{aB=aA}X=i+9|0;b[(c[277218]|0)+(X<<1)>>1]=aB;b[(c[277218]|0)+(ac<<1)>>1]=aB;ab=a[1108909]|0;a[(c[277219]|0)+X|0]=ab;a[(c[277219]|0)+ac|0]=ab;ax=a[1108908]|0;ay=c[277219]|0}else{ax=as;ay=at}}while(0);ac=i+10|0;do{if((ax&255)>(d[ay+ac|0]|0)){ab=a[e+2|0]|0;if(ab<<24>>24==0){aC=ax;aD=ay;break}X=b[(c[277225]|0)+((ab&255)<<1)>>1]|0;if((a[(c[277215]|0)+ac|0]&32)==0){aE=c[277228]&65535}else{aE=b[(c[277213]|0)+(ac<<1)>>1]|0}ab=X&-2048;q=aE&-2048;aa=(ab&65535)>(q&65535)?ab-q&65535:0;q=X&2016;ab=aE&2016;if((q&65535)>(ab&65535)){aF=(q-ab&65535)+aa&65535}else{aF=aa}aa=X&31;X=aE&31;if((aa&65535)>(X&65535)){aG=(aa-X&65535)+aF&65535}else{aG=aF}X=i+11|0;b[(c[277218]|0)+(X<<1)>>1]=aG;b[(c[277218]|0)+(ac<<1)>>1]=aG;aa=a[1108909]|0;a[(c[277219]|0)+X|0]=aa;a[(c[277219]|0)+ac|0]=aa;aC=a[1108908]|0;aD=c[277219]|0}else{aC=ax;aD=ay}}while(0);ac=i+12|0;do{if((aC&255)>(d[aD+ac|0]|0)){aa=a[e+1|0]|0;if(aa<<24>>24==0){aH=aC;aI=aD;break}X=b[(c[277225]|0)+((aa&255)<<1)>>1]|0;if((a[(c[277215]|0)+ac|0]&32)==0){aJ=c[277228]&65535}else{aJ=b[(c[277213]|0)+(ac<<1)>>1]|0}aa=X&-2048;ab=aJ&-2048;q=(aa&65535)>(ab&65535)?aa-ab&65535:0;ab=X&2016;aa=aJ&2016;if((ab&65535)>(aa&65535)){aK=(ab-aa&65535)+q&65535}else{aK=q}q=X&31;X=aJ&31;if((q&65535)>(X&65535)){aL=(q-X&65535)+aK&65535}else{aL=aK}X=i+13|0;b[(c[277218]|0)+(X<<1)>>1]=aL;b[(c[277218]|0)+(ac<<1)>>1]=aL;q=a[1108909]|0;a[(c[277219]|0)+X|0]=q;a[(c[277219]|0)+ac|0]=q;aH=a[1108908]|0;aI=c[277219]|0}else{aH=aC;aI=aD}}while(0);ac=i+14|0;do{if((aH&255)>(d[aI+ac|0]|0)){q=a[e]|0;if(q<<24>>24==0){break}X=b[(c[277225]|0)+((q&255)<<1)>>1]|0;if((a[(c[277215]|0)+ac|0]&32)==0){aM=c[277228]&65535}else{aM=b[(c[277213]|0)+(ac<<1)>>1]|0}q=X&-2048;aa=aM&-2048;ab=(q&65535)>(aa&65535)?q-aa&65535:0;aa=X&2016;q=aM&2016;if((aa&65535)>(q&65535)){aN=(aa-q&65535)+ab&65535}else{aN=ab}ab=X&31;X=aM&31;if((ab&65535)>(X&65535)){aO=(ab-X&65535)+aN&65535}else{aO=aN}X=i+15|0;b[(c[277218]|0)+(X<<1)>>1]=aO;b[(c[277218]|0)+(ac<<1)>>1]=aO;ab=a[1108909]|0;a[(c[277219]|0)+X|0]=ab;a[(c[277219]|0)+ac|0]=ab}}while(0);ac=g-1|0;if((ac|0)<=0){break}e=e+16|0;g=ac;i=(c[277223]|0)+i|0}return}i=o+(56-l)|0;l=(h|0)>0;if(j){if(l){aP=i;aQ=h;aR=f}else{return}while(1){j=a[1108908]|0;o=c[277219]|0;do{if((j&255)>(d[o+aR|0]|0)){g=a[aP+7|0]|0;if(g<<24>>24==0){aS=j;aT=o;break}e=b[(c[277225]|0)+((g&255)<<1)>>1]|0;if((a[(c[277215]|0)+aR|0]&32)==0){aU=c[277228]&65535}else{aU=b[(c[277213]|0)+(aR<<1)>>1]|0}g=e&-2048;aO=aU&-2048;aN=(g&65535)>(aO&65535)?g-aO&65535:0;aO=e&2016;g=aU&2016;if((aO&65535)>(g&65535)){aV=(aO-g&65535)+aN&65535}else{aV=aN}aN=e&31;e=aU&31;if((aN&65535)>(e&65535)){aW=(aN-e&65535)+aV&65535}else{aW=aV}e=aR+1|0;b[(c[277218]|0)+(e<<1)>>1]=aW;b[(c[277218]|0)+(aR<<1)>>1]=aW;aN=a[1108909]|0;a[(c[277219]|0)+e|0]=aN;a[(c[277219]|0)+aR|0]=aN;aS=a[1108908]|0;aT=c[277219]|0}else{aS=j;aT=o}}while(0);o=aR+2|0;do{if((aS&255)>(d[aT+o|0]|0)){j=a[aP+6|0]|0;if(j<<24>>24==0){aX=aS;aY=aT;break}aN=b[(c[277225]|0)+((j&255)<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){aZ=c[277228]&65535}else{aZ=b[(c[277213]|0)+(o<<1)>>1]|0}j=aN&-2048;e=aZ&-2048;g=(j&65535)>(e&65535)?j-e&65535:0;e=aN&2016;j=aZ&2016;if((e&65535)>(j&65535)){a_=(e-j&65535)+g&65535}else{a_=g}g=aN&31;aN=aZ&31;if((g&65535)>(aN&65535)){a$=(g-aN&65535)+a_&65535}else{a$=a_}aN=aR+3|0;b[(c[277218]|0)+(aN<<1)>>1]=a$;b[(c[277218]|0)+(o<<1)>>1]=a$;g=a[1108909]|0;a[(c[277219]|0)+aN|0]=g;a[(c[277219]|0)+o|0]=g;aX=a[1108908]|0;aY=c[277219]|0}else{aX=aS;aY=aT}}while(0);o=aR+4|0;do{if((aX&255)>(d[aY+o|0]|0)){g=a[aP+5|0]|0;if(g<<24>>24==0){a0=aX;a1=aY;break}aN=b[(c[277225]|0)+((g&255)<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){a2=c[277228]&65535}else{a2=b[(c[277213]|0)+(o<<1)>>1]|0}g=aN&-2048;j=a2&-2048;e=(g&65535)>(j&65535)?g-j&65535:0;j=aN&2016;g=a2&2016;if((j&65535)>(g&65535)){a3=(j-g&65535)+e&65535}else{a3=e}e=aN&31;aN=a2&31;if((e&65535)>(aN&65535)){a4=(e-aN&65535)+a3&65535}else{a4=a3}aN=aR+5|0;b[(c[277218]|0)+(aN<<1)>>1]=a4;b[(c[277218]|0)+(o<<1)>>1]=a4;e=a[1108909]|0;a[(c[277219]|0)+aN|0]=e;a[(c[277219]|0)+o|0]=e;a0=a[1108908]|0;a1=c[277219]|0}else{a0=aX;a1=aY}}while(0);o=aR+6|0;do{if((a0&255)>(d[a1+o|0]|0)){e=a[aP+4|0]|0;if(e<<24>>24==0){a5=a0;a6=a1;break}aN=b[(c[277225]|0)+((e&255)<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){a7=c[277228]&65535}else{a7=b[(c[277213]|0)+(o<<1)>>1]|0}e=aN&-2048;g=a7&-2048;j=(e&65535)>(g&65535)?e-g&65535:0;g=aN&2016;e=a7&2016;if((g&65535)>(e&65535)){a8=(g-e&65535)+j&65535}else{a8=j}j=aN&31;aN=a7&31;if((j&65535)>(aN&65535)){a9=(j-aN&65535)+a8&65535}else{a9=a8}aN=aR+7|0;b[(c[277218]|0)+(aN<<1)>>1]=a9;b[(c[277218]|0)+(o<<1)>>1]=a9;j=a[1108909]|0;a[(c[277219]|0)+aN|0]=j;a[(c[277219]|0)+o|0]=j;a5=a[1108908]|0;a6=c[277219]|0}else{a5=a0;a6=a1}}while(0);o=aR+8|0;do{if((a5&255)>(d[a6+o|0]|0)){j=a[aP+3|0]|0;if(j<<24>>24==0){ba=a5;bb=a6;break}aN=b[(c[277225]|0)+((j&255)<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){bc=c[277228]&65535}else{bc=b[(c[277213]|0)+(o<<1)>>1]|0}j=aN&-2048;e=bc&-2048;g=(j&65535)>(e&65535)?j-e&65535:0;e=aN&2016;j=bc&2016;if((e&65535)>(j&65535)){bd=(e-j&65535)+g&65535}else{bd=g}g=aN&31;aN=bc&31;if((g&65535)>(aN&65535)){be=(g-aN&65535)+bd&65535}else{be=bd}aN=aR+9|0;b[(c[277218]|0)+(aN<<1)>>1]=be;b[(c[277218]|0)+(o<<1)>>1]=be;g=a[1108909]|0;a[(c[277219]|0)+aN|0]=g;a[(c[277219]|0)+o|0]=g;ba=a[1108908]|0;bb=c[277219]|0}else{ba=a5;bb=a6}}while(0);o=aR+10|0;do{if((ba&255)>(d[bb+o|0]|0)){g=a[aP+2|0]|0;if(g<<24>>24==0){bf=ba;bg=bb;break}aN=b[(c[277225]|0)+((g&255)<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){bh=c[277228]&65535}else{bh=b[(c[277213]|0)+(o<<1)>>1]|0}g=aN&-2048;j=bh&-2048;e=(g&65535)>(j&65535)?g-j&65535:0;j=aN&2016;g=bh&2016;if((j&65535)>(g&65535)){bi=(j-g&65535)+e&65535}else{bi=e}e=aN&31;aN=bh&31;if((e&65535)>(aN&65535)){bj=(e-aN&65535)+bi&65535}else{bj=bi}aN=aR+11|0;b[(c[277218]|0)+(aN<<1)>>1]=bj;b[(c[277218]|0)+(o<<1)>>1]=bj;e=a[1108909]|0;a[(c[277219]|0)+aN|0]=e;a[(c[277219]|0)+o|0]=e;bf=a[1108908]|0;bg=c[277219]|0}else{bf=ba;bg=bb}}while(0);o=aR+12|0;do{if((bf&255)>(d[bg+o|0]|0)){e=a[aP+1|0]|0;if(e<<24>>24==0){bk=bf;bl=bg;break}aN=b[(c[277225]|0)+((e&255)<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){bm=c[277228]&65535}else{bm=b[(c[277213]|0)+(o<<1)>>1]|0}e=aN&-2048;g=bm&-2048;j=(e&65535)>(g&65535)?e-g&65535:0;g=aN&2016;e=bm&2016;if((g&65535)>(e&65535)){bn=(g-e&65535)+j&65535}else{bn=j}j=aN&31;aN=bm&31;if((j&65535)>(aN&65535)){bo=(j-aN&65535)+bn&65535}else{bo=bn}aN=aR+13|0;b[(c[277218]|0)+(aN<<1)>>1]=bo;b[(c[277218]|0)+(o<<1)>>1]=bo;j=a[1108909]|0;a[(c[277219]|0)+aN|0]=j;a[(c[277219]|0)+o|0]=j;bk=a[1108908]|0;bl=c[277219]|0}else{bk=bf;bl=bg}}while(0);o=aR+14|0;do{if((bk&255)>(d[bl+o|0]|0)){j=a[aP]|0;if(j<<24>>24==0){break}aN=b[(c[277225]|0)+((j&255)<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){bp=c[277228]&65535}else{bp=b[(c[277213]|0)+(o<<1)>>1]|0}j=aN&-2048;e=bp&-2048;g=(j&65535)>(e&65535)?j-e&65535:0;e=aN&2016;j=bp&2016;if((e&65535)>(j&65535)){bq=(e-j&65535)+g&65535}else{bq=g}g=aN&31;aN=bp&31;if((g&65535)>(aN&65535)){br=(g-aN&65535)+bq&65535}else{br=bq}aN=aR+15|0;b[(c[277218]|0)+(aN<<1)>>1]=br;b[(c[277218]|0)+(o<<1)>>1]=br;g=a[1108909]|0;a[(c[277219]|0)+aN|0]=g;a[(c[277219]|0)+o|0]=g}}while(0);o=aQ-1|0;if((o|0)<=0){break}aP=aP-16|0;aQ=o;aR=(c[277223]|0)+aR|0}return}else{if(l){bs=i;bt=h;bu=f}else{return}while(1){f=a[1108908]|0;h=c[277219]|0;do{if((f&255)>(d[h+bu|0]|0)){i=a[bs]|0;if(i<<24>>24==0){bv=f;bw=h;break}l=b[(c[277225]|0)+((i&255)<<1)>>1]|0;if((a[(c[277215]|0)+bu|0]&32)==0){bx=c[277228]&65535}else{bx=b[(c[277213]|0)+(bu<<1)>>1]|0}i=l&-2048;aR=bx&-2048;aQ=(i&65535)>(aR&65535)?i-aR&65535:0;aR=l&2016;i=bx&2016;if((aR&65535)>(i&65535)){by=(aR-i&65535)+aQ&65535}else{by=aQ}aQ=l&31;l=bx&31;if((aQ&65535)>(l&65535)){bz=(aQ-l&65535)+by&65535}else{bz=by}l=bu+1|0;b[(c[277218]|0)+(l<<1)>>1]=bz;b[(c[277218]|0)+(bu<<1)>>1]=bz;aQ=a[1108909]|0;a[(c[277219]|0)+l|0]=aQ;a[(c[277219]|0)+bu|0]=aQ;bv=a[1108908]|0;bw=c[277219]|0}else{bv=f;bw=h}}while(0);h=bu+2|0;do{if((bv&255)>(d[bw+h|0]|0)){f=a[bs+1|0]|0;if(f<<24>>24==0){bA=bv;bB=bw;break}aQ=b[(c[277225]|0)+((f&255)<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)==0){bC=c[277228]&65535}else{bC=b[(c[277213]|0)+(h<<1)>>1]|0}f=aQ&-2048;l=bC&-2048;i=(f&65535)>(l&65535)?f-l&65535:0;l=aQ&2016;f=bC&2016;if((l&65535)>(f&65535)){bD=(l-f&65535)+i&65535}else{bD=i}i=aQ&31;aQ=bC&31;if((i&65535)>(aQ&65535)){bE=(i-aQ&65535)+bD&65535}else{bE=bD}aQ=bu+3|0;b[(c[277218]|0)+(aQ<<1)>>1]=bE;b[(c[277218]|0)+(h<<1)>>1]=bE;i=a[1108909]|0;a[(c[277219]|0)+aQ|0]=i;a[(c[277219]|0)+h|0]=i;bA=a[1108908]|0;bB=c[277219]|0}else{bA=bv;bB=bw}}while(0);h=bu+4|0;do{if((bA&255)>(d[bB+h|0]|0)){i=a[bs+2|0]|0;if(i<<24>>24==0){bF=bA;bG=bB;break}aQ=b[(c[277225]|0)+((i&255)<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)==0){bH=c[277228]&65535}else{bH=b[(c[277213]|0)+(h<<1)>>1]|0}i=aQ&-2048;f=bH&-2048;l=(i&65535)>(f&65535)?i-f&65535:0;f=aQ&2016;i=bH&2016;if((f&65535)>(i&65535)){bI=(f-i&65535)+l&65535}else{bI=l}l=aQ&31;aQ=bH&31;if((l&65535)>(aQ&65535)){bJ=(l-aQ&65535)+bI&65535}else{bJ=bI}aQ=bu+5|0;b[(c[277218]|0)+(aQ<<1)>>1]=bJ;b[(c[277218]|0)+(h<<1)>>1]=bJ;l=a[1108909]|0;a[(c[277219]|0)+aQ|0]=l;a[(c[277219]|0)+h|0]=l;bF=a[1108908]|0;bG=c[277219]|0}else{bF=bA;bG=bB}}while(0);h=bu+6|0;do{if((bF&255)>(d[bG+h|0]|0)){l=a[bs+3|0]|0;if(l<<24>>24==0){bK=bF;bL=bG;break}aQ=b[(c[277225]|0)+((l&255)<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)==0){bM=c[277228]&65535}else{bM=b[(c[277213]|0)+(h<<1)>>1]|0}l=aQ&-2048;i=bM&-2048;f=(l&65535)>(i&65535)?l-i&65535:0;i=aQ&2016;l=bM&2016;if((i&65535)>(l&65535)){bN=(i-l&65535)+f&65535}else{bN=f}f=aQ&31;aQ=bM&31;if((f&65535)>(aQ&65535)){bO=(f-aQ&65535)+bN&65535}else{bO=bN}aQ=bu+7|0;b[(c[277218]|0)+(aQ<<1)>>1]=bO;b[(c[277218]|0)+(h<<1)>>1]=bO;f=a[1108909]|0;a[(c[277219]|0)+aQ|0]=f;a[(c[277219]|0)+h|0]=f;bK=a[1108908]|0;bL=c[277219]|0}else{bK=bF;bL=bG}}while(0);h=bu+8|0;do{if((bK&255)>(d[bL+h|0]|0)){f=a[bs+4|0]|0;if(f<<24>>24==0){bP=bK;bQ=bL;break}aQ=b[(c[277225]|0)+((f&255)<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)==0){bR=c[277228]&65535}else{bR=b[(c[277213]|0)+(h<<1)>>1]|0}f=aQ&-2048;l=bR&-2048;i=(f&65535)>(l&65535)?f-l&65535:0;l=aQ&2016;f=bR&2016;if((l&65535)>(f&65535)){bS=(l-f&65535)+i&65535}else{bS=i}i=aQ&31;aQ=bR&31;if((i&65535)>(aQ&65535)){bT=(i-aQ&65535)+bS&65535}else{bT=bS}aQ=bu+9|0;b[(c[277218]|0)+(aQ<<1)>>1]=bT;b[(c[277218]|0)+(h<<1)>>1]=bT;i=a[1108909]|0;a[(c[277219]|0)+aQ|0]=i;a[(c[277219]|0)+h|0]=i;bP=a[1108908]|0;bQ=c[277219]|0}else{bP=bK;bQ=bL}}while(0);h=bu+10|0;do{if((bP&255)>(d[bQ+h|0]|0)){i=a[bs+5|0]|0;if(i<<24>>24==0){bU=bP;bV=bQ;break}aQ=b[(c[277225]|0)+((i&255)<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)==0){bW=c[277228]&65535}else{bW=b[(c[277213]|0)+(h<<1)>>1]|0}i=aQ&-2048;f=bW&-2048;l=(i&65535)>(f&65535)?i-f&65535:0;f=aQ&2016;i=bW&2016;if((f&65535)>(i&65535)){bX=(f-i&65535)+l&65535}else{bX=l}l=aQ&31;aQ=bW&31;if((l&65535)>(aQ&65535)){bY=(l-aQ&65535)+bX&65535}else{bY=bX}aQ=bu+11|0;b[(c[277218]|0)+(aQ<<1)>>1]=bY;b[(c[277218]|0)+(h<<1)>>1]=bY;l=a[1108909]|0;a[(c[277219]|0)+aQ|0]=l;a[(c[277219]|0)+h|0]=l;bU=a[1108908]|0;bV=c[277219]|0}else{bU=bP;bV=bQ}}while(0);h=bu+12|0;do{if((bU&255)>(d[bV+h|0]|0)){l=a[bs+6|0]|0;if(l<<24>>24==0){bZ=bU;b_=bV;break}aQ=b[(c[277225]|0)+((l&255)<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)==0){b$=c[277228]&65535}else{b$=b[(c[277213]|0)+(h<<1)>>1]|0}l=aQ&-2048;i=b$&-2048;f=(l&65535)>(i&65535)?l-i&65535:0;i=aQ&2016;l=b$&2016;if((i&65535)>(l&65535)){b0=(i-l&65535)+f&65535}else{b0=f}f=aQ&31;aQ=b$&31;if((f&65535)>(aQ&65535)){b1=(f-aQ&65535)+b0&65535}else{b1=b0}aQ=bu+13|0;b[(c[277218]|0)+(aQ<<1)>>1]=b1;b[(c[277218]|0)+(h<<1)>>1]=b1;f=a[1108909]|0;a[(c[277219]|0)+aQ|0]=f;a[(c[277219]|0)+h|0]=f;bZ=a[1108908]|0;b_=c[277219]|0}else{bZ=bU;b_=bV}}while(0);h=bu+14|0;do{if((bZ&255)>(d[b_+h|0]|0)){f=a[bs+7|0]|0;if(f<<24>>24==0){break}aQ=b[(c[277225]|0)+((f&255)<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)==0){b2=c[277228]&65535}else{b2=b[(c[277213]|0)+(h<<1)>>1]|0}f=aQ&-2048;l=b2&-2048;i=(f&65535)>(l&65535)?f-l&65535:0;l=aQ&2016;f=b2&2016;if((l&65535)>(f&65535)){b3=(l-f&65535)+i&65535}else{b3=i}i=aQ&31;aQ=b2&31;if((i&65535)>(aQ&65535)){b4=(i-aQ&65535)+b3&65535}else{b4=b3}aQ=bu+15|0;b[(c[277218]|0)+(aQ<<1)>>1]=b4;b[(c[277218]|0)+(h<<1)>>1]=b4;i=a[1108909]|0;a[(c[277219]|0)+aQ|0]=i;a[(c[277219]|0)+h|0]=i}}while(0);h=bt-1|0;if((h|0)<=0){break}bs=bs-16|0;bt=h;bu=(c[277223]|0)+bu|0}return}}function Vr(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0;i=e&1023;j=c[348606]|0;k=(i<<j)+(c[348604]|0)|0;if((e&256|0)==0){l=k}else{l=(c[348602]|0)+k|0}k=l&65535;l=k>>>(j>>>0);j=(e&16384|0)!=0;m=l<<6;do{if(j){n=(c[348622]|0)+m|0;if((a[(c[348618]|0)+l|0]|0)!=0){o=n;break}p=fi[c[348636]&63](n,k,i)|0;a[(c[348618]|0)+l|0]=p;o=n}else{n=(c[348624]|0)+m|0;if((a[(c[348620]|0)+l|0]|0)!=0){o=n;break}p=fi[c[348638]&63](n,k,i)|0;a[(c[348620]|0)+l|0]=p;o=n}}while(0);if((a[(c[348620]|0)+l|0]|0)==2){return}if((a[1394464]|0)==0){q=1106168+((e>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){l=d[1044485]|0;c[276541]=7080+(l<<5);i=0;do{k=i<<1&2;m=i&2;n=i&4;p=0;do{b[1125528+(i<<9)+(p<<1)>>1]=d[(p>>>1&28|m)+(7080+(l<<5))|0]<<6|d[(p<<2&28|k)+(7080+(l<<5))|0]<<11|d[(p>>>3&24|n)+(7080+(l<<5))|0];p=p+1|0;}while(p>>>0<256);i=i+1|0;}while(i>>>0<8);a[1106089]=0}q=1125528+((e>>>10&7)<<9)|0}c[277226]=q;c[277225]=(a[1108928]|0)!=0?1393712:q;if((e&49152|0)==0){if((h|0)<=0){return}q=o+((d[1394504]|0)+(g<<1))|0;i=h;l=f;while(1){p=a[1108908]|0;n=c[277219]|0;do{if((p&255)>(d[n+l|0]|0)){k=a[q]|0;if(k<<24>>24==0){r=p;s=n;break}m=b[(c[277225]|0)+((k&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){t=b[(c[277221]|0)+(((m&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{k=c[277228]&65535;u=m&-2048;v=k&-2048;w=(u&65535)>(v&65535)?u-v&65535:0;v=m&2016;u=k&2016;if((v&65535)>(u&65535)){x=(v-u&65535)+w&65535}else{x=w}w=m&31;u=k&31;if((w&65535)<=(u&65535)){t=x;break}t=(w-u&65535)+x&65535}}while(0);m=l+1|0;b[(c[277218]|0)+(m<<1)>>1]=t;b[(c[277218]|0)+(l<<1)>>1]=t;u=a[1108909]|0;a[(c[277219]|0)+m|0]=u;a[(c[277219]|0)+l|0]=u;r=a[1108908]|0;s=c[277219]|0}else{r=p;s=n}}while(0);n=l+2|0;do{if((r&255)>(d[s+n|0]|0)){p=a[q+1|0]|0;if(p<<24>>24==0){y=r;z=s;break}u=b[(c[277225]|0)+((p&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){A=b[(c[277221]|0)+(((u&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{p=c[277228]&65535;m=u&-2048;w=p&-2048;k=(m&65535)>(w&65535)?m-w&65535:0;w=u&2016;m=p&2016;if((w&65535)>(m&65535)){B=(w-m&65535)+k&65535}else{B=k}k=u&31;m=p&31;if((k&65535)<=(m&65535)){A=B;break}A=(k-m&65535)+B&65535}}while(0);u=l+3|0;b[(c[277218]|0)+(u<<1)>>1]=A;b[(c[277218]|0)+(n<<1)>>1]=A;m=a[1108909]|0;a[(c[277219]|0)+u|0]=m;a[(c[277219]|0)+n|0]=m;y=a[1108908]|0;z=c[277219]|0}else{y=r;z=s}}while(0);n=l+4|0;do{if((y&255)>(d[z+n|0]|0)){m=a[q+2|0]|0;if(m<<24>>24==0){C=y;D=z;break}u=b[(c[277225]|0)+((m&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){E=b[(c[277221]|0)+(((u&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{m=c[277228]&65535;k=u&-2048;p=m&-2048;w=(k&65535)>(p&65535)?k-p&65535:0;p=u&2016;k=m&2016;if((p&65535)>(k&65535)){F=(p-k&65535)+w&65535}else{F=w}w=u&31;k=m&31;if((w&65535)<=(k&65535)){E=F;break}E=(w-k&65535)+F&65535}}while(0);u=l+5|0;b[(c[277218]|0)+(u<<1)>>1]=E;b[(c[277218]|0)+(n<<1)>>1]=E;k=a[1108909]|0;a[(c[277219]|0)+u|0]=k;a[(c[277219]|0)+n|0]=k;C=a[1108908]|0;D=c[277219]|0}else{C=y;D=z}}while(0);n=l+6|0;do{if((C&255)>(d[D+n|0]|0)){k=a[q+3|0]|0;if(k<<24>>24==0){G=C;H=D;break}u=b[(c[277225]|0)+((k&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){I=b[(c[277221]|0)+(((u&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{k=c[277228]&65535;w=u&-2048;m=k&-2048;p=(w&65535)>(m&65535)?w-m&65535:0;m=u&2016;w=k&2016;if((m&65535)>(w&65535)){J=(m-w&65535)+p&65535}else{J=p}p=u&31;w=k&31;if((p&65535)<=(w&65535)){I=J;break}I=(p-w&65535)+J&65535}}while(0);u=l+7|0;b[(c[277218]|0)+(u<<1)>>1]=I;b[(c[277218]|0)+(n<<1)>>1]=I;w=a[1108909]|0;a[(c[277219]|0)+u|0]=w;a[(c[277219]|0)+n|0]=w;G=a[1108908]|0;H=c[277219]|0}else{G=C;H=D}}while(0);n=l+8|0;do{if((G&255)>(d[H+n|0]|0)){w=a[q+4|0]|0;if(w<<24>>24==0){K=G;L=H;break}u=b[(c[277225]|0)+((w&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){M=b[(c[277221]|0)+(((u&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{w=c[277228]&65535;p=u&-2048;k=w&-2048;m=(p&65535)>(k&65535)?p-k&65535:0;k=u&2016;p=w&2016;if((k&65535)>(p&65535)){N=(k-p&65535)+m&65535}else{N=m}m=u&31;p=w&31;if((m&65535)<=(p&65535)){M=N;break}M=(m-p&65535)+N&65535}}while(0);u=l+9|0;b[(c[277218]|0)+(u<<1)>>1]=M;b[(c[277218]|0)+(n<<1)>>1]=M;p=a[1108909]|0;a[(c[277219]|0)+u|0]=p;a[(c[277219]|0)+n|0]=p;K=a[1108908]|0;L=c[277219]|0}else{K=G;L=H}}while(0);n=l+10|0;do{if((K&255)>(d[L+n|0]|0)){p=a[q+5|0]|0;if(p<<24>>24==0){O=K;P=L;break}u=b[(c[277225]|0)+((p&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){Q=b[(c[277221]|0)+(((u&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{p=c[277228]&65535;m=u&-2048;w=p&-2048;k=(m&65535)>(w&65535)?m-w&65535:0;w=u&2016;m=p&2016;if((w&65535)>(m&65535)){R=(w-m&65535)+k&65535}else{R=k}k=u&31;m=p&31;if((k&65535)<=(m&65535)){Q=R;break}Q=(k-m&65535)+R&65535}}while(0);u=l+11|0;b[(c[277218]|0)+(u<<1)>>1]=Q;b[(c[277218]|0)+(n<<1)>>1]=Q;m=a[1108909]|0;a[(c[277219]|0)+u|0]=m;a[(c[277219]|0)+n|0]=m;O=a[1108908]|0;P=c[277219]|0}else{O=K;P=L}}while(0);n=l+12|0;do{if((O&255)>(d[P+n|0]|0)){m=a[q+6|0]|0;if(m<<24>>24==0){S=O;T=P;break}u=b[(c[277225]|0)+((m&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){U=b[(c[277221]|0)+(((u&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{m=c[277228]&65535;k=u&-2048;p=m&-2048;w=(k&65535)>(p&65535)?k-p&65535:0;p=u&2016;k=m&2016;if((p&65535)>(k&65535)){V=(p-k&65535)+w&65535}else{V=w}w=u&31;k=m&31;if((w&65535)<=(k&65535)){U=V;break}U=(w-k&65535)+V&65535}}while(0);u=l+13|0;b[(c[277218]|0)+(u<<1)>>1]=U;b[(c[277218]|0)+(n<<1)>>1]=U;k=a[1108909]|0;a[(c[277219]|0)+u|0]=k;a[(c[277219]|0)+n|0]=k;S=a[1108908]|0;T=c[277219]|0}else{S=O;T=P}}while(0);n=l+14|0;do{if((S&255)>(d[T+n|0]|0)){k=a[q+7|0]|0;if(k<<24>>24==0){break}u=b[(c[277225]|0)+((k&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){W=b[(c[277221]|0)+(((u&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{k=c[277228]&65535;w=u&-2048;m=k&-2048;p=(w&65535)>(m&65535)?w-m&65535:0;m=u&2016;w=k&2016;if((m&65535)>(w&65535)){X=(m-w&65535)+p&65535}else{X=p}p=u&31;w=k&31;if((p&65535)<=(w&65535)){W=X;break}W=(p-w&65535)+X&65535}}while(0);u=l+15|0;b[(c[277218]|0)+(u<<1)>>1]=W;b[(c[277218]|0)+(n<<1)>>1]=W;w=a[1108909]|0;a[(c[277219]|0)+u|0]=w;a[(c[277219]|0)+n|0]=w}}while(0);n=i-1|0;if((n|0)<=0){break}q=q+16|0;i=n;l=(c[277223]|0)+l|0}return}l=(d[1394504]|0)+(g<<1)|0;if((e&32768|0)==0){if((h|0)<=0){return}e=o+l|0;g=h;i=f;while(1){q=a[1108908]|0;W=c[277219]|0;do{if((q&255)>(d[W+i|0]|0)){X=a[e+7|0]|0;if(X<<24>>24==0){Y=q;Z=W;break}T=b[(c[277225]|0)+((X&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){_=b[(c[277221]|0)+(((T&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{X=c[277228]&65535;S=T&-2048;P=X&-2048;O=(S&65535)>(P&65535)?S-P&65535:0;P=T&2016;S=X&2016;if((P&65535)>(S&65535)){$=(P-S&65535)+O&65535}else{$=O}O=T&31;S=X&31;if((O&65535)<=(S&65535)){_=$;break}_=(O-S&65535)+$&65535}}while(0);T=i+1|0;b[(c[277218]|0)+(T<<1)>>1]=_;b[(c[277218]|0)+(i<<1)>>1]=_;S=a[1108909]|0;a[(c[277219]|0)+T|0]=S;a[(c[277219]|0)+i|0]=S;Y=a[1108908]|0;Z=c[277219]|0}else{Y=q;Z=W}}while(0);W=i+2|0;do{if((Y&255)>(d[Z+W|0]|0)){q=a[e+6|0]|0;if(q<<24>>24==0){aa=Y;ab=Z;break}S=b[(c[277225]|0)+((q&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){ac=b[(c[277221]|0)+(((S&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{q=c[277228]&65535;T=S&-2048;O=q&-2048;X=(T&65535)>(O&65535)?T-O&65535:0;O=S&2016;T=q&2016;if((O&65535)>(T&65535)){ad=(O-T&65535)+X&65535}else{ad=X}X=S&31;T=q&31;if((X&65535)<=(T&65535)){ac=ad;break}ac=(X-T&65535)+ad&65535}}while(0);S=i+3|0;b[(c[277218]|0)+(S<<1)>>1]=ac;b[(c[277218]|0)+(W<<1)>>1]=ac;T=a[1108909]|0;a[(c[277219]|0)+S|0]=T;a[(c[277219]|0)+W|0]=T;aa=a[1108908]|0;ab=c[277219]|0}else{aa=Y;ab=Z}}while(0);W=i+4|0;do{if((aa&255)>(d[ab+W|0]|0)){T=a[e+5|0]|0;if(T<<24>>24==0){ae=aa;af=ab;break}S=b[(c[277225]|0)+((T&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){ag=b[(c[277221]|0)+(((S&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{T=c[277228]&65535;X=S&-2048;q=T&-2048;O=(X&65535)>(q&65535)?X-q&65535:0;q=S&2016;X=T&2016;if((q&65535)>(X&65535)){ah=(q-X&65535)+O&65535}else{ah=O}O=S&31;X=T&31;if((O&65535)<=(X&65535)){ag=ah;break}ag=(O-X&65535)+ah&65535}}while(0);S=i+5|0;b[(c[277218]|0)+(S<<1)>>1]=ag;b[(c[277218]|0)+(W<<1)>>1]=ag;X=a[1108909]|0;a[(c[277219]|0)+S|0]=X;a[(c[277219]|0)+W|0]=X;ae=a[1108908]|0;af=c[277219]|0}else{ae=aa;af=ab}}while(0);W=i+6|0;do{if((ae&255)>(d[af+W|0]|0)){X=a[e+4|0]|0;if(X<<24>>24==0){ai=ae;aj=af;break}S=b[(c[277225]|0)+((X&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){ak=b[(c[277221]|0)+(((S&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{X=c[277228]&65535;O=S&-2048;T=X&-2048;q=(O&65535)>(T&65535)?O-T&65535:0;T=S&2016;O=X&2016;if((T&65535)>(O&65535)){al=(T-O&65535)+q&65535}else{al=q}q=S&31;O=X&31;if((q&65535)<=(O&65535)){ak=al;break}ak=(q-O&65535)+al&65535}}while(0);S=i+7|0;b[(c[277218]|0)+(S<<1)>>1]=ak;b[(c[277218]|0)+(W<<1)>>1]=ak;O=a[1108909]|0;a[(c[277219]|0)+S|0]=O;a[(c[277219]|0)+W|0]=O;ai=a[1108908]|0;aj=c[277219]|0}else{ai=ae;aj=af}}while(0);W=i+8|0;do{if((ai&255)>(d[aj+W|0]|0)){O=a[e+3|0]|0;if(O<<24>>24==0){am=ai;an=aj;break}S=b[(c[277225]|0)+((O&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){ao=b[(c[277221]|0)+(((S&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{O=c[277228]&65535;q=S&-2048;X=O&-2048;T=(q&65535)>(X&65535)?q-X&65535:0;X=S&2016;q=O&2016;if((X&65535)>(q&65535)){ap=(X-q&65535)+T&65535}else{ap=T}T=S&31;q=O&31;if((T&65535)<=(q&65535)){ao=ap;break}ao=(T-q&65535)+ap&65535}}while(0);S=i+9|0;b[(c[277218]|0)+(S<<1)>>1]=ao;b[(c[277218]|0)+(W<<1)>>1]=ao;q=a[1108909]|0;a[(c[277219]|0)+S|0]=q;a[(c[277219]|0)+W|0]=q;am=a[1108908]|0;an=c[277219]|0}else{am=ai;an=aj}}while(0);W=i+10|0;do{if((am&255)>(d[an+W|0]|0)){q=a[e+2|0]|0;if(q<<24>>24==0){aq=am;ar=an;break}S=b[(c[277225]|0)+((q&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){as=b[(c[277221]|0)+(((S&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{q=c[277228]&65535;T=S&-2048;O=q&-2048;X=(T&65535)>(O&65535)?T-O&65535:0;O=S&2016;T=q&2016;if((O&65535)>(T&65535)){at=(O-T&65535)+X&65535}else{at=X}X=S&31;T=q&31;if((X&65535)<=(T&65535)){as=at;break}as=(X-T&65535)+at&65535}}while(0);S=i+11|0;b[(c[277218]|0)+(S<<1)>>1]=as;b[(c[277218]|0)+(W<<1)>>1]=as;T=a[1108909]|0;a[(c[277219]|0)+S|0]=T;a[(c[277219]|0)+W|0]=T;aq=a[1108908]|0;ar=c[277219]|0}else{aq=am;ar=an}}while(0);W=i+12|0;do{if((aq&255)>(d[ar+W|0]|0)){T=a[e+1|0]|0;if(T<<24>>24==0){au=aq;av=ar;break}S=b[(c[277225]|0)+((T&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aw=b[(c[277221]|0)+(((S&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{T=c[277228]&65535;X=S&-2048;q=T&-2048;O=(X&65535)>(q&65535)?X-q&65535:0;q=S&2016;X=T&2016;if((q&65535)>(X&65535)){ax=(q-X&65535)+O&65535}else{ax=O}O=S&31;X=T&31;if((O&65535)<=(X&65535)){aw=ax;break}aw=(O-X&65535)+ax&65535}}while(0);S=i+13|0;b[(c[277218]|0)+(S<<1)>>1]=aw;b[(c[277218]|0)+(W<<1)>>1]=aw;X=a[1108909]|0;a[(c[277219]|0)+S|0]=X;a[(c[277219]|0)+W|0]=X;au=a[1108908]|0;av=c[277219]|0}else{au=aq;av=ar}}while(0);W=i+14|0;do{if((au&255)>(d[av+W|0]|0)){X=a[e]|0;if(X<<24>>24==0){break}S=b[(c[277225]|0)+((X&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){ay=b[(c[277221]|0)+(((S&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{X=c[277228]&65535;O=S&-2048;T=X&-2048;q=(O&65535)>(T&65535)?O-T&65535:0;T=S&2016;O=X&2016;if((T&65535)>(O&65535)){az=(T-O&65535)+q&65535}else{az=q}q=S&31;O=X&31;if((q&65535)<=(O&65535)){ay=az;break}ay=(q-O&65535)+az&65535}}while(0);S=i+15|0;b[(c[277218]|0)+(S<<1)>>1]=ay;b[(c[277218]|0)+(W<<1)>>1]=ay;O=a[1108909]|0;a[(c[277219]|0)+S|0]=O;a[(c[277219]|0)+W|0]=O}}while(0);W=g-1|0;if((W|0)<=0){break}e=e+16|0;g=W;i=(c[277223]|0)+i|0}return}i=o+(56-l)|0;l=(h|0)>0;if(j){if(l){aA=i;aB=h;aC=f}else{return}while(1){j=a[1108908]|0;o=c[277219]|0;do{if((j&255)>(d[o+aC|0]|0)){g=a[aA+7|0]|0;if(g<<24>>24==0){aD=j;aE=o;break}e=b[(c[277225]|0)+((g&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aF=b[(c[277221]|0)+(((e&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{g=c[277228]&65535;ay=e&-2048;az=g&-2048;av=(ay&65535)>(az&65535)?ay-az&65535:0;az=e&2016;ay=g&2016;if((az&65535)>(ay&65535)){aG=(az-ay&65535)+av&65535}else{aG=av}av=e&31;ay=g&31;if((av&65535)<=(ay&65535)){aF=aG;break}aF=(av-ay&65535)+aG&65535}}while(0);e=aC+1|0;b[(c[277218]|0)+(e<<1)>>1]=aF;b[(c[277218]|0)+(aC<<1)>>1]=aF;ay=a[1108909]|0;a[(c[277219]|0)+e|0]=ay;a[(c[277219]|0)+aC|0]=ay;aD=a[1108908]|0;aE=c[277219]|0}else{aD=j;aE=o}}while(0);o=aC+2|0;do{if((aD&255)>(d[aE+o|0]|0)){j=a[aA+6|0]|0;if(j<<24>>24==0){aH=aD;aI=aE;break}ay=b[(c[277225]|0)+((j&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aJ=b[(c[277221]|0)+(((ay&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{j=c[277228]&65535;e=ay&-2048;av=j&-2048;g=(e&65535)>(av&65535)?e-av&65535:0;av=ay&2016;e=j&2016;if((av&65535)>(e&65535)){aK=(av-e&65535)+g&65535}else{aK=g}g=ay&31;e=j&31;if((g&65535)<=(e&65535)){aJ=aK;break}aJ=(g-e&65535)+aK&65535}}while(0);ay=aC+3|0;b[(c[277218]|0)+(ay<<1)>>1]=aJ;b[(c[277218]|0)+(o<<1)>>1]=aJ;e=a[1108909]|0;a[(c[277219]|0)+ay|0]=e;a[(c[277219]|0)+o|0]=e;aH=a[1108908]|0;aI=c[277219]|0}else{aH=aD;aI=aE}}while(0);o=aC+4|0;do{if((aH&255)>(d[aI+o|0]|0)){e=a[aA+5|0]|0;if(e<<24>>24==0){aL=aH;aM=aI;break}ay=b[(c[277225]|0)+((e&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aN=b[(c[277221]|0)+(((ay&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{e=c[277228]&65535;g=ay&-2048;j=e&-2048;av=(g&65535)>(j&65535)?g-j&65535:0;j=ay&2016;g=e&2016;if((j&65535)>(g&65535)){aO=(j-g&65535)+av&65535}else{aO=av}av=ay&31;g=e&31;if((av&65535)<=(g&65535)){aN=aO;break}aN=(av-g&65535)+aO&65535}}while(0);ay=aC+5|0;b[(c[277218]|0)+(ay<<1)>>1]=aN;b[(c[277218]|0)+(o<<1)>>1]=aN;g=a[1108909]|0;a[(c[277219]|0)+ay|0]=g;a[(c[277219]|0)+o|0]=g;aL=a[1108908]|0;aM=c[277219]|0}else{aL=aH;aM=aI}}while(0);o=aC+6|0;do{if((aL&255)>(d[aM+o|0]|0)){g=a[aA+4|0]|0;if(g<<24>>24==0){aP=aL;aQ=aM;break}ay=b[(c[277225]|0)+((g&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aR=b[(c[277221]|0)+(((ay&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{g=c[277228]&65535;av=ay&-2048;e=g&-2048;j=(av&65535)>(e&65535)?av-e&65535:0;e=ay&2016;av=g&2016;if((e&65535)>(av&65535)){aS=(e-av&65535)+j&65535}else{aS=j}j=ay&31;av=g&31;if((j&65535)<=(av&65535)){aR=aS;break}aR=(j-av&65535)+aS&65535}}while(0);ay=aC+7|0;b[(c[277218]|0)+(ay<<1)>>1]=aR;b[(c[277218]|0)+(o<<1)>>1]=aR;av=a[1108909]|0;a[(c[277219]|0)+ay|0]=av;a[(c[277219]|0)+o|0]=av;aP=a[1108908]|0;aQ=c[277219]|0}else{aP=aL;aQ=aM}}while(0);o=aC+8|0;do{if((aP&255)>(d[aQ+o|0]|0)){av=a[aA+3|0]|0;if(av<<24>>24==0){aT=aP;aU=aQ;break}ay=b[(c[277225]|0)+((av&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aV=b[(c[277221]|0)+(((ay&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{av=c[277228]&65535;j=ay&-2048;g=av&-2048;e=(j&65535)>(g&65535)?j-g&65535:0;g=ay&2016;j=av&2016;if((g&65535)>(j&65535)){aW=(g-j&65535)+e&65535}else{aW=e}e=ay&31;j=av&31;if((e&65535)<=(j&65535)){aV=aW;break}aV=(e-j&65535)+aW&65535}}while(0);ay=aC+9|0;b[(c[277218]|0)+(ay<<1)>>1]=aV;b[(c[277218]|0)+(o<<1)>>1]=aV;j=a[1108909]|0;a[(c[277219]|0)+ay|0]=j;a[(c[277219]|0)+o|0]=j;aT=a[1108908]|0;aU=c[277219]|0}else{aT=aP;aU=aQ}}while(0);o=aC+10|0;do{if((aT&255)>(d[aU+o|0]|0)){j=a[aA+2|0]|0;if(j<<24>>24==0){aX=aT;aY=aU;break}ay=b[(c[277225]|0)+((j&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aZ=b[(c[277221]|0)+(((ay&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{j=c[277228]&65535;e=ay&-2048;av=j&-2048;g=(e&65535)>(av&65535)?e-av&65535:0;av=ay&2016;e=j&2016;if((av&65535)>(e&65535)){a_=(av-e&65535)+g&65535}else{a_=g}g=ay&31;e=j&31;if((g&65535)<=(e&65535)){aZ=a_;break}aZ=(g-e&65535)+a_&65535}}while(0);ay=aC+11|0;b[(c[277218]|0)+(ay<<1)>>1]=aZ;b[(c[277218]|0)+(o<<1)>>1]=aZ;e=a[1108909]|0;a[(c[277219]|0)+ay|0]=e;a[(c[277219]|0)+o|0]=e;aX=a[1108908]|0;aY=c[277219]|0}else{aX=aT;aY=aU}}while(0);o=aC+12|0;do{if((aX&255)>(d[aY+o|0]|0)){e=a[aA+1|0]|0;if(e<<24>>24==0){a$=aX;a0=aY;break}ay=b[(c[277225]|0)+((e&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){a1=b[(c[277221]|0)+(((ay&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{e=c[277228]&65535;g=ay&-2048;j=e&-2048;av=(g&65535)>(j&65535)?g-j&65535:0;j=ay&2016;g=e&2016;if((j&65535)>(g&65535)){a2=(j-g&65535)+av&65535}else{a2=av}av=ay&31;g=e&31;if((av&65535)<=(g&65535)){a1=a2;break}a1=(av-g&65535)+a2&65535}}while(0);ay=aC+13|0;b[(c[277218]|0)+(ay<<1)>>1]=a1;b[(c[277218]|0)+(o<<1)>>1]=a1;g=a[1108909]|0;a[(c[277219]|0)+ay|0]=g;a[(c[277219]|0)+o|0]=g;a$=a[1108908]|0;a0=c[277219]|0}else{a$=aX;a0=aY}}while(0);o=aC+14|0;do{if((a$&255)>(d[a0+o|0]|0)){g=a[aA]|0;if(g<<24>>24==0){break}ay=b[(c[277225]|0)+((g&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){a3=b[(c[277221]|0)+(((ay&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{g=c[277228]&65535;av=ay&-2048;e=g&-2048;j=(av&65535)>(e&65535)?av-e&65535:0;e=ay&2016;av=g&2016;if((e&65535)>(av&65535)){a4=(e-av&65535)+j&65535}else{a4=j}j=ay&31;av=g&31;if((j&65535)<=(av&65535)){a3=a4;break}a3=(j-av&65535)+a4&65535}}while(0);ay=aC+15|0;b[(c[277218]|0)+(ay<<1)>>1]=a3;b[(c[277218]|0)+(o<<1)>>1]=a3;av=a[1108909]|0;a[(c[277219]|0)+ay|0]=av;a[(c[277219]|0)+o|0]=av}}while(0);o=aB-1|0;if((o|0)<=0){break}aA=aA-16|0;aB=o;aC=(c[277223]|0)+aC|0}return}else{if(l){a5=i;a6=h;a7=f}else{return}while(1){f=a[1108908]|0;h=c[277219]|0;do{if((f&255)>(d[h+a7|0]|0)){i=a[a5]|0;if(i<<24>>24==0){a8=f;a9=h;break}l=b[(c[277225]|0)+((i&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){ba=b[(c[277221]|0)+(((l&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{i=c[277228]&65535;aC=l&-2048;aB=i&-2048;aA=(aC&65535)>(aB&65535)?aC-aB&65535:0;aB=l&2016;aC=i&2016;if((aB&65535)>(aC&65535)){bb=(aB-aC&65535)+aA&65535}else{bb=aA}aA=l&31;aC=i&31;if((aA&65535)<=(aC&65535)){ba=bb;break}ba=(aA-aC&65535)+bb&65535}}while(0);l=a7+1|0;b[(c[277218]|0)+(l<<1)>>1]=ba;b[(c[277218]|0)+(a7<<1)>>1]=ba;aC=a[1108909]|0;a[(c[277219]|0)+l|0]=aC;a[(c[277219]|0)+a7|0]=aC;a8=a[1108908]|0;a9=c[277219]|0}else{a8=f;a9=h}}while(0);h=a7+2|0;do{if((a8&255)>(d[a9+h|0]|0)){f=a[a5+1|0]|0;if(f<<24>>24==0){bc=a8;bd=a9;break}aC=b[(c[277225]|0)+((f&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){be=b[(c[277221]|0)+(((aC&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{f=c[277228]&65535;l=aC&-2048;aA=f&-2048;i=(l&65535)>(aA&65535)?l-aA&65535:0;aA=aC&2016;l=f&2016;if((aA&65535)>(l&65535)){bf=(aA-l&65535)+i&65535}else{bf=i}i=aC&31;l=f&31;if((i&65535)<=(l&65535)){be=bf;break}be=(i-l&65535)+bf&65535}}while(0);aC=a7+3|0;b[(c[277218]|0)+(aC<<1)>>1]=be;b[(c[277218]|0)+(h<<1)>>1]=be;l=a[1108909]|0;a[(c[277219]|0)+aC|0]=l;a[(c[277219]|0)+h|0]=l;bc=a[1108908]|0;bd=c[277219]|0}else{bc=a8;bd=a9}}while(0);h=a7+4|0;do{if((bc&255)>(d[bd+h|0]|0)){l=a[a5+2|0]|0;if(l<<24>>24==0){bg=bc;bh=bd;break}aC=b[(c[277225]|0)+((l&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){bi=b[(c[277221]|0)+(((aC&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{l=c[277228]&65535;i=aC&-2048;f=l&-2048;aA=(i&65535)>(f&65535)?i-f&65535:0;f=aC&2016;i=l&2016;if((f&65535)>(i&65535)){bj=(f-i&65535)+aA&65535}else{bj=aA}aA=aC&31;i=l&31;if((aA&65535)<=(i&65535)){bi=bj;break}bi=(aA-i&65535)+bj&65535}}while(0);aC=a7+5|0;b[(c[277218]|0)+(aC<<1)>>1]=bi;b[(c[277218]|0)+(h<<1)>>1]=bi;i=a[1108909]|0;a[(c[277219]|0)+aC|0]=i;a[(c[277219]|0)+h|0]=i;bg=a[1108908]|0;bh=c[277219]|0}else{bg=bc;bh=bd}}while(0);h=a7+6|0;do{if((bg&255)>(d[bh+h|0]|0)){i=a[a5+3|0]|0;if(i<<24>>24==0){bk=bg;bl=bh;break}aC=b[(c[277225]|0)+((i&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){bm=b[(c[277221]|0)+(((aC&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{i=c[277228]&65535;aA=aC&-2048;l=i&-2048;f=(aA&65535)>(l&65535)?aA-l&65535:0;l=aC&2016;aA=i&2016;if((l&65535)>(aA&65535)){bn=(l-aA&65535)+f&65535}else{bn=f}f=aC&31;aA=i&31;if((f&65535)<=(aA&65535)){bm=bn;break}bm=(f-aA&65535)+bn&65535}}while(0);aC=a7+7|0;b[(c[277218]|0)+(aC<<1)>>1]=bm;b[(c[277218]|0)+(h<<1)>>1]=bm;aA=a[1108909]|0;a[(c[277219]|0)+aC|0]=aA;a[(c[277219]|0)+h|0]=aA;bk=a[1108908]|0;bl=c[277219]|0}else{bk=bg;bl=bh}}while(0);h=a7+8|0;do{if((bk&255)>(d[bl+h|0]|0)){aA=a[a5+4|0]|0;if(aA<<24>>24==0){bo=bk;bp=bl;break}aC=b[(c[277225]|0)+((aA&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){bq=b[(c[277221]|0)+(((aC&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{aA=c[277228]&65535;f=aC&-2048;i=aA&-2048;l=(f&65535)>(i&65535)?f-i&65535:0;i=aC&2016;f=aA&2016;if((i&65535)>(f&65535)){br=(i-f&65535)+l&65535}else{br=l}l=aC&31;f=aA&31;if((l&65535)<=(f&65535)){bq=br;break}bq=(l-f&65535)+br&65535}}while(0);aC=a7+9|0;b[(c[277218]|0)+(aC<<1)>>1]=bq;b[(c[277218]|0)+(h<<1)>>1]=bq;f=a[1108909]|0;a[(c[277219]|0)+aC|0]=f;a[(c[277219]|0)+h|0]=f;bo=a[1108908]|0;bp=c[277219]|0}else{bo=bk;bp=bl}}while(0);h=a7+10|0;do{if((bo&255)>(d[bp+h|0]|0)){f=a[a5+5|0]|0;if(f<<24>>24==0){bs=bo;bt=bp;break}aC=b[(c[277225]|0)+((f&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){bu=b[(c[277221]|0)+(((aC&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{f=c[277228]&65535;l=aC&-2048;aA=f&-2048;i=(l&65535)>(aA&65535)?l-aA&65535:0;aA=aC&2016;l=f&2016;if((aA&65535)>(l&65535)){bv=(aA-l&65535)+i&65535}else{bv=i}i=aC&31;l=f&31;if((i&65535)<=(l&65535)){bu=bv;break}bu=(i-l&65535)+bv&65535}}while(0);aC=a7+11|0;b[(c[277218]|0)+(aC<<1)>>1]=bu;b[(c[277218]|0)+(h<<1)>>1]=bu;l=a[1108909]|0;a[(c[277219]|0)+aC|0]=l;a[(c[277219]|0)+h|0]=l;bs=a[1108908]|0;bt=c[277219]|0}else{bs=bo;bt=bp}}while(0);h=a7+12|0;do{if((bs&255)>(d[bt+h|0]|0)){l=a[a5+6|0]|0;if(l<<24>>24==0){bw=bs;bx=bt;break}aC=b[(c[277225]|0)+((l&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){by=b[(c[277221]|0)+(((aC&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{l=c[277228]&65535;i=aC&-2048;f=l&-2048;aA=(i&65535)>(f&65535)?i-f&65535:0;f=aC&2016;i=l&2016;if((f&65535)>(i&65535)){bz=(f-i&65535)+aA&65535}else{bz=aA}aA=aC&31;i=l&31;if((aA&65535)<=(i&65535)){by=bz;break}by=(aA-i&65535)+bz&65535}}while(0);aC=a7+13|0;b[(c[277218]|0)+(aC<<1)>>1]=by;b[(c[277218]|0)+(h<<1)>>1]=by;i=a[1108909]|0;a[(c[277219]|0)+aC|0]=i;a[(c[277219]|0)+h|0]=i;bw=a[1108908]|0;bx=c[277219]|0}else{bw=bs;bx=bt}}while(0);h=a7+14|0;do{if((bw&255)>(d[bx+h|0]|0)){i=a[a5+7|0]|0;if(i<<24>>24==0){break}aC=b[(c[277225]|0)+((i&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){bA=b[(c[277221]|0)+(((aC&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{i=c[277228]&65535;aA=aC&-2048;l=i&-2048;f=(aA&65535)>(l&65535)?aA-l&65535:0;l=aC&2016;aA=i&2016;if((l&65535)>(aA&65535)){bB=(l-aA&65535)+f&65535}else{bB=f}f=aC&31;aA=i&31;if((f&65535)<=(aA&65535)){bA=bB;break}bA=(f-aA&65535)+bB&65535}}while(0);aC=a7+15|0;b[(c[277218]|0)+(aC<<1)>>1]=bA;b[(c[277218]|0)+(h<<1)>>1]=bA;aA=a[1108909]|0;a[(c[277219]|0)+aC|0]=aA;a[(c[277219]|0)+h|0]=aA}}while(0);h=a6-1|0;if((h|0)<=0){break}a5=a5-16|0;a6=h;a7=(c[277223]|0)+a7|0}return}}function Vs(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0,cf=0,cg=0,ch=0,ci=0,cj=0,ck=0,cl=0,cm=0,cn=0,co=0,cp=0,cq=0,cr=0,cs=0,ct=0,cu=0,cv=0,cw=0,cx=0,cy=0,cz=0,cA=0,cB=0,cC=0;i=e&1023;j=c[348606]|0;k=(i<<j)+(c[348604]|0)|0;if((e&256|0)==0){l=k}else{l=(c[348602]|0)+k|0}k=l&65535;l=k>>>(j>>>0);j=(e&16384|0)!=0;m=l<<6;do{if(j){n=(c[348622]|0)+m|0;if((a[(c[348618]|0)+l|0]|0)!=0){o=n;break}p=fi[c[348636]&63](n,k,i)|0;a[(c[348618]|0)+l|0]=p;o=n}else{n=(c[348624]|0)+m|0;if((a[(c[348620]|0)+l|0]|0)!=0){o=n;break}p=fi[c[348638]&63](n,k,i)|0;a[(c[348620]|0)+l|0]=p;o=n}}while(0);if((a[(c[348620]|0)+l|0]|0)==2){return}if((a[1394464]|0)==0){q=1106168+((e>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){l=d[1044485]|0;c[276541]=7080+(l<<5);i=0;do{k=i<<1&2;m=i&2;n=i&4;p=0;do{b[1125528+(i<<9)+(p<<1)>>1]=d[(p>>>1&28|m)+(7080+(l<<5))|0]<<6|d[(p<<2&28|k)+(7080+(l<<5))|0]<<11|d[(p>>>3&24|n)+(7080+(l<<5))|0];p=p+1|0;}while(p>>>0<256);i=i+1|0;}while(i>>>0<8);a[1106089]=0}q=1125528+((e>>>10&7)<<9)|0}c[277226]=q;c[277225]=(a[1108928]|0)!=0?1393712:q;if((e&49152|0)==0){if((h|0)<=0){return}q=o+((d[1394504]|0)+(g<<1))|0;i=h;l=f;while(1){p=a[1108908]|0;n=c[277219]|0;do{if((p&255)>(d[n+l|0]|0)){k=a[q]|0;m=k&255;if(k<<24>>24==0){r=p;s=n;break}do{if((a[1108928]|0)==0){k=b[(c[277225]|0)+(m<<1)>>1]|0;if((a[(c[277215]|0)+l|0]&32)!=0){t=b[(c[277221]|0)+((k&65535|67616)-(b[(c[277213]|0)+(l<<1)>>1]&63454)>>1<<1)>>1]|0;break}u=c[277228]&65535;v=k&-2048;w=u&-2048;x=(v&65535)>(w&65535)?v-w&65535:0;w=k&2016;v=u&2016;if((w&65535)>(v&65535)){y=(w-v&65535)+x&65535}else{y=x}x=k&31;k=u&31;if((x&65535)<=(k&65535)){t=y;break}t=(x-k&65535)+y&65535}else{k=b[(c[277225]|0)+(m<<1)>>1]|0;if((a[(c[277215]|0)+l|0]&32)==0){z=c[277228]&65535}else{z=b[(c[277213]|0)+(l<<1)>>1]|0}x=k&-2048;u=z&-2048;v=(x&65535)>(u&65535)?x-u&65535:0;u=k&2016;x=z&2016;if((u&65535)>(x&65535)){A=(u-x&65535)+v&65535}else{A=v}v=k&31;k=z&31;if((v&65535)<=(k&65535)){t=A;break}t=(v-k&65535)+A&65535}}while(0);m=l+1|0;b[(c[277218]|0)+(m<<1)>>1]=t;b[(c[277218]|0)+(l<<1)>>1]=t;k=a[1108909]|0;a[(c[277219]|0)+m|0]=k;a[(c[277219]|0)+l|0]=k;r=a[1108908]|0;s=c[277219]|0}else{r=p;s=n}}while(0);n=l+2|0;do{if((r&255)>(d[s+n|0]|0)){p=a[q+1|0]|0;k=p&255;if(p<<24>>24==0){B=r;C=s;break}do{if((a[1108928]|0)==0){p=b[(c[277225]|0)+(k<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)!=0){D=b[(c[277221]|0)+((p&65535|67616)-(b[(c[277213]|0)+(n<<1)>>1]&63454)>>1<<1)>>1]|0;break}m=c[277228]&65535;v=p&-2048;x=m&-2048;u=(v&65535)>(x&65535)?v-x&65535:0;x=p&2016;v=m&2016;if((x&65535)>(v&65535)){E=(x-v&65535)+u&65535}else{E=u}u=p&31;p=m&31;if((u&65535)<=(p&65535)){D=E;break}D=(u-p&65535)+E&65535}else{p=b[(c[277225]|0)+(k<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)==0){F=c[277228]&65535}else{F=b[(c[277213]|0)+(n<<1)>>1]|0}u=p&-2048;m=F&-2048;v=(u&65535)>(m&65535)?u-m&65535:0;m=p&2016;u=F&2016;if((m&65535)>(u&65535)){G=(m-u&65535)+v&65535}else{G=v}v=p&31;p=F&31;if((v&65535)<=(p&65535)){D=G;break}D=(v-p&65535)+G&65535}}while(0);k=l+3|0;b[(c[277218]|0)+(k<<1)>>1]=D;b[(c[277218]|0)+(n<<1)>>1]=D;p=a[1108909]|0;a[(c[277219]|0)+k|0]=p;a[(c[277219]|0)+n|0]=p;B=a[1108908]|0;C=c[277219]|0}else{B=r;C=s}}while(0);n=l+4|0;do{if((B&255)>(d[C+n|0]|0)){p=a[q+2|0]|0;k=p&255;if(p<<24>>24==0){H=B;I=C;break}do{if((a[1108928]|0)==0){p=b[(c[277225]|0)+(k<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)!=0){J=b[(c[277221]|0)+((p&65535|67616)-(b[(c[277213]|0)+(n<<1)>>1]&63454)>>1<<1)>>1]|0;break}v=c[277228]&65535;u=p&-2048;m=v&-2048;x=(u&65535)>(m&65535)?u-m&65535:0;m=p&2016;u=v&2016;if((m&65535)>(u&65535)){K=(m-u&65535)+x&65535}else{K=x}x=p&31;p=v&31;if((x&65535)<=(p&65535)){J=K;break}J=(x-p&65535)+K&65535}else{p=b[(c[277225]|0)+(k<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)==0){L=c[277228]&65535}else{L=b[(c[277213]|0)+(n<<1)>>1]|0}x=p&-2048;v=L&-2048;u=(x&65535)>(v&65535)?x-v&65535:0;v=p&2016;x=L&2016;if((v&65535)>(x&65535)){M=(v-x&65535)+u&65535}else{M=u}u=p&31;p=L&31;if((u&65535)<=(p&65535)){J=M;break}J=(u-p&65535)+M&65535}}while(0);k=l+5|0;b[(c[277218]|0)+(k<<1)>>1]=J;b[(c[277218]|0)+(n<<1)>>1]=J;p=a[1108909]|0;a[(c[277219]|0)+k|0]=p;a[(c[277219]|0)+n|0]=p;H=a[1108908]|0;I=c[277219]|0}else{H=B;I=C}}while(0);n=l+6|0;do{if((H&255)>(d[I+n|0]|0)){p=a[q+3|0]|0;k=p&255;if(p<<24>>24==0){N=H;O=I;break}do{if((a[1108928]|0)==0){p=b[(c[277225]|0)+(k<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)!=0){P=b[(c[277221]|0)+((p&65535|67616)-(b[(c[277213]|0)+(n<<1)>>1]&63454)>>1<<1)>>1]|0;break}u=c[277228]&65535;x=p&-2048;v=u&-2048;m=(x&65535)>(v&65535)?x-v&65535:0;v=p&2016;x=u&2016;if((v&65535)>(x&65535)){Q=(v-x&65535)+m&65535}else{Q=m}m=p&31;p=u&31;if((m&65535)<=(p&65535)){P=Q;break}P=(m-p&65535)+Q&65535}else{p=b[(c[277225]|0)+(k<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)==0){R=c[277228]&65535}else{R=b[(c[277213]|0)+(n<<1)>>1]|0}m=p&-2048;u=R&-2048;x=(m&65535)>(u&65535)?m-u&65535:0;u=p&2016;m=R&2016;if((u&65535)>(m&65535)){S=(u-m&65535)+x&65535}else{S=x}x=p&31;p=R&31;if((x&65535)<=(p&65535)){P=S;break}P=(x-p&65535)+S&65535}}while(0);k=l+7|0;b[(c[277218]|0)+(k<<1)>>1]=P;b[(c[277218]|0)+(n<<1)>>1]=P;p=a[1108909]|0;a[(c[277219]|0)+k|0]=p;a[(c[277219]|0)+n|0]=p;N=a[1108908]|0;O=c[277219]|0}else{N=H;O=I}}while(0);n=l+8|0;do{if((N&255)>(d[O+n|0]|0)){p=a[q+4|0]|0;k=p&255;if(p<<24>>24==0){T=N;U=O;break}do{if((a[1108928]|0)==0){p=b[(c[277225]|0)+(k<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)!=0){V=b[(c[277221]|0)+((p&65535|67616)-(b[(c[277213]|0)+(n<<1)>>1]&63454)>>1<<1)>>1]|0;break}x=c[277228]&65535;m=p&-2048;u=x&-2048;v=(m&65535)>(u&65535)?m-u&65535:0;u=p&2016;m=x&2016;if((u&65535)>(m&65535)){W=(u-m&65535)+v&65535}else{W=v}v=p&31;p=x&31;if((v&65535)<=(p&65535)){V=W;break}V=(v-p&65535)+W&65535}else{p=b[(c[277225]|0)+(k<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)==0){X=c[277228]&65535}else{X=b[(c[277213]|0)+(n<<1)>>1]|0}v=p&-2048;x=X&-2048;m=(v&65535)>(x&65535)?v-x&65535:0;x=p&2016;v=X&2016;if((x&65535)>(v&65535)){Y=(x-v&65535)+m&65535}else{Y=m}m=p&31;p=X&31;if((m&65535)<=(p&65535)){V=Y;break}V=(m-p&65535)+Y&65535}}while(0);k=l+9|0;b[(c[277218]|0)+(k<<1)>>1]=V;b[(c[277218]|0)+(n<<1)>>1]=V;p=a[1108909]|0;a[(c[277219]|0)+k|0]=p;a[(c[277219]|0)+n|0]=p;T=a[1108908]|0;U=c[277219]|0}else{T=N;U=O}}while(0);n=l+10|0;do{if((T&255)>(d[U+n|0]|0)){p=a[q+5|0]|0;k=p&255;if(p<<24>>24==0){Z=T;_=U;break}do{if((a[1108928]|0)==0){p=b[(c[277225]|0)+(k<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)!=0){$=b[(c[277221]|0)+((p&65535|67616)-(b[(c[277213]|0)+(n<<1)>>1]&63454)>>1<<1)>>1]|0;break}m=c[277228]&65535;v=p&-2048;x=m&-2048;u=(v&65535)>(x&65535)?v-x&65535:0;x=p&2016;v=m&2016;if((x&65535)>(v&65535)){aa=(x-v&65535)+u&65535}else{aa=u}u=p&31;p=m&31;if((u&65535)<=(p&65535)){$=aa;break}$=(u-p&65535)+aa&65535}else{p=b[(c[277225]|0)+(k<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)==0){ab=c[277228]&65535}else{ab=b[(c[277213]|0)+(n<<1)>>1]|0}u=p&-2048;m=ab&-2048;v=(u&65535)>(m&65535)?u-m&65535:0;m=p&2016;u=ab&2016;if((m&65535)>(u&65535)){ac=(m-u&65535)+v&65535}else{ac=v}v=p&31;p=ab&31;if((v&65535)<=(p&65535)){$=ac;break}$=(v-p&65535)+ac&65535}}while(0);k=l+11|0;b[(c[277218]|0)+(k<<1)>>1]=$;b[(c[277218]|0)+(n<<1)>>1]=$;p=a[1108909]|0;a[(c[277219]|0)+k|0]=p;a[(c[277219]|0)+n|0]=p;Z=a[1108908]|0;_=c[277219]|0}else{Z=T;_=U}}while(0);n=l+12|0;do{if((Z&255)>(d[_+n|0]|0)){p=a[q+6|0]|0;k=p&255;if(p<<24>>24==0){ad=Z;ae=_;break}do{if((a[1108928]|0)==0){p=b[(c[277225]|0)+(k<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)!=0){af=b[(c[277221]|0)+((p&65535|67616)-(b[(c[277213]|0)+(n<<1)>>1]&63454)>>1<<1)>>1]|0;break}v=c[277228]&65535;u=p&-2048;m=v&-2048;x=(u&65535)>(m&65535)?u-m&65535:0;m=p&2016;u=v&2016;if((m&65535)>(u&65535)){ag=(m-u&65535)+x&65535}else{ag=x}x=p&31;p=v&31;if((x&65535)<=(p&65535)){af=ag;break}af=(x-p&65535)+ag&65535}else{p=b[(c[277225]|0)+(k<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)==0){ah=c[277228]&65535}else{ah=b[(c[277213]|0)+(n<<1)>>1]|0}x=p&-2048;v=ah&-2048;u=(x&65535)>(v&65535)?x-v&65535:0;v=p&2016;x=ah&2016;if((v&65535)>(x&65535)){ai=(v-x&65535)+u&65535}else{ai=u}u=p&31;p=ah&31;if((u&65535)<=(p&65535)){af=ai;break}af=(u-p&65535)+ai&65535}}while(0);k=l+13|0;b[(c[277218]|0)+(k<<1)>>1]=af;b[(c[277218]|0)+(n<<1)>>1]=af;p=a[1108909]|0;a[(c[277219]|0)+k|0]=p;a[(c[277219]|0)+n|0]=p;ad=a[1108908]|0;ae=c[277219]|0}else{ad=Z;ae=_}}while(0);n=l+14|0;do{if((ad&255)>(d[ae+n|0]|0)){p=a[q+7|0]|0;k=p&255;if(p<<24>>24==0){break}do{if((a[1108928]|0)==0){p=b[(c[277225]|0)+(k<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)!=0){aj=b[(c[277221]|0)+((p&65535|67616)-(b[(c[277213]|0)+(n<<1)>>1]&63454)>>1<<1)>>1]|0;break}u=c[277228]&65535;x=p&-2048;v=u&-2048;m=(x&65535)>(v&65535)?x-v&65535:0;v=p&2016;x=u&2016;if((v&65535)>(x&65535)){ak=(v-x&65535)+m&65535}else{ak=m}m=p&31;p=u&31;if((m&65535)<=(p&65535)){aj=ak;break}aj=(m-p&65535)+ak&65535}else{p=b[(c[277225]|0)+(k<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)==0){al=c[277228]&65535}else{al=b[(c[277213]|0)+(n<<1)>>1]|0}m=p&-2048;u=al&-2048;x=(m&65535)>(u&65535)?m-u&65535:0;u=p&2016;m=al&2016;if((u&65535)>(m&65535)){am=(u-m&65535)+x&65535}else{am=x}x=p&31;p=al&31;if((x&65535)<=(p&65535)){aj=am;break}aj=(x-p&65535)+am&65535}}while(0);k=l+15|0;b[(c[277218]|0)+(k<<1)>>1]=aj;b[(c[277218]|0)+(n<<1)>>1]=aj;p=a[1108909]|0;a[(c[277219]|0)+k|0]=p;a[(c[277219]|0)+n|0]=p}}while(0);n=i-1|0;if((n|0)<=0){break}q=q+16|0;i=n;l=(c[277223]|0)+l|0}return}l=(d[1394504]|0)+(g<<1)|0;if((e&32768|0)==0){if((h|0)<=0){return}e=o+l|0;g=h;i=f;while(1){q=a[1108908]|0;aj=c[277219]|0;do{if((q&255)>(d[aj+i|0]|0)){am=a[e+7|0]|0;al=am&255;if(am<<24>>24==0){an=q;ao=aj;break}do{if((a[1108928]|0)==0){am=b[(c[277225]|0)+(al<<1)>>1]|0;if((a[(c[277215]|0)+i|0]&32)!=0){ap=b[(c[277221]|0)+((am&65535|67616)-(b[(c[277213]|0)+(i<<1)>>1]&63454)>>1<<1)>>1]|0;break}ak=c[277228]&65535;ae=am&-2048;ad=ak&-2048;_=(ae&65535)>(ad&65535)?ae-ad&65535:0;ad=am&2016;ae=ak&2016;if((ad&65535)>(ae&65535)){aq=(ad-ae&65535)+_&65535}else{aq=_}_=am&31;am=ak&31;if((_&65535)<=(am&65535)){ap=aq;break}ap=(_-am&65535)+aq&65535}else{am=b[(c[277225]|0)+(al<<1)>>1]|0;if((a[(c[277215]|0)+i|0]&32)==0){ar=c[277228]&65535}else{ar=b[(c[277213]|0)+(i<<1)>>1]|0}_=am&-2048;ak=ar&-2048;ae=(_&65535)>(ak&65535)?_-ak&65535:0;ak=am&2016;_=ar&2016;if((ak&65535)>(_&65535)){as=(ak-_&65535)+ae&65535}else{as=ae}ae=am&31;am=ar&31;if((ae&65535)<=(am&65535)){ap=as;break}ap=(ae-am&65535)+as&65535}}while(0);al=i+1|0;b[(c[277218]|0)+(al<<1)>>1]=ap;b[(c[277218]|0)+(i<<1)>>1]=ap;am=a[1108909]|0;a[(c[277219]|0)+al|0]=am;a[(c[277219]|0)+i|0]=am;an=a[1108908]|0;ao=c[277219]|0}else{an=q;ao=aj}}while(0);aj=i+2|0;do{if((an&255)>(d[ao+aj|0]|0)){q=a[e+6|0]|0;am=q&255;if(q<<24>>24==0){at=an;au=ao;break}do{if((a[1108928]|0)==0){q=b[(c[277225]|0)+(am<<1)>>1]|0;if((a[(c[277215]|0)+aj|0]&32)!=0){av=b[(c[277221]|0)+((q&65535|67616)-(b[(c[277213]|0)+(aj<<1)>>1]&63454)>>1<<1)>>1]|0;break}al=c[277228]&65535;ae=q&-2048;_=al&-2048;ak=(ae&65535)>(_&65535)?ae-_&65535:0;_=q&2016;ae=al&2016;if((_&65535)>(ae&65535)){aw=(_-ae&65535)+ak&65535}else{aw=ak}ak=q&31;q=al&31;if((ak&65535)<=(q&65535)){av=aw;break}av=(ak-q&65535)+aw&65535}else{q=b[(c[277225]|0)+(am<<1)>>1]|0;if((a[(c[277215]|0)+aj|0]&32)==0){ax=c[277228]&65535}else{ax=b[(c[277213]|0)+(aj<<1)>>1]|0}ak=q&-2048;al=ax&-2048;ae=(ak&65535)>(al&65535)?ak-al&65535:0;al=q&2016;ak=ax&2016;if((al&65535)>(ak&65535)){ay=(al-ak&65535)+ae&65535}else{ay=ae}ae=q&31;q=ax&31;if((ae&65535)<=(q&65535)){av=ay;break}av=(ae-q&65535)+ay&65535}}while(0);am=i+3|0;b[(c[277218]|0)+(am<<1)>>1]=av;b[(c[277218]|0)+(aj<<1)>>1]=av;q=a[1108909]|0;a[(c[277219]|0)+am|0]=q;a[(c[277219]|0)+aj|0]=q;at=a[1108908]|0;au=c[277219]|0}else{at=an;au=ao}}while(0);aj=i+4|0;do{if((at&255)>(d[au+aj|0]|0)){q=a[e+5|0]|0;am=q&255;if(q<<24>>24==0){az=at;aA=au;break}do{if((a[1108928]|0)==0){q=b[(c[277225]|0)+(am<<1)>>1]|0;if((a[(c[277215]|0)+aj|0]&32)!=0){aB=b[(c[277221]|0)+((q&65535|67616)-(b[(c[277213]|0)+(aj<<1)>>1]&63454)>>1<<1)>>1]|0;break}ae=c[277228]&65535;ak=q&-2048;al=ae&-2048;_=(ak&65535)>(al&65535)?ak-al&65535:0;al=q&2016;ak=ae&2016;if((al&65535)>(ak&65535)){aC=(al-ak&65535)+_&65535}else{aC=_}_=q&31;q=ae&31;if((_&65535)<=(q&65535)){aB=aC;break}aB=(_-q&65535)+aC&65535}else{q=b[(c[277225]|0)+(am<<1)>>1]|0;if((a[(c[277215]|0)+aj|0]&32)==0){aD=c[277228]&65535}else{aD=b[(c[277213]|0)+(aj<<1)>>1]|0}_=q&-2048;ae=aD&-2048;ak=(_&65535)>(ae&65535)?_-ae&65535:0;ae=q&2016;_=aD&2016;if((ae&65535)>(_&65535)){aE=(ae-_&65535)+ak&65535}else{aE=ak}ak=q&31;q=aD&31;if((ak&65535)<=(q&65535)){aB=aE;break}aB=(ak-q&65535)+aE&65535}}while(0);am=i+5|0;b[(c[277218]|0)+(am<<1)>>1]=aB;b[(c[277218]|0)+(aj<<1)>>1]=aB;q=a[1108909]|0;a[(c[277219]|0)+am|0]=q;a[(c[277219]|0)+aj|0]=q;az=a[1108908]|0;aA=c[277219]|0}else{az=at;aA=au}}while(0);aj=i+6|0;do{if((az&255)>(d[aA+aj|0]|0)){q=a[e+4|0]|0;am=q&255;if(q<<24>>24==0){aF=az;aG=aA;break}do{if((a[1108928]|0)==0){q=b[(c[277225]|0)+(am<<1)>>1]|0;if((a[(c[277215]|0)+aj|0]&32)!=0){aH=b[(c[277221]|0)+((q&65535|67616)-(b[(c[277213]|0)+(aj<<1)>>1]&63454)>>1<<1)>>1]|0;break}ak=c[277228]&65535;_=q&-2048;ae=ak&-2048;al=(_&65535)>(ae&65535)?_-ae&65535:0;ae=q&2016;_=ak&2016;if((ae&65535)>(_&65535)){aI=(ae-_&65535)+al&65535}else{aI=al}al=q&31;q=ak&31;if((al&65535)<=(q&65535)){aH=aI;break}aH=(al-q&65535)+aI&65535}else{q=b[(c[277225]|0)+(am<<1)>>1]|0;if((a[(c[277215]|0)+aj|0]&32)==0){aJ=c[277228]&65535}else{aJ=b[(c[277213]|0)+(aj<<1)>>1]|0}al=q&-2048;ak=aJ&-2048;_=(al&65535)>(ak&65535)?al-ak&65535:0;ak=q&2016;al=aJ&2016;if((ak&65535)>(al&65535)){aK=(ak-al&65535)+_&65535}else{aK=_}_=q&31;q=aJ&31;if((_&65535)<=(q&65535)){aH=aK;break}aH=(_-q&65535)+aK&65535}}while(0);am=i+7|0;b[(c[277218]|0)+(am<<1)>>1]=aH;b[(c[277218]|0)+(aj<<1)>>1]=aH;q=a[1108909]|0;a[(c[277219]|0)+am|0]=q;a[(c[277219]|0)+aj|0]=q;aF=a[1108908]|0;aG=c[277219]|0}else{aF=az;aG=aA}}while(0);aj=i+8|0;do{if((aF&255)>(d[aG+aj|0]|0)){q=a[e+3|0]|0;am=q&255;if(q<<24>>24==0){aL=aF;aM=aG;break}do{if((a[1108928]|0)==0){q=b[(c[277225]|0)+(am<<1)>>1]|0;if((a[(c[277215]|0)+aj|0]&32)!=0){aN=b[(c[277221]|0)+((q&65535|67616)-(b[(c[277213]|0)+(aj<<1)>>1]&63454)>>1<<1)>>1]|0;break}_=c[277228]&65535;al=q&-2048;ak=_&-2048;ae=(al&65535)>(ak&65535)?al-ak&65535:0;ak=q&2016;al=_&2016;if((ak&65535)>(al&65535)){aO=(ak-al&65535)+ae&65535}else{aO=ae}ae=q&31;q=_&31;if((ae&65535)<=(q&65535)){aN=aO;break}aN=(ae-q&65535)+aO&65535}else{q=b[(c[277225]|0)+(am<<1)>>1]|0;if((a[(c[277215]|0)+aj|0]&32)==0){aP=c[277228]&65535}else{aP=b[(c[277213]|0)+(aj<<1)>>1]|0}ae=q&-2048;_=aP&-2048;al=(ae&65535)>(_&65535)?ae-_&65535:0;_=q&2016;ae=aP&2016;if((_&65535)>(ae&65535)){aQ=(_-ae&65535)+al&65535}else{aQ=al}al=q&31;q=aP&31;if((al&65535)<=(q&65535)){aN=aQ;break}aN=(al-q&65535)+aQ&65535}}while(0);am=i+9|0;b[(c[277218]|0)+(am<<1)>>1]=aN;b[(c[277218]|0)+(aj<<1)>>1]=aN;q=a[1108909]|0;a[(c[277219]|0)+am|0]=q;a[(c[277219]|0)+aj|0]=q;aL=a[1108908]|0;aM=c[277219]|0}else{aL=aF;aM=aG}}while(0);aj=i+10|0;do{if((aL&255)>(d[aM+aj|0]|0)){q=a[e+2|0]|0;am=q&255;if(q<<24>>24==0){aR=aL;aS=aM;break}do{if((a[1108928]|0)==0){q=b[(c[277225]|0)+(am<<1)>>1]|0;if((a[(c[277215]|0)+aj|0]&32)!=0){aT=b[(c[277221]|0)+((q&65535|67616)-(b[(c[277213]|0)+(aj<<1)>>1]&63454)>>1<<1)>>1]|0;break}al=c[277228]&65535;ae=q&-2048;_=al&-2048;ak=(ae&65535)>(_&65535)?ae-_&65535:0;_=q&2016;ae=al&2016;if((_&65535)>(ae&65535)){aU=(_-ae&65535)+ak&65535}else{aU=ak}ak=q&31;q=al&31;if((ak&65535)<=(q&65535)){aT=aU;break}aT=(ak-q&65535)+aU&65535}else{q=b[(c[277225]|0)+(am<<1)>>1]|0;if((a[(c[277215]|0)+aj|0]&32)==0){aV=c[277228]&65535}else{aV=b[(c[277213]|0)+(aj<<1)>>1]|0}ak=q&-2048;al=aV&-2048;ae=(ak&65535)>(al&65535)?ak-al&65535:0;al=q&2016;ak=aV&2016;if((al&65535)>(ak&65535)){aW=(al-ak&65535)+ae&65535}else{aW=ae}ae=q&31;q=aV&31;if((ae&65535)<=(q&65535)){aT=aW;break}aT=(ae-q&65535)+aW&65535}}while(0);am=i+11|0;b[(c[277218]|0)+(am<<1)>>1]=aT;b[(c[277218]|0)+(aj<<1)>>1]=aT;q=a[1108909]|0;a[(c[277219]|0)+am|0]=q;a[(c[277219]|0)+aj|0]=q;aR=a[1108908]|0;aS=c[277219]|0}else{aR=aL;aS=aM}}while(0);aj=i+12|0;do{if((aR&255)>(d[aS+aj|0]|0)){q=a[e+1|0]|0;am=q&255;if(q<<24>>24==0){aX=aR;aY=aS;break}do{if((a[1108928]|0)==0){q=b[(c[277225]|0)+(am<<1)>>1]|0;if((a[(c[277215]|0)+aj|0]&32)!=0){aZ=b[(c[277221]|0)+((q&65535|67616)-(b[(c[277213]|0)+(aj<<1)>>1]&63454)>>1<<1)>>1]|0;break}ae=c[277228]&65535;ak=q&-2048;al=ae&-2048;_=(ak&65535)>(al&65535)?ak-al&65535:0;al=q&2016;ak=ae&2016;if((al&65535)>(ak&65535)){a_=(al-ak&65535)+_&65535}else{a_=_}_=q&31;q=ae&31;if((_&65535)<=(q&65535)){aZ=a_;break}aZ=(_-q&65535)+a_&65535}else{q=b[(c[277225]|0)+(am<<1)>>1]|0;if((a[(c[277215]|0)+aj|0]&32)==0){a$=c[277228]&65535}else{a$=b[(c[277213]|0)+(aj<<1)>>1]|0}_=q&-2048;ae=a$&-2048;ak=(_&65535)>(ae&65535)?_-ae&65535:0;ae=q&2016;_=a$&2016;if((ae&65535)>(_&65535)){a0=(ae-_&65535)+ak&65535}else{a0=ak}ak=q&31;q=a$&31;if((ak&65535)<=(q&65535)){aZ=a0;break}aZ=(ak-q&65535)+a0&65535}}while(0);am=i+13|0;b[(c[277218]|0)+(am<<1)>>1]=aZ;b[(c[277218]|0)+(aj<<1)>>1]=aZ;q=a[1108909]|0;a[(c[277219]|0)+am|0]=q;a[(c[277219]|0)+aj|0]=q;aX=a[1108908]|0;aY=c[277219]|0}else{aX=aR;aY=aS}}while(0);aj=i+14|0;do{if((aX&255)>(d[aY+aj|0]|0)){q=a[e]|0;am=q&255;if(q<<24>>24==0){break}do{if((a[1108928]|0)==0){q=b[(c[277225]|0)+(am<<1)>>1]|0;if((a[(c[277215]|0)+aj|0]&32)!=0){a1=b[(c[277221]|0)+((q&65535|67616)-(b[(c[277213]|0)+(aj<<1)>>1]&63454)>>1<<1)>>1]|0;break}ak=c[277228]&65535;_=q&-2048;ae=ak&-2048;al=(_&65535)>(ae&65535)?_-ae&65535:0;ae=q&2016;_=ak&2016;if((ae&65535)>(_&65535)){a2=(ae-_&65535)+al&65535}else{a2=al}al=q&31;q=ak&31;if((al&65535)<=(q&65535)){a1=a2;break}a1=(al-q&65535)+a2&65535}else{q=b[(c[277225]|0)+(am<<1)>>1]|0;if((a[(c[277215]|0)+aj|0]&32)==0){a3=c[277228]&65535}else{a3=b[(c[277213]|0)+(aj<<1)>>1]|0}al=q&-2048;ak=a3&-2048;_=(al&65535)>(ak&65535)?al-ak&65535:0;ak=q&2016;al=a3&2016;if((ak&65535)>(al&65535)){a4=(ak-al&65535)+_&65535}else{a4=_}_=q&31;q=a3&31;if((_&65535)<=(q&65535)){a1=a4;break}a1=(_-q&65535)+a4&65535}}while(0);am=i+15|0;b[(c[277218]|0)+(am<<1)>>1]=a1;b[(c[277218]|0)+(aj<<1)>>1]=a1;q=a[1108909]|0;a[(c[277219]|0)+am|0]=q;a[(c[277219]|0)+aj|0]=q}}while(0);aj=g-1|0;if((aj|0)<=0){break}e=e+16|0;g=aj;i=(c[277223]|0)+i|0}return}i=o+(56-l)|0;l=(h|0)>0;if(j){if(l){a5=i;a6=h;a7=f}else{return}while(1){j=a[1108908]|0;o=c[277219]|0;do{if((j&255)>(d[o+a7|0]|0)){g=a[a5+7|0]|0;e=g&255;if(g<<24>>24==0){a8=j;a9=o;break}do{if((a[1108928]|0)==0){g=b[(c[277225]|0)+(e<<1)>>1]|0;if((a[(c[277215]|0)+a7|0]&32)!=0){ba=b[(c[277221]|0)+((g&65535|67616)-(b[(c[277213]|0)+(a7<<1)>>1]&63454)>>1<<1)>>1]|0;break}a1=c[277228]&65535;a4=g&-2048;a3=a1&-2048;a2=(a4&65535)>(a3&65535)?a4-a3&65535:0;a3=g&2016;a4=a1&2016;if((a3&65535)>(a4&65535)){bb=(a3-a4&65535)+a2&65535}else{bb=a2}a2=g&31;g=a1&31;if((a2&65535)<=(g&65535)){ba=bb;break}ba=(a2-g&65535)+bb&65535}else{g=b[(c[277225]|0)+(e<<1)>>1]|0;if((a[(c[277215]|0)+a7|0]&32)==0){bc=c[277228]&65535}else{bc=b[(c[277213]|0)+(a7<<1)>>1]|0}a2=g&-2048;a1=bc&-2048;a4=(a2&65535)>(a1&65535)?a2-a1&65535:0;a1=g&2016;a2=bc&2016;if((a1&65535)>(a2&65535)){bd=(a1-a2&65535)+a4&65535}else{bd=a4}a4=g&31;g=bc&31;if((a4&65535)<=(g&65535)){ba=bd;break}ba=(a4-g&65535)+bd&65535}}while(0);e=a7+1|0;b[(c[277218]|0)+(e<<1)>>1]=ba;b[(c[277218]|0)+(a7<<1)>>1]=ba;g=a[1108909]|0;a[(c[277219]|0)+e|0]=g;a[(c[277219]|0)+a7|0]=g;a8=a[1108908]|0;a9=c[277219]|0}else{a8=j;a9=o}}while(0);o=a7+2|0;do{if((a8&255)>(d[a9+o|0]|0)){j=a[a5+6|0]|0;g=j&255;if(j<<24>>24==0){be=a8;bf=a9;break}do{if((a[1108928]|0)==0){j=b[(c[277225]|0)+(g<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){bg=b[(c[277221]|0)+((j&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}e=c[277228]&65535;a4=j&-2048;a2=e&-2048;a1=(a4&65535)>(a2&65535)?a4-a2&65535:0;a2=j&2016;a4=e&2016;if((a2&65535)>(a4&65535)){bh=(a2-a4&65535)+a1&65535}else{bh=a1}a1=j&31;j=e&31;if((a1&65535)<=(j&65535)){bg=bh;break}bg=(a1-j&65535)+bh&65535}else{j=b[(c[277225]|0)+(g<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){bi=c[277228]&65535}else{bi=b[(c[277213]|0)+(o<<1)>>1]|0}a1=j&-2048;e=bi&-2048;a4=(a1&65535)>(e&65535)?a1-e&65535:0;e=j&2016;a1=bi&2016;if((e&65535)>(a1&65535)){bj=(e-a1&65535)+a4&65535}else{bj=a4}a4=j&31;j=bi&31;if((a4&65535)<=(j&65535)){bg=bj;break}bg=(a4-j&65535)+bj&65535}}while(0);g=a7+3|0;b[(c[277218]|0)+(g<<1)>>1]=bg;b[(c[277218]|0)+(o<<1)>>1]=bg;j=a[1108909]|0;a[(c[277219]|0)+g|0]=j;a[(c[277219]|0)+o|0]=j;be=a[1108908]|0;bf=c[277219]|0}else{be=a8;bf=a9}}while(0);o=a7+4|0;do{if((be&255)>(d[bf+o|0]|0)){j=a[a5+5|0]|0;g=j&255;if(j<<24>>24==0){bk=be;bl=bf;break}do{if((a[1108928]|0)==0){j=b[(c[277225]|0)+(g<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){bm=b[(c[277221]|0)+((j&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}a4=c[277228]&65535;a1=j&-2048;e=a4&-2048;a2=(a1&65535)>(e&65535)?a1-e&65535:0;e=j&2016;a1=a4&2016;if((e&65535)>(a1&65535)){bn=(e-a1&65535)+a2&65535}else{bn=a2}a2=j&31;j=a4&31;if((a2&65535)<=(j&65535)){bm=bn;break}bm=(a2-j&65535)+bn&65535}else{j=b[(c[277225]|0)+(g<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){bo=c[277228]&65535}else{bo=b[(c[277213]|0)+(o<<1)>>1]|0}a2=j&-2048;a4=bo&-2048;a1=(a2&65535)>(a4&65535)?a2-a4&65535:0;a4=j&2016;a2=bo&2016;if((a4&65535)>(a2&65535)){bp=(a4-a2&65535)+a1&65535}else{bp=a1}a1=j&31;j=bo&31;if((a1&65535)<=(j&65535)){bm=bp;break}bm=(a1-j&65535)+bp&65535}}while(0);g=a7+5|0;b[(c[277218]|0)+(g<<1)>>1]=bm;b[(c[277218]|0)+(o<<1)>>1]=bm;j=a[1108909]|0;a[(c[277219]|0)+g|0]=j;a[(c[277219]|0)+o|0]=j;bk=a[1108908]|0;bl=c[277219]|0}else{bk=be;bl=bf}}while(0);o=a7+6|0;do{if((bk&255)>(d[bl+o|0]|0)){j=a[a5+4|0]|0;g=j&255;if(j<<24>>24==0){bq=bk;br=bl;break}do{if((a[1108928]|0)==0){j=b[(c[277225]|0)+(g<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){bs=b[(c[277221]|0)+((j&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}a1=c[277228]&65535;a2=j&-2048;a4=a1&-2048;e=(a2&65535)>(a4&65535)?a2-a4&65535:0;a4=j&2016;a2=a1&2016;if((a4&65535)>(a2&65535)){bt=(a4-a2&65535)+e&65535}else{bt=e}e=j&31;j=a1&31;if((e&65535)<=(j&65535)){bs=bt;break}bs=(e-j&65535)+bt&65535}else{j=b[(c[277225]|0)+(g<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){bu=c[277228]&65535}else{bu=b[(c[277213]|0)+(o<<1)>>1]|0}e=j&-2048;a1=bu&-2048;a2=(e&65535)>(a1&65535)?e-a1&65535:0;a1=j&2016;e=bu&2016;if((a1&65535)>(e&65535)){bv=(a1-e&65535)+a2&65535}else{bv=a2}a2=j&31;j=bu&31;if((a2&65535)<=(j&65535)){bs=bv;break}bs=(a2-j&65535)+bv&65535}}while(0);g=a7+7|0;b[(c[277218]|0)+(g<<1)>>1]=bs;b[(c[277218]|0)+(o<<1)>>1]=bs;j=a[1108909]|0;a[(c[277219]|0)+g|0]=j;a[(c[277219]|0)+o|0]=j;bq=a[1108908]|0;br=c[277219]|0}else{bq=bk;br=bl}}while(0);o=a7+8|0;do{if((bq&255)>(d[br+o|0]|0)){j=a[a5+3|0]|0;g=j&255;if(j<<24>>24==0){bw=bq;bx=br;break}do{if((a[1108928]|0)==0){j=b[(c[277225]|0)+(g<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){by=b[(c[277221]|0)+((j&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}a2=c[277228]&65535;e=j&-2048;a1=a2&-2048;a4=(e&65535)>(a1&65535)?e-a1&65535:0;a1=j&2016;e=a2&2016;if((a1&65535)>(e&65535)){bz=(a1-e&65535)+a4&65535}else{bz=a4}a4=j&31;j=a2&31;if((a4&65535)<=(j&65535)){by=bz;break}by=(a4-j&65535)+bz&65535}else{j=b[(c[277225]|0)+(g<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){bA=c[277228]&65535}else{bA=b[(c[277213]|0)+(o<<1)>>1]|0}a4=j&-2048;a2=bA&-2048;e=(a4&65535)>(a2&65535)?a4-a2&65535:0;a2=j&2016;a4=bA&2016;if((a2&65535)>(a4&65535)){bB=(a2-a4&65535)+e&65535}else{bB=e}e=j&31;j=bA&31;if((e&65535)<=(j&65535)){by=bB;break}by=(e-j&65535)+bB&65535}}while(0);g=a7+9|0;b[(c[277218]|0)+(g<<1)>>1]=by;b[(c[277218]|0)+(o<<1)>>1]=by;j=a[1108909]|0;a[(c[277219]|0)+g|0]=j;a[(c[277219]|0)+o|0]=j;bw=a[1108908]|0;bx=c[277219]|0}else{bw=bq;bx=br}}while(0);o=a7+10|0;do{if((bw&255)>(d[bx+o|0]|0)){j=a[a5+2|0]|0;g=j&255;if(j<<24>>24==0){bC=bw;bD=bx;break}do{if((a[1108928]|0)==0){j=b[(c[277225]|0)+(g<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){bE=b[(c[277221]|0)+((j&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}e=c[277228]&65535;a4=j&-2048;a2=e&-2048;a1=(a4&65535)>(a2&65535)?a4-a2&65535:0;a2=j&2016;a4=e&2016;if((a2&65535)>(a4&65535)){bF=(a2-a4&65535)+a1&65535}else{bF=a1}a1=j&31;j=e&31;if((a1&65535)<=(j&65535)){bE=bF;break}bE=(a1-j&65535)+bF&65535}else{j=b[(c[277225]|0)+(g<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){bG=c[277228]&65535}else{bG=b[(c[277213]|0)+(o<<1)>>1]|0}a1=j&-2048;e=bG&-2048;a4=(a1&65535)>(e&65535)?a1-e&65535:0;e=j&2016;a1=bG&2016;if((e&65535)>(a1&65535)){bH=(e-a1&65535)+a4&65535}else{bH=a4}a4=j&31;j=bG&31;if((a4&65535)<=(j&65535)){bE=bH;break}bE=(a4-j&65535)+bH&65535}}while(0);g=a7+11|0;b[(c[277218]|0)+(g<<1)>>1]=bE;b[(c[277218]|0)+(o<<1)>>1]=bE;j=a[1108909]|0;a[(c[277219]|0)+g|0]=j;a[(c[277219]|0)+o|0]=j;bC=a[1108908]|0;bD=c[277219]|0}else{bC=bw;bD=bx}}while(0);o=a7+12|0;do{if((bC&255)>(d[bD+o|0]|0)){j=a[a5+1|0]|0;g=j&255;if(j<<24>>24==0){bI=bC;bJ=bD;break}do{if((a[1108928]|0)==0){j=b[(c[277225]|0)+(g<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){bK=b[(c[277221]|0)+((j&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}a4=c[277228]&65535;a1=j&-2048;e=a4&-2048;a2=(a1&65535)>(e&65535)?a1-e&65535:0;e=j&2016;a1=a4&2016;if((e&65535)>(a1&65535)){bL=(e-a1&65535)+a2&65535}else{bL=a2}a2=j&31;j=a4&31;if((a2&65535)<=(j&65535)){bK=bL;break}bK=(a2-j&65535)+bL&65535}else{j=b[(c[277225]|0)+(g<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){bM=c[277228]&65535}else{bM=b[(c[277213]|0)+(o<<1)>>1]|0}a2=j&-2048;a4=bM&-2048;a1=(a2&65535)>(a4&65535)?a2-a4&65535:0;a4=j&2016;a2=bM&2016;if((a4&65535)>(a2&65535)){bN=(a4-a2&65535)+a1&65535}else{bN=a1}a1=j&31;j=bM&31;if((a1&65535)<=(j&65535)){bK=bN;break}bK=(a1-j&65535)+bN&65535}}while(0);g=a7+13|0;b[(c[277218]|0)+(g<<1)>>1]=bK;b[(c[277218]|0)+(o<<1)>>1]=bK;j=a[1108909]|0;a[(c[277219]|0)+g|0]=j;a[(c[277219]|0)+o|0]=j;bI=a[1108908]|0;bJ=c[277219]|0}else{bI=bC;bJ=bD}}while(0);o=a7+14|0;do{if((bI&255)>(d[bJ+o|0]|0)){j=a[a5]|0;g=j&255;if(j<<24>>24==0){break}do{if((a[1108928]|0)==0){j=b[(c[277225]|0)+(g<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){bO=b[(c[277221]|0)+((j&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}a1=c[277228]&65535;a2=j&-2048;a4=a1&-2048;e=(a2&65535)>(a4&65535)?a2-a4&65535:0;a4=j&2016;a2=a1&2016;if((a4&65535)>(a2&65535)){bP=(a4-a2&65535)+e&65535}else{bP=e}e=j&31;j=a1&31;if((e&65535)<=(j&65535)){bO=bP;break}bO=(e-j&65535)+bP&65535}else{j=b[(c[277225]|0)+(g<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){bQ=c[277228]&65535}else{bQ=b[(c[277213]|0)+(o<<1)>>1]|0}e=j&-2048;a1=bQ&-2048;a2=(e&65535)>(a1&65535)?e-a1&65535:0;a1=j&2016;e=bQ&2016;if((a1&65535)>(e&65535)){bR=(a1-e&65535)+a2&65535}else{bR=a2}a2=j&31;j=bQ&31;if((a2&65535)<=(j&65535)){bO=bR;break}bO=(a2-j&65535)+bR&65535}}while(0);g=a7+15|0;b[(c[277218]|0)+(g<<1)>>1]=bO;b[(c[277218]|0)+(o<<1)>>1]=bO;j=a[1108909]|0;a[(c[277219]|0)+g|0]=j;a[(c[277219]|0)+o|0]=j}}while(0);o=a6-1|0;if((o|0)<=0){break}a5=a5-16|0;a6=o;a7=(c[277223]|0)+a7|0}return}else{if(l){bS=i;bT=h;bU=f}else{return}while(1){f=a[1108908]|0;h=c[277219]|0;do{if((f&255)>(d[h+bU|0]|0)){i=a[bS]|0;l=i&255;if(i<<24>>24==0){bV=f;bW=h;break}do{if((a[1108928]|0)==0){i=b[(c[277225]|0)+(l<<1)>>1]|0;if((a[(c[277215]|0)+bU|0]&32)!=0){bX=b[(c[277221]|0)+((i&65535|67616)-(b[(c[277213]|0)+(bU<<1)>>1]&63454)>>1<<1)>>1]|0;break}a7=c[277228]&65535;a6=i&-2048;a5=a7&-2048;bO=(a6&65535)>(a5&65535)?a6-a5&65535:0;a5=i&2016;a6=a7&2016;if((a5&65535)>(a6&65535)){bY=(a5-a6&65535)+bO&65535}else{bY=bO}bO=i&31;i=a7&31;if((bO&65535)<=(i&65535)){bX=bY;break}bX=(bO-i&65535)+bY&65535}else{i=b[(c[277225]|0)+(l<<1)>>1]|0;if((a[(c[277215]|0)+bU|0]&32)==0){bZ=c[277228]&65535}else{bZ=b[(c[277213]|0)+(bU<<1)>>1]|0}bO=i&-2048;a7=bZ&-2048;a6=(bO&65535)>(a7&65535)?bO-a7&65535:0;a7=i&2016;bO=bZ&2016;if((a7&65535)>(bO&65535)){b_=(a7-bO&65535)+a6&65535}else{b_=a6}a6=i&31;i=bZ&31;if((a6&65535)<=(i&65535)){bX=b_;break}bX=(a6-i&65535)+b_&65535}}while(0);l=bU+1|0;b[(c[277218]|0)+(l<<1)>>1]=bX;b[(c[277218]|0)+(bU<<1)>>1]=bX;i=a[1108909]|0;a[(c[277219]|0)+l|0]=i;a[(c[277219]|0)+bU|0]=i;bV=a[1108908]|0;bW=c[277219]|0}else{bV=f;bW=h}}while(0);h=bU+2|0;do{if((bV&255)>(d[bW+h|0]|0)){f=a[bS+1|0]|0;i=f&255;if(f<<24>>24==0){b$=bV;b0=bW;break}do{if((a[1108928]|0)==0){f=b[(c[277225]|0)+(i<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)!=0){b1=b[(c[277221]|0)+((f&65535|67616)-(b[(c[277213]|0)+(h<<1)>>1]&63454)>>1<<1)>>1]|0;break}l=c[277228]&65535;a6=f&-2048;bO=l&-2048;a7=(a6&65535)>(bO&65535)?a6-bO&65535:0;bO=f&2016;a6=l&2016;if((bO&65535)>(a6&65535)){b2=(bO-a6&65535)+a7&65535}else{b2=a7}a7=f&31;f=l&31;if((a7&65535)<=(f&65535)){b1=b2;break}b1=(a7-f&65535)+b2&65535}else{f=b[(c[277225]|0)+(i<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)==0){b3=c[277228]&65535}else{b3=b[(c[277213]|0)+(h<<1)>>1]|0}a7=f&-2048;l=b3&-2048;a6=(a7&65535)>(l&65535)?a7-l&65535:0;l=f&2016;a7=b3&2016;if((l&65535)>(a7&65535)){b4=(l-a7&65535)+a6&65535}else{b4=a6}a6=f&31;f=b3&31;if((a6&65535)<=(f&65535)){b1=b4;break}b1=(a6-f&65535)+b4&65535}}while(0);i=bU+3|0;b[(c[277218]|0)+(i<<1)>>1]=b1;b[(c[277218]|0)+(h<<1)>>1]=b1;f=a[1108909]|0;a[(c[277219]|0)+i|0]=f;a[(c[277219]|0)+h|0]=f;b$=a[1108908]|0;b0=c[277219]|0}else{b$=bV;b0=bW}}while(0);h=bU+4|0;do{if((b$&255)>(d[b0+h|0]|0)){f=a[bS+2|0]|0;i=f&255;if(f<<24>>24==0){b5=b$;b6=b0;break}do{if((a[1108928]|0)==0){f=b[(c[277225]|0)+(i<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)!=0){b7=b[(c[277221]|0)+((f&65535|67616)-(b[(c[277213]|0)+(h<<1)>>1]&63454)>>1<<1)>>1]|0;break}a6=c[277228]&65535;a7=f&-2048;l=a6&-2048;bO=(a7&65535)>(l&65535)?a7-l&65535:0;l=f&2016;a7=a6&2016;if((l&65535)>(a7&65535)){b8=(l-a7&65535)+bO&65535}else{b8=bO}bO=f&31;f=a6&31;if((bO&65535)<=(f&65535)){b7=b8;break}b7=(bO-f&65535)+b8&65535}else{f=b[(c[277225]|0)+(i<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)==0){b9=c[277228]&65535}else{b9=b[(c[277213]|0)+(h<<1)>>1]|0}bO=f&-2048;a6=b9&-2048;a7=(bO&65535)>(a6&65535)?bO-a6&65535:0;a6=f&2016;bO=b9&2016;if((a6&65535)>(bO&65535)){ca=(a6-bO&65535)+a7&65535}else{ca=a7}a7=f&31;f=b9&31;if((a7&65535)<=(f&65535)){b7=ca;break}b7=(a7-f&65535)+ca&65535}}while(0);i=bU+5|0;b[(c[277218]|0)+(i<<1)>>1]=b7;b[(c[277218]|0)+(h<<1)>>1]=b7;f=a[1108909]|0;a[(c[277219]|0)+i|0]=f;a[(c[277219]|0)+h|0]=f;b5=a[1108908]|0;b6=c[277219]|0}else{b5=b$;b6=b0}}while(0);h=bU+6|0;do{if((b5&255)>(d[b6+h|0]|0)){f=a[bS+3|0]|0;i=f&255;if(f<<24>>24==0){cb=b5;cc=b6;break}do{if((a[1108928]|0)==0){f=b[(c[277225]|0)+(i<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)!=0){cd=b[(c[277221]|0)+((f&65535|67616)-(b[(c[277213]|0)+(h<<1)>>1]&63454)>>1<<1)>>1]|0;break}a7=c[277228]&65535;bO=f&-2048;a6=a7&-2048;l=(bO&65535)>(a6&65535)?bO-a6&65535:0;a6=f&2016;bO=a7&2016;if((a6&65535)>(bO&65535)){ce=(a6-bO&65535)+l&65535}else{ce=l}l=f&31;f=a7&31;if((l&65535)<=(f&65535)){cd=ce;break}cd=(l-f&65535)+ce&65535}else{f=b[(c[277225]|0)+(i<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)==0){cf=c[277228]&65535}else{cf=b[(c[277213]|0)+(h<<1)>>1]|0}l=f&-2048;a7=cf&-2048;bO=(l&65535)>(a7&65535)?l-a7&65535:0;a7=f&2016;l=cf&2016;if((a7&65535)>(l&65535)){cg=(a7-l&65535)+bO&65535}else{cg=bO}bO=f&31;f=cf&31;if((bO&65535)<=(f&65535)){cd=cg;break}cd=(bO-f&65535)+cg&65535}}while(0);i=bU+7|0;b[(c[277218]|0)+(i<<1)>>1]=cd;b[(c[277218]|0)+(h<<1)>>1]=cd;f=a[1108909]|0;a[(c[277219]|0)+i|0]=f;a[(c[277219]|0)+h|0]=f;cb=a[1108908]|0;cc=c[277219]|0}else{cb=b5;cc=b6}}while(0);h=bU+8|0;do{if((cb&255)>(d[cc+h|0]|0)){f=a[bS+4|0]|0;i=f&255;if(f<<24>>24==0){ch=cb;ci=cc;break}do{if((a[1108928]|0)==0){f=b[(c[277225]|0)+(i<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)!=0){cj=b[(c[277221]|0)+((f&65535|67616)-(b[(c[277213]|0)+(h<<1)>>1]&63454)>>1<<1)>>1]|0;break}bO=c[277228]&65535;l=f&-2048;a7=bO&-2048;a6=(l&65535)>(a7&65535)?l-a7&65535:0;a7=f&2016;l=bO&2016;if((a7&65535)>(l&65535)){ck=(a7-l&65535)+a6&65535}else{ck=a6}a6=f&31;f=bO&31;if((a6&65535)<=(f&65535)){cj=ck;break}cj=(a6-f&65535)+ck&65535}else{f=b[(c[277225]|0)+(i<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)==0){cl=c[277228]&65535}else{cl=b[(c[277213]|0)+(h<<1)>>1]|0}a6=f&-2048;bO=cl&-2048;l=(a6&65535)>(bO&65535)?a6-bO&65535:0;bO=f&2016;a6=cl&2016;if((bO&65535)>(a6&65535)){cm=(bO-a6&65535)+l&65535}else{cm=l}l=f&31;f=cl&31;if((l&65535)<=(f&65535)){cj=cm;break}cj=(l-f&65535)+cm&65535}}while(0);i=bU+9|0;b[(c[277218]|0)+(i<<1)>>1]=cj;b[(c[277218]|0)+(h<<1)>>1]=cj;f=a[1108909]|0;a[(c[277219]|0)+i|0]=f;a[(c[277219]|0)+h|0]=f;ch=a[1108908]|0;ci=c[277219]|0}else{ch=cb;ci=cc}}while(0);h=bU+10|0;do{if((ch&255)>(d[ci+h|0]|0)){f=a[bS+5|0]|0;i=f&255;if(f<<24>>24==0){cn=ch;co=ci;break}do{if((a[1108928]|0)==0){f=b[(c[277225]|0)+(i<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)!=0){cp=b[(c[277221]|0)+((f&65535|67616)-(b[(c[277213]|0)+(h<<1)>>1]&63454)>>1<<1)>>1]|0;break}l=c[277228]&65535;a6=f&-2048;bO=l&-2048;a7=(a6&65535)>(bO&65535)?a6-bO&65535:0;bO=f&2016;a6=l&2016;if((bO&65535)>(a6&65535)){cq=(bO-a6&65535)+a7&65535}else{cq=a7}a7=f&31;f=l&31;if((a7&65535)<=(f&65535)){cp=cq;break}cp=(a7-f&65535)+cq&65535}else{f=b[(c[277225]|0)+(i<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)==0){cr=c[277228]&65535}else{cr=b[(c[277213]|0)+(h<<1)>>1]|0}a7=f&-2048;l=cr&-2048;a6=(a7&65535)>(l&65535)?a7-l&65535:0;l=f&2016;a7=cr&2016;if((l&65535)>(a7&65535)){cs=(l-a7&65535)+a6&65535}else{cs=a6}a6=f&31;f=cr&31;if((a6&65535)<=(f&65535)){cp=cs;break}cp=(a6-f&65535)+cs&65535}}while(0);i=bU+11|0;b[(c[277218]|0)+(i<<1)>>1]=cp;b[(c[277218]|0)+(h<<1)>>1]=cp;f=a[1108909]|0;a[(c[277219]|0)+i|0]=f;a[(c[277219]|0)+h|0]=f;cn=a[1108908]|0;co=c[277219]|0}else{cn=ch;co=ci}}while(0);h=bU+12|0;do{if((cn&255)>(d[co+h|0]|0)){f=a[bS+6|0]|0;i=f&255;if(f<<24>>24==0){ct=cn;cu=co;break}do{if((a[1108928]|0)==0){f=b[(c[277225]|0)+(i<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)!=0){cv=b[(c[277221]|0)+((f&65535|67616)-(b[(c[277213]|0)+(h<<1)>>1]&63454)>>1<<1)>>1]|0;break}a6=c[277228]&65535;a7=f&-2048;l=a6&-2048;bO=(a7&65535)>(l&65535)?a7-l&65535:0;l=f&2016;a7=a6&2016;if((l&65535)>(a7&65535)){cw=(l-a7&65535)+bO&65535}else{cw=bO}bO=f&31;f=a6&31;if((bO&65535)<=(f&65535)){cv=cw;break}cv=(bO-f&65535)+cw&65535}else{f=b[(c[277225]|0)+(i<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)==0){cx=c[277228]&65535}else{cx=b[(c[277213]|0)+(h<<1)>>1]|0}bO=f&-2048;a6=cx&-2048;a7=(bO&65535)>(a6&65535)?bO-a6&65535:0;a6=f&2016;bO=cx&2016;if((a6&65535)>(bO&65535)){cy=(a6-bO&65535)+a7&65535}else{cy=a7}a7=f&31;f=cx&31;if((a7&65535)<=(f&65535)){cv=cy;break}cv=(a7-f&65535)+cy&65535}}while(0);i=bU+13|0;b[(c[277218]|0)+(i<<1)>>1]=cv;b[(c[277218]|0)+(h<<1)>>1]=cv;f=a[1108909]|0;a[(c[277219]|0)+i|0]=f;a[(c[277219]|0)+h|0]=f;ct=a[1108908]|0;cu=c[277219]|0}else{ct=cn;cu=co}}while(0);h=bU+14|0;do{if((ct&255)>(d[cu+h|0]|0)){f=a[bS+7|0]|0;i=f&255;if(f<<24>>24==0){break}do{if((a[1108928]|0)==0){f=b[(c[277225]|0)+(i<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)!=0){cz=b[(c[277221]|0)+((f&65535|67616)-(b[(c[277213]|0)+(h<<1)>>1]&63454)>>1<<1)>>1]|0;break}a7=c[277228]&65535;bO=f&-2048;a6=a7&-2048;l=(bO&65535)>(a6&65535)?bO-a6&65535:0;a6=f&2016;bO=a7&2016;if((a6&65535)>(bO&65535)){cA=(a6-bO&65535)+l&65535}else{cA=l}l=f&31;f=a7&31;if((l&65535)<=(f&65535)){cz=cA;break}cz=(l-f&65535)+cA&65535}else{f=b[(c[277225]|0)+(i<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)==0){cB=c[277228]&65535}else{cB=b[(c[277213]|0)+(h<<1)>>1]|0}l=f&-2048;a7=cB&-2048;bO=(l&65535)>(a7&65535)?l-a7&65535:0;a7=f&2016;l=cB&2016;if((a7&65535)>(l&65535)){cC=(a7-l&65535)+bO&65535}else{cC=bO}bO=f&31;f=cB&31;if((bO&65535)<=(f&65535)){cz=cC;break}cz=(bO-f&65535)+cC&65535}}while(0);i=bU+15|0;b[(c[277218]|0)+(i<<1)>>1]=cz;b[(c[277218]|0)+(h<<1)>>1]=cz;f=a[1108909]|0;a[(c[277219]|0)+i|0]=f;a[(c[277219]|0)+h|0]=f}}while(0);h=bT-1|0;if((h|0)<=0){break}bS=bS-16|0;bT=h;bU=(c[277223]|0)+bU|0}return}}function Vt(e,f,g,h,i,j){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;k=e&1023;l=c[348606]|0;m=(k<<l)+(c[348604]|0)|0;if((e&256|0)==0){n=m}else{n=(c[348602]|0)+m|0}m=n&65535;n=m>>>(l>>>0);l=(e&16384|0)!=0;o=n<<6;do{if(l){p=(c[348622]|0)+o|0;if((a[(c[348618]|0)+n|0]|0)!=0){q=p;break}r=fi[c[348636]&63](p,m,k)|0;a[(c[348618]|0)+n|0]=r;q=p}else{p=(c[348624]|0)+o|0;if((a[(c[348620]|0)+n|0]|0)!=0){q=p;break}r=fi[c[348638]&63](p,m,k)|0;a[(c[348620]|0)+n|0]=r;q=p}}while(0);if((a[(c[348620]|0)+n|0]|0)==2){return}if((a[1394464]|0)==0){s=1106168+((e>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){n=d[1044485]|0;c[276541]=7080+(n<<5);k=0;do{m=k<<1&2;o=k&2;p=k&4;r=0;do{b[1125528+(k<<9)+(r<<1)>>1]=d[(r>>>1&28|o)+(7080+(n<<5))|0]<<6|d[(r<<2&28|m)+(7080+(n<<5))|0]<<11|d[(r>>>3&24|p)+(7080+(n<<5))|0];r=r+1|0;}while(r>>>0<256);k=k+1|0;}while(k>>>0<8);a[1106089]=0}s=1125528+((e>>>10&7)<<9)|0}c[277226]=s;c[277225]=(a[1108928]|0)!=0?1393712:s;s=l?7-h|0:h;if((e&32768|0)==0){t=s+g|0}else{t=56-g+s|0}s=a[q+t|0]|0;if(!(s<<24>>24!=0&(j|0)>0)){return}t=i-1|0;i=(t|0)>-1;q=s&255;s=j;j=f;while(1){if(i){f=t;do{g=(f<<1)+j|0;if((d[1108908]|0)>(d[(c[277219]|0)+g|0]|0)){b[(c[277218]|0)+(g<<1)>>1]=b[(c[277225]|0)+(q<<1)>>1]|0;if((a[1108928]|0)==0){u=b[(c[277213]|0)+(g+2<<1)>>1]|0}else{u=0}e=g+1|0;b[(c[277218]|0)+(e<<1)>>1]=u;h=a[1108909]|0;a[(c[277219]|0)+e|0]=h;a[(c[277219]|0)+g|0]=h}f=f-1|0;}while((f|0)>-1)}f=s-1|0;if((f|0)>0){s=f;j=(c[277223]|0)+j|0}else{break}}return}function Vu(f,g,h,i,j,k){f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0;l=f&1023;m=c[348606]|0;n=(l<<m)+(c[348604]|0)|0;if((f&256|0)==0){o=n}else{o=(c[348602]|0)+n|0}n=o&65535;o=n>>>(m>>>0);m=(f&16384|0)!=0;p=o<<6;do{if(m){q=(c[348622]|0)+p|0;if((a[(c[348618]|0)+o|0]|0)!=0){r=q;break}s=fi[c[348636]&63](q,n,l)|0;a[(c[348618]|0)+o|0]=s;r=q}else{q=(c[348624]|0)+p|0;if((a[(c[348620]|0)+o|0]|0)!=0){r=q;break}s=fi[c[348638]&63](q,n,l)|0;a[(c[348620]|0)+o|0]=s;r=q}}while(0);if((a[(c[348620]|0)+o|0]|0)==2){return}if((a[1394464]|0)==0){t=1106168+((f>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){o=d[1044485]|0;c[276541]=7080+(o<<5);l=0;do{n=l<<1&2;p=l&2;q=l&4;s=0;do{b[1125528+(l<<9)+(s<<1)>>1]=d[(s>>>1&28|p)+(7080+(o<<5))|0]<<6|d[(s<<2&28|n)+(7080+(o<<5))|0]<<11|d[(s>>>3&24|q)+(7080+(o<<5))|0];s=s+1|0;}while(s>>>0<256);l=l+1|0;}while(l>>>0<8);a[1106089]=0}t=1125528+((f>>>10&7)<<9)|0}c[277226]=t;c[277225]=(a[1108928]|0)!=0?1393712:t;t=m?7-i|0:i;if((f&32768|0)==0){u=t+h|0}else{u=56-h+t|0}t=a[r+u|0]|0;if(!(t<<24>>24!=0&(k|0)>0)){return}u=j-1|0;j=(u|0)>-1;r=t&255;t=k;k=g;while(1){if(j){g=u;do{h=(g<<1)+k|0;if((d[1108908]|0)>(d[(c[277219]|0)+h|0]|0)){f=e[(c[277225]|0)+(r<<1)>>1]|0;i=(a[(c[277215]|0)+h|0]&32)==0;if(i){m=c[277228]|0;v=m;w=m&-2082}else{m=e[(c[277213]|0)+(h<<1)>>1]|0;v=m;w=m&63454}if(i){x=c[277228]|0}else{x=e[(c[277213]|0)+(h<<1)>>1]|0}b[(c[277218]|0)+(h<<1)>>1]=((x^f)&2081|e[(c[277220]|0)+((f&2081&v)+((w+(f&63454)|0)>>>1)<<1)>>1])&65535;f=(a[1108928]|0)==0;if(f){y=b[(c[277213]|0)+(h+2<<1)>>1]&63454}else{y=0}i=(a[(c[277215]|0)+h|0]&32)==0;if(i){z=c[277228]|0}else{z=e[(c[277226]|0)+(r<<1)>>1]|0}if(f){A=b[(c[277213]|0)+(h+2<<1)>>1]&2081}else{A=0}if(i){B=c[277228]|0}else{B=e[(c[277226]|0)+(r<<1)>>1]|0}if(f){C=e[(c[277213]|0)+(h+2<<1)>>1]|0}else{C=0}if(i){D=c[277228]|0}else{D=e[(c[277226]|0)+(r<<1)>>1]|0}i=h+1|0;b[(c[277218]|0)+(i<<1)>>1]=((D^C)&2081|e[(c[277220]|0)+((B&A)+(((z&-2082)+y|0)>>>1)<<1)>>1])&65535;f=a[1108909]|0;a[(c[277219]|0)+i|0]=f;a[(c[277219]|0)+h|0]=f}g=g-1|0;}while((g|0)>-1)}g=t-1|0;if((g|0)>0){t=g;k=(c[277223]|0)+k|0}else{break}}return}function Vv(f,g,h,i,j,k){f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;l=f&1023;m=c[348606]|0;n=(l<<m)+(c[348604]|0)|0;if((f&256|0)==0){o=n}else{o=(c[348602]|0)+n|0}n=o&65535;o=n>>>(m>>>0);m=(f&16384|0)!=0;p=o<<6;do{if(m){q=(c[348622]|0)+p|0;if((a[(c[348618]|0)+o|0]|0)!=0){r=q;break}s=fi[c[348636]&63](q,n,l)|0;a[(c[348618]|0)+o|0]=s;r=q}else{q=(c[348624]|0)+p|0;if((a[(c[348620]|0)+o|0]|0)!=0){r=q;break}s=fi[c[348638]&63](q,n,l)|0;a[(c[348620]|0)+o|0]=s;r=q}}while(0);if((a[(c[348620]|0)+o|0]|0)==2){return}if((a[1394464]|0)==0){t=1106168+((f>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){o=d[1044485]|0;c[276541]=7080+(o<<5);l=0;do{n=l<<1&2;p=l&2;q=l&4;s=0;do{b[1125528+(l<<9)+(s<<1)>>1]=d[(s>>>1&28|p)+(7080+(o<<5))|0]<<6|d[(s<<2&28|n)+(7080+(o<<5))|0]<<11|d[(s>>>3&24|q)+(7080+(o<<5))|0];s=s+1|0;}while(s>>>0<256);l=l+1|0;}while(l>>>0<8);a[1106089]=0}t=1125528+((f>>>10&7)<<9)|0}c[277226]=t;c[277225]=(a[1108928]|0)!=0?1393712:t;t=m?7-i|0:i;if((f&32768|0)==0){u=t+h|0}else{u=56-h+t|0}t=a[r+u|0]|0;if(!(t<<24>>24!=0&(k|0)>0)){return}u=j-1|0;j=(u|0)>-1;r=t&255;t=k;k=g;while(1){if(j){g=u;do{h=(g<<1)+k|0;if((d[1108908]|0)>(d[(c[277219]|0)+h|0]|0)){f=e[(c[277225]|0)+(r<<1)>>1]|0;i=c[277228]|0;m=(((f&63454)+(i&-2082)|0)>>>1)+(i&2081&f)|0;if((a[1108928]|0)==0){v=m&65535}else{v=(e[(c[277220]|0)+(m<<1)>>1]|(f^i)&2081)&65535}b[(c[277218]|0)+(h<<1)>>1]=v;if((a[1108928]|0)==0){i=e[(c[277213]|0)+(h+2<<1)>>1]|0;f=c[277228]|0;w=(((i&63454)+(f&128990)|0)>>>1)+(f&2081&i)|0}else{i=c[277228]|0;w=e[(c[277220]|0)+((i>>>1&2147482607)<<1)>>1]|i&2081}i=h+1|0;b[(c[277218]|0)+(i<<1)>>1]=w&65535;f=a[1108909]|0;a[(c[277219]|0)+i|0]=f;a[(c[277219]|0)+h|0]=f}g=g-1|0;}while((g|0)>-1)}g=t-1|0;if((g|0)>0){t=g;k=(c[277223]|0)+k|0}else{break}}return}function Vw(f,g,h,i,j,k){f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0;l=f&1023;m=c[348606]|0;n=(l<<m)+(c[348604]|0)|0;if((f&256|0)==0){o=n}else{o=(c[348602]|0)+n|0}n=o&65535;o=n>>>(m>>>0);m=(f&16384|0)!=0;p=o<<6;do{if(m){q=(c[348622]|0)+p|0;if((a[(c[348618]|0)+o|0]|0)!=0){r=q;break}s=fi[c[348636]&63](q,n,l)|0;a[(c[348618]|0)+o|0]=s;r=q}else{q=(c[348624]|0)+p|0;if((a[(c[348620]|0)+o|0]|0)!=0){r=q;break}s=fi[c[348638]&63](q,n,l)|0;a[(c[348620]|0)+o|0]=s;r=q}}while(0);if((a[(c[348620]|0)+o|0]|0)==2){return}if((a[1394464]|0)==0){t=1106168+((f>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){o=d[1044485]|0;c[276541]=7080+(o<<5);l=0;do{n=l<<1&2;p=l&2;q=l&4;s=0;do{b[1125528+(l<<9)+(s<<1)>>1]=d[(s>>>1&28|p)+(7080+(o<<5))|0]<<6|d[(s<<2&28|n)+(7080+(o<<5))|0]<<11|d[(s>>>3&24|q)+(7080+(o<<5))|0];s=s+1|0;}while(s>>>0<256);l=l+1|0;}while(l>>>0<8);a[1106089]=0}t=1125528+((f>>>10&7)<<9)|0}c[277226]=t;c[277225]=(a[1108928]|0)!=0?1393712:t;t=m?7-i|0:i;if((f&32768|0)==0){u=t+h|0}else{u=56-h+t|0}t=a[r+u|0]|0;if(!(t<<24>>24!=0&(k|0)>0)){return}u=j-1|0;j=(u|0)>-1;r=t&255;t=k;k=g;while(1){if(j){g=u;do{h=(g<<1)+k|0;if((d[1108908]|0)>(d[(c[277219]|0)+h|0]|0)){do{if((a[1108928]|0)==0){f=b[(c[277225]|0)+(r<<1)>>1]|0;i=f&65535;m=i&63454;if((a[(c[277215]|0)+h|0]&32)==0){l=c[277228]|0;v=(e[(c[277220]|0)+((((l&-2082)+m|0)>>>1)+(i&2081&l)<<1)>>1]|(l^i)&2081)&65535;break}else{i=b[(c[277213]|0)+(h<<1)>>1]|0;v=(((i&63454)+m|0)>>>1)+(i&f&2081)&65535;break}}else{f=e[(c[277225]|0)+(r<<1)>>1]|0;i=(a[(c[277215]|0)+h|0]&32)==0;if(i){m=c[277228]|0;w=m;x=m&-2082}else{m=e[(c[277213]|0)+(h<<1)>>1]|0;w=m;x=m&63454}if(i){y=c[277228]|0}else{y=e[(c[277213]|0)+(h<<1)>>1]|0}v=((y^f)&2081|e[(c[277220]|0)+((f&2081&w)+((x+(f&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(h<<1)>>1]=v;f=(a[(c[277215]|0)+h|0]&32)==0;do{if((a[1108928]|0)==0){i=e[(c[277213]|0)+(h+2<<1)>>1]|0;m=i&63454;if(f){l=c[277228]|0;z=(e[(c[277220]|0)+((((l&-2082)+m|0)>>>1)+(i&2081&l)<<1)>>1]|(l^i)&2081)&65535;break}else{l=e[(c[277226]|0)+(r<<1)>>1]|0;z=(((l&63454)+m|0)>>>1)+(i&2081&l)&65535;break}}else{if(f){l=c[277228]|0;A=l;B=(c[277220]|0)+((l>>>1&2147482607)<<1)|0}else{l=e[(c[277226]|0)+(r<<1)>>1]|0;A=l;B=(c[277220]|0)+((l>>>1&31727)<<1)|0}z=(e[B>>1]|A&2081)&65535}}while(0);f=h+1|0;b[(c[277218]|0)+(f<<1)>>1]=z;l=a[1108909]|0;a[(c[277219]|0)+f|0]=l;a[(c[277219]|0)+h|0]=l}g=g-1|0;}while((g|0)>-1)}g=t-1|0;if((g|0)>0){t=g;k=(c[277223]|0)+k|0}else{break}}return}function Vx(e,f,g,h,i,j){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;k=e&1023;l=c[348606]|0;m=(k<<l)+(c[348604]|0)|0;if((e&256|0)==0){n=m}else{n=(c[348602]|0)+m|0}m=n&65535;n=m>>>(l>>>0);l=(e&16384|0)!=0;o=n<<6;do{if(l){p=(c[348622]|0)+o|0;if((a[(c[348618]|0)+n|0]|0)!=0){q=p;break}r=fi[c[348636]&63](p,m,k)|0;a[(c[348618]|0)+n|0]=r;q=p}else{p=(c[348624]|0)+o|0;if((a[(c[348620]|0)+n|0]|0)!=0){q=p;break}r=fi[c[348638]&63](p,m,k)|0;a[(c[348620]|0)+n|0]=r;q=p}}while(0);if((a[(c[348620]|0)+n|0]|0)==2){return}if((a[1394464]|0)==0){s=1106168+((e>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){n=d[1044485]|0;c[276541]=7080+(n<<5);k=0;do{m=k<<1&2;o=k&2;p=k&4;r=0;do{b[1125528+(k<<9)+(r<<1)>>1]=d[(r>>>1&28|o)+(7080+(n<<5))|0]<<6|d[(r<<2&28|m)+(7080+(n<<5))|0]<<11|d[(r>>>3&24|p)+(7080+(n<<5))|0];r=r+1|0;}while(r>>>0<256);k=k+1|0;}while(k>>>0<8);a[1106089]=0}s=1125528+((e>>>10&7)<<9)|0}c[277226]=s;c[277225]=(a[1108928]|0)!=0?1393712:s;s=l?7-h|0:h;if((e&32768|0)==0){t=s+g|0}else{t=56-g+s|0}s=a[q+t|0]|0;if(!(s<<24>>24!=0&(j|0)>0)){return}t=i-1|0;i=(t|0)>-1;q=s&255;s=j;j=f;while(1){if(i){f=t;do{g=(f<<1)+j|0;if((d[1108908]|0)>(d[(c[277219]|0)+g|0]|0)){e=b[(c[277225]|0)+(q<<1)>>1]|0;if((a[(c[277215]|0)+g|0]&32)==0){u=c[277228]&65535}else{u=b[(c[277213]|0)+(g<<1)>>1]|0}h=e&-2048;l=u&-2048;k=(h&65535)>(l&65535)?h-l&65535:0;l=e&2016;h=u&2016;if((l&65535)>(h&65535)){v=(l-h&65535)+k&65535}else{v=k}k=e&31;e=u&31;if((k&65535)>(e&65535)){w=(k-e&65535)+v&65535}else{w=v}b[(c[277218]|0)+(g<<1)>>1]=w;if((a[1108928]|0)==0){x=b[(c[277213]|0)+(g+2<<1)>>1]|0}else{x=0}if((a[(c[277215]|0)+g|0]&32)==0){y=c[277228]&65535}else{y=b[(c[277226]|0)+(q<<1)>>1]|0}e=x&-2048;k=y&-2048;h=(e&65535)>(k&65535)?e-k&65535:0;k=x&2016;e=y&2016;if((k&65535)>(e&65535)){z=(k-e&65535)+h&65535}else{z=h}h=x&31;e=y&31;if((h&65535)>(e&65535)){A=(h-e&65535)+z&65535}else{A=z}e=g+1|0;b[(c[277218]|0)+(e<<1)>>1]=A;h=a[1108909]|0;a[(c[277219]|0)+e|0]=h;a[(c[277219]|0)+g|0]=h}f=f-1|0;}while((f|0)>-1)}f=s-1|0;if((f|0)>0){s=f;j=(c[277223]|0)+j|0}else{break}}return}function Vy(f,g,h,i,j,k){f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;l=f&1023;m=c[348606]|0;n=(l<<m)+(c[348604]|0)|0;if((f&256|0)==0){o=n}else{o=(c[348602]|0)+n|0}n=o&65535;o=n>>>(m>>>0);m=(f&16384|0)!=0;p=o<<6;do{if(m){q=(c[348622]|0)+p|0;if((a[(c[348618]|0)+o|0]|0)!=0){r=q;break}s=fi[c[348636]&63](q,n,l)|0;a[(c[348618]|0)+o|0]=s;r=q}else{q=(c[348624]|0)+p|0;if((a[(c[348620]|0)+o|0]|0)!=0){r=q;break}s=fi[c[348638]&63](q,n,l)|0;a[(c[348620]|0)+o|0]=s;r=q}}while(0);if((a[(c[348620]|0)+o|0]|0)==2){return}if((a[1394464]|0)==0){t=1106168+((f>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){o=d[1044485]|0;c[276541]=7080+(o<<5);l=0;do{n=l<<1&2;p=l&2;q=l&4;s=0;do{b[1125528+(l<<9)+(s<<1)>>1]=d[(s>>>1&28|p)+(7080+(o<<5))|0]<<6|d[(s<<2&28|n)+(7080+(o<<5))|0]<<11|d[(s>>>3&24|q)+(7080+(o<<5))|0];s=s+1|0;}while(s>>>0<256);l=l+1|0;}while(l>>>0<8);a[1106089]=0}t=1125528+((f>>>10&7)<<9)|0}c[277226]=t;c[277225]=(a[1108928]|0)!=0?1393712:t;t=m?7-i|0:i;if((f&32768|0)==0){u=t+h|0}else{u=56-h+t|0}t=a[r+u|0]|0;if(!(t<<24>>24!=0&(k|0)>0)){return}u=j-1|0;j=(u|0)>-1;r=t&255;t=k;k=g;while(1){if(j){g=u;do{h=(g<<1)+k|0;if((d[1108908]|0)>(d[(c[277219]|0)+h|0]|0)){f=b[(c[277225]|0)+(r<<1)>>1]|0;do{if((a[1108928]|0)==0){v=b[(c[277221]|0)+(((f&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{i=c[277228]&65535;m=f&-2048;l=i&-2048;o=(m&65535)>(l&65535)?m-l&65535:0;l=f&2016;m=i&2016;if((l&65535)>(m&65535)){w=(l-m&65535)+o&65535}else{w=o}o=f&31;m=i&31;if((o&65535)<=(m&65535)){v=w;break}v=(o-m&65535)+w&65535}}while(0);b[(c[277218]|0)+(h<<1)>>1]=v;if((a[1108928]|0)==0){x=b[(c[277221]|0)+(((e[(c[277213]|0)+(h+2<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{x=0}f=h+1|0;b[(c[277218]|0)+(f<<1)>>1]=x;m=a[1108909]|0;a[(c[277219]|0)+f|0]=m;a[(c[277219]|0)+h|0]=m}g=g-1|0;}while((g|0)>-1)}g=t-1|0;if((g|0)>0){t=g;k=(c[277223]|0)+k|0}else{break}}return}function Vz(e,f,g,h,i,j){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;k=e&1023;l=c[348606]|0;m=(k<<l)+(c[348604]|0)|0;if((e&256|0)==0){n=m}else{n=(c[348602]|0)+m|0}m=n&65535;n=m>>>(l>>>0);l=(e&16384|0)!=0;o=n<<6;do{if(l){p=(c[348622]|0)+o|0;if((a[(c[348618]|0)+n|0]|0)!=0){q=p;break}r=fi[c[348636]&63](p,m,k)|0;a[(c[348618]|0)+n|0]=r;q=p}else{p=(c[348624]|0)+o|0;if((a[(c[348620]|0)+n|0]|0)!=0){q=p;break}r=fi[c[348638]&63](p,m,k)|0;a[(c[348620]|0)+n|0]=r;q=p}}while(0);if((a[(c[348620]|0)+n|0]|0)==2){return}if((a[1394464]|0)==0){s=1106168+((e>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){n=d[1044485]|0;c[276541]=7080+(n<<5);k=0;do{m=k<<1&2;o=k&2;p=k&4;r=0;do{b[1125528+(k<<9)+(r<<1)>>1]=d[(r>>>1&28|o)+(7080+(n<<5))|0]<<6|d[(r<<2&28|m)+(7080+(n<<5))|0]<<11|d[(r>>>3&24|p)+(7080+(n<<5))|0];r=r+1|0;}while(r>>>0<256);k=k+1|0;}while(k>>>0<8);a[1106089]=0}s=1125528+((e>>>10&7)<<9)|0}c[277226]=s;c[277225]=(a[1108928]|0)!=0?1393712:s;s=l?7-h|0:h;if((e&32768|0)==0){t=s+g|0}else{t=56-g+s|0}s=a[q+t|0]|0;if(!(s<<24>>24!=0&(j|0)>0)){return}t=i-1|0;i=(t|0)>-1;q=s&255;s=j;j=f;while(1){if(i){f=t;do{g=(f<<1)+j|0;if((d[1108908]|0)>(d[(c[277219]|0)+g|0]|0)){do{if((a[1108928]|0)==0){e=b[(c[277225]|0)+(q<<1)>>1]|0;if((a[(c[277215]|0)+g|0]&32)!=0){u=b[(c[277221]|0)+((e&65535|67616)-(b[(c[277213]|0)+(g<<1)>>1]&63454)>>1<<1)>>1]|0;break}h=c[277228]&65535;l=e&-2048;k=h&-2048;n=(l&65535)>(k&65535)?l-k&65535:0;k=e&2016;l=h&2016;if((k&65535)>(l&65535)){v=(k-l&65535)+n&65535}else{v=n}n=e&31;e=h&31;if((n&65535)<=(e&65535)){u=v;break}u=(n-e&65535)+v&65535}else{e=b[(c[277225]|0)+(q<<1)>>1]|0;if((a[(c[277215]|0)+g|0]&32)==0){w=c[277228]&65535}else{w=b[(c[277213]|0)+(g<<1)>>1]|0}n=e&-2048;h=w&-2048;l=(n&65535)>(h&65535)?n-h&65535:0;h=e&2016;n=w&2016;if((h&65535)>(n&65535)){x=(h-n&65535)+l&65535}else{x=l}l=e&31;e=w&31;if((l&65535)<=(e&65535)){u=x;break}u=(l-e&65535)+x&65535}}while(0);b[(c[277218]|0)+(g<<1)>>1]=u;do{if((a[1108928]|0)==0){e=b[(c[277213]|0)+(g+2<<1)>>1]|0;if((a[(c[277215]|0)+g|0]&32)!=0){y=b[(c[277221]|0)+((e&65535|67616)-(b[(c[277226]|0)+(q<<1)>>1]&63454)>>1<<1)>>1]|0;break}l=c[277228]&65535;n=e&-2048;h=l&-2048;k=(n&65535)>(h&65535)?n-h&65535:0;h=e&2016;n=l&2016;if((h&65535)>(n&65535)){z=(h-n&65535)+k&65535}else{z=k}k=e&31;e=l&31;if((k&65535)<=(e&65535)){y=z;break}y=(k-e&65535)+z&65535}else{y=0}}while(0);e=g+1|0;b[(c[277218]|0)+(e<<1)>>1]=y;k=a[1108909]|0;a[(c[277219]|0)+e|0]=k;a[(c[277219]|0)+g|0]=k}f=f-1|0;}while((f|0)>-1)}f=s-1|0;if((f|0)>0){s=f;j=(c[277223]|0)+j|0}else{break}}return}function VA(e,f,g,h,i,j){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0;k=e&1023;l=c[348606]|0;m=(k<<l)+(c[348604]|0)|0;if((e&256|0)==0){n=m}else{n=(c[348602]|0)+m|0}m=n&65535;n=m>>>(l>>>0);l=(e&16384|0)!=0;o=n<<6;do{if(l){p=(c[348622]|0)+o|0;if((a[(c[348618]|0)+n|0]|0)!=0){q=p;break}r=fi[c[348636]&63](p,m,k)|0;a[(c[348618]|0)+n|0]=r;q=p}else{p=(c[348624]|0)+o|0;if((a[(c[348620]|0)+n|0]|0)!=0){q=p;break}r=fi[c[348638]&63](p,m,k)|0;a[(c[348620]|0)+n|0]=r;q=p}}while(0);if((a[(c[348620]|0)+n|0]|0)==2){return}if((a[1394464]|0)==0){s=1106168+((e>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){n=d[1044485]|0;c[276541]=7080+(n<<5);k=0;do{m=k<<1&2;o=k&2;p=k&4;r=0;do{b[1125528+(k<<9)+(r<<1)>>1]=d[(r>>>1&28|o)+(7080+(n<<5))|0]<<6|d[(r<<2&28|m)+(7080+(n<<5))|0]<<11|d[(r>>>3&24|p)+(7080+(n<<5))|0];r=r+1|0;}while(r>>>0<256);k=k+1|0;}while(k>>>0<8);a[1106089]=0}s=1125528+((e>>>10&7)<<9)|0}c[277226]=s;c[277225]=(a[1108928]|0)!=0?1393712:s;if((e&49152|0)==0){if((j|0)<=0){return}s=h&255;k=s-1&255;n=k<<24>>24==0;r=q+i|0;p=j;m=f;while(1){switch(g|0){case 2:{t=s;u=6451;break};case 3:{v=s;u=6457;break};case 7:{u=6481;break};case 6:{w=s;u=6475;break};case 5:{x=s;u=6469;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+m|0]|0)){o=a[r]|0;if(o<<24>>24==0){break}b[(c[277218]|0)+(m<<1)>>1]=b[(c[277225]|0)+((o&255)<<1)>>1]|0;if((a[1108928]|0)==0){y=b[(c[277213]|0)+(m+2<<1)>>1]|0}else{y=0}o=m+1|0;b[(c[277218]|0)+(o<<1)>>1]=y;z=a[1108909]|0;a[(c[277219]|0)+o|0]=z;a[(c[277219]|0)+m|0]=z}}while(0);if(!n){A=k;u=6445}break};case 4:{B=s;u=6463;break};case 1:{A=s;u=6445;break};default:{}}if((u|0)==6445){u=0;z=m+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+z|0]|0)){o=a[r+1|0]|0;if(o<<24>>24==0){break}b[(c[277218]|0)+(z<<1)>>1]=b[(c[277225]|0)+((o&255)<<1)>>1]|0;if((a[1108928]|0)==0){C=b[(c[277213]|0)+(m+4<<1)>>1]|0}else{C=0}o=m+3|0;b[(c[277218]|0)+(o<<1)>>1]=C;D=a[1108909]|0;a[(c[277219]|0)+o|0]=D;a[(c[277219]|0)+z|0]=D}}while(0);z=A-1&255;if(z<<24>>24!=0){t=z;u=6451}}if((u|0)==6451){u=0;z=m+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+z|0]|0)){D=a[r+2|0]|0;if(D<<24>>24==0){break}b[(c[277218]|0)+(z<<1)>>1]=b[(c[277225]|0)+((D&255)<<1)>>1]|0;if((a[1108928]|0)==0){E=b[(c[277213]|0)+(m+6<<1)>>1]|0}else{E=0}D=m+5|0;b[(c[277218]|0)+(D<<1)>>1]=E;o=a[1108909]|0;a[(c[277219]|0)+D|0]=o;a[(c[277219]|0)+z|0]=o}}while(0);z=t-1&255;if(z<<24>>24!=0){v=z;u=6457}}if((u|0)==6457){u=0;z=m+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+z|0]|0)){o=a[r+3|0]|0;if(o<<24>>24==0){break}b[(c[277218]|0)+(z<<1)>>1]=b[(c[277225]|0)+((o&255)<<1)>>1]|0;if((a[1108928]|0)==0){F=b[(c[277213]|0)+(m+8<<1)>>1]|0}else{F=0}o=m+7|0;b[(c[277218]|0)+(o<<1)>>1]=F;D=a[1108909]|0;a[(c[277219]|0)+o|0]=D;a[(c[277219]|0)+z|0]=D}}while(0);z=v-1&255;if(z<<24>>24!=0){B=z;u=6463}}if((u|0)==6463){u=0;z=m+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+z|0]|0)){D=a[r+4|0]|0;if(D<<24>>24==0){break}b[(c[277218]|0)+(z<<1)>>1]=b[(c[277225]|0)+((D&255)<<1)>>1]|0;if((a[1108928]|0)==0){G=b[(c[277213]|0)+(m+10<<1)>>1]|0}else{G=0}D=m+9|0;b[(c[277218]|0)+(D<<1)>>1]=G;o=a[1108909]|0;a[(c[277219]|0)+D|0]=o;a[(c[277219]|0)+z|0]=o}}while(0);z=B-1&255;if(z<<24>>24!=0){x=z;u=6469}}if((u|0)==6469){u=0;z=m+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+z|0]|0)){o=a[r+5|0]|0;if(o<<24>>24==0){break}b[(c[277218]|0)+(z<<1)>>1]=b[(c[277225]|0)+((o&255)<<1)>>1]|0;if((a[1108928]|0)==0){H=b[(c[277213]|0)+(m+12<<1)>>1]|0}else{H=0}o=m+11|0;b[(c[277218]|0)+(o<<1)>>1]=H;D=a[1108909]|0;a[(c[277219]|0)+o|0]=D;a[(c[277219]|0)+z|0]=D}}while(0);z=x-1&255;if(z<<24>>24!=0){w=z;u=6475}}if((u|0)==6475){u=0;z=m+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+z|0]|0)){D=a[r+6|0]|0;if(D<<24>>24==0){break}b[(c[277218]|0)+(z<<1)>>1]=b[(c[277225]|0)+((D&255)<<1)>>1]|0;if((a[1108928]|0)==0){I=b[(c[277213]|0)+(m+14<<1)>>1]|0}else{I=0}D=m+13|0;b[(c[277218]|0)+(D<<1)>>1]=I;o=a[1108909]|0;a[(c[277219]|0)+D|0]=o;a[(c[277219]|0)+z|0]=o}}while(0);if(w<<24>>24!=1){u=6481}}do{if((u|0)==6481){u=0;z=m+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+z|0]|0)){break}o=a[r+7|0]|0;if(o<<24>>24==0){break}b[(c[277218]|0)+(z<<1)>>1]=b[(c[277225]|0)+((o&255)<<1)>>1]|0;if((a[1108928]|0)==0){J=b[(c[277213]|0)+(m+16<<1)>>1]|0}else{J=0}o=m+15|0;b[(c[277218]|0)+(o<<1)>>1]=J;D=a[1108909]|0;a[(c[277219]|0)+o|0]=D;a[(c[277219]|0)+z|0]=D}}while(0);D=p-1|0;if((D|0)>0){r=r+8|0;p=D;m=(c[277223]|0)+m|0}else{break}}return}if((e&32768|0)==0){if((j|0)<=0){return}e=h&255;m=e-1&255;p=m<<24>>24==0;r=q+i|0;J=j;w=f;while(1){switch(g|0){case 3:{K=e;u=6509;break};case 1:{L=e;u=6497;break};case 7:{u=6533;break};case 2:{M=e;u=6503;break};case 6:{N=e;u=6527;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+w|0]|0)){I=a[r+7|0]|0;if(I<<24>>24==0){break}b[(c[277218]|0)+(w<<1)>>1]=b[(c[277225]|0)+((I&255)<<1)>>1]|0;if((a[1108928]|0)==0){O=b[(c[277213]|0)+(w+2<<1)>>1]|0}else{O=0}I=w+1|0;b[(c[277218]|0)+(I<<1)>>1]=O;x=a[1108909]|0;a[(c[277219]|0)+I|0]=x;a[(c[277219]|0)+w|0]=x}}while(0);if(!p){L=m;u=6497}break};case 4:{P=e;u=6515;break};case 5:{Q=e;u=6521;break};default:{}}if((u|0)==6497){u=0;x=w+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+x|0]|0)){I=a[r+6|0]|0;if(I<<24>>24==0){break}b[(c[277218]|0)+(x<<1)>>1]=b[(c[277225]|0)+((I&255)<<1)>>1]|0;if((a[1108928]|0)==0){R=b[(c[277213]|0)+(w+4<<1)>>1]|0}else{R=0}I=w+3|0;b[(c[277218]|0)+(I<<1)>>1]=R;H=a[1108909]|0;a[(c[277219]|0)+I|0]=H;a[(c[277219]|0)+x|0]=H}}while(0);x=L-1&255;if(x<<24>>24!=0){M=x;u=6503}}if((u|0)==6503){u=0;x=w+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+x|0]|0)){H=a[r+5|0]|0;if(H<<24>>24==0){break}b[(c[277218]|0)+(x<<1)>>1]=b[(c[277225]|0)+((H&255)<<1)>>1]|0;if((a[1108928]|0)==0){S=b[(c[277213]|0)+(w+6<<1)>>1]|0}else{S=0}H=w+5|0;b[(c[277218]|0)+(H<<1)>>1]=S;I=a[1108909]|0;a[(c[277219]|0)+H|0]=I;a[(c[277219]|0)+x|0]=I}}while(0);x=M-1&255;if(x<<24>>24!=0){K=x;u=6509}}if((u|0)==6509){u=0;x=w+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+x|0]|0)){I=a[r+4|0]|0;if(I<<24>>24==0){break}b[(c[277218]|0)+(x<<1)>>1]=b[(c[277225]|0)+((I&255)<<1)>>1]|0;if((a[1108928]|0)==0){T=b[(c[277213]|0)+(w+8<<1)>>1]|0}else{T=0}I=w+7|0;b[(c[277218]|0)+(I<<1)>>1]=T;H=a[1108909]|0;a[(c[277219]|0)+I|0]=H;a[(c[277219]|0)+x|0]=H}}while(0);x=K-1&255;if(x<<24>>24!=0){P=x;u=6515}}if((u|0)==6515){u=0;x=w+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+x|0]|0)){H=a[r+3|0]|0;if(H<<24>>24==0){break}b[(c[277218]|0)+(x<<1)>>1]=b[(c[277225]|0)+((H&255)<<1)>>1]|0;if((a[1108928]|0)==0){U=b[(c[277213]|0)+(w+10<<1)>>1]|0}else{U=0}H=w+9|0;b[(c[277218]|0)+(H<<1)>>1]=U;I=a[1108909]|0;a[(c[277219]|0)+H|0]=I;a[(c[277219]|0)+x|0]=I}}while(0);x=P-1&255;if(x<<24>>24!=0){Q=x;u=6521}}if((u|0)==6521){u=0;x=w+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+x|0]|0)){I=a[r+2|0]|0;if(I<<24>>24==0){break}b[(c[277218]|0)+(x<<1)>>1]=b[(c[277225]|0)+((I&255)<<1)>>1]|0;if((a[1108928]|0)==0){V=b[(c[277213]|0)+(w+12<<1)>>1]|0}else{V=0}I=w+11|0;b[(c[277218]|0)+(I<<1)>>1]=V;H=a[1108909]|0;a[(c[277219]|0)+I|0]=H;a[(c[277219]|0)+x|0]=H}}while(0);x=Q-1&255;if(x<<24>>24!=0){N=x;u=6527}}if((u|0)==6527){u=0;x=w+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+x|0]|0)){H=a[r+1|0]|0;if(H<<24>>24==0){break}b[(c[277218]|0)+(x<<1)>>1]=b[(c[277225]|0)+((H&255)<<1)>>1]|0;if((a[1108928]|0)==0){W=b[(c[277213]|0)+(w+14<<1)>>1]|0}else{W=0}H=w+13|0;b[(c[277218]|0)+(H<<1)>>1]=W;I=a[1108909]|0;a[(c[277219]|0)+H|0]=I;a[(c[277219]|0)+x|0]=I}}while(0);if(N<<24>>24!=1){u=6533}}do{if((u|0)==6533){u=0;x=w+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+x|0]|0)){break}I=a[r]|0;if(I<<24>>24==0){break}b[(c[277218]|0)+(x<<1)>>1]=b[(c[277225]|0)+((I&255)<<1)>>1]|0;if((a[1108928]|0)==0){X=b[(c[277213]|0)+(w+16<<1)>>1]|0}else{X=0}I=w+15|0;b[(c[277218]|0)+(I<<1)>>1]=X;H=a[1108909]|0;a[(c[277219]|0)+I|0]=H;a[(c[277219]|0)+x|0]=H}}while(0);H=J-1|0;if((H|0)>0){r=r+8|0;J=H;w=(c[277223]|0)+w|0}else{break}}return}w=q+(56-i)|0;i=(j|0)>0;if(l){if(!i){return}l=h&255;q=l-1&255;J=q<<24>>24==0;r=w;X=j;N=f;while(1){switch(g|0){case 7:{u=6636;break};case 2:{Y=l;u=6606;break};case 1:{Z=l;u=6600;break};case 5:{_=l;u=6624;break};case 3:{$=l;u=6612;break};case 4:{aa=l;u=6618;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+N|0]|0)){W=a[r+7|0]|0;if(W<<24>>24==0){break}b[(c[277218]|0)+(N<<1)>>1]=b[(c[277225]|0)+((W&255)<<1)>>1]|0;if((a[1108928]|0)==0){ab=b[(c[277213]|0)+(N+2<<1)>>1]|0}else{ab=0}W=N+1|0;b[(c[277218]|0)+(W<<1)>>1]=ab;Q=a[1108909]|0;a[(c[277219]|0)+W|0]=Q;a[(c[277219]|0)+N|0]=Q}}while(0);if(!J){Z=q;u=6600}break};case 6:{ac=l;u=6630;break};default:{}}if((u|0)==6600){u=0;Q=N+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+Q|0]|0)){W=a[r+6|0]|0;if(W<<24>>24==0){break}b[(c[277218]|0)+(Q<<1)>>1]=b[(c[277225]|0)+((W&255)<<1)>>1]|0;if((a[1108928]|0)==0){ad=b[(c[277213]|0)+(N+4<<1)>>1]|0}else{ad=0}W=N+3|0;b[(c[277218]|0)+(W<<1)>>1]=ad;V=a[1108909]|0;a[(c[277219]|0)+W|0]=V;a[(c[277219]|0)+Q|0]=V}}while(0);Q=Z-1&255;if(Q<<24>>24!=0){Y=Q;u=6606}}if((u|0)==6606){u=0;Q=N+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+Q|0]|0)){V=a[r+5|0]|0;if(V<<24>>24==0){break}b[(c[277218]|0)+(Q<<1)>>1]=b[(c[277225]|0)+((V&255)<<1)>>1]|0;if((a[1108928]|0)==0){ae=b[(c[277213]|0)+(N+6<<1)>>1]|0}else{ae=0}V=N+5|0;b[(c[277218]|0)+(V<<1)>>1]=ae;W=a[1108909]|0;a[(c[277219]|0)+V|0]=W;a[(c[277219]|0)+Q|0]=W}}while(0);Q=Y-1&255;if(Q<<24>>24!=0){$=Q;u=6612}}if((u|0)==6612){u=0;Q=N+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+Q|0]|0)){W=a[r+4|0]|0;if(W<<24>>24==0){break}b[(c[277218]|0)+(Q<<1)>>1]=b[(c[277225]|0)+((W&255)<<1)>>1]|0;if((a[1108928]|0)==0){af=b[(c[277213]|0)+(N+8<<1)>>1]|0}else{af=0}W=N+7|0;b[(c[277218]|0)+(W<<1)>>1]=af;V=a[1108909]|0;a[(c[277219]|0)+W|0]=V;a[(c[277219]|0)+Q|0]=V}}while(0);Q=$-1&255;if(Q<<24>>24!=0){aa=Q;u=6618}}if((u|0)==6618){u=0;Q=N+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+Q|0]|0)){V=a[r+3|0]|0;if(V<<24>>24==0){break}b[(c[277218]|0)+(Q<<1)>>1]=b[(c[277225]|0)+((V&255)<<1)>>1]|0;if((a[1108928]|0)==0){ag=b[(c[277213]|0)+(N+10<<1)>>1]|0}else{ag=0}V=N+9|0;b[(c[277218]|0)+(V<<1)>>1]=ag;W=a[1108909]|0;a[(c[277219]|0)+V|0]=W;a[(c[277219]|0)+Q|0]=W}}while(0);Q=aa-1&255;if(Q<<24>>24!=0){_=Q;u=6624}}if((u|0)==6624){u=0;Q=N+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+Q|0]|0)){W=a[r+2|0]|0;if(W<<24>>24==0){break}b[(c[277218]|0)+(Q<<1)>>1]=b[(c[277225]|0)+((W&255)<<1)>>1]|0;if((a[1108928]|0)==0){ah=b[(c[277213]|0)+(N+12<<1)>>1]|0}else{ah=0}W=N+11|0;b[(c[277218]|0)+(W<<1)>>1]=ah;V=a[1108909]|0;a[(c[277219]|0)+W|0]=V;a[(c[277219]|0)+Q|0]=V}}while(0);Q=_-1&255;if(Q<<24>>24!=0){ac=Q;u=6630}}if((u|0)==6630){u=0;Q=N+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+Q|0]|0)){V=a[r+1|0]|0;if(V<<24>>24==0){break}b[(c[277218]|0)+(Q<<1)>>1]=b[(c[277225]|0)+((V&255)<<1)>>1]|0;if((a[1108928]|0)==0){ai=b[(c[277213]|0)+(N+14<<1)>>1]|0}else{ai=0}V=N+13|0;b[(c[277218]|0)+(V<<1)>>1]=ai;W=a[1108909]|0;a[(c[277219]|0)+V|0]=W;a[(c[277219]|0)+Q|0]=W}}while(0);if(ac<<24>>24!=1){u=6636}}do{if((u|0)==6636){u=0;Q=N+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+Q|0]|0)){break}W=a[r]|0;if(W<<24>>24==0){break}b[(c[277218]|0)+(Q<<1)>>1]=b[(c[277225]|0)+((W&255)<<1)>>1]|0;if((a[1108928]|0)==0){aj=b[(c[277213]|0)+(N+16<<1)>>1]|0}else{aj=0}W=N+15|0;b[(c[277218]|0)+(W<<1)>>1]=aj;V=a[1108909]|0;a[(c[277219]|0)+W|0]=V;a[(c[277219]|0)+Q|0]=V}}while(0);V=X-1|0;if((V|0)>0){r=r-8|0;X=V;N=(c[277223]|0)+N|0}else{break}}return}else{if(!i){return}i=h&255;h=i-1&255;N=h<<24>>24==0;X=w;w=j;j=f;while(1){switch(g|0){case 5:{ak=i;u=6575;break};case 2:{al=i;u=6557;break};case 4:{am=i;u=6569;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+j|0]|0)){f=a[X]|0;if(f<<24>>24==0){break}b[(c[277218]|0)+(j<<1)>>1]=b[(c[277225]|0)+((f&255)<<1)>>1]|0;if((a[1108928]|0)==0){an=b[(c[277213]|0)+(j+2<<1)>>1]|0}else{an=0}f=j+1|0;b[(c[277218]|0)+(f<<1)>>1]=an;r=a[1108909]|0;a[(c[277219]|0)+f|0]=r;a[(c[277219]|0)+j|0]=r}}while(0);if(!N){ao=h;u=6551}break};case 3:{ap=i;u=6563;break};case 7:{u=6587;break};case 1:{ao=i;u=6551;break};case 6:{aq=i;u=6581;break};default:{}}if((u|0)==6551){u=0;r=j+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+r|0]|0)){f=a[X+1|0]|0;if(f<<24>>24==0){break}b[(c[277218]|0)+(r<<1)>>1]=b[(c[277225]|0)+((f&255)<<1)>>1]|0;if((a[1108928]|0)==0){ar=b[(c[277213]|0)+(j+4<<1)>>1]|0}else{ar=0}f=j+3|0;b[(c[277218]|0)+(f<<1)>>1]=ar;aj=a[1108909]|0;a[(c[277219]|0)+f|0]=aj;a[(c[277219]|0)+r|0]=aj}}while(0);r=ao-1&255;if(r<<24>>24!=0){al=r;u=6557}}if((u|0)==6557){u=0;r=j+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+r|0]|0)){aj=a[X+2|0]|0;if(aj<<24>>24==0){break}b[(c[277218]|0)+(r<<1)>>1]=b[(c[277225]|0)+((aj&255)<<1)>>1]|0;if((a[1108928]|0)==0){as=b[(c[277213]|0)+(j+6<<1)>>1]|0}else{as=0}aj=j+5|0;b[(c[277218]|0)+(aj<<1)>>1]=as;f=a[1108909]|0;a[(c[277219]|0)+aj|0]=f;a[(c[277219]|0)+r|0]=f}}while(0);r=al-1&255;if(r<<24>>24!=0){ap=r;u=6563}}if((u|0)==6563){u=0;r=j+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+r|0]|0)){f=a[X+3|0]|0;if(f<<24>>24==0){break}b[(c[277218]|0)+(r<<1)>>1]=b[(c[277225]|0)+((f&255)<<1)>>1]|0;if((a[1108928]|0)==0){at=b[(c[277213]|0)+(j+8<<1)>>1]|0}else{at=0}f=j+7|0;b[(c[277218]|0)+(f<<1)>>1]=at;aj=a[1108909]|0;a[(c[277219]|0)+f|0]=aj;a[(c[277219]|0)+r|0]=aj}}while(0);r=ap-1&255;if(r<<24>>24!=0){am=r;u=6569}}if((u|0)==6569){u=0;r=j+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+r|0]|0)){aj=a[X+4|0]|0;if(aj<<24>>24==0){break}b[(c[277218]|0)+(r<<1)>>1]=b[(c[277225]|0)+((aj&255)<<1)>>1]|0;if((a[1108928]|0)==0){au=b[(c[277213]|0)+(j+10<<1)>>1]|0}else{au=0}aj=j+9|0;b[(c[277218]|0)+(aj<<1)>>1]=au;f=a[1108909]|0;a[(c[277219]|0)+aj|0]=f;a[(c[277219]|0)+r|0]=f}}while(0);r=am-1&255;if(r<<24>>24!=0){ak=r;u=6575}}if((u|0)==6575){u=0;r=j+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+r|0]|0)){f=a[X+5|0]|0;if(f<<24>>24==0){break}b[(c[277218]|0)+(r<<1)>>1]=b[(c[277225]|0)+((f&255)<<1)>>1]|0;if((a[1108928]|0)==0){av=b[(c[277213]|0)+(j+12<<1)>>1]|0}else{av=0}f=j+11|0;b[(c[277218]|0)+(f<<1)>>1]=av;aj=a[1108909]|0;a[(c[277219]|0)+f|0]=aj;a[(c[277219]|0)+r|0]=aj}}while(0);r=ak-1&255;if(r<<24>>24!=0){aq=r;u=6581}}if((u|0)==6581){u=0;r=j+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+r|0]|0)){aj=a[X+6|0]|0;if(aj<<24>>24==0){break}b[(c[277218]|0)+(r<<1)>>1]=b[(c[277225]|0)+((aj&255)<<1)>>1]|0;if((a[1108928]|0)==0){aw=b[(c[277213]|0)+(j+14<<1)>>1]|0}else{aw=0}aj=j+13|0;b[(c[277218]|0)+(aj<<1)>>1]=aw;f=a[1108909]|0;a[(c[277219]|0)+aj|0]=f;a[(c[277219]|0)+r|0]=f}}while(0);if(aq<<24>>24!=1){u=6587}}do{if((u|0)==6587){u=0;r=j+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+r|0]|0)){break}f=a[X+7|0]|0;if(f<<24>>24==0){break}b[(c[277218]|0)+(r<<1)>>1]=b[(c[277225]|0)+((f&255)<<1)>>1]|0;if((a[1108928]|0)==0){ax=b[(c[277213]|0)+(j+16<<1)>>1]|0}else{ax=0}f=j+15|0;b[(c[277218]|0)+(f<<1)>>1]=ax;aj=a[1108909]|0;a[(c[277219]|0)+f|0]=aj;a[(c[277219]|0)+r|0]=aj}}while(0);aj=w-1|0;if((aj|0)>0){X=X-8|0;w=aj;j=(c[277223]|0)+j|0}else{break}}return}}function VB(f,g,h,i,j,k){f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0,cf=0,cg=0,ch=0,ci=0,cj=0,ck=0,cl=0,cm=0,cn=0,co=0,cp=0,cq=0,cr=0,cs=0,ct=0,cu=0,cv=0,cw=0,cx=0,cy=0,cz=0,cA=0,cB=0,cC=0,cD=0,cE=0,cF=0,cG=0,cH=0,cI=0,cJ=0,cK=0,cL=0,cM=0,cN=0,cO=0,cP=0,cQ=0,cR=0,cS=0,cT=0,cU=0,cV=0,cW=0,cX=0,cY=0,cZ=0,c_=0,c$=0,c0=0,c1=0,c2=0,c3=0,c4=0,c5=0,c6=0,c7=0,c8=0,c9=0,da=0,db=0,dc=0,dd=0,de=0,df=0,dg=0,dh=0,di=0,dj=0,dk=0,dl=0,dm=0,dn=0,dp=0,dq=0,dr=0,ds=0,dt=0,du=0,dv=0,dw=0,dx=0,dy=0,dz=0,dA=0,dB=0,dC=0,dD=0,dE=0,dF=0,dG=0,dH=0,dI=0,dJ=0,dK=0,dL=0,dM=0,dN=0,dO=0,dP=0,dQ=0,dR=0,dS=0,dT=0,dU=0,dV=0,dW=0,dX=0,dY=0,dZ=0,d_=0,d$=0,d0=0,d1=0,d2=0,d3=0,d4=0,d5=0,d6=0,d7=0,d8=0,d9=0,ea=0,eb=0,ec=0,ed=0,ee=0,ef=0,eg=0,eh=0,ei=0,ej=0,ek=0,el=0,em=0,en=0,eo=0,ep=0,eq=0,er=0,es=0,et=0,eu=0,ev=0,ew=0,ex=0,ey=0,ez=0,eA=0,eB=0;l=f&1023;m=c[348606]|0;n=(l<<m)+(c[348604]|0)|0;if((f&256|0)==0){o=n}else{o=(c[348602]|0)+n|0}n=o&65535;o=n>>>(m>>>0);m=(f&16384|0)!=0;p=o<<6;do{if(m){q=(c[348622]|0)+p|0;if((a[(c[348618]|0)+o|0]|0)!=0){r=q;break}s=fi[c[348636]&63](q,n,l)|0;a[(c[348618]|0)+o|0]=s;r=q}else{q=(c[348624]|0)+p|0;if((a[(c[348620]|0)+o|0]|0)!=0){r=q;break}s=fi[c[348638]&63](q,n,l)|0;a[(c[348620]|0)+o|0]=s;r=q}}while(0);if((a[(c[348620]|0)+o|0]|0)==2){return}if((a[1394464]|0)==0){t=1106168+((f>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){o=d[1044485]|0;c[276541]=7080+(o<<5);l=0;do{n=l<<1&2;p=l&2;q=l&4;s=0;do{b[1125528+(l<<9)+(s<<1)>>1]=d[(s>>>1&28|p)+(7080+(o<<5))|0]<<6|d[(s<<2&28|n)+(7080+(o<<5))|0]<<11|d[(s>>>3&24|q)+(7080+(o<<5))|0];s=s+1|0;}while(s>>>0<256);l=l+1|0;}while(l>>>0<8);a[1106089]=0}t=1125528+((f>>>10&7)<<9)|0}c[277226]=t;c[277225]=(a[1108928]|0)!=0?1393712:t;if((f&49152|0)==0){if((k|0)<=0){return}t=i&255;l=t-1&255;o=l<<24>>24==0;s=r+j|0;q=k;n=g;while(1){switch(h|0){case 1:{u=t;v=6698;break};case 6:{w=t;v=6823;break};case 7:{v=6848;break};case 4:{x=t;v=6773;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+n|0]|0)){p=a[s]|0;y=p&255;if(p<<24>>24==0){break}p=e[(c[277225]|0)+(y<<1)>>1]|0;z=(a[(c[277215]|0)+n|0]&32)==0;if(z){A=c[277228]|0;B=A;C=A&-2082}else{A=e[(c[277213]|0)+(n<<1)>>1]|0;B=A;C=A&63454}if(z){D=c[277228]|0}else{D=e[(c[277213]|0)+(n<<1)>>1]|0}b[(c[277218]|0)+(n<<1)>>1]=((D^p)&2081|e[(c[277220]|0)+((p&2081&B)+((C+(p&63454)|0)>>>1)<<1)>>1])&65535;p=(a[1108928]|0)==0;if(p){E=b[(c[277213]|0)+(n+2<<1)>>1]&63454}else{E=0}z=(a[(c[277215]|0)+n|0]&32)==0;if(z){F=c[277228]|0}else{F=e[(c[277226]|0)+(y<<1)>>1]|0}if(p){G=b[(c[277213]|0)+(n+2<<1)>>1]&2081}else{G=0}if(z){H=c[277228]|0}else{H=e[(c[277226]|0)+(y<<1)>>1]|0}if(p){I=e[(c[277213]|0)+(n+2<<1)>>1]|0}else{I=0}if(z){J=c[277228]|0}else{J=e[(c[277226]|0)+(y<<1)>>1]|0}y=n+1|0;b[(c[277218]|0)+(y<<1)>>1]=((J^I)&2081|e[(c[277220]|0)+((H&G)+(((F&-2082)+E|0)>>>1)<<1)>>1])&65535;z=a[1108909]|0;a[(c[277219]|0)+y|0]=z;a[(c[277219]|0)+n|0]=z}}while(0);if(!o){u=l;v=6698}break};case 3:{K=t;v=6748;break};case 2:{L=t;v=6723;break};case 5:{M=t;v=6798;break};default:{}}if((v|0)==6698){v=0;z=n+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+z|0]|0)){y=a[s+1|0]|0;p=y&255;if(y<<24>>24==0){break}y=e[(c[277225]|0)+(p<<1)>>1]|0;A=(a[(c[277215]|0)+z|0]&32)==0;if(A){N=c[277228]|0;O=N;P=N&-2082}else{N=e[(c[277213]|0)+(z<<1)>>1]|0;O=N;P=N&63454}if(A){Q=c[277228]|0}else{Q=e[(c[277213]|0)+(z<<1)>>1]|0}b[(c[277218]|0)+(z<<1)>>1]=((Q^y)&2081|e[(c[277220]|0)+((y&2081&O)+((P+(y&63454)|0)>>>1)<<1)>>1])&65535;y=(a[1108928]|0)==0;if(y){R=b[(c[277213]|0)+(n+4<<1)>>1]&63454}else{R=0}A=(a[(c[277215]|0)+z|0]&32)==0;if(A){S=c[277228]|0}else{S=e[(c[277226]|0)+(p<<1)>>1]|0}if(y){T=b[(c[277213]|0)+(n+4<<1)>>1]&2081}else{T=0}if(A){U=c[277228]|0}else{U=e[(c[277226]|0)+(p<<1)>>1]|0}if(y){V=e[(c[277213]|0)+(n+4<<1)>>1]|0}else{V=0}if(A){W=c[277228]|0}else{W=e[(c[277226]|0)+(p<<1)>>1]|0}p=n+3|0;b[(c[277218]|0)+(p<<1)>>1]=((W^V)&2081|e[(c[277220]|0)+((U&T)+(((S&-2082)+R|0)>>>1)<<1)>>1])&65535;A=a[1108909]|0;a[(c[277219]|0)+p|0]=A;a[(c[277219]|0)+z|0]=A}}while(0);z=u-1&255;if(z<<24>>24!=0){L=z;v=6723}}if((v|0)==6723){v=0;z=n+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+z|0]|0)){A=a[s+2|0]|0;p=A&255;if(A<<24>>24==0){break}A=e[(c[277225]|0)+(p<<1)>>1]|0;y=(a[(c[277215]|0)+z|0]&32)==0;if(y){N=c[277228]|0;X=N;Y=N&-2082}else{N=e[(c[277213]|0)+(z<<1)>>1]|0;X=N;Y=N&63454}if(y){Z=c[277228]|0}else{Z=e[(c[277213]|0)+(z<<1)>>1]|0}b[(c[277218]|0)+(z<<1)>>1]=((Z^A)&2081|e[(c[277220]|0)+((A&2081&X)+((Y+(A&63454)|0)>>>1)<<1)>>1])&65535;A=(a[1108928]|0)==0;if(A){_=b[(c[277213]|0)+(n+6<<1)>>1]&63454}else{_=0}y=(a[(c[277215]|0)+z|0]&32)==0;if(y){$=c[277228]|0}else{$=e[(c[277226]|0)+(p<<1)>>1]|0}if(A){aa=b[(c[277213]|0)+(n+6<<1)>>1]&2081}else{aa=0}if(y){ab=c[277228]|0}else{ab=e[(c[277226]|0)+(p<<1)>>1]|0}if(A){ac=e[(c[277213]|0)+(n+6<<1)>>1]|0}else{ac=0}if(y){ad=c[277228]|0}else{ad=e[(c[277226]|0)+(p<<1)>>1]|0}p=n+5|0;b[(c[277218]|0)+(p<<1)>>1]=((ad^ac)&2081|e[(c[277220]|0)+((ab&aa)+((($&-2082)+_|0)>>>1)<<1)>>1])&65535;y=a[1108909]|0;a[(c[277219]|0)+p|0]=y;a[(c[277219]|0)+z|0]=y}}while(0);z=L-1&255;if(z<<24>>24!=0){K=z;v=6748}}if((v|0)==6748){v=0;z=n+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+z|0]|0)){y=a[s+3|0]|0;p=y&255;if(y<<24>>24==0){break}y=e[(c[277225]|0)+(p<<1)>>1]|0;A=(a[(c[277215]|0)+z|0]&32)==0;if(A){N=c[277228]|0;ae=N;af=N&-2082}else{N=e[(c[277213]|0)+(z<<1)>>1]|0;ae=N;af=N&63454}if(A){ag=c[277228]|0}else{ag=e[(c[277213]|0)+(z<<1)>>1]|0}b[(c[277218]|0)+(z<<1)>>1]=((ag^y)&2081|e[(c[277220]|0)+((y&2081&ae)+((af+(y&63454)|0)>>>1)<<1)>>1])&65535;y=(a[1108928]|0)==0;if(y){ah=b[(c[277213]|0)+(n+8<<1)>>1]&63454}else{ah=0}A=(a[(c[277215]|0)+z|0]&32)==0;if(A){ai=c[277228]|0}else{ai=e[(c[277226]|0)+(p<<1)>>1]|0}if(y){aj=b[(c[277213]|0)+(n+8<<1)>>1]&2081}else{aj=0}if(A){ak=c[277228]|0}else{ak=e[(c[277226]|0)+(p<<1)>>1]|0}if(y){al=e[(c[277213]|0)+(n+8<<1)>>1]|0}else{al=0}if(A){am=c[277228]|0}else{am=e[(c[277226]|0)+(p<<1)>>1]|0}p=n+7|0;b[(c[277218]|0)+(p<<1)>>1]=((am^al)&2081|e[(c[277220]|0)+((ak&aj)+(((ai&-2082)+ah|0)>>>1)<<1)>>1])&65535;A=a[1108909]|0;a[(c[277219]|0)+p|0]=A;a[(c[277219]|0)+z|0]=A}}while(0);z=K-1&255;if(z<<24>>24!=0){x=z;v=6773}}if((v|0)==6773){v=0;z=n+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+z|0]|0)){A=a[s+4|0]|0;p=A&255;if(A<<24>>24==0){break}A=e[(c[277225]|0)+(p<<1)>>1]|0;y=(a[(c[277215]|0)+z|0]&32)==0;if(y){N=c[277228]|0;an=N;ao=N&-2082}else{N=e[(c[277213]|0)+(z<<1)>>1]|0;an=N;ao=N&63454}if(y){ap=c[277228]|0}else{ap=e[(c[277213]|0)+(z<<1)>>1]|0}b[(c[277218]|0)+(z<<1)>>1]=((ap^A)&2081|e[(c[277220]|0)+((A&2081&an)+((ao+(A&63454)|0)>>>1)<<1)>>1])&65535;A=(a[1108928]|0)==0;if(A){aq=b[(c[277213]|0)+(n+10<<1)>>1]&63454}else{aq=0}y=(a[(c[277215]|0)+z|0]&32)==0;if(y){ar=c[277228]|0}else{ar=e[(c[277226]|0)+(p<<1)>>1]|0}if(A){as=b[(c[277213]|0)+(n+10<<1)>>1]&2081}else{as=0}if(y){at=c[277228]|0}else{at=e[(c[277226]|0)+(p<<1)>>1]|0}if(A){au=e[(c[277213]|0)+(n+10<<1)>>1]|0}else{au=0}if(y){av=c[277228]|0}else{av=e[(c[277226]|0)+(p<<1)>>1]|0}p=n+9|0;b[(c[277218]|0)+(p<<1)>>1]=((av^au)&2081|e[(c[277220]|0)+((at&as)+(((ar&-2082)+aq|0)>>>1)<<1)>>1])&65535;y=a[1108909]|0;a[(c[277219]|0)+p|0]=y;a[(c[277219]|0)+z|0]=y}}while(0);z=x-1&255;if(z<<24>>24!=0){M=z;v=6798}}if((v|0)==6798){v=0;z=n+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+z|0]|0)){y=a[s+5|0]|0;p=y&255;if(y<<24>>24==0){break}y=e[(c[277225]|0)+(p<<1)>>1]|0;A=(a[(c[277215]|0)+z|0]&32)==0;if(A){N=c[277228]|0;aw=N;ax=N&-2082}else{N=e[(c[277213]|0)+(z<<1)>>1]|0;aw=N;ax=N&63454}if(A){ay=c[277228]|0}else{ay=e[(c[277213]|0)+(z<<1)>>1]|0}b[(c[277218]|0)+(z<<1)>>1]=((ay^y)&2081|e[(c[277220]|0)+((y&2081&aw)+((ax+(y&63454)|0)>>>1)<<1)>>1])&65535;y=(a[1108928]|0)==0;if(y){az=b[(c[277213]|0)+(n+12<<1)>>1]&63454}else{az=0}A=(a[(c[277215]|0)+z|0]&32)==0;if(A){aA=c[277228]|0}else{aA=e[(c[277226]|0)+(p<<1)>>1]|0}if(y){aB=b[(c[277213]|0)+(n+12<<1)>>1]&2081}else{aB=0}if(A){aC=c[277228]|0}else{aC=e[(c[277226]|0)+(p<<1)>>1]|0}if(y){aD=e[(c[277213]|0)+(n+12<<1)>>1]|0}else{aD=0}if(A){aE=c[277228]|0}else{aE=e[(c[277226]|0)+(p<<1)>>1]|0}p=n+11|0;b[(c[277218]|0)+(p<<1)>>1]=((aE^aD)&2081|e[(c[277220]|0)+((aC&aB)+(((aA&-2082)+az|0)>>>1)<<1)>>1])&65535;A=a[1108909]|0;a[(c[277219]|0)+p|0]=A;a[(c[277219]|0)+z|0]=A}}while(0);z=M-1&255;if(z<<24>>24!=0){w=z;v=6823}}if((v|0)==6823){v=0;z=n+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+z|0]|0)){A=a[s+6|0]|0;p=A&255;if(A<<24>>24==0){break}A=e[(c[277225]|0)+(p<<1)>>1]|0;y=(a[(c[277215]|0)+z|0]&32)==0;if(y){N=c[277228]|0;aF=N;aG=N&-2082}else{N=e[(c[277213]|0)+(z<<1)>>1]|0;aF=N;aG=N&63454}if(y){aH=c[277228]|0}else{aH=e[(c[277213]|0)+(z<<1)>>1]|0}b[(c[277218]|0)+(z<<1)>>1]=((aH^A)&2081|e[(c[277220]|0)+((A&2081&aF)+((aG+(A&63454)|0)>>>1)<<1)>>1])&65535;A=(a[1108928]|0)==0;if(A){aI=b[(c[277213]|0)+(n+14<<1)>>1]&63454}else{aI=0}y=(a[(c[277215]|0)+z|0]&32)==0;if(y){aJ=c[277228]|0}else{aJ=e[(c[277226]|0)+(p<<1)>>1]|0}if(A){aK=b[(c[277213]|0)+(n+14<<1)>>1]&2081}else{aK=0}if(y){aL=c[277228]|0}else{aL=e[(c[277226]|0)+(p<<1)>>1]|0}if(A){aM=e[(c[277213]|0)+(n+14<<1)>>1]|0}else{aM=0}if(y){aN=c[277228]|0}else{aN=e[(c[277226]|0)+(p<<1)>>1]|0}p=n+13|0;b[(c[277218]|0)+(p<<1)>>1]=((aN^aM)&2081|e[(c[277220]|0)+((aL&aK)+(((aJ&-2082)+aI|0)>>>1)<<1)>>1])&65535;y=a[1108909]|0;a[(c[277219]|0)+p|0]=y;a[(c[277219]|0)+z|0]=y}}while(0);if(w<<24>>24!=1){v=6848}}do{if((v|0)==6848){v=0;z=n+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+z|0]|0)){break}y=a[s+7|0]|0;p=y&255;if(y<<24>>24==0){break}y=e[(c[277225]|0)+(p<<1)>>1]|0;A=(a[(c[277215]|0)+z|0]&32)==0;if(A){N=c[277228]|0;aO=N;aP=N&-2082}else{N=e[(c[277213]|0)+(z<<1)>>1]|0;aO=N;aP=N&63454}if(A){aQ=c[277228]|0}else{aQ=e[(c[277213]|0)+(z<<1)>>1]|0}b[(c[277218]|0)+(z<<1)>>1]=((aQ^y)&2081|e[(c[277220]|0)+((y&2081&aO)+((aP+(y&63454)|0)>>>1)<<1)>>1])&65535;y=(a[1108928]|0)==0;if(y){aR=b[(c[277213]|0)+(n+16<<1)>>1]&63454}else{aR=0}A=(a[(c[277215]|0)+z|0]&32)==0;if(A){aS=c[277228]|0}else{aS=e[(c[277226]|0)+(p<<1)>>1]|0}if(y){aT=b[(c[277213]|0)+(n+16<<1)>>1]&2081}else{aT=0}if(A){aU=c[277228]|0}else{aU=e[(c[277226]|0)+(p<<1)>>1]|0}if(y){aV=e[(c[277213]|0)+(n+16<<1)>>1]|0}else{aV=0}if(A){aW=c[277228]|0}else{aW=e[(c[277226]|0)+(p<<1)>>1]|0}p=n+15|0;b[(c[277218]|0)+(p<<1)>>1]=((aW^aV)&2081|e[(c[277220]|0)+((aU&aT)+(((aS&-2082)+aR|0)>>>1)<<1)>>1])&65535;A=a[1108909]|0;a[(c[277219]|0)+p|0]=A;a[(c[277219]|0)+z|0]=A}}while(0);A=q-1|0;if((A|0)>0){s=s+8|0;q=A;n=(c[277223]|0)+n|0}else{break}}return}if((f&32768|0)==0){if((k|0)<=0){return}f=i&255;n=f-1&255;q=n<<24>>24==0;s=r+j|0;aR=k;aS=g;while(1){switch(h|0){case 5:{aX=f;v=7002;break};case 7:{v=7052;break};case 6:{aY=f;v=7027;break};case 1:{aZ=f;v=6902;break};case 2:{a_=f;v=6927;break};case 3:{a$=f;v=6952;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+aS|0]|0)){aT=a[s+7|0]|0;aU=aT&255;if(aT<<24>>24==0){break}aT=e[(c[277225]|0)+(aU<<1)>>1]|0;aV=(a[(c[277215]|0)+aS|0]&32)==0;if(aV){aW=c[277228]|0;a0=aW;a1=aW&-2082}else{aW=e[(c[277213]|0)+(aS<<1)>>1]|0;a0=aW;a1=aW&63454}if(aV){a2=c[277228]|0}else{a2=e[(c[277213]|0)+(aS<<1)>>1]|0}b[(c[277218]|0)+(aS<<1)>>1]=((a2^aT)&2081|e[(c[277220]|0)+((aT&2081&a0)+((a1+(aT&63454)|0)>>>1)<<1)>>1])&65535;aT=(a[1108928]|0)==0;if(aT){a3=b[(c[277213]|0)+(aS+2<<1)>>1]&63454}else{a3=0}aV=(a[(c[277215]|0)+aS|0]&32)==0;if(aV){a4=c[277228]|0}else{a4=e[(c[277226]|0)+(aU<<1)>>1]|0}if(aT){a5=b[(c[277213]|0)+(aS+2<<1)>>1]&2081}else{a5=0}if(aV){a6=c[277228]|0}else{a6=e[(c[277226]|0)+(aU<<1)>>1]|0}if(aT){a7=e[(c[277213]|0)+(aS+2<<1)>>1]|0}else{a7=0}if(aV){a8=c[277228]|0}else{a8=e[(c[277226]|0)+(aU<<1)>>1]|0}aU=aS+1|0;b[(c[277218]|0)+(aU<<1)>>1]=((a8^a7)&2081|e[(c[277220]|0)+((a6&a5)+(((a4&-2082)+a3|0)>>>1)<<1)>>1])&65535;aV=a[1108909]|0;a[(c[277219]|0)+aU|0]=aV;a[(c[277219]|0)+aS|0]=aV}}while(0);if(!q){aZ=n;v=6902}break};case 4:{a9=f;v=6977;break};default:{}}if((v|0)==6902){v=0;aV=aS+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+aV|0]|0)){aU=a[s+6|0]|0;aT=aU&255;if(aU<<24>>24==0){break}aU=e[(c[277225]|0)+(aT<<1)>>1]|0;aW=(a[(c[277215]|0)+aV|0]&32)==0;if(aW){aP=c[277228]|0;ba=aP;bb=aP&-2082}else{aP=e[(c[277213]|0)+(aV<<1)>>1]|0;ba=aP;bb=aP&63454}if(aW){bc=c[277228]|0}else{bc=e[(c[277213]|0)+(aV<<1)>>1]|0}b[(c[277218]|0)+(aV<<1)>>1]=((bc^aU)&2081|e[(c[277220]|0)+((aU&2081&ba)+((bb+(aU&63454)|0)>>>1)<<1)>>1])&65535;aU=(a[1108928]|0)==0;if(aU){bd=b[(c[277213]|0)+(aS+4<<1)>>1]&63454}else{bd=0}aW=(a[(c[277215]|0)+aV|0]&32)==0;if(aW){be=c[277228]|0}else{be=e[(c[277226]|0)+(aT<<1)>>1]|0}if(aU){bf=b[(c[277213]|0)+(aS+4<<1)>>1]&2081}else{bf=0}if(aW){bg=c[277228]|0}else{bg=e[(c[277226]|0)+(aT<<1)>>1]|0}if(aU){bh=e[(c[277213]|0)+(aS+4<<1)>>1]|0}else{bh=0}if(aW){bi=c[277228]|0}else{bi=e[(c[277226]|0)+(aT<<1)>>1]|0}aT=aS+3|0;b[(c[277218]|0)+(aT<<1)>>1]=((bi^bh)&2081|e[(c[277220]|0)+((bg&bf)+(((be&-2082)+bd|0)>>>1)<<1)>>1])&65535;aW=a[1108909]|0;a[(c[277219]|0)+aT|0]=aW;a[(c[277219]|0)+aV|0]=aW}}while(0);aV=aZ-1&255;if(aV<<24>>24!=0){a_=aV;v=6927}}if((v|0)==6927){v=0;aV=aS+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+aV|0]|0)){aW=a[s+5|0]|0;aT=aW&255;if(aW<<24>>24==0){break}aW=e[(c[277225]|0)+(aT<<1)>>1]|0;aU=(a[(c[277215]|0)+aV|0]&32)==0;if(aU){aP=c[277228]|0;bj=aP;bk=aP&-2082}else{aP=e[(c[277213]|0)+(aV<<1)>>1]|0;bj=aP;bk=aP&63454}if(aU){bl=c[277228]|0}else{bl=e[(c[277213]|0)+(aV<<1)>>1]|0}b[(c[277218]|0)+(aV<<1)>>1]=((bl^aW)&2081|e[(c[277220]|0)+((aW&2081&bj)+((bk+(aW&63454)|0)>>>1)<<1)>>1])&65535;aW=(a[1108928]|0)==0;if(aW){bm=b[(c[277213]|0)+(aS+6<<1)>>1]&63454}else{bm=0}aU=(a[(c[277215]|0)+aV|0]&32)==0;if(aU){bn=c[277228]|0}else{bn=e[(c[277226]|0)+(aT<<1)>>1]|0}if(aW){bo=b[(c[277213]|0)+(aS+6<<1)>>1]&2081}else{bo=0}if(aU){bp=c[277228]|0}else{bp=e[(c[277226]|0)+(aT<<1)>>1]|0}if(aW){bq=e[(c[277213]|0)+(aS+6<<1)>>1]|0}else{bq=0}if(aU){br=c[277228]|0}else{br=e[(c[277226]|0)+(aT<<1)>>1]|0}aT=aS+5|0;b[(c[277218]|0)+(aT<<1)>>1]=((br^bq)&2081|e[(c[277220]|0)+((bp&bo)+(((bn&-2082)+bm|0)>>>1)<<1)>>1])&65535;aU=a[1108909]|0;a[(c[277219]|0)+aT|0]=aU;a[(c[277219]|0)+aV|0]=aU}}while(0);aV=a_-1&255;if(aV<<24>>24!=0){a$=aV;v=6952}}if((v|0)==6952){v=0;aV=aS+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+aV|0]|0)){aU=a[s+4|0]|0;aT=aU&255;if(aU<<24>>24==0){break}aU=e[(c[277225]|0)+(aT<<1)>>1]|0;aW=(a[(c[277215]|0)+aV|0]&32)==0;if(aW){aP=c[277228]|0;bs=aP;bt=aP&-2082}else{aP=e[(c[277213]|0)+(aV<<1)>>1]|0;bs=aP;bt=aP&63454}if(aW){bu=c[277228]|0}else{bu=e[(c[277213]|0)+(aV<<1)>>1]|0}b[(c[277218]|0)+(aV<<1)>>1]=((bu^aU)&2081|e[(c[277220]|0)+((aU&2081&bs)+((bt+(aU&63454)|0)>>>1)<<1)>>1])&65535;aU=(a[1108928]|0)==0;if(aU){bv=b[(c[277213]|0)+(aS+8<<1)>>1]&63454}else{bv=0}aW=(a[(c[277215]|0)+aV|0]&32)==0;if(aW){bw=c[277228]|0}else{bw=e[(c[277226]|0)+(aT<<1)>>1]|0}if(aU){bx=b[(c[277213]|0)+(aS+8<<1)>>1]&2081}else{bx=0}if(aW){by=c[277228]|0}else{by=e[(c[277226]|0)+(aT<<1)>>1]|0}if(aU){bz=e[(c[277213]|0)+(aS+8<<1)>>1]|0}else{bz=0}if(aW){bA=c[277228]|0}else{bA=e[(c[277226]|0)+(aT<<1)>>1]|0}aT=aS+7|0;b[(c[277218]|0)+(aT<<1)>>1]=((bA^bz)&2081|e[(c[277220]|0)+((by&bx)+(((bw&-2082)+bv|0)>>>1)<<1)>>1])&65535;aW=a[1108909]|0;a[(c[277219]|0)+aT|0]=aW;a[(c[277219]|0)+aV|0]=aW}}while(0);aV=a$-1&255;if(aV<<24>>24!=0){a9=aV;v=6977}}if((v|0)==6977){v=0;aV=aS+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+aV|0]|0)){aW=a[s+3|0]|0;aT=aW&255;if(aW<<24>>24==0){break}aW=e[(c[277225]|0)+(aT<<1)>>1]|0;aU=(a[(c[277215]|0)+aV|0]&32)==0;if(aU){aP=c[277228]|0;bB=aP;bC=aP&-2082}else{aP=e[(c[277213]|0)+(aV<<1)>>1]|0;bB=aP;bC=aP&63454}if(aU){bD=c[277228]|0}else{bD=e[(c[277213]|0)+(aV<<1)>>1]|0}b[(c[277218]|0)+(aV<<1)>>1]=((bD^aW)&2081|e[(c[277220]|0)+((aW&2081&bB)+((bC+(aW&63454)|0)>>>1)<<1)>>1])&65535;aW=(a[1108928]|0)==0;if(aW){bE=b[(c[277213]|0)+(aS+10<<1)>>1]&63454}else{bE=0}aU=(a[(c[277215]|0)+aV|0]&32)==0;if(aU){bF=c[277228]|0}else{bF=e[(c[277226]|0)+(aT<<1)>>1]|0}if(aW){bG=b[(c[277213]|0)+(aS+10<<1)>>1]&2081}else{bG=0}if(aU){bH=c[277228]|0}else{bH=e[(c[277226]|0)+(aT<<1)>>1]|0}if(aW){bI=e[(c[277213]|0)+(aS+10<<1)>>1]|0}else{bI=0}if(aU){bJ=c[277228]|0}else{bJ=e[(c[277226]|0)+(aT<<1)>>1]|0}aT=aS+9|0;b[(c[277218]|0)+(aT<<1)>>1]=((bJ^bI)&2081|e[(c[277220]|0)+((bH&bG)+(((bF&-2082)+bE|0)>>>1)<<1)>>1])&65535;aU=a[1108909]|0;a[(c[277219]|0)+aT|0]=aU;a[(c[277219]|0)+aV|0]=aU}}while(0);aV=a9-1&255;if(aV<<24>>24!=0){aX=aV;v=7002}}if((v|0)==7002){v=0;aV=aS+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+aV|0]|0)){aU=a[s+2|0]|0;aT=aU&255;if(aU<<24>>24==0){break}aU=e[(c[277225]|0)+(aT<<1)>>1]|0;aW=(a[(c[277215]|0)+aV|0]&32)==0;if(aW){aP=c[277228]|0;bK=aP;bL=aP&-2082}else{aP=e[(c[277213]|0)+(aV<<1)>>1]|0;bK=aP;bL=aP&63454}if(aW){bM=c[277228]|0}else{bM=e[(c[277213]|0)+(aV<<1)>>1]|0}b[(c[277218]|0)+(aV<<1)>>1]=((bM^aU)&2081|e[(c[277220]|0)+((aU&2081&bK)+((bL+(aU&63454)|0)>>>1)<<1)>>1])&65535;aU=(a[1108928]|0)==0;if(aU){bN=b[(c[277213]|0)+(aS+12<<1)>>1]&63454}else{bN=0}aW=(a[(c[277215]|0)+aV|0]&32)==0;if(aW){bO=c[277228]|0}else{bO=e[(c[277226]|0)+(aT<<1)>>1]|0}if(aU){bP=b[(c[277213]|0)+(aS+12<<1)>>1]&2081}else{bP=0}if(aW){bQ=c[277228]|0}else{bQ=e[(c[277226]|0)+(aT<<1)>>1]|0}if(aU){bR=e[(c[277213]|0)+(aS+12<<1)>>1]|0}else{bR=0}if(aW){bS=c[277228]|0}else{bS=e[(c[277226]|0)+(aT<<1)>>1]|0}aT=aS+11|0;b[(c[277218]|0)+(aT<<1)>>1]=((bS^bR)&2081|e[(c[277220]|0)+((bQ&bP)+(((bO&-2082)+bN|0)>>>1)<<1)>>1])&65535;aW=a[1108909]|0;a[(c[277219]|0)+aT|0]=aW;a[(c[277219]|0)+aV|0]=aW}}while(0);aV=aX-1&255;if(aV<<24>>24!=0){aY=aV;v=7027}}if((v|0)==7027){v=0;aV=aS+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+aV|0]|0)){aW=a[s+1|0]|0;aT=aW&255;if(aW<<24>>24==0){break}aW=e[(c[277225]|0)+(aT<<1)>>1]|0;aU=(a[(c[277215]|0)+aV|0]&32)==0;if(aU){aP=c[277228]|0;bT=aP;bU=aP&-2082}else{aP=e[(c[277213]|0)+(aV<<1)>>1]|0;bT=aP;bU=aP&63454}if(aU){bV=c[277228]|0}else{bV=e[(c[277213]|0)+(aV<<1)>>1]|0}b[(c[277218]|0)+(aV<<1)>>1]=((bV^aW)&2081|e[(c[277220]|0)+((aW&2081&bT)+((bU+(aW&63454)|0)>>>1)<<1)>>1])&65535;aW=(a[1108928]|0)==0;if(aW){bW=b[(c[277213]|0)+(aS+14<<1)>>1]&63454}else{bW=0}aU=(a[(c[277215]|0)+aV|0]&32)==0;if(aU){bX=c[277228]|0}else{bX=e[(c[277226]|0)+(aT<<1)>>1]|0}if(aW){bY=b[(c[277213]|0)+(aS+14<<1)>>1]&2081}else{bY=0}if(aU){bZ=c[277228]|0}else{bZ=e[(c[277226]|0)+(aT<<1)>>1]|0}if(aW){b_=e[(c[277213]|0)+(aS+14<<1)>>1]|0}else{b_=0}if(aU){b$=c[277228]|0}else{b$=e[(c[277226]|0)+(aT<<1)>>1]|0}aT=aS+13|0;b[(c[277218]|0)+(aT<<1)>>1]=((b$^b_)&2081|e[(c[277220]|0)+((bZ&bY)+(((bX&-2082)+bW|0)>>>1)<<1)>>1])&65535;aU=a[1108909]|0;a[(c[277219]|0)+aT|0]=aU;a[(c[277219]|0)+aV|0]=aU}}while(0);if(aY<<24>>24!=1){v=7052}}do{if((v|0)==7052){v=0;aV=aS+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+aV|0]|0)){break}aU=a[s]|0;aT=aU&255;if(aU<<24>>24==0){break}aU=e[(c[277225]|0)+(aT<<1)>>1]|0;aW=(a[(c[277215]|0)+aV|0]&32)==0;if(aW){aP=c[277228]|0;b0=aP;b1=aP&-2082}else{aP=e[(c[277213]|0)+(aV<<1)>>1]|0;b0=aP;b1=aP&63454}if(aW){b2=c[277228]|0}else{b2=e[(c[277213]|0)+(aV<<1)>>1]|0}b[(c[277218]|0)+(aV<<1)>>1]=((b2^aU)&2081|e[(c[277220]|0)+((aU&2081&b0)+((b1+(aU&63454)|0)>>>1)<<1)>>1])&65535;aU=(a[1108928]|0)==0;if(aU){b3=b[(c[277213]|0)+(aS+16<<1)>>1]&63454}else{b3=0}aW=(a[(c[277215]|0)+aV|0]&32)==0;if(aW){b4=c[277228]|0}else{b4=e[(c[277226]|0)+(aT<<1)>>1]|0}if(aU){b5=b[(c[277213]|0)+(aS+16<<1)>>1]&2081}else{b5=0}if(aW){b6=c[277228]|0}else{b6=e[(c[277226]|0)+(aT<<1)>>1]|0}if(aU){b7=e[(c[277213]|0)+(aS+16<<1)>>1]|0}else{b7=0}if(aW){b8=c[277228]|0}else{b8=e[(c[277226]|0)+(aT<<1)>>1]|0}aT=aS+15|0;b[(c[277218]|0)+(aT<<1)>>1]=((b8^b7)&2081|e[(c[277220]|0)+((b6&b5)+(((b4&-2082)+b3|0)>>>1)<<1)>>1])&65535;aW=a[1108909]|0;a[(c[277219]|0)+aT|0]=aW;a[(c[277219]|0)+aV|0]=aW}}while(0);aW=aR-1|0;if((aW|0)>0){s=s+8|0;aR=aW;aS=(c[277223]|0)+aS|0}else{break}}return}aS=r+(56-j)|0;j=(k|0)>0;if(m){if(!j){return}m=i&255;r=m-1&255;aR=r<<24>>24==0;s=aS;b3=k;b4=g;while(1){switch(h|0){case 1:{b9=m;v=7309;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+b4|0]|0)){b5=a[s+7|0]|0;b6=b5&255;if(b5<<24>>24==0){break}b5=e[(c[277225]|0)+(b6<<1)>>1]|0;b7=(a[(c[277215]|0)+b4|0]&32)==0;if(b7){b8=c[277228]|0;ca=b8;cb=b8&-2082}else{b8=e[(c[277213]|0)+(b4<<1)>>1]|0;ca=b8;cb=b8&63454}if(b7){cc=c[277228]|0}else{cc=e[(c[277213]|0)+(b4<<1)>>1]|0}b[(c[277218]|0)+(b4<<1)>>1]=((cc^b5)&2081|e[(c[277220]|0)+((b5&2081&ca)+((cb+(b5&63454)|0)>>>1)<<1)>>1])&65535;b5=(a[1108928]|0)==0;if(b5){cd=b[(c[277213]|0)+(b4+2<<1)>>1]&63454}else{cd=0}b7=(a[(c[277215]|0)+b4|0]&32)==0;if(b7){ce=c[277228]|0}else{ce=e[(c[277226]|0)+(b6<<1)>>1]|0}if(b5){cf=b[(c[277213]|0)+(b4+2<<1)>>1]&2081}else{cf=0}if(b7){cg=c[277228]|0}else{cg=e[(c[277226]|0)+(b6<<1)>>1]|0}if(b5){ch=e[(c[277213]|0)+(b4+2<<1)>>1]|0}else{ch=0}if(b7){ci=c[277228]|0}else{ci=e[(c[277226]|0)+(b6<<1)>>1]|0}b6=b4+1|0;b[(c[277218]|0)+(b6<<1)>>1]=((ci^ch)&2081|e[(c[277220]|0)+((cg&cf)+(((ce&-2082)+cd|0)>>>1)<<1)>>1])&65535;b7=a[1108909]|0;a[(c[277219]|0)+b6|0]=b7;a[(c[277219]|0)+b4|0]=b7}}while(0);if(!aR){b9=r;v=7309}break};case 3:{cj=m;v=7359;break};case 4:{ck=m;v=7384;break};case 5:{cl=m;v=7409;break};case 6:{cm=m;v=7434;break};case 7:{v=7459;break};case 2:{cn=m;v=7334;break};default:{}}if((v|0)==7309){v=0;b7=b4+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+b7|0]|0)){b6=a[s+6|0]|0;b5=b6&255;if(b6<<24>>24==0){break}b6=e[(c[277225]|0)+(b5<<1)>>1]|0;b8=(a[(c[277215]|0)+b7|0]&32)==0;if(b8){b1=c[277228]|0;co=b1;cp=b1&-2082}else{b1=e[(c[277213]|0)+(b7<<1)>>1]|0;co=b1;cp=b1&63454}if(b8){cq=c[277228]|0}else{cq=e[(c[277213]|0)+(b7<<1)>>1]|0}b[(c[277218]|0)+(b7<<1)>>1]=((cq^b6)&2081|e[(c[277220]|0)+((b6&2081&co)+((cp+(b6&63454)|0)>>>1)<<1)>>1])&65535;b6=(a[1108928]|0)==0;if(b6){cr=b[(c[277213]|0)+(b4+4<<1)>>1]&63454}else{cr=0}b8=(a[(c[277215]|0)+b7|0]&32)==0;if(b8){cs=c[277228]|0}else{cs=e[(c[277226]|0)+(b5<<1)>>1]|0}if(b6){ct=b[(c[277213]|0)+(b4+4<<1)>>1]&2081}else{ct=0}if(b8){cu=c[277228]|0}else{cu=e[(c[277226]|0)+(b5<<1)>>1]|0}if(b6){cv=e[(c[277213]|0)+(b4+4<<1)>>1]|0}else{cv=0}if(b8){cw=c[277228]|0}else{cw=e[(c[277226]|0)+(b5<<1)>>1]|0}b5=b4+3|0;b[(c[277218]|0)+(b5<<1)>>1]=((cw^cv)&2081|e[(c[277220]|0)+((cu&ct)+(((cs&-2082)+cr|0)>>>1)<<1)>>1])&65535;b8=a[1108909]|0;a[(c[277219]|0)+b5|0]=b8;a[(c[277219]|0)+b7|0]=b8}}while(0);b7=b9-1&255;if(b7<<24>>24!=0){cn=b7;v=7334}}if((v|0)==7334){v=0;b7=b4+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+b7|0]|0)){b8=a[s+5|0]|0;b5=b8&255;if(b8<<24>>24==0){break}b8=e[(c[277225]|0)+(b5<<1)>>1]|0;b6=(a[(c[277215]|0)+b7|0]&32)==0;if(b6){b1=c[277228]|0;cx=b1;cy=b1&-2082}else{b1=e[(c[277213]|0)+(b7<<1)>>1]|0;cx=b1;cy=b1&63454}if(b6){cz=c[277228]|0}else{cz=e[(c[277213]|0)+(b7<<1)>>1]|0}b[(c[277218]|0)+(b7<<1)>>1]=((cz^b8)&2081|e[(c[277220]|0)+((b8&2081&cx)+((cy+(b8&63454)|0)>>>1)<<1)>>1])&65535;b8=(a[1108928]|0)==0;if(b8){cA=b[(c[277213]|0)+(b4+6<<1)>>1]&63454}else{cA=0}b6=(a[(c[277215]|0)+b7|0]&32)==0;if(b6){cB=c[277228]|0}else{cB=e[(c[277226]|0)+(b5<<1)>>1]|0}if(b8){cC=b[(c[277213]|0)+(b4+6<<1)>>1]&2081}else{cC=0}if(b6){cD=c[277228]|0}else{cD=e[(c[277226]|0)+(b5<<1)>>1]|0}if(b8){cE=e[(c[277213]|0)+(b4+6<<1)>>1]|0}else{cE=0}if(b6){cF=c[277228]|0}else{cF=e[(c[277226]|0)+(b5<<1)>>1]|0}b5=b4+5|0;b[(c[277218]|0)+(b5<<1)>>1]=((cF^cE)&2081|e[(c[277220]|0)+((cD&cC)+(((cB&-2082)+cA|0)>>>1)<<1)>>1])&65535;b6=a[1108909]|0;a[(c[277219]|0)+b5|0]=b6;a[(c[277219]|0)+b7|0]=b6}}while(0);b7=cn-1&255;if(b7<<24>>24!=0){cj=b7;v=7359}}if((v|0)==7359){v=0;b7=b4+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+b7|0]|0)){b6=a[s+4|0]|0;b5=b6&255;if(b6<<24>>24==0){break}b6=e[(c[277225]|0)+(b5<<1)>>1]|0;b8=(a[(c[277215]|0)+b7|0]&32)==0;if(b8){b1=c[277228]|0;cG=b1;cH=b1&-2082}else{b1=e[(c[277213]|0)+(b7<<1)>>1]|0;cG=b1;cH=b1&63454}if(b8){cI=c[277228]|0}else{cI=e[(c[277213]|0)+(b7<<1)>>1]|0}b[(c[277218]|0)+(b7<<1)>>1]=((cI^b6)&2081|e[(c[277220]|0)+((b6&2081&cG)+((cH+(b6&63454)|0)>>>1)<<1)>>1])&65535;b6=(a[1108928]|0)==0;if(b6){cJ=b[(c[277213]|0)+(b4+8<<1)>>1]&63454}else{cJ=0}b8=(a[(c[277215]|0)+b7|0]&32)==0;if(b8){cK=c[277228]|0}else{cK=e[(c[277226]|0)+(b5<<1)>>1]|0}if(b6){cL=b[(c[277213]|0)+(b4+8<<1)>>1]&2081}else{cL=0}if(b8){cM=c[277228]|0}else{cM=e[(c[277226]|0)+(b5<<1)>>1]|0}if(b6){cN=e[(c[277213]|0)+(b4+8<<1)>>1]|0}else{cN=0}if(b8){cO=c[277228]|0}else{cO=e[(c[277226]|0)+(b5<<1)>>1]|0}b5=b4+7|0;b[(c[277218]|0)+(b5<<1)>>1]=((cO^cN)&2081|e[(c[277220]|0)+((cM&cL)+(((cK&-2082)+cJ|0)>>>1)<<1)>>1])&65535;b8=a[1108909]|0;a[(c[277219]|0)+b5|0]=b8;a[(c[277219]|0)+b7|0]=b8}}while(0);b7=cj-1&255;if(b7<<24>>24!=0){ck=b7;v=7384}}if((v|0)==7384){v=0;b7=b4+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+b7|0]|0)){b8=a[s+3|0]|0;b5=b8&255;if(b8<<24>>24==0){break}b8=e[(c[277225]|0)+(b5<<1)>>1]|0;b6=(a[(c[277215]|0)+b7|0]&32)==0;if(b6){b1=c[277228]|0;cP=b1;cQ=b1&-2082}else{b1=e[(c[277213]|0)+(b7<<1)>>1]|0;cP=b1;cQ=b1&63454}if(b6){cR=c[277228]|0}else{cR=e[(c[277213]|0)+(b7<<1)>>1]|0}b[(c[277218]|0)+(b7<<1)>>1]=((cR^b8)&2081|e[(c[277220]|0)+((b8&2081&cP)+((cQ+(b8&63454)|0)>>>1)<<1)>>1])&65535;b8=(a[1108928]|0)==0;if(b8){cS=b[(c[277213]|0)+(b4+10<<1)>>1]&63454}else{cS=0}b6=(a[(c[277215]|0)+b7|0]&32)==0;if(b6){cT=c[277228]|0}else{cT=e[(c[277226]|0)+(b5<<1)>>1]|0}if(b8){cU=b[(c[277213]|0)+(b4+10<<1)>>1]&2081}else{cU=0}if(b6){cV=c[277228]|0}else{cV=e[(c[277226]|0)+(b5<<1)>>1]|0}if(b8){cW=e[(c[277213]|0)+(b4+10<<1)>>1]|0}else{cW=0}if(b6){cX=c[277228]|0}else{cX=e[(c[277226]|0)+(b5<<1)>>1]|0}b5=b4+9|0;b[(c[277218]|0)+(b5<<1)>>1]=((cX^cW)&2081|e[(c[277220]|0)+((cV&cU)+(((cT&-2082)+cS|0)>>>1)<<1)>>1])&65535;b6=a[1108909]|0;a[(c[277219]|0)+b5|0]=b6;a[(c[277219]|0)+b7|0]=b6}}while(0);b7=ck-1&255;if(b7<<24>>24!=0){cl=b7;v=7409}}if((v|0)==7409){v=0;b7=b4+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+b7|0]|0)){b6=a[s+2|0]|0;b5=b6&255;if(b6<<24>>24==0){break}b6=e[(c[277225]|0)+(b5<<1)>>1]|0;b8=(a[(c[277215]|0)+b7|0]&32)==0;if(b8){b1=c[277228]|0;cY=b1;cZ=b1&-2082}else{b1=e[(c[277213]|0)+(b7<<1)>>1]|0;cY=b1;cZ=b1&63454}if(b8){c_=c[277228]|0}else{c_=e[(c[277213]|0)+(b7<<1)>>1]|0}b[(c[277218]|0)+(b7<<1)>>1]=((c_^b6)&2081|e[(c[277220]|0)+((b6&2081&cY)+((cZ+(b6&63454)|0)>>>1)<<1)>>1])&65535;b6=(a[1108928]|0)==0;if(b6){c$=b[(c[277213]|0)+(b4+12<<1)>>1]&63454}else{c$=0}b8=(a[(c[277215]|0)+b7|0]&32)==0;if(b8){c0=c[277228]|0}else{c0=e[(c[277226]|0)+(b5<<1)>>1]|0}if(b6){c1=b[(c[277213]|0)+(b4+12<<1)>>1]&2081}else{c1=0}if(b8){c2=c[277228]|0}else{c2=e[(c[277226]|0)+(b5<<1)>>1]|0}if(b6){c3=e[(c[277213]|0)+(b4+12<<1)>>1]|0}else{c3=0}if(b8){c4=c[277228]|0}else{c4=e[(c[277226]|0)+(b5<<1)>>1]|0}b5=b4+11|0;b[(c[277218]|0)+(b5<<1)>>1]=((c4^c3)&2081|e[(c[277220]|0)+((c2&c1)+(((c0&-2082)+c$|0)>>>1)<<1)>>1])&65535;b8=a[1108909]|0;a[(c[277219]|0)+b5|0]=b8;a[(c[277219]|0)+b7|0]=b8}}while(0);b7=cl-1&255;if(b7<<24>>24!=0){cm=b7;v=7434}}if((v|0)==7434){v=0;b7=b4+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+b7|0]|0)){b8=a[s+1|0]|0;b5=b8&255;if(b8<<24>>24==0){break}b8=e[(c[277225]|0)+(b5<<1)>>1]|0;b6=(a[(c[277215]|0)+b7|0]&32)==0;if(b6){b1=c[277228]|0;c5=b1;c6=b1&-2082}else{b1=e[(c[277213]|0)+(b7<<1)>>1]|0;c5=b1;c6=b1&63454}if(b6){c7=c[277228]|0}else{c7=e[(c[277213]|0)+(b7<<1)>>1]|0}b[(c[277218]|0)+(b7<<1)>>1]=((c7^b8)&2081|e[(c[277220]|0)+((b8&2081&c5)+((c6+(b8&63454)|0)>>>1)<<1)>>1])&65535;b8=(a[1108928]|0)==0;if(b8){c8=b[(c[277213]|0)+(b4+14<<1)>>1]&63454}else{c8=0}b6=(a[(c[277215]|0)+b7|0]&32)==0;if(b6){c9=c[277228]|0}else{c9=e[(c[277226]|0)+(b5<<1)>>1]|0}if(b8){da=b[(c[277213]|0)+(b4+14<<1)>>1]&2081}else{da=0}if(b6){db=c[277228]|0}else{db=e[(c[277226]|0)+(b5<<1)>>1]|0}if(b8){dc=e[(c[277213]|0)+(b4+14<<1)>>1]|0}else{dc=0}if(b6){dd=c[277228]|0}else{dd=e[(c[277226]|0)+(b5<<1)>>1]|0}b5=b4+13|0;b[(c[277218]|0)+(b5<<1)>>1]=((dd^dc)&2081|e[(c[277220]|0)+((db&da)+(((c9&-2082)+c8|0)>>>1)<<1)>>1])&65535;b6=a[1108909]|0;a[(c[277219]|0)+b5|0]=b6;a[(c[277219]|0)+b7|0]=b6}}while(0);if(cm<<24>>24!=1){v=7459}}do{if((v|0)==7459){v=0;b7=b4+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+b7|0]|0)){break}b6=a[s]|0;b5=b6&255;if(b6<<24>>24==0){break}b6=e[(c[277225]|0)+(b5<<1)>>1]|0;b8=(a[(c[277215]|0)+b7|0]&32)==0;if(b8){b1=c[277228]|0;de=b1;df=b1&-2082}else{b1=e[(c[277213]|0)+(b7<<1)>>1]|0;de=b1;df=b1&63454}if(b8){dg=c[277228]|0}else{dg=e[(c[277213]|0)+(b7<<1)>>1]|0}b[(c[277218]|0)+(b7<<1)>>1]=((dg^b6)&2081|e[(c[277220]|0)+((b6&2081&de)+((df+(b6&63454)|0)>>>1)<<1)>>1])&65535;b6=(a[1108928]|0)==0;if(b6){dh=b[(c[277213]|0)+(b4+16<<1)>>1]&63454}else{dh=0}b8=(a[(c[277215]|0)+b7|0]&32)==0;if(b8){di=c[277228]|0}else{di=e[(c[277226]|0)+(b5<<1)>>1]|0}if(b6){dj=b[(c[277213]|0)+(b4+16<<1)>>1]&2081}else{dj=0}if(b8){dk=c[277228]|0}else{dk=e[(c[277226]|0)+(b5<<1)>>1]|0}if(b6){dl=e[(c[277213]|0)+(b4+16<<1)>>1]|0}else{dl=0}if(b8){dm=c[277228]|0}else{dm=e[(c[277226]|0)+(b5<<1)>>1]|0}b5=b4+15|0;b[(c[277218]|0)+(b5<<1)>>1]=((dm^dl)&2081|e[(c[277220]|0)+((dk&dj)+(((di&-2082)+dh|0)>>>1)<<1)>>1])&65535;b8=a[1108909]|0;a[(c[277219]|0)+b5|0]=b8;a[(c[277219]|0)+b7|0]=b8}}while(0);b8=b3-1|0;if((b8|0)>0){s=s-8|0;b3=b8;b4=(c[277223]|0)+b4|0}else{break}}return}else{if(!j){return}j=i&255;i=j-1&255;b4=i<<24>>24==0;b3=aS;aS=k;k=g;while(1){switch(h|0){case 2:{dn=j;v=7133;break};case 6:{dp=j;v=7233;break};case 5:{dq=j;v=7208;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+k|0]|0)){g=a[b3]|0;s=g&255;if(g<<24>>24==0){break}g=e[(c[277225]|0)+(s<<1)>>1]|0;dh=(a[(c[277215]|0)+k|0]&32)==0;if(dh){di=c[277228]|0;dr=di;ds=di&-2082}else{di=e[(c[277213]|0)+(k<<1)>>1]|0;dr=di;ds=di&63454}if(dh){dt=c[277228]|0}else{dt=e[(c[277213]|0)+(k<<1)>>1]|0}b[(c[277218]|0)+(k<<1)>>1]=((dt^g)&2081|e[(c[277220]|0)+((g&2081&dr)+((ds+(g&63454)|0)>>>1)<<1)>>1])&65535;g=(a[1108928]|0)==0;if(g){du=b[(c[277213]|0)+(k+2<<1)>>1]&63454}else{du=0}dh=(a[(c[277215]|0)+k|0]&32)==0;if(dh){dv=c[277228]|0}else{dv=e[(c[277226]|0)+(s<<1)>>1]|0}if(g){dw=b[(c[277213]|0)+(k+2<<1)>>1]&2081}else{dw=0}if(dh){dx=c[277228]|0}else{dx=e[(c[277226]|0)+(s<<1)>>1]|0}if(g){dy=e[(c[277213]|0)+(k+2<<1)>>1]|0}else{dy=0}if(dh){dz=c[277228]|0}else{dz=e[(c[277226]|0)+(s<<1)>>1]|0}s=k+1|0;b[(c[277218]|0)+(s<<1)>>1]=((dz^dy)&2081|e[(c[277220]|0)+((dx&dw)+(((dv&-2082)+du|0)>>>1)<<1)>>1])&65535;dh=a[1108909]|0;a[(c[277219]|0)+s|0]=dh;a[(c[277219]|0)+k|0]=dh}}while(0);if(!b4){dA=i;v=7108}break};case 7:{v=7258;break};case 4:{dB=j;v=7183;break};case 3:{dC=j;v=7158;break};case 1:{dA=j;v=7108;break};default:{}}if((v|0)==7108){v=0;dh=k+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+dh|0]|0)){s=a[b3+1|0]|0;g=s&255;if(s<<24>>24==0){break}s=e[(c[277225]|0)+(g<<1)>>1]|0;di=(a[(c[277215]|0)+dh|0]&32)==0;if(di){dj=c[277228]|0;dD=dj;dE=dj&-2082}else{dj=e[(c[277213]|0)+(dh<<1)>>1]|0;dD=dj;dE=dj&63454}if(di){dF=c[277228]|0}else{dF=e[(c[277213]|0)+(dh<<1)>>1]|0}b[(c[277218]|0)+(dh<<1)>>1]=((dF^s)&2081|e[(c[277220]|0)+((s&2081&dD)+((dE+(s&63454)|0)>>>1)<<1)>>1])&65535;s=(a[1108928]|0)==0;if(s){dG=b[(c[277213]|0)+(k+4<<1)>>1]&63454}else{dG=0}di=(a[(c[277215]|0)+dh|0]&32)==0;if(di){dH=c[277228]|0}else{dH=e[(c[277226]|0)+(g<<1)>>1]|0}if(s){dI=b[(c[277213]|0)+(k+4<<1)>>1]&2081}else{dI=0}if(di){dJ=c[277228]|0}else{dJ=e[(c[277226]|0)+(g<<1)>>1]|0}if(s){dK=e[(c[277213]|0)+(k+4<<1)>>1]|0}else{dK=0}if(di){dL=c[277228]|0}else{dL=e[(c[277226]|0)+(g<<1)>>1]|0}g=k+3|0;b[(c[277218]|0)+(g<<1)>>1]=((dL^dK)&2081|e[(c[277220]|0)+((dJ&dI)+(((dH&-2082)+dG|0)>>>1)<<1)>>1])&65535;di=a[1108909]|0;a[(c[277219]|0)+g|0]=di;a[(c[277219]|0)+dh|0]=di}}while(0);dh=dA-1&255;if(dh<<24>>24!=0){dn=dh;v=7133}}if((v|0)==7133){v=0;dh=k+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+dh|0]|0)){di=a[b3+2|0]|0;g=di&255;if(di<<24>>24==0){break}di=e[(c[277225]|0)+(g<<1)>>1]|0;s=(a[(c[277215]|0)+dh|0]&32)==0;if(s){dj=c[277228]|0;dM=dj;dN=dj&-2082}else{dj=e[(c[277213]|0)+(dh<<1)>>1]|0;dM=dj;dN=dj&63454}if(s){dO=c[277228]|0}else{dO=e[(c[277213]|0)+(dh<<1)>>1]|0}b[(c[277218]|0)+(dh<<1)>>1]=((dO^di)&2081|e[(c[277220]|0)+((di&2081&dM)+((dN+(di&63454)|0)>>>1)<<1)>>1])&65535;di=(a[1108928]|0)==0;if(di){dP=b[(c[277213]|0)+(k+6<<1)>>1]&63454}else{dP=0}s=(a[(c[277215]|0)+dh|0]&32)==0;if(s){dQ=c[277228]|0}else{dQ=e[(c[277226]|0)+(g<<1)>>1]|0}if(di){dR=b[(c[277213]|0)+(k+6<<1)>>1]&2081}else{dR=0}if(s){dS=c[277228]|0}else{dS=e[(c[277226]|0)+(g<<1)>>1]|0}if(di){dT=e[(c[277213]|0)+(k+6<<1)>>1]|0}else{dT=0}if(s){dU=c[277228]|0}else{dU=e[(c[277226]|0)+(g<<1)>>1]|0}g=k+5|0;b[(c[277218]|0)+(g<<1)>>1]=((dU^dT)&2081|e[(c[277220]|0)+((dS&dR)+(((dQ&-2082)+dP|0)>>>1)<<1)>>1])&65535;s=a[1108909]|0;a[(c[277219]|0)+g|0]=s;a[(c[277219]|0)+dh|0]=s}}while(0);dh=dn-1&255;if(dh<<24>>24!=0){dC=dh;v=7158}}if((v|0)==7158){v=0;dh=k+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+dh|0]|0)){s=a[b3+3|0]|0;g=s&255;if(s<<24>>24==0){break}s=e[(c[277225]|0)+(g<<1)>>1]|0;di=(a[(c[277215]|0)+dh|0]&32)==0;if(di){dj=c[277228]|0;dV=dj;dW=dj&-2082}else{dj=e[(c[277213]|0)+(dh<<1)>>1]|0;dV=dj;dW=dj&63454}if(di){dX=c[277228]|0}else{dX=e[(c[277213]|0)+(dh<<1)>>1]|0}b[(c[277218]|0)+(dh<<1)>>1]=((dX^s)&2081|e[(c[277220]|0)+((s&2081&dV)+((dW+(s&63454)|0)>>>1)<<1)>>1])&65535;s=(a[1108928]|0)==0;if(s){dY=b[(c[277213]|0)+(k+8<<1)>>1]&63454}else{dY=0}di=(a[(c[277215]|0)+dh|0]&32)==0;if(di){dZ=c[277228]|0}else{dZ=e[(c[277226]|0)+(g<<1)>>1]|0}if(s){d_=b[(c[277213]|0)+(k+8<<1)>>1]&2081}else{d_=0}if(di){d$=c[277228]|0}else{d$=e[(c[277226]|0)+(g<<1)>>1]|0}if(s){d0=e[(c[277213]|0)+(k+8<<1)>>1]|0}else{d0=0}if(di){d1=c[277228]|0}else{d1=e[(c[277226]|0)+(g<<1)>>1]|0}g=k+7|0;b[(c[277218]|0)+(g<<1)>>1]=((d1^d0)&2081|e[(c[277220]|0)+((d$&d_)+(((dZ&-2082)+dY|0)>>>1)<<1)>>1])&65535;di=a[1108909]|0;a[(c[277219]|0)+g|0]=di;a[(c[277219]|0)+dh|0]=di}}while(0);dh=dC-1&255;if(dh<<24>>24!=0){dB=dh;v=7183}}if((v|0)==7183){v=0;dh=k+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+dh|0]|0)){di=a[b3+4|0]|0;g=di&255;if(di<<24>>24==0){break}di=e[(c[277225]|0)+(g<<1)>>1]|0;s=(a[(c[277215]|0)+dh|0]&32)==0;if(s){dj=c[277228]|0;d2=dj;d3=dj&-2082}else{dj=e[(c[277213]|0)+(dh<<1)>>1]|0;d2=dj;d3=dj&63454}if(s){d4=c[277228]|0}else{d4=e[(c[277213]|0)+(dh<<1)>>1]|0}b[(c[277218]|0)+(dh<<1)>>1]=((d4^di)&2081|e[(c[277220]|0)+((di&2081&d2)+((d3+(di&63454)|0)>>>1)<<1)>>1])&65535;di=(a[1108928]|0)==0;if(di){d5=b[(c[277213]|0)+(k+10<<1)>>1]&63454}else{d5=0}s=(a[(c[277215]|0)+dh|0]&32)==0;if(s){d6=c[277228]|0}else{d6=e[(c[277226]|0)+(g<<1)>>1]|0}if(di){d7=b[(c[277213]|0)+(k+10<<1)>>1]&2081}else{d7=0}if(s){d8=c[277228]|0}else{d8=e[(c[277226]|0)+(g<<1)>>1]|0}if(di){d9=e[(c[277213]|0)+(k+10<<1)>>1]|0}else{d9=0}if(s){ea=c[277228]|0}else{ea=e[(c[277226]|0)+(g<<1)>>1]|0}g=k+9|0;b[(c[277218]|0)+(g<<1)>>1]=((ea^d9)&2081|e[(c[277220]|0)+((d8&d7)+(((d6&-2082)+d5|0)>>>1)<<1)>>1])&65535;s=a[1108909]|0;a[(c[277219]|0)+g|0]=s;a[(c[277219]|0)+dh|0]=s}}while(0);dh=dB-1&255;if(dh<<24>>24!=0){dq=dh;v=7208}}if((v|0)==7208){v=0;dh=k+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+dh|0]|0)){s=a[b3+5|0]|0;g=s&255;if(s<<24>>24==0){break}s=e[(c[277225]|0)+(g<<1)>>1]|0;di=(a[(c[277215]|0)+dh|0]&32)==0;if(di){dj=c[277228]|0;eb=dj;ec=dj&-2082}else{dj=e[(c[277213]|0)+(dh<<1)>>1]|0;eb=dj;ec=dj&63454}if(di){ed=c[277228]|0}else{ed=e[(c[277213]|0)+(dh<<1)>>1]|0}b[(c[277218]|0)+(dh<<1)>>1]=((ed^s)&2081|e[(c[277220]|0)+((s&2081&eb)+((ec+(s&63454)|0)>>>1)<<1)>>1])&65535;s=(a[1108928]|0)==0;if(s){ee=b[(c[277213]|0)+(k+12<<1)>>1]&63454}else{ee=0}di=(a[(c[277215]|0)+dh|0]&32)==0;if(di){ef=c[277228]|0}else{ef=e[(c[277226]|0)+(g<<1)>>1]|0}if(s){eg=b[(c[277213]|0)+(k+12<<1)>>1]&2081}else{eg=0}if(di){eh=c[277228]|0}else{eh=e[(c[277226]|0)+(g<<1)>>1]|0}if(s){ei=e[(c[277213]|0)+(k+12<<1)>>1]|0}else{ei=0}if(di){ej=c[277228]|0}else{ej=e[(c[277226]|0)+(g<<1)>>1]|0}g=k+11|0;b[(c[277218]|0)+(g<<1)>>1]=((ej^ei)&2081|e[(c[277220]|0)+((eh&eg)+(((ef&-2082)+ee|0)>>>1)<<1)>>1])&65535;di=a[1108909]|0;a[(c[277219]|0)+g|0]=di;a[(c[277219]|0)+dh|0]=di}}while(0);dh=dq-1&255;if(dh<<24>>24!=0){dp=dh;v=7233}}if((v|0)==7233){v=0;dh=k+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+dh|0]|0)){di=a[b3+6|0]|0;g=di&255;if(di<<24>>24==0){break}di=e[(c[277225]|0)+(g<<1)>>1]|0;s=(a[(c[277215]|0)+dh|0]&32)==0;if(s){dj=c[277228]|0;ek=dj;el=dj&-2082}else{dj=e[(c[277213]|0)+(dh<<1)>>1]|0;ek=dj;el=dj&63454}if(s){em=c[277228]|0}else{em=e[(c[277213]|0)+(dh<<1)>>1]|0}b[(c[277218]|0)+(dh<<1)>>1]=((em^di)&2081|e[(c[277220]|0)+((di&2081&ek)+((el+(di&63454)|0)>>>1)<<1)>>1])&65535;di=(a[1108928]|0)==0;if(di){en=b[(c[277213]|0)+(k+14<<1)>>1]&63454}else{en=0}s=(a[(c[277215]|0)+dh|0]&32)==0;if(s){eo=c[277228]|0}else{eo=e[(c[277226]|0)+(g<<1)>>1]|0}if(di){ep=b[(c[277213]|0)+(k+14<<1)>>1]&2081}else{ep=0}if(s){eq=c[277228]|0}else{eq=e[(c[277226]|0)+(g<<1)>>1]|0}if(di){er=e[(c[277213]|0)+(k+14<<1)>>1]|0}else{er=0}if(s){es=c[277228]|0}else{es=e[(c[277226]|0)+(g<<1)>>1]|0}g=k+13|0;b[(c[277218]|0)+(g<<1)>>1]=((es^er)&2081|e[(c[277220]|0)+((eq&ep)+(((eo&-2082)+en|0)>>>1)<<1)>>1])&65535;s=a[1108909]|0;a[(c[277219]|0)+g|0]=s;a[(c[277219]|0)+dh|0]=s}}while(0);if(dp<<24>>24!=1){v=7258}}do{if((v|0)==7258){v=0;dh=k+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+dh|0]|0)){break}s=a[b3+7|0]|0;g=s&255;if(s<<24>>24==0){break}s=e[(c[277225]|0)+(g<<1)>>1]|0;di=(a[(c[277215]|0)+dh|0]&32)==0;if(di){dj=c[277228]|0;et=dj;eu=dj&-2082}else{dj=e[(c[277213]|0)+(dh<<1)>>1]|0;et=dj;eu=dj&63454}if(di){ev=c[277228]|0}else{ev=e[(c[277213]|0)+(dh<<1)>>1]|0}b[(c[277218]|0)+(dh<<1)>>1]=((ev^s)&2081|e[(c[277220]|0)+((s&2081&et)+((eu+(s&63454)|0)>>>1)<<1)>>1])&65535;s=(a[1108928]|0)==0;if(s){ew=b[(c[277213]|0)+(k+16<<1)>>1]&63454}else{ew=0}di=(a[(c[277215]|0)+dh|0]&32)==0;if(di){ex=c[277228]|0}else{ex=e[(c[277226]|0)+(g<<1)>>1]|0}if(s){ey=b[(c[277213]|0)+(k+16<<1)>>1]&2081}else{ey=0}if(di){ez=c[277228]|0}else{ez=e[(c[277226]|0)+(g<<1)>>1]|0}if(s){eA=e[(c[277213]|0)+(k+16<<1)>>1]|0}else{eA=0}if(di){eB=c[277228]|0}else{eB=e[(c[277226]|0)+(g<<1)>>1]|0}g=k+15|0;b[(c[277218]|0)+(g<<1)>>1]=((eB^eA)&2081|e[(c[277220]|0)+((ez&ey)+(((ex&-2082)+ew|0)>>>1)<<1)>>1])&65535;di=a[1108909]|0;a[(c[277219]|0)+g|0]=di;a[(c[277219]|0)+dh|0]=di}}while(0);di=aS-1|0;if((di|0)>0){b3=b3-8|0;aS=di;k=(c[277223]|0)+k|0}else{break}}return}}function VC(f,g,h,i,j,k){f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0;l=f&1023;m=c[348606]|0;n=(l<<m)+(c[348604]|0)|0;if((f&256|0)==0){o=n}else{o=(c[348602]|0)+n|0}n=o&65535;o=n>>>(m>>>0);m=(f&16384|0)!=0;p=o<<6;do{if(m){q=(c[348622]|0)+p|0;if((a[(c[348618]|0)+o|0]|0)!=0){r=q;break}s=fi[c[348636]&63](q,n,l)|0;a[(c[348618]|0)+o|0]=s;r=q}else{q=(c[348624]|0)+p|0;if((a[(c[348620]|0)+o|0]|0)!=0){r=q;break}s=fi[c[348638]&63](q,n,l)|0;a[(c[348620]|0)+o|0]=s;r=q}}while(0);if((a[(c[348620]|0)+o|0]|0)==2){return}if((a[1394464]|0)==0){t=1106168+((f>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){o=d[1044485]|0;c[276541]=7080+(o<<5);l=0;do{n=l<<1&2;p=l&2;q=l&4;s=0;do{b[1125528+(l<<9)+(s<<1)>>1]=d[(s>>>1&28|p)+(7080+(o<<5))|0]<<6|d[(s<<2&28|n)+(7080+(o<<5))|0]<<11|d[(s>>>3&24|q)+(7080+(o<<5))|0];s=s+1|0;}while(s>>>0<256);l=l+1|0;}while(l>>>0<8);a[1106089]=0}t=1125528+((f>>>10&7)<<9)|0}c[277226]=t;c[277225]=(a[1108928]|0)!=0?1393712:t;if((f&49152|0)==0){if((k|0)<=0){return}t=i&255;l=t-1&255;o=l<<24>>24==0;s=r+j|0;q=k;n=g;while(1){switch(h|0){case 6:{u=t;v=7569;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+n|0]|0)){p=a[s]|0;if(p<<24>>24==0){break}w=e[(c[277225]|0)+((p&255)<<1)>>1]|0;p=c[277228]|0;x=(((w&63454)+(p&-2082)|0)>>>1)+(p&2081&w)|0;if((a[1108928]|0)==0){y=x&65535}else{y=(e[(c[277220]|0)+(x<<1)>>1]|(w^p)&2081)&65535}b[(c[277218]|0)+(n<<1)>>1]=y;if((a[1108928]|0)==0){p=e[(c[277213]|0)+(n+2<<1)>>1]|0;w=c[277228]|0;z=(((p&63454)+(w&128990)|0)>>>1)+(w&2081&p)|0}else{p=c[277228]|0;z=e[(c[277220]|0)+((p>>>1&2147482607)<<1)>>1]|p&2081}p=n+1|0;b[(c[277218]|0)+(p<<1)>>1]=z&65535;w=a[1108909]|0;a[(c[277219]|0)+p|0]=w;a[(c[277219]|0)+n|0]=w}}while(0);if(!o){A=l;v=7524}break};case 7:{v=7578;break};case 3:{B=t;v=7542;break};case 2:{C=t;v=7533;break};case 4:{D=t;v=7551;break};case 1:{A=t;v=7524;break};case 5:{E=t;v=7560;break};default:{}}if((v|0)==7524){v=0;w=n+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+w|0]|0)){p=a[s+1|0]|0;if(p<<24>>24==0){break}x=e[(c[277225]|0)+((p&255)<<1)>>1]|0;p=c[277228]|0;F=(((x&63454)+(p&-2082)|0)>>>1)+(p&2081&x)|0;if((a[1108928]|0)==0){G=F&65535}else{G=(e[(c[277220]|0)+(F<<1)>>1]|(x^p)&2081)&65535}b[(c[277218]|0)+(w<<1)>>1]=G;if((a[1108928]|0)==0){p=e[(c[277213]|0)+(n+4<<1)>>1]|0;x=c[277228]|0;H=(((p&63454)+(x&128990)|0)>>>1)+(x&2081&p)|0}else{p=c[277228]|0;H=e[(c[277220]|0)+((p>>>1&2147482607)<<1)>>1]|p&2081}p=n+3|0;b[(c[277218]|0)+(p<<1)>>1]=H&65535;x=a[1108909]|0;a[(c[277219]|0)+p|0]=x;a[(c[277219]|0)+w|0]=x}}while(0);w=A-1&255;if(w<<24>>24!=0){C=w;v=7533}}if((v|0)==7533){v=0;w=n+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+w|0]|0)){x=a[s+2|0]|0;if(x<<24>>24==0){break}p=e[(c[277225]|0)+((x&255)<<1)>>1]|0;x=c[277228]|0;F=(((p&63454)+(x&-2082)|0)>>>1)+(x&2081&p)|0;if((a[1108928]|0)==0){I=F&65535}else{I=(e[(c[277220]|0)+(F<<1)>>1]|(p^x)&2081)&65535}b[(c[277218]|0)+(w<<1)>>1]=I;if((a[1108928]|0)==0){x=e[(c[277213]|0)+(n+6<<1)>>1]|0;p=c[277228]|0;J=(((x&63454)+(p&128990)|0)>>>1)+(p&2081&x)|0}else{x=c[277228]|0;J=e[(c[277220]|0)+((x>>>1&2147482607)<<1)>>1]|x&2081}x=n+5|0;b[(c[277218]|0)+(x<<1)>>1]=J&65535;p=a[1108909]|0;a[(c[277219]|0)+x|0]=p;a[(c[277219]|0)+w|0]=p}}while(0);w=C-1&255;if(w<<24>>24!=0){B=w;v=7542}}if((v|0)==7542){v=0;w=n+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+w|0]|0)){p=a[s+3|0]|0;if(p<<24>>24==0){break}x=e[(c[277225]|0)+((p&255)<<1)>>1]|0;p=c[277228]|0;F=(((x&63454)+(p&-2082)|0)>>>1)+(p&2081&x)|0;if((a[1108928]|0)==0){K=F&65535}else{K=(e[(c[277220]|0)+(F<<1)>>1]|(x^p)&2081)&65535}b[(c[277218]|0)+(w<<1)>>1]=K;if((a[1108928]|0)==0){p=e[(c[277213]|0)+(n+8<<1)>>1]|0;x=c[277228]|0;L=(((p&63454)+(x&128990)|0)>>>1)+(x&2081&p)|0}else{p=c[277228]|0;L=e[(c[277220]|0)+((p>>>1&2147482607)<<1)>>1]|p&2081}p=n+7|0;b[(c[277218]|0)+(p<<1)>>1]=L&65535;x=a[1108909]|0;a[(c[277219]|0)+p|0]=x;a[(c[277219]|0)+w|0]=x}}while(0);w=B-1&255;if(w<<24>>24!=0){D=w;v=7551}}if((v|0)==7551){v=0;w=n+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+w|0]|0)){x=a[s+4|0]|0;if(x<<24>>24==0){break}p=e[(c[277225]|0)+((x&255)<<1)>>1]|0;x=c[277228]|0;F=(((p&63454)+(x&-2082)|0)>>>1)+(x&2081&p)|0;if((a[1108928]|0)==0){M=F&65535}else{M=(e[(c[277220]|0)+(F<<1)>>1]|(p^x)&2081)&65535}b[(c[277218]|0)+(w<<1)>>1]=M;if((a[1108928]|0)==0){x=e[(c[277213]|0)+(n+10<<1)>>1]|0;p=c[277228]|0;N=(((x&63454)+(p&128990)|0)>>>1)+(p&2081&x)|0}else{x=c[277228]|0;N=e[(c[277220]|0)+((x>>>1&2147482607)<<1)>>1]|x&2081}x=n+9|0;b[(c[277218]|0)+(x<<1)>>1]=N&65535;p=a[1108909]|0;a[(c[277219]|0)+x|0]=p;a[(c[277219]|0)+w|0]=p}}while(0);w=D-1&255;if(w<<24>>24!=0){E=w;v=7560}}if((v|0)==7560){v=0;w=n+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+w|0]|0)){p=a[s+5|0]|0;if(p<<24>>24==0){break}x=e[(c[277225]|0)+((p&255)<<1)>>1]|0;p=c[277228]|0;F=(((x&63454)+(p&-2082)|0)>>>1)+(p&2081&x)|0;if((a[1108928]|0)==0){O=F&65535}else{O=(e[(c[277220]|0)+(F<<1)>>1]|(x^p)&2081)&65535}b[(c[277218]|0)+(w<<1)>>1]=O;if((a[1108928]|0)==0){p=e[(c[277213]|0)+(n+12<<1)>>1]|0;x=c[277228]|0;P=(((p&63454)+(x&128990)|0)>>>1)+(x&2081&p)|0}else{p=c[277228]|0;P=e[(c[277220]|0)+((p>>>1&2147482607)<<1)>>1]|p&2081}p=n+11|0;b[(c[277218]|0)+(p<<1)>>1]=P&65535;x=a[1108909]|0;a[(c[277219]|0)+p|0]=x;a[(c[277219]|0)+w|0]=x}}while(0);w=E-1&255;if(w<<24>>24!=0){u=w;v=7569}}if((v|0)==7569){v=0;w=n+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+w|0]|0)){x=a[s+6|0]|0;if(x<<24>>24==0){break}p=e[(c[277225]|0)+((x&255)<<1)>>1]|0;x=c[277228]|0;F=(((p&63454)+(x&-2082)|0)>>>1)+(x&2081&p)|0;if((a[1108928]|0)==0){Q=F&65535}else{Q=(e[(c[277220]|0)+(F<<1)>>1]|(p^x)&2081)&65535}b[(c[277218]|0)+(w<<1)>>1]=Q;if((a[1108928]|0)==0){x=e[(c[277213]|0)+(n+14<<1)>>1]|0;p=c[277228]|0;R=(((x&63454)+(p&128990)|0)>>>1)+(p&2081&x)|0}else{x=c[277228]|0;R=e[(c[277220]|0)+((x>>>1&2147482607)<<1)>>1]|x&2081}x=n+13|0;b[(c[277218]|0)+(x<<1)>>1]=R&65535;p=a[1108909]|0;a[(c[277219]|0)+x|0]=p;a[(c[277219]|0)+w|0]=p}}while(0);if(u<<24>>24!=1){v=7578}}do{if((v|0)==7578){v=0;w=n+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+w|0]|0)){break}p=a[s+7|0]|0;if(p<<24>>24==0){break}x=e[(c[277225]|0)+((p&255)<<1)>>1]|0;p=c[277228]|0;F=(((x&63454)+(p&-2082)|0)>>>1)+(p&2081&x)|0;if((a[1108928]|0)==0){S=F&65535}else{S=(e[(c[277220]|0)+(F<<1)>>1]|(x^p)&2081)&65535}b[(c[277218]|0)+(w<<1)>>1]=S;if((a[1108928]|0)==0){p=e[(c[277213]|0)+(n+16<<1)>>1]|0;x=c[277228]|0;T=(((p&63454)+(x&128990)|0)>>>1)+(x&2081&p)|0}else{p=c[277228]|0;T=e[(c[277220]|0)+((p>>>1&2147482607)<<1)>>1]|p&2081}p=n+15|0;b[(c[277218]|0)+(p<<1)>>1]=T&65535;x=a[1108909]|0;a[(c[277219]|0)+p|0]=x;a[(c[277219]|0)+w|0]=x}}while(0);x=q-1|0;if((x|0)>0){s=s+8|0;q=x;n=(c[277223]|0)+n|0}else{break}}return}if((f&32768|0)==0){if((k|0)<=0){return}f=i&255;n=f-1&255;q=n<<24>>24==0;s=r+j|0;T=k;S=g;while(1){switch(h|0){case 2:{U=f;v=7609;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+S|0]|0)){u=a[s+7|0]|0;if(u<<24>>24==0){break}R=e[(c[277225]|0)+((u&255)<<1)>>1]|0;u=c[277228]|0;Q=(((R&63454)+(u&-2082)|0)>>>1)+(u&2081&R)|0;if((a[1108928]|0)==0){V=Q&65535}else{V=(e[(c[277220]|0)+(Q<<1)>>1]|(R^u)&2081)&65535}b[(c[277218]|0)+(S<<1)>>1]=V;if((a[1108928]|0)==0){u=e[(c[277213]|0)+(S+2<<1)>>1]|0;R=c[277228]|0;W=(((u&63454)+(R&128990)|0)>>>1)+(R&2081&u)|0}else{u=c[277228]|0;W=e[(c[277220]|0)+((u>>>1&2147482607)<<1)>>1]|u&2081}u=S+1|0;b[(c[277218]|0)+(u<<1)>>1]=W&65535;R=a[1108909]|0;a[(c[277219]|0)+u|0]=R;a[(c[277219]|0)+S|0]=R}}while(0);if(!q){X=n;v=7600}break};case 5:{Y=f;v=7636;break};case 4:{Z=f;v=7627;break};case 6:{_=f;v=7645;break};case 7:{v=7654;break};case 1:{X=f;v=7600;break};case 3:{$=f;v=7618;break};default:{}}if((v|0)==7600){v=0;R=S+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+R|0]|0)){u=a[s+6|0]|0;if(u<<24>>24==0){break}Q=e[(c[277225]|0)+((u&255)<<1)>>1]|0;u=c[277228]|0;E=(((Q&63454)+(u&-2082)|0)>>>1)+(u&2081&Q)|0;if((a[1108928]|0)==0){aa=E&65535}else{aa=(e[(c[277220]|0)+(E<<1)>>1]|(Q^u)&2081)&65535}b[(c[277218]|0)+(R<<1)>>1]=aa;if((a[1108928]|0)==0){u=e[(c[277213]|0)+(S+4<<1)>>1]|0;Q=c[277228]|0;ab=(((u&63454)+(Q&128990)|0)>>>1)+(Q&2081&u)|0}else{u=c[277228]|0;ab=e[(c[277220]|0)+((u>>>1&2147482607)<<1)>>1]|u&2081}u=S+3|0;b[(c[277218]|0)+(u<<1)>>1]=ab&65535;Q=a[1108909]|0;a[(c[277219]|0)+u|0]=Q;a[(c[277219]|0)+R|0]=Q}}while(0);R=X-1&255;if(R<<24>>24!=0){U=R;v=7609}}if((v|0)==7609){v=0;R=S+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+R|0]|0)){Q=a[s+5|0]|0;if(Q<<24>>24==0){break}u=e[(c[277225]|0)+((Q&255)<<1)>>1]|0;Q=c[277228]|0;E=(((u&63454)+(Q&-2082)|0)>>>1)+(Q&2081&u)|0;if((a[1108928]|0)==0){ac=E&65535}else{ac=(e[(c[277220]|0)+(E<<1)>>1]|(u^Q)&2081)&65535}b[(c[277218]|0)+(R<<1)>>1]=ac;if((a[1108928]|0)==0){Q=e[(c[277213]|0)+(S+6<<1)>>1]|0;u=c[277228]|0;ad=(((Q&63454)+(u&128990)|0)>>>1)+(u&2081&Q)|0}else{Q=c[277228]|0;ad=e[(c[277220]|0)+((Q>>>1&2147482607)<<1)>>1]|Q&2081}Q=S+5|0;b[(c[277218]|0)+(Q<<1)>>1]=ad&65535;u=a[1108909]|0;a[(c[277219]|0)+Q|0]=u;a[(c[277219]|0)+R|0]=u}}while(0);R=U-1&255;if(R<<24>>24!=0){$=R;v=7618}}if((v|0)==7618){v=0;R=S+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+R|0]|0)){u=a[s+4|0]|0;if(u<<24>>24==0){break}Q=e[(c[277225]|0)+((u&255)<<1)>>1]|0;u=c[277228]|0;E=(((Q&63454)+(u&-2082)|0)>>>1)+(u&2081&Q)|0;if((a[1108928]|0)==0){ae=E&65535}else{ae=(e[(c[277220]|0)+(E<<1)>>1]|(Q^u)&2081)&65535}b[(c[277218]|0)+(R<<1)>>1]=ae;if((a[1108928]|0)==0){u=e[(c[277213]|0)+(S+8<<1)>>1]|0;Q=c[277228]|0;af=(((u&63454)+(Q&128990)|0)>>>1)+(Q&2081&u)|0}else{u=c[277228]|0;af=e[(c[277220]|0)+((u>>>1&2147482607)<<1)>>1]|u&2081}u=S+7|0;b[(c[277218]|0)+(u<<1)>>1]=af&65535;Q=a[1108909]|0;a[(c[277219]|0)+u|0]=Q;a[(c[277219]|0)+R|0]=Q}}while(0);R=$-1&255;if(R<<24>>24!=0){Z=R;v=7627}}if((v|0)==7627){v=0;R=S+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+R|0]|0)){Q=a[s+3|0]|0;if(Q<<24>>24==0){break}u=e[(c[277225]|0)+((Q&255)<<1)>>1]|0;Q=c[277228]|0;E=(((u&63454)+(Q&-2082)|0)>>>1)+(Q&2081&u)|0;if((a[1108928]|0)==0){ag=E&65535}else{ag=(e[(c[277220]|0)+(E<<1)>>1]|(u^Q)&2081)&65535}b[(c[277218]|0)+(R<<1)>>1]=ag;if((a[1108928]|0)==0){Q=e[(c[277213]|0)+(S+10<<1)>>1]|0;u=c[277228]|0;ah=(((Q&63454)+(u&128990)|0)>>>1)+(u&2081&Q)|0}else{Q=c[277228]|0;ah=e[(c[277220]|0)+((Q>>>1&2147482607)<<1)>>1]|Q&2081}Q=S+9|0;b[(c[277218]|0)+(Q<<1)>>1]=ah&65535;u=a[1108909]|0;a[(c[277219]|0)+Q|0]=u;a[(c[277219]|0)+R|0]=u}}while(0);R=Z-1&255;if(R<<24>>24!=0){Y=R;v=7636}}if((v|0)==7636){v=0;R=S+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+R|0]|0)){u=a[s+2|0]|0;if(u<<24>>24==0){break}Q=e[(c[277225]|0)+((u&255)<<1)>>1]|0;u=c[277228]|0;E=(((Q&63454)+(u&-2082)|0)>>>1)+(u&2081&Q)|0;if((a[1108928]|0)==0){ai=E&65535}else{ai=(e[(c[277220]|0)+(E<<1)>>1]|(Q^u)&2081)&65535}b[(c[277218]|0)+(R<<1)>>1]=ai;if((a[1108928]|0)==0){u=e[(c[277213]|0)+(S+12<<1)>>1]|0;Q=c[277228]|0;aj=(((u&63454)+(Q&128990)|0)>>>1)+(Q&2081&u)|0}else{u=c[277228]|0;aj=e[(c[277220]|0)+((u>>>1&2147482607)<<1)>>1]|u&2081}u=S+11|0;b[(c[277218]|0)+(u<<1)>>1]=aj&65535;Q=a[1108909]|0;a[(c[277219]|0)+u|0]=Q;a[(c[277219]|0)+R|0]=Q}}while(0);R=Y-1&255;if(R<<24>>24!=0){_=R;v=7645}}if((v|0)==7645){v=0;R=S+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+R|0]|0)){Q=a[s+1|0]|0;if(Q<<24>>24==0){break}u=e[(c[277225]|0)+((Q&255)<<1)>>1]|0;Q=c[277228]|0;E=(((u&63454)+(Q&-2082)|0)>>>1)+(Q&2081&u)|0;if((a[1108928]|0)==0){ak=E&65535}else{ak=(e[(c[277220]|0)+(E<<1)>>1]|(u^Q)&2081)&65535}b[(c[277218]|0)+(R<<1)>>1]=ak;if((a[1108928]|0)==0){Q=e[(c[277213]|0)+(S+14<<1)>>1]|0;u=c[277228]|0;al=(((Q&63454)+(u&128990)|0)>>>1)+(u&2081&Q)|0}else{Q=c[277228]|0;al=e[(c[277220]|0)+((Q>>>1&2147482607)<<1)>>1]|Q&2081}Q=S+13|0;b[(c[277218]|0)+(Q<<1)>>1]=al&65535;u=a[1108909]|0;a[(c[277219]|0)+Q|0]=u;a[(c[277219]|0)+R|0]=u}}while(0);if(_<<24>>24!=1){v=7654}}do{if((v|0)==7654){v=0;R=S+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+R|0]|0)){break}u=a[s]|0;if(u<<24>>24==0){break}Q=e[(c[277225]|0)+((u&255)<<1)>>1]|0;u=c[277228]|0;E=(((Q&63454)+(u&-2082)|0)>>>1)+(u&2081&Q)|0;if((a[1108928]|0)==0){am=E&65535}else{am=(e[(c[277220]|0)+(E<<1)>>1]|(Q^u)&2081)&65535}b[(c[277218]|0)+(R<<1)>>1]=am;if((a[1108928]|0)==0){u=e[(c[277213]|0)+(S+16<<1)>>1]|0;Q=c[277228]|0;an=(((u&63454)+(Q&128990)|0)>>>1)+(Q&2081&u)|0}else{u=c[277228]|0;an=e[(c[277220]|0)+((u>>>1&2147482607)<<1)>>1]|u&2081}u=S+15|0;b[(c[277218]|0)+(u<<1)>>1]=an&65535;Q=a[1108909]|0;a[(c[277219]|0)+u|0]=Q;a[(c[277219]|0)+R|0]=Q}}while(0);Q=T-1|0;if((Q|0)>0){s=s+8|0;T=Q;S=(c[277223]|0)+S|0}else{break}}return}S=r+(56-j)|0;j=(k|0)>0;if(m){if(!j){return}m=i&255;r=m-1&255;T=r<<24>>24==0;s=S;an=k;am=g;while(1){switch(h|0){case 2:{ao=m;v=7760;break};case 6:{ap=m;v=7796;break};case 1:{aq=m;v=7751;break};case 3:{ar=m;v=7769;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+am|0]|0)){_=a[s+7|0]|0;if(_<<24>>24==0){break}al=e[(c[277225]|0)+((_&255)<<1)>>1]|0;_=c[277228]|0;ak=(((al&63454)+(_&-2082)|0)>>>1)+(_&2081&al)|0;if((a[1108928]|0)==0){as=ak&65535}else{as=(e[(c[277220]|0)+(ak<<1)>>1]|(al^_)&2081)&65535}b[(c[277218]|0)+(am<<1)>>1]=as;if((a[1108928]|0)==0){_=e[(c[277213]|0)+(am+2<<1)>>1]|0;al=c[277228]|0;at=(((_&63454)+(al&128990)|0)>>>1)+(al&2081&_)|0}else{_=c[277228]|0;at=e[(c[277220]|0)+((_>>>1&2147482607)<<1)>>1]|_&2081}_=am+1|0;b[(c[277218]|0)+(_<<1)>>1]=at&65535;al=a[1108909]|0;a[(c[277219]|0)+_|0]=al;a[(c[277219]|0)+am|0]=al}}while(0);if(!T){aq=r;v=7751}break};case 5:{au=m;v=7787;break};case 4:{av=m;v=7778;break};case 7:{v=7805;break};default:{}}if((v|0)==7751){v=0;al=am+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+al|0]|0)){_=a[s+6|0]|0;if(_<<24>>24==0){break}ak=e[(c[277225]|0)+((_&255)<<1)>>1]|0;_=c[277228]|0;Y=(((ak&63454)+(_&-2082)|0)>>>1)+(_&2081&ak)|0;if((a[1108928]|0)==0){aw=Y&65535}else{aw=(e[(c[277220]|0)+(Y<<1)>>1]|(ak^_)&2081)&65535}b[(c[277218]|0)+(al<<1)>>1]=aw;if((a[1108928]|0)==0){_=e[(c[277213]|0)+(am+4<<1)>>1]|0;ak=c[277228]|0;ax=(((_&63454)+(ak&128990)|0)>>>1)+(ak&2081&_)|0}else{_=c[277228]|0;ax=e[(c[277220]|0)+((_>>>1&2147482607)<<1)>>1]|_&2081}_=am+3|0;b[(c[277218]|0)+(_<<1)>>1]=ax&65535;ak=a[1108909]|0;a[(c[277219]|0)+_|0]=ak;a[(c[277219]|0)+al|0]=ak}}while(0);al=aq-1&255;if(al<<24>>24!=0){ao=al;v=7760}}if((v|0)==7760){v=0;al=am+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+al|0]|0)){ak=a[s+5|0]|0;if(ak<<24>>24==0){break}_=e[(c[277225]|0)+((ak&255)<<1)>>1]|0;ak=c[277228]|0;Y=(((_&63454)+(ak&-2082)|0)>>>1)+(ak&2081&_)|0;if((a[1108928]|0)==0){ay=Y&65535}else{ay=(e[(c[277220]|0)+(Y<<1)>>1]|(_^ak)&2081)&65535}b[(c[277218]|0)+(al<<1)>>1]=ay;if((a[1108928]|0)==0){ak=e[(c[277213]|0)+(am+6<<1)>>1]|0;_=c[277228]|0;az=(((ak&63454)+(_&128990)|0)>>>1)+(_&2081&ak)|0}else{ak=c[277228]|0;az=e[(c[277220]|0)+((ak>>>1&2147482607)<<1)>>1]|ak&2081}ak=am+5|0;b[(c[277218]|0)+(ak<<1)>>1]=az&65535;_=a[1108909]|0;a[(c[277219]|0)+ak|0]=_;a[(c[277219]|0)+al|0]=_}}while(0);al=ao-1&255;if(al<<24>>24!=0){ar=al;v=7769}}if((v|0)==7769){v=0;al=am+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+al|0]|0)){_=a[s+4|0]|0;if(_<<24>>24==0){break}ak=e[(c[277225]|0)+((_&255)<<1)>>1]|0;_=c[277228]|0;Y=(((ak&63454)+(_&-2082)|0)>>>1)+(_&2081&ak)|0;if((a[1108928]|0)==0){aA=Y&65535}else{aA=(e[(c[277220]|0)+(Y<<1)>>1]|(ak^_)&2081)&65535}b[(c[277218]|0)+(al<<1)>>1]=aA;if((a[1108928]|0)==0){_=e[(c[277213]|0)+(am+8<<1)>>1]|0;ak=c[277228]|0;aB=(((_&63454)+(ak&128990)|0)>>>1)+(ak&2081&_)|0}else{_=c[277228]|0;aB=e[(c[277220]|0)+((_>>>1&2147482607)<<1)>>1]|_&2081}_=am+7|0;b[(c[277218]|0)+(_<<1)>>1]=aB&65535;ak=a[1108909]|0;a[(c[277219]|0)+_|0]=ak;a[(c[277219]|0)+al|0]=ak}}while(0);al=ar-1&255;if(al<<24>>24!=0){av=al;v=7778}}if((v|0)==7778){v=0;al=am+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+al|0]|0)){ak=a[s+3|0]|0;if(ak<<24>>24==0){break}_=e[(c[277225]|0)+((ak&255)<<1)>>1]|0;ak=c[277228]|0;Y=(((_&63454)+(ak&-2082)|0)>>>1)+(ak&2081&_)|0;if((a[1108928]|0)==0){aC=Y&65535}else{aC=(e[(c[277220]|0)+(Y<<1)>>1]|(_^ak)&2081)&65535}b[(c[277218]|0)+(al<<1)>>1]=aC;if((a[1108928]|0)==0){ak=e[(c[277213]|0)+(am+10<<1)>>1]|0;_=c[277228]|0;aD=(((ak&63454)+(_&128990)|0)>>>1)+(_&2081&ak)|0}else{ak=c[277228]|0;aD=e[(c[277220]|0)+((ak>>>1&2147482607)<<1)>>1]|ak&2081}ak=am+9|0;b[(c[277218]|0)+(ak<<1)>>1]=aD&65535;_=a[1108909]|0;a[(c[277219]|0)+ak|0]=_;a[(c[277219]|0)+al|0]=_}}while(0);al=av-1&255;if(al<<24>>24!=0){au=al;v=7787}}if((v|0)==7787){v=0;al=am+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+al|0]|0)){_=a[s+2|0]|0;if(_<<24>>24==0){break}ak=e[(c[277225]|0)+((_&255)<<1)>>1]|0;_=c[277228]|0;Y=(((ak&63454)+(_&-2082)|0)>>>1)+(_&2081&ak)|0;if((a[1108928]|0)==0){aE=Y&65535}else{aE=(e[(c[277220]|0)+(Y<<1)>>1]|(ak^_)&2081)&65535}b[(c[277218]|0)+(al<<1)>>1]=aE;if((a[1108928]|0)==0){_=e[(c[277213]|0)+(am+12<<1)>>1]|0;ak=c[277228]|0;aF=(((_&63454)+(ak&128990)|0)>>>1)+(ak&2081&_)|0}else{_=c[277228]|0;aF=e[(c[277220]|0)+((_>>>1&2147482607)<<1)>>1]|_&2081}_=am+11|0;b[(c[277218]|0)+(_<<1)>>1]=aF&65535;ak=a[1108909]|0;a[(c[277219]|0)+_|0]=ak;a[(c[277219]|0)+al|0]=ak}}while(0);al=au-1&255;if(al<<24>>24!=0){ap=al;v=7796}}if((v|0)==7796){v=0;al=am+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+al|0]|0)){ak=a[s+1|0]|0;if(ak<<24>>24==0){break}_=e[(c[277225]|0)+((ak&255)<<1)>>1]|0;ak=c[277228]|0;Y=(((_&63454)+(ak&-2082)|0)>>>1)+(ak&2081&_)|0;if((a[1108928]|0)==0){aG=Y&65535}else{aG=(e[(c[277220]|0)+(Y<<1)>>1]|(_^ak)&2081)&65535}b[(c[277218]|0)+(al<<1)>>1]=aG;if((a[1108928]|0)==0){ak=e[(c[277213]|0)+(am+14<<1)>>1]|0;_=c[277228]|0;aH=(((ak&63454)+(_&128990)|0)>>>1)+(_&2081&ak)|0}else{ak=c[277228]|0;aH=e[(c[277220]|0)+((ak>>>1&2147482607)<<1)>>1]|ak&2081}ak=am+13|0;b[(c[277218]|0)+(ak<<1)>>1]=aH&65535;_=a[1108909]|0;a[(c[277219]|0)+ak|0]=_;a[(c[277219]|0)+al|0]=_}}while(0);if(ap<<24>>24!=1){v=7805}}do{if((v|0)==7805){v=0;al=am+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+al|0]|0)){break}_=a[s]|0;if(_<<24>>24==0){break}ak=e[(c[277225]|0)+((_&255)<<1)>>1]|0;_=c[277228]|0;Y=(((ak&63454)+(_&-2082)|0)>>>1)+(_&2081&ak)|0;if((a[1108928]|0)==0){aI=Y&65535}else{aI=(e[(c[277220]|0)+(Y<<1)>>1]|(ak^_)&2081)&65535}b[(c[277218]|0)+(al<<1)>>1]=aI;if((a[1108928]|0)==0){_=e[(c[277213]|0)+(am+16<<1)>>1]|0;ak=c[277228]|0;aJ=(((_&63454)+(ak&128990)|0)>>>1)+(ak&2081&_)|0}else{_=c[277228]|0;aJ=e[(c[277220]|0)+((_>>>1&2147482607)<<1)>>1]|_&2081}_=am+15|0;b[(c[277218]|0)+(_<<1)>>1]=aJ&65535;ak=a[1108909]|0;a[(c[277219]|0)+_|0]=ak;a[(c[277219]|0)+al|0]=ak}}while(0);ak=an-1|0;if((ak|0)>0){s=s-8|0;an=ak;am=(c[277223]|0)+am|0}else{break}}return}else{if(!j){return}j=i&255;i=j-1&255;am=i<<24>>24==0;an=S;S=k;k=g;while(1){switch(h|0){case 3:{aK=j;v=7696;break};case 1:{aL=j;v=7678;break};case 2:{aM=j;v=7687;break};case 4:{aN=j;v=7705;break};case 5:{aO=j;v=7714;break};case 7:{v=7732;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+k|0]|0)){g=a[an]|0;if(g<<24>>24==0){break}s=e[(c[277225]|0)+((g&255)<<1)>>1]|0;g=c[277228]|0;aJ=(((s&63454)+(g&-2082)|0)>>>1)+(g&2081&s)|0;if((a[1108928]|0)==0){aP=aJ&65535}else{aP=(e[(c[277220]|0)+(aJ<<1)>>1]|(s^g)&2081)&65535}b[(c[277218]|0)+(k<<1)>>1]=aP;if((a[1108928]|0)==0){g=e[(c[277213]|0)+(k+2<<1)>>1]|0;s=c[277228]|0;aQ=(((g&63454)+(s&128990)|0)>>>1)+(s&2081&g)|0}else{g=c[277228]|0;aQ=e[(c[277220]|0)+((g>>>1&2147482607)<<1)>>1]|g&2081}g=k+1|0;b[(c[277218]|0)+(g<<1)>>1]=aQ&65535;s=a[1108909]|0;a[(c[277219]|0)+g|0]=s;a[(c[277219]|0)+k|0]=s}}while(0);if(!am){aL=i;v=7678}break};case 6:{aR=j;v=7723;break};default:{}}if((v|0)==7678){v=0;s=k+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+s|0]|0)){g=a[an+1|0]|0;if(g<<24>>24==0){break}aJ=e[(c[277225]|0)+((g&255)<<1)>>1]|0;g=c[277228]|0;aI=(((aJ&63454)+(g&-2082)|0)>>>1)+(g&2081&aJ)|0;if((a[1108928]|0)==0){aS=aI&65535}else{aS=(e[(c[277220]|0)+(aI<<1)>>1]|(aJ^g)&2081)&65535}b[(c[277218]|0)+(s<<1)>>1]=aS;if((a[1108928]|0)==0){g=e[(c[277213]|0)+(k+4<<1)>>1]|0;aJ=c[277228]|0;aT=(((g&63454)+(aJ&128990)|0)>>>1)+(aJ&2081&g)|0}else{g=c[277228]|0;aT=e[(c[277220]|0)+((g>>>1&2147482607)<<1)>>1]|g&2081}g=k+3|0;b[(c[277218]|0)+(g<<1)>>1]=aT&65535;aJ=a[1108909]|0;a[(c[277219]|0)+g|0]=aJ;a[(c[277219]|0)+s|0]=aJ}}while(0);s=aL-1&255;if(s<<24>>24!=0){aM=s;v=7687}}if((v|0)==7687){v=0;s=k+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+s|0]|0)){aJ=a[an+2|0]|0;if(aJ<<24>>24==0){break}g=e[(c[277225]|0)+((aJ&255)<<1)>>1]|0;aJ=c[277228]|0;aI=(((g&63454)+(aJ&-2082)|0)>>>1)+(aJ&2081&g)|0;if((a[1108928]|0)==0){aU=aI&65535}else{aU=(e[(c[277220]|0)+(aI<<1)>>1]|(g^aJ)&2081)&65535}b[(c[277218]|0)+(s<<1)>>1]=aU;if((a[1108928]|0)==0){aJ=e[(c[277213]|0)+(k+6<<1)>>1]|0;g=c[277228]|0;aV=(((aJ&63454)+(g&128990)|0)>>>1)+(g&2081&aJ)|0}else{aJ=c[277228]|0;aV=e[(c[277220]|0)+((aJ>>>1&2147482607)<<1)>>1]|aJ&2081}aJ=k+5|0;b[(c[277218]|0)+(aJ<<1)>>1]=aV&65535;g=a[1108909]|0;a[(c[277219]|0)+aJ|0]=g;a[(c[277219]|0)+s|0]=g}}while(0);s=aM-1&255;if(s<<24>>24!=0){aK=s;v=7696}}if((v|0)==7696){v=0;s=k+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+s|0]|0)){g=a[an+3|0]|0;if(g<<24>>24==0){break}aJ=e[(c[277225]|0)+((g&255)<<1)>>1]|0;g=c[277228]|0;aI=(((aJ&63454)+(g&-2082)|0)>>>1)+(g&2081&aJ)|0;if((a[1108928]|0)==0){aW=aI&65535}else{aW=(e[(c[277220]|0)+(aI<<1)>>1]|(aJ^g)&2081)&65535}b[(c[277218]|0)+(s<<1)>>1]=aW;if((a[1108928]|0)==0){g=e[(c[277213]|0)+(k+8<<1)>>1]|0;aJ=c[277228]|0;aX=(((g&63454)+(aJ&128990)|0)>>>1)+(aJ&2081&g)|0}else{g=c[277228]|0;aX=e[(c[277220]|0)+((g>>>1&2147482607)<<1)>>1]|g&2081}g=k+7|0;b[(c[277218]|0)+(g<<1)>>1]=aX&65535;aJ=a[1108909]|0;a[(c[277219]|0)+g|0]=aJ;a[(c[277219]|0)+s|0]=aJ}}while(0);s=aK-1&255;if(s<<24>>24!=0){aN=s;v=7705}}if((v|0)==7705){v=0;s=k+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+s|0]|0)){aJ=a[an+4|0]|0;if(aJ<<24>>24==0){break}g=e[(c[277225]|0)+((aJ&255)<<1)>>1]|0;aJ=c[277228]|0;aI=(((g&63454)+(aJ&-2082)|0)>>>1)+(aJ&2081&g)|0;if((a[1108928]|0)==0){aY=aI&65535}else{aY=(e[(c[277220]|0)+(aI<<1)>>1]|(g^aJ)&2081)&65535}b[(c[277218]|0)+(s<<1)>>1]=aY;if((a[1108928]|0)==0){aJ=e[(c[277213]|0)+(k+10<<1)>>1]|0;g=c[277228]|0;aZ=(((aJ&63454)+(g&128990)|0)>>>1)+(g&2081&aJ)|0}else{aJ=c[277228]|0;aZ=e[(c[277220]|0)+((aJ>>>1&2147482607)<<1)>>1]|aJ&2081}aJ=k+9|0;b[(c[277218]|0)+(aJ<<1)>>1]=aZ&65535;g=a[1108909]|0;a[(c[277219]|0)+aJ|0]=g;a[(c[277219]|0)+s|0]=g}}while(0);s=aN-1&255;if(s<<24>>24!=0){aO=s;v=7714}}if((v|0)==7714){v=0;s=k+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+s|0]|0)){g=a[an+5|0]|0;if(g<<24>>24==0){break}aJ=e[(c[277225]|0)+((g&255)<<1)>>1]|0;g=c[277228]|0;aI=(((aJ&63454)+(g&-2082)|0)>>>1)+(g&2081&aJ)|0;if((a[1108928]|0)==0){a_=aI&65535}else{a_=(e[(c[277220]|0)+(aI<<1)>>1]|(aJ^g)&2081)&65535}b[(c[277218]|0)+(s<<1)>>1]=a_;if((a[1108928]|0)==0){g=e[(c[277213]|0)+(k+12<<1)>>1]|0;aJ=c[277228]|0;a$=(((g&63454)+(aJ&128990)|0)>>>1)+(aJ&2081&g)|0}else{g=c[277228]|0;a$=e[(c[277220]|0)+((g>>>1&2147482607)<<1)>>1]|g&2081}g=k+11|0;b[(c[277218]|0)+(g<<1)>>1]=a$&65535;aJ=a[1108909]|0;a[(c[277219]|0)+g|0]=aJ;a[(c[277219]|0)+s|0]=aJ}}while(0);s=aO-1&255;if(s<<24>>24!=0){aR=s;v=7723}}if((v|0)==7723){v=0;s=k+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+s|0]|0)){aJ=a[an+6|0]|0;if(aJ<<24>>24==0){break}g=e[(c[277225]|0)+((aJ&255)<<1)>>1]|0;aJ=c[277228]|0;aI=(((g&63454)+(aJ&-2082)|0)>>>1)+(aJ&2081&g)|0;if((a[1108928]|0)==0){a0=aI&65535}else{a0=(e[(c[277220]|0)+(aI<<1)>>1]|(g^aJ)&2081)&65535}b[(c[277218]|0)+(s<<1)>>1]=a0;if((a[1108928]|0)==0){aJ=e[(c[277213]|0)+(k+14<<1)>>1]|0;g=c[277228]|0;a1=(((aJ&63454)+(g&128990)|0)>>>1)+(g&2081&aJ)|0}else{aJ=c[277228]|0;a1=e[(c[277220]|0)+((aJ>>>1&2147482607)<<1)>>1]|aJ&2081}aJ=k+13|0;b[(c[277218]|0)+(aJ<<1)>>1]=a1&65535;g=a[1108909]|0;a[(c[277219]|0)+aJ|0]=g;a[(c[277219]|0)+s|0]=g}}while(0);if(aR<<24>>24!=1){v=7732}}do{if((v|0)==7732){v=0;s=k+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+s|0]|0)){break}g=a[an+7|0]|0;if(g<<24>>24==0){break}aJ=e[(c[277225]|0)+((g&255)<<1)>>1]|0;g=c[277228]|0;aI=(((aJ&63454)+(g&-2082)|0)>>>1)+(g&2081&aJ)|0;if((a[1108928]|0)==0){a2=aI&65535}else{a2=(e[(c[277220]|0)+(aI<<1)>>1]|(aJ^g)&2081)&65535}b[(c[277218]|0)+(s<<1)>>1]=a2;if((a[1108928]|0)==0){g=e[(c[277213]|0)+(k+16<<1)>>1]|0;aJ=c[277228]|0;a3=(((g&63454)+(aJ&128990)|0)>>>1)+(aJ&2081&g)|0}else{g=c[277228]|0;a3=e[(c[277220]|0)+((g>>>1&2147482607)<<1)>>1]|g&2081}g=k+15|0;b[(c[277218]|0)+(g<<1)>>1]=a3&65535;aJ=a[1108909]|0;a[(c[277219]|0)+g|0]=aJ;a[(c[277219]|0)+s|0]=aJ}}while(0);aJ=S-1|0;if((aJ|0)>0){an=an-8|0;S=aJ;k=(c[277223]|0)+k|0}else{break}}return}}function VD(f,g,h,i,j,k){f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0,cf=0,cg=0,ch=0,ci=0,cj=0,ck=0,cl=0,cm=0,cn=0,co=0,cp=0,cq=0,cr=0,cs=0,ct=0,cu=0,cv=0,cw=0,cx=0,cy=0,cz=0,cA=0,cB=0,cC=0,cD=0,cE=0,cF=0,cG=0,cH=0,cI=0,cJ=0,cK=0,cL=0,cM=0,cN=0,cO=0,cP=0,cQ=0,cR=0,cS=0,cT=0,cU=0,cV=0,cW=0,cX=0,cY=0,cZ=0,c_=0,c$=0,c0=0,c1=0,c2=0,c3=0,c4=0,c5=0,c6=0,c7=0,c8=0,c9=0,da=0,db=0,dc=0,dd=0,de=0,df=0,dg=0,dh=0,di=0,dj=0,dk=0,dl=0,dm=0,dn=0,dp=0,dq=0,dr=0,ds=0,dt=0,du=0,dv=0,dw=0,dx=0,dy=0,dz=0,dA=0,dB=0,dC=0;l=f&1023;m=c[348606]|0;n=(l<<m)+(c[348604]|0)|0;if((f&256|0)==0){o=n}else{o=(c[348602]|0)+n|0}n=o&65535;o=n>>>(m>>>0);m=(f&16384|0)!=0;p=o<<6;do{if(m){q=(c[348622]|0)+p|0;if((a[(c[348618]|0)+o|0]|0)!=0){r=q;break}s=fi[c[348636]&63](q,n,l)|0;a[(c[348618]|0)+o|0]=s;r=q}else{q=(c[348624]|0)+p|0;if((a[(c[348620]|0)+o|0]|0)!=0){r=q;break}s=fi[c[348638]&63](q,n,l)|0;a[(c[348620]|0)+o|0]=s;r=q}}while(0);if((a[(c[348620]|0)+o|0]|0)==2){return}if((a[1394464]|0)==0){t=1106168+((f>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){o=d[1044485]|0;c[276541]=7080+(o<<5);l=0;do{n=l<<1&2;p=l&2;q=l&4;s=0;do{b[1125528+(l<<9)+(s<<1)>>1]=d[(s>>>1&28|p)+(7080+(o<<5))|0]<<6|d[(s<<2&28|n)+(7080+(o<<5))|0]<<11|d[(s>>>3&24|q)+(7080+(o<<5))|0];s=s+1|0;}while(s>>>0<256);l=l+1|0;}while(l>>>0<8);a[1106089]=0}t=1125528+((f>>>10&7)<<9)|0}c[277226]=t;c[277225]=(a[1108928]|0)!=0?1393712:t;if((f&49152|0)==0){if((k|0)<=0){return}t=i&255;l=t-1&255;o=l<<24>>24==0;s=r+j|0;q=k;n=g;while(1){switch(h|0){case 4:{u=t;v=7937;break};case 6:{w=t;v=7983;break};case 7:{v=8006;break};case 5:{x=t;v=7960;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+n|0]|0)){p=a[s]|0;y=p&255;if(p<<24>>24==0){break}do{if((a[1108928]|0)==0){p=b[(c[277225]|0)+(y<<1)>>1]|0;z=p&65535;A=z&63454;if((a[(c[277215]|0)+n|0]&32)==0){B=c[277228]|0;C=(e[(c[277220]|0)+((((B&-2082)+A|0)>>>1)+(z&2081&B)<<1)>>1]|(B^z)&2081)&65535;break}else{z=b[(c[277213]|0)+(n<<1)>>1]|0;C=(((z&63454)+A|0)>>>1)+(z&p&2081)&65535;break}}else{p=e[(c[277225]|0)+(y<<1)>>1]|0;z=(a[(c[277215]|0)+n|0]&32)==0;if(z){A=c[277228]|0;D=A;E=A&-2082}else{A=e[(c[277213]|0)+(n<<1)>>1]|0;D=A;E=A&63454}if(z){F=c[277228]|0}else{F=e[(c[277213]|0)+(n<<1)>>1]|0}C=((F^p)&2081|e[(c[277220]|0)+((p&2081&D)+((E+(p&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(n<<1)>>1]=C;p=(a[(c[277215]|0)+n|0]&32)==0;do{if((a[1108928]|0)==0){z=e[(c[277213]|0)+(n+2<<1)>>1]|0;A=z&63454;if(p){B=c[277228]|0;G=(e[(c[277220]|0)+((((B&-2082)+A|0)>>>1)+(z&2081&B)<<1)>>1]|(B^z)&2081)&65535;break}else{B=e[(c[277226]|0)+(y<<1)>>1]|0;G=(((B&63454)+A|0)>>>1)+(z&2081&B)&65535;break}}else{if(p){B=c[277228]|0;H=B;I=(c[277220]|0)+((B>>>1&2147482607)<<1)|0}else{B=e[(c[277226]|0)+(y<<1)>>1]|0;H=B;I=(c[277220]|0)+((B>>>1&31727)<<1)|0}G=(e[I>>1]|H&2081)&65535}}while(0);y=n+1|0;b[(c[277218]|0)+(y<<1)>>1]=G;p=a[1108909]|0;a[(c[277219]|0)+y|0]=p;a[(c[277219]|0)+n|0]=p}}while(0);if(!o){J=l;v=7868}break};case 1:{J=t;v=7868;break};case 2:{K=t;v=7891;break};case 3:{L=t;v=7914;break};default:{}}if((v|0)==7868){v=0;p=n+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){y=a[s+1|0]|0;B=y&255;if(y<<24>>24==0){break}do{if((a[1108928]|0)==0){y=b[(c[277225]|0)+(B<<1)>>1]|0;z=y&65535;A=z&63454;if((a[(c[277215]|0)+p|0]&32)==0){M=c[277228]|0;N=(e[(c[277220]|0)+((((M&-2082)+A|0)>>>1)+(z&2081&M)<<1)>>1]|(M^z)&2081)&65535;break}else{z=b[(c[277213]|0)+(p<<1)>>1]|0;N=(((z&63454)+A|0)>>>1)+(z&y&2081)&65535;break}}else{y=e[(c[277225]|0)+(B<<1)>>1]|0;z=(a[(c[277215]|0)+p|0]&32)==0;if(z){A=c[277228]|0;O=A;P=A&-2082}else{A=e[(c[277213]|0)+(p<<1)>>1]|0;O=A;P=A&63454}if(z){Q=c[277228]|0}else{Q=e[(c[277213]|0)+(p<<1)>>1]|0}N=((Q^y)&2081|e[(c[277220]|0)+((y&2081&O)+((P+(y&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=N;y=(a[(c[277215]|0)+p|0]&32)==0;do{if((a[1108928]|0)==0){z=e[(c[277213]|0)+(n+4<<1)>>1]|0;A=z&63454;if(y){M=c[277228]|0;R=(e[(c[277220]|0)+((((M&-2082)+A|0)>>>1)+(z&2081&M)<<1)>>1]|(M^z)&2081)&65535;break}else{M=e[(c[277226]|0)+(B<<1)>>1]|0;R=(((M&63454)+A|0)>>>1)+(z&2081&M)&65535;break}}else{if(y){M=c[277228]|0;S=M;T=(c[277220]|0)+((M>>>1&2147482607)<<1)|0}else{M=e[(c[277226]|0)+(B<<1)>>1]|0;S=M;T=(c[277220]|0)+((M>>>1&31727)<<1)|0}R=(e[T>>1]|S&2081)&65535}}while(0);B=n+3|0;b[(c[277218]|0)+(B<<1)>>1]=R;y=a[1108909]|0;a[(c[277219]|0)+B|0]=y;a[(c[277219]|0)+p|0]=y}}while(0);p=J-1&255;if(p<<24>>24!=0){K=p;v=7891}}if((v|0)==7891){v=0;p=n+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){y=a[s+2|0]|0;B=y&255;if(y<<24>>24==0){break}do{if((a[1108928]|0)==0){y=b[(c[277225]|0)+(B<<1)>>1]|0;M=y&65535;z=M&63454;if((a[(c[277215]|0)+p|0]&32)==0){A=c[277228]|0;U=(e[(c[277220]|0)+((((A&-2082)+z|0)>>>1)+(M&2081&A)<<1)>>1]|(A^M)&2081)&65535;break}else{M=b[(c[277213]|0)+(p<<1)>>1]|0;U=(((M&63454)+z|0)>>>1)+(M&y&2081)&65535;break}}else{y=e[(c[277225]|0)+(B<<1)>>1]|0;M=(a[(c[277215]|0)+p|0]&32)==0;if(M){z=c[277228]|0;V=z;W=z&-2082}else{z=e[(c[277213]|0)+(p<<1)>>1]|0;V=z;W=z&63454}if(M){X=c[277228]|0}else{X=e[(c[277213]|0)+(p<<1)>>1]|0}U=((X^y)&2081|e[(c[277220]|0)+((y&2081&V)+((W+(y&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=U;y=(a[(c[277215]|0)+p|0]&32)==0;do{if((a[1108928]|0)==0){M=e[(c[277213]|0)+(n+6<<1)>>1]|0;z=M&63454;if(y){A=c[277228]|0;Y=(e[(c[277220]|0)+((((A&-2082)+z|0)>>>1)+(M&2081&A)<<1)>>1]|(A^M)&2081)&65535;break}else{A=e[(c[277226]|0)+(B<<1)>>1]|0;Y=(((A&63454)+z|0)>>>1)+(M&2081&A)&65535;break}}else{if(y){A=c[277228]|0;Z=A;_=(c[277220]|0)+((A>>>1&2147482607)<<1)|0}else{A=e[(c[277226]|0)+(B<<1)>>1]|0;Z=A;_=(c[277220]|0)+((A>>>1&31727)<<1)|0}Y=(e[_>>1]|Z&2081)&65535}}while(0);B=n+5|0;b[(c[277218]|0)+(B<<1)>>1]=Y;y=a[1108909]|0;a[(c[277219]|0)+B|0]=y;a[(c[277219]|0)+p|0]=y}}while(0);p=K-1&255;if(p<<24>>24!=0){L=p;v=7914}}if((v|0)==7914){v=0;p=n+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){y=a[s+3|0]|0;B=y&255;if(y<<24>>24==0){break}do{if((a[1108928]|0)==0){y=b[(c[277225]|0)+(B<<1)>>1]|0;A=y&65535;M=A&63454;if((a[(c[277215]|0)+p|0]&32)==0){z=c[277228]|0;$=(e[(c[277220]|0)+((((z&-2082)+M|0)>>>1)+(A&2081&z)<<1)>>1]|(z^A)&2081)&65535;break}else{A=b[(c[277213]|0)+(p<<1)>>1]|0;$=(((A&63454)+M|0)>>>1)+(A&y&2081)&65535;break}}else{y=e[(c[277225]|0)+(B<<1)>>1]|0;A=(a[(c[277215]|0)+p|0]&32)==0;if(A){M=c[277228]|0;aa=M;ab=M&-2082}else{M=e[(c[277213]|0)+(p<<1)>>1]|0;aa=M;ab=M&63454}if(A){ac=c[277228]|0}else{ac=e[(c[277213]|0)+(p<<1)>>1]|0}$=((ac^y)&2081|e[(c[277220]|0)+((y&2081&aa)+((ab+(y&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=$;y=(a[(c[277215]|0)+p|0]&32)==0;do{if((a[1108928]|0)==0){A=e[(c[277213]|0)+(n+8<<1)>>1]|0;M=A&63454;if(y){z=c[277228]|0;ad=(e[(c[277220]|0)+((((z&-2082)+M|0)>>>1)+(A&2081&z)<<1)>>1]|(z^A)&2081)&65535;break}else{z=e[(c[277226]|0)+(B<<1)>>1]|0;ad=(((z&63454)+M|0)>>>1)+(A&2081&z)&65535;break}}else{if(y){z=c[277228]|0;ae=z;af=(c[277220]|0)+((z>>>1&2147482607)<<1)|0}else{z=e[(c[277226]|0)+(B<<1)>>1]|0;ae=z;af=(c[277220]|0)+((z>>>1&31727)<<1)|0}ad=(e[af>>1]|ae&2081)&65535}}while(0);B=n+7|0;b[(c[277218]|0)+(B<<1)>>1]=ad;y=a[1108909]|0;a[(c[277219]|0)+B|0]=y;a[(c[277219]|0)+p|0]=y}}while(0);p=L-1&255;if(p<<24>>24!=0){u=p;v=7937}}if((v|0)==7937){v=0;p=n+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){y=a[s+4|0]|0;B=y&255;if(y<<24>>24==0){break}do{if((a[1108928]|0)==0){y=b[(c[277225]|0)+(B<<1)>>1]|0;z=y&65535;A=z&63454;if((a[(c[277215]|0)+p|0]&32)==0){M=c[277228]|0;ag=(e[(c[277220]|0)+((((M&-2082)+A|0)>>>1)+(z&2081&M)<<1)>>1]|(M^z)&2081)&65535;break}else{z=b[(c[277213]|0)+(p<<1)>>1]|0;ag=(((z&63454)+A|0)>>>1)+(z&y&2081)&65535;break}}else{y=e[(c[277225]|0)+(B<<1)>>1]|0;z=(a[(c[277215]|0)+p|0]&32)==0;if(z){A=c[277228]|0;ah=A;ai=A&-2082}else{A=e[(c[277213]|0)+(p<<1)>>1]|0;ah=A;ai=A&63454}if(z){aj=c[277228]|0}else{aj=e[(c[277213]|0)+(p<<1)>>1]|0}ag=((aj^y)&2081|e[(c[277220]|0)+((y&2081&ah)+((ai+(y&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=ag;y=(a[(c[277215]|0)+p|0]&32)==0;do{if((a[1108928]|0)==0){z=e[(c[277213]|0)+(n+10<<1)>>1]|0;A=z&63454;if(y){M=c[277228]|0;ak=(e[(c[277220]|0)+((((M&-2082)+A|0)>>>1)+(z&2081&M)<<1)>>1]|(M^z)&2081)&65535;break}else{M=e[(c[277226]|0)+(B<<1)>>1]|0;ak=(((M&63454)+A|0)>>>1)+(z&2081&M)&65535;break}}else{if(y){M=c[277228]|0;al=M;am=(c[277220]|0)+((M>>>1&2147482607)<<1)|0}else{M=e[(c[277226]|0)+(B<<1)>>1]|0;al=M;am=(c[277220]|0)+((M>>>1&31727)<<1)|0}ak=(e[am>>1]|al&2081)&65535}}while(0);B=n+9|0;b[(c[277218]|0)+(B<<1)>>1]=ak;y=a[1108909]|0;a[(c[277219]|0)+B|0]=y;a[(c[277219]|0)+p|0]=y}}while(0);p=u-1&255;if(p<<24>>24!=0){x=p;v=7960}}if((v|0)==7960){v=0;p=n+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){y=a[s+5|0]|0;B=y&255;if(y<<24>>24==0){break}do{if((a[1108928]|0)==0){y=b[(c[277225]|0)+(B<<1)>>1]|0;M=y&65535;z=M&63454;if((a[(c[277215]|0)+p|0]&32)==0){A=c[277228]|0;an=(e[(c[277220]|0)+((((A&-2082)+z|0)>>>1)+(M&2081&A)<<1)>>1]|(A^M)&2081)&65535;break}else{M=b[(c[277213]|0)+(p<<1)>>1]|0;an=(((M&63454)+z|0)>>>1)+(M&y&2081)&65535;break}}else{y=e[(c[277225]|0)+(B<<1)>>1]|0;M=(a[(c[277215]|0)+p|0]&32)==0;if(M){z=c[277228]|0;ao=z;ap=z&-2082}else{z=e[(c[277213]|0)+(p<<1)>>1]|0;ao=z;ap=z&63454}if(M){aq=c[277228]|0}else{aq=e[(c[277213]|0)+(p<<1)>>1]|0}an=((aq^y)&2081|e[(c[277220]|0)+((y&2081&ao)+((ap+(y&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=an;y=(a[(c[277215]|0)+p|0]&32)==0;do{if((a[1108928]|0)==0){M=e[(c[277213]|0)+(n+12<<1)>>1]|0;z=M&63454;if(y){A=c[277228]|0;ar=(e[(c[277220]|0)+((((A&-2082)+z|0)>>>1)+(M&2081&A)<<1)>>1]|(A^M)&2081)&65535;break}else{A=e[(c[277226]|0)+(B<<1)>>1]|0;ar=(((A&63454)+z|0)>>>1)+(M&2081&A)&65535;break}}else{if(y){A=c[277228]|0;as=A;at=(c[277220]|0)+((A>>>1&2147482607)<<1)|0}else{A=e[(c[277226]|0)+(B<<1)>>1]|0;as=A;at=(c[277220]|0)+((A>>>1&31727)<<1)|0}ar=(e[at>>1]|as&2081)&65535}}while(0);B=n+11|0;b[(c[277218]|0)+(B<<1)>>1]=ar;y=a[1108909]|0;a[(c[277219]|0)+B|0]=y;a[(c[277219]|0)+p|0]=y}}while(0);p=x-1&255;if(p<<24>>24!=0){w=p;v=7983}}if((v|0)==7983){v=0;p=n+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){y=a[s+6|0]|0;B=y&255;if(y<<24>>24==0){break}do{if((a[1108928]|0)==0){y=b[(c[277225]|0)+(B<<1)>>1]|0;A=y&65535;M=A&63454;if((a[(c[277215]|0)+p|0]&32)==0){z=c[277228]|0;au=(e[(c[277220]|0)+((((z&-2082)+M|0)>>>1)+(A&2081&z)<<1)>>1]|(z^A)&2081)&65535;break}else{A=b[(c[277213]|0)+(p<<1)>>1]|0;au=(((A&63454)+M|0)>>>1)+(A&y&2081)&65535;break}}else{y=e[(c[277225]|0)+(B<<1)>>1]|0;A=(a[(c[277215]|0)+p|0]&32)==0;if(A){M=c[277228]|0;av=M;aw=M&-2082}else{M=e[(c[277213]|0)+(p<<1)>>1]|0;av=M;aw=M&63454}if(A){ax=c[277228]|0}else{ax=e[(c[277213]|0)+(p<<1)>>1]|0}au=((ax^y)&2081|e[(c[277220]|0)+((y&2081&av)+((aw+(y&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=au;y=(a[(c[277215]|0)+p|0]&32)==0;do{if((a[1108928]|0)==0){A=e[(c[277213]|0)+(n+14<<1)>>1]|0;M=A&63454;if(y){z=c[277228]|0;ay=(e[(c[277220]|0)+((((z&-2082)+M|0)>>>1)+(A&2081&z)<<1)>>1]|(z^A)&2081)&65535;break}else{z=e[(c[277226]|0)+(B<<1)>>1]|0;ay=(((z&63454)+M|0)>>>1)+(A&2081&z)&65535;break}}else{if(y){z=c[277228]|0;az=z;aA=(c[277220]|0)+((z>>>1&2147482607)<<1)|0}else{z=e[(c[277226]|0)+(B<<1)>>1]|0;az=z;aA=(c[277220]|0)+((z>>>1&31727)<<1)|0}ay=(e[aA>>1]|az&2081)&65535}}while(0);B=n+13|0;b[(c[277218]|0)+(B<<1)>>1]=ay;y=a[1108909]|0;a[(c[277219]|0)+B|0]=y;a[(c[277219]|0)+p|0]=y}}while(0);if(w<<24>>24!=1){v=8006}}do{if((v|0)==8006){v=0;p=n+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+p|0]|0)){break}y=a[s+7|0]|0;B=y&255;if(y<<24>>24==0){break}do{if((a[1108928]|0)==0){y=b[(c[277225]|0)+(B<<1)>>1]|0;z=y&65535;A=z&63454;if((a[(c[277215]|0)+p|0]&32)==0){M=c[277228]|0;aB=(e[(c[277220]|0)+((((M&-2082)+A|0)>>>1)+(z&2081&M)<<1)>>1]|(M^z)&2081)&65535;break}else{z=b[(c[277213]|0)+(p<<1)>>1]|0;aB=(((z&63454)+A|0)>>>1)+(z&y&2081)&65535;break}}else{y=e[(c[277225]|0)+(B<<1)>>1]|0;z=(a[(c[277215]|0)+p|0]&32)==0;if(z){A=c[277228]|0;aC=A;aD=A&-2082}else{A=e[(c[277213]|0)+(p<<1)>>1]|0;aC=A;aD=A&63454}if(z){aE=c[277228]|0}else{aE=e[(c[277213]|0)+(p<<1)>>1]|0}aB=((aE^y)&2081|e[(c[277220]|0)+((y&2081&aC)+((aD+(y&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=aB;y=(a[(c[277215]|0)+p|0]&32)==0;do{if((a[1108928]|0)==0){z=e[(c[277213]|0)+(n+16<<1)>>1]|0;A=z&63454;if(y){M=c[277228]|0;aF=(e[(c[277220]|0)+((((M&-2082)+A|0)>>>1)+(z&2081&M)<<1)>>1]|(M^z)&2081)&65535;break}else{M=e[(c[277226]|0)+(B<<1)>>1]|0;aF=(((M&63454)+A|0)>>>1)+(z&2081&M)&65535;break}}else{if(y){M=c[277228]|0;aG=M;aH=(c[277220]|0)+((M>>>1&2147482607)<<1)|0}else{M=e[(c[277226]|0)+(B<<1)>>1]|0;aG=M;aH=(c[277220]|0)+((M>>>1&31727)<<1)|0}aF=(e[aH>>1]|aG&2081)&65535}}while(0);B=n+15|0;b[(c[277218]|0)+(B<<1)>>1]=aF;y=a[1108909]|0;a[(c[277219]|0)+B|0]=y;a[(c[277219]|0)+p|0]=y}}while(0);y=q-1|0;if((y|0)>0){s=s+8|0;q=y;n=(c[277223]|0)+n|0}else{break}}return}if((f&32768|0)==0){if((k|0)<=0){return}f=i&255;n=f-1&255;q=n<<24>>24==0;s=r+j|0;aF=k;aG=g;while(1){switch(h|0){case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+aG|0]|0)){aH=a[s+7|0]|0;aB=aH&255;if(aH<<24>>24==0){break}do{if((a[1108928]|0)==0){aH=b[(c[277225]|0)+(aB<<1)>>1]|0;aD=aH&65535;aC=aD&63454;if((a[(c[277215]|0)+aG|0]&32)==0){aE=c[277228]|0;aI=(e[(c[277220]|0)+((((aE&-2082)+aC|0)>>>1)+(aD&2081&aE)<<1)>>1]|(aE^aD)&2081)&65535;break}else{aD=b[(c[277213]|0)+(aG<<1)>>1]|0;aI=(((aD&63454)+aC|0)>>>1)+(aD&aH&2081)&65535;break}}else{aH=e[(c[277225]|0)+(aB<<1)>>1]|0;aD=(a[(c[277215]|0)+aG|0]&32)==0;if(aD){aC=c[277228]|0;aJ=aC;aK=aC&-2082}else{aC=e[(c[277213]|0)+(aG<<1)>>1]|0;aJ=aC;aK=aC&63454}if(aD){aL=c[277228]|0}else{aL=e[(c[277213]|0)+(aG<<1)>>1]|0}aI=((aL^aH)&2081|e[(c[277220]|0)+((aH&2081&aJ)+((aK+(aH&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(aG<<1)>>1]=aI;p=(a[(c[277215]|0)+aG|0]&32)==0;do{if((a[1108928]|0)==0){aH=e[(c[277213]|0)+(aG+2<<1)>>1]|0;aD=aH&63454;if(p){aC=c[277228]|0;aM=(e[(c[277220]|0)+((((aC&-2082)+aD|0)>>>1)+(aH&2081&aC)<<1)>>1]|(aC^aH)&2081)&65535;break}else{aC=e[(c[277226]|0)+(aB<<1)>>1]|0;aM=(((aC&63454)+aD|0)>>>1)+(aH&2081&aC)&65535;break}}else{if(p){aC=c[277228]|0;aN=aC;aO=(c[277220]|0)+((aC>>>1&2147482607)<<1)|0}else{aC=e[(c[277226]|0)+(aB<<1)>>1]|0;aN=aC;aO=(c[277220]|0)+((aC>>>1&31727)<<1)|0}aM=(e[aO>>1]|aN&2081)&65535}}while(0);aB=aG+1|0;b[(c[277218]|0)+(aB<<1)>>1]=aM;p=a[1108909]|0;a[(c[277219]|0)+aB|0]=p;a[(c[277219]|0)+aG|0]=p}}while(0);if(!q){aP=n;v=8056}break};case 6:{aQ=f;v=8171;break};case 1:{aP=f;v=8056;break};case 3:{aR=f;v=8102;break};case 7:{v=8194;break};case 5:{aS=f;v=8148;break};case 2:{aT=f;v=8079;break};case 4:{aU=f;v=8125;break};default:{}}if((v|0)==8056){v=0;p=aG+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){aB=a[s+6|0]|0;aC=aB&255;if(aB<<24>>24==0){break}do{if((a[1108928]|0)==0){aB=b[(c[277225]|0)+(aC<<1)>>1]|0;aH=aB&65535;aD=aH&63454;if((a[(c[277215]|0)+p|0]&32)==0){aE=c[277228]|0;aV=(e[(c[277220]|0)+((((aE&-2082)+aD|0)>>>1)+(aH&2081&aE)<<1)>>1]|(aE^aH)&2081)&65535;break}else{aH=b[(c[277213]|0)+(p<<1)>>1]|0;aV=(((aH&63454)+aD|0)>>>1)+(aH&aB&2081)&65535;break}}else{aB=e[(c[277225]|0)+(aC<<1)>>1]|0;aH=(a[(c[277215]|0)+p|0]&32)==0;if(aH){aD=c[277228]|0;aW=aD;aX=aD&-2082}else{aD=e[(c[277213]|0)+(p<<1)>>1]|0;aW=aD;aX=aD&63454}if(aH){aY=c[277228]|0}else{aY=e[(c[277213]|0)+(p<<1)>>1]|0}aV=((aY^aB)&2081|e[(c[277220]|0)+((aB&2081&aW)+((aX+(aB&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=aV;aB=(a[(c[277215]|0)+p|0]&32)==0;do{if((a[1108928]|0)==0){aH=e[(c[277213]|0)+(aG+4<<1)>>1]|0;aD=aH&63454;if(aB){aE=c[277228]|0;aZ=(e[(c[277220]|0)+((((aE&-2082)+aD|0)>>>1)+(aH&2081&aE)<<1)>>1]|(aE^aH)&2081)&65535;break}else{aE=e[(c[277226]|0)+(aC<<1)>>1]|0;aZ=(((aE&63454)+aD|0)>>>1)+(aH&2081&aE)&65535;break}}else{if(aB){aE=c[277228]|0;a_=aE;a$=(c[277220]|0)+((aE>>>1&2147482607)<<1)|0}else{aE=e[(c[277226]|0)+(aC<<1)>>1]|0;a_=aE;a$=(c[277220]|0)+((aE>>>1&31727)<<1)|0}aZ=(e[a$>>1]|a_&2081)&65535}}while(0);aC=aG+3|0;b[(c[277218]|0)+(aC<<1)>>1]=aZ;aB=a[1108909]|0;a[(c[277219]|0)+aC|0]=aB;a[(c[277219]|0)+p|0]=aB}}while(0);p=aP-1&255;if(p<<24>>24!=0){aT=p;v=8079}}if((v|0)==8079){v=0;p=aG+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){aB=a[s+5|0]|0;aC=aB&255;if(aB<<24>>24==0){break}do{if((a[1108928]|0)==0){aB=b[(c[277225]|0)+(aC<<1)>>1]|0;aE=aB&65535;aH=aE&63454;if((a[(c[277215]|0)+p|0]&32)==0){aD=c[277228]|0;a0=(e[(c[277220]|0)+((((aD&-2082)+aH|0)>>>1)+(aE&2081&aD)<<1)>>1]|(aD^aE)&2081)&65535;break}else{aE=b[(c[277213]|0)+(p<<1)>>1]|0;a0=(((aE&63454)+aH|0)>>>1)+(aE&aB&2081)&65535;break}}else{aB=e[(c[277225]|0)+(aC<<1)>>1]|0;aE=(a[(c[277215]|0)+p|0]&32)==0;if(aE){aH=c[277228]|0;a1=aH;a2=aH&-2082}else{aH=e[(c[277213]|0)+(p<<1)>>1]|0;a1=aH;a2=aH&63454}if(aE){a3=c[277228]|0}else{a3=e[(c[277213]|0)+(p<<1)>>1]|0}a0=((a3^aB)&2081|e[(c[277220]|0)+((aB&2081&a1)+((a2+(aB&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=a0;aB=(a[(c[277215]|0)+p|0]&32)==0;do{if((a[1108928]|0)==0){aE=e[(c[277213]|0)+(aG+6<<1)>>1]|0;aH=aE&63454;if(aB){aD=c[277228]|0;a4=(e[(c[277220]|0)+((((aD&-2082)+aH|0)>>>1)+(aE&2081&aD)<<1)>>1]|(aD^aE)&2081)&65535;break}else{aD=e[(c[277226]|0)+(aC<<1)>>1]|0;a4=(((aD&63454)+aH|0)>>>1)+(aE&2081&aD)&65535;break}}else{if(aB){aD=c[277228]|0;a5=aD;a6=(c[277220]|0)+((aD>>>1&2147482607)<<1)|0}else{aD=e[(c[277226]|0)+(aC<<1)>>1]|0;a5=aD;a6=(c[277220]|0)+((aD>>>1&31727)<<1)|0}a4=(e[a6>>1]|a5&2081)&65535}}while(0);aC=aG+5|0;b[(c[277218]|0)+(aC<<1)>>1]=a4;aB=a[1108909]|0;a[(c[277219]|0)+aC|0]=aB;a[(c[277219]|0)+p|0]=aB}}while(0);p=aT-1&255;if(p<<24>>24!=0){aR=p;v=8102}}if((v|0)==8102){v=0;p=aG+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){aB=a[s+4|0]|0;aC=aB&255;if(aB<<24>>24==0){break}do{if((a[1108928]|0)==0){aB=b[(c[277225]|0)+(aC<<1)>>1]|0;aD=aB&65535;aE=aD&63454;if((a[(c[277215]|0)+p|0]&32)==0){aH=c[277228]|0;a7=(e[(c[277220]|0)+((((aH&-2082)+aE|0)>>>1)+(aD&2081&aH)<<1)>>1]|(aH^aD)&2081)&65535;break}else{aD=b[(c[277213]|0)+(p<<1)>>1]|0;a7=(((aD&63454)+aE|0)>>>1)+(aD&aB&2081)&65535;break}}else{aB=e[(c[277225]|0)+(aC<<1)>>1]|0;aD=(a[(c[277215]|0)+p|0]&32)==0;if(aD){aE=c[277228]|0;a8=aE;a9=aE&-2082}else{aE=e[(c[277213]|0)+(p<<1)>>1]|0;a8=aE;a9=aE&63454}if(aD){ba=c[277228]|0}else{ba=e[(c[277213]|0)+(p<<1)>>1]|0}a7=((ba^aB)&2081|e[(c[277220]|0)+((aB&2081&a8)+((a9+(aB&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=a7;aB=(a[(c[277215]|0)+p|0]&32)==0;do{if((a[1108928]|0)==0){aD=e[(c[277213]|0)+(aG+8<<1)>>1]|0;aE=aD&63454;if(aB){aH=c[277228]|0;bb=(e[(c[277220]|0)+((((aH&-2082)+aE|0)>>>1)+(aD&2081&aH)<<1)>>1]|(aH^aD)&2081)&65535;break}else{aH=e[(c[277226]|0)+(aC<<1)>>1]|0;bb=(((aH&63454)+aE|0)>>>1)+(aD&2081&aH)&65535;break}}else{if(aB){aH=c[277228]|0;bc=aH;bd=(c[277220]|0)+((aH>>>1&2147482607)<<1)|0}else{aH=e[(c[277226]|0)+(aC<<1)>>1]|0;bc=aH;bd=(c[277220]|0)+((aH>>>1&31727)<<1)|0}bb=(e[bd>>1]|bc&2081)&65535}}while(0);aC=aG+7|0;b[(c[277218]|0)+(aC<<1)>>1]=bb;aB=a[1108909]|0;a[(c[277219]|0)+aC|0]=aB;a[(c[277219]|0)+p|0]=aB}}while(0);p=aR-1&255;if(p<<24>>24!=0){aU=p;v=8125}}if((v|0)==8125){v=0;p=aG+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){aB=a[s+3|0]|0;aC=aB&255;if(aB<<24>>24==0){break}do{if((a[1108928]|0)==0){aB=b[(c[277225]|0)+(aC<<1)>>1]|0;aH=aB&65535;aD=aH&63454;if((a[(c[277215]|0)+p|0]&32)==0){aE=c[277228]|0;be=(e[(c[277220]|0)+((((aE&-2082)+aD|0)>>>1)+(aH&2081&aE)<<1)>>1]|(aE^aH)&2081)&65535;break}else{aH=b[(c[277213]|0)+(p<<1)>>1]|0;be=(((aH&63454)+aD|0)>>>1)+(aH&aB&2081)&65535;break}}else{aB=e[(c[277225]|0)+(aC<<1)>>1]|0;aH=(a[(c[277215]|0)+p|0]&32)==0;if(aH){aD=c[277228]|0;bf=aD;bg=aD&-2082}else{aD=e[(c[277213]|0)+(p<<1)>>1]|0;bf=aD;bg=aD&63454}if(aH){bh=c[277228]|0}else{bh=e[(c[277213]|0)+(p<<1)>>1]|0}be=((bh^aB)&2081|e[(c[277220]|0)+((aB&2081&bf)+((bg+(aB&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=be;aB=(a[(c[277215]|0)+p|0]&32)==0;do{if((a[1108928]|0)==0){aH=e[(c[277213]|0)+(aG+10<<1)>>1]|0;aD=aH&63454;if(aB){aE=c[277228]|0;bi=(e[(c[277220]|0)+((((aE&-2082)+aD|0)>>>1)+(aH&2081&aE)<<1)>>1]|(aE^aH)&2081)&65535;break}else{aE=e[(c[277226]|0)+(aC<<1)>>1]|0;bi=(((aE&63454)+aD|0)>>>1)+(aH&2081&aE)&65535;break}}else{if(aB){aE=c[277228]|0;bj=aE;bk=(c[277220]|0)+((aE>>>1&2147482607)<<1)|0}else{aE=e[(c[277226]|0)+(aC<<1)>>1]|0;bj=aE;bk=(c[277220]|0)+((aE>>>1&31727)<<1)|0}bi=(e[bk>>1]|bj&2081)&65535}}while(0);aC=aG+9|0;b[(c[277218]|0)+(aC<<1)>>1]=bi;aB=a[1108909]|0;a[(c[277219]|0)+aC|0]=aB;a[(c[277219]|0)+p|0]=aB}}while(0);p=aU-1&255;if(p<<24>>24!=0){aS=p;v=8148}}if((v|0)==8148){v=0;p=aG+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){aB=a[s+2|0]|0;aC=aB&255;if(aB<<24>>24==0){break}do{if((a[1108928]|0)==0){aB=b[(c[277225]|0)+(aC<<1)>>1]|0;aE=aB&65535;aH=aE&63454;if((a[(c[277215]|0)+p|0]&32)==0){aD=c[277228]|0;bl=(e[(c[277220]|0)+((((aD&-2082)+aH|0)>>>1)+(aE&2081&aD)<<1)>>1]|(aD^aE)&2081)&65535;break}else{aE=b[(c[277213]|0)+(p<<1)>>1]|0;bl=(((aE&63454)+aH|0)>>>1)+(aE&aB&2081)&65535;break}}else{aB=e[(c[277225]|0)+(aC<<1)>>1]|0;aE=(a[(c[277215]|0)+p|0]&32)==0;if(aE){aH=c[277228]|0;bm=aH;bn=aH&-2082}else{aH=e[(c[277213]|0)+(p<<1)>>1]|0;bm=aH;bn=aH&63454}if(aE){bo=c[277228]|0}else{bo=e[(c[277213]|0)+(p<<1)>>1]|0}bl=((bo^aB)&2081|e[(c[277220]|0)+((aB&2081&bm)+((bn+(aB&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=bl;aB=(a[(c[277215]|0)+p|0]&32)==0;do{if((a[1108928]|0)==0){aE=e[(c[277213]|0)+(aG+12<<1)>>1]|0;aH=aE&63454;if(aB){aD=c[277228]|0;bp=(e[(c[277220]|0)+((((aD&-2082)+aH|0)>>>1)+(aE&2081&aD)<<1)>>1]|(aD^aE)&2081)&65535;break}else{aD=e[(c[277226]|0)+(aC<<1)>>1]|0;bp=(((aD&63454)+aH|0)>>>1)+(aE&2081&aD)&65535;break}}else{if(aB){aD=c[277228]|0;bq=aD;br=(c[277220]|0)+((aD>>>1&2147482607)<<1)|0}else{aD=e[(c[277226]|0)+(aC<<1)>>1]|0;bq=aD;br=(c[277220]|0)+((aD>>>1&31727)<<1)|0}bp=(e[br>>1]|bq&2081)&65535}}while(0);aC=aG+11|0;b[(c[277218]|0)+(aC<<1)>>1]=bp;aB=a[1108909]|0;a[(c[277219]|0)+aC|0]=aB;a[(c[277219]|0)+p|0]=aB}}while(0);p=aS-1&255;if(p<<24>>24!=0){aQ=p;v=8171}}if((v|0)==8171){v=0;p=aG+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){aB=a[s+1|0]|0;aC=aB&255;if(aB<<24>>24==0){break}do{if((a[1108928]|0)==0){aB=b[(c[277225]|0)+(aC<<1)>>1]|0;aD=aB&65535;aE=aD&63454;if((a[(c[277215]|0)+p|0]&32)==0){aH=c[277228]|0;bs=(e[(c[277220]|0)+((((aH&-2082)+aE|0)>>>1)+(aD&2081&aH)<<1)>>1]|(aH^aD)&2081)&65535;break}else{aD=b[(c[277213]|0)+(p<<1)>>1]|0;bs=(((aD&63454)+aE|0)>>>1)+(aD&aB&2081)&65535;break}}else{aB=e[(c[277225]|0)+(aC<<1)>>1]|0;aD=(a[(c[277215]|0)+p|0]&32)==0;if(aD){aE=c[277228]|0;bt=aE;bu=aE&-2082}else{aE=e[(c[277213]|0)+(p<<1)>>1]|0;bt=aE;bu=aE&63454}if(aD){bv=c[277228]|0}else{bv=e[(c[277213]|0)+(p<<1)>>1]|0}bs=((bv^aB)&2081|e[(c[277220]|0)+((aB&2081&bt)+((bu+(aB&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=bs;aB=(a[(c[277215]|0)+p|0]&32)==0;do{if((a[1108928]|0)==0){aD=e[(c[277213]|0)+(aG+14<<1)>>1]|0;aE=aD&63454;if(aB){aH=c[277228]|0;bw=(e[(c[277220]|0)+((((aH&-2082)+aE|0)>>>1)+(aD&2081&aH)<<1)>>1]|(aH^aD)&2081)&65535;break}else{aH=e[(c[277226]|0)+(aC<<1)>>1]|0;bw=(((aH&63454)+aE|0)>>>1)+(aD&2081&aH)&65535;break}}else{if(aB){aH=c[277228]|0;bx=aH;by=(c[277220]|0)+((aH>>>1&2147482607)<<1)|0}else{aH=e[(c[277226]|0)+(aC<<1)>>1]|0;bx=aH;by=(c[277220]|0)+((aH>>>1&31727)<<1)|0}bw=(e[by>>1]|bx&2081)&65535}}while(0);aC=aG+13|0;b[(c[277218]|0)+(aC<<1)>>1]=bw;aB=a[1108909]|0;a[(c[277219]|0)+aC|0]=aB;a[(c[277219]|0)+p|0]=aB}}while(0);if(aQ<<24>>24!=1){v=8194}}do{if((v|0)==8194){v=0;p=aG+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+p|0]|0)){break}aB=a[s]|0;aC=aB&255;if(aB<<24>>24==0){break}do{if((a[1108928]|0)==0){aB=b[(c[277225]|0)+(aC<<1)>>1]|0;aH=aB&65535;aD=aH&63454;if((a[(c[277215]|0)+p|0]&32)==0){aE=c[277228]|0;bz=(e[(c[277220]|0)+((((aE&-2082)+aD|0)>>>1)+(aH&2081&aE)<<1)>>1]|(aE^aH)&2081)&65535;break}else{aH=b[(c[277213]|0)+(p<<1)>>1]|0;bz=(((aH&63454)+aD|0)>>>1)+(aH&aB&2081)&65535;break}}else{aB=e[(c[277225]|0)+(aC<<1)>>1]|0;aH=(a[(c[277215]|0)+p|0]&32)==0;if(aH){aD=c[277228]|0;bA=aD;bB=aD&-2082}else{aD=e[(c[277213]|0)+(p<<1)>>1]|0;bA=aD;bB=aD&63454}if(aH){bC=c[277228]|0}else{bC=e[(c[277213]|0)+(p<<1)>>1]|0}bz=((bC^aB)&2081|e[(c[277220]|0)+((aB&2081&bA)+((bB+(aB&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=bz;aB=(a[(c[277215]|0)+p|0]&32)==0;do{if((a[1108928]|0)==0){aH=e[(c[277213]|0)+(aG+16<<1)>>1]|0;aD=aH&63454;if(aB){aE=c[277228]|0;bD=(e[(c[277220]|0)+((((aE&-2082)+aD|0)>>>1)+(aH&2081&aE)<<1)>>1]|(aE^aH)&2081)&65535;break}else{aE=e[(c[277226]|0)+(aC<<1)>>1]|0;bD=(((aE&63454)+aD|0)>>>1)+(aH&2081&aE)&65535;break}}else{if(aB){aE=c[277228]|0;bE=aE;bF=(c[277220]|0)+((aE>>>1&2147482607)<<1)|0}else{aE=e[(c[277226]|0)+(aC<<1)>>1]|0;bE=aE;bF=(c[277220]|0)+((aE>>>1&31727)<<1)|0}bD=(e[bF>>1]|bE&2081)&65535}}while(0);aC=aG+15|0;b[(c[277218]|0)+(aC<<1)>>1]=bD;aB=a[1108909]|0;a[(c[277219]|0)+aC|0]=aB;a[(c[277219]|0)+p|0]=aB}}while(0);aB=aF-1|0;if((aB|0)>0){s=s+8|0;aF=aB;aG=(c[277223]|0)+aG|0}else{break}}return}aG=r+(56-j)|0;j=(k|0)>0;if(m){if(!j){return}m=i&255;r=m-1&255;aF=r<<24>>24==0;s=aG;bD=k;bE=g;while(1){switch(h|0){case 2:{bG=m;v=8454;break};case 5:{bH=m;v=8523;break};case 6:{bI=m;v=8546;break};case 1:{bJ=m;v=8431;break};case 4:{bK=m;v=8500;break};case 3:{bL=m;v=8477;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+bE|0]|0)){bF=a[s+7|0]|0;bz=bF&255;if(bF<<24>>24==0){break}do{if((a[1108928]|0)==0){bF=b[(c[277225]|0)+(bz<<1)>>1]|0;bB=bF&65535;bA=bB&63454;if((a[(c[277215]|0)+bE|0]&32)==0){bC=c[277228]|0;bM=(e[(c[277220]|0)+((((bC&-2082)+bA|0)>>>1)+(bB&2081&bC)<<1)>>1]|(bC^bB)&2081)&65535;break}else{bB=b[(c[277213]|0)+(bE<<1)>>1]|0;bM=(((bB&63454)+bA|0)>>>1)+(bB&bF&2081)&65535;break}}else{bF=e[(c[277225]|0)+(bz<<1)>>1]|0;bB=(a[(c[277215]|0)+bE|0]&32)==0;if(bB){bA=c[277228]|0;bN=bA;bO=bA&-2082}else{bA=e[(c[277213]|0)+(bE<<1)>>1]|0;bN=bA;bO=bA&63454}if(bB){bP=c[277228]|0}else{bP=e[(c[277213]|0)+(bE<<1)>>1]|0}bM=((bP^bF)&2081|e[(c[277220]|0)+((bF&2081&bN)+((bO+(bF&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(bE<<1)>>1]=bM;p=(a[(c[277215]|0)+bE|0]&32)==0;do{if((a[1108928]|0)==0){bF=e[(c[277213]|0)+(bE+2<<1)>>1]|0;bB=bF&63454;if(p){bA=c[277228]|0;bQ=(e[(c[277220]|0)+((((bA&-2082)+bB|0)>>>1)+(bF&2081&bA)<<1)>>1]|(bA^bF)&2081)&65535;break}else{bA=e[(c[277226]|0)+(bz<<1)>>1]|0;bQ=(((bA&63454)+bB|0)>>>1)+(bF&2081&bA)&65535;break}}else{if(p){bA=c[277228]|0;bR=bA;bS=(c[277220]|0)+((bA>>>1&2147482607)<<1)|0}else{bA=e[(c[277226]|0)+(bz<<1)>>1]|0;bR=bA;bS=(c[277220]|0)+((bA>>>1&31727)<<1)|0}bQ=(e[bS>>1]|bR&2081)&65535}}while(0);bz=bE+1|0;b[(c[277218]|0)+(bz<<1)>>1]=bQ;p=a[1108909]|0;a[(c[277219]|0)+bz|0]=p;a[(c[277219]|0)+bE|0]=p}}while(0);if(!aF){bJ=r;v=8431}break};case 7:{v=8569;break};default:{}}if((v|0)==8431){v=0;p=bE+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){bz=a[s+6|0]|0;bA=bz&255;if(bz<<24>>24==0){break}do{if((a[1108928]|0)==0){bz=b[(c[277225]|0)+(bA<<1)>>1]|0;bF=bz&65535;bB=bF&63454;if((a[(c[277215]|0)+p|0]&32)==0){bC=c[277228]|0;bT=(e[(c[277220]|0)+((((bC&-2082)+bB|0)>>>1)+(bF&2081&bC)<<1)>>1]|(bC^bF)&2081)&65535;break}else{bF=b[(c[277213]|0)+(p<<1)>>1]|0;bT=(((bF&63454)+bB|0)>>>1)+(bF&bz&2081)&65535;break}}else{bz=e[(c[277225]|0)+(bA<<1)>>1]|0;bF=(a[(c[277215]|0)+p|0]&32)==0;if(bF){bB=c[277228]|0;bU=bB;bV=bB&-2082}else{bB=e[(c[277213]|0)+(p<<1)>>1]|0;bU=bB;bV=bB&63454}if(bF){bW=c[277228]|0}else{bW=e[(c[277213]|0)+(p<<1)>>1]|0}bT=((bW^bz)&2081|e[(c[277220]|0)+((bz&2081&bU)+((bV+(bz&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=bT;bz=(a[(c[277215]|0)+p|0]&32)==0;do{if((a[1108928]|0)==0){bF=e[(c[277213]|0)+(bE+4<<1)>>1]|0;bB=bF&63454;if(bz){bC=c[277228]|0;bX=(e[(c[277220]|0)+((((bC&-2082)+bB|0)>>>1)+(bF&2081&bC)<<1)>>1]|(bC^bF)&2081)&65535;break}else{bC=e[(c[277226]|0)+(bA<<1)>>1]|0;bX=(((bC&63454)+bB|0)>>>1)+(bF&2081&bC)&65535;break}}else{if(bz){bC=c[277228]|0;bY=bC;bZ=(c[277220]|0)+((bC>>>1&2147482607)<<1)|0}else{bC=e[(c[277226]|0)+(bA<<1)>>1]|0;bY=bC;bZ=(c[277220]|0)+((bC>>>1&31727)<<1)|0}bX=(e[bZ>>1]|bY&2081)&65535}}while(0);bA=bE+3|0;b[(c[277218]|0)+(bA<<1)>>1]=bX;bz=a[1108909]|0;a[(c[277219]|0)+bA|0]=bz;a[(c[277219]|0)+p|0]=bz}}while(0);p=bJ-1&255;if(p<<24>>24!=0){bG=p;v=8454}}if((v|0)==8454){v=0;p=bE+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){bz=a[s+5|0]|0;bA=bz&255;if(bz<<24>>24==0){break}do{if((a[1108928]|0)==0){bz=b[(c[277225]|0)+(bA<<1)>>1]|0;bC=bz&65535;bF=bC&63454;if((a[(c[277215]|0)+p|0]&32)==0){bB=c[277228]|0;b_=(e[(c[277220]|0)+((((bB&-2082)+bF|0)>>>1)+(bC&2081&bB)<<1)>>1]|(bB^bC)&2081)&65535;break}else{bC=b[(c[277213]|0)+(p<<1)>>1]|0;b_=(((bC&63454)+bF|0)>>>1)+(bC&bz&2081)&65535;break}}else{bz=e[(c[277225]|0)+(bA<<1)>>1]|0;bC=(a[(c[277215]|0)+p|0]&32)==0;if(bC){bF=c[277228]|0;b$=bF;b0=bF&-2082}else{bF=e[(c[277213]|0)+(p<<1)>>1]|0;b$=bF;b0=bF&63454}if(bC){b1=c[277228]|0}else{b1=e[(c[277213]|0)+(p<<1)>>1]|0}b_=((b1^bz)&2081|e[(c[277220]|0)+((bz&2081&b$)+((b0+(bz&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=b_;bz=(a[(c[277215]|0)+p|0]&32)==0;do{if((a[1108928]|0)==0){bC=e[(c[277213]|0)+(bE+6<<1)>>1]|0;bF=bC&63454;if(bz){bB=c[277228]|0;b2=(e[(c[277220]|0)+((((bB&-2082)+bF|0)>>>1)+(bC&2081&bB)<<1)>>1]|(bB^bC)&2081)&65535;break}else{bB=e[(c[277226]|0)+(bA<<1)>>1]|0;b2=(((bB&63454)+bF|0)>>>1)+(bC&2081&bB)&65535;break}}else{if(bz){bB=c[277228]|0;b3=bB;b4=(c[277220]|0)+((bB>>>1&2147482607)<<1)|0}else{bB=e[(c[277226]|0)+(bA<<1)>>1]|0;b3=bB;b4=(c[277220]|0)+((bB>>>1&31727)<<1)|0}b2=(e[b4>>1]|b3&2081)&65535}}while(0);bA=bE+5|0;b[(c[277218]|0)+(bA<<1)>>1]=b2;bz=a[1108909]|0;a[(c[277219]|0)+bA|0]=bz;a[(c[277219]|0)+p|0]=bz}}while(0);p=bG-1&255;if(p<<24>>24!=0){bL=p;v=8477}}if((v|0)==8477){v=0;p=bE+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){bz=a[s+4|0]|0;bA=bz&255;if(bz<<24>>24==0){break}do{if((a[1108928]|0)==0){bz=b[(c[277225]|0)+(bA<<1)>>1]|0;bB=bz&65535;bC=bB&63454;if((a[(c[277215]|0)+p|0]&32)==0){bF=c[277228]|0;b5=(e[(c[277220]|0)+((((bF&-2082)+bC|0)>>>1)+(bB&2081&bF)<<1)>>1]|(bF^bB)&2081)&65535;break}else{bB=b[(c[277213]|0)+(p<<1)>>1]|0;b5=(((bB&63454)+bC|0)>>>1)+(bB&bz&2081)&65535;break}}else{bz=e[(c[277225]|0)+(bA<<1)>>1]|0;bB=(a[(c[277215]|0)+p|0]&32)==0;if(bB){bC=c[277228]|0;b6=bC;b7=bC&-2082}else{bC=e[(c[277213]|0)+(p<<1)>>1]|0;b6=bC;b7=bC&63454}if(bB){b8=c[277228]|0}else{b8=e[(c[277213]|0)+(p<<1)>>1]|0}b5=((b8^bz)&2081|e[(c[277220]|0)+((bz&2081&b6)+((b7+(bz&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=b5;bz=(a[(c[277215]|0)+p|0]&32)==0;do{if((a[1108928]|0)==0){bB=e[(c[277213]|0)+(bE+8<<1)>>1]|0;bC=bB&63454;if(bz){bF=c[277228]|0;b9=(e[(c[277220]|0)+((((bF&-2082)+bC|0)>>>1)+(bB&2081&bF)<<1)>>1]|(bF^bB)&2081)&65535;break}else{bF=e[(c[277226]|0)+(bA<<1)>>1]|0;b9=(((bF&63454)+bC|0)>>>1)+(bB&2081&bF)&65535;break}}else{if(bz){bF=c[277228]|0;ca=bF;cb=(c[277220]|0)+((bF>>>1&2147482607)<<1)|0}else{bF=e[(c[277226]|0)+(bA<<1)>>1]|0;ca=bF;cb=(c[277220]|0)+((bF>>>1&31727)<<1)|0}b9=(e[cb>>1]|ca&2081)&65535}}while(0);bA=bE+7|0;b[(c[277218]|0)+(bA<<1)>>1]=b9;bz=a[1108909]|0;a[(c[277219]|0)+bA|0]=bz;a[(c[277219]|0)+p|0]=bz}}while(0);p=bL-1&255;if(p<<24>>24!=0){bK=p;v=8500}}if((v|0)==8500){v=0;p=bE+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){bz=a[s+3|0]|0;bA=bz&255;if(bz<<24>>24==0){break}do{if((a[1108928]|0)==0){bz=b[(c[277225]|0)+(bA<<1)>>1]|0;bF=bz&65535;bB=bF&63454;if((a[(c[277215]|0)+p|0]&32)==0){bC=c[277228]|0;cc=(e[(c[277220]|0)+((((bC&-2082)+bB|0)>>>1)+(bF&2081&bC)<<1)>>1]|(bC^bF)&2081)&65535;break}else{bF=b[(c[277213]|0)+(p<<1)>>1]|0;cc=(((bF&63454)+bB|0)>>>1)+(bF&bz&2081)&65535;break}}else{bz=e[(c[277225]|0)+(bA<<1)>>1]|0;bF=(a[(c[277215]|0)+p|0]&32)==0;if(bF){bB=c[277228]|0;cd=bB;ce=bB&-2082}else{bB=e[(c[277213]|0)+(p<<1)>>1]|0;cd=bB;ce=bB&63454}if(bF){cf=c[277228]|0}else{cf=e[(c[277213]|0)+(p<<1)>>1]|0}cc=((cf^bz)&2081|e[(c[277220]|0)+((bz&2081&cd)+((ce+(bz&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=cc;bz=(a[(c[277215]|0)+p|0]&32)==0;do{if((a[1108928]|0)==0){bF=e[(c[277213]|0)+(bE+10<<1)>>1]|0;bB=bF&63454;if(bz){bC=c[277228]|0;cg=(e[(c[277220]|0)+((((bC&-2082)+bB|0)>>>1)+(bF&2081&bC)<<1)>>1]|(bC^bF)&2081)&65535;break}else{bC=e[(c[277226]|0)+(bA<<1)>>1]|0;cg=(((bC&63454)+bB|0)>>>1)+(bF&2081&bC)&65535;break}}else{if(bz){bC=c[277228]|0;ch=bC;ci=(c[277220]|0)+((bC>>>1&2147482607)<<1)|0}else{bC=e[(c[277226]|0)+(bA<<1)>>1]|0;ch=bC;ci=(c[277220]|0)+((bC>>>1&31727)<<1)|0}cg=(e[ci>>1]|ch&2081)&65535}}while(0);bA=bE+9|0;b[(c[277218]|0)+(bA<<1)>>1]=cg;bz=a[1108909]|0;a[(c[277219]|0)+bA|0]=bz;a[(c[277219]|0)+p|0]=bz}}while(0);p=bK-1&255;if(p<<24>>24!=0){bH=p;v=8523}}if((v|0)==8523){v=0;p=bE+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){bz=a[s+2|0]|0;bA=bz&255;if(bz<<24>>24==0){break}do{if((a[1108928]|0)==0){bz=b[(c[277225]|0)+(bA<<1)>>1]|0;bC=bz&65535;bF=bC&63454;if((a[(c[277215]|0)+p|0]&32)==0){bB=c[277228]|0;cj=(e[(c[277220]|0)+((((bB&-2082)+bF|0)>>>1)+(bC&2081&bB)<<1)>>1]|(bB^bC)&2081)&65535;break}else{bC=b[(c[277213]|0)+(p<<1)>>1]|0;cj=(((bC&63454)+bF|0)>>>1)+(bC&bz&2081)&65535;break}}else{bz=e[(c[277225]|0)+(bA<<1)>>1]|0;bC=(a[(c[277215]|0)+p|0]&32)==0;if(bC){bF=c[277228]|0;ck=bF;cl=bF&-2082}else{bF=e[(c[277213]|0)+(p<<1)>>1]|0;ck=bF;cl=bF&63454}if(bC){cm=c[277228]|0}else{cm=e[(c[277213]|0)+(p<<1)>>1]|0}cj=((cm^bz)&2081|e[(c[277220]|0)+((bz&2081&ck)+((cl+(bz&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=cj;bz=(a[(c[277215]|0)+p|0]&32)==0;do{if((a[1108928]|0)==0){bC=e[(c[277213]|0)+(bE+12<<1)>>1]|0;bF=bC&63454;if(bz){bB=c[277228]|0;cn=(e[(c[277220]|0)+((((bB&-2082)+bF|0)>>>1)+(bC&2081&bB)<<1)>>1]|(bB^bC)&2081)&65535;break}else{bB=e[(c[277226]|0)+(bA<<1)>>1]|0;cn=(((bB&63454)+bF|0)>>>1)+(bC&2081&bB)&65535;break}}else{if(bz){bB=c[277228]|0;co=bB;cp=(c[277220]|0)+((bB>>>1&2147482607)<<1)|0}else{bB=e[(c[277226]|0)+(bA<<1)>>1]|0;co=bB;cp=(c[277220]|0)+((bB>>>1&31727)<<1)|0}cn=(e[cp>>1]|co&2081)&65535}}while(0);bA=bE+11|0;b[(c[277218]|0)+(bA<<1)>>1]=cn;bz=a[1108909]|0;a[(c[277219]|0)+bA|0]=bz;a[(c[277219]|0)+p|0]=bz}}while(0);p=bH-1&255;if(p<<24>>24!=0){bI=p;v=8546}}if((v|0)==8546){v=0;p=bE+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){bz=a[s+1|0]|0;bA=bz&255;if(bz<<24>>24==0){break}do{if((a[1108928]|0)==0){bz=b[(c[277225]|0)+(bA<<1)>>1]|0;bB=bz&65535;bC=bB&63454;if((a[(c[277215]|0)+p|0]&32)==0){bF=c[277228]|0;cq=(e[(c[277220]|0)+((((bF&-2082)+bC|0)>>>1)+(bB&2081&bF)<<1)>>1]|(bF^bB)&2081)&65535;break}else{bB=b[(c[277213]|0)+(p<<1)>>1]|0;cq=(((bB&63454)+bC|0)>>>1)+(bB&bz&2081)&65535;break}}else{bz=e[(c[277225]|0)+(bA<<1)>>1]|0;bB=(a[(c[277215]|0)+p|0]&32)==0;if(bB){bC=c[277228]|0;cr=bC;cs=bC&-2082}else{bC=e[(c[277213]|0)+(p<<1)>>1]|0;cr=bC;cs=bC&63454}if(bB){ct=c[277228]|0}else{ct=e[(c[277213]|0)+(p<<1)>>1]|0}cq=((ct^bz)&2081|e[(c[277220]|0)+((bz&2081&cr)+((cs+(bz&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=cq;bz=(a[(c[277215]|0)+p|0]&32)==0;do{if((a[1108928]|0)==0){bB=e[(c[277213]|0)+(bE+14<<1)>>1]|0;bC=bB&63454;if(bz){bF=c[277228]|0;cu=(e[(c[277220]|0)+((((bF&-2082)+bC|0)>>>1)+(bB&2081&bF)<<1)>>1]|(bF^bB)&2081)&65535;break}else{bF=e[(c[277226]|0)+(bA<<1)>>1]|0;cu=(((bF&63454)+bC|0)>>>1)+(bB&2081&bF)&65535;break}}else{if(bz){bF=c[277228]|0;cv=bF;cw=(c[277220]|0)+((bF>>>1&2147482607)<<1)|0}else{bF=e[(c[277226]|0)+(bA<<1)>>1]|0;cv=bF;cw=(c[277220]|0)+((bF>>>1&31727)<<1)|0}cu=(e[cw>>1]|cv&2081)&65535}}while(0);bA=bE+13|0;b[(c[277218]|0)+(bA<<1)>>1]=cu;bz=a[1108909]|0;a[(c[277219]|0)+bA|0]=bz;a[(c[277219]|0)+p|0]=bz}}while(0);if(bI<<24>>24!=1){v=8569}}do{if((v|0)==8569){v=0;p=bE+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+p|0]|0)){break}bz=a[s]|0;bA=bz&255;if(bz<<24>>24==0){break}do{if((a[1108928]|0)==0){bz=b[(c[277225]|0)+(bA<<1)>>1]|0;bF=bz&65535;bB=bF&63454;if((a[(c[277215]|0)+p|0]&32)==0){bC=c[277228]|0;cx=(e[(c[277220]|0)+((((bC&-2082)+bB|0)>>>1)+(bF&2081&bC)<<1)>>1]|(bC^bF)&2081)&65535;break}else{bF=b[(c[277213]|0)+(p<<1)>>1]|0;cx=(((bF&63454)+bB|0)>>>1)+(bF&bz&2081)&65535;break}}else{bz=e[(c[277225]|0)+(bA<<1)>>1]|0;bF=(a[(c[277215]|0)+p|0]&32)==0;if(bF){bB=c[277228]|0;cy=bB;cz=bB&-2082}else{bB=e[(c[277213]|0)+(p<<1)>>1]|0;cy=bB;cz=bB&63454}if(bF){cA=c[277228]|0}else{cA=e[(c[277213]|0)+(p<<1)>>1]|0}cx=((cA^bz)&2081|e[(c[277220]|0)+((bz&2081&cy)+((cz+(bz&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=cx;bz=(a[(c[277215]|0)+p|0]&32)==0;do{if((a[1108928]|0)==0){bF=e[(c[277213]|0)+(bE+16<<1)>>1]|0;bB=bF&63454;if(bz){bC=c[277228]|0;cB=(e[(c[277220]|0)+((((bC&-2082)+bB|0)>>>1)+(bF&2081&bC)<<1)>>1]|(bC^bF)&2081)&65535;break}else{bC=e[(c[277226]|0)+(bA<<1)>>1]|0;cB=(((bC&63454)+bB|0)>>>1)+(bF&2081&bC)&65535;break}}else{if(bz){bC=c[277228]|0;cC=bC;cD=(c[277220]|0)+((bC>>>1&2147482607)<<1)|0}else{bC=e[(c[277226]|0)+(bA<<1)>>1]|0;cC=bC;cD=(c[277220]|0)+((bC>>>1&31727)<<1)|0}cB=(e[cD>>1]|cC&2081)&65535}}while(0);bA=bE+15|0;b[(c[277218]|0)+(bA<<1)>>1]=cB;bz=a[1108909]|0;a[(c[277219]|0)+bA|0]=bz;a[(c[277219]|0)+p|0]=bz}}while(0);bz=bD-1|0;if((bz|0)>0){s=s-8|0;bD=bz;bE=(c[277223]|0)+bE|0}else{break}}return}else{if(!j){return}j=i&255;i=j-1&255;bE=i<<24>>24==0;bD=aG;aG=k;k=g;while(1){switch(h|0){case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+k|0]|0)){g=a[bD]|0;s=g&255;if(g<<24>>24==0){break}do{if((a[1108928]|0)==0){g=b[(c[277225]|0)+(s<<1)>>1]|0;cB=g&65535;cC=cB&63454;if((a[(c[277215]|0)+k|0]&32)==0){cD=c[277228]|0;cE=(e[(c[277220]|0)+((((cD&-2082)+cC|0)>>>1)+(cB&2081&cD)<<1)>>1]|(cD^cB)&2081)&65535;break}else{cB=b[(c[277213]|0)+(k<<1)>>1]|0;cE=(((cB&63454)+cC|0)>>>1)+(cB&g&2081)&65535;break}}else{g=e[(c[277225]|0)+(s<<1)>>1]|0;cB=(a[(c[277215]|0)+k|0]&32)==0;if(cB){cC=c[277228]|0;cF=cC;cG=cC&-2082}else{cC=e[(c[277213]|0)+(k<<1)>>1]|0;cF=cC;cG=cC&63454}if(cB){cH=c[277228]|0}else{cH=e[(c[277213]|0)+(k<<1)>>1]|0}cE=((cH^g)&2081|e[(c[277220]|0)+((g&2081&cF)+((cG+(g&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(k<<1)>>1]=cE;p=(a[(c[277215]|0)+k|0]&32)==0;do{if((a[1108928]|0)==0){g=e[(c[277213]|0)+(k+2<<1)>>1]|0;cB=g&63454;if(p){cC=c[277228]|0;cI=(e[(c[277220]|0)+((((cC&-2082)+cB|0)>>>1)+(g&2081&cC)<<1)>>1]|(cC^g)&2081)&65535;break}else{cC=e[(c[277226]|0)+(s<<1)>>1]|0;cI=(((cC&63454)+cB|0)>>>1)+(g&2081&cC)&65535;break}}else{if(p){cC=c[277228]|0;cJ=cC;cK=(c[277220]|0)+((cC>>>1&2147482607)<<1)|0}else{cC=e[(c[277226]|0)+(s<<1)>>1]|0;cJ=cC;cK=(c[277220]|0)+((cC>>>1&31727)<<1)|0}cI=(e[cK>>1]|cJ&2081)&65535}}while(0);s=k+1|0;b[(c[277218]|0)+(s<<1)>>1]=cI;p=a[1108909]|0;a[(c[277219]|0)+s|0]=p;a[(c[277219]|0)+k|0]=p}}while(0);if(!bE){cL=i;v=8246}break};case 3:{cM=j;v=8292;break};case 7:{v=8384;break};case 6:{cN=j;v=8361;break};case 5:{cO=j;v=8338;break};case 1:{cL=j;v=8246;break};case 4:{cP=j;v=8315;break};case 2:{cQ=j;v=8269;break};default:{}}if((v|0)==8246){v=0;p=k+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){s=a[bD+1|0]|0;cC=s&255;if(s<<24>>24==0){break}do{if((a[1108928]|0)==0){s=b[(c[277225]|0)+(cC<<1)>>1]|0;g=s&65535;cB=g&63454;if((a[(c[277215]|0)+p|0]&32)==0){cD=c[277228]|0;cR=(e[(c[277220]|0)+((((cD&-2082)+cB|0)>>>1)+(g&2081&cD)<<1)>>1]|(cD^g)&2081)&65535;break}else{g=b[(c[277213]|0)+(p<<1)>>1]|0;cR=(((g&63454)+cB|0)>>>1)+(g&s&2081)&65535;break}}else{s=e[(c[277225]|0)+(cC<<1)>>1]|0;g=(a[(c[277215]|0)+p|0]&32)==0;if(g){cB=c[277228]|0;cS=cB;cT=cB&-2082}else{cB=e[(c[277213]|0)+(p<<1)>>1]|0;cS=cB;cT=cB&63454}if(g){cU=c[277228]|0}else{cU=e[(c[277213]|0)+(p<<1)>>1]|0}cR=((cU^s)&2081|e[(c[277220]|0)+((s&2081&cS)+((cT+(s&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=cR;s=(a[(c[277215]|0)+p|0]&32)==0;do{if((a[1108928]|0)==0){g=e[(c[277213]|0)+(k+4<<1)>>1]|0;cB=g&63454;if(s){cD=c[277228]|0;cV=(e[(c[277220]|0)+((((cD&-2082)+cB|0)>>>1)+(g&2081&cD)<<1)>>1]|(cD^g)&2081)&65535;break}else{cD=e[(c[277226]|0)+(cC<<1)>>1]|0;cV=(((cD&63454)+cB|0)>>>1)+(g&2081&cD)&65535;break}}else{if(s){cD=c[277228]|0;cW=cD;cX=(c[277220]|0)+((cD>>>1&2147482607)<<1)|0}else{cD=e[(c[277226]|0)+(cC<<1)>>1]|0;cW=cD;cX=(c[277220]|0)+((cD>>>1&31727)<<1)|0}cV=(e[cX>>1]|cW&2081)&65535}}while(0);cC=k+3|0;b[(c[277218]|0)+(cC<<1)>>1]=cV;s=a[1108909]|0;a[(c[277219]|0)+cC|0]=s;a[(c[277219]|0)+p|0]=s}}while(0);p=cL-1&255;if(p<<24>>24!=0){cQ=p;v=8269}}if((v|0)==8269){v=0;p=k+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){s=a[bD+2|0]|0;cC=s&255;if(s<<24>>24==0){break}do{if((a[1108928]|0)==0){s=b[(c[277225]|0)+(cC<<1)>>1]|0;cD=s&65535;g=cD&63454;if((a[(c[277215]|0)+p|0]&32)==0){cB=c[277228]|0;cY=(e[(c[277220]|0)+((((cB&-2082)+g|0)>>>1)+(cD&2081&cB)<<1)>>1]|(cB^cD)&2081)&65535;break}else{cD=b[(c[277213]|0)+(p<<1)>>1]|0;cY=(((cD&63454)+g|0)>>>1)+(cD&s&2081)&65535;break}}else{s=e[(c[277225]|0)+(cC<<1)>>1]|0;cD=(a[(c[277215]|0)+p|0]&32)==0;if(cD){g=c[277228]|0;cZ=g;c_=g&-2082}else{g=e[(c[277213]|0)+(p<<1)>>1]|0;cZ=g;c_=g&63454}if(cD){c$=c[277228]|0}else{c$=e[(c[277213]|0)+(p<<1)>>1]|0}cY=((c$^s)&2081|e[(c[277220]|0)+((s&2081&cZ)+((c_+(s&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=cY;s=(a[(c[277215]|0)+p|0]&32)==0;do{if((a[1108928]|0)==0){cD=e[(c[277213]|0)+(k+6<<1)>>1]|0;g=cD&63454;if(s){cB=c[277228]|0;c0=(e[(c[277220]|0)+((((cB&-2082)+g|0)>>>1)+(cD&2081&cB)<<1)>>1]|(cB^cD)&2081)&65535;break}else{cB=e[(c[277226]|0)+(cC<<1)>>1]|0;c0=(((cB&63454)+g|0)>>>1)+(cD&2081&cB)&65535;break}}else{if(s){cB=c[277228]|0;c1=cB;c2=(c[277220]|0)+((cB>>>1&2147482607)<<1)|0}else{cB=e[(c[277226]|0)+(cC<<1)>>1]|0;c1=cB;c2=(c[277220]|0)+((cB>>>1&31727)<<1)|0}c0=(e[c2>>1]|c1&2081)&65535}}while(0);cC=k+5|0;b[(c[277218]|0)+(cC<<1)>>1]=c0;s=a[1108909]|0;a[(c[277219]|0)+cC|0]=s;a[(c[277219]|0)+p|0]=s}}while(0);p=cQ-1&255;if(p<<24>>24!=0){cM=p;v=8292}}if((v|0)==8292){v=0;p=k+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){s=a[bD+3|0]|0;cC=s&255;if(s<<24>>24==0){break}do{if((a[1108928]|0)==0){s=b[(c[277225]|0)+(cC<<1)>>1]|0;cB=s&65535;cD=cB&63454;if((a[(c[277215]|0)+p|0]&32)==0){g=c[277228]|0;c3=(e[(c[277220]|0)+((((g&-2082)+cD|0)>>>1)+(cB&2081&g)<<1)>>1]|(g^cB)&2081)&65535;break}else{cB=b[(c[277213]|0)+(p<<1)>>1]|0;c3=(((cB&63454)+cD|0)>>>1)+(cB&s&2081)&65535;break}}else{s=e[(c[277225]|0)+(cC<<1)>>1]|0;cB=(a[(c[277215]|0)+p|0]&32)==0;if(cB){cD=c[277228]|0;c4=cD;c5=cD&-2082}else{cD=e[(c[277213]|0)+(p<<1)>>1]|0;c4=cD;c5=cD&63454}if(cB){c6=c[277228]|0}else{c6=e[(c[277213]|0)+(p<<1)>>1]|0}c3=((c6^s)&2081|e[(c[277220]|0)+((s&2081&c4)+((c5+(s&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=c3;s=(a[(c[277215]|0)+p|0]&32)==0;do{if((a[1108928]|0)==0){cB=e[(c[277213]|0)+(k+8<<1)>>1]|0;cD=cB&63454;if(s){g=c[277228]|0;c7=(e[(c[277220]|0)+((((g&-2082)+cD|0)>>>1)+(cB&2081&g)<<1)>>1]|(g^cB)&2081)&65535;break}else{g=e[(c[277226]|0)+(cC<<1)>>1]|0;c7=(((g&63454)+cD|0)>>>1)+(cB&2081&g)&65535;break}}else{if(s){g=c[277228]|0;c8=g;c9=(c[277220]|0)+((g>>>1&2147482607)<<1)|0}else{g=e[(c[277226]|0)+(cC<<1)>>1]|0;c8=g;c9=(c[277220]|0)+((g>>>1&31727)<<1)|0}c7=(e[c9>>1]|c8&2081)&65535}}while(0);cC=k+7|0;b[(c[277218]|0)+(cC<<1)>>1]=c7;s=a[1108909]|0;a[(c[277219]|0)+cC|0]=s;a[(c[277219]|0)+p|0]=s}}while(0);p=cM-1&255;if(p<<24>>24!=0){cP=p;v=8315}}if((v|0)==8315){v=0;p=k+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){s=a[bD+4|0]|0;cC=s&255;if(s<<24>>24==0){break}do{if((a[1108928]|0)==0){s=b[(c[277225]|0)+(cC<<1)>>1]|0;g=s&65535;cB=g&63454;if((a[(c[277215]|0)+p|0]&32)==0){cD=c[277228]|0;da=(e[(c[277220]|0)+((((cD&-2082)+cB|0)>>>1)+(g&2081&cD)<<1)>>1]|(cD^g)&2081)&65535;break}else{g=b[(c[277213]|0)+(p<<1)>>1]|0;da=(((g&63454)+cB|0)>>>1)+(g&s&2081)&65535;break}}else{s=e[(c[277225]|0)+(cC<<1)>>1]|0;g=(a[(c[277215]|0)+p|0]&32)==0;if(g){cB=c[277228]|0;db=cB;dc=cB&-2082}else{cB=e[(c[277213]|0)+(p<<1)>>1]|0;db=cB;dc=cB&63454}if(g){dd=c[277228]|0}else{dd=e[(c[277213]|0)+(p<<1)>>1]|0}da=((dd^s)&2081|e[(c[277220]|0)+((s&2081&db)+((dc+(s&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=da;s=(a[(c[277215]|0)+p|0]&32)==0;do{if((a[1108928]|0)==0){g=e[(c[277213]|0)+(k+10<<1)>>1]|0;cB=g&63454;if(s){cD=c[277228]|0;de=(e[(c[277220]|0)+((((cD&-2082)+cB|0)>>>1)+(g&2081&cD)<<1)>>1]|(cD^g)&2081)&65535;break}else{cD=e[(c[277226]|0)+(cC<<1)>>1]|0;de=(((cD&63454)+cB|0)>>>1)+(g&2081&cD)&65535;break}}else{if(s){cD=c[277228]|0;df=cD;dg=(c[277220]|0)+((cD>>>1&2147482607)<<1)|0}else{cD=e[(c[277226]|0)+(cC<<1)>>1]|0;df=cD;dg=(c[277220]|0)+((cD>>>1&31727)<<1)|0}de=(e[dg>>1]|df&2081)&65535}}while(0);cC=k+9|0;b[(c[277218]|0)+(cC<<1)>>1]=de;s=a[1108909]|0;a[(c[277219]|0)+cC|0]=s;a[(c[277219]|0)+p|0]=s}}while(0);p=cP-1&255;if(p<<24>>24!=0){cO=p;v=8338}}if((v|0)==8338){v=0;p=k+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){s=a[bD+5|0]|0;cC=s&255;if(s<<24>>24==0){break}do{if((a[1108928]|0)==0){s=b[(c[277225]|0)+(cC<<1)>>1]|0;cD=s&65535;g=cD&63454;if((a[(c[277215]|0)+p|0]&32)==0){cB=c[277228]|0;dh=(e[(c[277220]|0)+((((cB&-2082)+g|0)>>>1)+(cD&2081&cB)<<1)>>1]|(cB^cD)&2081)&65535;break}else{cD=b[(c[277213]|0)+(p<<1)>>1]|0;dh=(((cD&63454)+g|0)>>>1)+(cD&s&2081)&65535;break}}else{s=e[(c[277225]|0)+(cC<<1)>>1]|0;cD=(a[(c[277215]|0)+p|0]&32)==0;if(cD){g=c[277228]|0;di=g;dj=g&-2082}else{g=e[(c[277213]|0)+(p<<1)>>1]|0;di=g;dj=g&63454}if(cD){dk=c[277228]|0}else{dk=e[(c[277213]|0)+(p<<1)>>1]|0}dh=((dk^s)&2081|e[(c[277220]|0)+((s&2081&di)+((dj+(s&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=dh;s=(a[(c[277215]|0)+p|0]&32)==0;do{if((a[1108928]|0)==0){cD=e[(c[277213]|0)+(k+12<<1)>>1]|0;g=cD&63454;if(s){cB=c[277228]|0;dl=(e[(c[277220]|0)+((((cB&-2082)+g|0)>>>1)+(cD&2081&cB)<<1)>>1]|(cB^cD)&2081)&65535;break}else{cB=e[(c[277226]|0)+(cC<<1)>>1]|0;dl=(((cB&63454)+g|0)>>>1)+(cD&2081&cB)&65535;break}}else{if(s){cB=c[277228]|0;dm=cB;dn=(c[277220]|0)+((cB>>>1&2147482607)<<1)|0}else{cB=e[(c[277226]|0)+(cC<<1)>>1]|0;dm=cB;dn=(c[277220]|0)+((cB>>>1&31727)<<1)|0}dl=(e[dn>>1]|dm&2081)&65535}}while(0);cC=k+11|0;b[(c[277218]|0)+(cC<<1)>>1]=dl;s=a[1108909]|0;a[(c[277219]|0)+cC|0]=s;a[(c[277219]|0)+p|0]=s}}while(0);p=cO-1&255;if(p<<24>>24!=0){cN=p;v=8361}}if((v|0)==8361){v=0;p=k+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){s=a[bD+6|0]|0;cC=s&255;if(s<<24>>24==0){break}do{if((a[1108928]|0)==0){s=b[(c[277225]|0)+(cC<<1)>>1]|0;cB=s&65535;cD=cB&63454;if((a[(c[277215]|0)+p|0]&32)==0){g=c[277228]|0;dp=(e[(c[277220]|0)+((((g&-2082)+cD|0)>>>1)+(cB&2081&g)<<1)>>1]|(g^cB)&2081)&65535;break}else{cB=b[(c[277213]|0)+(p<<1)>>1]|0;dp=(((cB&63454)+cD|0)>>>1)+(cB&s&2081)&65535;break}}else{s=e[(c[277225]|0)+(cC<<1)>>1]|0;cB=(a[(c[277215]|0)+p|0]&32)==0;if(cB){cD=c[277228]|0;dq=cD;dr=cD&-2082}else{cD=e[(c[277213]|0)+(p<<1)>>1]|0;dq=cD;dr=cD&63454}if(cB){ds=c[277228]|0}else{ds=e[(c[277213]|0)+(p<<1)>>1]|0}dp=((ds^s)&2081|e[(c[277220]|0)+((s&2081&dq)+((dr+(s&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=dp;s=(a[(c[277215]|0)+p|0]&32)==0;do{if((a[1108928]|0)==0){cB=e[(c[277213]|0)+(k+14<<1)>>1]|0;cD=cB&63454;if(s){g=c[277228]|0;dt=(e[(c[277220]|0)+((((g&-2082)+cD|0)>>>1)+(cB&2081&g)<<1)>>1]|(g^cB)&2081)&65535;break}else{g=e[(c[277226]|0)+(cC<<1)>>1]|0;dt=(((g&63454)+cD|0)>>>1)+(cB&2081&g)&65535;break}}else{if(s){g=c[277228]|0;du=g;dv=(c[277220]|0)+((g>>>1&2147482607)<<1)|0}else{g=e[(c[277226]|0)+(cC<<1)>>1]|0;du=g;dv=(c[277220]|0)+((g>>>1&31727)<<1)|0}dt=(e[dv>>1]|du&2081)&65535}}while(0);cC=k+13|0;b[(c[277218]|0)+(cC<<1)>>1]=dt;s=a[1108909]|0;a[(c[277219]|0)+cC|0]=s;a[(c[277219]|0)+p|0]=s}}while(0);if(cN<<24>>24!=1){v=8384}}do{if((v|0)==8384){v=0;p=k+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+p|0]|0)){break}s=a[bD+7|0]|0;cC=s&255;if(s<<24>>24==0){break}do{if((a[1108928]|0)==0){s=b[(c[277225]|0)+(cC<<1)>>1]|0;g=s&65535;cB=g&63454;if((a[(c[277215]|0)+p|0]&32)==0){cD=c[277228]|0;dw=(e[(c[277220]|0)+((((cD&-2082)+cB|0)>>>1)+(g&2081&cD)<<1)>>1]|(cD^g)&2081)&65535;break}else{g=b[(c[277213]|0)+(p<<1)>>1]|0;dw=(((g&63454)+cB|0)>>>1)+(g&s&2081)&65535;break}}else{s=e[(c[277225]|0)+(cC<<1)>>1]|0;g=(a[(c[277215]|0)+p|0]&32)==0;if(g){cB=c[277228]|0;dx=cB;dy=cB&-2082}else{cB=e[(c[277213]|0)+(p<<1)>>1]|0;dx=cB;dy=cB&63454}if(g){dz=c[277228]|0}else{dz=e[(c[277213]|0)+(p<<1)>>1]|0}dw=((dz^s)&2081|e[(c[277220]|0)+((s&2081&dx)+((dy+(s&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=dw;s=(a[(c[277215]|0)+p|0]&32)==0;do{if((a[1108928]|0)==0){g=e[(c[277213]|0)+(k+16<<1)>>1]|0;cB=g&63454;if(s){cD=c[277228]|0;dA=(e[(c[277220]|0)+((((cD&-2082)+cB|0)>>>1)+(g&2081&cD)<<1)>>1]|(cD^g)&2081)&65535;break}else{cD=e[(c[277226]|0)+(cC<<1)>>1]|0;dA=(((cD&63454)+cB|0)>>>1)+(g&2081&cD)&65535;break}}else{if(s){cD=c[277228]|0;dB=cD;dC=(c[277220]|0)+((cD>>>1&2147482607)<<1)|0}else{cD=e[(c[277226]|0)+(cC<<1)>>1]|0;dB=cD;dC=(c[277220]|0)+((cD>>>1&31727)<<1)|0}dA=(e[dC>>1]|dB&2081)&65535}}while(0);cC=k+15|0;b[(c[277218]|0)+(cC<<1)>>1]=dA;s=a[1108909]|0;a[(c[277219]|0)+cC|0]=s;a[(c[277219]|0)+p|0]=s}}while(0);s=aG-1|0;if((s|0)>0){bD=bD-8|0;aG=s;k=(c[277223]|0)+k|0}else{break}}return}}function VE(e,f,g,h,i,j){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0,cf=0,cg=0,ch=0,ci=0,cj=0,ck=0,cl=0,cm=0,cn=0,co=0,cp=0,cq=0,cr=0,cs=0,ct=0,cu=0,cv=0,cw=0,cx=0,cy=0,cz=0,cA=0,cB=0,cC=0,cD=0,cE=0,cF=0,cG=0,cH=0,cI=0,cJ=0,cK=0,cL=0,cM=0,cN=0,cO=0,cP=0,cQ=0,cR=0,cS=0,cT=0,cU=0,cV=0,cW=0,cX=0,cY=0,cZ=0,c_=0,c$=0,c0=0,c1=0,c2=0,c3=0,c4=0,c5=0,c6=0,c7=0,c8=0,c9=0,da=0,db=0,dc=0,dd=0,de=0,df=0,dg=0,dh=0,di=0,dj=0,dk=0,dl=0,dm=0,dn=0,dp=0,dq=0,dr=0,ds=0,dt=0,du=0,dv=0,dw=0,dx=0,dy=0,dz=0,dA=0,dB=0;k=e&1023;l=c[348606]|0;m=(k<<l)+(c[348604]|0)|0;if((e&256|0)==0){n=m}else{n=(c[348602]|0)+m|0}m=n&65535;n=m>>>(l>>>0);l=(e&16384|0)!=0;o=n<<6;do{if(l){p=(c[348622]|0)+o|0;if((a[(c[348618]|0)+n|0]|0)!=0){q=p;break}r=fi[c[348636]&63](p,m,k)|0;a[(c[348618]|0)+n|0]=r;q=p}else{p=(c[348624]|0)+o|0;if((a[(c[348620]|0)+n|0]|0)!=0){q=p;break}r=fi[c[348638]&63](p,m,k)|0;a[(c[348620]|0)+n|0]=r;q=p}}while(0);if((a[(c[348620]|0)+n|0]|0)==2){return}if((a[1394464]|0)==0){s=1106168+((e>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){n=d[1044485]|0;c[276541]=7080+(n<<5);k=0;do{m=k<<1&2;o=k&2;p=k&4;r=0;do{b[1125528+(k<<9)+(r<<1)>>1]=d[(r>>>1&28|o)+(7080+(n<<5))|0]<<6|d[(r<<2&28|m)+(7080+(n<<5))|0]<<11|d[(r>>>3&24|p)+(7080+(n<<5))|0];r=r+1|0;}while(r>>>0<256);k=k+1|0;}while(k>>>0<8);a[1106089]=0}s=1125528+((e>>>10&7)<<9)|0}c[277226]=s;c[277225]=(a[1108928]|0)!=0?1393712:s;if((e&49152|0)==0){if((j|0)<=0){return}s=h&255;k=s-1&255;n=k<<24>>24==0;r=q+i|0;p=j;m=f;while(1){switch(g|0){case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+m|0]|0)){o=a[r]|0;t=o&255;if(o<<24>>24==0){break}o=b[(c[277225]|0)+(t<<1)>>1]|0;if((a[(c[277215]|0)+m|0]&32)==0){u=c[277228]&65535}else{u=b[(c[277213]|0)+(m<<1)>>1]|0}v=o&-2048;w=u&-2048;x=(v&65535)>(w&65535)?v-w&65535:0;w=o&2016;v=u&2016;if((w&65535)>(v&65535)){y=(w-v&65535)+x&65535}else{y=x}x=o&31;o=u&31;if((x&65535)>(o&65535)){z=(x-o&65535)+y&65535}else{z=y}b[(c[277218]|0)+(m<<1)>>1]=z;if((a[1108928]|0)==0){A=b[(c[277213]|0)+(m+2<<1)>>1]|0}else{A=0}if((a[(c[277215]|0)+m|0]&32)==0){B=c[277228]&65535}else{B=b[(c[277226]|0)+(t<<1)>>1]|0}t=A&-2048;o=B&-2048;x=(t&65535)>(o&65535)?t-o&65535:0;o=A&2016;t=B&2016;if((o&65535)>(t&65535)){C=(o-t&65535)+x&65535}else{C=x}x=A&31;t=B&31;if((x&65535)>(t&65535)){D=(x-t&65535)+C&65535}else{D=C}t=m+1|0;b[(c[277218]|0)+(t<<1)>>1]=D;x=a[1108909]|0;a[(c[277219]|0)+t|0]=x;a[(c[277219]|0)+m|0]=x}}while(0);if(!n){E=k;F=8643}break};case 5:{G=s;F=8723;break};case 7:{F=8763;break};case 4:{H=s;F=8703;break};case 6:{I=s;F=8743;break};case 3:{J=s;F=8683;break};case 1:{E=s;F=8643;break};case 2:{K=s;F=8663;break};default:{}}if((F|0)==8643){F=0;x=m+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+x|0]|0)){t=a[r+1|0]|0;o=t&255;if(t<<24>>24==0){break}t=b[(c[277225]|0)+(o<<1)>>1]|0;if((a[(c[277215]|0)+x|0]&32)==0){L=c[277228]&65535}else{L=b[(c[277213]|0)+(x<<1)>>1]|0}v=t&-2048;w=L&-2048;M=(v&65535)>(w&65535)?v-w&65535:0;w=t&2016;v=L&2016;if((w&65535)>(v&65535)){N=(w-v&65535)+M&65535}else{N=M}M=t&31;t=L&31;if((M&65535)>(t&65535)){O=(M-t&65535)+N&65535}else{O=N}b[(c[277218]|0)+(x<<1)>>1]=O;if((a[1108928]|0)==0){P=b[(c[277213]|0)+(m+4<<1)>>1]|0}else{P=0}if((a[(c[277215]|0)+x|0]&32)==0){Q=c[277228]&65535}else{Q=b[(c[277226]|0)+(o<<1)>>1]|0}o=P&-2048;t=Q&-2048;M=(o&65535)>(t&65535)?o-t&65535:0;t=P&2016;o=Q&2016;if((t&65535)>(o&65535)){R=(t-o&65535)+M&65535}else{R=M}M=P&31;o=Q&31;if((M&65535)>(o&65535)){S=(M-o&65535)+R&65535}else{S=R}o=m+3|0;b[(c[277218]|0)+(o<<1)>>1]=S;M=a[1108909]|0;a[(c[277219]|0)+o|0]=M;a[(c[277219]|0)+x|0]=M}}while(0);x=E-1&255;if(x<<24>>24!=0){K=x;F=8663}}if((F|0)==8663){F=0;x=m+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+x|0]|0)){M=a[r+2|0]|0;o=M&255;if(M<<24>>24==0){break}M=b[(c[277225]|0)+(o<<1)>>1]|0;if((a[(c[277215]|0)+x|0]&32)==0){T=c[277228]&65535}else{T=b[(c[277213]|0)+(x<<1)>>1]|0}t=M&-2048;v=T&-2048;w=(t&65535)>(v&65535)?t-v&65535:0;v=M&2016;t=T&2016;if((v&65535)>(t&65535)){U=(v-t&65535)+w&65535}else{U=w}w=M&31;M=T&31;if((w&65535)>(M&65535)){V=(w-M&65535)+U&65535}else{V=U}b[(c[277218]|0)+(x<<1)>>1]=V;if((a[1108928]|0)==0){W=b[(c[277213]|0)+(m+6<<1)>>1]|0}else{W=0}if((a[(c[277215]|0)+x|0]&32)==0){X=c[277228]&65535}else{X=b[(c[277226]|0)+(o<<1)>>1]|0}o=W&-2048;M=X&-2048;w=(o&65535)>(M&65535)?o-M&65535:0;M=W&2016;o=X&2016;if((M&65535)>(o&65535)){Y=(M-o&65535)+w&65535}else{Y=w}w=W&31;o=X&31;if((w&65535)>(o&65535)){Z=(w-o&65535)+Y&65535}else{Z=Y}o=m+5|0;b[(c[277218]|0)+(o<<1)>>1]=Z;w=a[1108909]|0;a[(c[277219]|0)+o|0]=w;a[(c[277219]|0)+x|0]=w}}while(0);x=K-1&255;if(x<<24>>24!=0){J=x;F=8683}}if((F|0)==8683){F=0;x=m+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+x|0]|0)){w=a[r+3|0]|0;o=w&255;if(w<<24>>24==0){break}w=b[(c[277225]|0)+(o<<1)>>1]|0;if((a[(c[277215]|0)+x|0]&32)==0){_=c[277228]&65535}else{_=b[(c[277213]|0)+(x<<1)>>1]|0}M=w&-2048;t=_&-2048;v=(M&65535)>(t&65535)?M-t&65535:0;t=w&2016;M=_&2016;if((t&65535)>(M&65535)){$=(t-M&65535)+v&65535}else{$=v}v=w&31;w=_&31;if((v&65535)>(w&65535)){aa=(v-w&65535)+$&65535}else{aa=$}b[(c[277218]|0)+(x<<1)>>1]=aa;if((a[1108928]|0)==0){ab=b[(c[277213]|0)+(m+8<<1)>>1]|0}else{ab=0}if((a[(c[277215]|0)+x|0]&32)==0){ac=c[277228]&65535}else{ac=b[(c[277226]|0)+(o<<1)>>1]|0}o=ab&-2048;w=ac&-2048;v=(o&65535)>(w&65535)?o-w&65535:0;w=ab&2016;o=ac&2016;if((w&65535)>(o&65535)){ad=(w-o&65535)+v&65535}else{ad=v}v=ab&31;o=ac&31;if((v&65535)>(o&65535)){ae=(v-o&65535)+ad&65535}else{ae=ad}o=m+7|0;b[(c[277218]|0)+(o<<1)>>1]=ae;v=a[1108909]|0;a[(c[277219]|0)+o|0]=v;a[(c[277219]|0)+x|0]=v}}while(0);x=J-1&255;if(x<<24>>24!=0){H=x;F=8703}}if((F|0)==8703){F=0;x=m+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+x|0]|0)){v=a[r+4|0]|0;o=v&255;if(v<<24>>24==0){break}v=b[(c[277225]|0)+(o<<1)>>1]|0;if((a[(c[277215]|0)+x|0]&32)==0){af=c[277228]&65535}else{af=b[(c[277213]|0)+(x<<1)>>1]|0}w=v&-2048;M=af&-2048;t=(w&65535)>(M&65535)?w-M&65535:0;M=v&2016;w=af&2016;if((M&65535)>(w&65535)){ag=(M-w&65535)+t&65535}else{ag=t}t=v&31;v=af&31;if((t&65535)>(v&65535)){ah=(t-v&65535)+ag&65535}else{ah=ag}b[(c[277218]|0)+(x<<1)>>1]=ah;if((a[1108928]|0)==0){ai=b[(c[277213]|0)+(m+10<<1)>>1]|0}else{ai=0}if((a[(c[277215]|0)+x|0]&32)==0){aj=c[277228]&65535}else{aj=b[(c[277226]|0)+(o<<1)>>1]|0}o=ai&-2048;v=aj&-2048;t=(o&65535)>(v&65535)?o-v&65535:0;v=ai&2016;o=aj&2016;if((v&65535)>(o&65535)){ak=(v-o&65535)+t&65535}else{ak=t}t=ai&31;o=aj&31;if((t&65535)>(o&65535)){al=(t-o&65535)+ak&65535}else{al=ak}o=m+9|0;b[(c[277218]|0)+(o<<1)>>1]=al;t=a[1108909]|0;a[(c[277219]|0)+o|0]=t;a[(c[277219]|0)+x|0]=t}}while(0);x=H-1&255;if(x<<24>>24!=0){G=x;F=8723}}if((F|0)==8723){F=0;x=m+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+x|0]|0)){t=a[r+5|0]|0;o=t&255;if(t<<24>>24==0){break}t=b[(c[277225]|0)+(o<<1)>>1]|0;if((a[(c[277215]|0)+x|0]&32)==0){am=c[277228]&65535}else{am=b[(c[277213]|0)+(x<<1)>>1]|0}v=t&-2048;w=am&-2048;M=(v&65535)>(w&65535)?v-w&65535:0;w=t&2016;v=am&2016;if((w&65535)>(v&65535)){an=(w-v&65535)+M&65535}else{an=M}M=t&31;t=am&31;if((M&65535)>(t&65535)){ao=(M-t&65535)+an&65535}else{ao=an}b[(c[277218]|0)+(x<<1)>>1]=ao;if((a[1108928]|0)==0){ap=b[(c[277213]|0)+(m+12<<1)>>1]|0}else{ap=0}if((a[(c[277215]|0)+x|0]&32)==0){aq=c[277228]&65535}else{aq=b[(c[277226]|0)+(o<<1)>>1]|0}o=ap&-2048;t=aq&-2048;M=(o&65535)>(t&65535)?o-t&65535:0;t=ap&2016;o=aq&2016;if((t&65535)>(o&65535)){ar=(t-o&65535)+M&65535}else{ar=M}M=ap&31;o=aq&31;if((M&65535)>(o&65535)){as=(M-o&65535)+ar&65535}else{as=ar}o=m+11|0;b[(c[277218]|0)+(o<<1)>>1]=as;M=a[1108909]|0;a[(c[277219]|0)+o|0]=M;a[(c[277219]|0)+x|0]=M}}while(0);x=G-1&255;if(x<<24>>24!=0){I=x;F=8743}}if((F|0)==8743){F=0;x=m+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+x|0]|0)){M=a[r+6|0]|0;o=M&255;if(M<<24>>24==0){break}M=b[(c[277225]|0)+(o<<1)>>1]|0;if((a[(c[277215]|0)+x|0]&32)==0){at=c[277228]&65535}else{at=b[(c[277213]|0)+(x<<1)>>1]|0}t=M&-2048;v=at&-2048;w=(t&65535)>(v&65535)?t-v&65535:0;v=M&2016;t=at&2016;if((v&65535)>(t&65535)){au=(v-t&65535)+w&65535}else{au=w}w=M&31;M=at&31;if((w&65535)>(M&65535)){av=(w-M&65535)+au&65535}else{av=au}b[(c[277218]|0)+(x<<1)>>1]=av;if((a[1108928]|0)==0){aw=b[(c[277213]|0)+(m+14<<1)>>1]|0}else{aw=0}if((a[(c[277215]|0)+x|0]&32)==0){ax=c[277228]&65535}else{ax=b[(c[277226]|0)+(o<<1)>>1]|0}o=aw&-2048;M=ax&-2048;w=(o&65535)>(M&65535)?o-M&65535:0;M=aw&2016;o=ax&2016;if((M&65535)>(o&65535)){ay=(M-o&65535)+w&65535}else{ay=w}w=aw&31;o=ax&31;if((w&65535)>(o&65535)){az=(w-o&65535)+ay&65535}else{az=ay}o=m+13|0;b[(c[277218]|0)+(o<<1)>>1]=az;w=a[1108909]|0;a[(c[277219]|0)+o|0]=w;a[(c[277219]|0)+x|0]=w}}while(0);if(I<<24>>24!=1){F=8763}}do{if((F|0)==8763){F=0;x=m+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+x|0]|0)){break}w=a[r+7|0]|0;o=w&255;if(w<<24>>24==0){break}w=b[(c[277225]|0)+(o<<1)>>1]|0;if((a[(c[277215]|0)+x|0]&32)==0){aA=c[277228]&65535}else{aA=b[(c[277213]|0)+(x<<1)>>1]|0}M=w&-2048;t=aA&-2048;v=(M&65535)>(t&65535)?M-t&65535:0;t=w&2016;M=aA&2016;if((t&65535)>(M&65535)){aB=(t-M&65535)+v&65535}else{aB=v}v=w&31;w=aA&31;if((v&65535)>(w&65535)){aC=(v-w&65535)+aB&65535}else{aC=aB}b[(c[277218]|0)+(x<<1)>>1]=aC;if((a[1108928]|0)==0){aD=b[(c[277213]|0)+(m+16<<1)>>1]|0}else{aD=0}if((a[(c[277215]|0)+x|0]&32)==0){aE=c[277228]&65535}else{aE=b[(c[277226]|0)+(o<<1)>>1]|0}o=aD&-2048;w=aE&-2048;v=(o&65535)>(w&65535)?o-w&65535:0;w=aD&2016;o=aE&2016;if((w&65535)>(o&65535)){aF=(w-o&65535)+v&65535}else{aF=v}v=aD&31;o=aE&31;if((v&65535)>(o&65535)){aG=(v-o&65535)+aF&65535}else{aG=aF}o=m+15|0;b[(c[277218]|0)+(o<<1)>>1]=aG;v=a[1108909]|0;a[(c[277219]|0)+o|0]=v;a[(c[277219]|0)+x|0]=v}}while(0);v=p-1|0;if((v|0)>0){r=r+8|0;p=v;m=(c[277223]|0)+m|0}else{break}}return}if((e&32768|0)==0){if((j|0)<=0){return}e=h&255;m=e-1&255;p=m<<24>>24==0;r=q+i|0;aG=j;aF=f;while(1){switch(g|0){case 4:{aH=e;F=8867;break};case 2:{aI=e;F=8827;break};case 5:{aJ=e;F=8887;break};case 7:{F=8927;break};case 3:{aK=e;F=8847;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+aF|0]|0)){aE=a[r+7|0]|0;aD=aE&255;if(aE<<24>>24==0){break}aE=b[(c[277225]|0)+(aD<<1)>>1]|0;if((a[(c[277215]|0)+aF|0]&32)==0){aL=c[277228]&65535}else{aL=b[(c[277213]|0)+(aF<<1)>>1]|0}aC=aE&-2048;aB=aL&-2048;aA=(aC&65535)>(aB&65535)?aC-aB&65535:0;aB=aE&2016;aC=aL&2016;if((aB&65535)>(aC&65535)){aM=(aB-aC&65535)+aA&65535}else{aM=aA}aA=aE&31;aE=aL&31;if((aA&65535)>(aE&65535)){aN=(aA-aE&65535)+aM&65535}else{aN=aM}b[(c[277218]|0)+(aF<<1)>>1]=aN;if((a[1108928]|0)==0){aO=b[(c[277213]|0)+(aF+2<<1)>>1]|0}else{aO=0}if((a[(c[277215]|0)+aF|0]&32)==0){aP=c[277228]&65535}else{aP=b[(c[277226]|0)+(aD<<1)>>1]|0}aD=aO&-2048;aE=aP&-2048;aA=(aD&65535)>(aE&65535)?aD-aE&65535:0;aE=aO&2016;aD=aP&2016;if((aE&65535)>(aD&65535)){aQ=(aE-aD&65535)+aA&65535}else{aQ=aA}aA=aO&31;aD=aP&31;if((aA&65535)>(aD&65535)){aR=(aA-aD&65535)+aQ&65535}else{aR=aQ}aD=aF+1|0;b[(c[277218]|0)+(aD<<1)>>1]=aR;aA=a[1108909]|0;a[(c[277219]|0)+aD|0]=aA;a[(c[277219]|0)+aF|0]=aA}}while(0);if(!p){aS=m;F=8807}break};case 6:{aT=e;F=8907;break};case 1:{aS=e;F=8807;break};default:{}}if((F|0)==8807){F=0;aA=aF+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+aA|0]|0)){aD=a[r+6|0]|0;aE=aD&255;if(aD<<24>>24==0){break}aD=b[(c[277225]|0)+(aE<<1)>>1]|0;if((a[(c[277215]|0)+aA|0]&32)==0){aU=c[277228]&65535}else{aU=b[(c[277213]|0)+(aA<<1)>>1]|0}aC=aD&-2048;aB=aU&-2048;I=(aC&65535)>(aB&65535)?aC-aB&65535:0;aB=aD&2016;aC=aU&2016;if((aB&65535)>(aC&65535)){aV=(aB-aC&65535)+I&65535}else{aV=I}I=aD&31;aD=aU&31;if((I&65535)>(aD&65535)){aW=(I-aD&65535)+aV&65535}else{aW=aV}b[(c[277218]|0)+(aA<<1)>>1]=aW;if((a[1108928]|0)==0){aX=b[(c[277213]|0)+(aF+4<<1)>>1]|0}else{aX=0}if((a[(c[277215]|0)+aA|0]&32)==0){aY=c[277228]&65535}else{aY=b[(c[277226]|0)+(aE<<1)>>1]|0}aE=aX&-2048;aD=aY&-2048;I=(aE&65535)>(aD&65535)?aE-aD&65535:0;aD=aX&2016;aE=aY&2016;if((aD&65535)>(aE&65535)){aZ=(aD-aE&65535)+I&65535}else{aZ=I}I=aX&31;aE=aY&31;if((I&65535)>(aE&65535)){a_=(I-aE&65535)+aZ&65535}else{a_=aZ}aE=aF+3|0;b[(c[277218]|0)+(aE<<1)>>1]=a_;I=a[1108909]|0;a[(c[277219]|0)+aE|0]=I;a[(c[277219]|0)+aA|0]=I}}while(0);aA=aS-1&255;if(aA<<24>>24!=0){aI=aA;F=8827}}if((F|0)==8827){F=0;aA=aF+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+aA|0]|0)){I=a[r+5|0]|0;aE=I&255;if(I<<24>>24==0){break}I=b[(c[277225]|0)+(aE<<1)>>1]|0;if((a[(c[277215]|0)+aA|0]&32)==0){a$=c[277228]&65535}else{a$=b[(c[277213]|0)+(aA<<1)>>1]|0}aD=I&-2048;aC=a$&-2048;aB=(aD&65535)>(aC&65535)?aD-aC&65535:0;aC=I&2016;aD=a$&2016;if((aC&65535)>(aD&65535)){a0=(aC-aD&65535)+aB&65535}else{a0=aB}aB=I&31;I=a$&31;if((aB&65535)>(I&65535)){a1=(aB-I&65535)+a0&65535}else{a1=a0}b[(c[277218]|0)+(aA<<1)>>1]=a1;if((a[1108928]|0)==0){a2=b[(c[277213]|0)+(aF+6<<1)>>1]|0}else{a2=0}if((a[(c[277215]|0)+aA|0]&32)==0){a3=c[277228]&65535}else{a3=b[(c[277226]|0)+(aE<<1)>>1]|0}aE=a2&-2048;I=a3&-2048;aB=(aE&65535)>(I&65535)?aE-I&65535:0;I=a2&2016;aE=a3&2016;if((I&65535)>(aE&65535)){a4=(I-aE&65535)+aB&65535}else{a4=aB}aB=a2&31;aE=a3&31;if((aB&65535)>(aE&65535)){a5=(aB-aE&65535)+a4&65535}else{a5=a4}aE=aF+5|0;b[(c[277218]|0)+(aE<<1)>>1]=a5;aB=a[1108909]|0;a[(c[277219]|0)+aE|0]=aB;a[(c[277219]|0)+aA|0]=aB}}while(0);aA=aI-1&255;if(aA<<24>>24!=0){aK=aA;F=8847}}if((F|0)==8847){F=0;aA=aF+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+aA|0]|0)){aB=a[r+4|0]|0;aE=aB&255;if(aB<<24>>24==0){break}aB=b[(c[277225]|0)+(aE<<1)>>1]|0;if((a[(c[277215]|0)+aA|0]&32)==0){a6=c[277228]&65535}else{a6=b[(c[277213]|0)+(aA<<1)>>1]|0}I=aB&-2048;aD=a6&-2048;aC=(I&65535)>(aD&65535)?I-aD&65535:0;aD=aB&2016;I=a6&2016;if((aD&65535)>(I&65535)){a7=(aD-I&65535)+aC&65535}else{a7=aC}aC=aB&31;aB=a6&31;if((aC&65535)>(aB&65535)){a8=(aC-aB&65535)+a7&65535}else{a8=a7}b[(c[277218]|0)+(aA<<1)>>1]=a8;if((a[1108928]|0)==0){a9=b[(c[277213]|0)+(aF+8<<1)>>1]|0}else{a9=0}if((a[(c[277215]|0)+aA|0]&32)==0){ba=c[277228]&65535}else{ba=b[(c[277226]|0)+(aE<<1)>>1]|0}aE=a9&-2048;aB=ba&-2048;aC=(aE&65535)>(aB&65535)?aE-aB&65535:0;aB=a9&2016;aE=ba&2016;if((aB&65535)>(aE&65535)){bb=(aB-aE&65535)+aC&65535}else{bb=aC}aC=a9&31;aE=ba&31;if((aC&65535)>(aE&65535)){bc=(aC-aE&65535)+bb&65535}else{bc=bb}aE=aF+7|0;b[(c[277218]|0)+(aE<<1)>>1]=bc;aC=a[1108909]|0;a[(c[277219]|0)+aE|0]=aC;a[(c[277219]|0)+aA|0]=aC}}while(0);aA=aK-1&255;if(aA<<24>>24!=0){aH=aA;F=8867}}if((F|0)==8867){F=0;aA=aF+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+aA|0]|0)){aC=a[r+3|0]|0;aE=aC&255;if(aC<<24>>24==0){break}aC=b[(c[277225]|0)+(aE<<1)>>1]|0;if((a[(c[277215]|0)+aA|0]&32)==0){bd=c[277228]&65535}else{bd=b[(c[277213]|0)+(aA<<1)>>1]|0}aB=aC&-2048;I=bd&-2048;aD=(aB&65535)>(I&65535)?aB-I&65535:0;I=aC&2016;aB=bd&2016;if((I&65535)>(aB&65535)){be=(I-aB&65535)+aD&65535}else{be=aD}aD=aC&31;aC=bd&31;if((aD&65535)>(aC&65535)){bf=(aD-aC&65535)+be&65535}else{bf=be}b[(c[277218]|0)+(aA<<1)>>1]=bf;if((a[1108928]|0)==0){bg=b[(c[277213]|0)+(aF+10<<1)>>1]|0}else{bg=0}if((a[(c[277215]|0)+aA|0]&32)==0){bh=c[277228]&65535}else{bh=b[(c[277226]|0)+(aE<<1)>>1]|0}aE=bg&-2048;aC=bh&-2048;aD=(aE&65535)>(aC&65535)?aE-aC&65535:0;aC=bg&2016;aE=bh&2016;if((aC&65535)>(aE&65535)){bi=(aC-aE&65535)+aD&65535}else{bi=aD}aD=bg&31;aE=bh&31;if((aD&65535)>(aE&65535)){bj=(aD-aE&65535)+bi&65535}else{bj=bi}aE=aF+9|0;b[(c[277218]|0)+(aE<<1)>>1]=bj;aD=a[1108909]|0;a[(c[277219]|0)+aE|0]=aD;a[(c[277219]|0)+aA|0]=aD}}while(0);aA=aH-1&255;if(aA<<24>>24!=0){aJ=aA;F=8887}}if((F|0)==8887){F=0;aA=aF+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+aA|0]|0)){aD=a[r+2|0]|0;aE=aD&255;if(aD<<24>>24==0){break}aD=b[(c[277225]|0)+(aE<<1)>>1]|0;if((a[(c[277215]|0)+aA|0]&32)==0){bk=c[277228]&65535}else{bk=b[(c[277213]|0)+(aA<<1)>>1]|0}aC=aD&-2048;aB=bk&-2048;I=(aC&65535)>(aB&65535)?aC-aB&65535:0;aB=aD&2016;aC=bk&2016;if((aB&65535)>(aC&65535)){bl=(aB-aC&65535)+I&65535}else{bl=I}I=aD&31;aD=bk&31;if((I&65535)>(aD&65535)){bm=(I-aD&65535)+bl&65535}else{bm=bl}b[(c[277218]|0)+(aA<<1)>>1]=bm;if((a[1108928]|0)==0){bn=b[(c[277213]|0)+(aF+12<<1)>>1]|0}else{bn=0}if((a[(c[277215]|0)+aA|0]&32)==0){bo=c[277228]&65535}else{bo=b[(c[277226]|0)+(aE<<1)>>1]|0}aE=bn&-2048;aD=bo&-2048;I=(aE&65535)>(aD&65535)?aE-aD&65535:0;aD=bn&2016;aE=bo&2016;if((aD&65535)>(aE&65535)){bp=(aD-aE&65535)+I&65535}else{bp=I}I=bn&31;aE=bo&31;if((I&65535)>(aE&65535)){bq=(I-aE&65535)+bp&65535}else{bq=bp}aE=aF+11|0;b[(c[277218]|0)+(aE<<1)>>1]=bq;I=a[1108909]|0;a[(c[277219]|0)+aE|0]=I;a[(c[277219]|0)+aA|0]=I}}while(0);aA=aJ-1&255;if(aA<<24>>24!=0){aT=aA;F=8907}}if((F|0)==8907){F=0;aA=aF+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+aA|0]|0)){I=a[r+1|0]|0;aE=I&255;if(I<<24>>24==0){break}I=b[(c[277225]|0)+(aE<<1)>>1]|0;if((a[(c[277215]|0)+aA|0]&32)==0){br=c[277228]&65535}else{br=b[(c[277213]|0)+(aA<<1)>>1]|0}aD=I&-2048;aC=br&-2048;aB=(aD&65535)>(aC&65535)?aD-aC&65535:0;aC=I&2016;aD=br&2016;if((aC&65535)>(aD&65535)){bs=(aC-aD&65535)+aB&65535}else{bs=aB}aB=I&31;I=br&31;if((aB&65535)>(I&65535)){bt=(aB-I&65535)+bs&65535}else{bt=bs}b[(c[277218]|0)+(aA<<1)>>1]=bt;if((a[1108928]|0)==0){bu=b[(c[277213]|0)+(aF+14<<1)>>1]|0}else{bu=0}if((a[(c[277215]|0)+aA|0]&32)==0){bv=c[277228]&65535}else{bv=b[(c[277226]|0)+(aE<<1)>>1]|0}aE=bu&-2048;I=bv&-2048;aB=(aE&65535)>(I&65535)?aE-I&65535:0;I=bu&2016;aE=bv&2016;if((I&65535)>(aE&65535)){bw=(I-aE&65535)+aB&65535}else{bw=aB}aB=bu&31;aE=bv&31;if((aB&65535)>(aE&65535)){bx=(aB-aE&65535)+bw&65535}else{bx=bw}aE=aF+13|0;b[(c[277218]|0)+(aE<<1)>>1]=bx;aB=a[1108909]|0;a[(c[277219]|0)+aE|0]=aB;a[(c[277219]|0)+aA|0]=aB}}while(0);if(aT<<24>>24!=1){F=8927}}do{if((F|0)==8927){F=0;aA=aF+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+aA|0]|0)){break}aB=a[r]|0;aE=aB&255;if(aB<<24>>24==0){break}aB=b[(c[277225]|0)+(aE<<1)>>1]|0;if((a[(c[277215]|0)+aA|0]&32)==0){by=c[277228]&65535}else{by=b[(c[277213]|0)+(aA<<1)>>1]|0}I=aB&-2048;aD=by&-2048;aC=(I&65535)>(aD&65535)?I-aD&65535:0;aD=aB&2016;I=by&2016;if((aD&65535)>(I&65535)){bz=(aD-I&65535)+aC&65535}else{bz=aC}aC=aB&31;aB=by&31;if((aC&65535)>(aB&65535)){bA=(aC-aB&65535)+bz&65535}else{bA=bz}b[(c[277218]|0)+(aA<<1)>>1]=bA;if((a[1108928]|0)==0){bB=b[(c[277213]|0)+(aF+16<<1)>>1]|0}else{bB=0}if((a[(c[277215]|0)+aA|0]&32)==0){bC=c[277228]&65535}else{bC=b[(c[277226]|0)+(aE<<1)>>1]|0}aE=bB&-2048;aB=bC&-2048;aC=(aE&65535)>(aB&65535)?aE-aB&65535:0;aB=bB&2016;aE=bC&2016;if((aB&65535)>(aE&65535)){bD=(aB-aE&65535)+aC&65535}else{bD=aC}aC=bB&31;aE=bC&31;if((aC&65535)>(aE&65535)){bE=(aC-aE&65535)+bD&65535}else{bE=bD}aE=aF+15|0;b[(c[277218]|0)+(aE<<1)>>1]=bE;aC=a[1108909]|0;a[(c[277219]|0)+aE|0]=aC;a[(c[277219]|0)+aA|0]=aC}}while(0);aC=aG-1|0;if((aC|0)>0){r=r+8|0;aG=aC;aF=(c[277223]|0)+aF|0}else{break}}return}aF=q+(56-i)|0;i=(j|0)>0;if(l){if(!i){return}l=h&255;q=l-1&255;aG=q<<24>>24==0;r=aF;bE=j;bD=f;while(1){switch(g|0){case 3:{bF=l;F=9174;break};case 6:{bG=l;F=9234;break};case 7:{F=9254;break};case 2:{bH=l;F=9154;break};case 4:{bI=l;F=9194;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+bD|0]|0)){bC=a[r+7|0]|0;bB=bC&255;if(bC<<24>>24==0){break}bC=b[(c[277225]|0)+(bB<<1)>>1]|0;if((a[(c[277215]|0)+bD|0]&32)==0){bJ=c[277228]&65535}else{bJ=b[(c[277213]|0)+(bD<<1)>>1]|0}bA=bC&-2048;bz=bJ&-2048;by=(bA&65535)>(bz&65535)?bA-bz&65535:0;bz=bC&2016;bA=bJ&2016;if((bz&65535)>(bA&65535)){bK=(bz-bA&65535)+by&65535}else{bK=by}by=bC&31;bC=bJ&31;if((by&65535)>(bC&65535)){bL=(by-bC&65535)+bK&65535}else{bL=bK}b[(c[277218]|0)+(bD<<1)>>1]=bL;if((a[1108928]|0)==0){bM=b[(c[277213]|0)+(bD+2<<1)>>1]|0}else{bM=0}if((a[(c[277215]|0)+bD|0]&32)==0){bN=c[277228]&65535}else{bN=b[(c[277226]|0)+(bB<<1)>>1]|0}bB=bM&-2048;bC=bN&-2048;by=(bB&65535)>(bC&65535)?bB-bC&65535:0;bC=bM&2016;bB=bN&2016;if((bC&65535)>(bB&65535)){bO=(bC-bB&65535)+by&65535}else{bO=by}by=bM&31;bB=bN&31;if((by&65535)>(bB&65535)){bP=(by-bB&65535)+bO&65535}else{bP=bO}bB=bD+1|0;b[(c[277218]|0)+(bB<<1)>>1]=bP;by=a[1108909]|0;a[(c[277219]|0)+bB|0]=by;a[(c[277219]|0)+bD|0]=by}}while(0);if(!aG){bQ=q;F=9134}break};case 5:{bR=l;F=9214;break};case 1:{bQ=l;F=9134;break};default:{}}if((F|0)==9134){F=0;by=bD+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+by|0]|0)){bB=a[r+6|0]|0;bC=bB&255;if(bB<<24>>24==0){break}bB=b[(c[277225]|0)+(bC<<1)>>1]|0;if((a[(c[277215]|0)+by|0]&32)==0){bS=c[277228]&65535}else{bS=b[(c[277213]|0)+(by<<1)>>1]|0}bA=bB&-2048;bz=bS&-2048;aT=(bA&65535)>(bz&65535)?bA-bz&65535:0;bz=bB&2016;bA=bS&2016;if((bz&65535)>(bA&65535)){bT=(bz-bA&65535)+aT&65535}else{bT=aT}aT=bB&31;bB=bS&31;if((aT&65535)>(bB&65535)){bU=(aT-bB&65535)+bT&65535}else{bU=bT}b[(c[277218]|0)+(by<<1)>>1]=bU;if((a[1108928]|0)==0){bV=b[(c[277213]|0)+(bD+4<<1)>>1]|0}else{bV=0}if((a[(c[277215]|0)+by|0]&32)==0){bW=c[277228]&65535}else{bW=b[(c[277226]|0)+(bC<<1)>>1]|0}bC=bV&-2048;bB=bW&-2048;aT=(bC&65535)>(bB&65535)?bC-bB&65535:0;bB=bV&2016;bC=bW&2016;if((bB&65535)>(bC&65535)){bX=(bB-bC&65535)+aT&65535}else{bX=aT}aT=bV&31;bC=bW&31;if((aT&65535)>(bC&65535)){bY=(aT-bC&65535)+bX&65535}else{bY=bX}bC=bD+3|0;b[(c[277218]|0)+(bC<<1)>>1]=bY;aT=a[1108909]|0;a[(c[277219]|0)+bC|0]=aT;a[(c[277219]|0)+by|0]=aT}}while(0);by=bQ-1&255;if(by<<24>>24!=0){bH=by;F=9154}}if((F|0)==9154){F=0;by=bD+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+by|0]|0)){aT=a[r+5|0]|0;bC=aT&255;if(aT<<24>>24==0){break}aT=b[(c[277225]|0)+(bC<<1)>>1]|0;if((a[(c[277215]|0)+by|0]&32)==0){bZ=c[277228]&65535}else{bZ=b[(c[277213]|0)+(by<<1)>>1]|0}bB=aT&-2048;bA=bZ&-2048;bz=(bB&65535)>(bA&65535)?bB-bA&65535:0;bA=aT&2016;bB=bZ&2016;if((bA&65535)>(bB&65535)){b_=(bA-bB&65535)+bz&65535}else{b_=bz}bz=aT&31;aT=bZ&31;if((bz&65535)>(aT&65535)){b$=(bz-aT&65535)+b_&65535}else{b$=b_}b[(c[277218]|0)+(by<<1)>>1]=b$;if((a[1108928]|0)==0){b0=b[(c[277213]|0)+(bD+6<<1)>>1]|0}else{b0=0}if((a[(c[277215]|0)+by|0]&32)==0){b1=c[277228]&65535}else{b1=b[(c[277226]|0)+(bC<<1)>>1]|0}bC=b0&-2048;aT=b1&-2048;bz=(bC&65535)>(aT&65535)?bC-aT&65535:0;aT=b0&2016;bC=b1&2016;if((aT&65535)>(bC&65535)){b2=(aT-bC&65535)+bz&65535}else{b2=bz}bz=b0&31;bC=b1&31;if((bz&65535)>(bC&65535)){b3=(bz-bC&65535)+b2&65535}else{b3=b2}bC=bD+5|0;b[(c[277218]|0)+(bC<<1)>>1]=b3;bz=a[1108909]|0;a[(c[277219]|0)+bC|0]=bz;a[(c[277219]|0)+by|0]=bz}}while(0);by=bH-1&255;if(by<<24>>24!=0){bF=by;F=9174}}if((F|0)==9174){F=0;by=bD+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+by|0]|0)){bz=a[r+4|0]|0;bC=bz&255;if(bz<<24>>24==0){break}bz=b[(c[277225]|0)+(bC<<1)>>1]|0;if((a[(c[277215]|0)+by|0]&32)==0){b4=c[277228]&65535}else{b4=b[(c[277213]|0)+(by<<1)>>1]|0}aT=bz&-2048;bB=b4&-2048;bA=(aT&65535)>(bB&65535)?aT-bB&65535:0;bB=bz&2016;aT=b4&2016;if((bB&65535)>(aT&65535)){b5=(bB-aT&65535)+bA&65535}else{b5=bA}bA=bz&31;bz=b4&31;if((bA&65535)>(bz&65535)){b6=(bA-bz&65535)+b5&65535}else{b6=b5}b[(c[277218]|0)+(by<<1)>>1]=b6;if((a[1108928]|0)==0){b7=b[(c[277213]|0)+(bD+8<<1)>>1]|0}else{b7=0}if((a[(c[277215]|0)+by|0]&32)==0){b8=c[277228]&65535}else{b8=b[(c[277226]|0)+(bC<<1)>>1]|0}bC=b7&-2048;bz=b8&-2048;bA=(bC&65535)>(bz&65535)?bC-bz&65535:0;bz=b7&2016;bC=b8&2016;if((bz&65535)>(bC&65535)){b9=(bz-bC&65535)+bA&65535}else{b9=bA}bA=b7&31;bC=b8&31;if((bA&65535)>(bC&65535)){ca=(bA-bC&65535)+b9&65535}else{ca=b9}bC=bD+7|0;b[(c[277218]|0)+(bC<<1)>>1]=ca;bA=a[1108909]|0;a[(c[277219]|0)+bC|0]=bA;a[(c[277219]|0)+by|0]=bA}}while(0);by=bF-1&255;if(by<<24>>24!=0){bI=by;F=9194}}if((F|0)==9194){F=0;by=bD+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+by|0]|0)){bA=a[r+3|0]|0;bC=bA&255;if(bA<<24>>24==0){break}bA=b[(c[277225]|0)+(bC<<1)>>1]|0;if((a[(c[277215]|0)+by|0]&32)==0){cb=c[277228]&65535}else{cb=b[(c[277213]|0)+(by<<1)>>1]|0}bz=bA&-2048;aT=cb&-2048;bB=(bz&65535)>(aT&65535)?bz-aT&65535:0;aT=bA&2016;bz=cb&2016;if((aT&65535)>(bz&65535)){cc=(aT-bz&65535)+bB&65535}else{cc=bB}bB=bA&31;bA=cb&31;if((bB&65535)>(bA&65535)){cd=(bB-bA&65535)+cc&65535}else{cd=cc}b[(c[277218]|0)+(by<<1)>>1]=cd;if((a[1108928]|0)==0){ce=b[(c[277213]|0)+(bD+10<<1)>>1]|0}else{ce=0}if((a[(c[277215]|0)+by|0]&32)==0){cf=c[277228]&65535}else{cf=b[(c[277226]|0)+(bC<<1)>>1]|0}bC=ce&-2048;bA=cf&-2048;bB=(bC&65535)>(bA&65535)?bC-bA&65535:0;bA=ce&2016;bC=cf&2016;if((bA&65535)>(bC&65535)){cg=(bA-bC&65535)+bB&65535}else{cg=bB}bB=ce&31;bC=cf&31;if((bB&65535)>(bC&65535)){ch=(bB-bC&65535)+cg&65535}else{ch=cg}bC=bD+9|0;b[(c[277218]|0)+(bC<<1)>>1]=ch;bB=a[1108909]|0;a[(c[277219]|0)+bC|0]=bB;a[(c[277219]|0)+by|0]=bB}}while(0);by=bI-1&255;if(by<<24>>24!=0){bR=by;F=9214}}if((F|0)==9214){F=0;by=bD+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+by|0]|0)){bB=a[r+2|0]|0;bC=bB&255;if(bB<<24>>24==0){break}bB=b[(c[277225]|0)+(bC<<1)>>1]|0;if((a[(c[277215]|0)+by|0]&32)==0){ci=c[277228]&65535}else{ci=b[(c[277213]|0)+(by<<1)>>1]|0}bA=bB&-2048;bz=ci&-2048;aT=(bA&65535)>(bz&65535)?bA-bz&65535:0;bz=bB&2016;bA=ci&2016;if((bz&65535)>(bA&65535)){cj=(bz-bA&65535)+aT&65535}else{cj=aT}aT=bB&31;bB=ci&31;if((aT&65535)>(bB&65535)){ck=(aT-bB&65535)+cj&65535}else{ck=cj}b[(c[277218]|0)+(by<<1)>>1]=ck;if((a[1108928]|0)==0){cl=b[(c[277213]|0)+(bD+12<<1)>>1]|0}else{cl=0}if((a[(c[277215]|0)+by|0]&32)==0){cm=c[277228]&65535}else{cm=b[(c[277226]|0)+(bC<<1)>>1]|0}bC=cl&-2048;bB=cm&-2048;aT=(bC&65535)>(bB&65535)?bC-bB&65535:0;bB=cl&2016;bC=cm&2016;if((bB&65535)>(bC&65535)){cn=(bB-bC&65535)+aT&65535}else{cn=aT}aT=cl&31;bC=cm&31;if((aT&65535)>(bC&65535)){co=(aT-bC&65535)+cn&65535}else{co=cn}bC=bD+11|0;b[(c[277218]|0)+(bC<<1)>>1]=co;aT=a[1108909]|0;a[(c[277219]|0)+bC|0]=aT;a[(c[277219]|0)+by|0]=aT}}while(0);by=bR-1&255;if(by<<24>>24!=0){bG=by;F=9234}}if((F|0)==9234){F=0;by=bD+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+by|0]|0)){aT=a[r+1|0]|0;bC=aT&255;if(aT<<24>>24==0){break}aT=b[(c[277225]|0)+(bC<<1)>>1]|0;if((a[(c[277215]|0)+by|0]&32)==0){cp=c[277228]&65535}else{cp=b[(c[277213]|0)+(by<<1)>>1]|0}bB=aT&-2048;bA=cp&-2048;bz=(bB&65535)>(bA&65535)?bB-bA&65535:0;bA=aT&2016;bB=cp&2016;if((bA&65535)>(bB&65535)){cq=(bA-bB&65535)+bz&65535}else{cq=bz}bz=aT&31;aT=cp&31;if((bz&65535)>(aT&65535)){cr=(bz-aT&65535)+cq&65535}else{cr=cq}b[(c[277218]|0)+(by<<1)>>1]=cr;if((a[1108928]|0)==0){cs=b[(c[277213]|0)+(bD+14<<1)>>1]|0}else{cs=0}if((a[(c[277215]|0)+by|0]&32)==0){ct=c[277228]&65535}else{ct=b[(c[277226]|0)+(bC<<1)>>1]|0}bC=cs&-2048;aT=ct&-2048;bz=(bC&65535)>(aT&65535)?bC-aT&65535:0;aT=cs&2016;bC=ct&2016;if((aT&65535)>(bC&65535)){cu=(aT-bC&65535)+bz&65535}else{cu=bz}bz=cs&31;bC=ct&31;if((bz&65535)>(bC&65535)){cv=(bz-bC&65535)+cu&65535}else{cv=cu}bC=bD+13|0;b[(c[277218]|0)+(bC<<1)>>1]=cv;bz=a[1108909]|0;a[(c[277219]|0)+bC|0]=bz;a[(c[277219]|0)+by|0]=bz}}while(0);if(bG<<24>>24!=1){F=9254}}do{if((F|0)==9254){F=0;by=bD+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+by|0]|0)){break}bz=a[r]|0;bC=bz&255;if(bz<<24>>24==0){break}bz=b[(c[277225]|0)+(bC<<1)>>1]|0;if((a[(c[277215]|0)+by|0]&32)==0){cw=c[277228]&65535}else{cw=b[(c[277213]|0)+(by<<1)>>1]|0}aT=bz&-2048;bB=cw&-2048;bA=(aT&65535)>(bB&65535)?aT-bB&65535:0;bB=bz&2016;aT=cw&2016;if((bB&65535)>(aT&65535)){cx=(bB-aT&65535)+bA&65535}else{cx=bA}bA=bz&31;bz=cw&31;if((bA&65535)>(bz&65535)){cy=(bA-bz&65535)+cx&65535}else{cy=cx}b[(c[277218]|0)+(by<<1)>>1]=cy;if((a[1108928]|0)==0){cz=b[(c[277213]|0)+(bD+16<<1)>>1]|0}else{cz=0}if((a[(c[277215]|0)+by|0]&32)==0){cA=c[277228]&65535}else{cA=b[(c[277226]|0)+(bC<<1)>>1]|0}bC=cz&-2048;bz=cA&-2048;bA=(bC&65535)>(bz&65535)?bC-bz&65535:0;bz=cz&2016;bC=cA&2016;if((bz&65535)>(bC&65535)){cB=(bz-bC&65535)+bA&65535}else{cB=bA}bA=cz&31;bC=cA&31;if((bA&65535)>(bC&65535)){cC=(bA-bC&65535)+cB&65535}else{cC=cB}bC=bD+15|0;b[(c[277218]|0)+(bC<<1)>>1]=cC;bA=a[1108909]|0;a[(c[277219]|0)+bC|0]=bA;a[(c[277219]|0)+by|0]=bA}}while(0);bA=bE-1|0;if((bA|0)>0){r=r-8|0;bE=bA;bD=(c[277223]|0)+bD|0}else{break}}return}else{if(!i){return}i=h&255;h=i-1&255;bD=h<<24>>24==0;bE=aF;aF=j;j=f;while(1){switch(g|0){case 1:{cD=i;F=8973;break};case 3:{cE=i;F=9013;break};case 2:{cF=i;F=8993;break};case 6:{cG=i;F=9073;break};case 5:{cH=i;F=9053;break};case 4:{cI=i;F=9033;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+j|0]|0)){f=a[bE]|0;r=f&255;if(f<<24>>24==0){break}f=b[(c[277225]|0)+(r<<1)>>1]|0;if((a[(c[277215]|0)+j|0]&32)==0){cJ=c[277228]&65535}else{cJ=b[(c[277213]|0)+(j<<1)>>1]|0}cC=f&-2048;cB=cJ&-2048;cA=(cC&65535)>(cB&65535)?cC-cB&65535:0;cB=f&2016;cC=cJ&2016;if((cB&65535)>(cC&65535)){cK=(cB-cC&65535)+cA&65535}else{cK=cA}cA=f&31;f=cJ&31;if((cA&65535)>(f&65535)){cL=(cA-f&65535)+cK&65535}else{cL=cK}b[(c[277218]|0)+(j<<1)>>1]=cL;if((a[1108928]|0)==0){cM=b[(c[277213]|0)+(j+2<<1)>>1]|0}else{cM=0}if((a[(c[277215]|0)+j|0]&32)==0){cN=c[277228]&65535}else{cN=b[(c[277226]|0)+(r<<1)>>1]|0}r=cM&-2048;f=cN&-2048;cA=(r&65535)>(f&65535)?r-f&65535:0;f=cM&2016;r=cN&2016;if((f&65535)>(r&65535)){cO=(f-r&65535)+cA&65535}else{cO=cA}cA=cM&31;r=cN&31;if((cA&65535)>(r&65535)){cP=(cA-r&65535)+cO&65535}else{cP=cO}r=j+1|0;b[(c[277218]|0)+(r<<1)>>1]=cP;cA=a[1108909]|0;a[(c[277219]|0)+r|0]=cA;a[(c[277219]|0)+j|0]=cA}}while(0);if(!bD){cD=h;F=8973}break};case 7:{F=9093;break};default:{}}if((F|0)==8973){F=0;cA=j+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+cA|0]|0)){r=a[bE+1|0]|0;f=r&255;if(r<<24>>24==0){break}r=b[(c[277225]|0)+(f<<1)>>1]|0;if((a[(c[277215]|0)+cA|0]&32)==0){cQ=c[277228]&65535}else{cQ=b[(c[277213]|0)+(cA<<1)>>1]|0}cC=r&-2048;cB=cQ&-2048;cz=(cC&65535)>(cB&65535)?cC-cB&65535:0;cB=r&2016;cC=cQ&2016;if((cB&65535)>(cC&65535)){cR=(cB-cC&65535)+cz&65535}else{cR=cz}cz=r&31;r=cQ&31;if((cz&65535)>(r&65535)){cS=(cz-r&65535)+cR&65535}else{cS=cR}b[(c[277218]|0)+(cA<<1)>>1]=cS;if((a[1108928]|0)==0){cT=b[(c[277213]|0)+(j+4<<1)>>1]|0}else{cT=0}if((a[(c[277215]|0)+cA|0]&32)==0){cU=c[277228]&65535}else{cU=b[(c[277226]|0)+(f<<1)>>1]|0}f=cT&-2048;r=cU&-2048;cz=(f&65535)>(r&65535)?f-r&65535:0;r=cT&2016;f=cU&2016;if((r&65535)>(f&65535)){cV=(r-f&65535)+cz&65535}else{cV=cz}cz=cT&31;f=cU&31;if((cz&65535)>(f&65535)){cW=(cz-f&65535)+cV&65535}else{cW=cV}f=j+3|0;b[(c[277218]|0)+(f<<1)>>1]=cW;cz=a[1108909]|0;a[(c[277219]|0)+f|0]=cz;a[(c[277219]|0)+cA|0]=cz}}while(0);cA=cD-1&255;if(cA<<24>>24!=0){cF=cA;F=8993}}if((F|0)==8993){F=0;cA=j+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+cA|0]|0)){cz=a[bE+2|0]|0;f=cz&255;if(cz<<24>>24==0){break}cz=b[(c[277225]|0)+(f<<1)>>1]|0;if((a[(c[277215]|0)+cA|0]&32)==0){cX=c[277228]&65535}else{cX=b[(c[277213]|0)+(cA<<1)>>1]|0}r=cz&-2048;cC=cX&-2048;cB=(r&65535)>(cC&65535)?r-cC&65535:0;cC=cz&2016;r=cX&2016;if((cC&65535)>(r&65535)){cY=(cC-r&65535)+cB&65535}else{cY=cB}cB=cz&31;cz=cX&31;if((cB&65535)>(cz&65535)){cZ=(cB-cz&65535)+cY&65535}else{cZ=cY}b[(c[277218]|0)+(cA<<1)>>1]=cZ;if((a[1108928]|0)==0){c_=b[(c[277213]|0)+(j+6<<1)>>1]|0}else{c_=0}if((a[(c[277215]|0)+cA|0]&32)==0){c$=c[277228]&65535}else{c$=b[(c[277226]|0)+(f<<1)>>1]|0}f=c_&-2048;cz=c$&-2048;cB=(f&65535)>(cz&65535)?f-cz&65535:0;cz=c_&2016;f=c$&2016;if((cz&65535)>(f&65535)){c0=(cz-f&65535)+cB&65535}else{c0=cB}cB=c_&31;f=c$&31;if((cB&65535)>(f&65535)){c1=(cB-f&65535)+c0&65535}else{c1=c0}f=j+5|0;b[(c[277218]|0)+(f<<1)>>1]=c1;cB=a[1108909]|0;a[(c[277219]|0)+f|0]=cB;a[(c[277219]|0)+cA|0]=cB}}while(0);cA=cF-1&255;if(cA<<24>>24!=0){cE=cA;F=9013}}if((F|0)==9013){F=0;cA=j+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+cA|0]|0)){cB=a[bE+3|0]|0;f=cB&255;if(cB<<24>>24==0){break}cB=b[(c[277225]|0)+(f<<1)>>1]|0;if((a[(c[277215]|0)+cA|0]&32)==0){c2=c[277228]&65535}else{c2=b[(c[277213]|0)+(cA<<1)>>1]|0}cz=cB&-2048;r=c2&-2048;cC=(cz&65535)>(r&65535)?cz-r&65535:0;r=cB&2016;cz=c2&2016;if((r&65535)>(cz&65535)){c3=(r-cz&65535)+cC&65535}else{c3=cC}cC=cB&31;cB=c2&31;if((cC&65535)>(cB&65535)){c4=(cC-cB&65535)+c3&65535}else{c4=c3}b[(c[277218]|0)+(cA<<1)>>1]=c4;if((a[1108928]|0)==0){c5=b[(c[277213]|0)+(j+8<<1)>>1]|0}else{c5=0}if((a[(c[277215]|0)+cA|0]&32)==0){c6=c[277228]&65535}else{c6=b[(c[277226]|0)+(f<<1)>>1]|0}f=c5&-2048;cB=c6&-2048;cC=(f&65535)>(cB&65535)?f-cB&65535:0;cB=c5&2016;f=c6&2016;if((cB&65535)>(f&65535)){c7=(cB-f&65535)+cC&65535}else{c7=cC}cC=c5&31;f=c6&31;if((cC&65535)>(f&65535)){c8=(cC-f&65535)+c7&65535}else{c8=c7}f=j+7|0;b[(c[277218]|0)+(f<<1)>>1]=c8;cC=a[1108909]|0;a[(c[277219]|0)+f|0]=cC;a[(c[277219]|0)+cA|0]=cC}}while(0);cA=cE-1&255;if(cA<<24>>24!=0){cI=cA;F=9033}}if((F|0)==9033){F=0;cA=j+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+cA|0]|0)){cC=a[bE+4|0]|0;f=cC&255;if(cC<<24>>24==0){break}cC=b[(c[277225]|0)+(f<<1)>>1]|0;if((a[(c[277215]|0)+cA|0]&32)==0){c9=c[277228]&65535}else{c9=b[(c[277213]|0)+(cA<<1)>>1]|0}cB=cC&-2048;cz=c9&-2048;r=(cB&65535)>(cz&65535)?cB-cz&65535:0;cz=cC&2016;cB=c9&2016;if((cz&65535)>(cB&65535)){da=(cz-cB&65535)+r&65535}else{da=r}r=cC&31;cC=c9&31;if((r&65535)>(cC&65535)){db=(r-cC&65535)+da&65535}else{db=da}b[(c[277218]|0)+(cA<<1)>>1]=db;if((a[1108928]|0)==0){dc=b[(c[277213]|0)+(j+10<<1)>>1]|0}else{dc=0}if((a[(c[277215]|0)+cA|0]&32)==0){dd=c[277228]&65535}else{dd=b[(c[277226]|0)+(f<<1)>>1]|0}f=dc&-2048;cC=dd&-2048;r=(f&65535)>(cC&65535)?f-cC&65535:0;cC=dc&2016;f=dd&2016;if((cC&65535)>(f&65535)){de=(cC-f&65535)+r&65535}else{de=r}r=dc&31;f=dd&31;if((r&65535)>(f&65535)){df=(r-f&65535)+de&65535}else{df=de}f=j+9|0;b[(c[277218]|0)+(f<<1)>>1]=df;r=a[1108909]|0;a[(c[277219]|0)+f|0]=r;a[(c[277219]|0)+cA|0]=r}}while(0);cA=cI-1&255;if(cA<<24>>24!=0){cH=cA;F=9053}}if((F|0)==9053){F=0;cA=j+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+cA|0]|0)){r=a[bE+5|0]|0;f=r&255;if(r<<24>>24==0){break}r=b[(c[277225]|0)+(f<<1)>>1]|0;if((a[(c[277215]|0)+cA|0]&32)==0){dg=c[277228]&65535}else{dg=b[(c[277213]|0)+(cA<<1)>>1]|0}cC=r&-2048;cB=dg&-2048;cz=(cC&65535)>(cB&65535)?cC-cB&65535:0;cB=r&2016;cC=dg&2016;if((cB&65535)>(cC&65535)){dh=(cB-cC&65535)+cz&65535}else{dh=cz}cz=r&31;r=dg&31;if((cz&65535)>(r&65535)){di=(cz-r&65535)+dh&65535}else{di=dh}b[(c[277218]|0)+(cA<<1)>>1]=di;if((a[1108928]|0)==0){dj=b[(c[277213]|0)+(j+12<<1)>>1]|0}else{dj=0}if((a[(c[277215]|0)+cA|0]&32)==0){dk=c[277228]&65535}else{dk=b[(c[277226]|0)+(f<<1)>>1]|0}f=dj&-2048;r=dk&-2048;cz=(f&65535)>(r&65535)?f-r&65535:0;r=dj&2016;f=dk&2016;if((r&65535)>(f&65535)){dl=(r-f&65535)+cz&65535}else{dl=cz}cz=dj&31;f=dk&31;if((cz&65535)>(f&65535)){dm=(cz-f&65535)+dl&65535}else{dm=dl}f=j+11|0;b[(c[277218]|0)+(f<<1)>>1]=dm;cz=a[1108909]|0;a[(c[277219]|0)+f|0]=cz;a[(c[277219]|0)+cA|0]=cz}}while(0);cA=cH-1&255;if(cA<<24>>24!=0){cG=cA;F=9073}}if((F|0)==9073){F=0;cA=j+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+cA|0]|0)){cz=a[bE+6|0]|0;f=cz&255;if(cz<<24>>24==0){break}cz=b[(c[277225]|0)+(f<<1)>>1]|0;if((a[(c[277215]|0)+cA|0]&32)==0){dn=c[277228]&65535}else{dn=b[(c[277213]|0)+(cA<<1)>>1]|0}r=cz&-2048;cC=dn&-2048;cB=(r&65535)>(cC&65535)?r-cC&65535:0;cC=cz&2016;r=dn&2016;if((cC&65535)>(r&65535)){dp=(cC-r&65535)+cB&65535}else{dp=cB}cB=cz&31;cz=dn&31;if((cB&65535)>(cz&65535)){dq=(cB-cz&65535)+dp&65535}else{dq=dp}b[(c[277218]|0)+(cA<<1)>>1]=dq;if((a[1108928]|0)==0){dr=b[(c[277213]|0)+(j+14<<1)>>1]|0}else{dr=0}if((a[(c[277215]|0)+cA|0]&32)==0){ds=c[277228]&65535}else{ds=b[(c[277226]|0)+(f<<1)>>1]|0}f=dr&-2048;cz=ds&-2048;cB=(f&65535)>(cz&65535)?f-cz&65535:0;cz=dr&2016;f=ds&2016;if((cz&65535)>(f&65535)){dt=(cz-f&65535)+cB&65535}else{dt=cB}cB=dr&31;f=ds&31;if((cB&65535)>(f&65535)){du=(cB-f&65535)+dt&65535}else{du=dt}f=j+13|0;b[(c[277218]|0)+(f<<1)>>1]=du;cB=a[1108909]|0;a[(c[277219]|0)+f|0]=cB;a[(c[277219]|0)+cA|0]=cB}}while(0);if(cG<<24>>24!=1){F=9093}}do{if((F|0)==9093){F=0;cA=j+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+cA|0]|0)){break}cB=a[bE+7|0]|0;f=cB&255;if(cB<<24>>24==0){break}cB=b[(c[277225]|0)+(f<<1)>>1]|0;if((a[(c[277215]|0)+cA|0]&32)==0){dv=c[277228]&65535}else{dv=b[(c[277213]|0)+(cA<<1)>>1]|0}cz=cB&-2048;r=dv&-2048;cC=(cz&65535)>(r&65535)?cz-r&65535:0;r=cB&2016;cz=dv&2016;if((r&65535)>(cz&65535)){dw=(r-cz&65535)+cC&65535}else{dw=cC}cC=cB&31;cB=dv&31;if((cC&65535)>(cB&65535)){dx=(cC-cB&65535)+dw&65535}else{dx=dw}b[(c[277218]|0)+(cA<<1)>>1]=dx;if((a[1108928]|0)==0){dy=b[(c[277213]|0)+(j+16<<1)>>1]|0}else{dy=0}if((a[(c[277215]|0)+cA|0]&32)==0){dz=c[277228]&65535}else{dz=b[(c[277226]|0)+(f<<1)>>1]|0}f=dy&-2048;cB=dz&-2048;cC=(f&65535)>(cB&65535)?f-cB&65535:0;cB=dy&2016;f=dz&2016;if((cB&65535)>(f&65535)){dA=(cB-f&65535)+cC&65535}else{dA=cC}cC=dy&31;f=dz&31;if((cC&65535)>(f&65535)){dB=(cC-f&65535)+dA&65535}else{dB=dA}f=j+15|0;b[(c[277218]|0)+(f<<1)>>1]=dB;cC=a[1108909]|0;a[(c[277219]|0)+f|0]=cC;a[(c[277219]|0)+cA|0]=cC}}while(0);cC=aF-1|0;if((cC|0)>0){bE=bE-8|0;aF=cC;j=(c[277223]|0)+j|0}else{break}}return}}
function WX(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0;i=c[263194]|0;do{if((a[(c[263195]|0)+8496|0]&1)==0){j=1106168}else{if((a[1106089]|0)==0){j=1125528;break}k=d[1044485]|0;c[276541]=7080+(k<<5);l=0;do{m=l<<1&2;n=l&2;o=l&4;p=0;do{b[1125528+(l<<9)+(p<<1)>>1]=d[(p>>>1&28|n)+(7080+(k<<5))|0]<<6|d[(p<<2&28|m)+(7080+(k<<5))|0]<<11|d[(p>>>3&24|o)+(7080+(k<<5))|0];p=p+1|0;}while(p>>>0<256);l=l+1|0;}while(l>>>0<8);a[1106089]=0;j=1125528}}while(0);c[277226]=j;c[277225]=(a[1108928]|0)!=0?1393712:j;j=c[277230]|0;if(j>>>0>(c[277231]|0)>>>0){return}l=f>>>0<g>>>0;k=h+7|0;h=k&255;p=g-1|0;o=ab(c[277223]|0,j)|0;m=j;n=1097960+(j<<4)|0;while(1){j=e[n+12>>1]<<19>>19;q=e[n+8>>1]<<19;r=e[n+10>>1]<<19;s=m+1|0;t=(e[n+14>>1]<<19>>19)-(r>>19)|0;u=(t&8192|0)!=0?t|-1024:t&1023;t=b[n+2>>1]|0;v=((a[1044414]|0)==0?s:s^255)&255;w=(ab(v,t)|0)&-64;x=w+(q>>11)+((ab(u,t)|0)&-64)|0;t=b[n+6>>1]|0;w=(ab(t,v)|0)&-64;v=w+(r>>11)+((ab(u,t)|0)&-64)|0;t=b[n>>1]|0;if((a[1044413]|0)==0){u=b[n+4>>1]|0;y=t;z=u<<16>>16;A=f;B=u}else{u=b[n+4>>1]|0;y=-t|0;z=-(u<<16>>16)|0;A=p;B=u}u=j-(q>>19)|0;q=(u&8192|0)!=0?u|-1024:u&1023;u=ab(A,t)|0;j=u+((ab(t,q)|0)&-64)|0;t=B<<16>>16;u=ab(t,A)|0;r=((ab(t,q)|0)&-64)+u|0;L17100:do{if((a[1044415]|0)==0){if(l){C=r;D=j;E=f}else{break}while(1){u=D+x|0;q=(C+v|0)>>>8;t=E+o|0;do{if((k|0)>(d[(c[277219]|0)+t|0]|0)){w=a[i+(u>>>8<<1&14|q<<4&112|d[(c[263194]|0)+(q<<5&32512|u>>>10&254)|0]<<7|1)|0]|0;F=w&255;if(w<<24>>24==0){break}do{if((a[1108928]|0)==0){w=b[(c[277225]|0)+(F<<1)>>1]|0;G=w&65535;H=G&63454;if((a[(c[277215]|0)+t|0]&32)==0){I=c[277228]|0;J=(e[(c[277220]|0)+((((I&-2082)+H|0)>>>1)+(G&2081&I)<<1)>>1]|(I^G)&2081)&65535;break}else{G=b[(c[277213]|0)+(t<<1)>>1]|0;J=(((G&63454)+H|0)>>>1)+(G&w&2081)&65535;break}}else{w=e[(c[277225]|0)+(F<<1)>>1]|0;G=(a[(c[277215]|0)+t|0]&32)==0;if(G){H=c[277228]|0;K=H;L=H&-2082}else{H=e[(c[277213]|0)+(t<<1)>>1]|0;K=H;L=H&63454}if(G){M=c[277228]|0}else{M=e[(c[277213]|0)+(t<<1)>>1]|0}J=((M^w)&2081|e[(c[277220]|0)+((w&2081&K)+((L+(w&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(t<<1)>>1]=J;a[(c[277219]|0)+t|0]=h}}while(0);t=E+1|0;if(t>>>0>=g>>>0){break L17100}C=C+z|0;D=D+y|0;E=t}}else{if(l){N=r;O=j;P=f}else{break}while(1){t=O+x|0;u=t>>8;q=N+v>>8;do{if((q|u)>>>0<1024){Q=q<<4&112|u<<1&14|d[(c[263194]|0)+((q<<5&-256)+(t>>10&-2))|0]<<7;R=12306}else{if((a[1044415]|0)!=3){break}Q=q<<4&112|u<<1&14;R=12306}}while(0);do{if((R|0)==12306){R=0;u=P+o|0;if((k|0)<=(d[(c[277219]|0)+u|0]|0)){break}q=a[i+(Q|1)|0]|0;t=q&255;if(q<<24>>24==0){break}do{if((a[1108928]|0)==0){q=b[(c[277225]|0)+(t<<1)>>1]|0;F=q&65535;w=F&63454;if((a[(c[277215]|0)+u|0]&32)==0){G=c[277228]|0;S=(e[(c[277220]|0)+((((G&-2082)+w|0)>>>1)+(F&2081&G)<<1)>>1]|(G^F)&2081)&65535;break}else{F=b[(c[277213]|0)+(u<<1)>>1]|0;S=(((F&63454)+w|0)>>>1)+(F&q&2081)&65535;break}}else{q=e[(c[277225]|0)+(t<<1)>>1]|0;F=(a[(c[277215]|0)+u|0]&32)==0;if(F){w=c[277228]|0;T=w;U=w&-2082}else{w=e[(c[277213]|0)+(u<<1)>>1]|0;T=w;U=w&63454}if(F){V=c[277228]|0}else{V=e[(c[277213]|0)+(u<<1)>>1]|0}S=((V^q)&2081|e[(c[277220]|0)+((q&2081&T)+((U+(q&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(u<<1)>>1]=S;a[(c[277219]|0)+u|0]=h}}while(0);t=P+1|0;if(t>>>0<g>>>0){N=N+z|0;O=O+y|0;P=t}else{break}}}}while(0);if(s>>>0>(c[277231]|0)>>>0){break}o=(c[277223]|0)+o|0;m=s;n=n+16|0}return}function WY(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;i=c[263194]|0;do{if((a[(c[263195]|0)+8496|0]&1)==0){j=1106168}else{if((a[1106089]|0)==0){j=1125528;break}k=d[1044485]|0;c[276541]=7080+(k<<5);l=0;do{m=l<<1&2;n=l&2;o=l&4;p=0;do{b[1125528+(l<<9)+(p<<1)>>1]=d[(p>>>1&28|n)+(7080+(k<<5))|0]<<6|d[(p<<2&28|m)+(7080+(k<<5))|0]<<11|d[(p>>>3&24|o)+(7080+(k<<5))|0];p=p+1|0;}while(p>>>0<256);l=l+1|0;}while(l>>>0<8);a[1106089]=0;j=1125528}}while(0);c[277226]=j;c[277225]=(a[1108928]|0)!=0?1393712:j;j=c[277230]|0;if(j>>>0>(c[277231]|0)>>>0){return}l=f>>>0<g>>>0;k=h+7|0;h=k&255;p=g-1|0;o=ab(c[277223]|0,j)|0;m=j;n=1097960+(j<<4)|0;while(1){j=e[n+12>>1]<<19>>19;q=e[n+8>>1]<<19;r=e[n+10>>1]<<19;s=m+1|0;t=(e[n+14>>1]<<19>>19)-(r>>19)|0;u=(t&8192|0)!=0?t|-1024:t&1023;t=b[n+2>>1]|0;v=((a[1044414]|0)==0?s:s^255)&255;w=(ab(v,t)|0)&-64;x=w+(q>>11)+((ab(u,t)|0)&-64)|0;t=b[n+6>>1]|0;w=(ab(t,v)|0)&-64;v=w+(r>>11)+((ab(u,t)|0)&-64)|0;t=b[n>>1]|0;if((a[1044413]|0)==0){u=b[n+4>>1]|0;y=t;z=u<<16>>16;A=f;B=u}else{u=b[n+4>>1]|0;y=-t|0;z=-(u<<16>>16)|0;A=p;B=u}u=j-(q>>19)|0;q=(u&8192|0)!=0?u|-1024:u&1023;u=ab(A,t)|0;j=u+((ab(t,q)|0)&-64)|0;t=B<<16>>16;u=ab(t,A)|0;r=((ab(t,q)|0)&-64)+u|0;L17174:do{if((a[1044415]|0)==0){if(l){C=r;D=j;E=f}else{break}while(1){u=D+x|0;q=(C+v|0)>>>8;t=E+o|0;do{if((k|0)>(d[(c[277219]|0)+t|0]|0)){w=a[i+(u>>>8<<1&14|q<<4&112|d[(c[263194]|0)+(q<<5&32512|u>>>10&254)|0]<<7|1)|0]|0;if(w<<24>>24==0){break}F=b[(c[277225]|0)+((w&255)<<1)>>1]|0;if((a[(c[277215]|0)+t|0]&32)==0){G=c[277228]&65535}else{G=b[(c[277213]|0)+(t<<1)>>1]|0}w=F&-2048;H=G&-2048;I=(w&65535)>(H&65535)?w-H&65535:0;H=F&2016;w=G&2016;if((H&65535)>(w&65535)){J=(H-w&65535)+I&65535}else{J=I}I=F&31;F=G&31;if((I&65535)>(F&65535)){K=(I-F&65535)+J&65535}else{K=J}b[(c[277218]|0)+(t<<1)>>1]=K;a[(c[277219]|0)+t|0]=h}}while(0);t=E+1|0;if(t>>>0>=g>>>0){break L17174}C=C+z|0;D=D+y|0;E=t}}else{if(l){L=r;M=j;N=f}else{break}while(1){t=M+x|0;u=t>>8;q=L+v>>8;do{if((q|u)>>>0<1024){O=q<<4&112|u<<1&14|d[(c[263194]|0)+((q<<5&-256)+(t>>10&-2))|0]<<7;P=12357}else{if((a[1044415]|0)!=3){break}O=q<<4&112|u<<1&14;P=12357}}while(0);do{if((P|0)==12357){P=0;u=N+o|0;if((k|0)<=(d[(c[277219]|0)+u|0]|0)){break}q=a[i+(O|1)|0]|0;if(q<<24>>24==0){break}t=b[(c[277225]|0)+((q&255)<<1)>>1]|0;if((a[(c[277215]|0)+u|0]&32)==0){Q=c[277228]&65535}else{Q=b[(c[277213]|0)+(u<<1)>>1]|0}q=t&-2048;F=Q&-2048;I=(q&65535)>(F&65535)?q-F&65535:0;F=t&2016;q=Q&2016;if((F&65535)>(q&65535)){R=(F-q&65535)+I&65535}else{R=I}I=t&31;t=Q&31;if((I&65535)>(t&65535)){S=(I-t&65535)+R&65535}else{S=R}b[(c[277218]|0)+(u<<1)>>1]=S;a[(c[277219]|0)+u|0]=h}}while(0);u=N+1|0;if(u>>>0<g>>>0){L=L+z|0;M=M+y|0;N=u}else{break}}}}while(0);if(s>>>0>(c[277231]|0)>>>0){break}o=(c[277223]|0)+o|0;m=s;n=n+16|0}return}function WZ(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0;i=c[263194]|0;do{if((a[(c[263195]|0)+8496|0]&1)==0){j=1106168}else{if((a[1106089]|0)==0){j=1125528;break}k=d[1044485]|0;c[276541]=7080+(k<<5);l=0;do{m=l<<1&2;n=l&2;o=l&4;p=0;do{b[1125528+(l<<9)+(p<<1)>>1]=d[(p>>>1&28|n)+(7080+(k<<5))|0]<<6|d[(p<<2&28|m)+(7080+(k<<5))|0]<<11|d[(p>>>3&24|o)+(7080+(k<<5))|0];p=p+1|0;}while(p>>>0<256);l=l+1|0;}while(l>>>0<8);a[1106089]=0;j=1125528}}while(0);c[277226]=j;c[277225]=(a[1108928]|0)!=0?1393712:j;j=c[277230]|0;if(j>>>0>(c[277231]|0)>>>0){return}l=f>>>0<g>>>0;k=h+7|0;h=k&255;p=g-1|0;o=ab(c[277223]|0,j)|0;m=j;n=1097960+(j<<4)|0;while(1){j=e[n+12>>1]<<19>>19;q=e[n+8>>1]<<19;r=e[n+10>>1]<<19;s=m+1|0;t=(e[n+14>>1]<<19>>19)-(r>>19)|0;u=(t&8192|0)!=0?t|-1024:t&1023;t=b[n+2>>1]|0;v=((a[1044414]|0)==0?s:s^255)&255;w=(ab(v,t)|0)&-64;x=w+(q>>11)+((ab(u,t)|0)&-64)|0;t=b[n+6>>1]|0;w=(ab(t,v)|0)&-64;v=w+(r>>11)+((ab(u,t)|0)&-64)|0;t=b[n>>1]|0;if((a[1044413]|0)==0){u=b[n+4>>1]|0;y=t;z=u<<16>>16;A=f;B=u}else{u=b[n+4>>1]|0;y=-t|0;z=-(u<<16>>16)|0;A=p;B=u}u=j-(q>>19)|0;q=(u&8192|0)!=0?u|-1024:u&1023;u=ab(A,t)|0;j=u+((ab(t,q)|0)&-64)|0;t=B<<16>>16;u=ab(t,A)|0;r=((ab(t,q)|0)&-64)+u|0;L17238:do{if((a[1044415]|0)==0){if(l){C=r;D=j;E=f}else{break}while(1){u=D+x|0;q=(C+v|0)>>>8;t=E+o|0;do{if((k|0)>(d[(c[277219]|0)+t|0]|0)){w=a[i+(u>>>8<<1&14|q<<4&112|d[(c[263194]|0)+(q<<5&32512|u>>>10&254)|0]<<7|1)|0]|0;if(w<<24>>24==0){break}F=b[(c[277225]|0)+((w&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){G=b[(c[277221]|0)+(((F&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{w=c[277228]&65535;H=F&-2048;I=w&-2048;J=(H&65535)>(I&65535)?H-I&65535:0;I=F&2016;H=w&2016;if((I&65535)>(H&65535)){K=(I-H&65535)+J&65535}else{K=J}J=F&31;H=w&31;if((J&65535)<=(H&65535)){G=K;break}G=(J-H&65535)+K&65535}}while(0);b[(c[277218]|0)+(t<<1)>>1]=G;a[(c[277219]|0)+t|0]=h}}while(0);t=E+1|0;if(t>>>0>=g>>>0){break L17238}C=C+z|0;D=D+y|0;E=t}}else{if(l){L=r;M=j;N=f}else{break}while(1){t=M+x|0;u=t>>8;q=L+v>>8;do{if((q|u)>>>0<1024){O=q<<4&112|u<<1&14|d[(c[263194]|0)+((q<<5&-256)+(t>>10&-2))|0]<<7;P=12403}else{if((a[1044415]|0)!=3){break}O=q<<4&112|u<<1&14;P=12403}}while(0);do{if((P|0)==12403){P=0;u=N+o|0;if((k|0)<=(d[(c[277219]|0)+u|0]|0)){break}q=a[i+(O|1)|0]|0;if(q<<24>>24==0){break}t=b[(c[277225]|0)+((q&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){Q=b[(c[277221]|0)+(((t&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{q=c[277228]&65535;F=t&-2048;H=q&-2048;J=(F&65535)>(H&65535)?F-H&65535:0;H=t&2016;F=q&2016;if((H&65535)>(F&65535)){R=(H-F&65535)+J&65535}else{R=J}J=t&31;F=q&31;if((J&65535)<=(F&65535)){Q=R;break}Q=(J-F&65535)+R&65535}}while(0);b[(c[277218]|0)+(u<<1)>>1]=Q;a[(c[277219]|0)+u|0]=h}}while(0);t=N+1|0;if(t>>>0<g>>>0){L=L+z|0;M=M+y|0;N=t}else{break}}}}while(0);if(s>>>0>(c[277231]|0)>>>0){break}o=(c[277223]|0)+o|0;m=s;n=n+16|0}return}function W_(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0;i=c[263194]|0;do{if((a[(c[263195]|0)+8496|0]&1)==0){j=1106168}else{if((a[1106089]|0)==0){j=1125528;break}k=d[1044485]|0;c[276541]=7080+(k<<5);l=0;do{m=l<<1&2;n=l&2;o=l&4;p=0;do{b[1125528+(l<<9)+(p<<1)>>1]=d[(p>>>1&28|n)+(7080+(k<<5))|0]<<6|d[(p<<2&28|m)+(7080+(k<<5))|0]<<11|d[(p>>>3&24|o)+(7080+(k<<5))|0];p=p+1|0;}while(p>>>0<256);l=l+1|0;}while(l>>>0<8);a[1106089]=0;j=1125528}}while(0);c[277226]=j;c[277225]=(a[1108928]|0)!=0?1393712:j;j=c[277230]|0;if(j>>>0>(c[277231]|0)>>>0){return}l=f>>>0<g>>>0;k=h+7|0;h=k&255;p=g-1|0;o=ab(c[277223]|0,j)|0;m=j;n=1097960+(j<<4)|0;while(1){j=e[n+12>>1]<<19>>19;q=e[n+8>>1]<<19;r=e[n+10>>1]<<19;s=m+1|0;t=(e[n+14>>1]<<19>>19)-(r>>19)|0;u=(t&8192|0)!=0?t|-1024:t&1023;t=b[n+2>>1]|0;v=((a[1044414]|0)==0?s:s^255)&255;w=(ab(v,t)|0)&-64;x=w+(q>>11)+((ab(u,t)|0)&-64)|0;t=b[n+6>>1]|0;w=(ab(t,v)|0)&-64;v=w+(r>>11)+((ab(u,t)|0)&-64)|0;t=b[n>>1]|0;if((a[1044413]|0)==0){u=b[n+4>>1]|0;y=t;z=u<<16>>16;A=f;B=u}else{u=b[n+4>>1]|0;y=-t|0;z=-(u<<16>>16)|0;A=p;B=u}u=j-(q>>19)|0;q=(u&8192|0)!=0?u|-1024:u&1023;u=ab(A,t)|0;j=u+((ab(t,q)|0)&-64)|0;t=B<<16>>16;u=ab(t,A)|0;r=((ab(t,q)|0)&-64)+u|0;L17298:do{if((a[1044415]|0)==0){if(l){C=r;D=j;E=f}else{break}while(1){u=D+x|0;q=(C+v|0)>>>8;t=E+o|0;do{if((k|0)>(d[(c[277219]|0)+t|0]|0)){w=a[i+(u>>>8<<1&14|q<<4&112|d[(c[263194]|0)+(q<<5&32512|u>>>10&254)|0]<<7|1)|0]|0;F=w&255;if(w<<24>>24==0){break}do{if((a[1108928]|0)==0){w=b[(c[277225]|0)+(F<<1)>>1]|0;if((a[(c[277215]|0)+t|0]&32)!=0){G=b[(c[277221]|0)+((w&65535|67616)-(b[(c[277213]|0)+(t<<1)>>1]&63454)>>1<<1)>>1]|0;break}H=c[277228]&65535;I=w&-2048;J=H&-2048;K=(I&65535)>(J&65535)?I-J&65535:0;J=w&2016;I=H&2016;if((J&65535)>(I&65535)){L=(J-I&65535)+K&65535}else{L=K}K=w&31;w=H&31;if((K&65535)<=(w&65535)){G=L;break}G=(K-w&65535)+L&65535}else{w=b[(c[277225]|0)+(F<<1)>>1]|0;if((a[(c[277215]|0)+t|0]&32)==0){M=c[277228]&65535}else{M=b[(c[277213]|0)+(t<<1)>>1]|0}K=w&-2048;H=M&-2048;I=(K&65535)>(H&65535)?K-H&65535:0;H=w&2016;K=M&2016;if((H&65535)>(K&65535)){N=(H-K&65535)+I&65535}else{N=I}I=w&31;w=M&31;if((I&65535)<=(w&65535)){G=N;break}G=(I-w&65535)+N&65535}}while(0);b[(c[277218]|0)+(t<<1)>>1]=G;a[(c[277219]|0)+t|0]=h}}while(0);t=E+1|0;if(t>>>0>=g>>>0){break L17298}C=C+z|0;D=D+y|0;E=t}}else{if(l){O=r;P=j;Q=f}else{break}while(1){t=P+x|0;u=t>>8;q=O+v>>8;do{if((q|u)>>>0<1024){R=q<<4&112|u<<1&14|d[(c[263194]|0)+((q<<5&-256)+(t>>10&-2))|0]<<7;S=12456}else{if((a[1044415]|0)!=3){break}R=q<<4&112|u<<1&14;S=12456}}while(0);do{if((S|0)==12456){S=0;u=Q+o|0;if((k|0)<=(d[(c[277219]|0)+u|0]|0)){break}q=a[i+(R|1)|0]|0;t=q&255;if(q<<24>>24==0){break}do{if((a[1108928]|0)==0){q=b[(c[277225]|0)+(t<<1)>>1]|0;if((a[(c[277215]|0)+u|0]&32)!=0){T=b[(c[277221]|0)+((q&65535|67616)-(b[(c[277213]|0)+(u<<1)>>1]&63454)>>1<<1)>>1]|0;break}F=c[277228]&65535;w=q&-2048;I=F&-2048;K=(w&65535)>(I&65535)?w-I&65535:0;I=q&2016;w=F&2016;if((I&65535)>(w&65535)){U=(I-w&65535)+K&65535}else{U=K}K=q&31;q=F&31;if((K&65535)<=(q&65535)){T=U;break}T=(K-q&65535)+U&65535}else{q=b[(c[277225]|0)+(t<<1)>>1]|0;if((a[(c[277215]|0)+u|0]&32)==0){V=c[277228]&65535}else{V=b[(c[277213]|0)+(u<<1)>>1]|0}K=q&-2048;F=V&-2048;w=(K&65535)>(F&65535)?K-F&65535:0;F=q&2016;K=V&2016;if((F&65535)>(K&65535)){W=(F-K&65535)+w&65535}else{W=w}w=q&31;q=V&31;if((w&65535)<=(q&65535)){T=W;break}T=(w-q&65535)+W&65535}}while(0);b[(c[277218]|0)+(u<<1)>>1]=T;a[(c[277219]|0)+u|0]=h}}while(0);t=Q+1|0;if(t>>>0<g>>>0){O=O+z|0;P=P+y|0;Q=t}else{break}}}}while(0);if(s>>>0>(c[277231]|0)>>>0){break}o=(c[277223]|0)+o|0;m=s;n=n+16|0}return}function W$(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0;i=c[263194]|0;do{if((a[(c[263195]|0)+8496|0]&1)==0){j=1106168}else{if((a[1106089]|0)==0){j=1125528;break}k=d[1044485]|0;c[276541]=7080+(k<<5);l=0;do{m=l<<1&2;n=l&2;o=l&4;p=0;do{b[1125528+(l<<9)+(p<<1)>>1]=d[(p>>>1&28|n)+(7080+(k<<5))|0]<<6|d[(p<<2&28|m)+(7080+(k<<5))|0]<<11|d[(p>>>3&24|o)+(7080+(k<<5))|0];p=p+1|0;}while(p>>>0<256);l=l+1|0;}while(l>>>0<8);a[1106089]=0;j=1125528}}while(0);c[277226]=j;c[277225]=(a[1108928]|0)!=0?1393712:j;j=c[277230]|0;if((a[1044434]|0)==0){q=f;r=g;s=0;t=1;u=j}else{l=d[1044432]|0;k=((j-(d[1044433]|0)|0)>>>0)%(l>>>0)|0;p=g-1+l|0;q=f-((f|0)%(l|0)|0)|0;r=p-((p|0)%(l|0)|0)|0;s=k;t=l;u=j-k|0}k=c[277231]|0;if(u>>>0>k>>>0){return}j=(q|0)<(r|0);l=t&255;p=h+7|0;h=p&255;o=r-1|0;m=t-1|0;n=s;s=t;t=ab(c[277223]|0,u)|0;v=u;w=1097960+(u<<4)|0;u=k;while(1){if((s+v|0)>>>0>u>>>0){x=u+1-v|0}else{x=s}k=e[w+12>>1]<<19>>19;y=e[w+8>>1]<<19;z=e[w+10>>1]<<19;A=v+1|0;B=(e[w+14>>1]<<19>>19)-(z>>19)|0;C=(B&8192|0)!=0?B|-1024:B&1023;B=b[w+2>>1]|0;D=((a[1044414]|0)==0?A:A^255)&255;A=(ab(D,B)|0)&-64;E=A+(y>>11)+((ab(C,B)|0)&-64)|0;B=b[w+6>>1]|0;A=(ab(B,D)|0)&-64;D=A+(z>>11)+((ab(C,B)|0)&-64)|0;B=b[w>>1]|0;if((a[1044413]|0)==0){C=b[w+4>>1]|0;F=B;G=C<<16>>16;H=q;I=C}else{C=b[w+4>>1]|0;F=-B|0;G=-(C<<16>>16)|0;H=o;I=C}C=k-(y>>19)|0;y=(C&8192|0)!=0?C|-1024:C&1023;C=ab(H,B)|0;k=C+((ab(B,y)|0)&-64)|0;B=I<<16>>16;C=ab(B,H)|0;z=((ab(B,y)|0)&-64)+C|0;do{if((a[1044415]|0)==0){if(!j){break}C=(n|0)>=(x|0);y=k;B=z;A=1;J=q;while(1){K=A-1&255;do{if(K<<24>>24==0){L=y+E|0;M=(B+D|0)>>>8;N=a[i+(M<<4&112|L>>>8<<1&14|d[(c[263194]|0)+(M<<5&32512|L>>>10&254)|0]<<7|1)|0]|0;if(N<<24>>24==0|C){O=l;break}L=m+J|0;M=(L|0)<(J|0);P=N&255;N=n;while(1){if(!M){Q=L;do{R=Q+t|0;S=(ab(c[277223]|0,N)|0)+R|0;if((Q|0)>=(f|0)&(p|0)>(d[(c[277219]|0)+S|0]|0)&(Q|0)<(g|0)){b[(c[277218]|0)+(S<<1)>>1]=b[(c[277225]|0)+(P<<1)>>1]|0;S=(ab(c[277223]|0,N)|0)+R|0;a[(c[277219]|0)+S|0]=h}Q=Q-1|0;}while((Q|0)>=(J|0))}Q=N+1|0;if((Q|0)<(x|0)){N=Q}else{O=l;break}}}else{O=K}}while(0);K=J+1|0;if((K|0)<(r|0)){y=y+F|0;B=B+G|0;A=O;J=K}else{break}}}else{if(!j){break}J=(n|0)>=(x|0);A=k;B=z;y=1;C=q;while(1){K=y-1&255;do{if(K<<24>>24==0){N=A+E|0;P=N>>8;L=B+D>>8;if((P|L)>>>0<1024){T=P<<1&14|L<<4&112|d[(c[263194]|0)+((L<<5&-256)+(N>>10&-2))|0]<<7}else{if((a[1044415]|0)!=3){U=l;break}T=P<<1&14|L<<4&112}L=a[i+(T|1)|0]|0;if(L<<24>>24==0|J){U=l;break}P=m+C|0;N=(P|0)<(C|0);M=L&255;L=n;while(1){if(!N){Q=P;do{S=Q+t|0;R=(ab(c[277223]|0,L)|0)+S|0;if((Q|0)>=(f|0)&(p|0)>(d[(c[277219]|0)+R|0]|0)&(Q|0)<(g|0)){b[(c[277218]|0)+(R<<1)>>1]=b[(c[277225]|0)+(M<<1)>>1]|0;R=(ab(c[277223]|0,L)|0)+S|0;a[(c[277219]|0)+R|0]=h}Q=Q-1|0;}while((Q|0)>=(C|0))}Q=L+1|0;if((Q|0)<(x|0)){L=Q}else{U=l;break}}}else{U=K}}while(0);K=C+1|0;if((K|0)<(r|0)){A=A+F|0;B=B+G|0;y=U;C=K}else{break}}}}while(0);D=x+v|0;E=(ab(c[277223]|0,x)|0)+t|0;z=c[277231]|0;if(D>>>0>z>>>0){break}else{n=0;s=x;t=E;v=D;w=w+(x<<4)|0;u=z}}return}function W0(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ac=0;i=c[263194]|0;do{if((a[(c[263195]|0)+8496|0]&1)==0){j=1106168}else{if((a[1106089]|0)==0){j=1125528;break}k=d[1044485]|0;c[276541]=7080+(k<<5);l=0;do{m=l<<1&2;n=l&2;o=l&4;p=0;do{b[1125528+(l<<9)+(p<<1)>>1]=d[(p>>>1&28|n)+(7080+(k<<5))|0]<<6|d[(p<<2&28|m)+(7080+(k<<5))|0]<<11|d[(p>>>3&24|o)+(7080+(k<<5))|0];p=p+1|0;}while(p>>>0<256);l=l+1|0;}while(l>>>0<8);a[1106089]=0;j=1125528}}while(0);c[277226]=j;c[277225]=(a[1108928]|0)!=0?1393712:j;j=c[277230]|0;if((a[1044434]|0)==0){q=f;r=g;s=0;t=1;u=j}else{l=d[1044432]|0;k=((j-(d[1044433]|0)|0)>>>0)%(l>>>0)|0;p=g-1+l|0;q=f-((f|0)%(l|0)|0)|0;r=p-((p|0)%(l|0)|0)|0;s=k;t=l;u=j-k|0}k=c[277231]|0;if(u>>>0>k>>>0){return}j=(q|0)<(r|0);l=t&255;p=h+7|0;h=p&255;o=r-1|0;m=t-1|0;n=s;s=t;t=ab(c[277223]|0,u)|0;v=u;w=1097960+(u<<4)|0;u=k;while(1){if((s+v|0)>>>0>u>>>0){x=u+1-v|0}else{x=s}k=e[w+12>>1]<<19>>19;y=e[w+8>>1]<<19;z=e[w+10>>1]<<19;A=v+1|0;B=(e[w+14>>1]<<19>>19)-(z>>19)|0;C=(B&8192|0)!=0?B|-1024:B&1023;B=b[w+2>>1]|0;D=((a[1044414]|0)==0?A:A^255)&255;A=(ab(D,B)|0)&-64;E=A+(y>>11)+((ab(C,B)|0)&-64)|0;B=b[w+6>>1]|0;A=(ab(B,D)|0)&-64;D=A+(z>>11)+((ab(C,B)|0)&-64)|0;B=b[w>>1]|0;if((a[1044413]|0)==0){C=b[w+4>>1]|0;F=B;G=C<<16>>16;H=q;I=C}else{C=b[w+4>>1]|0;F=-B|0;G=-(C<<16>>16)|0;H=o;I=C}C=k-(y>>19)|0;y=(C&8192|0)!=0?C|-1024:C&1023;C=ab(H,B)|0;k=C+((ab(B,y)|0)&-64)|0;B=I<<16>>16;C=ab(B,H)|0;z=((ab(B,y)|0)&-64)+C|0;do{if((a[1044415]|0)==0){if(!j){break}C=(n|0)>=(x|0);y=k;B=z;A=1;J=q;while(1){K=A-1&255;do{if(K<<24>>24==0){L=y+E|0;M=(B+D|0)>>>8;N=a[i+(M<<4&112|L>>>8<<1&14|d[(c[263194]|0)+(M<<5&32512|L>>>10&254)|0]<<7|1)|0]|0;if(N<<24>>24==0|C){O=l;break}L=m+J|0;M=(L|0)<(J|0);P=N&255;N=n;while(1){if(!M){Q=L;do{R=Q+t|0;S=(ab(c[277223]|0,N)|0)+R|0;if((Q|0)>=(f|0)&(p|0)>(d[(c[277219]|0)+S|0]|0)&(Q|0)<(g|0)){T=e[(c[277225]|0)+(P<<1)>>1]|0;U=(a[(c[277215]|0)+S|0]&32)==0;if(U){V=c[277228]|0;W=V;X=V&-2082}else{V=e[(c[277213]|0)+(S<<1)>>1]|0;W=V;X=V&63454}if(U){Y=c[277228]|0}else{Y=e[(c[277213]|0)+(S<<1)>>1]|0}b[(c[277218]|0)+(S<<1)>>1]=((Y^T)&2081|e[(c[277220]|0)+((T&2081&W)+((X+(T&63454)|0)>>>1)<<1)>>1])&65535;T=(ab(c[277223]|0,N)|0)+R|0;a[(c[277219]|0)+T|0]=h}Q=Q-1|0;}while((Q|0)>=(J|0))}Q=N+1|0;if((Q|0)<(x|0)){N=Q}else{O=l;break}}}else{O=K}}while(0);K=J+1|0;if((K|0)<(r|0)){y=y+F|0;B=B+G|0;A=O;J=K}else{break}}}else{if(!j){break}J=(n|0)>=(x|0);A=k;B=z;y=1;C=q;while(1){K=y-1&255;do{if(K<<24>>24==0){N=A+E|0;P=N>>8;L=B+D>>8;if((P|L)>>>0<1024){Z=P<<1&14|L<<4&112|d[(c[263194]|0)+((L<<5&-256)+(N>>10&-2))|0]<<7}else{if((a[1044415]|0)!=3){_=l;break}Z=P<<1&14|L<<4&112}L=a[i+(Z|1)|0]|0;if(L<<24>>24==0|J){_=l;break}P=m+C|0;N=(P|0)<(C|0);M=L&255;L=n;while(1){if(!N){Q=P;do{T=Q+t|0;R=(ab(c[277223]|0,L)|0)+T|0;if((Q|0)>=(f|0)&(p|0)>(d[(c[277219]|0)+R|0]|0)&(Q|0)<(g|0)){S=e[(c[277225]|0)+(M<<1)>>1]|0;U=(a[(c[277215]|0)+R|0]&32)==0;if(U){V=c[277228]|0;$=V;aa=V&-2082}else{V=e[(c[277213]|0)+(R<<1)>>1]|0;$=V;aa=V&63454}if(U){ac=c[277228]|0}else{ac=e[(c[277213]|0)+(R<<1)>>1]|0}b[(c[277218]|0)+(R<<1)>>1]=((ac^S)&2081|e[(c[277220]|0)+((S&2081&$)+((aa+(S&63454)|0)>>>1)<<1)>>1])&65535;S=(ab(c[277223]|0,L)|0)+T|0;a[(c[277219]|0)+S|0]=h}Q=Q-1|0;}while((Q|0)>=(C|0))}Q=L+1|0;if((Q|0)<(x|0)){L=Q}else{_=l;break}}}else{_=K}}while(0);K=C+1|0;if((K|0)<(r|0)){A=A+F|0;B=B+G|0;y=_;C=K}else{break}}}}while(0);D=x+v|0;E=(ab(c[277223]|0,x)|0)+t|0;z=c[277231]|0;if(D>>>0>z>>>0){break}else{n=0;s=x;t=E;v=D;w=w+(x<<4)|0;u=z}}return}function W1(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0;i=c[263194]|0;do{if((a[(c[263195]|0)+8496|0]&1)==0){j=1106168}else{if((a[1106089]|0)==0){j=1125528;break}k=d[1044485]|0;c[276541]=7080+(k<<5);l=0;do{m=l<<1&2;n=l&2;o=l&4;p=0;do{b[1125528+(l<<9)+(p<<1)>>1]=d[(p>>>1&28|n)+(7080+(k<<5))|0]<<6|d[(p<<2&28|m)+(7080+(k<<5))|0]<<11|d[(p>>>3&24|o)+(7080+(k<<5))|0];p=p+1|0;}while(p>>>0<256);l=l+1|0;}while(l>>>0<8);a[1106089]=0;j=1125528}}while(0);c[277226]=j;c[277225]=(a[1108928]|0)!=0?1393712:j;j=c[277230]|0;if((a[1044434]|0)==0){q=f;r=g;s=0;t=1;u=j}else{l=d[1044432]|0;k=((j-(d[1044433]|0)|0)>>>0)%(l>>>0)|0;p=g-1+l|0;q=f-((f|0)%(l|0)|0)|0;r=p-((p|0)%(l|0)|0)|0;s=k;t=l;u=j-k|0}k=c[277231]|0;if(u>>>0>k>>>0){return}j=(q|0)<(r|0);l=t&255;p=h+7|0;h=p&255;o=r-1|0;m=t-1|0;n=s;s=t;t=ab(c[277223]|0,u)|0;v=u;w=1097960+(u<<4)|0;u=k;while(1){if((s+v|0)>>>0>u>>>0){x=u+1-v|0}else{x=s}k=e[w+12>>1]<<19>>19;y=e[w+8>>1]<<19;z=e[w+10>>1]<<19;A=v+1|0;B=(e[w+14>>1]<<19>>19)-(z>>19)|0;C=(B&8192|0)!=0?B|-1024:B&1023;B=b[w+2>>1]|0;D=((a[1044414]|0)==0?A:A^255)&255;A=(ab(D,B)|0)&-64;E=A+(y>>11)+((ab(C,B)|0)&-64)|0;B=b[w+6>>1]|0;A=(ab(B,D)|0)&-64;D=A+(z>>11)+((ab(C,B)|0)&-64)|0;B=b[w>>1]|0;if((a[1044413]|0)==0){C=b[w+4>>1]|0;F=B;G=C<<16>>16;H=q;I=C}else{C=b[w+4>>1]|0;F=-B|0;G=-(C<<16>>16)|0;H=o;I=C}C=k-(y>>19)|0;y=(C&8192|0)!=0?C|-1024:C&1023;C=ab(H,B)|0;k=C+((ab(B,y)|0)&-64)|0;B=I<<16>>16;C=ab(B,H)|0;z=((ab(B,y)|0)&-64)+C|0;do{if((a[1044415]|0)==0){if(!j){break}C=(n|0)>=(x|0);y=k;B=z;A=1;J=q;while(1){K=A-1&255;do{if(K<<24>>24==0){L=y+E|0;M=(B+D|0)>>>8;N=a[i+(M<<4&112|L>>>8<<1&14|d[(c[263194]|0)+(M<<5&32512|L>>>10&254)|0]<<7|1)|0]|0;if(N<<24>>24==0|C){O=l;break}L=m+J|0;M=(L|0)<(J|0);P=N&255;N=n;while(1){if(!M){Q=L;do{R=Q+t|0;S=(ab(c[277223]|0,N)|0)+R|0;if((Q|0)>=(f|0)&(p|0)>(d[(c[277219]|0)+S|0]|0)&(Q|0)<(g|0)){T=e[(c[277225]|0)+(P<<1)>>1]|0;U=c[277228]|0;V=(((T&63454)+(U&-2082)|0)>>>1)+(U&2081&T)|0;if((a[1108928]|0)==0){W=V&65535}else{W=(e[(c[277220]|0)+(V<<1)>>1]|(T^U)&2081)&65535}b[(c[277218]|0)+(S<<1)>>1]=W;S=(ab(c[277223]|0,N)|0)+R|0;a[(c[277219]|0)+S|0]=h}Q=Q-1|0;}while((Q|0)>=(J|0))}Q=N+1|0;if((Q|0)<(x|0)){N=Q}else{O=l;break}}}else{O=K}}while(0);K=J+1|0;if((K|0)<(r|0)){y=y+F|0;B=B+G|0;A=O;J=K}else{break}}}else{if(!j){break}J=(n|0)>=(x|0);A=k;B=z;y=1;C=q;while(1){K=y-1&255;do{if(K<<24>>24==0){N=A+E|0;P=N>>8;L=B+D>>8;if((P|L)>>>0<1024){X=P<<1&14|L<<4&112|d[(c[263194]|0)+((L<<5&-256)+(N>>10&-2))|0]<<7}else{if((a[1044415]|0)!=3){Y=l;break}X=P<<1&14|L<<4&112}L=a[i+(X|1)|0]|0;if(L<<24>>24==0|J){Y=l;break}P=m+C|0;N=(P|0)<(C|0);M=L&255;L=n;while(1){if(!N){Q=P;do{S=Q+t|0;R=(ab(c[277223]|0,L)|0)+S|0;if((Q|0)>=(f|0)&(p|0)>(d[(c[277219]|0)+R|0]|0)&(Q|0)<(g|0)){U=e[(c[277225]|0)+(M<<1)>>1]|0;T=c[277228]|0;V=(((U&63454)+(T&-2082)|0)>>>1)+(T&2081&U)|0;if((a[1108928]|0)==0){Z=V&65535}else{Z=(e[(c[277220]|0)+(V<<1)>>1]|(U^T)&2081)&65535}b[(c[277218]|0)+(R<<1)>>1]=Z;R=(ab(c[277223]|0,L)|0)+S|0;a[(c[277219]|0)+R|0]=h}Q=Q-1|0;}while((Q|0)>=(C|0))}Q=L+1|0;if((Q|0)<(x|0)){L=Q}else{Y=l;break}}}else{Y=K}}while(0);K=C+1|0;if((K|0)<(r|0)){A=A+F|0;B=B+G|0;y=Y;C=K}else{break}}}}while(0);D=x+v|0;E=(ab(c[277223]|0,x)|0)+t|0;z=c[277231]|0;if(D>>>0>z>>>0){break}else{n=0;s=x;t=E;v=D;w=w+(x<<4)|0;u=z}}return}function W2(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0;i=c[263194]|0;do{if((a[(c[263195]|0)+8496|0]&1)==0){j=1106168}else{if((a[1106089]|0)==0){j=1125528;break}k=d[1044485]|0;c[276541]=7080+(k<<5);l=0;do{m=l<<1&2;n=l&2;o=l&4;p=0;do{b[1125528+(l<<9)+(p<<1)>>1]=d[(p>>>1&28|n)+(7080+(k<<5))|0]<<6|d[(p<<2&28|m)+(7080+(k<<5))|0]<<11|d[(p>>>3&24|o)+(7080+(k<<5))|0];p=p+1|0;}while(p>>>0<256);l=l+1|0;}while(l>>>0<8);a[1106089]=0;j=1125528}}while(0);c[277226]=j;c[277225]=(a[1108928]|0)!=0?1393712:j;j=c[277230]|0;if((a[1044434]|0)==0){q=f;r=g;s=0;t=1;u=j}else{l=d[1044432]|0;k=((j-(d[1044433]|0)|0)>>>0)%(l>>>0)|0;p=g-1+l|0;q=f-((f|0)%(l|0)|0)|0;r=p-((p|0)%(l|0)|0)|0;s=k;t=l;u=j-k|0}k=c[277231]|0;if(u>>>0>k>>>0){return}j=(q|0)<(r|0);l=t&255;p=h+7|0;h=p&255;o=r-1|0;m=t-1|0;n=s;s=t;t=ab(c[277223]|0,u)|0;v=u;w=1097960+(u<<4)|0;u=k;while(1){if((s+v|0)>>>0>u>>>0){x=u+1-v|0}else{x=s}k=e[w+12>>1]<<19>>19;y=e[w+8>>1]<<19;z=e[w+10>>1]<<19;A=v+1|0;B=(e[w+14>>1]<<19>>19)-(z>>19)|0;C=(B&8192|0)!=0?B|-1024:B&1023;B=b[w+2>>1]|0;D=((a[1044414]|0)==0?A:A^255)&255;A=(ab(D,B)|0)&-64;E=A+(y>>11)+((ab(C,B)|0)&-64)|0;B=b[w+6>>1]|0;A=(ab(B,D)|0)&-64;D=A+(z>>11)+((ab(C,B)|0)&-64)|0;B=b[w>>1]|0;if((a[1044413]|0)==0){C=b[w+4>>1]|0;F=B;G=C<<16>>16;H=q;I=C}else{C=b[w+4>>1]|0;F=-B|0;G=-(C<<16>>16)|0;H=o;I=C}C=k-(y>>19)|0;y=(C&8192|0)!=0?C|-1024:C&1023;C=ab(H,B)|0;k=C+((ab(B,y)|0)&-64)|0;B=I<<16>>16;C=ab(B,H)|0;z=((ab(B,y)|0)&-64)+C|0;do{if((a[1044415]|0)==0){if(!j){break}C=(n|0)>=(x|0);y=k;B=z;A=1;J=q;while(1){K=A-1&255;do{if(K<<24>>24==0){L=y+E|0;M=(B+D|0)>>>8;N=a[i+(M<<4&112|L>>>8<<1&14|d[(c[263194]|0)+(M<<5&32512|L>>>10&254)|0]<<7|1)|0]|0;if(N<<24>>24==0|C){O=l;break}L=m+J|0;M=(L|0)<(J|0);P=N&255;N=n;while(1){if(!M){Q=L;do{R=Q+t|0;S=(ab(c[277223]|0,N)|0)+R|0;if((Q|0)>=(f|0)&(p|0)>(d[(c[277219]|0)+S|0]|0)&(Q|0)<(g|0)){do{if((a[1108928]|0)==0){T=b[(c[277225]|0)+(P<<1)>>1]|0;U=T&65535;V=U&63454;if((a[(c[277215]|0)+S|0]&32)==0){W=c[277228]|0;X=(e[(c[277220]|0)+((((W&-2082)+V|0)>>>1)+(U&2081&W)<<1)>>1]|(W^U)&2081)&65535;break}else{U=b[(c[277213]|0)+(S<<1)>>1]|0;X=(((U&63454)+V|0)>>>1)+(U&T&2081)&65535;break}}else{T=e[(c[277225]|0)+(P<<1)>>1]|0;U=(a[(c[277215]|0)+S|0]&32)==0;if(U){V=c[277228]|0;Y=V;Z=V&-2082}else{V=e[(c[277213]|0)+(S<<1)>>1]|0;Y=V;Z=V&63454}if(U){_=c[277228]|0}else{_=e[(c[277213]|0)+(S<<1)>>1]|0}X=((_^T)&2081|e[(c[277220]|0)+((T&2081&Y)+((Z+(T&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(S<<1)>>1]=X;T=(ab(c[277223]|0,N)|0)+R|0;a[(c[277219]|0)+T|0]=h}Q=Q-1|0;}while((Q|0)>=(J|0))}Q=N+1|0;if((Q|0)<(x|0)){N=Q}else{O=l;break}}}else{O=K}}while(0);K=J+1|0;if((K|0)<(r|0)){y=y+F|0;B=B+G|0;A=O;J=K}else{break}}}else{if(!j){break}J=(n|0)>=(x|0);A=k;B=z;y=1;C=q;while(1){K=y-1&255;do{if(K<<24>>24==0){N=A+E|0;P=N>>8;L=B+D>>8;if((P|L)>>>0<1024){$=P<<1&14|L<<4&112|d[(c[263194]|0)+((L<<5&-256)+(N>>10&-2))|0]<<7}else{if((a[1044415]|0)!=3){aa=l;break}$=P<<1&14|L<<4&112}L=a[i+($|1)|0]|0;if(L<<24>>24==0|J){aa=l;break}P=m+C|0;N=(P|0)<(C|0);M=L&255;L=n;while(1){if(!N){Q=P;do{T=Q+t|0;U=(ab(c[277223]|0,L)|0)+T|0;if((Q|0)>=(f|0)&(p|0)>(d[(c[277219]|0)+U|0]|0)&(Q|0)<(g|0)){do{if((a[1108928]|0)==0){V=b[(c[277225]|0)+(M<<1)>>1]|0;W=V&65535;ac=W&63454;if((a[(c[277215]|0)+U|0]&32)==0){ad=c[277228]|0;ae=(e[(c[277220]|0)+((((ad&-2082)+ac|0)>>>1)+(W&2081&ad)<<1)>>1]|(ad^W)&2081)&65535;break}else{W=b[(c[277213]|0)+(U<<1)>>1]|0;ae=(((W&63454)+ac|0)>>>1)+(W&V&2081)&65535;break}}else{V=e[(c[277225]|0)+(M<<1)>>1]|0;W=(a[(c[277215]|0)+U|0]&32)==0;if(W){ac=c[277228]|0;af=ac;ag=ac&-2082}else{ac=e[(c[277213]|0)+(U<<1)>>1]|0;af=ac;ag=ac&63454}if(W){ah=c[277228]|0}else{ah=e[(c[277213]|0)+(U<<1)>>1]|0}ae=((ah^V)&2081|e[(c[277220]|0)+((V&2081&af)+((ag+(V&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(U<<1)>>1]=ae;R=(ab(c[277223]|0,L)|0)+T|0;a[(c[277219]|0)+R|0]=h}Q=Q-1|0;}while((Q|0)>=(C|0))}Q=L+1|0;if((Q|0)<(x|0)){L=Q}else{aa=l;break}}}else{aa=K}}while(0);K=C+1|0;if((K|0)<(r|0)){A=A+F|0;B=B+G|0;y=aa;C=K}else{break}}}}while(0);D=x+v|0;E=(ab(c[277223]|0,x)|0)+t|0;z=c[277231]|0;if(D>>>0>z>>>0){break}else{n=0;s=x;t=E;v=D;w=w+(x<<4)|0;u=z}}return}function W3(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ac=0,ad=0;i=c[263194]|0;do{if((a[(c[263195]|0)+8496|0]&1)==0){j=1106168}else{if((a[1106089]|0)==0){j=1125528;break}k=d[1044485]|0;c[276541]=7080+(k<<5);l=0;do{m=l<<1&2;n=l&2;o=l&4;p=0;do{b[1125528+(l<<9)+(p<<1)>>1]=d[(p>>>1&28|n)+(7080+(k<<5))|0]<<6|d[(p<<2&28|m)+(7080+(k<<5))|0]<<11|d[(p>>>3&24|o)+(7080+(k<<5))|0];p=p+1|0;}while(p>>>0<256);l=l+1|0;}while(l>>>0<8);a[1106089]=0;j=1125528}}while(0);c[277226]=j;c[277225]=(a[1108928]|0)!=0?1393712:j;j=c[277230]|0;if((a[1044434]|0)==0){q=f;r=g;s=0;t=1;u=j}else{l=d[1044432]|0;k=((j-(d[1044433]|0)|0)>>>0)%(l>>>0)|0;p=g-1+l|0;q=f-((f|0)%(l|0)|0)|0;r=p-((p|0)%(l|0)|0)|0;s=k;t=l;u=j-k|0}k=c[277231]|0;if(u>>>0>k>>>0){return}j=(q|0)<(r|0);l=t&255;p=h+7|0;h=p&255;o=r-1|0;m=t-1|0;n=s;s=t;t=ab(c[277223]|0,u)|0;v=u;w=1097960+(u<<4)|0;u=k;while(1){if((s+v|0)>>>0>u>>>0){x=u+1-v|0}else{x=s}k=e[w+12>>1]<<19>>19;y=e[w+8>>1]<<19;z=e[w+10>>1]<<19;A=v+1|0;B=(e[w+14>>1]<<19>>19)-(z>>19)|0;C=(B&8192|0)!=0?B|-1024:B&1023;B=b[w+2>>1]|0;D=((a[1044414]|0)==0?A:A^255)&255;A=(ab(D,B)|0)&-64;E=A+(y>>11)+((ab(C,B)|0)&-64)|0;B=b[w+6>>1]|0;A=(ab(B,D)|0)&-64;D=A+(z>>11)+((ab(C,B)|0)&-64)|0;B=b[w>>1]|0;if((a[1044413]|0)==0){C=b[w+4>>1]|0;F=B;G=C<<16>>16;H=q;I=C}else{C=b[w+4>>1]|0;F=-B|0;G=-(C<<16>>16)|0;H=o;I=C}C=k-(y>>19)|0;y=(C&8192|0)!=0?C|-1024:C&1023;C=ab(H,B)|0;k=C+((ab(B,y)|0)&-64)|0;B=I<<16>>16;C=ab(B,H)|0;z=((ab(B,y)|0)&-64)+C|0;do{if((a[1044415]|0)==0){if(!j){break}C=(n|0)>=(x|0);y=k;B=z;A=1;J=q;while(1){K=A-1&255;do{if(K<<24>>24==0){L=y+E|0;M=(B+D|0)>>>8;N=a[i+(M<<4&112|L>>>8<<1&14|d[(c[263194]|0)+(M<<5&32512|L>>>10&254)|0]<<7|1)|0]|0;if(N<<24>>24==0|C){O=l;break}L=m+J|0;M=(L|0)<(J|0);P=N&255;N=n;while(1){if(!M){Q=L;do{R=Q+t|0;S=(ab(c[277223]|0,N)|0)+R|0;if((Q|0)>=(f|0)&(p|0)>(d[(c[277219]|0)+S|0]|0)&(Q|0)<(g|0)){T=b[(c[277225]|0)+(P<<1)>>1]|0;if((a[(c[277215]|0)+S|0]&32)==0){U=c[277228]&65535}else{U=b[(c[277213]|0)+(S<<1)>>1]|0}V=T&-2048;W=U&-2048;X=(V&65535)>(W&65535)?V-W&65535:0;W=T&2016;V=U&2016;if((W&65535)>(V&65535)){Y=(W-V&65535)+X&65535}else{Y=X}X=T&31;T=U&31;if((X&65535)>(T&65535)){Z=(X-T&65535)+Y&65535}else{Z=Y}b[(c[277218]|0)+(S<<1)>>1]=Z;S=(ab(c[277223]|0,N)|0)+R|0;a[(c[277219]|0)+S|0]=h}Q=Q-1|0;}while((Q|0)>=(J|0))}Q=N+1|0;if((Q|0)<(x|0)){N=Q}else{O=l;break}}}else{O=K}}while(0);K=J+1|0;if((K|0)<(r|0)){y=y+F|0;B=B+G|0;A=O;J=K}else{break}}}else{if(!j){break}J=(n|0)>=(x|0);A=k;B=z;y=1;C=q;while(1){K=y-1&255;do{if(K<<24>>24==0){N=A+E|0;P=N>>8;L=B+D>>8;if((P|L)>>>0<1024){_=P<<1&14|L<<4&112|d[(c[263194]|0)+((L<<5&-256)+(N>>10&-2))|0]<<7}else{if((a[1044415]|0)!=3){$=l;break}_=P<<1&14|L<<4&112}L=a[i+(_|1)|0]|0;if(L<<24>>24==0|J){$=l;break}P=m+C|0;N=(P|0)<(C|0);M=L&255;L=n;while(1){if(!N){Q=P;do{S=Q+t|0;R=(ab(c[277223]|0,L)|0)+S|0;if((Q|0)>=(f|0)&(p|0)>(d[(c[277219]|0)+R|0]|0)&(Q|0)<(g|0)){T=b[(c[277225]|0)+(M<<1)>>1]|0;if((a[(c[277215]|0)+R|0]&32)==0){aa=c[277228]&65535}else{aa=b[(c[277213]|0)+(R<<1)>>1]|0}X=T&-2048;V=aa&-2048;W=(X&65535)>(V&65535)?X-V&65535:0;V=T&2016;X=aa&2016;if((V&65535)>(X&65535)){ac=(V-X&65535)+W&65535}else{ac=W}W=T&31;T=aa&31;if((W&65535)>(T&65535)){ad=(W-T&65535)+ac&65535}else{ad=ac}b[(c[277218]|0)+(R<<1)>>1]=ad;R=(ab(c[277223]|0,L)|0)+S|0;a[(c[277219]|0)+R|0]=h}Q=Q-1|0;}while((Q|0)>=(C|0))}Q=L+1|0;if((Q|0)<(x|0)){L=Q}else{$=l;break}}}else{$=K}}while(0);K=C+1|0;if((K|0)<(r|0)){A=A+F|0;B=B+G|0;y=$;C=K}else{break}}}}while(0);D=x+v|0;E=(ab(c[277223]|0,x)|0)+t|0;z=c[277231]|0;if(D>>>0>z>>>0){break}else{n=0;s=x;t=E;v=D;w=w+(x<<4)|0;u=z}}return}function W4(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ac=0,ad=0,ae=0;i=c[263194]|0;do{if((a[(c[263195]|0)+8496|0]&1)==0){j=1106168}else{if((a[1106089]|0)==0){j=1125528;break}k=d[1044485]|0;c[276541]=7080+(k<<5);l=0;do{m=l<<1&2;n=l&2;o=l&4;p=0;do{b[1125528+(l<<9)+(p<<1)>>1]=d[(p>>>1&28|n)+(7080+(k<<5))|0]<<6|d[(p<<2&28|m)+(7080+(k<<5))|0]<<11|d[(p>>>3&24|o)+(7080+(k<<5))|0];p=p+1|0;}while(p>>>0<256);l=l+1|0;}while(l>>>0<8);a[1106089]=0;j=1125528}}while(0);c[277226]=j;c[277225]=(a[1108928]|0)!=0?1393712:j;j=c[277230]|0;if((a[1044434]|0)==0){q=f;r=g;s=0;t=1;u=j}else{l=d[1044432]|0;k=((j-(d[1044433]|0)|0)>>>0)%(l>>>0)|0;p=g-1+l|0;q=f-((f|0)%(l|0)|0)|0;r=p-((p|0)%(l|0)|0)|0;s=k;t=l;u=j-k|0}k=c[277231]|0;if(u>>>0>k>>>0){return}j=(q|0)<(r|0);l=t&255;p=h+7|0;h=p&255;o=r-1|0;m=t-1|0;n=s;s=t;t=ab(c[277223]|0,u)|0;v=u;w=1097960+(u<<4)|0;u=k;while(1){if((s+v|0)>>>0>u>>>0){x=u+1-v|0}else{x=s}k=e[w+12>>1]<<19>>19;y=e[w+8>>1]<<19;z=e[w+10>>1]<<19;A=v+1|0;B=(e[w+14>>1]<<19>>19)-(z>>19)|0;C=(B&8192|0)!=0?B|-1024:B&1023;B=b[w+2>>1]|0;D=((a[1044414]|0)==0?A:A^255)&255;A=(ab(D,B)|0)&-64;E=A+(y>>11)+((ab(C,B)|0)&-64)|0;B=b[w+6>>1]|0;A=(ab(B,D)|0)&-64;D=A+(z>>11)+((ab(C,B)|0)&-64)|0;B=b[w>>1]|0;if((a[1044413]|0)==0){C=b[w+4>>1]|0;F=B;G=C<<16>>16;H=q;I=C}else{C=b[w+4>>1]|0;F=-B|0;G=-(C<<16>>16)|0;H=o;I=C}C=k-(y>>19)|0;y=(C&8192|0)!=0?C|-1024:C&1023;C=ab(H,B)|0;k=C+((ab(B,y)|0)&-64)|0;B=I<<16>>16;C=ab(B,H)|0;z=((ab(B,y)|0)&-64)+C|0;do{if((a[1044415]|0)==0){if(!j){break}C=(n|0)>=(x|0);y=k;B=z;A=1;J=q;while(1){K=A-1&255;do{if(K<<24>>24==0){L=y+E|0;M=(B+D|0)>>>8;N=a[i+(M<<4&112|L>>>8<<1&14|d[(c[263194]|0)+(M<<5&32512|L>>>10&254)|0]<<7|1)|0]|0;if(N<<24>>24==0|C){O=l;break}L=m+J|0;M=(L|0)<(J|0);P=N&255;N=n;while(1){if(!M){Q=L;do{R=Q+t|0;S=(ab(c[277223]|0,N)|0)+R|0;if((Q|0)>=(f|0)&(p|0)>(d[(c[277219]|0)+S|0]|0)&(Q|0)<(g|0)){T=b[(c[277225]|0)+(P<<1)>>1]|0;do{if((a[1108928]|0)==0){U=b[(c[277221]|0)+(((T&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{V=c[277228]&65535;W=T&-2048;X=V&-2048;Y=(W&65535)>(X&65535)?W-X&65535:0;X=T&2016;W=V&2016;if((X&65535)>(W&65535)){Z=(X-W&65535)+Y&65535}else{Z=Y}Y=T&31;W=V&31;if((Y&65535)<=(W&65535)){U=Z;break}U=(Y-W&65535)+Z&65535}}while(0);b[(c[277218]|0)+(S<<1)>>1]=U;T=(ab(c[277223]|0,N)|0)+R|0;a[(c[277219]|0)+T|0]=h}Q=Q-1|0;}while((Q|0)>=(J|0))}Q=N+1|0;if((Q|0)<(x|0)){N=Q}else{O=l;break}}}else{O=K}}while(0);K=J+1|0;if((K|0)<(r|0)){y=y+F|0;B=B+G|0;A=O;J=K}else{break}}}else{if(!j){break}J=(n|0)>=(x|0);A=k;B=z;y=1;C=q;while(1){K=y-1&255;do{if(K<<24>>24==0){N=A+E|0;P=N>>8;L=B+D>>8;if((P|L)>>>0<1024){_=P<<1&14|L<<4&112|d[(c[263194]|0)+((L<<5&-256)+(N>>10&-2))|0]<<7}else{if((a[1044415]|0)!=3){$=l;break}_=P<<1&14|L<<4&112}L=a[i+(_|1)|0]|0;if(L<<24>>24==0|J){$=l;break}P=m+C|0;N=(P|0)<(C|0);M=L&255;L=n;while(1){if(!N){Q=P;do{T=Q+t|0;W=(ab(c[277223]|0,L)|0)+T|0;if((Q|0)>=(f|0)&(p|0)>(d[(c[277219]|0)+W|0]|0)&(Q|0)<(g|0)){Y=b[(c[277225]|0)+(M<<1)>>1]|0;do{if((a[1108928]|0)==0){aa=b[(c[277221]|0)+(((Y&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{V=c[277228]&65535;X=Y&-2048;ac=V&-2048;ad=(X&65535)>(ac&65535)?X-ac&65535:0;ac=Y&2016;X=V&2016;if((ac&65535)>(X&65535)){ae=(ac-X&65535)+ad&65535}else{ae=ad}ad=Y&31;X=V&31;if((ad&65535)<=(X&65535)){aa=ae;break}aa=(ad-X&65535)+ae&65535}}while(0);b[(c[277218]|0)+(W<<1)>>1]=aa;Y=(ab(c[277223]|0,L)|0)+T|0;a[(c[277219]|0)+Y|0]=h}Q=Q-1|0;}while((Q|0)>=(C|0))}Q=L+1|0;if((Q|0)<(x|0)){L=Q}else{$=l;break}}}else{$=K}}while(0);K=C+1|0;if((K|0)<(r|0)){A=A+F|0;B=B+G|0;y=$;C=K}else{break}}}}while(0);D=x+v|0;E=(ab(c[277223]|0,x)|0)+t|0;z=c[277231]|0;if(D>>>0>z>>>0){break}else{n=0;s=x;t=E;v=D;w=w+(x<<4)|0;u=z}}return}function W5(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0;i=c[263194]|0;do{if((a[(c[263195]|0)+8496|0]&1)==0){j=1106168}else{if((a[1106089]|0)==0){j=1125528;break}k=d[1044485]|0;c[276541]=7080+(k<<5);l=0;do{m=l<<1&2;n=l&2;o=l&4;p=0;do{b[1125528+(l<<9)+(p<<1)>>1]=d[(p>>>1&28|n)+(7080+(k<<5))|0]<<6|d[(p<<2&28|m)+(7080+(k<<5))|0]<<11|d[(p>>>3&24|o)+(7080+(k<<5))|0];p=p+1|0;}while(p>>>0<256);l=l+1|0;}while(l>>>0<8);a[1106089]=0;j=1125528}}while(0);c[277226]=j;c[277225]=(a[1108928]|0)!=0?1393712:j;j=c[277230]|0;if((a[1044434]|0)==0){q=f;r=g;s=0;t=1;u=j}else{l=d[1044432]|0;k=((j-(d[1044433]|0)|0)>>>0)%(l>>>0)|0;p=g-1+l|0;q=f-((f|0)%(l|0)|0)|0;r=p-((p|0)%(l|0)|0)|0;s=k;t=l;u=j-k|0}k=c[277231]|0;if(u>>>0>k>>>0){return}j=(q|0)<(r|0);l=t&255;p=h+7|0;h=p&255;o=r-1|0;m=t-1|0;n=s;s=t;t=ab(c[277223]|0,u)|0;v=u;w=1097960+(u<<4)|0;u=k;while(1){if((s+v|0)>>>0>u>>>0){x=u+1-v|0}else{x=s}k=e[w+12>>1]<<19>>19;y=e[w+8>>1]<<19;z=e[w+10>>1]<<19;A=v+1|0;B=(e[w+14>>1]<<19>>19)-(z>>19)|0;C=(B&8192|0)!=0?B|-1024:B&1023;B=b[w+2>>1]|0;D=((a[1044414]|0)==0?A:A^255)&255;A=(ab(D,B)|0)&-64;E=A+(y>>11)+((ab(C,B)|0)&-64)|0;B=b[w+6>>1]|0;A=(ab(B,D)|0)&-64;D=A+(z>>11)+((ab(C,B)|0)&-64)|0;B=b[w>>1]|0;if((a[1044413]|0)==0){C=b[w+4>>1]|0;F=B;G=C<<16>>16;H=q;I=C}else{C=b[w+4>>1]|0;F=-B|0;G=-(C<<16>>16)|0;H=o;I=C}C=k-(y>>19)|0;y=(C&8192|0)!=0?C|-1024:C&1023;C=ab(H,B)|0;k=C+((ab(B,y)|0)&-64)|0;B=I<<16>>16;C=ab(B,H)|0;z=((ab(B,y)|0)&-64)+C|0;do{if((a[1044415]|0)==0){if(!j){break}C=(n|0)>=(x|0);y=k;B=z;A=1;J=q;while(1){K=A-1&255;do{if(K<<24>>24==0){L=y+E|0;M=(B+D|0)>>>8;N=a[i+(M<<4&112|L>>>8<<1&14|d[(c[263194]|0)+(M<<5&32512|L>>>10&254)|0]<<7|1)|0]|0;if(N<<24>>24==0|C){O=l;break}L=m+J|0;M=(L|0)<(J|0);P=N&255;N=n;while(1){if(!M){Q=L;do{R=Q+t|0;S=(ab(c[277223]|0,N)|0)+R|0;if((Q|0)>=(f|0)&(p|0)>(d[(c[277219]|0)+S|0]|0)&(Q|0)<(g|0)){do{if((a[1108928]|0)==0){T=b[(c[277225]|0)+(P<<1)>>1]|0;if((a[(c[277215]|0)+S|0]&32)!=0){U=b[(c[277221]|0)+((T&65535|67616)-(b[(c[277213]|0)+(S<<1)>>1]&63454)>>1<<1)>>1]|0;break}V=c[277228]&65535;W=T&-2048;X=V&-2048;Y=(W&65535)>(X&65535)?W-X&65535:0;X=T&2016;W=V&2016;if((X&65535)>(W&65535)){Z=(X-W&65535)+Y&65535}else{Z=Y}Y=T&31;T=V&31;if((Y&65535)<=(T&65535)){U=Z;break}U=(Y-T&65535)+Z&65535}else{T=b[(c[277225]|0)+(P<<1)>>1]|0;if((a[(c[277215]|0)+S|0]&32)==0){_=c[277228]&65535}else{_=b[(c[277213]|0)+(S<<1)>>1]|0}Y=T&-2048;V=_&-2048;W=(Y&65535)>(V&65535)?Y-V&65535:0;V=T&2016;Y=_&2016;if((V&65535)>(Y&65535)){$=(V-Y&65535)+W&65535}else{$=W}W=T&31;T=_&31;if((W&65535)<=(T&65535)){U=$;break}U=(W-T&65535)+$&65535}}while(0);b[(c[277218]|0)+(S<<1)>>1]=U;T=(ab(c[277223]|0,N)|0)+R|0;a[(c[277219]|0)+T|0]=h}Q=Q-1|0;}while((Q|0)>=(J|0))}Q=N+1|0;if((Q|0)<(x|0)){N=Q}else{O=l;break}}}else{O=K}}while(0);K=J+1|0;if((K|0)<(r|0)){y=y+F|0;B=B+G|0;A=O;J=K}else{break}}}else{if(!j){break}J=(n|0)>=(x|0);A=k;B=z;y=1;C=q;while(1){K=y-1&255;do{if(K<<24>>24==0){N=A+E|0;P=N>>8;L=B+D>>8;if((P|L)>>>0<1024){aa=P<<1&14|L<<4&112|d[(c[263194]|0)+((L<<5&-256)+(N>>10&-2))|0]<<7}else{if((a[1044415]|0)!=3){ac=l;break}aa=P<<1&14|L<<4&112}L=a[i+(aa|1)|0]|0;if(L<<24>>24==0|J){ac=l;break}P=m+C|0;N=(P|0)<(C|0);M=L&255;L=n;while(1){if(!N){Q=P;do{T=Q+t|0;W=(ab(c[277223]|0,L)|0)+T|0;if((Q|0)>=(f|0)&(p|0)>(d[(c[277219]|0)+W|0]|0)&(Q|0)<(g|0)){do{if((a[1108928]|0)==0){Y=b[(c[277225]|0)+(M<<1)>>1]|0;if((a[(c[277215]|0)+W|0]&32)!=0){ad=b[(c[277221]|0)+((Y&65535|67616)-(b[(c[277213]|0)+(W<<1)>>1]&63454)>>1<<1)>>1]|0;break}V=c[277228]&65535;X=Y&-2048;ae=V&-2048;af=(X&65535)>(ae&65535)?X-ae&65535:0;ae=Y&2016;X=V&2016;if((ae&65535)>(X&65535)){ag=(ae-X&65535)+af&65535}else{ag=af}af=Y&31;Y=V&31;if((af&65535)<=(Y&65535)){ad=ag;break}ad=(af-Y&65535)+ag&65535}else{Y=b[(c[277225]|0)+(M<<1)>>1]|0;if((a[(c[277215]|0)+W|0]&32)==0){ah=c[277228]&65535}else{ah=b[(c[277213]|0)+(W<<1)>>1]|0}af=Y&-2048;V=ah&-2048;X=(af&65535)>(V&65535)?af-V&65535:0;V=Y&2016;af=ah&2016;if((V&65535)>(af&65535)){ai=(V-af&65535)+X&65535}else{ai=X}X=Y&31;Y=ah&31;if((X&65535)<=(Y&65535)){ad=ai;break}ad=(X-Y&65535)+ai&65535}}while(0);b[(c[277218]|0)+(W<<1)>>1]=ad;R=(ab(c[277223]|0,L)|0)+T|0;a[(c[277219]|0)+R|0]=h}Q=Q-1|0;}while((Q|0)>=(C|0))}Q=L+1|0;if((Q|0)<(x|0)){L=Q}else{ac=l;break}}}else{ac=K}}while(0);K=C+1|0;if((K|0)<(r|0)){A=A+F|0;B=B+G|0;y=ac;C=K}else{break}}}}while(0);D=x+v|0;E=(ab(c[277223]|0,x)|0)+t|0;z=c[277231]|0;if(D>>>0>z>>>0){break}else{n=0;s=x;t=E;v=D;w=w+(x<<4)|0;u=z}}return}function W6(e,f,g,h,i,j){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;k=e&1023;l=c[348606]|0;m=(k<<l)+(c[348604]|0)|0;if((e&256|0)==0){n=m}else{n=(c[348602]|0)+m|0}m=n&65535;n=m>>>(l>>>0);l=(e&16384|0)!=0;o=n<<6;do{if(l){p=(c[348622]|0)+o|0;if((a[(c[348618]|0)+n|0]|0)!=0){q=p;break}r=fi[c[348636]&63](p,m,k)|0;a[(c[348618]|0)+n|0]=r;q=p}else{p=(c[348624]|0)+o|0;if((a[(c[348620]|0)+n|0]|0)!=0){q=p;break}r=fi[c[348638]&63](p,m,k)|0;a[(c[348620]|0)+n|0]=r;q=p}}while(0);if((a[(c[348620]|0)+n|0]|0)==2){return}if((a[1394464]|0)==0){s=1106168+((e>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){n=d[1044485]|0;c[276541]=7080+(n<<5);k=0;do{m=k<<1&2;o=k&2;p=k&4;r=0;do{b[1125528+(k<<9)+(r<<1)>>1]=d[(r>>>1&28|o)+(7080+(n<<5))|0]<<6|d[(r<<2&28|m)+(7080+(n<<5))|0]<<11|d[(r>>>3&24|p)+(7080+(n<<5))|0];r=r+1|0;}while(r>>>0<256);k=k+1|0;}while(k>>>0<8);a[1106089]=0}s=1125528+((e>>>10&7)<<9)|0}c[277226]=s;c[277225]=(a[1108928]|0)!=0?1393712:s;s=l?7-h|0:h;if((e&32768|0)==0){t=s+g|0}else{t=56-g+s|0}s=a[q+t|0]|0;if(!(s<<24>>24!=0&(j|0)>0)){return}t=i-1|0;i=(t|0)>-1;q=s&255;s=j;j=f;while(1){if(i){f=t;do{g=f+j|0;if((d[1108908]|0)>(d[(c[277219]|0)+g|0]|0)){b[(c[277218]|0)+(g<<1)>>1]=b[(c[277225]|0)+(q<<1)>>1]|0;a[(c[277219]|0)+g|0]=a[1108909]|0}f=f-1|0;}while((f|0)>-1)}f=s-1|0;if((f|0)>0){s=f;j=(c[277223]|0)+j|0}else{break}}return}function W7(f,g,h,i,j,k){f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;l=f&1023;m=c[348606]|0;n=(l<<m)+(c[348604]|0)|0;if((f&256|0)==0){o=n}else{o=(c[348602]|0)+n|0}n=o&65535;o=n>>>(m>>>0);m=(f&16384|0)!=0;p=o<<6;do{if(m){q=(c[348622]|0)+p|0;if((a[(c[348618]|0)+o|0]|0)!=0){r=q;break}s=fi[c[348636]&63](q,n,l)|0;a[(c[348618]|0)+o|0]=s;r=q}else{q=(c[348624]|0)+p|0;if((a[(c[348620]|0)+o|0]|0)!=0){r=q;break}s=fi[c[348638]&63](q,n,l)|0;a[(c[348620]|0)+o|0]=s;r=q}}while(0);if((a[(c[348620]|0)+o|0]|0)==2){return}if((a[1394464]|0)==0){t=1106168+((f>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){o=d[1044485]|0;c[276541]=7080+(o<<5);l=0;do{n=l<<1&2;p=l&2;q=l&4;s=0;do{b[1125528+(l<<9)+(s<<1)>>1]=d[(s>>>1&28|p)+(7080+(o<<5))|0]<<6|d[(s<<2&28|n)+(7080+(o<<5))|0]<<11|d[(s>>>3&24|q)+(7080+(o<<5))|0];s=s+1|0;}while(s>>>0<256);l=l+1|0;}while(l>>>0<8);a[1106089]=0}t=1125528+((f>>>10&7)<<9)|0}c[277226]=t;c[277225]=(a[1108928]|0)!=0?1393712:t;t=m?7-i|0:i;if((f&32768|0)==0){u=t+h|0}else{u=56-h+t|0}t=a[r+u|0]|0;if(!(t<<24>>24!=0&(k|0)>0)){return}u=j-1|0;j=(u|0)>-1;r=t&255;t=k;k=g;while(1){if(j){g=u;do{h=g+k|0;if((d[1108908]|0)>(d[(c[277219]|0)+h|0]|0)){f=e[(c[277225]|0)+(r<<1)>>1]|0;i=(a[(c[277215]|0)+h|0]&32)==0;if(i){m=c[277228]|0;v=m;w=m&-2082}else{m=e[(c[277213]|0)+(h<<1)>>1]|0;v=m;w=m&63454}if(i){x=c[277228]|0}else{x=e[(c[277213]|0)+(h<<1)>>1]|0}b[(c[277218]|0)+(h<<1)>>1]=((x^f)&2081|e[(c[277220]|0)+((f&2081&v)+((w+(f&63454)|0)>>>1)<<1)>>1])&65535;a[(c[277219]|0)+h|0]=a[1108909]|0}g=g-1|0;}while((g|0)>-1)}g=t-1|0;if((g|0)>0){t=g;k=(c[277223]|0)+k|0}else{break}}return}function W8(f,g,h,i,j,k){f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;l=f&1023;m=c[348606]|0;n=(l<<m)+(c[348604]|0)|0;if((f&256|0)==0){o=n}else{o=(c[348602]|0)+n|0}n=o&65535;o=n>>>(m>>>0);m=(f&16384|0)!=0;p=o<<6;do{if(m){q=(c[348622]|0)+p|0;if((a[(c[348618]|0)+o|0]|0)!=0){r=q;break}s=fi[c[348636]&63](q,n,l)|0;a[(c[348618]|0)+o|0]=s;r=q}else{q=(c[348624]|0)+p|0;if((a[(c[348620]|0)+o|0]|0)!=0){r=q;break}s=fi[c[348638]&63](q,n,l)|0;a[(c[348620]|0)+o|0]=s;r=q}}while(0);if((a[(c[348620]|0)+o|0]|0)==2){return}if((a[1394464]|0)==0){t=1106168+((f>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){o=d[1044485]|0;c[276541]=7080+(o<<5);l=0;do{n=l<<1&2;p=l&2;q=l&4;s=0;do{b[1125528+(l<<9)+(s<<1)>>1]=d[(s>>>1&28|p)+(7080+(o<<5))|0]<<6|d[(s<<2&28|n)+(7080+(o<<5))|0]<<11|d[(s>>>3&24|q)+(7080+(o<<5))|0];s=s+1|0;}while(s>>>0<256);l=l+1|0;}while(l>>>0<8);a[1106089]=0}t=1125528+((f>>>10&7)<<9)|0}c[277226]=t;c[277225]=(a[1108928]|0)!=0?1393712:t;t=m?7-i|0:i;if((f&32768|0)==0){u=t+h|0}else{u=56-h+t|0}t=a[r+u|0]|0;if(!(t<<24>>24!=0&(k|0)>0)){return}u=j-1|0;j=(u|0)>-1;r=t&255;t=k;k=g;while(1){if(j){g=u;do{h=g+k|0;if((d[1108908]|0)>(d[(c[277219]|0)+h|0]|0)){f=e[(c[277225]|0)+(r<<1)>>1]|0;i=c[277228]|0;m=(((f&63454)+(i&-2082)|0)>>>1)+(i&2081&f)|0;if((a[1108928]|0)==0){v=m&65535}else{v=(e[(c[277220]|0)+(m<<1)>>1]|(f^i)&2081)&65535}b[(c[277218]|0)+(h<<1)>>1]=v;a[(c[277219]|0)+h|0]=a[1108909]|0}g=g-1|0;}while((g|0)>-1)}g=t-1|0;if((g|0)>0){t=g;k=(c[277223]|0)+k|0}else{break}}return}function W9(f,g,h,i,j,k){f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;l=f&1023;m=c[348606]|0;n=(l<<m)+(c[348604]|0)|0;if((f&256|0)==0){o=n}else{o=(c[348602]|0)+n|0}n=o&65535;o=n>>>(m>>>0);m=(f&16384|0)!=0;p=o<<6;do{if(m){q=(c[348622]|0)+p|0;if((a[(c[348618]|0)+o|0]|0)!=0){r=q;break}s=fi[c[348636]&63](q,n,l)|0;a[(c[348618]|0)+o|0]=s;r=q}else{q=(c[348624]|0)+p|0;if((a[(c[348620]|0)+o|0]|0)!=0){r=q;break}s=fi[c[348638]&63](q,n,l)|0;a[(c[348620]|0)+o|0]=s;r=q}}while(0);if((a[(c[348620]|0)+o|0]|0)==2){return}if((a[1394464]|0)==0){t=1106168+((f>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){o=d[1044485]|0;c[276541]=7080+(o<<5);l=0;do{n=l<<1&2;p=l&2;q=l&4;s=0;do{b[1125528+(l<<9)+(s<<1)>>1]=d[(s>>>1&28|p)+(7080+(o<<5))|0]<<6|d[(s<<2&28|n)+(7080+(o<<5))|0]<<11|d[(s>>>3&24|q)+(7080+(o<<5))|0];s=s+1|0;}while(s>>>0<256);l=l+1|0;}while(l>>>0<8);a[1106089]=0}t=1125528+((f>>>10&7)<<9)|0}c[277226]=t;c[277225]=(a[1108928]|0)!=0?1393712:t;t=m?7-i|0:i;if((f&32768|0)==0){u=t+h|0}else{u=56-h+t|0}t=a[r+u|0]|0;if(!(t<<24>>24!=0&(k|0)>0)){return}u=j-1|0;j=(u|0)>-1;r=t&255;t=k;k=g;while(1){if(j){g=u;do{h=g+k|0;if((d[1108908]|0)>(d[(c[277219]|0)+h|0]|0)){do{if((a[1108928]|0)==0){f=b[(c[277225]|0)+(r<<1)>>1]|0;i=f&65535;m=i&63454;if((a[(c[277215]|0)+h|0]&32)==0){l=c[277228]|0;v=(e[(c[277220]|0)+((((l&-2082)+m|0)>>>1)+(i&2081&l)<<1)>>1]|(l^i)&2081)&65535;break}else{i=b[(c[277213]|0)+(h<<1)>>1]|0;v=(((i&63454)+m|0)>>>1)+(i&f&2081)&65535;break}}else{f=e[(c[277225]|0)+(r<<1)>>1]|0;i=(a[(c[277215]|0)+h|0]&32)==0;if(i){m=c[277228]|0;w=m;x=m&-2082}else{m=e[(c[277213]|0)+(h<<1)>>1]|0;w=m;x=m&63454}if(i){y=c[277228]|0}else{y=e[(c[277213]|0)+(h<<1)>>1]|0}v=((y^f)&2081|e[(c[277220]|0)+((f&2081&w)+((x+(f&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(h<<1)>>1]=v;a[(c[277219]|0)+h|0]=a[1108909]|0}g=g-1|0;}while((g|0)>-1)}g=t-1|0;if((g|0)>0){t=g;k=(c[277223]|0)+k|0}else{break}}return}function Xa(d,e,f){d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0;c[277226]=1106168;c[277225]=(a[1108928]|0)!=0?1393712:1106168;g=c[277230]|0;h=c[277231]|0;if(g>>>0>h>>>0){return}i=e>>>0<f>>>0;j=d;d=g;g=h;while(1){if(i){h=e;do{k=h+j|0;if((a[(c[277219]|0)+k|0]|0)==0){b[(c[277218]|0)+(k<<1)>>1]=b[c[277225]>>1]|0;a[(c[277219]|0)+k|0]=1}h=h+1|0;}while(h>>>0<f>>>0);l=c[277231]|0}else{l=g}h=d+1|0;if(h>>>0>l>>>0){break}else{j=(c[277223]|0)+j|0;d=h;g=l}}return}function Xb(e,f,g,h,i,j){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;k=e&1023;l=c[348606]|0;m=(k<<l)+(c[348604]|0)|0;if((e&256|0)==0){n=m}else{n=(c[348602]|0)+m|0}m=n&65535;n=m>>>(l>>>0);l=(e&16384|0)!=0;o=n<<6;do{if(l){p=(c[348622]|0)+o|0;if((a[(c[348618]|0)+n|0]|0)!=0){q=p;break}r=fi[c[348636]&63](p,m,k)|0;a[(c[348618]|0)+n|0]=r;q=p}else{p=(c[348624]|0)+o|0;if((a[(c[348620]|0)+n|0]|0)!=0){q=p;break}r=fi[c[348638]&63](p,m,k)|0;a[(c[348620]|0)+n|0]=r;q=p}}while(0);if((a[(c[348620]|0)+n|0]|0)==2){return}if((a[1394464]|0)==0){s=1106168+((e>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){n=d[1044485]|0;c[276541]=7080+(n<<5);k=0;do{m=k<<1&2;o=k&2;p=k&4;r=0;do{b[1125528+(k<<9)+(r<<1)>>1]=d[(r>>>1&28|o)+(7080+(n<<5))|0]<<6|d[(r<<2&28|m)+(7080+(n<<5))|0]<<11|d[(r>>>3&24|p)+(7080+(n<<5))|0];r=r+1|0;}while(r>>>0<256);k=k+1|0;}while(k>>>0<8);a[1106089]=0}s=1125528+((e>>>10&7)<<9)|0}c[277226]=s;c[277225]=(a[1108928]|0)!=0?1393712:s;s=l?7-h|0:h;if((e&32768|0)==0){t=s+g|0}else{t=56-g+s|0}s=a[q+t|0]|0;if(!(s<<24>>24!=0&(j|0)>0)){return}t=i-1|0;i=(t|0)>-1;q=s&255;s=j;j=f;while(1){if(i){f=t;do{g=f+j|0;if((d[1108908]|0)>(d[(c[277219]|0)+g|0]|0)){e=b[(c[277225]|0)+(q<<1)>>1]|0;if((a[(c[277215]|0)+g|0]&32)==0){u=c[277228]&65535}else{u=b[(c[277213]|0)+(g<<1)>>1]|0}h=e&-2048;l=u&-2048;k=(h&65535)>(l&65535)?h-l&65535:0;l=e&2016;h=u&2016;if((l&65535)>(h&65535)){v=(l-h&65535)+k&65535}else{v=k}k=e&31;e=u&31;if((k&65535)>(e&65535)){w=(k-e&65535)+v&65535}else{w=v}b[(c[277218]|0)+(g<<1)>>1]=w;a[(c[277219]|0)+g|0]=a[1108909]|0}f=f-1|0;}while((f|0)>-1)}f=s-1|0;if((f|0)>0){s=f;j=(c[277223]|0)+j|0}else{break}}return}function Xc(e,f,g,h,i,j){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;k=e&1023;l=c[348606]|0;m=(k<<l)+(c[348604]|0)|0;if((e&256|0)==0){n=m}else{n=(c[348602]|0)+m|0}m=n&65535;n=m>>>(l>>>0);l=(e&16384|0)!=0;o=n<<6;do{if(l){p=(c[348622]|0)+o|0;if((a[(c[348618]|0)+n|0]|0)!=0){q=p;break}r=fi[c[348636]&63](p,m,k)|0;a[(c[348618]|0)+n|0]=r;q=p}else{p=(c[348624]|0)+o|0;if((a[(c[348620]|0)+n|0]|0)!=0){q=p;break}r=fi[c[348638]&63](p,m,k)|0;a[(c[348620]|0)+n|0]=r;q=p}}while(0);if((a[(c[348620]|0)+n|0]|0)==2){return}if((a[1394464]|0)==0){s=1106168+((e>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){n=d[1044485]|0;c[276541]=7080+(n<<5);k=0;do{m=k<<1&2;o=k&2;p=k&4;r=0;do{b[1125528+(k<<9)+(r<<1)>>1]=d[(r>>>1&28|o)+(7080+(n<<5))|0]<<6|d[(r<<2&28|m)+(7080+(n<<5))|0]<<11|d[(r>>>3&24|p)+(7080+(n<<5))|0];r=r+1|0;}while(r>>>0<256);k=k+1|0;}while(k>>>0<8);a[1106089]=0}s=1125528+((e>>>10&7)<<9)|0}c[277226]=s;c[277225]=(a[1108928]|0)!=0?1393712:s;s=l?7-h|0:h;if((e&32768|0)==0){t=s+g|0}else{t=56-g+s|0}s=a[q+t|0]|0;if(!(s<<24>>24!=0&(j|0)>0)){return}t=i-1|0;i=(t|0)>-1;q=s&255;s=j;j=f;while(1){if(i){f=t;do{g=f+j|0;if((d[1108908]|0)>(d[(c[277219]|0)+g|0]|0)){e=b[(c[277225]|0)+(q<<1)>>1]|0;do{if((a[1108928]|0)==0){u=b[(c[277221]|0)+(((e&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{h=c[277228]&65535;l=e&-2048;k=h&-2048;n=(l&65535)>(k&65535)?l-k&65535:0;k=e&2016;l=h&2016;if((k&65535)>(l&65535)){v=(k-l&65535)+n&65535}else{v=n}n=e&31;l=h&31;if((n&65535)<=(l&65535)){u=v;break}u=(n-l&65535)+v&65535}}while(0);b[(c[277218]|0)+(g<<1)>>1]=u;a[(c[277219]|0)+g|0]=a[1108909]|0}f=f-1|0;}while((f|0)>-1)}f=s-1|0;if((f|0)>0){s=f;j=(c[277223]|0)+j|0}else{break}}return}function Xd(e,f,g,h,i,j){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;k=e&1023;l=c[348606]|0;m=(k<<l)+(c[348604]|0)|0;if((e&256|0)==0){n=m}else{n=(c[348602]|0)+m|0}m=n&65535;n=m>>>(l>>>0);l=(e&16384|0)!=0;o=n<<6;do{if(l){p=(c[348622]|0)+o|0;if((a[(c[348618]|0)+n|0]|0)!=0){q=p;break}r=fi[c[348636]&63](p,m,k)|0;a[(c[348618]|0)+n|0]=r;q=p}else{p=(c[348624]|0)+o|0;if((a[(c[348620]|0)+n|0]|0)!=0){q=p;break}r=fi[c[348638]&63](p,m,k)|0;a[(c[348620]|0)+n|0]=r;q=p}}while(0);if((a[(c[348620]|0)+n|0]|0)==2){return}if((a[1394464]|0)==0){s=1106168+((e>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){n=d[1044485]|0;c[276541]=7080+(n<<5);k=0;do{m=k<<1&2;o=k&2;p=k&4;r=0;do{b[1125528+(k<<9)+(r<<1)>>1]=d[(r>>>1&28|o)+(7080+(n<<5))|0]<<6|d[(r<<2&28|m)+(7080+(n<<5))|0]<<11|d[(r>>>3&24|p)+(7080+(n<<5))|0];r=r+1|0;}while(r>>>0<256);k=k+1|0;}while(k>>>0<8);a[1106089]=0}s=1125528+((e>>>10&7)<<9)|0}c[277226]=s;c[277225]=(a[1108928]|0)!=0?1393712:s;s=l?7-h|0:h;if((e&32768|0)==0){t=s+g|0}else{t=56-g+s|0}s=a[q+t|0]|0;if(!(s<<24>>24!=0&(j|0)>0)){return}t=i-1|0;i=(t|0)>-1;q=s&255;s=j;j=f;while(1){if(i){f=t;do{g=f+j|0;if((d[1108908]|0)>(d[(c[277219]|0)+g|0]|0)){do{if((a[1108928]|0)==0){e=b[(c[277225]|0)+(q<<1)>>1]|0;if((a[(c[277215]|0)+g|0]&32)!=0){u=b[(c[277221]|0)+((e&65535|67616)-(b[(c[277213]|0)+(g<<1)>>1]&63454)>>1<<1)>>1]|0;break}h=c[277228]&65535;l=e&-2048;k=h&-2048;n=(l&65535)>(k&65535)?l-k&65535:0;k=e&2016;l=h&2016;if((k&65535)>(l&65535)){v=(k-l&65535)+n&65535}else{v=n}n=e&31;e=h&31;if((n&65535)<=(e&65535)){u=v;break}u=(n-e&65535)+v&65535}else{e=b[(c[277225]|0)+(q<<1)>>1]|0;if((a[(c[277215]|0)+g|0]&32)==0){w=c[277228]&65535}else{w=b[(c[277213]|0)+(g<<1)>>1]|0}n=e&-2048;h=w&-2048;l=(n&65535)>(h&65535)?n-h&65535:0;h=e&2016;n=w&2016;if((h&65535)>(n&65535)){x=(h-n&65535)+l&65535}else{x=l}l=e&31;e=w&31;if((l&65535)<=(e&65535)){u=x;break}u=(l-e&65535)+x&65535}}while(0);b[(c[277218]|0)+(g<<1)>>1]=u;a[(c[277219]|0)+g|0]=a[1108909]|0}f=f-1|0;}while((f|0)>-1)}f=s-1|0;if((f|0)>0){s=f;j=(c[277223]|0)+j|0}else{break}}return}function Xe(d,f,g){d=d|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;c[277226]=1106168;c[277225]=(a[1108928]|0)!=0?1393712:1106168;h=c[277230]|0;i=c[277231]|0;if(h>>>0>i>>>0){return}j=f>>>0<g>>>0;k=d;d=h;h=i;while(1){if(j){i=f;do{l=i+k|0;if((a[(c[277219]|0)+l|0]|0)==0){m=e[c[277225]>>1]|0;n=(a[(c[277215]|0)+l|0]&32)==0;if(n){o=c[277228]|0;p=o;q=o&-2082}else{o=e[(c[277213]|0)+(l<<1)>>1]|0;p=o;q=o&63454}if(n){r=c[277228]|0}else{r=e[(c[277213]|0)+(l<<1)>>1]|0}b[(c[277218]|0)+(l<<1)>>1]=((r^m)&2081|e[(c[277220]|0)+((m&2081&p)+((q+(m&63454)|0)>>>1)<<1)>>1])&65535;a[(c[277219]|0)+l|0]=1}i=i+1|0;}while(i>>>0<g>>>0);s=c[277231]|0}else{s=h}i=d+1|0;if(i>>>0>s>>>0){break}else{k=(c[277223]|0)+k|0;d=i;h=s}}return}function Xf(d,f,g){d=d|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0;c[277226]=1106168;c[277225]=(a[1108928]|0)!=0?1393712:1106168;h=c[277230]|0;i=c[277231]|0;if(h>>>0>i>>>0){return}j=f>>>0<g>>>0;k=d;d=h;h=i;while(1){if(j){i=f;do{l=i+k|0;if((a[(c[277219]|0)+l|0]|0)==0){m=e[c[277225]>>1]|0;n=c[277228]|0;o=(((m&63454)+(n&-2082)|0)>>>1)+(n&2081&m)|0;if((a[1108928]|0)==0){p=o&65535}else{p=(e[(c[277220]|0)+(o<<1)>>1]|(m^n)&2081)&65535}b[(c[277218]|0)+(l<<1)>>1]=p;a[(c[277219]|0)+l|0]=1}i=i+1|0;}while(i>>>0<g>>>0);q=c[277231]|0}else{q=h}i=d+1|0;if(i>>>0>q>>>0){break}else{k=(c[277223]|0)+k|0;d=i;h=q}}return}function Xg(d,f,g){d=d|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;c[277226]=1106168;c[277225]=(a[1108928]|0)!=0?1393712:1106168;h=c[277230]|0;i=c[277231]|0;if(h>>>0>i>>>0){return}j=f>>>0<g>>>0;k=d;d=h;h=i;while(1){if(j){i=f;do{l=i+k|0;if((a[(c[277219]|0)+l|0]|0)==0){do{if((a[1108928]|0)==0){m=b[c[277225]>>1]|0;n=m&65535;o=n&63454;if((a[(c[277215]|0)+l|0]&32)==0){p=c[277228]|0;q=(e[(c[277220]|0)+((((p&-2082)+o|0)>>>1)+(n&2081&p)<<1)>>1]|(p^n)&2081)&65535;break}else{n=b[(c[277213]|0)+(l<<1)>>1]|0;q=(((n&63454)+o|0)>>>1)+(n&m&2081)&65535;break}}else{m=e[c[277225]>>1]|0;n=(a[(c[277215]|0)+l|0]&32)==0;if(n){o=c[277228]|0;r=o;s=o&-2082}else{o=e[(c[277213]|0)+(l<<1)>>1]|0;r=o;s=o&63454}if(n){t=c[277228]|0}else{t=e[(c[277213]|0)+(l<<1)>>1]|0}q=((t^m)&2081|e[(c[277220]|0)+((m&2081&r)+((s+(m&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(l<<1)>>1]=q;a[(c[277219]|0)+l|0]=1}i=i+1|0;}while(i>>>0<g>>>0);u=c[277231]|0}else{u=h}i=d+1|0;if(i>>>0>u>>>0){break}else{k=(c[277223]|0)+k|0;d=i;h=u}}return}function Xh(d,e,f){d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;c[277226]=1106168;c[277225]=(a[1108928]|0)!=0?1393712:1106168;g=c[277230]|0;h=c[277231]|0;if(g>>>0>h>>>0){return}i=e>>>0<f>>>0;j=d;d=g;g=h;while(1){if(i){h=e;do{k=h+j|0;if((a[(c[277219]|0)+k|0]|0)==0){l=b[c[277225]>>1]|0;if((a[(c[277215]|0)+k|0]&32)==0){m=c[277228]&65535}else{m=b[(c[277213]|0)+(k<<1)>>1]|0}n=l&-2048;o=m&-2048;p=(n&65535)>(o&65535)?n-o&65535:0;o=l&2016;n=m&2016;if((o&65535)>(n&65535)){q=(o-n&65535)+p&65535}else{q=p}p=l&31;l=m&31;if((p&65535)>(l&65535)){r=(p-l&65535)+q&65535}else{r=q}b[(c[277218]|0)+(k<<1)>>1]=r;a[(c[277219]|0)+k|0]=1}h=h+1|0;}while(h>>>0<f>>>0);s=c[277231]|0}else{s=g}h=d+1|0;if(h>>>0>s>>>0){break}else{j=(c[277223]|0)+j|0;d=h;g=s}}return}function Xi(d,e,f){d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0;c[277226]=1106168;c[277225]=(a[1108928]|0)!=0?1393712:1106168;g=c[277230]|0;h=c[277231]|0;if(g>>>0>h>>>0){return}i=e>>>0<f>>>0;j=d;d=g;g=h;while(1){if(i){h=e;do{k=h+j|0;if((a[(c[277219]|0)+k|0]|0)==0){l=b[c[277225]>>1]|0;do{if((a[1108928]|0)==0){m=b[(c[277221]|0)+(((l&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{n=c[277228]&65535;o=l&-2048;p=n&-2048;q=(o&65535)>(p&65535)?o-p&65535:0;p=l&2016;o=n&2016;if((p&65535)>(o&65535)){r=(p-o&65535)+q&65535}else{r=q}q=l&31;o=n&31;if((q&65535)<=(o&65535)){m=r;break}m=(q-o&65535)+r&65535}}while(0);b[(c[277218]|0)+(k<<1)>>1]=m;a[(c[277219]|0)+k|0]=1}h=h+1|0;}while(h>>>0<f>>>0);s=c[277231]|0}else{s=g}h=d+1|0;if(h>>>0>s>>>0){break}else{j=(c[277223]|0)+j|0;d=h;g=s}}return}function Xj(d,e,f){d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;c[277226]=1106168;c[277225]=(a[1108928]|0)!=0?1393712:1106168;g=c[277230]|0;h=c[277231]|0;if(g>>>0>h>>>0){return}i=e>>>0<f>>>0;j=d;d=g;g=h;while(1){if(i){h=e;do{k=h+j|0;if((a[(c[277219]|0)+k|0]|0)==0){do{if((a[1108928]|0)==0){l=b[c[277225]>>1]|0;if((a[(c[277215]|0)+k|0]&32)!=0){m=b[(c[277221]|0)+((l&65535|67616)-(b[(c[277213]|0)+(k<<1)>>1]&63454)>>1<<1)>>1]|0;break}n=c[277228]&65535;o=l&-2048;p=n&-2048;q=(o&65535)>(p&65535)?o-p&65535:0;p=l&2016;o=n&2016;if((p&65535)>(o&65535)){r=(p-o&65535)+q&65535}else{r=q}q=l&31;l=n&31;if((q&65535)<=(l&65535)){m=r;break}m=(q-l&65535)+r&65535}else{l=b[c[277225]>>1]|0;if((a[(c[277215]|0)+k|0]&32)==0){s=c[277228]&65535}else{s=b[(c[277213]|0)+(k<<1)>>1]|0}q=l&-2048;n=s&-2048;o=(q&65535)>(n&65535)?q-n&65535:0;n=l&2016;q=s&2016;if((n&65535)>(q&65535)){t=(n-q&65535)+o&65535}else{t=o}o=l&31;l=s&31;if((o&65535)<=(l&65535)){m=t;break}m=(o-l&65535)+t&65535}}while(0);b[(c[277218]|0)+(k<<1)>>1]=m;a[(c[277219]|0)+k|0]=1}h=h+1|0;}while(h>>>0<f>>>0);u=c[277231]|0}else{u=g}h=d+1|0;if(h>>>0>u>>>0){break}else{j=(c[277223]|0)+j|0;d=h;g=u}}return}function Xk(e,f,g,h,i,j){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;k=e&1023;l=c[348606]|0;m=(k<<l)+(c[348604]|0)|0;if((e&256|0)==0){n=m}else{n=(c[348602]|0)+m|0}m=n&65535;n=m>>>(l>>>0);l=(e&16384|0)!=0;o=n<<6;do{if(l){p=(c[348622]|0)+o|0;if((a[(c[348618]|0)+n|0]|0)!=0){q=p;break}r=fi[c[348636]&63](p,m,k)|0;a[(c[348618]|0)+n|0]=r;q=p}else{p=(c[348624]|0)+o|0;if((a[(c[348620]|0)+n|0]|0)!=0){q=p;break}r=fi[c[348638]&63](p,m,k)|0;a[(c[348620]|0)+n|0]=r;q=p}}while(0);if((a[(c[348620]|0)+n|0]|0)==2){return}if((a[1394464]|0)==0){s=1106168+((e>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){n=d[1044485]|0;c[276541]=7080+(n<<5);k=0;do{m=k<<1&2;o=k&2;p=k&4;r=0;do{b[1125528+(k<<9)+(r<<1)>>1]=d[(r>>>1&28|o)+(7080+(n<<5))|0]<<6|d[(r<<2&28|m)+(7080+(n<<5))|0]<<11|d[(r>>>3&24|p)+(7080+(n<<5))|0];r=r+1|0;}while(r>>>0<256);k=k+1|0;}while(k>>>0<8);a[1106089]=0}s=1125528+((e>>>10&7)<<9)|0}c[277226]=s;c[277225]=(a[1108928]|0)!=0?1393712:s;if((e&49152|0)==0){if((j|0)<=0){return}s=h&255;k=s-1&255;n=k<<24>>24==0;r=q+i|0;p=j;m=f;while(1){switch(g|0){case 1:{t=s;u=13311;break};case 7:{u=13335;break};case 5:{v=s;u=13327;break};case 4:{w=s;u=13323;break};case 3:{x=s;u=13319;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+m|0]|0)){o=a[r]|0;if(o<<24>>24==0){break}b[(c[277218]|0)+(m<<1)>>1]=b[(c[277225]|0)+((o&255)<<1)>>1]|0;a[(c[277219]|0)+m|0]=a[1108909]|0}}while(0);if(!n){t=k;u=13311}break};case 2:{y=s;u=13315;break};case 6:{z=s;u=13331;break};default:{}}if((u|0)==13311){u=0;o=m+1|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){A=a[r+1|0]|0;if(A<<24>>24==0){break}b[(c[277218]|0)+(o<<1)>>1]=b[(c[277225]|0)+((A&255)<<1)>>1]|0;a[(c[277219]|0)+o|0]=a[1108909]|0}}while(0);o=t-1&255;if(o<<24>>24!=0){y=o;u=13315}}if((u|0)==13315){u=0;o=m+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){A=a[r+2|0]|0;if(A<<24>>24==0){break}b[(c[277218]|0)+(o<<1)>>1]=b[(c[277225]|0)+((A&255)<<1)>>1]|0;a[(c[277219]|0)+o|0]=a[1108909]|0}}while(0);o=y-1&255;if(o<<24>>24!=0){x=o;u=13319}}if((u|0)==13319){u=0;o=m+3|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){A=a[r+3|0]|0;if(A<<24>>24==0){break}b[(c[277218]|0)+(o<<1)>>1]=b[(c[277225]|0)+((A&255)<<1)>>1]|0;a[(c[277219]|0)+o|0]=a[1108909]|0}}while(0);o=x-1&255;if(o<<24>>24!=0){w=o;u=13323}}if((u|0)==13323){u=0;o=m+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){A=a[r+4|0]|0;if(A<<24>>24==0){break}b[(c[277218]|0)+(o<<1)>>1]=b[(c[277225]|0)+((A&255)<<1)>>1]|0;a[(c[277219]|0)+o|0]=a[1108909]|0}}while(0);o=w-1&255;if(o<<24>>24!=0){v=o;u=13327}}if((u|0)==13327){u=0;o=m+5|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){A=a[r+5|0]|0;if(A<<24>>24==0){break}b[(c[277218]|0)+(o<<1)>>1]=b[(c[277225]|0)+((A&255)<<1)>>1]|0;a[(c[277219]|0)+o|0]=a[1108909]|0}}while(0);o=v-1&255;if(o<<24>>24!=0){z=o;u=13331}}if((u|0)==13331){u=0;o=m+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+o|0]|0)){A=a[r+6|0]|0;if(A<<24>>24==0){break}b[(c[277218]|0)+(o<<1)>>1]=b[(c[277225]|0)+((A&255)<<1)>>1]|0;a[(c[277219]|0)+o|0]=a[1108909]|0}}while(0);if(z<<24>>24!=1){u=13335}}do{if((u|0)==13335){u=0;o=m+7|0;if((d[1108908]|0)<=(d[(c[277219]|0)+o|0]|0)){break}A=a[r+7|0]|0;if(A<<24>>24==0){break}b[(c[277218]|0)+(o<<1)>>1]=b[(c[277225]|0)+((A&255)<<1)>>1]|0;a[(c[277219]|0)+o|0]=a[1108909]|0}}while(0);o=p-1|0;if((o|0)>0){r=r+8|0;p=o;m=(c[277223]|0)+m|0}else{break}}return}if((e&32768|0)==0){if((j|0)<=0){return}e=h&255;m=e-1&255;p=m<<24>>24==0;r=q+i|0;z=j;v=f;while(1){switch(g|0){case 3:{B=e;u=13355;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+v|0]|0)){w=a[r+7|0]|0;if(w<<24>>24==0){break}b[(c[277218]|0)+(v<<1)>>1]=b[(c[277225]|0)+((w&255)<<1)>>1]|0;a[(c[277219]|0)+v|0]=a[1108909]|0}}while(0);if(!p){C=m;u=13347}break};case 4:{D=e;u=13359;break};case 7:{u=13371;break};case 6:{E=e;u=13367;break};case 2:{F=e;u=13351;break};case 5:{G=e;u=13363;break};case 1:{C=e;u=13347;break};default:{}}if((u|0)==13347){u=0;w=v+1|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+w|0]|0)){x=a[r+6|0]|0;if(x<<24>>24==0){break}b[(c[277218]|0)+(w<<1)>>1]=b[(c[277225]|0)+((x&255)<<1)>>1]|0;a[(c[277219]|0)+w|0]=a[1108909]|0}}while(0);w=C-1&255;if(w<<24>>24!=0){F=w;u=13351}}if((u|0)==13351){u=0;w=v+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+w|0]|0)){x=a[r+5|0]|0;if(x<<24>>24==0){break}b[(c[277218]|0)+(w<<1)>>1]=b[(c[277225]|0)+((x&255)<<1)>>1]|0;a[(c[277219]|0)+w|0]=a[1108909]|0}}while(0);w=F-1&255;if(w<<24>>24!=0){B=w;u=13355}}if((u|0)==13355){u=0;w=v+3|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+w|0]|0)){x=a[r+4|0]|0;if(x<<24>>24==0){break}b[(c[277218]|0)+(w<<1)>>1]=b[(c[277225]|0)+((x&255)<<1)>>1]|0;a[(c[277219]|0)+w|0]=a[1108909]|0}}while(0);w=B-1&255;if(w<<24>>24!=0){D=w;u=13359}}if((u|0)==13359){u=0;w=v+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+w|0]|0)){x=a[r+3|0]|0;if(x<<24>>24==0){break}b[(c[277218]|0)+(w<<1)>>1]=b[(c[277225]|0)+((x&255)<<1)>>1]|0;a[(c[277219]|0)+w|0]=a[1108909]|0}}while(0);w=D-1&255;if(w<<24>>24!=0){G=w;u=13363}}if((u|0)==13363){u=0;w=v+5|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+w|0]|0)){x=a[r+2|0]|0;if(x<<24>>24==0){break}b[(c[277218]|0)+(w<<1)>>1]=b[(c[277225]|0)+((x&255)<<1)>>1]|0;a[(c[277219]|0)+w|0]=a[1108909]|0}}while(0);w=G-1&255;if(w<<24>>24!=0){E=w;u=13367}}if((u|0)==13367){u=0;w=v+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+w|0]|0)){x=a[r+1|0]|0;if(x<<24>>24==0){break}b[(c[277218]|0)+(w<<1)>>1]=b[(c[277225]|0)+((x&255)<<1)>>1]|0;a[(c[277219]|0)+w|0]=a[1108909]|0}}while(0);if(E<<24>>24!=1){u=13371}}do{if((u|0)==13371){u=0;w=v+7|0;if((d[1108908]|0)<=(d[(c[277219]|0)+w|0]|0)){break}x=a[r]|0;if(x<<24>>24==0){break}b[(c[277218]|0)+(w<<1)>>1]=b[(c[277225]|0)+((x&255)<<1)>>1]|0;a[(c[277219]|0)+w|0]=a[1108909]|0}}while(0);w=z-1|0;if((w|0)>0){r=r+8|0;z=w;v=(c[277223]|0)+v|0}else{break}}return}v=q+(56-i)|0;i=(j|0)>0;if(l){if(!i){return}l=h&255;q=l-1&255;z=q<<24>>24==0;r=v;E=j;G=f;while(1){switch(g|0){case 3:{H=l;u=13426;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+G|0]|0)){D=a[r+7|0]|0;if(D<<24>>24==0){break}b[(c[277218]|0)+(G<<1)>>1]=b[(c[277225]|0)+((D&255)<<1)>>1]|0;a[(c[277219]|0)+G|0]=a[1108909]|0}}while(0);if(!z){I=q;u=13418}break};case 1:{I=l;u=13418;break};case 4:{J=l;u=13430;break};case 6:{K=l;u=13438;break};case 7:{u=13442;break};case 2:{L=l;u=13422;break};case 5:{M=l;u=13434;break};default:{}}if((u|0)==13418){u=0;D=G+1|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+D|0]|0)){B=a[r+6|0]|0;if(B<<24>>24==0){break}b[(c[277218]|0)+(D<<1)>>1]=b[(c[277225]|0)+((B&255)<<1)>>1]|0;a[(c[277219]|0)+D|0]=a[1108909]|0}}while(0);D=I-1&255;if(D<<24>>24!=0){L=D;u=13422}}if((u|0)==13422){u=0;D=G+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+D|0]|0)){B=a[r+5|0]|0;if(B<<24>>24==0){break}b[(c[277218]|0)+(D<<1)>>1]=b[(c[277225]|0)+((B&255)<<1)>>1]|0;a[(c[277219]|0)+D|0]=a[1108909]|0}}while(0);D=L-1&255;if(D<<24>>24!=0){H=D;u=13426}}if((u|0)==13426){u=0;D=G+3|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+D|0]|0)){B=a[r+4|0]|0;if(B<<24>>24==0){break}b[(c[277218]|0)+(D<<1)>>1]=b[(c[277225]|0)+((B&255)<<1)>>1]|0;a[(c[277219]|0)+D|0]=a[1108909]|0}}while(0);D=H-1&255;if(D<<24>>24!=0){J=D;u=13430}}if((u|0)==13430){u=0;D=G+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+D|0]|0)){B=a[r+3|0]|0;if(B<<24>>24==0){break}b[(c[277218]|0)+(D<<1)>>1]=b[(c[277225]|0)+((B&255)<<1)>>1]|0;a[(c[277219]|0)+D|0]=a[1108909]|0}}while(0);D=J-1&255;if(D<<24>>24!=0){M=D;u=13434}}if((u|0)==13434){u=0;D=G+5|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+D|0]|0)){B=a[r+2|0]|0;if(B<<24>>24==0){break}b[(c[277218]|0)+(D<<1)>>1]=b[(c[277225]|0)+((B&255)<<1)>>1]|0;a[(c[277219]|0)+D|0]=a[1108909]|0}}while(0);D=M-1&255;if(D<<24>>24!=0){K=D;u=13438}}if((u|0)==13438){u=0;D=G+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+D|0]|0)){B=a[r+1|0]|0;if(B<<24>>24==0){break}b[(c[277218]|0)+(D<<1)>>1]=b[(c[277225]|0)+((B&255)<<1)>>1]|0;a[(c[277219]|0)+D|0]=a[1108909]|0}}while(0);if(K<<24>>24!=1){u=13442}}do{if((u|0)==13442){u=0;D=G+7|0;if((d[1108908]|0)<=(d[(c[277219]|0)+D|0]|0)){break}B=a[r]|0;if(B<<24>>24==0){break}b[(c[277218]|0)+(D<<1)>>1]=b[(c[277225]|0)+((B&255)<<1)>>1]|0;a[(c[277219]|0)+D|0]=a[1108909]|0}}while(0);D=E-1|0;if((D|0)>0){r=r-8|0;E=D;G=(c[277223]|0)+G|0}else{break}}return}else{if(!i){return}i=h&255;h=i-1&255;G=h<<24>>24==0;E=v;v=j;j=f;while(1){switch(g|0){case 1:{N=i;u=13385;break};case 4:{O=i;u=13397;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+j|0]|0)){f=a[E]|0;if(f<<24>>24==0){break}b[(c[277218]|0)+(j<<1)>>1]=b[(c[277225]|0)+((f&255)<<1)>>1]|0;a[(c[277219]|0)+j|0]=a[1108909]|0}}while(0);if(!G){N=h;u=13385}break};case 7:{u=13409;break};case 3:{P=i;u=13393;break};case 5:{Q=i;u=13401;break};case 2:{R=i;u=13389;break};case 6:{S=i;u=13405;break};default:{}}if((u|0)==13385){u=0;f=j+1|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+f|0]|0)){r=a[E+1|0]|0;if(r<<24>>24==0){break}b[(c[277218]|0)+(f<<1)>>1]=b[(c[277225]|0)+((r&255)<<1)>>1]|0;a[(c[277219]|0)+f|0]=a[1108909]|0}}while(0);f=N-1&255;if(f<<24>>24!=0){R=f;u=13389}}if((u|0)==13389){u=0;f=j+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+f|0]|0)){r=a[E+2|0]|0;if(r<<24>>24==0){break}b[(c[277218]|0)+(f<<1)>>1]=b[(c[277225]|0)+((r&255)<<1)>>1]|0;a[(c[277219]|0)+f|0]=a[1108909]|0}}while(0);f=R-1&255;if(f<<24>>24!=0){P=f;u=13393}}if((u|0)==13393){u=0;f=j+3|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+f|0]|0)){r=a[E+3|0]|0;if(r<<24>>24==0){break}b[(c[277218]|0)+(f<<1)>>1]=b[(c[277225]|0)+((r&255)<<1)>>1]|0;a[(c[277219]|0)+f|0]=a[1108909]|0}}while(0);f=P-1&255;if(f<<24>>24!=0){O=f;u=13397}}if((u|0)==13397){u=0;f=j+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+f|0]|0)){r=a[E+4|0]|0;if(r<<24>>24==0){break}b[(c[277218]|0)+(f<<1)>>1]=b[(c[277225]|0)+((r&255)<<1)>>1]|0;a[(c[277219]|0)+f|0]=a[1108909]|0}}while(0);f=O-1&255;if(f<<24>>24!=0){Q=f;u=13401}}if((u|0)==13401){u=0;f=j+5|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+f|0]|0)){r=a[E+5|0]|0;if(r<<24>>24==0){break}b[(c[277218]|0)+(f<<1)>>1]=b[(c[277225]|0)+((r&255)<<1)>>1]|0;a[(c[277219]|0)+f|0]=a[1108909]|0}}while(0);f=Q-1&255;if(f<<24>>24!=0){S=f;u=13405}}if((u|0)==13405){u=0;f=j+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+f|0]|0)){r=a[E+6|0]|0;if(r<<24>>24==0){break}b[(c[277218]|0)+(f<<1)>>1]=b[(c[277225]|0)+((r&255)<<1)>>1]|0;a[(c[277219]|0)+f|0]=a[1108909]|0}}while(0);if(S<<24>>24!=1){u=13409}}do{if((u|0)==13409){u=0;f=j+7|0;if((d[1108908]|0)<=(d[(c[277219]|0)+f|0]|0)){break}r=a[E+7|0]|0;if(r<<24>>24==0){break}b[(c[277218]|0)+(f<<1)>>1]=b[(c[277225]|0)+((r&255)<<1)>>1]|0;a[(c[277219]|0)+f|0]=a[1108909]|0}}while(0);f=v-1|0;if((f|0)>0){E=E-8|0;v=f;j=(c[277223]|0)+j|0}else{break}}return}}function Xl(f,g,h,i,j,k){f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0;l=f&1023;m=c[348606]|0;n=(l<<m)+(c[348604]|0)|0;if((f&256|0)==0){o=n}else{o=(c[348602]|0)+n|0}n=o&65535;o=n>>>(m>>>0);m=(f&16384|0)!=0;p=o<<6;do{if(m){q=(c[348622]|0)+p|0;if((a[(c[348618]|0)+o|0]|0)!=0){r=q;break}s=fi[c[348636]&63](q,n,l)|0;a[(c[348618]|0)+o|0]=s;r=q}else{q=(c[348624]|0)+p|0;if((a[(c[348620]|0)+o|0]|0)!=0){r=q;break}s=fi[c[348638]&63](q,n,l)|0;a[(c[348620]|0)+o|0]=s;r=q}}while(0);if((a[(c[348620]|0)+o|0]|0)==2){return}if((a[1394464]|0)==0){t=1106168+((f>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){o=d[1044485]|0;c[276541]=7080+(o<<5);l=0;do{n=l<<1&2;p=l&2;q=l&4;s=0;do{b[1125528+(l<<9)+(s<<1)>>1]=d[(s>>>1&28|p)+(7080+(o<<5))|0]<<6|d[(s<<2&28|n)+(7080+(o<<5))|0]<<11|d[(s>>>3&24|q)+(7080+(o<<5))|0];s=s+1|0;}while(s>>>0<256);l=l+1|0;}while(l>>>0<8);a[1106089]=0}t=1125528+((f>>>10&7)<<9)|0}c[277226]=t;c[277225]=(a[1108928]|0)!=0?1393712:t;if((f&49152|0)==0){if((k|0)<=0){return}t=i&255;l=t-1&255;o=l<<24>>24==0;s=r+j|0;q=k;n=g;while(1){switch(h|0){case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+n|0]|0)){p=a[s]|0;if(p<<24>>24==0){break}u=e[(c[277225]|0)+((p&255)<<1)>>1]|0;p=(a[(c[277215]|0)+n|0]&32)==0;if(p){v=c[277228]|0;w=v;x=v&-2082}else{v=e[(c[277213]|0)+(n<<1)>>1]|0;w=v;x=v&63454}if(p){y=c[277228]|0}else{y=e[(c[277213]|0)+(n<<1)>>1]|0}b[(c[277218]|0)+(n<<1)>>1]=((y^u)&2081|e[(c[277220]|0)+((u&2081&w)+((x+(u&63454)|0)>>>1)<<1)>>1])&65535;a[(c[277219]|0)+n|0]=a[1108909]|0}}while(0);if(!o){z=l;A=32}break};case 1:{z=t;A=32;break};case 2:{B=t;A=42;break};case 3:{C=t;A=52;break};case 4:{D=t;A=62;break};case 5:{E=t;A=72;break};case 6:{F=t;A=82;break};case 7:{A=92;break};default:{}}if((A|0)==32){A=0;u=n+1|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+u|0]|0)){p=a[s+1|0]|0;if(p<<24>>24==0){break}v=e[(c[277225]|0)+((p&255)<<1)>>1]|0;p=(a[(c[277215]|0)+u|0]&32)==0;if(p){G=c[277228]|0;H=G;I=G&-2082}else{G=e[(c[277213]|0)+(u<<1)>>1]|0;H=G;I=G&63454}if(p){J=c[277228]|0}else{J=e[(c[277213]|0)+(u<<1)>>1]|0}b[(c[277218]|0)+(u<<1)>>1]=((J^v)&2081|e[(c[277220]|0)+((v&2081&H)+((I+(v&63454)|0)>>>1)<<1)>>1])&65535;a[(c[277219]|0)+u|0]=a[1108909]|0}}while(0);u=z-1&255;if(u<<24>>24!=0){B=u;A=42}}if((A|0)==42){A=0;u=n+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+u|0]|0)){v=a[s+2|0]|0;if(v<<24>>24==0){break}p=e[(c[277225]|0)+((v&255)<<1)>>1]|0;v=(a[(c[277215]|0)+u|0]&32)==0;if(v){G=c[277228]|0;K=G;L=G&-2082}else{G=e[(c[277213]|0)+(u<<1)>>1]|0;K=G;L=G&63454}if(v){M=c[277228]|0}else{M=e[(c[277213]|0)+(u<<1)>>1]|0}b[(c[277218]|0)+(u<<1)>>1]=((M^p)&2081|e[(c[277220]|0)+((p&2081&K)+((L+(p&63454)|0)>>>1)<<1)>>1])&65535;a[(c[277219]|0)+u|0]=a[1108909]|0}}while(0);u=B-1&255;if(u<<24>>24!=0){C=u;A=52}}if((A|0)==52){A=0;u=n+3|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+u|0]|0)){p=a[s+3|0]|0;if(p<<24>>24==0){break}v=e[(c[277225]|0)+((p&255)<<1)>>1]|0;p=(a[(c[277215]|0)+u|0]&32)==0;if(p){G=c[277228]|0;N=G;O=G&-2082}else{G=e[(c[277213]|0)+(u<<1)>>1]|0;N=G;O=G&63454}if(p){P=c[277228]|0}else{P=e[(c[277213]|0)+(u<<1)>>1]|0}b[(c[277218]|0)+(u<<1)>>1]=((P^v)&2081|e[(c[277220]|0)+((v&2081&N)+((O+(v&63454)|0)>>>1)<<1)>>1])&65535;a[(c[277219]|0)+u|0]=a[1108909]|0}}while(0);u=C-1&255;if(u<<24>>24!=0){D=u;A=62}}if((A|0)==62){A=0;u=n+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+u|0]|0)){v=a[s+4|0]|0;if(v<<24>>24==0){break}p=e[(c[277225]|0)+((v&255)<<1)>>1]|0;v=(a[(c[277215]|0)+u|0]&32)==0;if(v){G=c[277228]|0;Q=G;R=G&-2082}else{G=e[(c[277213]|0)+(u<<1)>>1]|0;Q=G;R=G&63454}if(v){S=c[277228]|0}else{S=e[(c[277213]|0)+(u<<1)>>1]|0}b[(c[277218]|0)+(u<<1)>>1]=((S^p)&2081|e[(c[277220]|0)+((p&2081&Q)+((R+(p&63454)|0)>>>1)<<1)>>1])&65535;a[(c[277219]|0)+u|0]=a[1108909]|0}}while(0);u=D-1&255;if(u<<24>>24!=0){E=u;A=72}}if((A|0)==72){A=0;u=n+5|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+u|0]|0)){p=a[s+5|0]|0;if(p<<24>>24==0){break}v=e[(c[277225]|0)+((p&255)<<1)>>1]|0;p=(a[(c[277215]|0)+u|0]&32)==0;if(p){G=c[277228]|0;T=G;U=G&-2082}else{G=e[(c[277213]|0)+(u<<1)>>1]|0;T=G;U=G&63454}if(p){V=c[277228]|0}else{V=e[(c[277213]|0)+(u<<1)>>1]|0}b[(c[277218]|0)+(u<<1)>>1]=((V^v)&2081|e[(c[277220]|0)+((v&2081&T)+((U+(v&63454)|0)>>>1)<<1)>>1])&65535;a[(c[277219]|0)+u|0]=a[1108909]|0}}while(0);u=E-1&255;if(u<<24>>24!=0){F=u;A=82}}if((A|0)==82){A=0;u=n+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+u|0]|0)){v=a[s+6|0]|0;if(v<<24>>24==0){break}p=e[(c[277225]|0)+((v&255)<<1)>>1]|0;v=(a[(c[277215]|0)+u|0]&32)==0;if(v){G=c[277228]|0;W=G;X=G&-2082}else{G=e[(c[277213]|0)+(u<<1)>>1]|0;W=G;X=G&63454}if(v){Y=c[277228]|0}else{Y=e[(c[277213]|0)+(u<<1)>>1]|0}b[(c[277218]|0)+(u<<1)>>1]=((Y^p)&2081|e[(c[277220]|0)+((p&2081&W)+((X+(p&63454)|0)>>>1)<<1)>>1])&65535;a[(c[277219]|0)+u|0]=a[1108909]|0}}while(0);if(F<<24>>24!=1){A=92}}do{if((A|0)==92){A=0;u=n+7|0;if((d[1108908]|0)<=(d[(c[277219]|0)+u|0]|0)){break}p=a[s+7|0]|0;if(p<<24>>24==0){break}v=e[(c[277225]|0)+((p&255)<<1)>>1]|0;p=(a[(c[277215]|0)+u|0]&32)==0;if(p){G=c[277228]|0;Z=G;_=G&-2082}else{G=e[(c[277213]|0)+(u<<1)>>1]|0;Z=G;_=G&63454}if(p){$=c[277228]|0}else{$=e[(c[277213]|0)+(u<<1)>>1]|0}b[(c[277218]|0)+(u<<1)>>1]=(($^v)&2081|e[(c[277220]|0)+((v&2081&Z)+((_+(v&63454)|0)>>>1)<<1)>>1])&65535;a[(c[277219]|0)+u|0]=a[1108909]|0}}while(0);u=q-1|0;if((u|0)>0){s=s+8|0;q=u;n=(c[277223]|0)+n|0}else{break}}return}if((f&32768|0)==0){if((k|0)<=0){return}f=i&255;n=f-1&255;q=n<<24>>24==0;s=r+j|0;_=k;Z=g;while(1){switch(h|0){case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+Z|0]|0)){$=a[s+7|0]|0;if($<<24>>24==0){break}F=e[(c[277225]|0)+(($&255)<<1)>>1]|0;$=(a[(c[277215]|0)+Z|0]&32)==0;if($){X=c[277228]|0;aa=X;ab=X&-2082}else{X=e[(c[277213]|0)+(Z<<1)>>1]|0;aa=X;ab=X&63454}if($){ac=c[277228]|0}else{ac=e[(c[277213]|0)+(Z<<1)>>1]|0}b[(c[277218]|0)+(Z<<1)>>1]=((ac^F)&2081|e[(c[277220]|0)+((F&2081&aa)+((ab+(F&63454)|0)>>>1)<<1)>>1])&65535;a[(c[277219]|0)+Z|0]=a[1108909]|0}}while(0);if(!q){ad=n;A=116}break};case 1:{ad=f;A=116;break};case 2:{ae=f;A=126;break};case 3:{af=f;A=136;break};case 4:{ag=f;A=146;break};case 5:{ah=f;A=156;break};case 6:{ai=f;A=166;break};case 7:{A=176;break};default:{}}if((A|0)==116){A=0;F=Z+1|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+F|0]|0)){$=a[s+6|0]|0;if($<<24>>24==0){break}X=e[(c[277225]|0)+(($&255)<<1)>>1]|0;$=(a[(c[277215]|0)+F|0]&32)==0;if($){W=c[277228]|0;aj=W;ak=W&-2082}else{W=e[(c[277213]|0)+(F<<1)>>1]|0;aj=W;ak=W&63454}if($){al=c[277228]|0}else{al=e[(c[277213]|0)+(F<<1)>>1]|0}b[(c[277218]|0)+(F<<1)>>1]=((al^X)&2081|e[(c[277220]|0)+((X&2081&aj)+((ak+(X&63454)|0)>>>1)<<1)>>1])&65535;a[(c[277219]|0)+F|0]=a[1108909]|0}}while(0);F=ad-1&255;if(F<<24>>24!=0){ae=F;A=126}}if((A|0)==126){A=0;F=Z+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+F|0]|0)){X=a[s+5|0]|0;if(X<<24>>24==0){break}$=e[(c[277225]|0)+((X&255)<<1)>>1]|0;X=(a[(c[277215]|0)+F|0]&32)==0;if(X){W=c[277228]|0;am=W;an=W&-2082}else{W=e[(c[277213]|0)+(F<<1)>>1]|0;am=W;an=W&63454}if(X){ao=c[277228]|0}else{ao=e[(c[277213]|0)+(F<<1)>>1]|0}b[(c[277218]|0)+(F<<1)>>1]=((ao^$)&2081|e[(c[277220]|0)+(($&2081&am)+((an+($&63454)|0)>>>1)<<1)>>1])&65535;a[(c[277219]|0)+F|0]=a[1108909]|0}}while(0);F=ae-1&255;if(F<<24>>24!=0){af=F;A=136}}if((A|0)==136){A=0;F=Z+3|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+F|0]|0)){$=a[s+4|0]|0;if($<<24>>24==0){break}X=e[(c[277225]|0)+(($&255)<<1)>>1]|0;$=(a[(c[277215]|0)+F|0]&32)==0;if($){W=c[277228]|0;ap=W;aq=W&-2082}else{W=e[(c[277213]|0)+(F<<1)>>1]|0;ap=W;aq=W&63454}if($){ar=c[277228]|0}else{ar=e[(c[277213]|0)+(F<<1)>>1]|0}b[(c[277218]|0)+(F<<1)>>1]=((ar^X)&2081|e[(c[277220]|0)+((X&2081&ap)+((aq+(X&63454)|0)>>>1)<<1)>>1])&65535;a[(c[277219]|0)+F|0]=a[1108909]|0}}while(0);F=af-1&255;if(F<<24>>24!=0){ag=F;A=146}}if((A|0)==146){A=0;F=Z+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+F|0]|0)){X=a[s+3|0]|0;if(X<<24>>24==0){break}$=e[(c[277225]|0)+((X&255)<<1)>>1]|0;X=(a[(c[277215]|0)+F|0]&32)==0;if(X){W=c[277228]|0;as=W;at=W&-2082}else{W=e[(c[277213]|0)+(F<<1)>>1]|0;as=W;at=W&63454}if(X){au=c[277228]|0}else{au=e[(c[277213]|0)+(F<<1)>>1]|0}b[(c[277218]|0)+(F<<1)>>1]=((au^$)&2081|e[(c[277220]|0)+(($&2081&as)+((at+($&63454)|0)>>>1)<<1)>>1])&65535;a[(c[277219]|0)+F|0]=a[1108909]|0}}while(0);F=ag-1&255;if(F<<24>>24!=0){ah=F;A=156}}if((A|0)==156){A=0;F=Z+5|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+F|0]|0)){$=a[s+2|0]|0;if($<<24>>24==0){break}X=e[(c[277225]|0)+(($&255)<<1)>>1]|0;$=(a[(c[277215]|0)+F|0]&32)==0;if($){W=c[277228]|0;av=W;aw=W&-2082}else{W=e[(c[277213]|0)+(F<<1)>>1]|0;av=W;aw=W&63454}if($){ax=c[277228]|0}else{ax=e[(c[277213]|0)+(F<<1)>>1]|0}b[(c[277218]|0)+(F<<1)>>1]=((ax^X)&2081|e[(c[277220]|0)+((X&2081&av)+((aw+(X&63454)|0)>>>1)<<1)>>1])&65535;a[(c[277219]|0)+F|0]=a[1108909]|0}}while(0);F=ah-1&255;if(F<<24>>24!=0){ai=F;A=166}}if((A|0)==166){A=0;F=Z+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+F|0]|0)){X=a[s+1|0]|0;if(X<<24>>24==0){break}$=e[(c[277225]|0)+((X&255)<<1)>>1]|0;X=(a[(c[277215]|0)+F|0]&32)==0;if(X){W=c[277228]|0;ay=W;az=W&-2082}else{W=e[(c[277213]|0)+(F<<1)>>1]|0;ay=W;az=W&63454}if(X){aA=c[277228]|0}else{aA=e[(c[277213]|0)+(F<<1)>>1]|0}b[(c[277218]|0)+(F<<1)>>1]=((aA^$)&2081|e[(c[277220]|0)+(($&2081&ay)+((az+($&63454)|0)>>>1)<<1)>>1])&65535;a[(c[277219]|0)+F|0]=a[1108909]|0}}while(0);if(ai<<24>>24!=1){A=176}}do{if((A|0)==176){A=0;F=Z+7|0;if((d[1108908]|0)<=(d[(c[277219]|0)+F|0]|0)){break}$=a[s]|0;if($<<24>>24==0){break}X=e[(c[277225]|0)+(($&255)<<1)>>1]|0;$=(a[(c[277215]|0)+F|0]&32)==0;if($){W=c[277228]|0;aB=W;aC=W&-2082}else{W=e[(c[277213]|0)+(F<<1)>>1]|0;aB=W;aC=W&63454}if($){aD=c[277228]|0}else{aD=e[(c[277213]|0)+(F<<1)>>1]|0}b[(c[277218]|0)+(F<<1)>>1]=((aD^X)&2081|e[(c[277220]|0)+((X&2081&aB)+((aC+(X&63454)|0)>>>1)<<1)>>1])&65535;a[(c[277219]|0)+F|0]=a[1108909]|0}}while(0);F=_-1|0;if((F|0)>0){s=s+8|0;_=F;Z=(c[277223]|0)+Z|0}else{break}}return}Z=r+(56-j)|0;j=(k|0)>0;if(m){if(!j){return}m=i&255;r=m-1&255;_=r<<24>>24==0;s=Z;aC=k;aB=g;while(1){switch(h|0){case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+aB|0]|0)){aD=a[s+7|0]|0;if(aD<<24>>24==0){break}ai=e[(c[277225]|0)+((aD&255)<<1)>>1]|0;aD=(a[(c[277215]|0)+aB|0]&32)==0;if(aD){az=c[277228]|0;aE=az;aF=az&-2082}else{az=e[(c[277213]|0)+(aB<<1)>>1]|0;aE=az;aF=az&63454}if(aD){aG=c[277228]|0}else{aG=e[(c[277213]|0)+(aB<<1)>>1]|0}b[(c[277218]|0)+(aB<<1)>>1]=((aG^ai)&2081|e[(c[277220]|0)+((ai&2081&aE)+((aF+(ai&63454)|0)>>>1)<<1)>>1])&65535;a[(c[277219]|0)+aB|0]=a[1108909]|0}}while(0);if(!_){aH=r;A=283}break};case 1:{aH=m;A=283;break};case 2:{aI=m;A=293;break};case 3:{aJ=m;A=303;break};case 4:{aK=m;A=313;break};case 5:{aL=m;A=323;break};case 6:{aM=m;A=333;break};case 7:{A=343;break};default:{}}if((A|0)==283){A=0;ai=aB+1|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+ai|0]|0)){aD=a[s+6|0]|0;if(aD<<24>>24==0){break}az=e[(c[277225]|0)+((aD&255)<<1)>>1]|0;aD=(a[(c[277215]|0)+ai|0]&32)==0;if(aD){ay=c[277228]|0;aN=ay;aO=ay&-2082}else{ay=e[(c[277213]|0)+(ai<<1)>>1]|0;aN=ay;aO=ay&63454}if(aD){aP=c[277228]|0}else{aP=e[(c[277213]|0)+(ai<<1)>>1]|0}b[(c[277218]|0)+(ai<<1)>>1]=((aP^az)&2081|e[(c[277220]|0)+((az&2081&aN)+((aO+(az&63454)|0)>>>1)<<1)>>1])&65535;a[(c[277219]|0)+ai|0]=a[1108909]|0}}while(0);ai=aH-1&255;if(ai<<24>>24!=0){aI=ai;A=293}}if((A|0)==293){A=0;ai=aB+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+ai|0]|0)){az=a[s+5|0]|0;if(az<<24>>24==0){break}aD=e[(c[277225]|0)+((az&255)<<1)>>1]|0;az=(a[(c[277215]|0)+ai|0]&32)==0;if(az){ay=c[277228]|0;aQ=ay;aR=ay&-2082}else{ay=e[(c[277213]|0)+(ai<<1)>>1]|0;aQ=ay;aR=ay&63454}if(az){aS=c[277228]|0}else{aS=e[(c[277213]|0)+(ai<<1)>>1]|0}b[(c[277218]|0)+(ai<<1)>>1]=((aS^aD)&2081|e[(c[277220]|0)+((aD&2081&aQ)+((aR+(aD&63454)|0)>>>1)<<1)>>1])&65535;a[(c[277219]|0)+ai|0]=a[1108909]|0}}while(0);ai=aI-1&255;if(ai<<24>>24!=0){aJ=ai;A=303}}if((A|0)==303){A=0;ai=aB+3|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+ai|0]|0)){aD=a[s+4|0]|0;if(aD<<24>>24==0){break}az=e[(c[277225]|0)+((aD&255)<<1)>>1]|0;aD=(a[(c[277215]|0)+ai|0]&32)==0;if(aD){ay=c[277228]|0;aT=ay;aU=ay&-2082}else{ay=e[(c[277213]|0)+(ai<<1)>>1]|0;aT=ay;aU=ay&63454}if(aD){aV=c[277228]|0}else{aV=e[(c[277213]|0)+(ai<<1)>>1]|0}b[(c[277218]|0)+(ai<<1)>>1]=((aV^az)&2081|e[(c[277220]|0)+((az&2081&aT)+((aU+(az&63454)|0)>>>1)<<1)>>1])&65535;a[(c[277219]|0)+ai|0]=a[1108909]|0}}while(0);ai=aJ-1&255;if(ai<<24>>24!=0){aK=ai;A=313}}if((A|0)==313){A=0;ai=aB+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+ai|0]|0)){az=a[s+3|0]|0;if(az<<24>>24==0){break}aD=e[(c[277225]|0)+((az&255)<<1)>>1]|0;az=(a[(c[277215]|0)+ai|0]&32)==0;if(az){ay=c[277228]|0;aW=ay;aX=ay&-2082}else{ay=e[(c[277213]|0)+(ai<<1)>>1]|0;aW=ay;aX=ay&63454}if(az){aY=c[277228]|0}else{aY=e[(c[277213]|0)+(ai<<1)>>1]|0}b[(c[277218]|0)+(ai<<1)>>1]=((aY^aD)&2081|e[(c[277220]|0)+((aD&2081&aW)+((aX+(aD&63454)|0)>>>1)<<1)>>1])&65535;a[(c[277219]|0)+ai|0]=a[1108909]|0}}while(0);ai=aK-1&255;if(ai<<24>>24!=0){aL=ai;A=323}}if((A|0)==323){A=0;ai=aB+5|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+ai|0]|0)){aD=a[s+2|0]|0;if(aD<<24>>24==0){break}az=e[(c[277225]|0)+((aD&255)<<1)>>1]|0;aD=(a[(c[277215]|0)+ai|0]&32)==0;if(aD){ay=c[277228]|0;aZ=ay;a_=ay&-2082}else{ay=e[(c[277213]|0)+(ai<<1)>>1]|0;aZ=ay;a_=ay&63454}if(aD){a$=c[277228]|0}else{a$=e[(c[277213]|0)+(ai<<1)>>1]|0}b[(c[277218]|0)+(ai<<1)>>1]=((a$^az)&2081|e[(c[277220]|0)+((az&2081&aZ)+((a_+(az&63454)|0)>>>1)<<1)>>1])&65535;a[(c[277219]|0)+ai|0]=a[1108909]|0}}while(0);ai=aL-1&255;if(ai<<24>>24!=0){aM=ai;A=333}}if((A|0)==333){A=0;ai=aB+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+ai|0]|0)){az=a[s+1|0]|0;if(az<<24>>24==0){break}aD=e[(c[277225]|0)+((az&255)<<1)>>1]|0;az=(a[(c[277215]|0)+ai|0]&32)==0;if(az){ay=c[277228]|0;a0=ay;a1=ay&-2082}else{ay=e[(c[277213]|0)+(ai<<1)>>1]|0;a0=ay;a1=ay&63454}if(az){a2=c[277228]|0}else{a2=e[(c[277213]|0)+(ai<<1)>>1]|0}b[(c[277218]|0)+(ai<<1)>>1]=((a2^aD)&2081|e[(c[277220]|0)+((aD&2081&a0)+((a1+(aD&63454)|0)>>>1)<<1)>>1])&65535;a[(c[277219]|0)+ai|0]=a[1108909]|0}}while(0);if(aM<<24>>24!=1){A=343}}do{if((A|0)==343){A=0;ai=aB+7|0;if((d[1108908]|0)<=(d[(c[277219]|0)+ai|0]|0)){break}aD=a[s]|0;if(aD<<24>>24==0){break}az=e[(c[277225]|0)+((aD&255)<<1)>>1]|0;aD=(a[(c[277215]|0)+ai|0]&32)==0;if(aD){ay=c[277228]|0;a3=ay;a4=ay&-2082}else{ay=e[(c[277213]|0)+(ai<<1)>>1]|0;a3=ay;a4=ay&63454}if(aD){a5=c[277228]|0}else{a5=e[(c[277213]|0)+(ai<<1)>>1]|0}b[(c[277218]|0)+(ai<<1)>>1]=((a5^az)&2081|e[(c[277220]|0)+((az&2081&a3)+((a4+(az&63454)|0)>>>1)<<1)>>1])&65535;a[(c[277219]|0)+ai|0]=a[1108909]|0}}while(0);ai=aC-1|0;if((ai|0)>0){s=s-8|0;aC=ai;aB=(c[277223]|0)+aB|0}else{break}}return}else{if(!j){return}j=i&255;i=j-1&255;aB=i<<24>>24==0;aC=Z;Z=k;k=g;while(1){switch(h|0){case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+k|0]|0)){g=a[aC]|0;if(g<<24>>24==0){break}s=e[(c[277225]|0)+((g&255)<<1)>>1]|0;g=(a[(c[277215]|0)+k|0]&32)==0;if(g){a4=c[277228]|0;a6=a4;a7=a4&-2082}else{a4=e[(c[277213]|0)+(k<<1)>>1]|0;a6=a4;a7=a4&63454}if(g){a8=c[277228]|0}else{a8=e[(c[277213]|0)+(k<<1)>>1]|0}b[(c[277218]|0)+(k<<1)>>1]=((a8^s)&2081|e[(c[277220]|0)+((s&2081&a6)+((a7+(s&63454)|0)>>>1)<<1)>>1])&65535;a[(c[277219]|0)+k|0]=a[1108909]|0}}while(0);if(!aB){a9=i;A=202}break};case 1:{a9=j;A=202;break};case 2:{ba=j;A=212;break};case 3:{bb=j;A=222;break};case 4:{bc=j;A=232;break};case 5:{bd=j;A=242;break};case 6:{be=j;A=252;break};case 7:{A=262;break};default:{}}if((A|0)==202){A=0;s=k+1|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+s|0]|0)){g=a[aC+1|0]|0;if(g<<24>>24==0){break}a4=e[(c[277225]|0)+((g&255)<<1)>>1]|0;g=(a[(c[277215]|0)+s|0]&32)==0;if(g){a3=c[277228]|0;bf=a3;bg=a3&-2082}else{a3=e[(c[277213]|0)+(s<<1)>>1]|0;bf=a3;bg=a3&63454}if(g){bh=c[277228]|0}else{bh=e[(c[277213]|0)+(s<<1)>>1]|0}b[(c[277218]|0)+(s<<1)>>1]=((bh^a4)&2081|e[(c[277220]|0)+((a4&2081&bf)+((bg+(a4&63454)|0)>>>1)<<1)>>1])&65535;a[(c[277219]|0)+s|0]=a[1108909]|0}}while(0);s=a9-1&255;if(s<<24>>24!=0){ba=s;A=212}}if((A|0)==212){A=0;s=k+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+s|0]|0)){a4=a[aC+2|0]|0;if(a4<<24>>24==0){break}g=e[(c[277225]|0)+((a4&255)<<1)>>1]|0;a4=(a[(c[277215]|0)+s|0]&32)==0;if(a4){a3=c[277228]|0;bi=a3;bj=a3&-2082}else{a3=e[(c[277213]|0)+(s<<1)>>1]|0;bi=a3;bj=a3&63454}if(a4){bk=c[277228]|0}else{bk=e[(c[277213]|0)+(s<<1)>>1]|0}b[(c[277218]|0)+(s<<1)>>1]=((bk^g)&2081|e[(c[277220]|0)+((g&2081&bi)+((bj+(g&63454)|0)>>>1)<<1)>>1])&65535;a[(c[277219]|0)+s|0]=a[1108909]|0}}while(0);s=ba-1&255;if(s<<24>>24!=0){bb=s;A=222}}if((A|0)==222){A=0;s=k+3|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+s|0]|0)){g=a[aC+3|0]|0;if(g<<24>>24==0){break}a4=e[(c[277225]|0)+((g&255)<<1)>>1]|0;g=(a[(c[277215]|0)+s|0]&32)==0;if(g){a3=c[277228]|0;bl=a3;bm=a3&-2082}else{a3=e[(c[277213]|0)+(s<<1)>>1]|0;bl=a3;bm=a3&63454}if(g){bn=c[277228]|0}else{bn=e[(c[277213]|0)+(s<<1)>>1]|0}b[(c[277218]|0)+(s<<1)>>1]=((bn^a4)&2081|e[(c[277220]|0)+((a4&2081&bl)+((bm+(a4&63454)|0)>>>1)<<1)>>1])&65535;a[(c[277219]|0)+s|0]=a[1108909]|0}}while(0);s=bb-1&255;if(s<<24>>24!=0){bc=s;A=232}}if((A|0)==232){A=0;s=k+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+s|0]|0)){a4=a[aC+4|0]|0;if(a4<<24>>24==0){break}g=e[(c[277225]|0)+((a4&255)<<1)>>1]|0;a4=(a[(c[277215]|0)+s|0]&32)==0;if(a4){a3=c[277228]|0;bo=a3;bp=a3&-2082}else{a3=e[(c[277213]|0)+(s<<1)>>1]|0;bo=a3;bp=a3&63454}if(a4){bq=c[277228]|0}else{bq=e[(c[277213]|0)+(s<<1)>>1]|0}b[(c[277218]|0)+(s<<1)>>1]=((bq^g)&2081|e[(c[277220]|0)+((g&2081&bo)+((bp+(g&63454)|0)>>>1)<<1)>>1])&65535;a[(c[277219]|0)+s|0]=a[1108909]|0}}while(0);s=bc-1&255;if(s<<24>>24!=0){bd=s;A=242}}if((A|0)==242){A=0;s=k+5|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+s|0]|0)){g=a[aC+5|0]|0;if(g<<24>>24==0){break}a4=e[(c[277225]|0)+((g&255)<<1)>>1]|0;g=(a[(c[277215]|0)+s|0]&32)==0;if(g){a3=c[277228]|0;br=a3;bs=a3&-2082}else{a3=e[(c[277213]|0)+(s<<1)>>1]|0;br=a3;bs=a3&63454}if(g){bt=c[277228]|0}else{bt=e[(c[277213]|0)+(s<<1)>>1]|0}b[(c[277218]|0)+(s<<1)>>1]=((bt^a4)&2081|e[(c[277220]|0)+((a4&2081&br)+((bs+(a4&63454)|0)>>>1)<<1)>>1])&65535;a[(c[277219]|0)+s|0]=a[1108909]|0}}while(0);s=bd-1&255;if(s<<24>>24!=0){be=s;A=252}}if((A|0)==252){A=0;s=k+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+s|0]|0)){a4=a[aC+6|0]|0;if(a4<<24>>24==0){break}g=e[(c[277225]|0)+((a4&255)<<1)>>1]|0;a4=(a[(c[277215]|0)+s|0]&32)==0;if(a4){a3=c[277228]|0;bu=a3;bv=a3&-2082}else{a3=e[(c[277213]|0)+(s<<1)>>1]|0;bu=a3;bv=a3&63454}if(a4){bw=c[277228]|0}else{bw=e[(c[277213]|0)+(s<<1)>>1]|0}b[(c[277218]|0)+(s<<1)>>1]=((bw^g)&2081|e[(c[277220]|0)+((g&2081&bu)+((bv+(g&63454)|0)>>>1)<<1)>>1])&65535;a[(c[277219]|0)+s|0]=a[1108909]|0}}while(0);if(be<<24>>24!=1){A=262}}do{if((A|0)==262){A=0;s=k+7|0;if((d[1108908]|0)<=(d[(c[277219]|0)+s|0]|0)){break}g=a[aC+7|0]|0;if(g<<24>>24==0){break}a4=e[(c[277225]|0)+((g&255)<<1)>>1]|0;g=(a[(c[277215]|0)+s|0]&32)==0;if(g){a3=c[277228]|0;bx=a3;by=a3&-2082}else{a3=e[(c[277213]|0)+(s<<1)>>1]|0;bx=a3;by=a3&63454}if(g){bz=c[277228]|0}else{bz=e[(c[277213]|0)+(s<<1)>>1]|0}b[(c[277218]|0)+(s<<1)>>1]=((bz^a4)&2081|e[(c[277220]|0)+((a4&2081&bx)+((by+(a4&63454)|0)>>>1)<<1)>>1])&65535;a[(c[277219]|0)+s|0]=a[1108909]|0}}while(0);s=Z-1|0;if((s|0)>0){aC=aC-8|0;Z=s;k=(c[277223]|0)+k|0}else{break}}return}}function Xm(f,g,h,i,j,k){f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0;l=f&1023;m=c[348606]|0;n=(l<<m)+(c[348604]|0)|0;if((f&256|0)==0){o=n}else{o=(c[348602]|0)+n|0}n=o&65535;o=n>>>(m>>>0);m=(f&16384|0)!=0;p=o<<6;do{if(m){q=(c[348622]|0)+p|0;if((a[(c[348618]|0)+o|0]|0)!=0){r=q;break}s=fi[c[348636]&63](q,n,l)|0;a[(c[348618]|0)+o|0]=s;r=q}else{q=(c[348624]|0)+p|0;if((a[(c[348620]|0)+o|0]|0)!=0){r=q;break}s=fi[c[348638]&63](q,n,l)|0;a[(c[348620]|0)+o|0]=s;r=q}}while(0);if((a[(c[348620]|0)+o|0]|0)==2){return}if((a[1394464]|0)==0){t=1106168+((f>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){o=d[1044485]|0;c[276541]=7080+(o<<5);l=0;do{n=l<<1&2;p=l&2;q=l&4;s=0;do{b[1125528+(l<<9)+(s<<1)>>1]=d[(s>>>1&28|p)+(7080+(o<<5))|0]<<6|d[(s<<2&28|n)+(7080+(o<<5))|0]<<11|d[(s>>>3&24|q)+(7080+(o<<5))|0];s=s+1|0;}while(s>>>0<256);l=l+1|0;}while(l>>>0<8);a[1106089]=0}t=1125528+((f>>>10&7)<<9)|0}c[277226]=t;c[277225]=(a[1108928]|0)!=0?1393712:t;if((f&49152|0)==0){if((k|0)<=0){return}t=i&255;l=t-1&255;o=l<<24>>24==0;s=r+j|0;q=k;n=g;while(1){switch(h|0){case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+n|0]|0)){p=a[s]|0;if(p<<24>>24==0){break}u=e[(c[277225]|0)+((p&255)<<1)>>1]|0;p=c[277228]|0;v=(((u&63454)+(p&-2082)|0)>>>1)+(p&2081&u)|0;if((a[1108928]|0)==0){w=v&65535}else{w=(e[(c[277220]|0)+(v<<1)>>1]|(u^p)&2081)&65535}b[(c[277218]|0)+(n<<1)>>1]=w;a[(c[277219]|0)+n|0]=a[1108909]|0}}while(0);if(!o){x=l;y=390}break};case 1:{x=t;y=390;break};case 2:{z=t;y=396;break};case 3:{A=t;y=402;break};case 4:{B=t;y=408;break};case 5:{C=t;y=414;break};case 6:{D=t;y=420;break};case 7:{y=426;break};default:{}}if((y|0)==390){y=0;p=n+1|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){u=a[s+1|0]|0;if(u<<24>>24==0){break}v=e[(c[277225]|0)+((u&255)<<1)>>1]|0;u=c[277228]|0;E=(((v&63454)+(u&-2082)|0)>>>1)+(u&2081&v)|0;if((a[1108928]|0)==0){F=E&65535}else{F=(e[(c[277220]|0)+(E<<1)>>1]|(v^u)&2081)&65535}b[(c[277218]|0)+(p<<1)>>1]=F;a[(c[277219]|0)+p|0]=a[1108909]|0}}while(0);p=x-1&255;if(p<<24>>24!=0){z=p;y=396}}if((y|0)==396){y=0;p=n+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){u=a[s+2|0]|0;if(u<<24>>24==0){break}v=e[(c[277225]|0)+((u&255)<<1)>>1]|0;u=c[277228]|0;E=(((v&63454)+(u&-2082)|0)>>>1)+(u&2081&v)|0;if((a[1108928]|0)==0){G=E&65535}else{G=(e[(c[277220]|0)+(E<<1)>>1]|(v^u)&2081)&65535}b[(c[277218]|0)+(p<<1)>>1]=G;a[(c[277219]|0)+p|0]=a[1108909]|0}}while(0);p=z-1&255;if(p<<24>>24!=0){A=p;y=402}}if((y|0)==402){y=0;p=n+3|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){u=a[s+3|0]|0;if(u<<24>>24==0){break}v=e[(c[277225]|0)+((u&255)<<1)>>1]|0;u=c[277228]|0;E=(((v&63454)+(u&-2082)|0)>>>1)+(u&2081&v)|0;if((a[1108928]|0)==0){H=E&65535}else{H=(e[(c[277220]|0)+(E<<1)>>1]|(v^u)&2081)&65535}b[(c[277218]|0)+(p<<1)>>1]=H;a[(c[277219]|0)+p|0]=a[1108909]|0}}while(0);p=A-1&255;if(p<<24>>24!=0){B=p;y=408}}if((y|0)==408){y=0;p=n+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){u=a[s+4|0]|0;if(u<<24>>24==0){break}v=e[(c[277225]|0)+((u&255)<<1)>>1]|0;u=c[277228]|0;E=(((v&63454)+(u&-2082)|0)>>>1)+(u&2081&v)|0;if((a[1108928]|0)==0){I=E&65535}else{I=(e[(c[277220]|0)+(E<<1)>>1]|(v^u)&2081)&65535}b[(c[277218]|0)+(p<<1)>>1]=I;a[(c[277219]|0)+p|0]=a[1108909]|0}}while(0);p=B-1&255;if(p<<24>>24!=0){C=p;y=414}}if((y|0)==414){y=0;p=n+5|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){u=a[s+5|0]|0;if(u<<24>>24==0){break}v=e[(c[277225]|0)+((u&255)<<1)>>1]|0;u=c[277228]|0;E=(((v&63454)+(u&-2082)|0)>>>1)+(u&2081&v)|0;if((a[1108928]|0)==0){J=E&65535}else{J=(e[(c[277220]|0)+(E<<1)>>1]|(v^u)&2081)&65535}b[(c[277218]|0)+(p<<1)>>1]=J;a[(c[277219]|0)+p|0]=a[1108909]|0}}while(0);p=C-1&255;if(p<<24>>24!=0){D=p;y=420}}if((y|0)==420){y=0;p=n+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){u=a[s+6|0]|0;if(u<<24>>24==0){break}v=e[(c[277225]|0)+((u&255)<<1)>>1]|0;u=c[277228]|0;E=(((v&63454)+(u&-2082)|0)>>>1)+(u&2081&v)|0;if((a[1108928]|0)==0){K=E&65535}else{K=(e[(c[277220]|0)+(E<<1)>>1]|(v^u)&2081)&65535}b[(c[277218]|0)+(p<<1)>>1]=K;a[(c[277219]|0)+p|0]=a[1108909]|0}}while(0);if(D<<24>>24!=1){y=426}}do{if((y|0)==426){y=0;p=n+7|0;if((d[1108908]|0)<=(d[(c[277219]|0)+p|0]|0)){break}u=a[s+7|0]|0;if(u<<24>>24==0){break}v=e[(c[277225]|0)+((u&255)<<1)>>1]|0;u=c[277228]|0;E=(((v&63454)+(u&-2082)|0)>>>1)+(u&2081&v)|0;if((a[1108928]|0)==0){L=E&65535}else{L=(e[(c[277220]|0)+(E<<1)>>1]|(v^u)&2081)&65535}b[(c[277218]|0)+(p<<1)>>1]=L;a[(c[277219]|0)+p|0]=a[1108909]|0}}while(0);p=q-1|0;if((p|0)>0){s=s+8|0;q=p;n=(c[277223]|0)+n|0}else{break}}return}if((f&32768|0)==0){if((k|0)<=0){return}f=i&255;n=f-1&255;q=n<<24>>24==0;s=r+j|0;L=k;D=g;while(1){switch(h|0){case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+D|0]|0)){K=a[s+7|0]|0;if(K<<24>>24==0){break}C=e[(c[277225]|0)+((K&255)<<1)>>1]|0;K=c[277228]|0;J=(((C&63454)+(K&-2082)|0)>>>1)+(K&2081&C)|0;if((a[1108928]|0)==0){M=J&65535}else{M=(e[(c[277220]|0)+(J<<1)>>1]|(C^K)&2081)&65535}b[(c[277218]|0)+(D<<1)>>1]=M;a[(c[277219]|0)+D|0]=a[1108909]|0}}while(0);if(!q){N=n;y=442}break};case 1:{N=f;y=442;break};case 2:{O=f;y=448;break};case 3:{P=f;y=454;break};case 4:{Q=f;y=460;break};case 5:{R=f;y=466;break};case 6:{S=f;y=472;break};case 7:{y=478;break};default:{}}if((y|0)==442){y=0;K=D+1|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+K|0]|0)){C=a[s+6|0]|0;if(C<<24>>24==0){break}J=e[(c[277225]|0)+((C&255)<<1)>>1]|0;C=c[277228]|0;B=(((J&63454)+(C&-2082)|0)>>>1)+(C&2081&J)|0;if((a[1108928]|0)==0){T=B&65535}else{T=(e[(c[277220]|0)+(B<<1)>>1]|(J^C)&2081)&65535}b[(c[277218]|0)+(K<<1)>>1]=T;a[(c[277219]|0)+K|0]=a[1108909]|0}}while(0);K=N-1&255;if(K<<24>>24!=0){O=K;y=448}}if((y|0)==448){y=0;K=D+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+K|0]|0)){C=a[s+5|0]|0;if(C<<24>>24==0){break}J=e[(c[277225]|0)+((C&255)<<1)>>1]|0;C=c[277228]|0;B=(((J&63454)+(C&-2082)|0)>>>1)+(C&2081&J)|0;if((a[1108928]|0)==0){U=B&65535}else{U=(e[(c[277220]|0)+(B<<1)>>1]|(J^C)&2081)&65535}b[(c[277218]|0)+(K<<1)>>1]=U;a[(c[277219]|0)+K|0]=a[1108909]|0}}while(0);K=O-1&255;if(K<<24>>24!=0){P=K;y=454}}if((y|0)==454){y=0;K=D+3|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+K|0]|0)){C=a[s+4|0]|0;if(C<<24>>24==0){break}J=e[(c[277225]|0)+((C&255)<<1)>>1]|0;C=c[277228]|0;B=(((J&63454)+(C&-2082)|0)>>>1)+(C&2081&J)|0;if((a[1108928]|0)==0){V=B&65535}else{V=(e[(c[277220]|0)+(B<<1)>>1]|(J^C)&2081)&65535}b[(c[277218]|0)+(K<<1)>>1]=V;a[(c[277219]|0)+K|0]=a[1108909]|0}}while(0);K=P-1&255;if(K<<24>>24!=0){Q=K;y=460}}if((y|0)==460){y=0;K=D+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+K|0]|0)){C=a[s+3|0]|0;if(C<<24>>24==0){break}J=e[(c[277225]|0)+((C&255)<<1)>>1]|0;C=c[277228]|0;B=(((J&63454)+(C&-2082)|0)>>>1)+(C&2081&J)|0;if((a[1108928]|0)==0){W=B&65535}else{W=(e[(c[277220]|0)+(B<<1)>>1]|(J^C)&2081)&65535}b[(c[277218]|0)+(K<<1)>>1]=W;a[(c[277219]|0)+K|0]=a[1108909]|0}}while(0);K=Q-1&255;if(K<<24>>24!=0){R=K;y=466}}if((y|0)==466){y=0;K=D+5|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+K|0]|0)){C=a[s+2|0]|0;if(C<<24>>24==0){break}J=e[(c[277225]|0)+((C&255)<<1)>>1]|0;C=c[277228]|0;B=(((J&63454)+(C&-2082)|0)>>>1)+(C&2081&J)|0;if((a[1108928]|0)==0){X=B&65535}else{X=(e[(c[277220]|0)+(B<<1)>>1]|(J^C)&2081)&65535}b[(c[277218]|0)+(K<<1)>>1]=X;a[(c[277219]|0)+K|0]=a[1108909]|0}}while(0);K=R-1&255;if(K<<24>>24!=0){S=K;y=472}}if((y|0)==472){y=0;K=D+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+K|0]|0)){C=a[s+1|0]|0;if(C<<24>>24==0){break}J=e[(c[277225]|0)+((C&255)<<1)>>1]|0;C=c[277228]|0;B=(((J&63454)+(C&-2082)|0)>>>1)+(C&2081&J)|0;if((a[1108928]|0)==0){Y=B&65535}else{Y=(e[(c[277220]|0)+(B<<1)>>1]|(J^C)&2081)&65535}b[(c[277218]|0)+(K<<1)>>1]=Y;a[(c[277219]|0)+K|0]=a[1108909]|0}}while(0);if(S<<24>>24!=1){y=478}}do{if((y|0)==478){y=0;K=D+7|0;if((d[1108908]|0)<=(d[(c[277219]|0)+K|0]|0)){break}C=a[s]|0;if(C<<24>>24==0){break}J=e[(c[277225]|0)+((C&255)<<1)>>1]|0;C=c[277228]|0;B=(((J&63454)+(C&-2082)|0)>>>1)+(C&2081&J)|0;if((a[1108928]|0)==0){Z=B&65535}else{Z=(e[(c[277220]|0)+(B<<1)>>1]|(J^C)&2081)&65535}b[(c[277218]|0)+(K<<1)>>1]=Z;a[(c[277219]|0)+K|0]=a[1108909]|0}}while(0);K=L-1|0;if((K|0)>0){s=s+8|0;L=K;D=(c[277223]|0)+D|0}else{break}}return}D=r+(56-j)|0;j=(k|0)>0;if(m){if(!j){return}m=i&255;r=m-1&255;L=r<<24>>24==0;s=D;Z=k;S=g;while(1){switch(h|0){case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+S|0]|0)){Y=a[s+7|0]|0;if(Y<<24>>24==0){break}R=e[(c[277225]|0)+((Y&255)<<1)>>1]|0;Y=c[277228]|0;X=(((R&63454)+(Y&-2082)|0)>>>1)+(Y&2081&R)|0;if((a[1108928]|0)==0){_=X&65535}else{_=(e[(c[277220]|0)+(X<<1)>>1]|(R^Y)&2081)&65535}b[(c[277218]|0)+(S<<1)>>1]=_;a[(c[277219]|0)+S|0]=a[1108909]|0}}while(0);if(!L){$=r;y=545}break};case 1:{$=m;y=545;break};case 2:{aa=m;y=551;break};case 3:{ab=m;y=557;break};case 4:{ac=m;y=563;break};case 5:{ad=m;y=569;break};case 6:{ae=m;y=575;break};case 7:{y=581;break};default:{}}if((y|0)==545){y=0;Y=S+1|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+Y|0]|0)){R=a[s+6|0]|0;if(R<<24>>24==0){break}X=e[(c[277225]|0)+((R&255)<<1)>>1]|0;R=c[277228]|0;Q=(((X&63454)+(R&-2082)|0)>>>1)+(R&2081&X)|0;if((a[1108928]|0)==0){af=Q&65535}else{af=(e[(c[277220]|0)+(Q<<1)>>1]|(X^R)&2081)&65535}b[(c[277218]|0)+(Y<<1)>>1]=af;a[(c[277219]|0)+Y|0]=a[1108909]|0}}while(0);Y=$-1&255;if(Y<<24>>24!=0){aa=Y;y=551}}if((y|0)==551){y=0;Y=S+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+Y|0]|0)){R=a[s+5|0]|0;if(R<<24>>24==0){break}X=e[(c[277225]|0)+((R&255)<<1)>>1]|0;R=c[277228]|0;Q=(((X&63454)+(R&-2082)|0)>>>1)+(R&2081&X)|0;if((a[1108928]|0)==0){ag=Q&65535}else{ag=(e[(c[277220]|0)+(Q<<1)>>1]|(X^R)&2081)&65535}b[(c[277218]|0)+(Y<<1)>>1]=ag;a[(c[277219]|0)+Y|0]=a[1108909]|0}}while(0);Y=aa-1&255;if(Y<<24>>24!=0){ab=Y;y=557}}if((y|0)==557){y=0;Y=S+3|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+Y|0]|0)){R=a[s+4|0]|0;if(R<<24>>24==0){break}X=e[(c[277225]|0)+((R&255)<<1)>>1]|0;R=c[277228]|0;Q=(((X&63454)+(R&-2082)|0)>>>1)+(R&2081&X)|0;if((a[1108928]|0)==0){ah=Q&65535}else{ah=(e[(c[277220]|0)+(Q<<1)>>1]|(X^R)&2081)&65535}b[(c[277218]|0)+(Y<<1)>>1]=ah;a[(c[277219]|0)+Y|0]=a[1108909]|0}}while(0);Y=ab-1&255;if(Y<<24>>24!=0){ac=Y;y=563}}if((y|0)==563){y=0;Y=S+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+Y|0]|0)){R=a[s+3|0]|0;if(R<<24>>24==0){break}X=e[(c[277225]|0)+((R&255)<<1)>>1]|0;R=c[277228]|0;Q=(((X&63454)+(R&-2082)|0)>>>1)+(R&2081&X)|0;if((a[1108928]|0)==0){ai=Q&65535}else{ai=(e[(c[277220]|0)+(Q<<1)>>1]|(X^R)&2081)&65535}b[(c[277218]|0)+(Y<<1)>>1]=ai;a[(c[277219]|0)+Y|0]=a[1108909]|0}}while(0);Y=ac-1&255;if(Y<<24>>24!=0){ad=Y;y=569}}if((y|0)==569){y=0;Y=S+5|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+Y|0]|0)){R=a[s+2|0]|0;if(R<<24>>24==0){break}X=e[(c[277225]|0)+((R&255)<<1)>>1]|0;R=c[277228]|0;Q=(((X&63454)+(R&-2082)|0)>>>1)+(R&2081&X)|0;if((a[1108928]|0)==0){aj=Q&65535}else{aj=(e[(c[277220]|0)+(Q<<1)>>1]|(X^R)&2081)&65535}b[(c[277218]|0)+(Y<<1)>>1]=aj;a[(c[277219]|0)+Y|0]=a[1108909]|0}}while(0);Y=ad-1&255;if(Y<<24>>24!=0){ae=Y;y=575}}if((y|0)==575){y=0;Y=S+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+Y|0]|0)){R=a[s+1|0]|0;if(R<<24>>24==0){break}X=e[(c[277225]|0)+((R&255)<<1)>>1]|0;R=c[277228]|0;Q=(((X&63454)+(R&-2082)|0)>>>1)+(R&2081&X)|0;if((a[1108928]|0)==0){ak=Q&65535}else{ak=(e[(c[277220]|0)+(Q<<1)>>1]|(X^R)&2081)&65535}b[(c[277218]|0)+(Y<<1)>>1]=ak;a[(c[277219]|0)+Y|0]=a[1108909]|0}}while(0);if(ae<<24>>24!=1){y=581}}do{if((y|0)==581){y=0;Y=S+7|0;if((d[1108908]|0)<=(d[(c[277219]|0)+Y|0]|0)){break}R=a[s]|0;if(R<<24>>24==0){break}X=e[(c[277225]|0)+((R&255)<<1)>>1]|0;R=c[277228]|0;Q=(((X&63454)+(R&-2082)|0)>>>1)+(R&2081&X)|0;if((a[1108928]|0)==0){al=Q&65535}else{al=(e[(c[277220]|0)+(Q<<1)>>1]|(X^R)&2081)&65535}b[(c[277218]|0)+(Y<<1)>>1]=al;a[(c[277219]|0)+Y|0]=a[1108909]|0}}while(0);Y=Z-1|0;if((Y|0)>0){s=s-8|0;Z=Y;S=(c[277223]|0)+S|0}else{break}}return}else{if(!j){return}j=i&255;i=j-1&255;S=i<<24>>24==0;Z=D;D=k;k=g;while(1){switch(h|0){case 3:{am=j;y=508;break};case 4:{an=j;y=514;break};case 5:{ao=j;y=520;break};case 6:{ap=j;y=526;break};case 7:{y=532;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+k|0]|0)){g=a[Z]|0;if(g<<24>>24==0){break}s=e[(c[277225]|0)+((g&255)<<1)>>1]|0;g=c[277228]|0;al=(((s&63454)+(g&-2082)|0)>>>1)+(g&2081&s)|0;if((a[1108928]|0)==0){aq=al&65535}else{aq=(e[(c[277220]|0)+(al<<1)>>1]|(s^g)&2081)&65535}b[(c[277218]|0)+(k<<1)>>1]=aq;a[(c[277219]|0)+k|0]=a[1108909]|0}}while(0);if(!S){ar=i;y=496}break};case 1:{ar=j;y=496;break};case 2:{as=j;y=502;break};default:{}}if((y|0)==496){y=0;g=k+1|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+g|0]|0)){s=a[Z+1|0]|0;if(s<<24>>24==0){break}al=e[(c[277225]|0)+((s&255)<<1)>>1]|0;s=c[277228]|0;ae=(((al&63454)+(s&-2082)|0)>>>1)+(s&2081&al)|0;if((a[1108928]|0)==0){at=ae&65535}else{at=(e[(c[277220]|0)+(ae<<1)>>1]|(al^s)&2081)&65535}b[(c[277218]|0)+(g<<1)>>1]=at;a[(c[277219]|0)+g|0]=a[1108909]|0}}while(0);g=ar-1&255;if(g<<24>>24!=0){as=g;y=502}}if((y|0)==502){y=0;g=k+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+g|0]|0)){s=a[Z+2|0]|0;if(s<<24>>24==0){break}al=e[(c[277225]|0)+((s&255)<<1)>>1]|0;s=c[277228]|0;ae=(((al&63454)+(s&-2082)|0)>>>1)+(s&2081&al)|0;if((a[1108928]|0)==0){au=ae&65535}else{au=(e[(c[277220]|0)+(ae<<1)>>1]|(al^s)&2081)&65535}b[(c[277218]|0)+(g<<1)>>1]=au;a[(c[277219]|0)+g|0]=a[1108909]|0}}while(0);g=as-1&255;if(g<<24>>24!=0){am=g;y=508}}if((y|0)==508){y=0;g=k+3|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+g|0]|0)){s=a[Z+3|0]|0;if(s<<24>>24==0){break}al=e[(c[277225]|0)+((s&255)<<1)>>1]|0;s=c[277228]|0;ae=(((al&63454)+(s&-2082)|0)>>>1)+(s&2081&al)|0;if((a[1108928]|0)==0){av=ae&65535}else{av=(e[(c[277220]|0)+(ae<<1)>>1]|(al^s)&2081)&65535}b[(c[277218]|0)+(g<<1)>>1]=av;a[(c[277219]|0)+g|0]=a[1108909]|0}}while(0);g=am-1&255;if(g<<24>>24!=0){an=g;y=514}}if((y|0)==514){y=0;g=k+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+g|0]|0)){s=a[Z+4|0]|0;if(s<<24>>24==0){break}al=e[(c[277225]|0)+((s&255)<<1)>>1]|0;s=c[277228]|0;ae=(((al&63454)+(s&-2082)|0)>>>1)+(s&2081&al)|0;if((a[1108928]|0)==0){aw=ae&65535}else{aw=(e[(c[277220]|0)+(ae<<1)>>1]|(al^s)&2081)&65535}b[(c[277218]|0)+(g<<1)>>1]=aw;a[(c[277219]|0)+g|0]=a[1108909]|0}}while(0);g=an-1&255;if(g<<24>>24!=0){ao=g;y=520}}if((y|0)==520){y=0;g=k+5|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+g|0]|0)){s=a[Z+5|0]|0;if(s<<24>>24==0){break}al=e[(c[277225]|0)+((s&255)<<1)>>1]|0;s=c[277228]|0;ae=(((al&63454)+(s&-2082)|0)>>>1)+(s&2081&al)|0;if((a[1108928]|0)==0){ax=ae&65535}else{ax=(e[(c[277220]|0)+(ae<<1)>>1]|(al^s)&2081)&65535}b[(c[277218]|0)+(g<<1)>>1]=ax;a[(c[277219]|0)+g|0]=a[1108909]|0}}while(0);g=ao-1&255;if(g<<24>>24!=0){ap=g;y=526}}if((y|0)==526){y=0;g=k+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+g|0]|0)){s=a[Z+6|0]|0;if(s<<24>>24==0){break}al=e[(c[277225]|0)+((s&255)<<1)>>1]|0;s=c[277228]|0;ae=(((al&63454)+(s&-2082)|0)>>>1)+(s&2081&al)|0;if((a[1108928]|0)==0){ay=ae&65535}else{ay=(e[(c[277220]|0)+(ae<<1)>>1]|(al^s)&2081)&65535}b[(c[277218]|0)+(g<<1)>>1]=ay;a[(c[277219]|0)+g|0]=a[1108909]|0}}while(0);if(ap<<24>>24!=1){y=532}}do{if((y|0)==532){y=0;g=k+7|0;if((d[1108908]|0)<=(d[(c[277219]|0)+g|0]|0)){break}s=a[Z+7|0]|0;if(s<<24>>24==0){break}al=e[(c[277225]|0)+((s&255)<<1)>>1]|0;s=c[277228]|0;ae=(((al&63454)+(s&-2082)|0)>>>1)+(s&2081&al)|0;if((a[1108928]|0)==0){az=ae&65535}else{az=(e[(c[277220]|0)+(ae<<1)>>1]|(al^s)&2081)&65535}b[(c[277218]|0)+(g<<1)>>1]=az;a[(c[277219]|0)+g|0]=a[1108909]|0}}while(0);g=D-1|0;if((g|0)>0){Z=Z-8|0;D=g;k=(c[277223]|0)+k|0}else{break}}return}}function Xn(f,g,h,i,j,k){f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0;l=f&1023;m=c[348606]|0;n=(l<<m)+(c[348604]|0)|0;if((f&256|0)==0){o=n}else{o=(c[348602]|0)+n|0}n=o&65535;o=n>>>(m>>>0);m=(f&16384|0)!=0;p=o<<6;do{if(m){q=(c[348622]|0)+p|0;if((a[(c[348618]|0)+o|0]|0)!=0){r=q;break}s=fi[c[348636]&63](q,n,l)|0;a[(c[348618]|0)+o|0]=s;r=q}else{q=(c[348624]|0)+p|0;if((a[(c[348620]|0)+o|0]|0)!=0){r=q;break}s=fi[c[348638]&63](q,n,l)|0;a[(c[348620]|0)+o|0]=s;r=q}}while(0);if((a[(c[348620]|0)+o|0]|0)==2){return}if((a[1394464]|0)==0){t=1106168+((f>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){o=d[1044485]|0;c[276541]=7080+(o<<5);l=0;do{n=l<<1&2;p=l&2;q=l&4;s=0;do{b[1125528+(l<<9)+(s<<1)>>1]=d[(s>>>1&28|p)+(7080+(o<<5))|0]<<6|d[(s<<2&28|n)+(7080+(o<<5))|0]<<11|d[(s>>>3&24|q)+(7080+(o<<5))|0];s=s+1|0;}while(s>>>0<256);l=l+1|0;}while(l>>>0<8);a[1106089]=0}t=1125528+((f>>>10&7)<<9)|0}c[277226]=t;c[277225]=(a[1108928]|0)!=0?1393712:t;if((f&49152|0)==0){if((k|0)<=0){return}t=i&255;l=t-1&255;o=l<<24>>24==0;s=r+j|0;q=k;n=g;while(1){switch(h|0){case 3:{u=t;v=663;break};case 1:{w=t;v=633;break};case 2:{x=t;v=648;break};case 4:{y=t;v=678;break};case 5:{z=t;v=693;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+n|0]|0)){p=a[s]|0;A=p&255;if(p<<24>>24==0){break}do{if((a[1108928]|0)==0){p=b[(c[277225]|0)+(A<<1)>>1]|0;B=p&65535;C=B&63454;if((a[(c[277215]|0)+n|0]&32)==0){D=c[277228]|0;E=(e[(c[277220]|0)+((((D&-2082)+C|0)>>>1)+(B&2081&D)<<1)>>1]|(D^B)&2081)&65535;break}else{B=b[(c[277213]|0)+(n<<1)>>1]|0;E=(((B&63454)+C|0)>>>1)+(B&p&2081)&65535;break}}else{p=e[(c[277225]|0)+(A<<1)>>1]|0;B=(a[(c[277215]|0)+n|0]&32)==0;if(B){C=c[277228]|0;F=C;G=C&-2082}else{C=e[(c[277213]|0)+(n<<1)>>1]|0;F=C;G=C&63454}if(B){H=c[277228]|0}else{H=e[(c[277213]|0)+(n<<1)>>1]|0}E=((H^p)&2081|e[(c[277220]|0)+((p&2081&F)+((G+(p&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(n<<1)>>1]=E;a[(c[277219]|0)+n|0]=a[1108909]|0}}while(0);if(!o){w=l;v=633}break};case 6:{I=t;v=708;break};case 7:{v=723;break};default:{}}if((v|0)==633){v=0;A=n+1|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+A|0]|0)){p=a[s+1|0]|0;B=p&255;if(p<<24>>24==0){break}do{if((a[1108928]|0)==0){p=b[(c[277225]|0)+(B<<1)>>1]|0;C=p&65535;D=C&63454;if((a[(c[277215]|0)+A|0]&32)==0){J=c[277228]|0;K=(e[(c[277220]|0)+((((J&-2082)+D|0)>>>1)+(C&2081&J)<<1)>>1]|(J^C)&2081)&65535;break}else{C=b[(c[277213]|0)+(A<<1)>>1]|0;K=(((C&63454)+D|0)>>>1)+(C&p&2081)&65535;break}}else{p=e[(c[277225]|0)+(B<<1)>>1]|0;C=(a[(c[277215]|0)+A|0]&32)==0;if(C){D=c[277228]|0;L=D;M=D&-2082}else{D=e[(c[277213]|0)+(A<<1)>>1]|0;L=D;M=D&63454}if(C){N=c[277228]|0}else{N=e[(c[277213]|0)+(A<<1)>>1]|0}K=((N^p)&2081|e[(c[277220]|0)+((p&2081&L)+((M+(p&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(A<<1)>>1]=K;a[(c[277219]|0)+A|0]=a[1108909]|0}}while(0);A=w-1&255;if(A<<24>>24!=0){x=A;v=648}}if((v|0)==648){v=0;A=n+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+A|0]|0)){B=a[s+2|0]|0;p=B&255;if(B<<24>>24==0){break}do{if((a[1108928]|0)==0){B=b[(c[277225]|0)+(p<<1)>>1]|0;C=B&65535;D=C&63454;if((a[(c[277215]|0)+A|0]&32)==0){J=c[277228]|0;O=(e[(c[277220]|0)+((((J&-2082)+D|0)>>>1)+(C&2081&J)<<1)>>1]|(J^C)&2081)&65535;break}else{C=b[(c[277213]|0)+(A<<1)>>1]|0;O=(((C&63454)+D|0)>>>1)+(C&B&2081)&65535;break}}else{B=e[(c[277225]|0)+(p<<1)>>1]|0;C=(a[(c[277215]|0)+A|0]&32)==0;if(C){D=c[277228]|0;P=D;Q=D&-2082}else{D=e[(c[277213]|0)+(A<<1)>>1]|0;P=D;Q=D&63454}if(C){R=c[277228]|0}else{R=e[(c[277213]|0)+(A<<1)>>1]|0}O=((R^B)&2081|e[(c[277220]|0)+((B&2081&P)+((Q+(B&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(A<<1)>>1]=O;a[(c[277219]|0)+A|0]=a[1108909]|0}}while(0);A=x-1&255;if(A<<24>>24!=0){u=A;v=663}}if((v|0)==663){v=0;A=n+3|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+A|0]|0)){p=a[s+3|0]|0;B=p&255;if(p<<24>>24==0){break}do{if((a[1108928]|0)==0){p=b[(c[277225]|0)+(B<<1)>>1]|0;C=p&65535;D=C&63454;if((a[(c[277215]|0)+A|0]&32)==0){J=c[277228]|0;S=(e[(c[277220]|0)+((((J&-2082)+D|0)>>>1)+(C&2081&J)<<1)>>1]|(J^C)&2081)&65535;break}else{C=b[(c[277213]|0)+(A<<1)>>1]|0;S=(((C&63454)+D|0)>>>1)+(C&p&2081)&65535;break}}else{p=e[(c[277225]|0)+(B<<1)>>1]|0;C=(a[(c[277215]|0)+A|0]&32)==0;if(C){D=c[277228]|0;T=D;U=D&-2082}else{D=e[(c[277213]|0)+(A<<1)>>1]|0;T=D;U=D&63454}if(C){V=c[277228]|0}else{V=e[(c[277213]|0)+(A<<1)>>1]|0}S=((V^p)&2081|e[(c[277220]|0)+((p&2081&T)+((U+(p&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(A<<1)>>1]=S;a[(c[277219]|0)+A|0]=a[1108909]|0}}while(0);A=u-1&255;if(A<<24>>24!=0){y=A;v=678}}if((v|0)==678){v=0;A=n+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+A|0]|0)){B=a[s+4|0]|0;p=B&255;if(B<<24>>24==0){break}do{if((a[1108928]|0)==0){B=b[(c[277225]|0)+(p<<1)>>1]|0;C=B&65535;D=C&63454;if((a[(c[277215]|0)+A|0]&32)==0){J=c[277228]|0;W=(e[(c[277220]|0)+((((J&-2082)+D|0)>>>1)+(C&2081&J)<<1)>>1]|(J^C)&2081)&65535;break}else{C=b[(c[277213]|0)+(A<<1)>>1]|0;W=(((C&63454)+D|0)>>>1)+(C&B&2081)&65535;break}}else{B=e[(c[277225]|0)+(p<<1)>>1]|0;C=(a[(c[277215]|0)+A|0]&32)==0;if(C){D=c[277228]|0;X=D;Y=D&-2082}else{D=e[(c[277213]|0)+(A<<1)>>1]|0;X=D;Y=D&63454}if(C){Z=c[277228]|0}else{Z=e[(c[277213]|0)+(A<<1)>>1]|0}W=((Z^B)&2081|e[(c[277220]|0)+((B&2081&X)+((Y+(B&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(A<<1)>>1]=W;a[(c[277219]|0)+A|0]=a[1108909]|0}}while(0);A=y-1&255;if(A<<24>>24!=0){z=A;v=693}}if((v|0)==693){v=0;A=n+5|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+A|0]|0)){p=a[s+5|0]|0;B=p&255;if(p<<24>>24==0){break}do{if((a[1108928]|0)==0){p=b[(c[277225]|0)+(B<<1)>>1]|0;C=p&65535;D=C&63454;if((a[(c[277215]|0)+A|0]&32)==0){J=c[277228]|0;_=(e[(c[277220]|0)+((((J&-2082)+D|0)>>>1)+(C&2081&J)<<1)>>1]|(J^C)&2081)&65535;break}else{C=b[(c[277213]|0)+(A<<1)>>1]|0;_=(((C&63454)+D|0)>>>1)+(C&p&2081)&65535;break}}else{p=e[(c[277225]|0)+(B<<1)>>1]|0;C=(a[(c[277215]|0)+A|0]&32)==0;if(C){D=c[277228]|0;$=D;aa=D&-2082}else{D=e[(c[277213]|0)+(A<<1)>>1]|0;$=D;aa=D&63454}if(C){ab=c[277228]|0}else{ab=e[(c[277213]|0)+(A<<1)>>1]|0}_=((ab^p)&2081|e[(c[277220]|0)+((p&2081&$)+((aa+(p&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(A<<1)>>1]=_;a[(c[277219]|0)+A|0]=a[1108909]|0}}while(0);A=z-1&255;if(A<<24>>24!=0){I=A;v=708}}if((v|0)==708){v=0;A=n+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+A|0]|0)){B=a[s+6|0]|0;p=B&255;if(B<<24>>24==0){break}do{if((a[1108928]|0)==0){B=b[(c[277225]|0)+(p<<1)>>1]|0;C=B&65535;D=C&63454;if((a[(c[277215]|0)+A|0]&32)==0){J=c[277228]|0;ac=(e[(c[277220]|0)+((((J&-2082)+D|0)>>>1)+(C&2081&J)<<1)>>1]|(J^C)&2081)&65535;break}else{C=b[(c[277213]|0)+(A<<1)>>1]|0;ac=(((C&63454)+D|0)>>>1)+(C&B&2081)&65535;break}}else{B=e[(c[277225]|0)+(p<<1)>>1]|0;C=(a[(c[277215]|0)+A|0]&32)==0;if(C){D=c[277228]|0;ad=D;ae=D&-2082}else{D=e[(c[277213]|0)+(A<<1)>>1]|0;ad=D;ae=D&63454}if(C){af=c[277228]|0}else{af=e[(c[277213]|0)+(A<<1)>>1]|0}ac=((af^B)&2081|e[(c[277220]|0)+((B&2081&ad)+((ae+(B&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(A<<1)>>1]=ac;a[(c[277219]|0)+A|0]=a[1108909]|0}}while(0);if(I<<24>>24!=1){v=723}}do{if((v|0)==723){v=0;A=n+7|0;if((d[1108908]|0)<=(d[(c[277219]|0)+A|0]|0)){break}p=a[s+7|0]|0;B=p&255;if(p<<24>>24==0){break}do{if((a[1108928]|0)==0){p=b[(c[277225]|0)+(B<<1)>>1]|0;C=p&65535;D=C&63454;if((a[(c[277215]|0)+A|0]&32)==0){J=c[277228]|0;ag=(e[(c[277220]|0)+((((J&-2082)+D|0)>>>1)+(C&2081&J)<<1)>>1]|(J^C)&2081)&65535;break}else{C=b[(c[277213]|0)+(A<<1)>>1]|0;ag=(((C&63454)+D|0)>>>1)+(C&p&2081)&65535;break}}else{p=e[(c[277225]|0)+(B<<1)>>1]|0;C=(a[(c[277215]|0)+A|0]&32)==0;if(C){D=c[277228]|0;ah=D;ai=D&-2082}else{D=e[(c[277213]|0)+(A<<1)>>1]|0;ah=D;ai=D&63454}if(C){aj=c[277228]|0}else{aj=e[(c[277213]|0)+(A<<1)>>1]|0}ag=((aj^p)&2081|e[(c[277220]|0)+((p&2081&ah)+((ai+(p&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(A<<1)>>1]=ag;a[(c[277219]|0)+A|0]=a[1108909]|0}}while(0);B=q-1|0;if((B|0)>0){s=s+8|0;q=B;n=(c[277223]|0)+n|0}else{break}}return}if((f&32768|0)==0){if((k|0)<=0){return}f=i&255;n=f-1&255;q=n<<24>>24==0;s=r+j|0;ag=k;ai=g;while(1){switch(h|0){case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+ai|0]|0)){ah=a[s+7|0]|0;aj=ah&255;if(ah<<24>>24==0){break}do{if((a[1108928]|0)==0){ah=b[(c[277225]|0)+(aj<<1)>>1]|0;I=ah&65535;ac=I&63454;if((a[(c[277215]|0)+ai|0]&32)==0){ae=c[277228]|0;ak=(e[(c[277220]|0)+((((ae&-2082)+ac|0)>>>1)+(I&2081&ae)<<1)>>1]|(ae^I)&2081)&65535;break}else{I=b[(c[277213]|0)+(ai<<1)>>1]|0;ak=(((I&63454)+ac|0)>>>1)+(I&ah&2081)&65535;break}}else{ah=e[(c[277225]|0)+(aj<<1)>>1]|0;I=(a[(c[277215]|0)+ai|0]&32)==0;if(I){ac=c[277228]|0;al=ac;am=ac&-2082}else{ac=e[(c[277213]|0)+(ai<<1)>>1]|0;al=ac;am=ac&63454}if(I){an=c[277228]|0}else{an=e[(c[277213]|0)+(ai<<1)>>1]|0}ak=((an^ah)&2081|e[(c[277220]|0)+((ah&2081&al)+((am+(ah&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(ai<<1)>>1]=ak;a[(c[277219]|0)+ai|0]=a[1108909]|0}}while(0);if(!q){ao=n;v=757}break};case 3:{ap=f;v=787;break};case 4:{aq=f;v=802;break};case 5:{ar=f;v=817;break};case 6:{as=f;v=832;break};case 7:{v=847;break};case 1:{ao=f;v=757;break};case 2:{at=f;v=772;break};default:{}}if((v|0)==757){v=0;aj=ai+1|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+aj|0]|0)){A=a[s+6|0]|0;ah=A&255;if(A<<24>>24==0){break}do{if((a[1108928]|0)==0){A=b[(c[277225]|0)+(ah<<1)>>1]|0;I=A&65535;ac=I&63454;if((a[(c[277215]|0)+aj|0]&32)==0){ae=c[277228]|0;au=(e[(c[277220]|0)+((((ae&-2082)+ac|0)>>>1)+(I&2081&ae)<<1)>>1]|(ae^I)&2081)&65535;break}else{I=b[(c[277213]|0)+(aj<<1)>>1]|0;au=(((I&63454)+ac|0)>>>1)+(I&A&2081)&65535;break}}else{A=e[(c[277225]|0)+(ah<<1)>>1]|0;I=(a[(c[277215]|0)+aj|0]&32)==0;if(I){ac=c[277228]|0;av=ac;aw=ac&-2082}else{ac=e[(c[277213]|0)+(aj<<1)>>1]|0;av=ac;aw=ac&63454}if(I){ax=c[277228]|0}else{ax=e[(c[277213]|0)+(aj<<1)>>1]|0}au=((ax^A)&2081|e[(c[277220]|0)+((A&2081&av)+((aw+(A&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(aj<<1)>>1]=au;a[(c[277219]|0)+aj|0]=a[1108909]|0}}while(0);aj=ao-1&255;if(aj<<24>>24!=0){at=aj;v=772}}if((v|0)==772){v=0;aj=ai+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+aj|0]|0)){ah=a[s+5|0]|0;A=ah&255;if(ah<<24>>24==0){break}do{if((a[1108928]|0)==0){ah=b[(c[277225]|0)+(A<<1)>>1]|0;I=ah&65535;ac=I&63454;if((a[(c[277215]|0)+aj|0]&32)==0){ae=c[277228]|0;ay=(e[(c[277220]|0)+((((ae&-2082)+ac|0)>>>1)+(I&2081&ae)<<1)>>1]|(ae^I)&2081)&65535;break}else{I=b[(c[277213]|0)+(aj<<1)>>1]|0;ay=(((I&63454)+ac|0)>>>1)+(I&ah&2081)&65535;break}}else{ah=e[(c[277225]|0)+(A<<1)>>1]|0;I=(a[(c[277215]|0)+aj|0]&32)==0;if(I){ac=c[277228]|0;az=ac;aA=ac&-2082}else{ac=e[(c[277213]|0)+(aj<<1)>>1]|0;az=ac;aA=ac&63454}if(I){aB=c[277228]|0}else{aB=e[(c[277213]|0)+(aj<<1)>>1]|0}ay=((aB^ah)&2081|e[(c[277220]|0)+((ah&2081&az)+((aA+(ah&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(aj<<1)>>1]=ay;a[(c[277219]|0)+aj|0]=a[1108909]|0}}while(0);aj=at-1&255;if(aj<<24>>24!=0){ap=aj;v=787}}if((v|0)==787){v=0;aj=ai+3|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+aj|0]|0)){A=a[s+4|0]|0;ah=A&255;if(A<<24>>24==0){break}do{if((a[1108928]|0)==0){A=b[(c[277225]|0)+(ah<<1)>>1]|0;I=A&65535;ac=I&63454;if((a[(c[277215]|0)+aj|0]&32)==0){ae=c[277228]|0;aC=(e[(c[277220]|0)+((((ae&-2082)+ac|0)>>>1)+(I&2081&ae)<<1)>>1]|(ae^I)&2081)&65535;break}else{I=b[(c[277213]|0)+(aj<<1)>>1]|0;aC=(((I&63454)+ac|0)>>>1)+(I&A&2081)&65535;break}}else{A=e[(c[277225]|0)+(ah<<1)>>1]|0;I=(a[(c[277215]|0)+aj|0]&32)==0;if(I){ac=c[277228]|0;aD=ac;aE=ac&-2082}else{ac=e[(c[277213]|0)+(aj<<1)>>1]|0;aD=ac;aE=ac&63454}if(I){aF=c[277228]|0}else{aF=e[(c[277213]|0)+(aj<<1)>>1]|0}aC=((aF^A)&2081|e[(c[277220]|0)+((A&2081&aD)+((aE+(A&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(aj<<1)>>1]=aC;a[(c[277219]|0)+aj|0]=a[1108909]|0}}while(0);aj=ap-1&255;if(aj<<24>>24!=0){aq=aj;v=802}}if((v|0)==802){v=0;aj=ai+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+aj|0]|0)){ah=a[s+3|0]|0;A=ah&255;if(ah<<24>>24==0){break}do{if((a[1108928]|0)==0){ah=b[(c[277225]|0)+(A<<1)>>1]|0;I=ah&65535;ac=I&63454;if((a[(c[277215]|0)+aj|0]&32)==0){ae=c[277228]|0;aG=(e[(c[277220]|0)+((((ae&-2082)+ac|0)>>>1)+(I&2081&ae)<<1)>>1]|(ae^I)&2081)&65535;break}else{I=b[(c[277213]|0)+(aj<<1)>>1]|0;aG=(((I&63454)+ac|0)>>>1)+(I&ah&2081)&65535;break}}else{ah=e[(c[277225]|0)+(A<<1)>>1]|0;I=(a[(c[277215]|0)+aj|0]&32)==0;if(I){ac=c[277228]|0;aH=ac;aI=ac&-2082}else{ac=e[(c[277213]|0)+(aj<<1)>>1]|0;aH=ac;aI=ac&63454}if(I){aJ=c[277228]|0}else{aJ=e[(c[277213]|0)+(aj<<1)>>1]|0}aG=((aJ^ah)&2081|e[(c[277220]|0)+((ah&2081&aH)+((aI+(ah&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(aj<<1)>>1]=aG;a[(c[277219]|0)+aj|0]=a[1108909]|0}}while(0);aj=aq-1&255;if(aj<<24>>24!=0){ar=aj;v=817}}if((v|0)==817){v=0;aj=ai+5|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+aj|0]|0)){A=a[s+2|0]|0;ah=A&255;if(A<<24>>24==0){break}do{if((a[1108928]|0)==0){A=b[(c[277225]|0)+(ah<<1)>>1]|0;I=A&65535;ac=I&63454;if((a[(c[277215]|0)+aj|0]&32)==0){ae=c[277228]|0;aK=(e[(c[277220]|0)+((((ae&-2082)+ac|0)>>>1)+(I&2081&ae)<<1)>>1]|(ae^I)&2081)&65535;break}else{I=b[(c[277213]|0)+(aj<<1)>>1]|0;aK=(((I&63454)+ac|0)>>>1)+(I&A&2081)&65535;break}}else{A=e[(c[277225]|0)+(ah<<1)>>1]|0;I=(a[(c[277215]|0)+aj|0]&32)==0;if(I){ac=c[277228]|0;aL=ac;aM=ac&-2082}else{ac=e[(c[277213]|0)+(aj<<1)>>1]|0;aL=ac;aM=ac&63454}if(I){aN=c[277228]|0}else{aN=e[(c[277213]|0)+(aj<<1)>>1]|0}aK=((aN^A)&2081|e[(c[277220]|0)+((A&2081&aL)+((aM+(A&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(aj<<1)>>1]=aK;a[(c[277219]|0)+aj|0]=a[1108909]|0}}while(0);aj=ar-1&255;if(aj<<24>>24!=0){as=aj;v=832}}if((v|0)==832){v=0;aj=ai+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+aj|0]|0)){ah=a[s+1|0]|0;A=ah&255;if(ah<<24>>24==0){break}do{if((a[1108928]|0)==0){ah=b[(c[277225]|0)+(A<<1)>>1]|0;I=ah&65535;ac=I&63454;if((a[(c[277215]|0)+aj|0]&32)==0){ae=c[277228]|0;aO=(e[(c[277220]|0)+((((ae&-2082)+ac|0)>>>1)+(I&2081&ae)<<1)>>1]|(ae^I)&2081)&65535;break}else{I=b[(c[277213]|0)+(aj<<1)>>1]|0;aO=(((I&63454)+ac|0)>>>1)+(I&ah&2081)&65535;break}}else{ah=e[(c[277225]|0)+(A<<1)>>1]|0;I=(a[(c[277215]|0)+aj|0]&32)==0;if(I){ac=c[277228]|0;aP=ac;aQ=ac&-2082}else{ac=e[(c[277213]|0)+(aj<<1)>>1]|0;aP=ac;aQ=ac&63454}if(I){aR=c[277228]|0}else{aR=e[(c[277213]|0)+(aj<<1)>>1]|0}aO=((aR^ah)&2081|e[(c[277220]|0)+((ah&2081&aP)+((aQ+(ah&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(aj<<1)>>1]=aO;a[(c[277219]|0)+aj|0]=a[1108909]|0}}while(0);if(as<<24>>24!=1){v=847}}do{if((v|0)==847){v=0;aj=ai+7|0;if((d[1108908]|0)<=(d[(c[277219]|0)+aj|0]|0)){break}A=a[s]|0;ah=A&255;if(A<<24>>24==0){break}do{if((a[1108928]|0)==0){A=b[(c[277225]|0)+(ah<<1)>>1]|0;I=A&65535;ac=I&63454;if((a[(c[277215]|0)+aj|0]&32)==0){ae=c[277228]|0;aS=(e[(c[277220]|0)+((((ae&-2082)+ac|0)>>>1)+(I&2081&ae)<<1)>>1]|(ae^I)&2081)&65535;break}else{I=b[(c[277213]|0)+(aj<<1)>>1]|0;aS=(((I&63454)+ac|0)>>>1)+(I&A&2081)&65535;break}}else{A=e[(c[277225]|0)+(ah<<1)>>1]|0;I=(a[(c[277215]|0)+aj|0]&32)==0;if(I){ac=c[277228]|0;aT=ac;aU=ac&-2082}else{ac=e[(c[277213]|0)+(aj<<1)>>1]|0;aT=ac;aU=ac&63454}if(I){aV=c[277228]|0}else{aV=e[(c[277213]|0)+(aj<<1)>>1]|0}aS=((aV^A)&2081|e[(c[277220]|0)+((A&2081&aT)+((aU+(A&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(aj<<1)>>1]=aS;a[(c[277219]|0)+aj|0]=a[1108909]|0}}while(0);ah=ag-1|0;if((ah|0)>0){s=s+8|0;ag=ah;ai=(c[277223]|0)+ai|0}else{break}}return}ai=r+(56-j)|0;j=(k|0)>0;if(m){if(!j){return}m=i&255;r=m-1&255;ag=r<<24>>24==0;s=ai;aS=k;aU=g;while(1){switch(h|0){case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+aU|0]|0)){aT=a[s+7|0]|0;aV=aT&255;if(aT<<24>>24==0){break}do{if((a[1108928]|0)==0){aT=b[(c[277225]|0)+(aV<<1)>>1]|0;as=aT&65535;aO=as&63454;if((a[(c[277215]|0)+aU|0]&32)==0){aQ=c[277228]|0;aW=(e[(c[277220]|0)+((((aQ&-2082)+aO|0)>>>1)+(as&2081&aQ)<<1)>>1]|(aQ^as)&2081)&65535;break}else{as=b[(c[277213]|0)+(aU<<1)>>1]|0;aW=(((as&63454)+aO|0)>>>1)+(as&aT&2081)&65535;break}}else{aT=e[(c[277225]|0)+(aV<<1)>>1]|0;as=(a[(c[277215]|0)+aU|0]&32)==0;if(as){aO=c[277228]|0;aX=aO;aY=aO&-2082}else{aO=e[(c[277213]|0)+(aU<<1)>>1]|0;aX=aO;aY=aO&63454}if(as){aZ=c[277228]|0}else{aZ=e[(c[277213]|0)+(aU<<1)>>1]|0}aW=((aZ^aT)&2081|e[(c[277220]|0)+((aT&2081&aX)+((aY+(aT&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(aU<<1)>>1]=aW;a[(c[277219]|0)+aU|0]=a[1108909]|0}}while(0);if(!ag){a_=r;v=1004}break};case 1:{a_=m;v=1004;break};case 2:{a$=m;v=1019;break};case 3:{a0=m;v=1034;break};case 4:{a1=m;v=1049;break};case 5:{a2=m;v=1064;break};case 6:{a3=m;v=1079;break};case 7:{v=1094;break};default:{}}if((v|0)==1004){v=0;aV=aU+1|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+aV|0]|0)){aj=a[s+6|0]|0;aT=aj&255;if(aj<<24>>24==0){break}do{if((a[1108928]|0)==0){aj=b[(c[277225]|0)+(aT<<1)>>1]|0;as=aj&65535;aO=as&63454;if((a[(c[277215]|0)+aV|0]&32)==0){aQ=c[277228]|0;a4=(e[(c[277220]|0)+((((aQ&-2082)+aO|0)>>>1)+(as&2081&aQ)<<1)>>1]|(aQ^as)&2081)&65535;break}else{as=b[(c[277213]|0)+(aV<<1)>>1]|0;a4=(((as&63454)+aO|0)>>>1)+(as&aj&2081)&65535;break}}else{aj=e[(c[277225]|0)+(aT<<1)>>1]|0;as=(a[(c[277215]|0)+aV|0]&32)==0;if(as){aO=c[277228]|0;a5=aO;a6=aO&-2082}else{aO=e[(c[277213]|0)+(aV<<1)>>1]|0;a5=aO;a6=aO&63454}if(as){a7=c[277228]|0}else{a7=e[(c[277213]|0)+(aV<<1)>>1]|0}a4=((a7^aj)&2081|e[(c[277220]|0)+((aj&2081&a5)+((a6+(aj&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(aV<<1)>>1]=a4;a[(c[277219]|0)+aV|0]=a[1108909]|0}}while(0);aV=a_-1&255;if(aV<<24>>24!=0){a$=aV;v=1019}}if((v|0)==1019){v=0;aV=aU+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+aV|0]|0)){aT=a[s+5|0]|0;aj=aT&255;if(aT<<24>>24==0){break}do{if((a[1108928]|0)==0){aT=b[(c[277225]|0)+(aj<<1)>>1]|0;as=aT&65535;aO=as&63454;if((a[(c[277215]|0)+aV|0]&32)==0){aQ=c[277228]|0;a8=(e[(c[277220]|0)+((((aQ&-2082)+aO|0)>>>1)+(as&2081&aQ)<<1)>>1]|(aQ^as)&2081)&65535;break}else{as=b[(c[277213]|0)+(aV<<1)>>1]|0;a8=(((as&63454)+aO|0)>>>1)+(as&aT&2081)&65535;break}}else{aT=e[(c[277225]|0)+(aj<<1)>>1]|0;as=(a[(c[277215]|0)+aV|0]&32)==0;if(as){aO=c[277228]|0;a9=aO;ba=aO&-2082}else{aO=e[(c[277213]|0)+(aV<<1)>>1]|0;a9=aO;ba=aO&63454}if(as){bb=c[277228]|0}else{bb=e[(c[277213]|0)+(aV<<1)>>1]|0}a8=((bb^aT)&2081|e[(c[277220]|0)+((aT&2081&a9)+((ba+(aT&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(aV<<1)>>1]=a8;a[(c[277219]|0)+aV|0]=a[1108909]|0}}while(0);aV=a$-1&255;if(aV<<24>>24!=0){a0=aV;v=1034}}if((v|0)==1034){v=0;aV=aU+3|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+aV|0]|0)){aj=a[s+4|0]|0;aT=aj&255;if(aj<<24>>24==0){break}do{if((a[1108928]|0)==0){aj=b[(c[277225]|0)+(aT<<1)>>1]|0;as=aj&65535;aO=as&63454;if((a[(c[277215]|0)+aV|0]&32)==0){aQ=c[277228]|0;bc=(e[(c[277220]|0)+((((aQ&-2082)+aO|0)>>>1)+(as&2081&aQ)<<1)>>1]|(aQ^as)&2081)&65535;break}else{as=b[(c[277213]|0)+(aV<<1)>>1]|0;bc=(((as&63454)+aO|0)>>>1)+(as&aj&2081)&65535;break}}else{aj=e[(c[277225]|0)+(aT<<1)>>1]|0;as=(a[(c[277215]|0)+aV|0]&32)==0;if(as){aO=c[277228]|0;bd=aO;be=aO&-2082}else{aO=e[(c[277213]|0)+(aV<<1)>>1]|0;bd=aO;be=aO&63454}if(as){bf=c[277228]|0}else{bf=e[(c[277213]|0)+(aV<<1)>>1]|0}bc=((bf^aj)&2081|e[(c[277220]|0)+((aj&2081&bd)+((be+(aj&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(aV<<1)>>1]=bc;a[(c[277219]|0)+aV|0]=a[1108909]|0}}while(0);aV=a0-1&255;if(aV<<24>>24!=0){a1=aV;v=1049}}if((v|0)==1049){v=0;aV=aU+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+aV|0]|0)){aT=a[s+3|0]|0;aj=aT&255;if(aT<<24>>24==0){break}do{if((a[1108928]|0)==0){aT=b[(c[277225]|0)+(aj<<1)>>1]|0;as=aT&65535;aO=as&63454;if((a[(c[277215]|0)+aV|0]&32)==0){aQ=c[277228]|0;bg=(e[(c[277220]|0)+((((aQ&-2082)+aO|0)>>>1)+(as&2081&aQ)<<1)>>1]|(aQ^as)&2081)&65535;break}else{as=b[(c[277213]|0)+(aV<<1)>>1]|0;bg=(((as&63454)+aO|0)>>>1)+(as&aT&2081)&65535;break}}else{aT=e[(c[277225]|0)+(aj<<1)>>1]|0;as=(a[(c[277215]|0)+aV|0]&32)==0;if(as){aO=c[277228]|0;bh=aO;bi=aO&-2082}else{aO=e[(c[277213]|0)+(aV<<1)>>1]|0;bh=aO;bi=aO&63454}if(as){bj=c[277228]|0}else{bj=e[(c[277213]|0)+(aV<<1)>>1]|0}bg=((bj^aT)&2081|e[(c[277220]|0)+((aT&2081&bh)+((bi+(aT&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(aV<<1)>>1]=bg;a[(c[277219]|0)+aV|0]=a[1108909]|0}}while(0);aV=a1-1&255;if(aV<<24>>24!=0){a2=aV;v=1064}}if((v|0)==1064){v=0;aV=aU+5|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+aV|0]|0)){aj=a[s+2|0]|0;aT=aj&255;if(aj<<24>>24==0){break}do{if((a[1108928]|0)==0){aj=b[(c[277225]|0)+(aT<<1)>>1]|0;as=aj&65535;aO=as&63454;if((a[(c[277215]|0)+aV|0]&32)==0){aQ=c[277228]|0;bk=(e[(c[277220]|0)+((((aQ&-2082)+aO|0)>>>1)+(as&2081&aQ)<<1)>>1]|(aQ^as)&2081)&65535;break}else{as=b[(c[277213]|0)+(aV<<1)>>1]|0;bk=(((as&63454)+aO|0)>>>1)+(as&aj&2081)&65535;break}}else{aj=e[(c[277225]|0)+(aT<<1)>>1]|0;as=(a[(c[277215]|0)+aV|0]&32)==0;if(as){aO=c[277228]|0;bl=aO;bm=aO&-2082}else{aO=e[(c[277213]|0)+(aV<<1)>>1]|0;bl=aO;bm=aO&63454}if(as){bn=c[277228]|0}else{bn=e[(c[277213]|0)+(aV<<1)>>1]|0}bk=((bn^aj)&2081|e[(c[277220]|0)+((aj&2081&bl)+((bm+(aj&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(aV<<1)>>1]=bk;a[(c[277219]|0)+aV|0]=a[1108909]|0}}while(0);aV=a2-1&255;if(aV<<24>>24!=0){a3=aV;v=1079}}if((v|0)==1079){v=0;aV=aU+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+aV|0]|0)){aT=a[s+1|0]|0;aj=aT&255;if(aT<<24>>24==0){break}do{if((a[1108928]|0)==0){aT=b[(c[277225]|0)+(aj<<1)>>1]|0;as=aT&65535;aO=as&63454;if((a[(c[277215]|0)+aV|0]&32)==0){aQ=c[277228]|0;bo=(e[(c[277220]|0)+((((aQ&-2082)+aO|0)>>>1)+(as&2081&aQ)<<1)>>1]|(aQ^as)&2081)&65535;break}else{as=b[(c[277213]|0)+(aV<<1)>>1]|0;bo=(((as&63454)+aO|0)>>>1)+(as&aT&2081)&65535;break}}else{aT=e[(c[277225]|0)+(aj<<1)>>1]|0;as=(a[(c[277215]|0)+aV|0]&32)==0;if(as){aO=c[277228]|0;bp=aO;bq=aO&-2082}else{aO=e[(c[277213]|0)+(aV<<1)>>1]|0;bp=aO;bq=aO&63454}if(as){br=c[277228]|0}else{br=e[(c[277213]|0)+(aV<<1)>>1]|0}bo=((br^aT)&2081|e[(c[277220]|0)+((aT&2081&bp)+((bq+(aT&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(aV<<1)>>1]=bo;a[(c[277219]|0)+aV|0]=a[1108909]|0}}while(0);if(a3<<24>>24!=1){v=1094}}do{if((v|0)==1094){v=0;aV=aU+7|0;if((d[1108908]|0)<=(d[(c[277219]|0)+aV|0]|0)){break}aj=a[s]|0;aT=aj&255;if(aj<<24>>24==0){break}do{if((a[1108928]|0)==0){aj=b[(c[277225]|0)+(aT<<1)>>1]|0;as=aj&65535;aO=as&63454;if((a[(c[277215]|0)+aV|0]&32)==0){aQ=c[277228]|0;bs=(e[(c[277220]|0)+((((aQ&-2082)+aO|0)>>>1)+(as&2081&aQ)<<1)>>1]|(aQ^as)&2081)&65535;break}else{as=b[(c[277213]|0)+(aV<<1)>>1]|0;bs=(((as&63454)+aO|0)>>>1)+(as&aj&2081)&65535;break}}else{aj=e[(c[277225]|0)+(aT<<1)>>1]|0;as=(a[(c[277215]|0)+aV|0]&32)==0;if(as){aO=c[277228]|0;bt=aO;bu=aO&-2082}else{aO=e[(c[277213]|0)+(aV<<1)>>1]|0;bt=aO;bu=aO&63454}if(as){bv=c[277228]|0}else{bv=e[(c[277213]|0)+(aV<<1)>>1]|0}bs=((bv^aj)&2081|e[(c[277220]|0)+((aj&2081&bt)+((bu+(aj&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(aV<<1)>>1]=bs;a[(c[277219]|0)+aV|0]=a[1108909]|0}}while(0);aT=aS-1|0;if((aT|0)>0){s=s-8|0;aS=aT;aU=(c[277223]|0)+aU|0}else{break}}return}else{if(!j){return}j=i&255;i=j-1&255;aU=i<<24>>24==0;aS=ai;ai=k;k=g;while(1){switch(h|0){case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+k|0]|0)){g=a[aS]|0;s=g&255;if(g<<24>>24==0){break}do{if((a[1108928]|0)==0){g=b[(c[277225]|0)+(s<<1)>>1]|0;bs=g&65535;bu=bs&63454;if((a[(c[277215]|0)+k|0]&32)==0){bt=c[277228]|0;bw=(e[(c[277220]|0)+((((bt&-2082)+bu|0)>>>1)+(bs&2081&bt)<<1)>>1]|(bt^bs)&2081)&65535;break}else{bs=b[(c[277213]|0)+(k<<1)>>1]|0;bw=(((bs&63454)+bu|0)>>>1)+(bs&g&2081)&65535;break}}else{g=e[(c[277225]|0)+(s<<1)>>1]|0;bs=(a[(c[277215]|0)+k|0]&32)==0;if(bs){bu=c[277228]|0;bx=bu;by=bu&-2082}else{bu=e[(c[277213]|0)+(k<<1)>>1]|0;bx=bu;by=bu&63454}if(bs){bz=c[277228]|0}else{bz=e[(c[277213]|0)+(k<<1)>>1]|0}bw=((bz^g)&2081|e[(c[277220]|0)+((g&2081&bx)+((by+(g&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(k<<1)>>1]=bw;a[(c[277219]|0)+k|0]=a[1108909]|0}}while(0);if(!aU){bA=i;v=883}break};case 1:{bA=j;v=883;break};case 2:{bB=j;v=898;break};case 3:{bC=j;v=913;break};case 4:{bD=j;v=928;break};case 5:{bE=j;v=943;break};case 6:{bF=j;v=958;break};case 7:{v=973;break};default:{}}if((v|0)==883){v=0;s=k+1|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+s|0]|0)){aV=a[aS+1|0]|0;g=aV&255;if(aV<<24>>24==0){break}do{if((a[1108928]|0)==0){aV=b[(c[277225]|0)+(g<<1)>>1]|0;bs=aV&65535;bu=bs&63454;if((a[(c[277215]|0)+s|0]&32)==0){bt=c[277228]|0;bG=(e[(c[277220]|0)+((((bt&-2082)+bu|0)>>>1)+(bs&2081&bt)<<1)>>1]|(bt^bs)&2081)&65535;break}else{bs=b[(c[277213]|0)+(s<<1)>>1]|0;bG=(((bs&63454)+bu|0)>>>1)+(bs&aV&2081)&65535;break}}else{aV=e[(c[277225]|0)+(g<<1)>>1]|0;bs=(a[(c[277215]|0)+s|0]&32)==0;if(bs){bu=c[277228]|0;bH=bu;bI=bu&-2082}else{bu=e[(c[277213]|0)+(s<<1)>>1]|0;bH=bu;bI=bu&63454}if(bs){bJ=c[277228]|0}else{bJ=e[(c[277213]|0)+(s<<1)>>1]|0}bG=((bJ^aV)&2081|e[(c[277220]|0)+((aV&2081&bH)+((bI+(aV&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(s<<1)>>1]=bG;a[(c[277219]|0)+s|0]=a[1108909]|0}}while(0);s=bA-1&255;if(s<<24>>24!=0){bB=s;v=898}}if((v|0)==898){v=0;s=k+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+s|0]|0)){g=a[aS+2|0]|0;aV=g&255;if(g<<24>>24==0){break}do{if((a[1108928]|0)==0){g=b[(c[277225]|0)+(aV<<1)>>1]|0;bs=g&65535;bu=bs&63454;if((a[(c[277215]|0)+s|0]&32)==0){bt=c[277228]|0;bK=(e[(c[277220]|0)+((((bt&-2082)+bu|0)>>>1)+(bs&2081&bt)<<1)>>1]|(bt^bs)&2081)&65535;break}else{bs=b[(c[277213]|0)+(s<<1)>>1]|0;bK=(((bs&63454)+bu|0)>>>1)+(bs&g&2081)&65535;break}}else{g=e[(c[277225]|0)+(aV<<1)>>1]|0;bs=(a[(c[277215]|0)+s|0]&32)==0;if(bs){bu=c[277228]|0;bL=bu;bM=bu&-2082}else{bu=e[(c[277213]|0)+(s<<1)>>1]|0;bL=bu;bM=bu&63454}if(bs){bN=c[277228]|0}else{bN=e[(c[277213]|0)+(s<<1)>>1]|0}bK=((bN^g)&2081|e[(c[277220]|0)+((g&2081&bL)+((bM+(g&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(s<<1)>>1]=bK;a[(c[277219]|0)+s|0]=a[1108909]|0}}while(0);s=bB-1&255;if(s<<24>>24!=0){bC=s;v=913}}if((v|0)==913){v=0;s=k+3|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+s|0]|0)){aV=a[aS+3|0]|0;g=aV&255;if(aV<<24>>24==0){break}do{if((a[1108928]|0)==0){aV=b[(c[277225]|0)+(g<<1)>>1]|0;bs=aV&65535;bu=bs&63454;if((a[(c[277215]|0)+s|0]&32)==0){bt=c[277228]|0;bO=(e[(c[277220]|0)+((((bt&-2082)+bu|0)>>>1)+(bs&2081&bt)<<1)>>1]|(bt^bs)&2081)&65535;break}else{bs=b[(c[277213]|0)+(s<<1)>>1]|0;bO=(((bs&63454)+bu|0)>>>1)+(bs&aV&2081)&65535;break}}else{aV=e[(c[277225]|0)+(g<<1)>>1]|0;bs=(a[(c[277215]|0)+s|0]&32)==0;if(bs){bu=c[277228]|0;bP=bu;bQ=bu&-2082}else{bu=e[(c[277213]|0)+(s<<1)>>1]|0;bP=bu;bQ=bu&63454}if(bs){bR=c[277228]|0}else{bR=e[(c[277213]|0)+(s<<1)>>1]|0}bO=((bR^aV)&2081|e[(c[277220]|0)+((aV&2081&bP)+((bQ+(aV&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(s<<1)>>1]=bO;a[(c[277219]|0)+s|0]=a[1108909]|0}}while(0);s=bC-1&255;if(s<<24>>24!=0){bD=s;v=928}}if((v|0)==928){v=0;s=k+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+s|0]|0)){g=a[aS+4|0]|0;aV=g&255;if(g<<24>>24==0){break}do{if((a[1108928]|0)==0){g=b[(c[277225]|0)+(aV<<1)>>1]|0;bs=g&65535;bu=bs&63454;if((a[(c[277215]|0)+s|0]&32)==0){bt=c[277228]|0;bS=(e[(c[277220]|0)+((((bt&-2082)+bu|0)>>>1)+(bs&2081&bt)<<1)>>1]|(bt^bs)&2081)&65535;break}else{bs=b[(c[277213]|0)+(s<<1)>>1]|0;bS=(((bs&63454)+bu|0)>>>1)+(bs&g&2081)&65535;break}}else{g=e[(c[277225]|0)+(aV<<1)>>1]|0;bs=(a[(c[277215]|0)+s|0]&32)==0;if(bs){bu=c[277228]|0;bT=bu;bU=bu&-2082}else{bu=e[(c[277213]|0)+(s<<1)>>1]|0;bT=bu;bU=bu&63454}if(bs){bV=c[277228]|0}else{bV=e[(c[277213]|0)+(s<<1)>>1]|0}bS=((bV^g)&2081|e[(c[277220]|0)+((g&2081&bT)+((bU+(g&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(s<<1)>>1]=bS;a[(c[277219]|0)+s|0]=a[1108909]|0}}while(0);s=bD-1&255;if(s<<24>>24!=0){bE=s;v=943}}if((v|0)==943){v=0;s=k+5|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+s|0]|0)){aV=a[aS+5|0]|0;g=aV&255;if(aV<<24>>24==0){break}do{if((a[1108928]|0)==0){aV=b[(c[277225]|0)+(g<<1)>>1]|0;bs=aV&65535;bu=bs&63454;if((a[(c[277215]|0)+s|0]&32)==0){bt=c[277228]|0;bW=(e[(c[277220]|0)+((((bt&-2082)+bu|0)>>>1)+(bs&2081&bt)<<1)>>1]|(bt^bs)&2081)&65535;break}else{bs=b[(c[277213]|0)+(s<<1)>>1]|0;bW=(((bs&63454)+bu|0)>>>1)+(bs&aV&2081)&65535;break}}else{aV=e[(c[277225]|0)+(g<<1)>>1]|0;bs=(a[(c[277215]|0)+s|0]&32)==0;if(bs){bu=c[277228]|0;bX=bu;bY=bu&-2082}else{bu=e[(c[277213]|0)+(s<<1)>>1]|0;bX=bu;bY=bu&63454}if(bs){bZ=c[277228]|0}else{bZ=e[(c[277213]|0)+(s<<1)>>1]|0}bW=((bZ^aV)&2081|e[(c[277220]|0)+((aV&2081&bX)+((bY+(aV&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(s<<1)>>1]=bW;a[(c[277219]|0)+s|0]=a[1108909]|0}}while(0);s=bE-1&255;if(s<<24>>24!=0){bF=s;v=958}}if((v|0)==958){v=0;s=k+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+s|0]|0)){g=a[aS+6|0]|0;aV=g&255;if(g<<24>>24==0){break}do{if((a[1108928]|0)==0){g=b[(c[277225]|0)+(aV<<1)>>1]|0;bs=g&65535;bu=bs&63454;if((a[(c[277215]|0)+s|0]&32)==0){bt=c[277228]|0;b_=(e[(c[277220]|0)+((((bt&-2082)+bu|0)>>>1)+(bs&2081&bt)<<1)>>1]|(bt^bs)&2081)&65535;break}else{bs=b[(c[277213]|0)+(s<<1)>>1]|0;b_=(((bs&63454)+bu|0)>>>1)+(bs&g&2081)&65535;break}}else{g=e[(c[277225]|0)+(aV<<1)>>1]|0;bs=(a[(c[277215]|0)+s|0]&32)==0;if(bs){bu=c[277228]|0;b$=bu;b0=bu&-2082}else{bu=e[(c[277213]|0)+(s<<1)>>1]|0;b$=bu;b0=bu&63454}if(bs){b1=c[277228]|0}else{b1=e[(c[277213]|0)+(s<<1)>>1]|0}b_=((b1^g)&2081|e[(c[277220]|0)+((g&2081&b$)+((b0+(g&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(s<<1)>>1]=b_;a[(c[277219]|0)+s|0]=a[1108909]|0}}while(0);if(bF<<24>>24!=1){v=973}}do{if((v|0)==973){v=0;s=k+7|0;if((d[1108908]|0)<=(d[(c[277219]|0)+s|0]|0)){break}aV=a[aS+7|0]|0;g=aV&255;if(aV<<24>>24==0){break}do{if((a[1108928]|0)==0){aV=b[(c[277225]|0)+(g<<1)>>1]|0;bs=aV&65535;bu=bs&63454;if((a[(c[277215]|0)+s|0]&32)==0){bt=c[277228]|0;b2=(e[(c[277220]|0)+((((bt&-2082)+bu|0)>>>1)+(bs&2081&bt)<<1)>>1]|(bt^bs)&2081)&65535;break}else{bs=b[(c[277213]|0)+(s<<1)>>1]|0;b2=(((bs&63454)+bu|0)>>>1)+(bs&aV&2081)&65535;break}}else{aV=e[(c[277225]|0)+(g<<1)>>1]|0;bs=(a[(c[277215]|0)+s|0]&32)==0;if(bs){bu=c[277228]|0;b3=bu;b4=bu&-2082}else{bu=e[(c[277213]|0)+(s<<1)>>1]|0;b3=bu;b4=bu&63454}if(bs){b5=c[277228]|0}else{b5=e[(c[277213]|0)+(s<<1)>>1]|0}b2=((b5^aV)&2081|e[(c[277220]|0)+((aV&2081&b3)+((b4+(aV&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(s<<1)>>1]=b2;a[(c[277219]|0)+s|0]=a[1108909]|0}}while(0);g=ai-1|0;if((g|0)>0){aS=aS-8|0;ai=g;k=(c[277223]|0)+k|0}else{break}}return}}function Xo(e,f,g,h,i,j){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0;k=e&1023;l=c[348606]|0;m=(k<<l)+(c[348604]|0)|0;if((e&256|0)==0){n=m}else{n=(c[348602]|0)+m|0}m=n&65535;n=m>>>(l>>>0);l=(e&16384|0)!=0;o=n<<6;do{if(l){p=(c[348622]|0)+o|0;if((a[(c[348618]|0)+n|0]|0)!=0){q=p;break}r=fi[c[348636]&63](p,m,k)|0;a[(c[348618]|0)+n|0]=r;q=p}else{p=(c[348624]|0)+o|0;if((a[(c[348620]|0)+n|0]|0)!=0){q=p;break}r=fi[c[348638]&63](p,m,k)|0;a[(c[348620]|0)+n|0]=r;q=p}}while(0);if((a[(c[348620]|0)+n|0]|0)==2){return}if((a[1394464]|0)==0){s=1106168+((e>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){n=d[1044485]|0;c[276541]=7080+(n<<5);k=0;do{m=k<<1&2;o=k&2;p=k&4;r=0;do{b[1125528+(k<<9)+(r<<1)>>1]=d[(r>>>1&28|o)+(7080+(n<<5))|0]<<6|d[(r<<2&28|m)+(7080+(n<<5))|0]<<11|d[(r>>>3&24|p)+(7080+(n<<5))|0];r=r+1|0;}while(r>>>0<256);k=k+1|0;}while(k>>>0<8);a[1106089]=0}s=1125528+((e>>>10&7)<<9)|0}c[277226]=s;c[277225]=(a[1108928]|0)!=0?1393712:s;if((e&49152|0)==0){if((j|0)<=0){return}s=h&255;k=s-1&255;n=k<<24>>24==0;r=q+i|0;p=j;m=f;while(1){switch(g|0){case 2:{t=s;u=1162;break};case 3:{v=s;u=1173;break};case 4:{w=s;u=1184;break};case 5:{x=s;u=1195;break};case 6:{y=s;u=1206;break};case 7:{u=1217;break};case 1:{z=s;u=1151;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+m|0]|0)){o=a[r]|0;if(o<<24>>24==0){break}A=b[(c[277225]|0)+((o&255)<<1)>>1]|0;if((a[(c[277215]|0)+m|0]&32)==0){B=c[277228]&65535}else{B=b[(c[277213]|0)+(m<<1)>>1]|0}o=A&-2048;C=B&-2048;D=(o&65535)>(C&65535)?o-C&65535:0;C=A&2016;o=B&2016;if((C&65535)>(o&65535)){E=(C-o&65535)+D&65535}else{E=D}D=A&31;A=B&31;if((D&65535)>(A&65535)){F=(D-A&65535)+E&65535}else{F=E}b[(c[277218]|0)+(m<<1)>>1]=F;a[(c[277219]|0)+m|0]=a[1108909]|0}}while(0);if(!n){z=k;u=1151}break};default:{}}if((u|0)==1151){u=0;A=m+1|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+A|0]|0)){D=a[r+1|0]|0;if(D<<24>>24==0){break}o=b[(c[277225]|0)+((D&255)<<1)>>1]|0;if((a[(c[277215]|0)+A|0]&32)==0){G=c[277228]&65535}else{G=b[(c[277213]|0)+(A<<1)>>1]|0}D=o&-2048;C=G&-2048;H=(D&65535)>(C&65535)?D-C&65535:0;C=o&2016;D=G&2016;if((C&65535)>(D&65535)){I=(C-D&65535)+H&65535}else{I=H}H=o&31;o=G&31;if((H&65535)>(o&65535)){J=(H-o&65535)+I&65535}else{J=I}b[(c[277218]|0)+(A<<1)>>1]=J;a[(c[277219]|0)+A|0]=a[1108909]|0}}while(0);A=z-1&255;if(A<<24>>24!=0){t=A;u=1162}}if((u|0)==1162){u=0;A=m+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+A|0]|0)){o=a[r+2|0]|0;if(o<<24>>24==0){break}H=b[(c[277225]|0)+((o&255)<<1)>>1]|0;if((a[(c[277215]|0)+A|0]&32)==0){K=c[277228]&65535}else{K=b[(c[277213]|0)+(A<<1)>>1]|0}o=H&-2048;D=K&-2048;C=(o&65535)>(D&65535)?o-D&65535:0;D=H&2016;o=K&2016;if((D&65535)>(o&65535)){L=(D-o&65535)+C&65535}else{L=C}C=H&31;H=K&31;if((C&65535)>(H&65535)){M=(C-H&65535)+L&65535}else{M=L}b[(c[277218]|0)+(A<<1)>>1]=M;a[(c[277219]|0)+A|0]=a[1108909]|0}}while(0);A=t-1&255;if(A<<24>>24!=0){v=A;u=1173}}if((u|0)==1173){u=0;A=m+3|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+A|0]|0)){H=a[r+3|0]|0;if(H<<24>>24==0){break}C=b[(c[277225]|0)+((H&255)<<1)>>1]|0;if((a[(c[277215]|0)+A|0]&32)==0){N=c[277228]&65535}else{N=b[(c[277213]|0)+(A<<1)>>1]|0}H=C&-2048;o=N&-2048;D=(H&65535)>(o&65535)?H-o&65535:0;o=C&2016;H=N&2016;if((o&65535)>(H&65535)){O=(o-H&65535)+D&65535}else{O=D}D=C&31;C=N&31;if((D&65535)>(C&65535)){P=(D-C&65535)+O&65535}else{P=O}b[(c[277218]|0)+(A<<1)>>1]=P;a[(c[277219]|0)+A|0]=a[1108909]|0}}while(0);A=v-1&255;if(A<<24>>24!=0){w=A;u=1184}}if((u|0)==1184){u=0;A=m+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+A|0]|0)){C=a[r+4|0]|0;if(C<<24>>24==0){break}D=b[(c[277225]|0)+((C&255)<<1)>>1]|0;if((a[(c[277215]|0)+A|0]&32)==0){Q=c[277228]&65535}else{Q=b[(c[277213]|0)+(A<<1)>>1]|0}C=D&-2048;H=Q&-2048;o=(C&65535)>(H&65535)?C-H&65535:0;H=D&2016;C=Q&2016;if((H&65535)>(C&65535)){R=(H-C&65535)+o&65535}else{R=o}o=D&31;D=Q&31;if((o&65535)>(D&65535)){S=(o-D&65535)+R&65535}else{S=R}b[(c[277218]|0)+(A<<1)>>1]=S;a[(c[277219]|0)+A|0]=a[1108909]|0}}while(0);A=w-1&255;if(A<<24>>24!=0){x=A;u=1195}}if((u|0)==1195){u=0;A=m+5|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+A|0]|0)){D=a[r+5|0]|0;if(D<<24>>24==0){break}o=b[(c[277225]|0)+((D&255)<<1)>>1]|0;if((a[(c[277215]|0)+A|0]&32)==0){T=c[277228]&65535}else{T=b[(c[277213]|0)+(A<<1)>>1]|0}D=o&-2048;C=T&-2048;H=(D&65535)>(C&65535)?D-C&65535:0;C=o&2016;D=T&2016;if((C&65535)>(D&65535)){U=(C-D&65535)+H&65535}else{U=H}H=o&31;o=T&31;if((H&65535)>(o&65535)){V=(H-o&65535)+U&65535}else{V=U}b[(c[277218]|0)+(A<<1)>>1]=V;a[(c[277219]|0)+A|0]=a[1108909]|0}}while(0);A=x-1&255;if(A<<24>>24!=0){y=A;u=1206}}if((u|0)==1206){u=0;A=m+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+A|0]|0)){o=a[r+6|0]|0;if(o<<24>>24==0){break}H=b[(c[277225]|0)+((o&255)<<1)>>1]|0;if((a[(c[277215]|0)+A|0]&32)==0){W=c[277228]&65535}else{W=b[(c[277213]|0)+(A<<1)>>1]|0}o=H&-2048;D=W&-2048;C=(o&65535)>(D&65535)?o-D&65535:0;D=H&2016;o=W&2016;if((D&65535)>(o&65535)){X=(D-o&65535)+C&65535}else{X=C}C=H&31;H=W&31;if((C&65535)>(H&65535)){Y=(C-H&65535)+X&65535}else{Y=X}b[(c[277218]|0)+(A<<1)>>1]=Y;a[(c[277219]|0)+A|0]=a[1108909]|0}}while(0);if(y<<24>>24!=1){u=1217}}do{if((u|0)==1217){u=0;A=m+7|0;if((d[1108908]|0)<=(d[(c[277219]|0)+A|0]|0)){break}H=a[r+7|0]|0;if(H<<24>>24==0){break}C=b[(c[277225]|0)+((H&255)<<1)>>1]|0;if((a[(c[277215]|0)+A|0]&32)==0){Z=c[277228]&65535}else{Z=b[(c[277213]|0)+(A<<1)>>1]|0}H=C&-2048;o=Z&-2048;D=(H&65535)>(o&65535)?H-o&65535:0;o=C&2016;H=Z&2016;if((o&65535)>(H&65535)){_=(o-H&65535)+D&65535}else{_=D}D=C&31;C=Z&31;if((D&65535)>(C&65535)){$=(D-C&65535)+_&65535}else{$=_}b[(c[277218]|0)+(A<<1)>>1]=$;a[(c[277219]|0)+A|0]=a[1108909]|0}}while(0);A=p-1|0;if((A|0)>0){r=r+8|0;p=A;m=(c[277223]|0)+m|0}else{break}}return}if((e&32768|0)==0){if((j|0)<=0){return}e=h&255;m=e-1&255;p=m<<24>>24==0;r=q+i|0;$=j;_=f;while(1){switch(g|0){case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+_|0]|0)){Z=a[r+7|0]|0;if(Z<<24>>24==0){break}y=b[(c[277225]|0)+((Z&255)<<1)>>1]|0;if((a[(c[277215]|0)+_|0]&32)==0){aa=c[277228]&65535}else{aa=b[(c[277213]|0)+(_<<1)>>1]|0}Z=y&-2048;Y=aa&-2048;X=(Z&65535)>(Y&65535)?Z-Y&65535:0;Y=y&2016;Z=aa&2016;if((Y&65535)>(Z&65535)){ab=(Y-Z&65535)+X&65535}else{ab=X}X=y&31;y=aa&31;if((X&65535)>(y&65535)){ac=(X-y&65535)+ab&65535}else{ac=ab}b[(c[277218]|0)+(_<<1)>>1]=ac;a[(c[277219]|0)+_|0]=a[1108909]|0}}while(0);if(!p){ad=m;u=1243}break};case 1:{ad=e;u=1243;break};case 6:{ae=e;u=1298;break};case 7:{u=1309;break};case 2:{af=e;u=1254;break};case 3:{ag=e;u=1265;break};case 4:{ah=e;u=1276;break};case 5:{ai=e;u=1287;break};default:{}}if((u|0)==1243){u=0;y=_+1|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+y|0]|0)){X=a[r+6|0]|0;if(X<<24>>24==0){break}Z=b[(c[277225]|0)+((X&255)<<1)>>1]|0;if((a[(c[277215]|0)+y|0]&32)==0){aj=c[277228]&65535}else{aj=b[(c[277213]|0)+(y<<1)>>1]|0}X=Z&-2048;Y=aj&-2048;W=(X&65535)>(Y&65535)?X-Y&65535:0;Y=Z&2016;X=aj&2016;if((Y&65535)>(X&65535)){ak=(Y-X&65535)+W&65535}else{ak=W}W=Z&31;Z=aj&31;if((W&65535)>(Z&65535)){al=(W-Z&65535)+ak&65535}else{al=ak}b[(c[277218]|0)+(y<<1)>>1]=al;a[(c[277219]|0)+y|0]=a[1108909]|0}}while(0);y=ad-1&255;if(y<<24>>24!=0){af=y;u=1254}}if((u|0)==1254){u=0;y=_+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+y|0]|0)){Z=a[r+5|0]|0;if(Z<<24>>24==0){break}W=b[(c[277225]|0)+((Z&255)<<1)>>1]|0;if((a[(c[277215]|0)+y|0]&32)==0){am=c[277228]&65535}else{am=b[(c[277213]|0)+(y<<1)>>1]|0}Z=W&-2048;X=am&-2048;Y=(Z&65535)>(X&65535)?Z-X&65535:0;X=W&2016;Z=am&2016;if((X&65535)>(Z&65535)){an=(X-Z&65535)+Y&65535}else{an=Y}Y=W&31;W=am&31;if((Y&65535)>(W&65535)){ao=(Y-W&65535)+an&65535}else{ao=an}b[(c[277218]|0)+(y<<1)>>1]=ao;a[(c[277219]|0)+y|0]=a[1108909]|0}}while(0);y=af-1&255;if(y<<24>>24!=0){ag=y;u=1265}}if((u|0)==1265){u=0;y=_+3|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+y|0]|0)){W=a[r+4|0]|0;if(W<<24>>24==0){break}Y=b[(c[277225]|0)+((W&255)<<1)>>1]|0;if((a[(c[277215]|0)+y|0]&32)==0){ap=c[277228]&65535}else{ap=b[(c[277213]|0)+(y<<1)>>1]|0}W=Y&-2048;Z=ap&-2048;X=(W&65535)>(Z&65535)?W-Z&65535:0;Z=Y&2016;W=ap&2016;if((Z&65535)>(W&65535)){aq=(Z-W&65535)+X&65535}else{aq=X}X=Y&31;Y=ap&31;if((X&65535)>(Y&65535)){ar=(X-Y&65535)+aq&65535}else{ar=aq}b[(c[277218]|0)+(y<<1)>>1]=ar;a[(c[277219]|0)+y|0]=a[1108909]|0}}while(0);y=ag-1&255;if(y<<24>>24!=0){ah=y;u=1276}}if((u|0)==1276){u=0;y=_+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+y|0]|0)){Y=a[r+3|0]|0;if(Y<<24>>24==0){break}X=b[(c[277225]|0)+((Y&255)<<1)>>1]|0;if((a[(c[277215]|0)+y|0]&32)==0){as=c[277228]&65535}else{as=b[(c[277213]|0)+(y<<1)>>1]|0}Y=X&-2048;W=as&-2048;Z=(Y&65535)>(W&65535)?Y-W&65535:0;W=X&2016;Y=as&2016;if((W&65535)>(Y&65535)){at=(W-Y&65535)+Z&65535}else{at=Z}Z=X&31;X=as&31;if((Z&65535)>(X&65535)){au=(Z-X&65535)+at&65535}else{au=at}b[(c[277218]|0)+(y<<1)>>1]=au;a[(c[277219]|0)+y|0]=a[1108909]|0}}while(0);y=ah-1&255;if(y<<24>>24!=0){ai=y;u=1287}}if((u|0)==1287){u=0;y=_+5|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+y|0]|0)){X=a[r+2|0]|0;if(X<<24>>24==0){break}Z=b[(c[277225]|0)+((X&255)<<1)>>1]|0;if((a[(c[277215]|0)+y|0]&32)==0){av=c[277228]&65535}else{av=b[(c[277213]|0)+(y<<1)>>1]|0}X=Z&-2048;Y=av&-2048;W=(X&65535)>(Y&65535)?X-Y&65535:0;Y=Z&2016;X=av&2016;if((Y&65535)>(X&65535)){aw=(Y-X&65535)+W&65535}else{aw=W}W=Z&31;Z=av&31;if((W&65535)>(Z&65535)){ax=(W-Z&65535)+aw&65535}else{ax=aw}b[(c[277218]|0)+(y<<1)>>1]=ax;a[(c[277219]|0)+y|0]=a[1108909]|0}}while(0);y=ai-1&255;if(y<<24>>24!=0){ae=y;u=1298}}if((u|0)==1298){u=0;y=_+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+y|0]|0)){Z=a[r+1|0]|0;if(Z<<24>>24==0){break}W=b[(c[277225]|0)+((Z&255)<<1)>>1]|0;if((a[(c[277215]|0)+y|0]&32)==0){ay=c[277228]&65535}else{ay=b[(c[277213]|0)+(y<<1)>>1]|0}Z=W&-2048;X=ay&-2048;Y=(Z&65535)>(X&65535)?Z-X&65535:0;X=W&2016;Z=ay&2016;if((X&65535)>(Z&65535)){az=(X-Z&65535)+Y&65535}else{az=Y}Y=W&31;W=ay&31;if((Y&65535)>(W&65535)){aA=(Y-W&65535)+az&65535}else{aA=az}b[(c[277218]|0)+(y<<1)>>1]=aA;a[(c[277219]|0)+y|0]=a[1108909]|0}}while(0);if(ae<<24>>24!=1){u=1309}}do{if((u|0)==1309){u=0;y=_+7|0;if((d[1108908]|0)<=(d[(c[277219]|0)+y|0]|0)){break}W=a[r]|0;if(W<<24>>24==0){break}Y=b[(c[277225]|0)+((W&255)<<1)>>1]|0;if((a[(c[277215]|0)+y|0]&32)==0){aB=c[277228]&65535}else{aB=b[(c[277213]|0)+(y<<1)>>1]|0}W=Y&-2048;Z=aB&-2048;X=(W&65535)>(Z&65535)?W-Z&65535:0;Z=Y&2016;W=aB&2016;if((Z&65535)>(W&65535)){aC=(Z-W&65535)+X&65535}else{aC=X}X=Y&31;Y=aB&31;if((X&65535)>(Y&65535)){aD=(X-Y&65535)+aC&65535}else{aD=aC}b[(c[277218]|0)+(y<<1)>>1]=aD;a[(c[277219]|0)+y|0]=a[1108909]|0}}while(0);y=$-1|0;if((y|0)>0){r=r+8|0;$=y;_=(c[277223]|0)+_|0}else{break}}return}_=q+(56-i)|0;i=(j|0)>0;if(l){if(!i){return}l=h&255;q=l-1&255;$=q<<24>>24==0;r=_;aD=j;aC=f;while(1){switch(g|0){case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+aC|0]|0)){aB=a[r+7|0]|0;if(aB<<24>>24==0){break}ae=b[(c[277225]|0)+((aB&255)<<1)>>1]|0;if((a[(c[277215]|0)+aC|0]&32)==0){aE=c[277228]&65535}else{aE=b[(c[277213]|0)+(aC<<1)>>1]|0}aB=ae&-2048;aA=aE&-2048;az=(aB&65535)>(aA&65535)?aB-aA&65535:0;aA=ae&2016;aB=aE&2016;if((aA&65535)>(aB&65535)){aF=(aA-aB&65535)+az&65535}else{aF=az}az=ae&31;ae=aE&31;if((az&65535)>(ae&65535)){aG=(az-ae&65535)+aF&65535}else{aG=aF}b[(c[277218]|0)+(aC<<1)>>1]=aG;a[(c[277219]|0)+aC|0]=a[1108909]|0}}while(0);if(!$){aH=q;u=1426}break};case 1:{aH=l;u=1426;break};case 2:{aI=l;u=1437;break};case 3:{aJ=l;u=1448;break};case 4:{aK=l;u=1459;break};case 5:{aL=l;u=1470;break};case 6:{aM=l;u=1481;break};case 7:{u=1492;break};default:{}}if((u|0)==1426){u=0;ae=aC+1|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+ae|0]|0)){az=a[r+6|0]|0;if(az<<24>>24==0){break}aB=b[(c[277225]|0)+((az&255)<<1)>>1]|0;if((a[(c[277215]|0)+ae|0]&32)==0){aN=c[277228]&65535}else{aN=b[(c[277213]|0)+(ae<<1)>>1]|0}az=aB&-2048;aA=aN&-2048;ay=(az&65535)>(aA&65535)?az-aA&65535:0;aA=aB&2016;az=aN&2016;if((aA&65535)>(az&65535)){aO=(aA-az&65535)+ay&65535}else{aO=ay}ay=aB&31;aB=aN&31;if((ay&65535)>(aB&65535)){aP=(ay-aB&65535)+aO&65535}else{aP=aO}b[(c[277218]|0)+(ae<<1)>>1]=aP;a[(c[277219]|0)+ae|0]=a[1108909]|0}}while(0);ae=aH-1&255;if(ae<<24>>24!=0){aI=ae;u=1437}}if((u|0)==1437){u=0;ae=aC+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+ae|0]|0)){aB=a[r+5|0]|0;if(aB<<24>>24==0){break}ay=b[(c[277225]|0)+((aB&255)<<1)>>1]|0;if((a[(c[277215]|0)+ae|0]&32)==0){aQ=c[277228]&65535}else{aQ=b[(c[277213]|0)+(ae<<1)>>1]|0}aB=ay&-2048;az=aQ&-2048;aA=(aB&65535)>(az&65535)?aB-az&65535:0;az=ay&2016;aB=aQ&2016;if((az&65535)>(aB&65535)){aR=(az-aB&65535)+aA&65535}else{aR=aA}aA=ay&31;ay=aQ&31;if((aA&65535)>(ay&65535)){aS=(aA-ay&65535)+aR&65535}else{aS=aR}b[(c[277218]|0)+(ae<<1)>>1]=aS;a[(c[277219]|0)+ae|0]=a[1108909]|0}}while(0);ae=aI-1&255;if(ae<<24>>24!=0){aJ=ae;u=1448}}if((u|0)==1448){u=0;ae=aC+3|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+ae|0]|0)){ay=a[r+4|0]|0;if(ay<<24>>24==0){break}aA=b[(c[277225]|0)+((ay&255)<<1)>>1]|0;if((a[(c[277215]|0)+ae|0]&32)==0){aT=c[277228]&65535}else{aT=b[(c[277213]|0)+(ae<<1)>>1]|0}ay=aA&-2048;aB=aT&-2048;az=(ay&65535)>(aB&65535)?ay-aB&65535:0;aB=aA&2016;ay=aT&2016;if((aB&65535)>(ay&65535)){aU=(aB-ay&65535)+az&65535}else{aU=az}az=aA&31;aA=aT&31;if((az&65535)>(aA&65535)){aV=(az-aA&65535)+aU&65535}else{aV=aU}b[(c[277218]|0)+(ae<<1)>>1]=aV;a[(c[277219]|0)+ae|0]=a[1108909]|0}}while(0);ae=aJ-1&255;if(ae<<24>>24!=0){aK=ae;u=1459}}if((u|0)==1459){u=0;ae=aC+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+ae|0]|0)){aA=a[r+3|0]|0;if(aA<<24>>24==0){break}az=b[(c[277225]|0)+((aA&255)<<1)>>1]|0;if((a[(c[277215]|0)+ae|0]&32)==0){aW=c[277228]&65535}else{aW=b[(c[277213]|0)+(ae<<1)>>1]|0}aA=az&-2048;ay=aW&-2048;aB=(aA&65535)>(ay&65535)?aA-ay&65535:0;ay=az&2016;aA=aW&2016;if((ay&65535)>(aA&65535)){aX=(ay-aA&65535)+aB&65535}else{aX=aB}aB=az&31;az=aW&31;if((aB&65535)>(az&65535)){aY=(aB-az&65535)+aX&65535}else{aY=aX}b[(c[277218]|0)+(ae<<1)>>1]=aY;a[(c[277219]|0)+ae|0]=a[1108909]|0}}while(0);ae=aK-1&255;if(ae<<24>>24!=0){aL=ae;u=1470}}if((u|0)==1470){u=0;ae=aC+5|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+ae|0]|0)){az=a[r+2|0]|0;if(az<<24>>24==0){break}aB=b[(c[277225]|0)+((az&255)<<1)>>1]|0;if((a[(c[277215]|0)+ae|0]&32)==0){aZ=c[277228]&65535}else{aZ=b[(c[277213]|0)+(ae<<1)>>1]|0}az=aB&-2048;aA=aZ&-2048;ay=(az&65535)>(aA&65535)?az-aA&65535:0;aA=aB&2016;az=aZ&2016;if((aA&65535)>(az&65535)){a_=(aA-az&65535)+ay&65535}else{a_=ay}ay=aB&31;aB=aZ&31;if((ay&65535)>(aB&65535)){a$=(ay-aB&65535)+a_&65535}else{a$=a_}b[(c[277218]|0)+(ae<<1)>>1]=a$;a[(c[277219]|0)+ae|0]=a[1108909]|0}}while(0);ae=aL-1&255;if(ae<<24>>24!=0){aM=ae;u=1481}}if((u|0)==1481){u=0;ae=aC+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+ae|0]|0)){aB=a[r+1|0]|0;if(aB<<24>>24==0){break}ay=b[(c[277225]|0)+((aB&255)<<1)>>1]|0;if((a[(c[277215]|0)+ae|0]&32)==0){a0=c[277228]&65535}else{a0=b[(c[277213]|0)+(ae<<1)>>1]|0}aB=ay&-2048;az=a0&-2048;aA=(aB&65535)>(az&65535)?aB-az&65535:0;az=ay&2016;aB=a0&2016;if((az&65535)>(aB&65535)){a1=(az-aB&65535)+aA&65535}else{a1=aA}aA=ay&31;ay=a0&31;if((aA&65535)>(ay&65535)){a2=(aA-ay&65535)+a1&65535}else{a2=a1}b[(c[277218]|0)+(ae<<1)>>1]=a2;a[(c[277219]|0)+ae|0]=a[1108909]|0}}while(0);if(aM<<24>>24!=1){u=1492}}do{if((u|0)==1492){u=0;ae=aC+7|0;if((d[1108908]|0)<=(d[(c[277219]|0)+ae|0]|0)){break}ay=a[r]|0;if(ay<<24>>24==0){break}aA=b[(c[277225]|0)+((ay&255)<<1)>>1]|0;if((a[(c[277215]|0)+ae|0]&32)==0){a3=c[277228]&65535}else{a3=b[(c[277213]|0)+(ae<<1)>>1]|0}ay=aA&-2048;aB=a3&-2048;az=(ay&65535)>(aB&65535)?ay-aB&65535:0;aB=aA&2016;ay=a3&2016;if((aB&65535)>(ay&65535)){a4=(aB-ay&65535)+az&65535}else{a4=az}az=aA&31;aA=a3&31;if((az&65535)>(aA&65535)){a5=(az-aA&65535)+a4&65535}else{a5=a4}b[(c[277218]|0)+(ae<<1)>>1]=a5;a[(c[277219]|0)+ae|0]=a[1108909]|0}}while(0);ae=aD-1|0;if((ae|0)>0){r=r-8|0;aD=ae;aC=(c[277223]|0)+aC|0}else{break}}return}else{if(!i){return}i=h&255;h=i-1&255;aC=h<<24>>24==0;aD=_;_=j;j=f;while(1){switch(g|0){case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+j|0]|0)){f=a[aD]|0;if(f<<24>>24==0){break}r=b[(c[277225]|0)+((f&255)<<1)>>1]|0;if((a[(c[277215]|0)+j|0]&32)==0){a6=c[277228]&65535}else{a6=b[(c[277213]|0)+(j<<1)>>1]|0}f=r&-2048;a5=a6&-2048;a4=(f&65535)>(a5&65535)?f-a5&65535:0;a5=r&2016;f=a6&2016;if((a5&65535)>(f&65535)){a7=(a5-f&65535)+a4&65535}else{a7=a4}a4=r&31;r=a6&31;if((a4&65535)>(r&65535)){a8=(a4-r&65535)+a7&65535}else{a8=a7}b[(c[277218]|0)+(j<<1)>>1]=a8;a[(c[277219]|0)+j|0]=a[1108909]|0}}while(0);if(!aC){a9=h;u=1337}break};case 1:{a9=i;u=1337;break};case 6:{ba=i;u=1392;break};case 7:{u=1403;break};case 2:{bb=i;u=1348;break};case 3:{bc=i;u=1359;break};case 4:{bd=i;u=1370;break};case 5:{be=i;u=1381;break};default:{}}if((u|0)==1337){u=0;r=j+1|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+r|0]|0)){a4=a[aD+1|0]|0;if(a4<<24>>24==0){break}f=b[(c[277225]|0)+((a4&255)<<1)>>1]|0;if((a[(c[277215]|0)+r|0]&32)==0){bf=c[277228]&65535}else{bf=b[(c[277213]|0)+(r<<1)>>1]|0}a4=f&-2048;a5=bf&-2048;a3=(a4&65535)>(a5&65535)?a4-a5&65535:0;a5=f&2016;a4=bf&2016;if((a5&65535)>(a4&65535)){bg=(a5-a4&65535)+a3&65535}else{bg=a3}a3=f&31;f=bf&31;if((a3&65535)>(f&65535)){bh=(a3-f&65535)+bg&65535}else{bh=bg}b[(c[277218]|0)+(r<<1)>>1]=bh;a[(c[277219]|0)+r|0]=a[1108909]|0}}while(0);r=a9-1&255;if(r<<24>>24!=0){bb=r;u=1348}}if((u|0)==1348){u=0;r=j+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+r|0]|0)){f=a[aD+2|0]|0;if(f<<24>>24==0){break}a3=b[(c[277225]|0)+((f&255)<<1)>>1]|0;if((a[(c[277215]|0)+r|0]&32)==0){bi=c[277228]&65535}else{bi=b[(c[277213]|0)+(r<<1)>>1]|0}f=a3&-2048;a4=bi&-2048;a5=(f&65535)>(a4&65535)?f-a4&65535:0;a4=a3&2016;f=bi&2016;if((a4&65535)>(f&65535)){bj=(a4-f&65535)+a5&65535}else{bj=a5}a5=a3&31;a3=bi&31;if((a5&65535)>(a3&65535)){bk=(a5-a3&65535)+bj&65535}else{bk=bj}b[(c[277218]|0)+(r<<1)>>1]=bk;a[(c[277219]|0)+r|0]=a[1108909]|0}}while(0);r=bb-1&255;if(r<<24>>24!=0){bc=r;u=1359}}if((u|0)==1359){u=0;r=j+3|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+r|0]|0)){a3=a[aD+3|0]|0;if(a3<<24>>24==0){break}a5=b[(c[277225]|0)+((a3&255)<<1)>>1]|0;if((a[(c[277215]|0)+r|0]&32)==0){bl=c[277228]&65535}else{bl=b[(c[277213]|0)+(r<<1)>>1]|0}a3=a5&-2048;f=bl&-2048;a4=(a3&65535)>(f&65535)?a3-f&65535:0;f=a5&2016;a3=bl&2016;if((f&65535)>(a3&65535)){bm=(f-a3&65535)+a4&65535}else{bm=a4}a4=a5&31;a5=bl&31;if((a4&65535)>(a5&65535)){bn=(a4-a5&65535)+bm&65535}else{bn=bm}b[(c[277218]|0)+(r<<1)>>1]=bn;a[(c[277219]|0)+r|0]=a[1108909]|0}}while(0);r=bc-1&255;if(r<<24>>24!=0){bd=r;u=1370}}if((u|0)==1370){u=0;r=j+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+r|0]|0)){a5=a[aD+4|0]|0;if(a5<<24>>24==0){break}a4=b[(c[277225]|0)+((a5&255)<<1)>>1]|0;if((a[(c[277215]|0)+r|0]&32)==0){bo=c[277228]&65535}else{bo=b[(c[277213]|0)+(r<<1)>>1]|0}a5=a4&-2048;a3=bo&-2048;f=(a5&65535)>(a3&65535)?a5-a3&65535:0;a3=a4&2016;a5=bo&2016;if((a3&65535)>(a5&65535)){bp=(a3-a5&65535)+f&65535}else{bp=f}f=a4&31;a4=bo&31;if((f&65535)>(a4&65535)){bq=(f-a4&65535)+bp&65535}else{bq=bp}b[(c[277218]|0)+(r<<1)>>1]=bq;a[(c[277219]|0)+r|0]=a[1108909]|0}}while(0);r=bd-1&255;if(r<<24>>24!=0){be=r;u=1381}}if((u|0)==1381){u=0;r=j+5|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+r|0]|0)){a4=a[aD+5|0]|0;if(a4<<24>>24==0){break}f=b[(c[277225]|0)+((a4&255)<<1)>>1]|0;if((a[(c[277215]|0)+r|0]&32)==0){br=c[277228]&65535}else{br=b[(c[277213]|0)+(r<<1)>>1]|0}a4=f&-2048;a5=br&-2048;a3=(a4&65535)>(a5&65535)?a4-a5&65535:0;a5=f&2016;a4=br&2016;if((a5&65535)>(a4&65535)){bs=(a5-a4&65535)+a3&65535}else{bs=a3}a3=f&31;f=br&31;if((a3&65535)>(f&65535)){bt=(a3-f&65535)+bs&65535}else{bt=bs}b[(c[277218]|0)+(r<<1)>>1]=bt;a[(c[277219]|0)+r|0]=a[1108909]|0}}while(0);r=be-1&255;if(r<<24>>24!=0){ba=r;u=1392}}if((u|0)==1392){u=0;r=j+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+r|0]|0)){f=a[aD+6|0]|0;if(f<<24>>24==0){break}a3=b[(c[277225]|0)+((f&255)<<1)>>1]|0;if((a[(c[277215]|0)+r|0]&32)==0){bu=c[277228]&65535}else{bu=b[(c[277213]|0)+(r<<1)>>1]|0}f=a3&-2048;a4=bu&-2048;a5=(f&65535)>(a4&65535)?f-a4&65535:0;a4=a3&2016;f=bu&2016;if((a4&65535)>(f&65535)){bv=(a4-f&65535)+a5&65535}else{bv=a5}a5=a3&31;a3=bu&31;if((a5&65535)>(a3&65535)){bw=(a5-a3&65535)+bv&65535}else{bw=bv}b[(c[277218]|0)+(r<<1)>>1]=bw;a[(c[277219]|0)+r|0]=a[1108909]|0}}while(0);if(ba<<24>>24!=1){u=1403}}do{if((u|0)==1403){u=0;r=j+7|0;if((d[1108908]|0)<=(d[(c[277219]|0)+r|0]|0)){break}a3=a[aD+7|0]|0;if(a3<<24>>24==0){break}a5=b[(c[277225]|0)+((a3&255)<<1)>>1]|0;if((a[(c[277215]|0)+r|0]&32)==0){bx=c[277228]&65535}else{bx=b[(c[277213]|0)+(r<<1)>>1]|0}a3=a5&-2048;f=bx&-2048;a4=(a3&65535)>(f&65535)?a3-f&65535:0;f=a5&2016;a3=bx&2016;if((f&65535)>(a3&65535)){by=(f-a3&65535)+a4&65535}else{by=a4}a4=a5&31;a5=bx&31;if((a4&65535)>(a5&65535)){bz=(a4-a5&65535)+by&65535}else{bz=by}b[(c[277218]|0)+(r<<1)>>1]=bz;a[(c[277219]|0)+r|0]=a[1108909]|0}}while(0);r=_-1|0;if((r|0)>0){aD=aD-8|0;_=r;j=(c[277223]|0)+j|0}else{break}}return}}function Xp(e,f,g,h,i,j){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0;k=e&1023;l=c[348606]|0;m=(k<<l)+(c[348604]|0)|0;if((e&256|0)==0){n=m}else{n=(c[348602]|0)+m|0}m=n&65535;n=m>>>(l>>>0);l=(e&16384|0)!=0;o=n<<6;do{if(l){p=(c[348622]|0)+o|0;if((a[(c[348618]|0)+n|0]|0)!=0){q=p;break}r=fi[c[348636]&63](p,m,k)|0;a[(c[348618]|0)+n|0]=r;q=p}else{p=(c[348624]|0)+o|0;if((a[(c[348620]|0)+n|0]|0)!=0){q=p;break}r=fi[c[348638]&63](p,m,k)|0;a[(c[348620]|0)+n|0]=r;q=p}}while(0);if((a[(c[348620]|0)+n|0]|0)==2){return}if((a[1394464]|0)==0){s=1106168+((e>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){n=d[1044485]|0;c[276541]=7080+(n<<5);k=0;do{m=k<<1&2;o=k&2;p=k&4;r=0;do{b[1125528+(k<<9)+(r<<1)>>1]=d[(r>>>1&28|o)+(7080+(n<<5))|0]<<6|d[(r<<2&28|m)+(7080+(n<<5))|0]<<11|d[(r>>>3&24|p)+(7080+(n<<5))|0];r=r+1|0;}while(r>>>0<256);k=k+1|0;}while(k>>>0<8);a[1106089]=0}s=1125528+((e>>>10&7)<<9)|0}c[277226]=s;c[277225]=(a[1108928]|0)!=0?1393712:s;if((e&49152|0)==0){if((j|0)<=0){return}s=h&255;k=s-1&255;n=k<<24>>24==0;r=q+i|0;p=j;m=f;while(1){switch(g|0){case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+m|0]|0)){o=a[r]|0;if(o<<24>>24==0){break}t=b[(c[277225]|0)+((o&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){u=b[(c[277221]|0)+(((t&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{o=c[277228]&65535;v=t&-2048;w=o&-2048;x=(v&65535)>(w&65535)?v-w&65535:0;w=t&2016;v=o&2016;if((w&65535)>(v&65535)){y=(w-v&65535)+x&65535}else{y=x}x=t&31;v=o&31;if((x&65535)<=(v&65535)){u=y;break}u=(x-v&65535)+y&65535}}while(0);b[(c[277218]|0)+(m<<1)>>1]=u;a[(c[277219]|0)+m|0]=a[1108909]|0}}while(0);if(!n){z=k;A=1544}break};case 1:{z=s;A=1544;break};case 2:{B=s;A=1554;break};case 3:{C=s;A=1564;break};case 4:{D=s;A=1574;break};case 5:{E=s;A=1584;break};case 6:{F=s;A=1594;break};case 7:{A=1604;break};default:{}}if((A|0)==1544){A=0;t=m+1|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+t|0]|0)){v=a[r+1|0]|0;if(v<<24>>24==0){break}x=b[(c[277225]|0)+((v&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){G=b[(c[277221]|0)+(((x&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{v=c[277228]&65535;o=x&-2048;w=v&-2048;H=(o&65535)>(w&65535)?o-w&65535:0;w=x&2016;o=v&2016;if((w&65535)>(o&65535)){I=(w-o&65535)+H&65535}else{I=H}H=x&31;o=v&31;if((H&65535)<=(o&65535)){G=I;break}G=(H-o&65535)+I&65535}}while(0);b[(c[277218]|0)+(t<<1)>>1]=G;a[(c[277219]|0)+t|0]=a[1108909]|0}}while(0);t=z-1&255;if(t<<24>>24!=0){B=t;A=1554}}if((A|0)==1554){A=0;t=m+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+t|0]|0)){x=a[r+2|0]|0;if(x<<24>>24==0){break}o=b[(c[277225]|0)+((x&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){J=b[(c[277221]|0)+(((o&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{x=c[277228]&65535;H=o&-2048;v=x&-2048;w=(H&65535)>(v&65535)?H-v&65535:0;v=o&2016;H=x&2016;if((v&65535)>(H&65535)){K=(v-H&65535)+w&65535}else{K=w}w=o&31;H=x&31;if((w&65535)<=(H&65535)){J=K;break}J=(w-H&65535)+K&65535}}while(0);b[(c[277218]|0)+(t<<1)>>1]=J;a[(c[277219]|0)+t|0]=a[1108909]|0}}while(0);t=B-1&255;if(t<<24>>24!=0){C=t;A=1564}}if((A|0)==1564){A=0;t=m+3|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+t|0]|0)){o=a[r+3|0]|0;if(o<<24>>24==0){break}H=b[(c[277225]|0)+((o&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){L=b[(c[277221]|0)+(((H&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{o=c[277228]&65535;w=H&-2048;x=o&-2048;v=(w&65535)>(x&65535)?w-x&65535:0;x=H&2016;w=o&2016;if((x&65535)>(w&65535)){M=(x-w&65535)+v&65535}else{M=v}v=H&31;w=o&31;if((v&65535)<=(w&65535)){L=M;break}L=(v-w&65535)+M&65535}}while(0);b[(c[277218]|0)+(t<<1)>>1]=L;a[(c[277219]|0)+t|0]=a[1108909]|0}}while(0);t=C-1&255;if(t<<24>>24!=0){D=t;A=1574}}if((A|0)==1574){A=0;t=m+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+t|0]|0)){H=a[r+4|0]|0;if(H<<24>>24==0){break}w=b[(c[277225]|0)+((H&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){N=b[(c[277221]|0)+(((w&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{H=c[277228]&65535;v=w&-2048;o=H&-2048;x=(v&65535)>(o&65535)?v-o&65535:0;o=w&2016;v=H&2016;if((o&65535)>(v&65535)){O=(o-v&65535)+x&65535}else{O=x}x=w&31;v=H&31;if((x&65535)<=(v&65535)){N=O;break}N=(x-v&65535)+O&65535}}while(0);b[(c[277218]|0)+(t<<1)>>1]=N;a[(c[277219]|0)+t|0]=a[1108909]|0}}while(0);t=D-1&255;if(t<<24>>24!=0){E=t;A=1584}}if((A|0)==1584){A=0;t=m+5|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+t|0]|0)){w=a[r+5|0]|0;if(w<<24>>24==0){break}v=b[(c[277225]|0)+((w&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){P=b[(c[277221]|0)+(((v&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{w=c[277228]&65535;x=v&-2048;H=w&-2048;o=(x&65535)>(H&65535)?x-H&65535:0;H=v&2016;x=w&2016;if((H&65535)>(x&65535)){Q=(H-x&65535)+o&65535}else{Q=o}o=v&31;x=w&31;if((o&65535)<=(x&65535)){P=Q;break}P=(o-x&65535)+Q&65535}}while(0);b[(c[277218]|0)+(t<<1)>>1]=P;a[(c[277219]|0)+t|0]=a[1108909]|0}}while(0);t=E-1&255;if(t<<24>>24!=0){F=t;A=1594}}if((A|0)==1594){A=0;t=m+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+t|0]|0)){v=a[r+6|0]|0;if(v<<24>>24==0){break}x=b[(c[277225]|0)+((v&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){R=b[(c[277221]|0)+(((x&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{v=c[277228]&65535;o=x&-2048;w=v&-2048;H=(o&65535)>(w&65535)?o-w&65535:0;w=x&2016;o=v&2016;if((w&65535)>(o&65535)){S=(w-o&65535)+H&65535}else{S=H}H=x&31;o=v&31;if((H&65535)<=(o&65535)){R=S;break}R=(H-o&65535)+S&65535}}while(0);b[(c[277218]|0)+(t<<1)>>1]=R;a[(c[277219]|0)+t|0]=a[1108909]|0}}while(0);if(F<<24>>24!=1){A=1604}}do{if((A|0)==1604){A=0;t=m+7|0;if((d[1108908]|0)<=(d[(c[277219]|0)+t|0]|0)){break}x=a[r+7|0]|0;if(x<<24>>24==0){break}o=b[(c[277225]|0)+((x&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){T=b[(c[277221]|0)+(((o&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{x=c[277228]&65535;H=o&-2048;v=x&-2048;w=(H&65535)>(v&65535)?H-v&65535:0;v=o&2016;H=x&2016;if((v&65535)>(H&65535)){U=(v-H&65535)+w&65535}else{U=w}w=o&31;H=x&31;if((w&65535)<=(H&65535)){T=U;break}T=(w-H&65535)+U&65535}}while(0);b[(c[277218]|0)+(t<<1)>>1]=T;a[(c[277219]|0)+t|0]=a[1108909]|0}}while(0);o=p-1|0;if((o|0)>0){r=r+8|0;p=o;m=(c[277223]|0)+m|0}else{break}}return}if((e&32768|0)==0){if((j|0)<=0){return}e=h&255;m=e-1&255;p=m<<24>>24==0;r=q+i|0;T=j;U=f;while(1){switch(g|0){case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+U|0]|0)){F=a[r+7|0]|0;if(F<<24>>24==0){break}R=b[(c[277225]|0)+((F&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){V=b[(c[277221]|0)+(((R&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{F=c[277228]&65535;S=R&-2048;E=F&-2048;P=(S&65535)>(E&65535)?S-E&65535:0;E=R&2016;S=F&2016;if((E&65535)>(S&65535)){W=(E-S&65535)+P&65535}else{W=P}P=R&31;S=F&31;if((P&65535)<=(S&65535)){V=W;break}V=(P-S&65535)+W&65535}}while(0);b[(c[277218]|0)+(U<<1)>>1]=V;a[(c[277219]|0)+U|0]=a[1108909]|0}}while(0);if(!p){X=m;A=1628}break};case 1:{X=e;A=1628;break};case 2:{Y=e;A=1638;break};case 3:{Z=e;A=1648;break};case 4:{_=e;A=1658;break};case 5:{$=e;A=1668;break};case 6:{aa=e;A=1678;break};case 7:{A=1688;break};default:{}}if((A|0)==1628){A=0;R=U+1|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+R|0]|0)){t=a[r+6|0]|0;if(t<<24>>24==0){break}S=b[(c[277225]|0)+((t&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){ab=b[(c[277221]|0)+(((S&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{t=c[277228]&65535;P=S&-2048;F=t&-2048;E=(P&65535)>(F&65535)?P-F&65535:0;F=S&2016;P=t&2016;if((F&65535)>(P&65535)){ac=(F-P&65535)+E&65535}else{ac=E}E=S&31;P=t&31;if((E&65535)<=(P&65535)){ab=ac;break}ab=(E-P&65535)+ac&65535}}while(0);b[(c[277218]|0)+(R<<1)>>1]=ab;a[(c[277219]|0)+R|0]=a[1108909]|0}}while(0);R=X-1&255;if(R<<24>>24!=0){Y=R;A=1638}}if((A|0)==1638){A=0;R=U+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+R|0]|0)){S=a[r+5|0]|0;if(S<<24>>24==0){break}P=b[(c[277225]|0)+((S&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){ad=b[(c[277221]|0)+(((P&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{S=c[277228]&65535;E=P&-2048;t=S&-2048;F=(E&65535)>(t&65535)?E-t&65535:0;t=P&2016;E=S&2016;if((t&65535)>(E&65535)){ae=(t-E&65535)+F&65535}else{ae=F}F=P&31;E=S&31;if((F&65535)<=(E&65535)){ad=ae;break}ad=(F-E&65535)+ae&65535}}while(0);b[(c[277218]|0)+(R<<1)>>1]=ad;a[(c[277219]|0)+R|0]=a[1108909]|0}}while(0);R=Y-1&255;if(R<<24>>24!=0){Z=R;A=1648}}if((A|0)==1648){A=0;R=U+3|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+R|0]|0)){P=a[r+4|0]|0;if(P<<24>>24==0){break}E=b[(c[277225]|0)+((P&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){af=b[(c[277221]|0)+(((E&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{P=c[277228]&65535;F=E&-2048;S=P&-2048;t=(F&65535)>(S&65535)?F-S&65535:0;S=E&2016;F=P&2016;if((S&65535)>(F&65535)){ag=(S-F&65535)+t&65535}else{ag=t}t=E&31;F=P&31;if((t&65535)<=(F&65535)){af=ag;break}af=(t-F&65535)+ag&65535}}while(0);b[(c[277218]|0)+(R<<1)>>1]=af;a[(c[277219]|0)+R|0]=a[1108909]|0}}while(0);R=Z-1&255;if(R<<24>>24!=0){_=R;A=1658}}if((A|0)==1658){A=0;R=U+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+R|0]|0)){E=a[r+3|0]|0;if(E<<24>>24==0){break}F=b[(c[277225]|0)+((E&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){ah=b[(c[277221]|0)+(((F&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{E=c[277228]&65535;t=F&-2048;P=E&-2048;S=(t&65535)>(P&65535)?t-P&65535:0;P=F&2016;t=E&2016;if((P&65535)>(t&65535)){ai=(P-t&65535)+S&65535}else{ai=S}S=F&31;t=E&31;if((S&65535)<=(t&65535)){ah=ai;break}ah=(S-t&65535)+ai&65535}}while(0);b[(c[277218]|0)+(R<<1)>>1]=ah;a[(c[277219]|0)+R|0]=a[1108909]|0}}while(0);R=_-1&255;if(R<<24>>24!=0){$=R;A=1668}}if((A|0)==1668){A=0;R=U+5|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+R|0]|0)){F=a[r+2|0]|0;if(F<<24>>24==0){break}t=b[(c[277225]|0)+((F&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aj=b[(c[277221]|0)+(((t&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{F=c[277228]&65535;S=t&-2048;E=F&-2048;P=(S&65535)>(E&65535)?S-E&65535:0;E=t&2016;S=F&2016;if((E&65535)>(S&65535)){ak=(E-S&65535)+P&65535}else{ak=P}P=t&31;S=F&31;if((P&65535)<=(S&65535)){aj=ak;break}aj=(P-S&65535)+ak&65535}}while(0);b[(c[277218]|0)+(R<<1)>>1]=aj;a[(c[277219]|0)+R|0]=a[1108909]|0}}while(0);R=$-1&255;if(R<<24>>24!=0){aa=R;A=1678}}if((A|0)==1678){A=0;R=U+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+R|0]|0)){t=a[r+1|0]|0;if(t<<24>>24==0){break}S=b[(c[277225]|0)+((t&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){al=b[(c[277221]|0)+(((S&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{t=c[277228]&65535;P=S&-2048;F=t&-2048;E=(P&65535)>(F&65535)?P-F&65535:0;F=S&2016;P=t&2016;if((F&65535)>(P&65535)){am=(F-P&65535)+E&65535}else{am=E}E=S&31;P=t&31;if((E&65535)<=(P&65535)){al=am;break}al=(E-P&65535)+am&65535}}while(0);b[(c[277218]|0)+(R<<1)>>1]=al;a[(c[277219]|0)+R|0]=a[1108909]|0}}while(0);if(aa<<24>>24!=1){A=1688}}do{if((A|0)==1688){A=0;R=U+7|0;if((d[1108908]|0)<=(d[(c[277219]|0)+R|0]|0)){break}S=a[r]|0;if(S<<24>>24==0){break}P=b[(c[277225]|0)+((S&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){an=b[(c[277221]|0)+(((P&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{S=c[277228]&65535;E=P&-2048;t=S&-2048;F=(E&65535)>(t&65535)?E-t&65535:0;t=P&2016;E=S&2016;if((t&65535)>(E&65535)){ao=(t-E&65535)+F&65535}else{ao=F}F=P&31;E=S&31;if((F&65535)<=(E&65535)){an=ao;break}an=(F-E&65535)+ao&65535}}while(0);b[(c[277218]|0)+(R<<1)>>1]=an;a[(c[277219]|0)+R|0]=a[1108909]|0}}while(0);P=T-1|0;if((P|0)>0){r=r+8|0;T=P;U=(c[277223]|0)+U|0}else{break}}return}U=q+(56-i)|0;i=(j|0)>0;if(l){if(!i){return}l=h&255;q=l-1&255;T=q<<24>>24==0;r=U;an=j;ao=f;while(1){switch(g|0){case 3:{ap=l;A=1815;break};case 4:{aq=l;A=1825;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+ao|0]|0)){aa=a[r+7|0]|0;if(aa<<24>>24==0){break}al=b[(c[277225]|0)+((aa&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){ar=b[(c[277221]|0)+(((al&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{aa=c[277228]&65535;am=al&-2048;$=aa&-2048;aj=(am&65535)>($&65535)?am-$&65535:0;$=al&2016;am=aa&2016;if(($&65535)>(am&65535)){as=($-am&65535)+aj&65535}else{as=aj}aj=al&31;am=aa&31;if((aj&65535)<=(am&65535)){ar=as;break}ar=(aj-am&65535)+as&65535}}while(0);b[(c[277218]|0)+(ao<<1)>>1]=ar;a[(c[277219]|0)+ao|0]=a[1108909]|0}}while(0);if(!T){at=q;A=1795}break};case 1:{at=l;A=1795;break};case 2:{au=l;A=1805;break};case 5:{av=l;A=1835;break};case 6:{aw=l;A=1845;break};case 7:{A=1855;break};default:{}}if((A|0)==1795){A=0;al=ao+1|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+al|0]|0)){R=a[r+6|0]|0;if(R<<24>>24==0){break}am=b[(c[277225]|0)+((R&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){ax=b[(c[277221]|0)+(((am&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{R=c[277228]&65535;aj=am&-2048;aa=R&-2048;$=(aj&65535)>(aa&65535)?aj-aa&65535:0;aa=am&2016;aj=R&2016;if((aa&65535)>(aj&65535)){ay=(aa-aj&65535)+$&65535}else{ay=$}$=am&31;aj=R&31;if(($&65535)<=(aj&65535)){ax=ay;break}ax=($-aj&65535)+ay&65535}}while(0);b[(c[277218]|0)+(al<<1)>>1]=ax;a[(c[277219]|0)+al|0]=a[1108909]|0}}while(0);al=at-1&255;if(al<<24>>24!=0){au=al;A=1805}}if((A|0)==1805){A=0;al=ao+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+al|0]|0)){am=a[r+5|0]|0;if(am<<24>>24==0){break}aj=b[(c[277225]|0)+((am&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){az=b[(c[277221]|0)+(((aj&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{am=c[277228]&65535;$=aj&-2048;R=am&-2048;aa=($&65535)>(R&65535)?$-R&65535:0;R=aj&2016;$=am&2016;if((R&65535)>($&65535)){aA=(R-$&65535)+aa&65535}else{aA=aa}aa=aj&31;$=am&31;if((aa&65535)<=($&65535)){az=aA;break}az=(aa-$&65535)+aA&65535}}while(0);b[(c[277218]|0)+(al<<1)>>1]=az;a[(c[277219]|0)+al|0]=a[1108909]|0}}while(0);al=au-1&255;if(al<<24>>24!=0){ap=al;A=1815}}if((A|0)==1815){A=0;al=ao+3|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+al|0]|0)){aj=a[r+4|0]|0;if(aj<<24>>24==0){break}$=b[(c[277225]|0)+((aj&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aB=b[(c[277221]|0)+((($&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{aj=c[277228]&65535;aa=$&-2048;am=aj&-2048;R=(aa&65535)>(am&65535)?aa-am&65535:0;am=$&2016;aa=aj&2016;if((am&65535)>(aa&65535)){aC=(am-aa&65535)+R&65535}else{aC=R}R=$&31;aa=aj&31;if((R&65535)<=(aa&65535)){aB=aC;break}aB=(R-aa&65535)+aC&65535}}while(0);b[(c[277218]|0)+(al<<1)>>1]=aB;a[(c[277219]|0)+al|0]=a[1108909]|0}}while(0);al=ap-1&255;if(al<<24>>24!=0){aq=al;A=1825}}if((A|0)==1825){A=0;al=ao+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+al|0]|0)){$=a[r+3|0]|0;if($<<24>>24==0){break}aa=b[(c[277225]|0)+(($&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aD=b[(c[277221]|0)+(((aa&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{$=c[277228]&65535;R=aa&-2048;aj=$&-2048;am=(R&65535)>(aj&65535)?R-aj&65535:0;aj=aa&2016;R=$&2016;if((aj&65535)>(R&65535)){aE=(aj-R&65535)+am&65535}else{aE=am}am=aa&31;R=$&31;if((am&65535)<=(R&65535)){aD=aE;break}aD=(am-R&65535)+aE&65535}}while(0);b[(c[277218]|0)+(al<<1)>>1]=aD;a[(c[277219]|0)+al|0]=a[1108909]|0}}while(0);al=aq-1&255;if(al<<24>>24!=0){av=al;A=1835}}if((A|0)==1835){A=0;al=ao+5|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+al|0]|0)){aa=a[r+2|0]|0;if(aa<<24>>24==0){break}R=b[(c[277225]|0)+((aa&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aF=b[(c[277221]|0)+(((R&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{aa=c[277228]&65535;am=R&-2048;$=aa&-2048;aj=(am&65535)>($&65535)?am-$&65535:0;$=R&2016;am=aa&2016;if(($&65535)>(am&65535)){aG=($-am&65535)+aj&65535}else{aG=aj}aj=R&31;am=aa&31;if((aj&65535)<=(am&65535)){aF=aG;break}aF=(aj-am&65535)+aG&65535}}while(0);b[(c[277218]|0)+(al<<1)>>1]=aF;a[(c[277219]|0)+al|0]=a[1108909]|0}}while(0);al=av-1&255;if(al<<24>>24!=0){aw=al;A=1845}}if((A|0)==1845){A=0;al=ao+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+al|0]|0)){R=a[r+1|0]|0;if(R<<24>>24==0){break}am=b[(c[277225]|0)+((R&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aH=b[(c[277221]|0)+(((am&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{R=c[277228]&65535;aj=am&-2048;aa=R&-2048;$=(aj&65535)>(aa&65535)?aj-aa&65535:0;aa=am&2016;aj=R&2016;if((aa&65535)>(aj&65535)){aI=(aa-aj&65535)+$&65535}else{aI=$}$=am&31;aj=R&31;if(($&65535)<=(aj&65535)){aH=aI;break}aH=($-aj&65535)+aI&65535}}while(0);b[(c[277218]|0)+(al<<1)>>1]=aH;a[(c[277219]|0)+al|0]=a[1108909]|0}}while(0);if(aw<<24>>24!=1){A=1855}}do{if((A|0)==1855){A=0;al=ao+7|0;if((d[1108908]|0)<=(d[(c[277219]|0)+al|0]|0)){break}am=a[r]|0;if(am<<24>>24==0){break}aj=b[(c[277225]|0)+((am&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aJ=b[(c[277221]|0)+(((aj&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{am=c[277228]&65535;$=aj&-2048;R=am&-2048;aa=($&65535)>(R&65535)?$-R&65535:0;R=aj&2016;$=am&2016;if((R&65535)>($&65535)){aK=(R-$&65535)+aa&65535}else{aK=aa}aa=aj&31;$=am&31;if((aa&65535)<=($&65535)){aJ=aK;break}aJ=(aa-$&65535)+aK&65535}}while(0);b[(c[277218]|0)+(al<<1)>>1]=aJ;a[(c[277219]|0)+al|0]=a[1108909]|0}}while(0);aj=an-1|0;if((aj|0)>0){r=r-8|0;an=aj;ao=(c[277223]|0)+ao|0}else{break}}return}else{if(!i){return}i=h&255;h=i-1&255;ao=h<<24>>24==0;an=U;U=j;j=f;while(1){switch(g|0){case 5:{aL=i;A=1754;break};case 6:{aM=i;A=1764;break};case 7:{A=1774;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+j|0]|0)){f=a[an]|0;if(f<<24>>24==0){break}r=b[(c[277225]|0)+((f&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aN=b[(c[277221]|0)+(((r&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{f=c[277228]&65535;aJ=r&-2048;aK=f&-2048;aw=(aJ&65535)>(aK&65535)?aJ-aK&65535:0;aK=r&2016;aJ=f&2016;if((aK&65535)>(aJ&65535)){aO=(aK-aJ&65535)+aw&65535}else{aO=aw}aw=r&31;aJ=f&31;if((aw&65535)<=(aJ&65535)){aN=aO;break}aN=(aw-aJ&65535)+aO&65535}}while(0);b[(c[277218]|0)+(j<<1)>>1]=aN;a[(c[277219]|0)+j|0]=a[1108909]|0}}while(0);if(!ao){aP=h;A=1714}break};case 1:{aP=i;A=1714;break};case 2:{aQ=i;A=1724;break};case 3:{aR=i;A=1734;break};case 4:{aS=i;A=1744;break};default:{}}if((A|0)==1714){A=0;r=j+1|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+r|0]|0)){al=a[an+1|0]|0;if(al<<24>>24==0){break}aJ=b[(c[277225]|0)+((al&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aT=b[(c[277221]|0)+(((aJ&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{al=c[277228]&65535;aw=aJ&-2048;f=al&-2048;aK=(aw&65535)>(f&65535)?aw-f&65535:0;f=aJ&2016;aw=al&2016;if((f&65535)>(aw&65535)){aU=(f-aw&65535)+aK&65535}else{aU=aK}aK=aJ&31;aw=al&31;if((aK&65535)<=(aw&65535)){aT=aU;break}aT=(aK-aw&65535)+aU&65535}}while(0);b[(c[277218]|0)+(r<<1)>>1]=aT;a[(c[277219]|0)+r|0]=a[1108909]|0}}while(0);r=aP-1&255;if(r<<24>>24!=0){aQ=r;A=1724}}if((A|0)==1724){A=0;r=j+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+r|0]|0)){aJ=a[an+2|0]|0;if(aJ<<24>>24==0){break}aw=b[(c[277225]|0)+((aJ&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aV=b[(c[277221]|0)+(((aw&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{aJ=c[277228]&65535;aK=aw&-2048;al=aJ&-2048;f=(aK&65535)>(al&65535)?aK-al&65535:0;al=aw&2016;aK=aJ&2016;if((al&65535)>(aK&65535)){aW=(al-aK&65535)+f&65535}else{aW=f}f=aw&31;aK=aJ&31;if((f&65535)<=(aK&65535)){aV=aW;break}aV=(f-aK&65535)+aW&65535}}while(0);b[(c[277218]|0)+(r<<1)>>1]=aV;a[(c[277219]|0)+r|0]=a[1108909]|0}}while(0);r=aQ-1&255;if(r<<24>>24!=0){aR=r;A=1734}}if((A|0)==1734){A=0;r=j+3|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+r|0]|0)){aw=a[an+3|0]|0;if(aw<<24>>24==0){break}aK=b[(c[277225]|0)+((aw&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aX=b[(c[277221]|0)+(((aK&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{aw=c[277228]&65535;f=aK&-2048;aJ=aw&-2048;al=(f&65535)>(aJ&65535)?f-aJ&65535:0;aJ=aK&2016;f=aw&2016;if((aJ&65535)>(f&65535)){aY=(aJ-f&65535)+al&65535}else{aY=al}al=aK&31;f=aw&31;if((al&65535)<=(f&65535)){aX=aY;break}aX=(al-f&65535)+aY&65535}}while(0);b[(c[277218]|0)+(r<<1)>>1]=aX;a[(c[277219]|0)+r|0]=a[1108909]|0}}while(0);r=aR-1&255;if(r<<24>>24!=0){aS=r;A=1744}}if((A|0)==1744){A=0;r=j+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+r|0]|0)){aK=a[an+4|0]|0;if(aK<<24>>24==0){break}f=b[(c[277225]|0)+((aK&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aZ=b[(c[277221]|0)+(((f&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{aK=c[277228]&65535;al=f&-2048;aw=aK&-2048;aJ=(al&65535)>(aw&65535)?al-aw&65535:0;aw=f&2016;al=aK&2016;if((aw&65535)>(al&65535)){a_=(aw-al&65535)+aJ&65535}else{a_=aJ}aJ=f&31;al=aK&31;if((aJ&65535)<=(al&65535)){aZ=a_;break}aZ=(aJ-al&65535)+a_&65535}}while(0);b[(c[277218]|0)+(r<<1)>>1]=aZ;a[(c[277219]|0)+r|0]=a[1108909]|0}}while(0);r=aS-1&255;if(r<<24>>24!=0){aL=r;A=1754}}if((A|0)==1754){A=0;r=j+5|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+r|0]|0)){f=a[an+5|0]|0;if(f<<24>>24==0){break}al=b[(c[277225]|0)+((f&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){a$=b[(c[277221]|0)+(((al&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{f=c[277228]&65535;aJ=al&-2048;aK=f&-2048;aw=(aJ&65535)>(aK&65535)?aJ-aK&65535:0;aK=al&2016;aJ=f&2016;if((aK&65535)>(aJ&65535)){a0=(aK-aJ&65535)+aw&65535}else{a0=aw}aw=al&31;aJ=f&31;if((aw&65535)<=(aJ&65535)){a$=a0;break}a$=(aw-aJ&65535)+a0&65535}}while(0);b[(c[277218]|0)+(r<<1)>>1]=a$;a[(c[277219]|0)+r|0]=a[1108909]|0}}while(0);r=aL-1&255;if(r<<24>>24!=0){aM=r;A=1764}}if((A|0)==1764){A=0;r=j+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+r|0]|0)){al=a[an+6|0]|0;if(al<<24>>24==0){break}aJ=b[(c[277225]|0)+((al&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){a1=b[(c[277221]|0)+(((aJ&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{al=c[277228]&65535;aw=aJ&-2048;f=al&-2048;aK=(aw&65535)>(f&65535)?aw-f&65535:0;f=aJ&2016;aw=al&2016;if((f&65535)>(aw&65535)){a2=(f-aw&65535)+aK&65535}else{a2=aK}aK=aJ&31;aw=al&31;if((aK&65535)<=(aw&65535)){a1=a2;break}a1=(aK-aw&65535)+a2&65535}}while(0);b[(c[277218]|0)+(r<<1)>>1]=a1;a[(c[277219]|0)+r|0]=a[1108909]|0}}while(0);if(aM<<24>>24!=1){A=1774}}do{if((A|0)==1774){A=0;r=j+7|0;if((d[1108908]|0)<=(d[(c[277219]|0)+r|0]|0)){break}aJ=a[an+7|0]|0;if(aJ<<24>>24==0){break}aw=b[(c[277225]|0)+((aJ&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){a3=b[(c[277221]|0)+(((aw&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{aJ=c[277228]&65535;aK=aw&-2048;al=aJ&-2048;f=(aK&65535)>(al&65535)?aK-al&65535:0;al=aw&2016;aK=aJ&2016;if((al&65535)>(aK&65535)){a4=(al-aK&65535)+f&65535}else{a4=f}f=aw&31;aK=aJ&31;if((f&65535)<=(aK&65535)){a3=a4;break}a3=(f-aK&65535)+a4&65535}}while(0);b[(c[277218]|0)+(r<<1)>>1]=a3;a[(c[277219]|0)+r|0]=a[1108909]|0}}while(0);aw=U-1|0;if((aw|0)>0){an=an-8|0;U=aw;j=(c[277223]|0)+j|0}else{break}}return}}function Xq(e,f,g,h,i,j){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0;k=e&1023;l=c[348606]|0;m=(k<<l)+(c[348604]|0)|0;if((e&256|0)==0){n=m}else{n=(c[348602]|0)+m|0}m=n&65535;n=m>>>(l>>>0);l=(e&16384|0)!=0;o=n<<6;do{if(l){p=(c[348622]|0)+o|0;if((a[(c[348618]|0)+n|0]|0)!=0){q=p;break}r=fi[c[348636]&63](p,m,k)|0;a[(c[348618]|0)+n|0]=r;q=p}else{p=(c[348624]|0)+o|0;if((a[(c[348620]|0)+n|0]|0)!=0){q=p;break}r=fi[c[348638]&63](p,m,k)|0;a[(c[348620]|0)+n|0]=r;q=p}}while(0);if((a[(c[348620]|0)+n|0]|0)==2){return}if((a[1394464]|0)==0){s=1106168+((e>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){n=d[1044485]|0;c[276541]=7080+(n<<5);k=0;do{m=k<<1&2;o=k&2;p=k&4;r=0;do{b[1125528+(k<<9)+(r<<1)>>1]=d[(r>>>1&28|o)+(7080+(n<<5))|0]<<6|d[(r<<2&28|m)+(7080+(n<<5))|0]<<11|d[(r>>>3&24|p)+(7080+(n<<5))|0];r=r+1|0;}while(r>>>0<256);k=k+1|0;}while(k>>>0<8);a[1106089]=0}s=1125528+((e>>>10&7)<<9)|0}c[277226]=s;c[277225]=(a[1108928]|0)!=0?1393712:s;if((e&49152|0)==0){if((j|0)<=0){return}s=h&255;k=s-1&255;n=k<<24>>24==0;r=q+i|0;p=j;m=f;while(1){switch(g|0){case 3:{t=s;u=1950;break};case 4:{v=s;u=1968;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+m|0]|0)){o=a[r]|0;w=o&255;if(o<<24>>24==0){break}do{if((a[1108928]|0)==0){o=b[(c[277225]|0)+(w<<1)>>1]|0;if((a[(c[277215]|0)+m|0]&32)!=0){x=b[(c[277221]|0)+((o&65535|67616)-(b[(c[277213]|0)+(m<<1)>>1]&63454)>>1<<1)>>1]|0;break}y=c[277228]&65535;z=o&-2048;A=y&-2048;B=(z&65535)>(A&65535)?z-A&65535:0;A=o&2016;z=y&2016;if((A&65535)>(z&65535)){C=(A-z&65535)+B&65535}else{C=B}B=o&31;o=y&31;if((B&65535)<=(o&65535)){x=C;break}x=(B-o&65535)+C&65535}else{o=b[(c[277225]|0)+(w<<1)>>1]|0;if((a[(c[277215]|0)+m|0]&32)==0){D=c[277228]&65535}else{D=b[(c[277213]|0)+(m<<1)>>1]|0}B=o&-2048;y=D&-2048;z=(B&65535)>(y&65535)?B-y&65535:0;y=o&2016;B=D&2016;if((y&65535)>(B&65535)){E=(y-B&65535)+z&65535}else{E=z}z=o&31;o=D&31;if((z&65535)<=(o&65535)){x=E;break}x=(z-o&65535)+E&65535}}while(0);b[(c[277218]|0)+(m<<1)>>1]=x;a[(c[277219]|0)+m|0]=a[1108909]|0}}while(0);if(!n){F=k;u=1914}break};case 7:{u=2022;break};case 2:{G=s;u=1932;break};case 5:{H=s;u=1986;break};case 1:{F=s;u=1914;break};case 6:{I=s;u=2004;break};default:{}}if((u|0)==1914){u=0;w=m+1|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+w|0]|0)){o=a[r+1|0]|0;z=o&255;if(o<<24>>24==0){break}do{if((a[1108928]|0)==0){o=b[(c[277225]|0)+(z<<1)>>1]|0;if((a[(c[277215]|0)+w|0]&32)!=0){J=b[(c[277221]|0)+((o&65535|67616)-(b[(c[277213]|0)+(w<<1)>>1]&63454)>>1<<1)>>1]|0;break}B=c[277228]&65535;y=o&-2048;A=B&-2048;K=(y&65535)>(A&65535)?y-A&65535:0;A=o&2016;y=B&2016;if((A&65535)>(y&65535)){L=(A-y&65535)+K&65535}else{L=K}K=o&31;o=B&31;if((K&65535)<=(o&65535)){J=L;break}J=(K-o&65535)+L&65535}else{o=b[(c[277225]|0)+(z<<1)>>1]|0;if((a[(c[277215]|0)+w|0]&32)==0){M=c[277228]&65535}else{M=b[(c[277213]|0)+(w<<1)>>1]|0}K=o&-2048;B=M&-2048;y=(K&65535)>(B&65535)?K-B&65535:0;B=o&2016;K=M&2016;if((B&65535)>(K&65535)){N=(B-K&65535)+y&65535}else{N=y}y=o&31;o=M&31;if((y&65535)<=(o&65535)){J=N;break}J=(y-o&65535)+N&65535}}while(0);b[(c[277218]|0)+(w<<1)>>1]=J;a[(c[277219]|0)+w|0]=a[1108909]|0}}while(0);w=F-1&255;if(w<<24>>24!=0){G=w;u=1932}}if((u|0)==1932){u=0;w=m+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+w|0]|0)){z=a[r+2|0]|0;o=z&255;if(z<<24>>24==0){break}do{if((a[1108928]|0)==0){z=b[(c[277225]|0)+(o<<1)>>1]|0;if((a[(c[277215]|0)+w|0]&32)!=0){O=b[(c[277221]|0)+((z&65535|67616)-(b[(c[277213]|0)+(w<<1)>>1]&63454)>>1<<1)>>1]|0;break}y=c[277228]&65535;K=z&-2048;B=y&-2048;A=(K&65535)>(B&65535)?K-B&65535:0;B=z&2016;K=y&2016;if((B&65535)>(K&65535)){P=(B-K&65535)+A&65535}else{P=A}A=z&31;z=y&31;if((A&65535)<=(z&65535)){O=P;break}O=(A-z&65535)+P&65535}else{z=b[(c[277225]|0)+(o<<1)>>1]|0;if((a[(c[277215]|0)+w|0]&32)==0){Q=c[277228]&65535}else{Q=b[(c[277213]|0)+(w<<1)>>1]|0}A=z&-2048;y=Q&-2048;K=(A&65535)>(y&65535)?A-y&65535:0;y=z&2016;A=Q&2016;if((y&65535)>(A&65535)){R=(y-A&65535)+K&65535}else{R=K}K=z&31;z=Q&31;if((K&65535)<=(z&65535)){O=R;break}O=(K-z&65535)+R&65535}}while(0);b[(c[277218]|0)+(w<<1)>>1]=O;a[(c[277219]|0)+w|0]=a[1108909]|0}}while(0);w=G-1&255;if(w<<24>>24!=0){t=w;u=1950}}if((u|0)==1950){u=0;w=m+3|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+w|0]|0)){o=a[r+3|0]|0;z=o&255;if(o<<24>>24==0){break}do{if((a[1108928]|0)==0){o=b[(c[277225]|0)+(z<<1)>>1]|0;if((a[(c[277215]|0)+w|0]&32)!=0){S=b[(c[277221]|0)+((o&65535|67616)-(b[(c[277213]|0)+(w<<1)>>1]&63454)>>1<<1)>>1]|0;break}K=c[277228]&65535;A=o&-2048;y=K&-2048;B=(A&65535)>(y&65535)?A-y&65535:0;y=o&2016;A=K&2016;if((y&65535)>(A&65535)){T=(y-A&65535)+B&65535}else{T=B}B=o&31;o=K&31;if((B&65535)<=(o&65535)){S=T;break}S=(B-o&65535)+T&65535}else{o=b[(c[277225]|0)+(z<<1)>>1]|0;if((a[(c[277215]|0)+w|0]&32)==0){U=c[277228]&65535}else{U=b[(c[277213]|0)+(w<<1)>>1]|0}B=o&-2048;K=U&-2048;A=(B&65535)>(K&65535)?B-K&65535:0;K=o&2016;B=U&2016;if((K&65535)>(B&65535)){V=(K-B&65535)+A&65535}else{V=A}A=o&31;o=U&31;if((A&65535)<=(o&65535)){S=V;break}S=(A-o&65535)+V&65535}}while(0);b[(c[277218]|0)+(w<<1)>>1]=S;a[(c[277219]|0)+w|0]=a[1108909]|0}}while(0);w=t-1&255;if(w<<24>>24!=0){v=w;u=1968}}if((u|0)==1968){u=0;w=m+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+w|0]|0)){z=a[r+4|0]|0;o=z&255;if(z<<24>>24==0){break}do{if((a[1108928]|0)==0){z=b[(c[277225]|0)+(o<<1)>>1]|0;if((a[(c[277215]|0)+w|0]&32)!=0){W=b[(c[277221]|0)+((z&65535|67616)-(b[(c[277213]|0)+(w<<1)>>1]&63454)>>1<<1)>>1]|0;break}A=c[277228]&65535;B=z&-2048;K=A&-2048;y=(B&65535)>(K&65535)?B-K&65535:0;K=z&2016;B=A&2016;if((K&65535)>(B&65535)){X=(K-B&65535)+y&65535}else{X=y}y=z&31;z=A&31;if((y&65535)<=(z&65535)){W=X;break}W=(y-z&65535)+X&65535}else{z=b[(c[277225]|0)+(o<<1)>>1]|0;if((a[(c[277215]|0)+w|0]&32)==0){Y=c[277228]&65535}else{Y=b[(c[277213]|0)+(w<<1)>>1]|0}y=z&-2048;A=Y&-2048;B=(y&65535)>(A&65535)?y-A&65535:0;A=z&2016;y=Y&2016;if((A&65535)>(y&65535)){Z=(A-y&65535)+B&65535}else{Z=B}B=z&31;z=Y&31;if((B&65535)<=(z&65535)){W=Z;break}W=(B-z&65535)+Z&65535}}while(0);b[(c[277218]|0)+(w<<1)>>1]=W;a[(c[277219]|0)+w|0]=a[1108909]|0}}while(0);w=v-1&255;if(w<<24>>24!=0){H=w;u=1986}}if((u|0)==1986){u=0;w=m+5|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+w|0]|0)){o=a[r+5|0]|0;z=o&255;if(o<<24>>24==0){break}do{if((a[1108928]|0)==0){o=b[(c[277225]|0)+(z<<1)>>1]|0;if((a[(c[277215]|0)+w|0]&32)!=0){_=b[(c[277221]|0)+((o&65535|67616)-(b[(c[277213]|0)+(w<<1)>>1]&63454)>>1<<1)>>1]|0;break}B=c[277228]&65535;y=o&-2048;A=B&-2048;K=(y&65535)>(A&65535)?y-A&65535:0;A=o&2016;y=B&2016;if((A&65535)>(y&65535)){$=(A-y&65535)+K&65535}else{$=K}K=o&31;o=B&31;if((K&65535)<=(o&65535)){_=$;break}_=(K-o&65535)+$&65535}else{o=b[(c[277225]|0)+(z<<1)>>1]|0;if((a[(c[277215]|0)+w|0]&32)==0){aa=c[277228]&65535}else{aa=b[(c[277213]|0)+(w<<1)>>1]|0}K=o&-2048;B=aa&-2048;y=(K&65535)>(B&65535)?K-B&65535:0;B=o&2016;K=aa&2016;if((B&65535)>(K&65535)){ab=(B-K&65535)+y&65535}else{ab=y}y=o&31;o=aa&31;if((y&65535)<=(o&65535)){_=ab;break}_=(y-o&65535)+ab&65535}}while(0);b[(c[277218]|0)+(w<<1)>>1]=_;a[(c[277219]|0)+w|0]=a[1108909]|0}}while(0);w=H-1&255;if(w<<24>>24!=0){I=w;u=2004}}if((u|0)==2004){u=0;w=m+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+w|0]|0)){z=a[r+6|0]|0;o=z&255;if(z<<24>>24==0){break}do{if((a[1108928]|0)==0){z=b[(c[277225]|0)+(o<<1)>>1]|0;if((a[(c[277215]|0)+w|0]&32)!=0){ac=b[(c[277221]|0)+((z&65535|67616)-(b[(c[277213]|0)+(w<<1)>>1]&63454)>>1<<1)>>1]|0;break}y=c[277228]&65535;K=z&-2048;B=y&-2048;A=(K&65535)>(B&65535)?K-B&65535:0;B=z&2016;K=y&2016;if((B&65535)>(K&65535)){ad=(B-K&65535)+A&65535}else{ad=A}A=z&31;z=y&31;if((A&65535)<=(z&65535)){ac=ad;break}ac=(A-z&65535)+ad&65535}else{z=b[(c[277225]|0)+(o<<1)>>1]|0;if((a[(c[277215]|0)+w|0]&32)==0){ae=c[277228]&65535}else{ae=b[(c[277213]|0)+(w<<1)>>1]|0}A=z&-2048;y=ae&-2048;K=(A&65535)>(y&65535)?A-y&65535:0;y=z&2016;A=ae&2016;if((y&65535)>(A&65535)){af=(y-A&65535)+K&65535}else{af=K}K=z&31;z=ae&31;if((K&65535)<=(z&65535)){ac=af;break}ac=(K-z&65535)+af&65535}}while(0);b[(c[277218]|0)+(w<<1)>>1]=ac;a[(c[277219]|0)+w|0]=a[1108909]|0}}while(0);if(I<<24>>24!=1){u=2022}}do{if((u|0)==2022){u=0;w=m+7|0;if((d[1108908]|0)<=(d[(c[277219]|0)+w|0]|0)){break}o=a[r+7|0]|0;z=o&255;if(o<<24>>24==0){break}do{if((a[1108928]|0)==0){o=b[(c[277225]|0)+(z<<1)>>1]|0;if((a[(c[277215]|0)+w|0]&32)!=0){ag=b[(c[277221]|0)+((o&65535|67616)-(b[(c[277213]|0)+(w<<1)>>1]&63454)>>1<<1)>>1]|0;break}K=c[277228]&65535;A=o&-2048;y=K&-2048;B=(A&65535)>(y&65535)?A-y&65535:0;y=o&2016;A=K&2016;if((y&65535)>(A&65535)){ah=(y-A&65535)+B&65535}else{ah=B}B=o&31;o=K&31;if((B&65535)<=(o&65535)){ag=ah;break}ag=(B-o&65535)+ah&65535}else{o=b[(c[277225]|0)+(z<<1)>>1]|0;if((a[(c[277215]|0)+w|0]&32)==0){ai=c[277228]&65535}else{ai=b[(c[277213]|0)+(w<<1)>>1]|0}B=o&-2048;K=ai&-2048;A=(B&65535)>(K&65535)?B-K&65535:0;K=o&2016;B=ai&2016;if((K&65535)>(B&65535)){aj=(K-B&65535)+A&65535}else{aj=A}A=o&31;o=ai&31;if((A&65535)<=(o&65535)){ag=aj;break}ag=(A-o&65535)+aj&65535}}while(0);b[(c[277218]|0)+(w<<1)>>1]=ag;a[(c[277219]|0)+w|0]=a[1108909]|0}}while(0);z=p-1|0;if((z|0)>0){r=r+8|0;p=z;m=(c[277223]|0)+m|0}else{break}}return}if((e&32768|0)==0){if((j|0)<=0){return}e=h&255;m=e-1&255;p=m<<24>>24==0;r=q+i|0;ag=j;aj=f;while(1){switch(g|0){case 2:{ak=e;u=2080;break};case 3:{al=e;u=2098;break};case 4:{am=e;u=2116;break};case 5:{an=e;u=2134;break};case 6:{ao=e;u=2152;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+aj|0]|0)){ai=a[r+7|0]|0;ah=ai&255;if(ai<<24>>24==0){break}do{if((a[1108928]|0)==0){ai=b[(c[277225]|0)+(ah<<1)>>1]|0;if((a[(c[277215]|0)+aj|0]&32)!=0){ap=b[(c[277221]|0)+((ai&65535|67616)-(b[(c[277213]|0)+(aj<<1)>>1]&63454)>>1<<1)>>1]|0;break}I=c[277228]&65535;ac=ai&-2048;af=I&-2048;ae=(ac&65535)>(af&65535)?ac-af&65535:0;af=ai&2016;ac=I&2016;if((af&65535)>(ac&65535)){aq=(af-ac&65535)+ae&65535}else{aq=ae}ae=ai&31;ai=I&31;if((ae&65535)<=(ai&65535)){ap=aq;break}ap=(ae-ai&65535)+aq&65535}else{ai=b[(c[277225]|0)+(ah<<1)>>1]|0;if((a[(c[277215]|0)+aj|0]&32)==0){ar=c[277228]&65535}else{ar=b[(c[277213]|0)+(aj<<1)>>1]|0}ae=ai&-2048;I=ar&-2048;ac=(ae&65535)>(I&65535)?ae-I&65535:0;I=ai&2016;ae=ar&2016;if((I&65535)>(ae&65535)){as=(I-ae&65535)+ac&65535}else{as=ac}ac=ai&31;ai=ar&31;if((ac&65535)<=(ai&65535)){ap=as;break}ap=(ac-ai&65535)+as&65535}}while(0);b[(c[277218]|0)+(aj<<1)>>1]=ap;a[(c[277219]|0)+aj|0]=a[1108909]|0}}while(0);if(!p){at=m;u=2062}break};case 1:{at=e;u=2062;break};case 7:{u=2170;break};default:{}}if((u|0)==2062){u=0;ah=aj+1|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+ah|0]|0)){w=a[r+6|0]|0;ai=w&255;if(w<<24>>24==0){break}do{if((a[1108928]|0)==0){w=b[(c[277225]|0)+(ai<<1)>>1]|0;if((a[(c[277215]|0)+ah|0]&32)!=0){au=b[(c[277221]|0)+((w&65535|67616)-(b[(c[277213]|0)+(ah<<1)>>1]&63454)>>1<<1)>>1]|0;break}ac=c[277228]&65535;ae=w&-2048;I=ac&-2048;af=(ae&65535)>(I&65535)?ae-I&65535:0;I=w&2016;ae=ac&2016;if((I&65535)>(ae&65535)){av=(I-ae&65535)+af&65535}else{av=af}af=w&31;w=ac&31;if((af&65535)<=(w&65535)){au=av;break}au=(af-w&65535)+av&65535}else{w=b[(c[277225]|0)+(ai<<1)>>1]|0;if((a[(c[277215]|0)+ah|0]&32)==0){aw=c[277228]&65535}else{aw=b[(c[277213]|0)+(ah<<1)>>1]|0}af=w&-2048;ac=aw&-2048;ae=(af&65535)>(ac&65535)?af-ac&65535:0;ac=w&2016;af=aw&2016;if((ac&65535)>(af&65535)){ax=(ac-af&65535)+ae&65535}else{ax=ae}ae=w&31;w=aw&31;if((ae&65535)<=(w&65535)){au=ax;break}au=(ae-w&65535)+ax&65535}}while(0);b[(c[277218]|0)+(ah<<1)>>1]=au;a[(c[277219]|0)+ah|0]=a[1108909]|0}}while(0);ah=at-1&255;if(ah<<24>>24!=0){ak=ah;u=2080}}if((u|0)==2080){u=0;ah=aj+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+ah|0]|0)){ai=a[r+5|0]|0;w=ai&255;if(ai<<24>>24==0){break}do{if((a[1108928]|0)==0){ai=b[(c[277225]|0)+(w<<1)>>1]|0;if((a[(c[277215]|0)+ah|0]&32)!=0){ay=b[(c[277221]|0)+((ai&65535|67616)-(b[(c[277213]|0)+(ah<<1)>>1]&63454)>>1<<1)>>1]|0;break}ae=c[277228]&65535;af=ai&-2048;ac=ae&-2048;I=(af&65535)>(ac&65535)?af-ac&65535:0;ac=ai&2016;af=ae&2016;if((ac&65535)>(af&65535)){az=(ac-af&65535)+I&65535}else{az=I}I=ai&31;ai=ae&31;if((I&65535)<=(ai&65535)){ay=az;break}ay=(I-ai&65535)+az&65535}else{ai=b[(c[277225]|0)+(w<<1)>>1]|0;if((a[(c[277215]|0)+ah|0]&32)==0){aA=c[277228]&65535}else{aA=b[(c[277213]|0)+(ah<<1)>>1]|0}I=ai&-2048;ae=aA&-2048;af=(I&65535)>(ae&65535)?I-ae&65535:0;ae=ai&2016;I=aA&2016;if((ae&65535)>(I&65535)){aB=(ae-I&65535)+af&65535}else{aB=af}af=ai&31;ai=aA&31;if((af&65535)<=(ai&65535)){ay=aB;break}ay=(af-ai&65535)+aB&65535}}while(0);b[(c[277218]|0)+(ah<<1)>>1]=ay;a[(c[277219]|0)+ah|0]=a[1108909]|0}}while(0);ah=ak-1&255;if(ah<<24>>24!=0){al=ah;u=2098}}if((u|0)==2098){u=0;ah=aj+3|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+ah|0]|0)){w=a[r+4|0]|0;ai=w&255;if(w<<24>>24==0){break}do{if((a[1108928]|0)==0){w=b[(c[277225]|0)+(ai<<1)>>1]|0;if((a[(c[277215]|0)+ah|0]&32)!=0){aC=b[(c[277221]|0)+((w&65535|67616)-(b[(c[277213]|0)+(ah<<1)>>1]&63454)>>1<<1)>>1]|0;break}af=c[277228]&65535;I=w&-2048;ae=af&-2048;ac=(I&65535)>(ae&65535)?I-ae&65535:0;ae=w&2016;I=af&2016;if((ae&65535)>(I&65535)){aD=(ae-I&65535)+ac&65535}else{aD=ac}ac=w&31;w=af&31;if((ac&65535)<=(w&65535)){aC=aD;break}aC=(ac-w&65535)+aD&65535}else{w=b[(c[277225]|0)+(ai<<1)>>1]|0;if((a[(c[277215]|0)+ah|0]&32)==0){aE=c[277228]&65535}else{aE=b[(c[277213]|0)+(ah<<1)>>1]|0}ac=w&-2048;af=aE&-2048;I=(ac&65535)>(af&65535)?ac-af&65535:0;af=w&2016;ac=aE&2016;if((af&65535)>(ac&65535)){aF=(af-ac&65535)+I&65535}else{aF=I}I=w&31;w=aE&31;if((I&65535)<=(w&65535)){aC=aF;break}aC=(I-w&65535)+aF&65535}}while(0);b[(c[277218]|0)+(ah<<1)>>1]=aC;a[(c[277219]|0)+ah|0]=a[1108909]|0}}while(0);ah=al-1&255;if(ah<<24>>24!=0){am=ah;u=2116}}if((u|0)==2116){u=0;ah=aj+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+ah|0]|0)){ai=a[r+3|0]|0;w=ai&255;if(ai<<24>>24==0){break}do{if((a[1108928]|0)==0){ai=b[(c[277225]|0)+(w<<1)>>1]|0;if((a[(c[277215]|0)+ah|0]&32)!=0){aG=b[(c[277221]|0)+((ai&65535|67616)-(b[(c[277213]|0)+(ah<<1)>>1]&63454)>>1<<1)>>1]|0;break}I=c[277228]&65535;ac=ai&-2048;af=I&-2048;ae=(ac&65535)>(af&65535)?ac-af&65535:0;af=ai&2016;ac=I&2016;if((af&65535)>(ac&65535)){aH=(af-ac&65535)+ae&65535}else{aH=ae}ae=ai&31;ai=I&31;if((ae&65535)<=(ai&65535)){aG=aH;break}aG=(ae-ai&65535)+aH&65535}else{ai=b[(c[277225]|0)+(w<<1)>>1]|0;if((a[(c[277215]|0)+ah|0]&32)==0){aI=c[277228]&65535}else{aI=b[(c[277213]|0)+(ah<<1)>>1]|0}ae=ai&-2048;I=aI&-2048;ac=(ae&65535)>(I&65535)?ae-I&65535:0;I=ai&2016;ae=aI&2016;if((I&65535)>(ae&65535)){aJ=(I-ae&65535)+ac&65535}else{aJ=ac}ac=ai&31;ai=aI&31;if((ac&65535)<=(ai&65535)){aG=aJ;break}aG=(ac-ai&65535)+aJ&65535}}while(0);b[(c[277218]|0)+(ah<<1)>>1]=aG;a[(c[277219]|0)+ah|0]=a[1108909]|0}}while(0);ah=am-1&255;if(ah<<24>>24!=0){an=ah;u=2134}}if((u|0)==2134){u=0;ah=aj+5|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+ah|0]|0)){w=a[r+2|0]|0;ai=w&255;if(w<<24>>24==0){break}do{if((a[1108928]|0)==0){w=b[(c[277225]|0)+(ai<<1)>>1]|0;if((a[(c[277215]|0)+ah|0]&32)!=0){aK=b[(c[277221]|0)+((w&65535|67616)-(b[(c[277213]|0)+(ah<<1)>>1]&63454)>>1<<1)>>1]|0;break}ac=c[277228]&65535;ae=w&-2048;I=ac&-2048;af=(ae&65535)>(I&65535)?ae-I&65535:0;I=w&2016;ae=ac&2016;if((I&65535)>(ae&65535)){aL=(I-ae&65535)+af&65535}else{aL=af}af=w&31;w=ac&31;if((af&65535)<=(w&65535)){aK=aL;break}aK=(af-w&65535)+aL&65535}else{w=b[(c[277225]|0)+(ai<<1)>>1]|0;if((a[(c[277215]|0)+ah|0]&32)==0){aM=c[277228]&65535}else{aM=b[(c[277213]|0)+(ah<<1)>>1]|0}af=w&-2048;ac=aM&-2048;ae=(af&65535)>(ac&65535)?af-ac&65535:0;ac=w&2016;af=aM&2016;if((ac&65535)>(af&65535)){aN=(ac-af&65535)+ae&65535}else{aN=ae}ae=w&31;w=aM&31;if((ae&65535)<=(w&65535)){aK=aN;break}aK=(ae-w&65535)+aN&65535}}while(0);b[(c[277218]|0)+(ah<<1)>>1]=aK;a[(c[277219]|0)+ah|0]=a[1108909]|0}}while(0);ah=an-1&255;if(ah<<24>>24!=0){ao=ah;u=2152}}if((u|0)==2152){u=0;ah=aj+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+ah|0]|0)){ai=a[r+1|0]|0;w=ai&255;if(ai<<24>>24==0){break}do{if((a[1108928]|0)==0){ai=b[(c[277225]|0)+(w<<1)>>1]|0;if((a[(c[277215]|0)+ah|0]&32)!=0){aO=b[(c[277221]|0)+((ai&65535|67616)-(b[(c[277213]|0)+(ah<<1)>>1]&63454)>>1<<1)>>1]|0;break}ae=c[277228]&65535;af=ai&-2048;ac=ae&-2048;I=(af&65535)>(ac&65535)?af-ac&65535:0;ac=ai&2016;af=ae&2016;if((ac&65535)>(af&65535)){aP=(ac-af&65535)+I&65535}else{aP=I}I=ai&31;ai=ae&31;if((I&65535)<=(ai&65535)){aO=aP;break}aO=(I-ai&65535)+aP&65535}else{ai=b[(c[277225]|0)+(w<<1)>>1]|0;if((a[(c[277215]|0)+ah|0]&32)==0){aQ=c[277228]&65535}else{aQ=b[(c[277213]|0)+(ah<<1)>>1]|0}I=ai&-2048;ae=aQ&-2048;af=(I&65535)>(ae&65535)?I-ae&65535:0;ae=ai&2016;I=aQ&2016;if((ae&65535)>(I&65535)){aR=(ae-I&65535)+af&65535}else{aR=af}af=ai&31;ai=aQ&31;if((af&65535)<=(ai&65535)){aO=aR;break}aO=(af-ai&65535)+aR&65535}}while(0);b[(c[277218]|0)+(ah<<1)>>1]=aO;a[(c[277219]|0)+ah|0]=a[1108909]|0}}while(0);if(ao<<24>>24!=1){u=2170}}do{if((u|0)==2170){u=0;ah=aj+7|0;if((d[1108908]|0)<=(d[(c[277219]|0)+ah|0]|0)){break}w=a[r]|0;ai=w&255;if(w<<24>>24==0){break}do{if((a[1108928]|0)==0){w=b[(c[277225]|0)+(ai<<1)>>1]|0;if((a[(c[277215]|0)+ah|0]&32)!=0){aS=b[(c[277221]|0)+((w&65535|67616)-(b[(c[277213]|0)+(ah<<1)>>1]&63454)>>1<<1)>>1]|0;break}af=c[277228]&65535;I=w&-2048;ae=af&-2048;ac=(I&65535)>(ae&65535)?I-ae&65535:0;ae=w&2016;I=af&2016;if((ae&65535)>(I&65535)){aT=(ae-I&65535)+ac&65535}else{aT=ac}ac=w&31;w=af&31;if((ac&65535)<=(w&65535)){aS=aT;break}aS=(ac-w&65535)+aT&65535}else{w=b[(c[277225]|0)+(ai<<1)>>1]|0;if((a[(c[277215]|0)+ah|0]&32)==0){aU=c[277228]&65535}else{aU=b[(c[277213]|0)+(ah<<1)>>1]|0}ac=w&-2048;af=aU&-2048;I=(ac&65535)>(af&65535)?ac-af&65535:0;af=w&2016;ac=aU&2016;if((af&65535)>(ac&65535)){aV=(af-ac&65535)+I&65535}else{aV=I}I=w&31;w=aU&31;if((I&65535)<=(w&65535)){aS=aV;break}aS=(I-w&65535)+aV&65535}}while(0);b[(c[277218]|0)+(ah<<1)>>1]=aS;a[(c[277219]|0)+ah|0]=a[1108909]|0}}while(0);ai=ag-1|0;if((ai|0)>0){r=r+8|0;ag=ai;aj=(c[277223]|0)+aj|0}else{break}}return}aj=q+(56-i)|0;i=(j|0)>0;if(l){if(!i){return}l=h&255;q=l-1&255;ag=q<<24>>24==0;r=aj;aS=j;aV=f;while(1){switch(g|0){case 7:{u=2465;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+aV|0]|0)){aU=a[r+7|0]|0;aT=aU&255;if(aU<<24>>24==0){break}do{if((a[1108928]|0)==0){aU=b[(c[277225]|0)+(aT<<1)>>1]|0;if((a[(c[277215]|0)+aV|0]&32)!=0){aW=b[(c[277221]|0)+((aU&65535|67616)-(b[(c[277213]|0)+(aV<<1)>>1]&63454)>>1<<1)>>1]|0;break}ao=c[277228]&65535;aO=aU&-2048;aR=ao&-2048;aQ=(aO&65535)>(aR&65535)?aO-aR&65535:0;aR=aU&2016;aO=ao&2016;if((aR&65535)>(aO&65535)){aX=(aR-aO&65535)+aQ&65535}else{aX=aQ}aQ=aU&31;aU=ao&31;if((aQ&65535)<=(aU&65535)){aW=aX;break}aW=(aQ-aU&65535)+aX&65535}else{aU=b[(c[277225]|0)+(aT<<1)>>1]|0;if((a[(c[277215]|0)+aV|0]&32)==0){aY=c[277228]&65535}else{aY=b[(c[277213]|0)+(aV<<1)>>1]|0}aQ=aU&-2048;ao=aY&-2048;aO=(aQ&65535)>(ao&65535)?aQ-ao&65535:0;ao=aU&2016;aQ=aY&2016;if((ao&65535)>(aQ&65535)){aZ=(ao-aQ&65535)+aO&65535}else{aZ=aO}aO=aU&31;aU=aY&31;if((aO&65535)<=(aU&65535)){aW=aZ;break}aW=(aO-aU&65535)+aZ&65535}}while(0);b[(c[277218]|0)+(aV<<1)>>1]=aW;a[(c[277219]|0)+aV|0]=a[1108909]|0}}while(0);if(!ag){a_=q;u=2357}break};case 4:{a$=l;u=2411;break};case 5:{a0=l;u=2429;break};case 6:{a1=l;u=2447;break};case 1:{a_=l;u=2357;break};case 2:{a2=l;u=2375;break};case 3:{a3=l;u=2393;break};default:{}}if((u|0)==2357){u=0;aT=aV+1|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+aT|0]|0)){ah=a[r+6|0]|0;aU=ah&255;if(ah<<24>>24==0){break}do{if((a[1108928]|0)==0){ah=b[(c[277225]|0)+(aU<<1)>>1]|0;if((a[(c[277215]|0)+aT|0]&32)!=0){a4=b[(c[277221]|0)+((ah&65535|67616)-(b[(c[277213]|0)+(aT<<1)>>1]&63454)>>1<<1)>>1]|0;break}aO=c[277228]&65535;aQ=ah&-2048;ao=aO&-2048;aR=(aQ&65535)>(ao&65535)?aQ-ao&65535:0;ao=ah&2016;aQ=aO&2016;if((ao&65535)>(aQ&65535)){a5=(ao-aQ&65535)+aR&65535}else{a5=aR}aR=ah&31;ah=aO&31;if((aR&65535)<=(ah&65535)){a4=a5;break}a4=(aR-ah&65535)+a5&65535}else{ah=b[(c[277225]|0)+(aU<<1)>>1]|0;if((a[(c[277215]|0)+aT|0]&32)==0){a6=c[277228]&65535}else{a6=b[(c[277213]|0)+(aT<<1)>>1]|0}aR=ah&-2048;aO=a6&-2048;aQ=(aR&65535)>(aO&65535)?aR-aO&65535:0;aO=ah&2016;aR=a6&2016;if((aO&65535)>(aR&65535)){a7=(aO-aR&65535)+aQ&65535}else{a7=aQ}aQ=ah&31;ah=a6&31;if((aQ&65535)<=(ah&65535)){a4=a7;break}a4=(aQ-ah&65535)+a7&65535}}while(0);b[(c[277218]|0)+(aT<<1)>>1]=a4;a[(c[277219]|0)+aT|0]=a[1108909]|0}}while(0);aT=a_-1&255;if(aT<<24>>24!=0){a2=aT;u=2375}}if((u|0)==2375){u=0;aT=aV+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+aT|0]|0)){aU=a[r+5|0]|0;ah=aU&255;if(aU<<24>>24==0){break}do{if((a[1108928]|0)==0){aU=b[(c[277225]|0)+(ah<<1)>>1]|0;if((a[(c[277215]|0)+aT|0]&32)!=0){a8=b[(c[277221]|0)+((aU&65535|67616)-(b[(c[277213]|0)+(aT<<1)>>1]&63454)>>1<<1)>>1]|0;break}aQ=c[277228]&65535;aR=aU&-2048;aO=aQ&-2048;ao=(aR&65535)>(aO&65535)?aR-aO&65535:0;aO=aU&2016;aR=aQ&2016;if((aO&65535)>(aR&65535)){a9=(aO-aR&65535)+ao&65535}else{a9=ao}ao=aU&31;aU=aQ&31;if((ao&65535)<=(aU&65535)){a8=a9;break}a8=(ao-aU&65535)+a9&65535}else{aU=b[(c[277225]|0)+(ah<<1)>>1]|0;if((a[(c[277215]|0)+aT|0]&32)==0){ba=c[277228]&65535}else{ba=b[(c[277213]|0)+(aT<<1)>>1]|0}ao=aU&-2048;aQ=ba&-2048;aR=(ao&65535)>(aQ&65535)?ao-aQ&65535:0;aQ=aU&2016;ao=ba&2016;if((aQ&65535)>(ao&65535)){bb=(aQ-ao&65535)+aR&65535}else{bb=aR}aR=aU&31;aU=ba&31;if((aR&65535)<=(aU&65535)){a8=bb;break}a8=(aR-aU&65535)+bb&65535}}while(0);b[(c[277218]|0)+(aT<<1)>>1]=a8;a[(c[277219]|0)+aT|0]=a[1108909]|0}}while(0);aT=a2-1&255;if(aT<<24>>24!=0){a3=aT;u=2393}}if((u|0)==2393){u=0;aT=aV+3|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+aT|0]|0)){ah=a[r+4|0]|0;aU=ah&255;if(ah<<24>>24==0){break}do{if((a[1108928]|0)==0){ah=b[(c[277225]|0)+(aU<<1)>>1]|0;if((a[(c[277215]|0)+aT|0]&32)!=0){bc=b[(c[277221]|0)+((ah&65535|67616)-(b[(c[277213]|0)+(aT<<1)>>1]&63454)>>1<<1)>>1]|0;break}aR=c[277228]&65535;ao=ah&-2048;aQ=aR&-2048;aO=(ao&65535)>(aQ&65535)?ao-aQ&65535:0;aQ=ah&2016;ao=aR&2016;if((aQ&65535)>(ao&65535)){bd=(aQ-ao&65535)+aO&65535}else{bd=aO}aO=ah&31;ah=aR&31;if((aO&65535)<=(ah&65535)){bc=bd;break}bc=(aO-ah&65535)+bd&65535}else{ah=b[(c[277225]|0)+(aU<<1)>>1]|0;if((a[(c[277215]|0)+aT|0]&32)==0){be=c[277228]&65535}else{be=b[(c[277213]|0)+(aT<<1)>>1]|0}aO=ah&-2048;aR=be&-2048;ao=(aO&65535)>(aR&65535)?aO-aR&65535:0;aR=ah&2016;aO=be&2016;if((aR&65535)>(aO&65535)){bf=(aR-aO&65535)+ao&65535}else{bf=ao}ao=ah&31;ah=be&31;if((ao&65535)<=(ah&65535)){bc=bf;break}bc=(ao-ah&65535)+bf&65535}}while(0);b[(c[277218]|0)+(aT<<1)>>1]=bc;a[(c[277219]|0)+aT|0]=a[1108909]|0}}while(0);aT=a3-1&255;if(aT<<24>>24!=0){a$=aT;u=2411}}if((u|0)==2411){u=0;aT=aV+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+aT|0]|0)){aU=a[r+3|0]|0;ah=aU&255;if(aU<<24>>24==0){break}do{if((a[1108928]|0)==0){aU=b[(c[277225]|0)+(ah<<1)>>1]|0;if((a[(c[277215]|0)+aT|0]&32)!=0){bg=b[(c[277221]|0)+((aU&65535|67616)-(b[(c[277213]|0)+(aT<<1)>>1]&63454)>>1<<1)>>1]|0;break}ao=c[277228]&65535;aO=aU&-2048;aR=ao&-2048;aQ=(aO&65535)>(aR&65535)?aO-aR&65535:0;aR=aU&2016;aO=ao&2016;if((aR&65535)>(aO&65535)){bh=(aR-aO&65535)+aQ&65535}else{bh=aQ}aQ=aU&31;aU=ao&31;if((aQ&65535)<=(aU&65535)){bg=bh;break}bg=(aQ-aU&65535)+bh&65535}else{aU=b[(c[277225]|0)+(ah<<1)>>1]|0;if((a[(c[277215]|0)+aT|0]&32)==0){bi=c[277228]&65535}else{bi=b[(c[277213]|0)+(aT<<1)>>1]|0}aQ=aU&-2048;ao=bi&-2048;aO=(aQ&65535)>(ao&65535)?aQ-ao&65535:0;ao=aU&2016;aQ=bi&2016;if((ao&65535)>(aQ&65535)){bj=(ao-aQ&65535)+aO&65535}else{bj=aO}aO=aU&31;aU=bi&31;if((aO&65535)<=(aU&65535)){bg=bj;break}bg=(aO-aU&65535)+bj&65535}}while(0);b[(c[277218]|0)+(aT<<1)>>1]=bg;a[(c[277219]|0)+aT|0]=a[1108909]|0}}while(0);aT=a$-1&255;if(aT<<24>>24!=0){a0=aT;u=2429}}if((u|0)==2429){u=0;aT=aV+5|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+aT|0]|0)){ah=a[r+2|0]|0;aU=ah&255;if(ah<<24>>24==0){break}do{if((a[1108928]|0)==0){ah=b[(c[277225]|0)+(aU<<1)>>1]|0;if((a[(c[277215]|0)+aT|0]&32)!=0){bk=b[(c[277221]|0)+((ah&65535|67616)-(b[(c[277213]|0)+(aT<<1)>>1]&63454)>>1<<1)>>1]|0;break}aO=c[277228]&65535;aQ=ah&-2048;ao=aO&-2048;aR=(aQ&65535)>(ao&65535)?aQ-ao&65535:0;ao=ah&2016;aQ=aO&2016;if((ao&65535)>(aQ&65535)){bl=(ao-aQ&65535)+aR&65535}else{bl=aR}aR=ah&31;ah=aO&31;if((aR&65535)<=(ah&65535)){bk=bl;break}bk=(aR-ah&65535)+bl&65535}else{ah=b[(c[277225]|0)+(aU<<1)>>1]|0;if((a[(c[277215]|0)+aT|0]&32)==0){bm=c[277228]&65535}else{bm=b[(c[277213]|0)+(aT<<1)>>1]|0}aR=ah&-2048;aO=bm&-2048;aQ=(aR&65535)>(aO&65535)?aR-aO&65535:0;aO=ah&2016;aR=bm&2016;if((aO&65535)>(aR&65535)){bn=(aO-aR&65535)+aQ&65535}else{bn=aQ}aQ=ah&31;ah=bm&31;if((aQ&65535)<=(ah&65535)){bk=bn;break}bk=(aQ-ah&65535)+bn&65535}}while(0);b[(c[277218]|0)+(aT<<1)>>1]=bk;a[(c[277219]|0)+aT|0]=a[1108909]|0}}while(0);aT=a0-1&255;if(aT<<24>>24!=0){a1=aT;u=2447}}if((u|0)==2447){u=0;aT=aV+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+aT|0]|0)){aU=a[r+1|0]|0;ah=aU&255;if(aU<<24>>24==0){break}do{if((a[1108928]|0)==0){aU=b[(c[277225]|0)+(ah<<1)>>1]|0;if((a[(c[277215]|0)+aT|0]&32)!=0){bo=b[(c[277221]|0)+((aU&65535|67616)-(b[(c[277213]|0)+(aT<<1)>>1]&63454)>>1<<1)>>1]|0;break}aQ=c[277228]&65535;aR=aU&-2048;aO=aQ&-2048;ao=(aR&65535)>(aO&65535)?aR-aO&65535:0;aO=aU&2016;aR=aQ&2016;if((aO&65535)>(aR&65535)){bp=(aO-aR&65535)+ao&65535}else{bp=ao}ao=aU&31;aU=aQ&31;if((ao&65535)<=(aU&65535)){bo=bp;break}bo=(ao-aU&65535)+bp&65535}else{aU=b[(c[277225]|0)+(ah<<1)>>1]|0;if((a[(c[277215]|0)+aT|0]&32)==0){bq=c[277228]&65535}else{bq=b[(c[277213]|0)+(aT<<1)>>1]|0}ao=aU&-2048;aQ=bq&-2048;aR=(ao&65535)>(aQ&65535)?ao-aQ&65535:0;aQ=aU&2016;ao=bq&2016;if((aQ&65535)>(ao&65535)){br=(aQ-ao&65535)+aR&65535}else{br=aR}aR=aU&31;aU=bq&31;if((aR&65535)<=(aU&65535)){bo=br;break}bo=(aR-aU&65535)+br&65535}}while(0);b[(c[277218]|0)+(aT<<1)>>1]=bo;a[(c[277219]|0)+aT|0]=a[1108909]|0}}while(0);if(a1<<24>>24!=1){u=2465}}do{if((u|0)==2465){u=0;aT=aV+7|0;if((d[1108908]|0)<=(d[(c[277219]|0)+aT|0]|0)){break}ah=a[r]|0;aU=ah&255;if(ah<<24>>24==0){break}do{if((a[1108928]|0)==0){ah=b[(c[277225]|0)+(aU<<1)>>1]|0;if((a[(c[277215]|0)+aT|0]&32)!=0){bs=b[(c[277221]|0)+((ah&65535|67616)-(b[(c[277213]|0)+(aT<<1)>>1]&63454)>>1<<1)>>1]|0;break}aR=c[277228]&65535;ao=ah&-2048;aQ=aR&-2048;aO=(ao&65535)>(aQ&65535)?ao-aQ&65535:0;aQ=ah&2016;ao=aR&2016;if((aQ&65535)>(ao&65535)){bt=(aQ-ao&65535)+aO&65535}else{bt=aO}aO=ah&31;ah=aR&31;if((aO&65535)<=(ah&65535)){bs=bt;break}bs=(aO-ah&65535)+bt&65535}else{ah=b[(c[277225]|0)+(aU<<1)>>1]|0;if((a[(c[277215]|0)+aT|0]&32)==0){bu=c[277228]&65535}else{bu=b[(c[277213]|0)+(aT<<1)>>1]|0}aO=ah&-2048;aR=bu&-2048;ao=(aO&65535)>(aR&65535)?aO-aR&65535:0;aR=ah&2016;aO=bu&2016;if((aR&65535)>(aO&65535)){bv=(aR-aO&65535)+ao&65535}else{bv=ao}ao=ah&31;ah=bu&31;if((ao&65535)<=(ah&65535)){bs=bv;break}bs=(ao-ah&65535)+bv&65535}}while(0);b[(c[277218]|0)+(aT<<1)>>1]=bs;a[(c[277219]|0)+aT|0]=a[1108909]|0}}while(0);aU=aS-1|0;if((aU|0)>0){r=r-8|0;aS=aU;aV=(c[277223]|0)+aV|0}else{break}}return}else{if(!i){return}i=h&255;h=i-1&255;aV=h<<24>>24==0;aS=aj;aj=j;j=f;while(1){switch(g|0){case 5:{bw=i;u=2284;break};case 6:{bx=i;u=2302;break};case 1:{by=i;u=2212;break};case 2:{bz=i;u=2230;break};case 7:{u=2320;break};case 3:{bA=i;u=2248;break};case 4:{bB=i;u=2266;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+j|0]|0)){f=a[aS]|0;r=f&255;if(f<<24>>24==0){break}do{if((a[1108928]|0)==0){f=b[(c[277225]|0)+(r<<1)>>1]|0;if((a[(c[277215]|0)+j|0]&32)!=0){bC=b[(c[277221]|0)+((f&65535|67616)-(b[(c[277213]|0)+(j<<1)>>1]&63454)>>1<<1)>>1]|0;break}bs=c[277228]&65535;bv=f&-2048;bu=bs&-2048;bt=(bv&65535)>(bu&65535)?bv-bu&65535:0;bu=f&2016;bv=bs&2016;if((bu&65535)>(bv&65535)){bD=(bu-bv&65535)+bt&65535}else{bD=bt}bt=f&31;f=bs&31;if((bt&65535)<=(f&65535)){bC=bD;break}bC=(bt-f&65535)+bD&65535}else{f=b[(c[277225]|0)+(r<<1)>>1]|0;if((a[(c[277215]|0)+j|0]&32)==0){bE=c[277228]&65535}else{bE=b[(c[277213]|0)+(j<<1)>>1]|0}bt=f&-2048;bs=bE&-2048;bv=(bt&65535)>(bs&65535)?bt-bs&65535:0;bs=f&2016;bt=bE&2016;if((bs&65535)>(bt&65535)){bF=(bs-bt&65535)+bv&65535}else{bF=bv}bv=f&31;f=bE&31;if((bv&65535)<=(f&65535)){bC=bF;break}bC=(bv-f&65535)+bF&65535}}while(0);b[(c[277218]|0)+(j<<1)>>1]=bC;a[(c[277219]|0)+j|0]=a[1108909]|0}}while(0);if(!aV){by=h;u=2212}break};default:{}}if((u|0)==2212){u=0;r=j+1|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+r|0]|0)){aT=a[aS+1|0]|0;f=aT&255;if(aT<<24>>24==0){break}do{if((a[1108928]|0)==0){aT=b[(c[277225]|0)+(f<<1)>>1]|0;if((a[(c[277215]|0)+r|0]&32)!=0){bG=b[(c[277221]|0)+((aT&65535|67616)-(b[(c[277213]|0)+(r<<1)>>1]&63454)>>1<<1)>>1]|0;break}bv=c[277228]&65535;bt=aT&-2048;bs=bv&-2048;bu=(bt&65535)>(bs&65535)?bt-bs&65535:0;bs=aT&2016;bt=bv&2016;if((bs&65535)>(bt&65535)){bH=(bs-bt&65535)+bu&65535}else{bH=bu}bu=aT&31;aT=bv&31;if((bu&65535)<=(aT&65535)){bG=bH;break}bG=(bu-aT&65535)+bH&65535}else{aT=b[(c[277225]|0)+(f<<1)>>1]|0;if((a[(c[277215]|0)+r|0]&32)==0){bI=c[277228]&65535}else{bI=b[(c[277213]|0)+(r<<1)>>1]|0}bu=aT&-2048;bv=bI&-2048;bt=(bu&65535)>(bv&65535)?bu-bv&65535:0;bv=aT&2016;bu=bI&2016;if((bv&65535)>(bu&65535)){bJ=(bv-bu&65535)+bt&65535}else{bJ=bt}bt=aT&31;aT=bI&31;if((bt&65535)<=(aT&65535)){bG=bJ;break}bG=(bt-aT&65535)+bJ&65535}}while(0);b[(c[277218]|0)+(r<<1)>>1]=bG;a[(c[277219]|0)+r|0]=a[1108909]|0}}while(0);r=by-1&255;if(r<<24>>24!=0){bz=r;u=2230}}if((u|0)==2230){u=0;r=j+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+r|0]|0)){f=a[aS+2|0]|0;aT=f&255;if(f<<24>>24==0){break}do{if((a[1108928]|0)==0){f=b[(c[277225]|0)+(aT<<1)>>1]|0;if((a[(c[277215]|0)+r|0]&32)!=0){bK=b[(c[277221]|0)+((f&65535|67616)-(b[(c[277213]|0)+(r<<1)>>1]&63454)>>1<<1)>>1]|0;break}bt=c[277228]&65535;bu=f&-2048;bv=bt&-2048;bs=(bu&65535)>(bv&65535)?bu-bv&65535:0;bv=f&2016;bu=bt&2016;if((bv&65535)>(bu&65535)){bL=(bv-bu&65535)+bs&65535}else{bL=bs}bs=f&31;f=bt&31;if((bs&65535)<=(f&65535)){bK=bL;break}bK=(bs-f&65535)+bL&65535}else{f=b[(c[277225]|0)+(aT<<1)>>1]|0;if((a[(c[277215]|0)+r|0]&32)==0){bM=c[277228]&65535}else{bM=b[(c[277213]|0)+(r<<1)>>1]|0}bs=f&-2048;bt=bM&-2048;bu=(bs&65535)>(bt&65535)?bs-bt&65535:0;bt=f&2016;bs=bM&2016;if((bt&65535)>(bs&65535)){bN=(bt-bs&65535)+bu&65535}else{bN=bu}bu=f&31;f=bM&31;if((bu&65535)<=(f&65535)){bK=bN;break}bK=(bu-f&65535)+bN&65535}}while(0);b[(c[277218]|0)+(r<<1)>>1]=bK;a[(c[277219]|0)+r|0]=a[1108909]|0}}while(0);r=bz-1&255;if(r<<24>>24!=0){bA=r;u=2248}}if((u|0)==2248){u=0;r=j+3|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+r|0]|0)){aT=a[aS+3|0]|0;f=aT&255;if(aT<<24>>24==0){break}do{if((a[1108928]|0)==0){aT=b[(c[277225]|0)+(f<<1)>>1]|0;if((a[(c[277215]|0)+r|0]&32)!=0){bO=b[(c[277221]|0)+((aT&65535|67616)-(b[(c[277213]|0)+(r<<1)>>1]&63454)>>1<<1)>>1]|0;break}bu=c[277228]&65535;bs=aT&-2048;bt=bu&-2048;bv=(bs&65535)>(bt&65535)?bs-bt&65535:0;bt=aT&2016;bs=bu&2016;if((bt&65535)>(bs&65535)){bP=(bt-bs&65535)+bv&65535}else{bP=bv}bv=aT&31;aT=bu&31;if((bv&65535)<=(aT&65535)){bO=bP;break}bO=(bv-aT&65535)+bP&65535}else{aT=b[(c[277225]|0)+(f<<1)>>1]|0;if((a[(c[277215]|0)+r|0]&32)==0){bQ=c[277228]&65535}else{bQ=b[(c[277213]|0)+(r<<1)>>1]|0}bv=aT&-2048;bu=bQ&-2048;bs=(bv&65535)>(bu&65535)?bv-bu&65535:0;bu=aT&2016;bv=bQ&2016;if((bu&65535)>(bv&65535)){bR=(bu-bv&65535)+bs&65535}else{bR=bs}bs=aT&31;aT=bQ&31;if((bs&65535)<=(aT&65535)){bO=bR;break}bO=(bs-aT&65535)+bR&65535}}while(0);b[(c[277218]|0)+(r<<1)>>1]=bO;a[(c[277219]|0)+r|0]=a[1108909]|0}}while(0);r=bA-1&255;if(r<<24>>24!=0){bB=r;u=2266}}if((u|0)==2266){u=0;r=j+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+r|0]|0)){f=a[aS+4|0]|0;aT=f&255;if(f<<24>>24==0){break}do{if((a[1108928]|0)==0){f=b[(c[277225]|0)+(aT<<1)>>1]|0;if((a[(c[277215]|0)+r|0]&32)!=0){bS=b[(c[277221]|0)+((f&65535|67616)-(b[(c[277213]|0)+(r<<1)>>1]&63454)>>1<<1)>>1]|0;break}bs=c[277228]&65535;bv=f&-2048;bu=bs&-2048;bt=(bv&65535)>(bu&65535)?bv-bu&65535:0;bu=f&2016;bv=bs&2016;if((bu&65535)>(bv&65535)){bT=(bu-bv&65535)+bt&65535}else{bT=bt}bt=f&31;f=bs&31;if((bt&65535)<=(f&65535)){bS=bT;break}bS=(bt-f&65535)+bT&65535}else{f=b[(c[277225]|0)+(aT<<1)>>1]|0;if((a[(c[277215]|0)+r|0]&32)==0){bU=c[277228]&65535}else{bU=b[(c[277213]|0)+(r<<1)>>1]|0}bt=f&-2048;bs=bU&-2048;bv=(bt&65535)>(bs&65535)?bt-bs&65535:0;bs=f&2016;bt=bU&2016;if((bs&65535)>(bt&65535)){bV=(bs-bt&65535)+bv&65535}else{bV=bv}bv=f&31;f=bU&31;if((bv&65535)<=(f&65535)){bS=bV;break}bS=(bv-f&65535)+bV&65535}}while(0);b[(c[277218]|0)+(r<<1)>>1]=bS;a[(c[277219]|0)+r|0]=a[1108909]|0}}while(0);r=bB-1&255;if(r<<24>>24!=0){bw=r;u=2284}}if((u|0)==2284){u=0;r=j+5|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+r|0]|0)){aT=a[aS+5|0]|0;f=aT&255;if(aT<<24>>24==0){break}do{if((a[1108928]|0)==0){aT=b[(c[277225]|0)+(f<<1)>>1]|0;if((a[(c[277215]|0)+r|0]&32)!=0){bW=b[(c[277221]|0)+((aT&65535|67616)-(b[(c[277213]|0)+(r<<1)>>1]&63454)>>1<<1)>>1]|0;break}bv=c[277228]&65535;bt=aT&-2048;bs=bv&-2048;bu=(bt&65535)>(bs&65535)?bt-bs&65535:0;bs=aT&2016;bt=bv&2016;if((bs&65535)>(bt&65535)){bX=(bs-bt&65535)+bu&65535}else{bX=bu}bu=aT&31;aT=bv&31;if((bu&65535)<=(aT&65535)){bW=bX;break}bW=(bu-aT&65535)+bX&65535}else{aT=b[(c[277225]|0)+(f<<1)>>1]|0;if((a[(c[277215]|0)+r|0]&32)==0){bY=c[277228]&65535}else{bY=b[(c[277213]|0)+(r<<1)>>1]|0}bu=aT&-2048;bv=bY&-2048;bt=(bu&65535)>(bv&65535)?bu-bv&65535:0;bv=aT&2016;bu=bY&2016;if((bv&65535)>(bu&65535)){bZ=(bv-bu&65535)+bt&65535}else{bZ=bt}bt=aT&31;aT=bY&31;if((bt&65535)<=(aT&65535)){bW=bZ;break}bW=(bt-aT&65535)+bZ&65535}}while(0);b[(c[277218]|0)+(r<<1)>>1]=bW;a[(c[277219]|0)+r|0]=a[1108909]|0}}while(0);r=bw-1&255;if(r<<24>>24!=0){bx=r;u=2302}}if((u|0)==2302){u=0;r=j+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+r|0]|0)){f=a[aS+6|0]|0;aT=f&255;if(f<<24>>24==0){break}do{if((a[1108928]|0)==0){f=b[(c[277225]|0)+(aT<<1)>>1]|0;if((a[(c[277215]|0)+r|0]&32)!=0){b_=b[(c[277221]|0)+((f&65535|67616)-(b[(c[277213]|0)+(r<<1)>>1]&63454)>>1<<1)>>1]|0;break}bt=c[277228]&65535;bu=f&-2048;bv=bt&-2048;bs=(bu&65535)>(bv&65535)?bu-bv&65535:0;bv=f&2016;bu=bt&2016;if((bv&65535)>(bu&65535)){b$=(bv-bu&65535)+bs&65535}else{b$=bs}bs=f&31;f=bt&31;if((bs&65535)<=(f&65535)){b_=b$;break}b_=(bs-f&65535)+b$&65535}else{f=b[(c[277225]|0)+(aT<<1)>>1]|0;if((a[(c[277215]|0)+r|0]&32)==0){b0=c[277228]&65535}else{b0=b[(c[277213]|0)+(r<<1)>>1]|0}bs=f&-2048;bt=b0&-2048;bu=(bs&65535)>(bt&65535)?bs-bt&65535:0;bt=f&2016;bs=b0&2016;if((bt&65535)>(bs&65535)){b1=(bt-bs&65535)+bu&65535}else{b1=bu}bu=f&31;f=b0&31;if((bu&65535)<=(f&65535)){b_=b1;break}b_=(bu-f&65535)+b1&65535}}while(0);b[(c[277218]|0)+(r<<1)>>1]=b_;a[(c[277219]|0)+r|0]=a[1108909]|0}}while(0);if(bx<<24>>24!=1){u=2320}}do{if((u|0)==2320){u=0;r=j+7|0;if((d[1108908]|0)<=(d[(c[277219]|0)+r|0]|0)){break}aT=a[aS+7|0]|0;f=aT&255;if(aT<<24>>24==0){break}do{if((a[1108928]|0)==0){aT=b[(c[277225]|0)+(f<<1)>>1]|0;if((a[(c[277215]|0)+r|0]&32)!=0){b2=b[(c[277221]|0)+((aT&65535|67616)-(b[(c[277213]|0)+(r<<1)>>1]&63454)>>1<<1)>>1]|0;break}bu=c[277228]&65535;bs=aT&-2048;bt=bu&-2048;bv=(bs&65535)>(bt&65535)?bs-bt&65535:0;bt=aT&2016;bs=bu&2016;if((bt&65535)>(bs&65535)){b3=(bt-bs&65535)+bv&65535}else{b3=bv}bv=aT&31;aT=bu&31;if((bv&65535)<=(aT&65535)){b2=b3;break}b2=(bv-aT&65535)+b3&65535}else{aT=b[(c[277225]|0)+(f<<1)>>1]|0;if((a[(c[277215]|0)+r|0]&32)==0){b4=c[277228]&65535}else{b4=b[(c[277213]|0)+(r<<1)>>1]|0}bv=aT&-2048;bu=b4&-2048;bs=(bv&65535)>(bu&65535)?bv-bu&65535:0;bu=aT&2016;bv=b4&2016;if((bu&65535)>(bv&65535)){b5=(bu-bv&65535)+bs&65535}else{b5=bs}bs=aT&31;aT=b4&31;if((bs&65535)<=(aT&65535)){b2=b5;break}b2=(bs-aT&65535)+b5&65535}}while(0);b[(c[277218]|0)+(r<<1)>>1]=b2;a[(c[277219]|0)+r|0]=a[1108909]|0}}while(0);f=aj-1|0;if((f|0)>0){aS=aS-8|0;aj=f;j=(c[277223]|0)+j|0}else{break}}return}}function Xr(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0;i=e&1023;j=c[348606]|0;k=(i<<j)+(c[348604]|0)|0;if((e&256|0)==0){l=k}else{l=(c[348602]|0)+k|0}k=l&65535;l=k>>>(j>>>0);j=(e&16384|0)!=0;m=l<<6;do{if(j){n=(c[348622]|0)+m|0;if((a[(c[348618]|0)+l|0]|0)!=0){o=n;break}p=fi[c[348636]&63](n,k,i)|0;a[(c[348618]|0)+l|0]=p;o=n}else{n=(c[348624]|0)+m|0;if((a[(c[348620]|0)+l|0]|0)!=0){o=n;break}p=fi[c[348638]&63](n,k,i)|0;a[(c[348620]|0)+l|0]=p;o=n}}while(0);if((a[(c[348620]|0)+l|0]|0)==2){return}if((a[1394464]|0)==0){q=1106168+((e>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){l=d[1044485]|0;c[276541]=7080+(l<<5);i=0;do{k=i<<1&2;m=i&2;n=i&4;p=0;do{b[1125528+(i<<9)+(p<<1)>>1]=d[(p>>>1&28|m)+(7080+(l<<5))|0]<<6|d[(p<<2&28|k)+(7080+(l<<5))|0]<<11|d[(p>>>3&24|n)+(7080+(l<<5))|0];p=p+1|0;}while(p>>>0<256);i=i+1|0;}while(i>>>0<8);a[1106089]=0}q=1125528+((e>>>10&7)<<9)|0}c[277226]=q;c[277225]=(a[1108928]|0)!=0?1393712:q;if((e&49152|0)==0){if((h|0)<=0){return}q=o+g|0;i=h;l=f;while(1){p=a[1108908]|0;n=c[277219]|0;do{if((p&255)>(d[n+l|0]|0)){k=a[q]|0;if(k<<24>>24==0){r=p;s=n;break}b[(c[277218]|0)+(l<<1)>>1]=b[(c[277225]|0)+((k&255)<<1)>>1]|0;a[(c[277219]|0)+l|0]=a[1108909]|0;r=a[1108908]|0;s=c[277219]|0}else{r=p;s=n}}while(0);n=l+1|0;do{if((r&255)>(d[s+n|0]|0)){p=a[q+1|0]|0;if(p<<24>>24==0){t=r;u=s;break}b[(c[277218]|0)+(n<<1)>>1]=b[(c[277225]|0)+((p&255)<<1)>>1]|0;a[(c[277219]|0)+n|0]=a[1108909]|0;t=a[1108908]|0;u=c[277219]|0}else{t=r;u=s}}while(0);n=l+2|0;do{if((t&255)>(d[u+n|0]|0)){p=a[q+2|0]|0;if(p<<24>>24==0){v=t;w=u;break}b[(c[277218]|0)+(n<<1)>>1]=b[(c[277225]|0)+((p&255)<<1)>>1]|0;a[(c[277219]|0)+n|0]=a[1108909]|0;v=a[1108908]|0;w=c[277219]|0}else{v=t;w=u}}while(0);n=l+3|0;do{if((v&255)>(d[w+n|0]|0)){p=a[q+3|0]|0;if(p<<24>>24==0){x=v;y=w;break}b[(c[277218]|0)+(n<<1)>>1]=b[(c[277225]|0)+((p&255)<<1)>>1]|0;a[(c[277219]|0)+n|0]=a[1108909]|0;x=a[1108908]|0;y=c[277219]|0}else{x=v;y=w}}while(0);n=l+4|0;do{if((x&255)>(d[y+n|0]|0)){p=a[q+4|0]|0;if(p<<24>>24==0){z=x;A=y;break}b[(c[277218]|0)+(n<<1)>>1]=b[(c[277225]|0)+((p&255)<<1)>>1]|0;a[(c[277219]|0)+n|0]=a[1108909]|0;z=a[1108908]|0;A=c[277219]|0}else{z=x;A=y}}while(0);n=l+5|0;do{if((z&255)>(d[A+n|0]|0)){p=a[q+5|0]|0;if(p<<24>>24==0){B=z;C=A;break}b[(c[277218]|0)+(n<<1)>>1]=b[(c[277225]|0)+((p&255)<<1)>>1]|0;a[(c[277219]|0)+n|0]=a[1108909]|0;B=a[1108908]|0;C=c[277219]|0}else{B=z;C=A}}while(0);n=l+6|0;do{if((B&255)>(d[C+n|0]|0)){p=a[q+6|0]|0;if(p<<24>>24==0){D=B;E=C;break}b[(c[277218]|0)+(n<<1)>>1]=b[(c[277225]|0)+((p&255)<<1)>>1]|0;a[(c[277219]|0)+n|0]=a[1108909]|0;D=a[1108908]|0;E=c[277219]|0}else{D=B;E=C}}while(0);n=l+7|0;do{if((D&255)>(d[E+n|0]|0)){p=a[q+7|0]|0;if(p<<24>>24==0){break}b[(c[277218]|0)+(n<<1)>>1]=b[(c[277225]|0)+((p&255)<<1)>>1]|0;a[(c[277219]|0)+n|0]=a[1108909]|0}}while(0);n=i-1|0;if((n|0)<=0){break}q=q+8|0;i=n;l=(c[277223]|0)+l|0}return}if((e&32768|0)==0){if((h|0)<=0){return}e=o+g|0;l=h;i=f;while(1){q=a[1108908]|0;E=c[277219]|0;do{if((q&255)>(d[E+i|0]|0)){D=a[e+7|0]|0;if(D<<24>>24==0){F=q;G=E;break}b[(c[277218]|0)+(i<<1)>>1]=b[(c[277225]|0)+((D&255)<<1)>>1]|0;a[(c[277219]|0)+i|0]=a[1108909]|0;F=a[1108908]|0;G=c[277219]|0}else{F=q;G=E}}while(0);E=i+1|0;do{if((F&255)>(d[G+E|0]|0)){q=a[e+6|0]|0;if(q<<24>>24==0){H=F;I=G;break}b[(c[277218]|0)+(E<<1)>>1]=b[(c[277225]|0)+((q&255)<<1)>>1]|0;a[(c[277219]|0)+E|0]=a[1108909]|0;H=a[1108908]|0;I=c[277219]|0}else{H=F;I=G}}while(0);E=i+2|0;do{if((H&255)>(d[I+E|0]|0)){q=a[e+5|0]|0;if(q<<24>>24==0){J=H;K=I;break}b[(c[277218]|0)+(E<<1)>>1]=b[(c[277225]|0)+((q&255)<<1)>>1]|0;a[(c[277219]|0)+E|0]=a[1108909]|0;J=a[1108908]|0;K=c[277219]|0}else{J=H;K=I}}while(0);E=i+3|0;do{if((J&255)>(d[K+E|0]|0)){q=a[e+4|0]|0;if(q<<24>>24==0){L=J;M=K;break}b[(c[277218]|0)+(E<<1)>>1]=b[(c[277225]|0)+((q&255)<<1)>>1]|0;a[(c[277219]|0)+E|0]=a[1108909]|0;L=a[1108908]|0;M=c[277219]|0}else{L=J;M=K}}while(0);E=i+4|0;do{if((L&255)>(d[M+E|0]|0)){q=a[e+3|0]|0;if(q<<24>>24==0){N=L;O=M;break}b[(c[277218]|0)+(E<<1)>>1]=b[(c[277225]|0)+((q&255)<<1)>>1]|0;a[(c[277219]|0)+E|0]=a[1108909]|0;N=a[1108908]|0;O=c[277219]|0}else{N=L;O=M}}while(0);E=i+5|0;do{if((N&255)>(d[O+E|0]|0)){q=a[e+2|0]|0;if(q<<24>>24==0){P=N;Q=O;break}b[(c[277218]|0)+(E<<1)>>1]=b[(c[277225]|0)+((q&255)<<1)>>1]|0;a[(c[277219]|0)+E|0]=a[1108909]|0;P=a[1108908]|0;Q=c[277219]|0}else{P=N;Q=O}}while(0);E=i+6|0;do{if((P&255)>(d[Q+E|0]|0)){q=a[e+1|0]|0;if(q<<24>>24==0){R=P;S=Q;break}b[(c[277218]|0)+(E<<1)>>1]=b[(c[277225]|0)+((q&255)<<1)>>1]|0;a[(c[277219]|0)+E|0]=a[1108909]|0;R=a[1108908]|0;S=c[277219]|0}else{R=P;S=Q}}while(0);E=i+7|0;do{if((R&255)>(d[S+E|0]|0)){q=a[e]|0;if(q<<24>>24==0){break}b[(c[277218]|0)+(E<<1)>>1]=b[(c[277225]|0)+((q&255)<<1)>>1]|0;a[(c[277219]|0)+E|0]=a[1108909]|0}}while(0);E=l-1|0;if((E|0)<=0){break}e=e+8|0;l=E;i=(c[277223]|0)+i|0}return}i=o+(56-g)|0;g=(h|0)>0;if(j){if(g){T=i;U=h;V=f}else{return}while(1){j=a[1108908]|0;o=c[277219]|0;do{if((j&255)>(d[o+V|0]|0)){l=a[T+7|0]|0;if(l<<24>>24==0){W=j;X=o;break}b[(c[277218]|0)+(V<<1)>>1]=b[(c[277225]|0)+((l&255)<<1)>>1]|0;a[(c[277219]|0)+V|0]=a[1108909]|0;W=a[1108908]|0;X=c[277219]|0}else{W=j;X=o}}while(0);o=V+1|0;do{if((W&255)>(d[X+o|0]|0)){j=a[T+6|0]|0;if(j<<24>>24==0){Y=W;Z=X;break}b[(c[277218]|0)+(o<<1)>>1]=b[(c[277225]|0)+((j&255)<<1)>>1]|0;a[(c[277219]|0)+o|0]=a[1108909]|0;Y=a[1108908]|0;Z=c[277219]|0}else{Y=W;Z=X}}while(0);o=V+2|0;do{if((Y&255)>(d[Z+o|0]|0)){j=a[T+5|0]|0;if(j<<24>>24==0){_=Y;$=Z;break}b[(c[277218]|0)+(o<<1)>>1]=b[(c[277225]|0)+((j&255)<<1)>>1]|0;a[(c[277219]|0)+o|0]=a[1108909]|0;_=a[1108908]|0;$=c[277219]|0}else{_=Y;$=Z}}while(0);o=V+3|0;do{if((_&255)>(d[$+o|0]|0)){j=a[T+4|0]|0;if(j<<24>>24==0){aa=_;ab=$;break}b[(c[277218]|0)+(o<<1)>>1]=b[(c[277225]|0)+((j&255)<<1)>>1]|0;a[(c[277219]|0)+o|0]=a[1108909]|0;aa=a[1108908]|0;ab=c[277219]|0}else{aa=_;ab=$}}while(0);o=V+4|0;do{if((aa&255)>(d[ab+o|0]|0)){j=a[T+3|0]|0;if(j<<24>>24==0){ac=aa;ad=ab;break}b[(c[277218]|0)+(o<<1)>>1]=b[(c[277225]|0)+((j&255)<<1)>>1]|0;a[(c[277219]|0)+o|0]=a[1108909]|0;ac=a[1108908]|0;ad=c[277219]|0}else{ac=aa;ad=ab}}while(0);o=V+5|0;do{if((ac&255)>(d[ad+o|0]|0)){j=a[T+2|0]|0;if(j<<24>>24==0){ae=ac;af=ad;break}b[(c[277218]|0)+(o<<1)>>1]=b[(c[277225]|0)+((j&255)<<1)>>1]|0;a[(c[277219]|0)+o|0]=a[1108909]|0;ae=a[1108908]|0;af=c[277219]|0}else{ae=ac;af=ad}}while(0);o=V+6|0;do{if((ae&255)>(d[af+o|0]|0)){j=a[T+1|0]|0;if(j<<24>>24==0){ag=ae;ah=af;break}b[(c[277218]|0)+(o<<1)>>1]=b[(c[277225]|0)+((j&255)<<1)>>1]|0;a[(c[277219]|0)+o|0]=a[1108909]|0;ag=a[1108908]|0;ah=c[277219]|0}else{ag=ae;ah=af}}while(0);o=V+7|0;do{if((ag&255)>(d[ah+o|0]|0)){j=a[T]|0;if(j<<24>>24==0){break}b[(c[277218]|0)+(o<<1)>>1]=b[(c[277225]|0)+((j&255)<<1)>>1]|0;a[(c[277219]|0)+o|0]=a[1108909]|0}}while(0);o=U-1|0;if((o|0)<=0){break}T=T-8|0;U=o;V=(c[277223]|0)+V|0}return}else{if(g){ai=i;aj=h;ak=f}else{return}while(1){f=a[1108908]|0;h=c[277219]|0;do{if((f&255)>(d[h+ak|0]|0)){i=a[ai]|0;if(i<<24>>24==0){al=f;am=h;break}b[(c[277218]|0)+(ak<<1)>>1]=b[(c[277225]|0)+((i&255)<<1)>>1]|0;a[(c[277219]|0)+ak|0]=a[1108909]|0;al=a[1108908]|0;am=c[277219]|0}else{al=f;am=h}}while(0);h=ak+1|0;do{if((al&255)>(d[am+h|0]|0)){f=a[ai+1|0]|0;if(f<<24>>24==0){an=al;ao=am;break}b[(c[277218]|0)+(h<<1)>>1]=b[(c[277225]|0)+((f&255)<<1)>>1]|0;a[(c[277219]|0)+h|0]=a[1108909]|0;an=a[1108908]|0;ao=c[277219]|0}else{an=al;ao=am}}while(0);h=ak+2|0;do{if((an&255)>(d[ao+h|0]|0)){f=a[ai+2|0]|0;if(f<<24>>24==0){ap=an;aq=ao;break}b[(c[277218]|0)+(h<<1)>>1]=b[(c[277225]|0)+((f&255)<<1)>>1]|0;a[(c[277219]|0)+h|0]=a[1108909]|0;ap=a[1108908]|0;aq=c[277219]|0}else{ap=an;aq=ao}}while(0);h=ak+3|0;do{if((ap&255)>(d[aq+h|0]|0)){f=a[ai+3|0]|0;if(f<<24>>24==0){ar=ap;as=aq;break}b[(c[277218]|0)+(h<<1)>>1]=b[(c[277225]|0)+((f&255)<<1)>>1]|0;a[(c[277219]|0)+h|0]=a[1108909]|0;ar=a[1108908]|0;as=c[277219]|0}else{ar=ap;as=aq}}while(0);h=ak+4|0;do{if((ar&255)>(d[as+h|0]|0)){f=a[ai+4|0]|0;if(f<<24>>24==0){at=ar;au=as;break}b[(c[277218]|0)+(h<<1)>>1]=b[(c[277225]|0)+((f&255)<<1)>>1]|0;a[(c[277219]|0)+h|0]=a[1108909]|0;at=a[1108908]|0;au=c[277219]|0}else{at=ar;au=as}}while(0);h=ak+5|0;do{if((at&255)>(d[au+h|0]|0)){f=a[ai+5|0]|0;if(f<<24>>24==0){av=at;aw=au;break}b[(c[277218]|0)+(h<<1)>>1]=b[(c[277225]|0)+((f&255)<<1)>>1]|0;a[(c[277219]|0)+h|0]=a[1108909]|0;av=a[1108908]|0;aw=c[277219]|0}else{av=at;aw=au}}while(0);h=ak+6|0;do{if((av&255)>(d[aw+h|0]|0)){f=a[ai+6|0]|0;if(f<<24>>24==0){ax=av;ay=aw;break}b[(c[277218]|0)+(h<<1)>>1]=b[(c[277225]|0)+((f&255)<<1)>>1]|0;a[(c[277219]|0)+h|0]=a[1108909]|0;ax=a[1108908]|0;ay=c[277219]|0}else{ax=av;ay=aw}}while(0);h=ak+7|0;do{if((ax&255)>(d[ay+h|0]|0)){f=a[ai+7|0]|0;if(f<<24>>24==0){break}b[(c[277218]|0)+(h<<1)>>1]=b[(c[277225]|0)+((f&255)<<1)>>1]|0;a[(c[277219]|0)+h|0]=a[1108909]|0}}while(0);h=aj-1|0;if((h|0)<=0){break}ai=ai-8|0;aj=h;ak=(c[277223]|0)+ak|0}return}}function Xs(f,g,h,i){f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0;j=f&1023;k=c[348606]|0;l=(j<<k)+(c[348604]|0)|0;if((f&256|0)==0){m=l}else{m=(c[348602]|0)+l|0}l=m&65535;m=l>>>(k>>>0);k=(f&16384|0)!=0;n=m<<6;do{if(k){o=(c[348622]|0)+n|0;if((a[(c[348618]|0)+m|0]|0)!=0){p=o;break}q=fi[c[348636]&63](o,l,j)|0;a[(c[348618]|0)+m|0]=q;p=o}else{o=(c[348624]|0)+n|0;if((a[(c[348620]|0)+m|0]|0)!=0){p=o;break}q=fi[c[348638]&63](o,l,j)|0;a[(c[348620]|0)+m|0]=q;p=o}}while(0);if((a[(c[348620]|0)+m|0]|0)==2){return}if((a[1394464]|0)==0){r=1106168+((f>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){m=d[1044485]|0;c[276541]=7080+(m<<5);j=0;do{l=j<<1&2;n=j&2;o=j&4;q=0;do{b[1125528+(j<<9)+(q<<1)>>1]=d[(q>>>1&28|n)+(7080+(m<<5))|0]<<6|d[(q<<2&28|l)+(7080+(m<<5))|0]<<11|d[(q>>>3&24|o)+(7080+(m<<5))|0];q=q+1|0;}while(q>>>0<256);j=j+1|0;}while(j>>>0<8);a[1106089]=0}r=1125528+((f>>>10&7)<<9)|0}c[277226]=r;c[277225]=(a[1108928]|0)!=0?1393712:r;if((f&49152|0)==0){if((i|0)<=0){return}r=p+h|0;j=i;m=g;while(1){q=a[1108908]|0;o=c[277219]|0;do{if((q&255)>(d[o+m|0]|0)){l=a[r]|0;if(l<<24>>24==0){s=q;t=o;break}n=e[(c[277225]|0)+((l&255)<<1)>>1]|0;l=(a[(c[277215]|0)+m|0]&32)==0;if(l){u=c[277228]|0;v=u;w=u&-2082}else{u=e[(c[277213]|0)+(m<<1)>>1]|0;v=u;w=u&63454}if(l){x=c[277228]|0}else{x=e[(c[277213]|0)+(m<<1)>>1]|0}b[(c[277218]|0)+(m<<1)>>1]=((x^n)&2081|e[(c[277220]|0)+((n&2081&v)+((w+(n&63454)|0)>>>1)<<1)>>1])&65535;a[(c[277219]|0)+m|0]=a[1108909]|0;s=a[1108908]|0;t=c[277219]|0}else{s=q;t=o}}while(0);o=m+1|0;do{if((s&255)>(d[t+o|0]|0)){q=a[r+1|0]|0;if(q<<24>>24==0){y=s;z=t;break}n=e[(c[277225]|0)+((q&255)<<1)>>1]|0;q=(a[(c[277215]|0)+o|0]&32)==0;if(q){l=c[277228]|0;A=l;B=l&-2082}else{l=e[(c[277213]|0)+(o<<1)>>1]|0;A=l;B=l&63454}if(q){C=c[277228]|0}else{C=e[(c[277213]|0)+(o<<1)>>1]|0}b[(c[277218]|0)+(o<<1)>>1]=((C^n)&2081|e[(c[277220]|0)+((n&2081&A)+((B+(n&63454)|0)>>>1)<<1)>>1])&65535;a[(c[277219]|0)+o|0]=a[1108909]|0;y=a[1108908]|0;z=c[277219]|0}else{y=s;z=t}}while(0);o=m+2|0;do{if((y&255)>(d[z+o|0]|0)){n=a[r+2|0]|0;if(n<<24>>24==0){D=y;E=z;break}q=e[(c[277225]|0)+((n&255)<<1)>>1]|0;n=(a[(c[277215]|0)+o|0]&32)==0;if(n){l=c[277228]|0;F=l;G=l&-2082}else{l=e[(c[277213]|0)+(o<<1)>>1]|0;F=l;G=l&63454}if(n){H=c[277228]|0}else{H=e[(c[277213]|0)+(o<<1)>>1]|0}b[(c[277218]|0)+(o<<1)>>1]=((H^q)&2081|e[(c[277220]|0)+((q&2081&F)+((G+(q&63454)|0)>>>1)<<1)>>1])&65535;a[(c[277219]|0)+o|0]=a[1108909]|0;D=a[1108908]|0;E=c[277219]|0}else{D=y;E=z}}while(0);o=m+3|0;do{if((D&255)>(d[E+o|0]|0)){q=a[r+3|0]|0;if(q<<24>>24==0){I=D;J=E;break}n=e[(c[277225]|0)+((q&255)<<1)>>1]|0;q=(a[(c[277215]|0)+o|0]&32)==0;if(q){l=c[277228]|0;K=l;L=l&-2082}else{l=e[(c[277213]|0)+(o<<1)>>1]|0;K=l;L=l&63454}if(q){M=c[277228]|0}else{M=e[(c[277213]|0)+(o<<1)>>1]|0}b[(c[277218]|0)+(o<<1)>>1]=((M^n)&2081|e[(c[277220]|0)+((n&2081&K)+((L+(n&63454)|0)>>>1)<<1)>>1])&65535;a[(c[277219]|0)+o|0]=a[1108909]|0;I=a[1108908]|0;J=c[277219]|0}else{I=D;J=E}}while(0);o=m+4|0;do{if((I&255)>(d[J+o|0]|0)){n=a[r+4|0]|0;if(n<<24>>24==0){N=I;O=J;break}q=e[(c[277225]|0)+((n&255)<<1)>>1]|0;n=(a[(c[277215]|0)+o|0]&32)==0;if(n){l=c[277228]|0;P=l;Q=l&-2082}else{l=e[(c[277213]|0)+(o<<1)>>1]|0;P=l;Q=l&63454}if(n){R=c[277228]|0}else{R=e[(c[277213]|0)+(o<<1)>>1]|0}b[(c[277218]|0)+(o<<1)>>1]=((R^q)&2081|e[(c[277220]|0)+((q&2081&P)+((Q+(q&63454)|0)>>>1)<<1)>>1])&65535;a[(c[277219]|0)+o|0]=a[1108909]|0;N=a[1108908]|0;O=c[277219]|0}else{N=I;O=J}}while(0);o=m+5|0;do{if((N&255)>(d[O+o|0]|0)){q=a[r+5|0]|0;if(q<<24>>24==0){S=N;T=O;break}n=e[(c[277225]|0)+((q&255)<<1)>>1]|0;q=(a[(c[277215]|0)+o|0]&32)==0;if(q){l=c[277228]|0;U=l;V=l&-2082}else{l=e[(c[277213]|0)+(o<<1)>>1]|0;U=l;V=l&63454}if(q){W=c[277228]|0}else{W=e[(c[277213]|0)+(o<<1)>>1]|0}b[(c[277218]|0)+(o<<1)>>1]=((W^n)&2081|e[(c[277220]|0)+((n&2081&U)+((V+(n&63454)|0)>>>1)<<1)>>1])&65535;a[(c[277219]|0)+o|0]=a[1108909]|0;S=a[1108908]|0;T=c[277219]|0}else{S=N;T=O}}while(0);o=m+6|0;do{if((S&255)>(d[T+o|0]|0)){n=a[r+6|0]|0;if(n<<24>>24==0){X=S;Y=T;break}q=e[(c[277225]|0)+((n&255)<<1)>>1]|0;n=(a[(c[277215]|0)+o|0]&32)==0;if(n){l=c[277228]|0;Z=l;_=l&-2082}else{l=e[(c[277213]|0)+(o<<1)>>1]|0;Z=l;_=l&63454}if(n){$=c[277228]|0}else{$=e[(c[277213]|0)+(o<<1)>>1]|0}b[(c[277218]|0)+(o<<1)>>1]=(($^q)&2081|e[(c[277220]|0)+((q&2081&Z)+((_+(q&63454)|0)>>>1)<<1)>>1])&65535;a[(c[277219]|0)+o|0]=a[1108909]|0;X=a[1108908]|0;Y=c[277219]|0}else{X=S;Y=T}}while(0);o=m+7|0;do{if((X&255)>(d[Y+o|0]|0)){q=a[r+7|0]|0;if(q<<24>>24==0){break}n=e[(c[277225]|0)+((q&255)<<1)>>1]|0;q=(a[(c[277215]|0)+o|0]&32)==0;if(q){l=c[277228]|0;aa=l;ab=l&-2082}else{l=e[(c[277213]|0)+(o<<1)>>1]|0;aa=l;ab=l&63454}if(q){ac=c[277228]|0}else{ac=e[(c[277213]|0)+(o<<1)>>1]|0}b[(c[277218]|0)+(o<<1)>>1]=((ac^n)&2081|e[(c[277220]|0)+((n&2081&aa)+((ab+(n&63454)|0)>>>1)<<1)>>1])&65535;a[(c[277219]|0)+o|0]=a[1108909]|0}}while(0);o=j-1|0;if((o|0)<=0){break}r=r+8|0;j=o;m=(c[277223]|0)+m|0}return}if((f&32768|0)==0){if((i|0)<=0){return}f=p+h|0;m=i;j=g;while(1){r=a[1108908]|0;ab=c[277219]|0;do{if((r&255)>(d[ab+j|0]|0)){aa=a[f+7|0]|0;if(aa<<24>>24==0){ad=r;ae=ab;break}ac=e[(c[277225]|0)+((aa&255)<<1)>>1]|0;aa=(a[(c[277215]|0)+j|0]&32)==0;if(aa){Y=c[277228]|0;af=Y;ag=Y&-2082}else{Y=e[(c[277213]|0)+(j<<1)>>1]|0;af=Y;ag=Y&63454}if(aa){ah=c[277228]|0}else{ah=e[(c[277213]|0)+(j<<1)>>1]|0}b[(c[277218]|0)+(j<<1)>>1]=((ah^ac)&2081|e[(c[277220]|0)+((ac&2081&af)+((ag+(ac&63454)|0)>>>1)<<1)>>1])&65535;a[(c[277219]|0)+j|0]=a[1108909]|0;ad=a[1108908]|0;ae=c[277219]|0}else{ad=r;ae=ab}}while(0);ab=j+1|0;do{if((ad&255)>(d[ae+ab|0]|0)){r=a[f+6|0]|0;if(r<<24>>24==0){ai=ad;aj=ae;break}ac=e[(c[277225]|0)+((r&255)<<1)>>1]|0;r=(a[(c[277215]|0)+ab|0]&32)==0;if(r){aa=c[277228]|0;ak=aa;al=aa&-2082}else{aa=e[(c[277213]|0)+(ab<<1)>>1]|0;ak=aa;al=aa&63454}if(r){am=c[277228]|0}else{am=e[(c[277213]|0)+(ab<<1)>>1]|0}b[(c[277218]|0)+(ab<<1)>>1]=((am^ac)&2081|e[(c[277220]|0)+((ac&2081&ak)+((al+(ac&63454)|0)>>>1)<<1)>>1])&65535;a[(c[277219]|0)+ab|0]=a[1108909]|0;ai=a[1108908]|0;aj=c[277219]|0}else{ai=ad;aj=ae}}while(0);ab=j+2|0;do{if((ai&255)>(d[aj+ab|0]|0)){ac=a[f+5|0]|0;if(ac<<24>>24==0){an=ai;ao=aj;break}r=e[(c[277225]|0)+((ac&255)<<1)>>1]|0;ac=(a[(c[277215]|0)+ab|0]&32)==0;if(ac){aa=c[277228]|0;ap=aa;aq=aa&-2082}else{aa=e[(c[277213]|0)+(ab<<1)>>1]|0;ap=aa;aq=aa&63454}if(ac){ar=c[277228]|0}else{ar=e[(c[277213]|0)+(ab<<1)>>1]|0}b[(c[277218]|0)+(ab<<1)>>1]=((ar^r)&2081|e[(c[277220]|0)+((r&2081&ap)+((aq+(r&63454)|0)>>>1)<<1)>>1])&65535;a[(c[277219]|0)+ab|0]=a[1108909]|0;an=a[1108908]|0;ao=c[277219]|0}else{an=ai;ao=aj}}while(0);ab=j+3|0;do{if((an&255)>(d[ao+ab|0]|0)){r=a[f+4|0]|0;if(r<<24>>24==0){as=an;at=ao;break}ac=e[(c[277225]|0)+((r&255)<<1)>>1]|0;r=(a[(c[277215]|0)+ab|0]&32)==0;if(r){aa=c[277228]|0;au=aa;av=aa&-2082}else{aa=e[(c[277213]|0)+(ab<<1)>>1]|0;au=aa;av=aa&63454}if(r){aw=c[277228]|0}else{aw=e[(c[277213]|0)+(ab<<1)>>1]|0}b[(c[277218]|0)+(ab<<1)>>1]=((aw^ac)&2081|e[(c[277220]|0)+((ac&2081&au)+((av+(ac&63454)|0)>>>1)<<1)>>1])&65535;a[(c[277219]|0)+ab|0]=a[1108909]|0;as=a[1108908]|0;at=c[277219]|0}else{as=an;at=ao}}while(0);ab=j+4|0;do{if((as&255)>(d[at+ab|0]|0)){ac=a[f+3|0]|0;if(ac<<24>>24==0){ax=as;ay=at;break}r=e[(c[277225]|0)+((ac&255)<<1)>>1]|0;ac=(a[(c[277215]|0)+ab|0]&32)==0;if(ac){aa=c[277228]|0;az=aa;aA=aa&-2082}else{aa=e[(c[277213]|0)+(ab<<1)>>1]|0;az=aa;aA=aa&63454}if(ac){aB=c[277228]|0}else{aB=e[(c[277213]|0)+(ab<<1)>>1]|0}b[(c[277218]|0)+(ab<<1)>>1]=((aB^r)&2081|e[(c[277220]|0)+((r&2081&az)+((aA+(r&63454)|0)>>>1)<<1)>>1])&65535;a[(c[277219]|0)+ab|0]=a[1108909]|0;ax=a[1108908]|0;ay=c[277219]|0}else{ax=as;ay=at}}while(0);ab=j+5|0;do{if((ax&255)>(d[ay+ab|0]|0)){r=a[f+2|0]|0;if(r<<24>>24==0){aC=ax;aD=ay;break}ac=e[(c[277225]|0)+((r&255)<<1)>>1]|0;r=(a[(c[277215]|0)+ab|0]&32)==0;if(r){aa=c[277228]|0;aE=aa;aF=aa&-2082}else{aa=e[(c[277213]|0)+(ab<<1)>>1]|0;aE=aa;aF=aa&63454}if(r){aG=c[277228]|0}else{aG=e[(c[277213]|0)+(ab<<1)>>1]|0}b[(c[277218]|0)+(ab<<1)>>1]=((aG^ac)&2081|e[(c[277220]|0)+((ac&2081&aE)+((aF+(ac&63454)|0)>>>1)<<1)>>1])&65535;a[(c[277219]|0)+ab|0]=a[1108909]|0;aC=a[1108908]|0;aD=c[277219]|0}else{aC=ax;aD=ay}}while(0);ab=j+6|0;do{if((aC&255)>(d[aD+ab|0]|0)){ac=a[f+1|0]|0;if(ac<<24>>24==0){aH=aC;aI=aD;break}r=e[(c[277225]|0)+((ac&255)<<1)>>1]|0;ac=(a[(c[277215]|0)+ab|0]&32)==0;if(ac){aa=c[277228]|0;aJ=aa;aK=aa&-2082}else{aa=e[(c[277213]|0)+(ab<<1)>>1]|0;aJ=aa;aK=aa&63454}if(ac){aL=c[277228]|0}else{aL=e[(c[277213]|0)+(ab<<1)>>1]|0}b[(c[277218]|0)+(ab<<1)>>1]=((aL^r)&2081|e[(c[277220]|0)+((r&2081&aJ)+((aK+(r&63454)|0)>>>1)<<1)>>1])&65535;a[(c[277219]|0)+ab|0]=a[1108909]|0;aH=a[1108908]|0;aI=c[277219]|0}else{aH=aC;aI=aD}}while(0);ab=j+7|0;do{if((aH&255)>(d[aI+ab|0]|0)){r=a[f]|0;if(r<<24>>24==0){break}ac=e[(c[277225]|0)+((r&255)<<1)>>1]|0;r=(a[(c[277215]|0)+ab|0]&32)==0;if(r){aa=c[277228]|0;aM=aa;aN=aa&-2082}else{aa=e[(c[277213]|0)+(ab<<1)>>1]|0;aM=aa;aN=aa&63454}if(r){aO=c[277228]|0}else{aO=e[(c[277213]|0)+(ab<<1)>>1]|0}b[(c[277218]|0)+(ab<<1)>>1]=((aO^ac)&2081|e[(c[277220]|0)+((ac&2081&aM)+((aN+(ac&63454)|0)>>>1)<<1)>>1])&65535;a[(c[277219]|0)+ab|0]=a[1108909]|0}}while(0);ab=m-1|0;if((ab|0)<=0){break}f=f+8|0;m=ab;j=(c[277223]|0)+j|0}return}j=p+(56-h)|0;h=(i|0)>0;if(k){if(h){aP=j;aQ=i;aR=g}else{return}while(1){k=a[1108908]|0;p=c[277219]|0;do{if((k&255)>(d[p+aR|0]|0)){m=a[aP+7|0]|0;if(m<<24>>24==0){aS=k;aT=p;break}f=e[(c[277225]|0)+((m&255)<<1)>>1]|0;m=(a[(c[277215]|0)+aR|0]&32)==0;if(m){aN=c[277228]|0;aU=aN;aV=aN&-2082}else{aN=e[(c[277213]|0)+(aR<<1)>>1]|0;aU=aN;aV=aN&63454}if(m){aW=c[277228]|0}else{aW=e[(c[277213]|0)+(aR<<1)>>1]|0}b[(c[277218]|0)+(aR<<1)>>1]=((aW^f)&2081|e[(c[277220]|0)+((f&2081&aU)+((aV+(f&63454)|0)>>>1)<<1)>>1])&65535;a[(c[277219]|0)+aR|0]=a[1108909]|0;aS=a[1108908]|0;aT=c[277219]|0}else{aS=k;aT=p}}while(0);p=aR+1|0;do{if((aS&255)>(d[aT+p|0]|0)){k=a[aP+6|0]|0;if(k<<24>>24==0){aX=aS;aY=aT;break}f=e[(c[277225]|0)+((k&255)<<1)>>1]|0;k=(a[(c[277215]|0)+p|0]&32)==0;if(k){m=c[277228]|0;aZ=m;a_=m&-2082}else{m=e[(c[277213]|0)+(p<<1)>>1]|0;aZ=m;a_=m&63454}if(k){a$=c[277228]|0}else{a$=e[(c[277213]|0)+(p<<1)>>1]|0}b[(c[277218]|0)+(p<<1)>>1]=((a$^f)&2081|e[(c[277220]|0)+((f&2081&aZ)+((a_+(f&63454)|0)>>>1)<<1)>>1])&65535;a[(c[277219]|0)+p|0]=a[1108909]|0;aX=a[1108908]|0;aY=c[277219]|0}else{aX=aS;aY=aT}}while(0);p=aR+2|0;do{if((aX&255)>(d[aY+p|0]|0)){f=a[aP+5|0]|0;if(f<<24>>24==0){a0=aX;a1=aY;break}k=e[(c[277225]|0)+((f&255)<<1)>>1]|0;f=(a[(c[277215]|0)+p|0]&32)==0;if(f){m=c[277228]|0;a2=m;a3=m&-2082}else{m=e[(c[277213]|0)+(p<<1)>>1]|0;a2=m;a3=m&63454}if(f){a4=c[277228]|0}else{a4=e[(c[277213]|0)+(p<<1)>>1]|0}b[(c[277218]|0)+(p<<1)>>1]=((a4^k)&2081|e[(c[277220]|0)+((k&2081&a2)+((a3+(k&63454)|0)>>>1)<<1)>>1])&65535;a[(c[277219]|0)+p|0]=a[1108909]|0;a0=a[1108908]|0;a1=c[277219]|0}else{a0=aX;a1=aY}}while(0);p=aR+3|0;do{if((a0&255)>(d[a1+p|0]|0)){k=a[aP+4|0]|0;if(k<<24>>24==0){a5=a0;a6=a1;break}f=e[(c[277225]|0)+((k&255)<<1)>>1]|0;k=(a[(c[277215]|0)+p|0]&32)==0;if(k){m=c[277228]|0;a7=m;a8=m&-2082}else{m=e[(c[277213]|0)+(p<<1)>>1]|0;a7=m;a8=m&63454}if(k){a9=c[277228]|0}else{a9=e[(c[277213]|0)+(p<<1)>>1]|0}b[(c[277218]|0)+(p<<1)>>1]=((a9^f)&2081|e[(c[277220]|0)+((f&2081&a7)+((a8+(f&63454)|0)>>>1)<<1)>>1])&65535;a[(c[277219]|0)+p|0]=a[1108909]|0;a5=a[1108908]|0;a6=c[277219]|0}else{a5=a0;a6=a1}}while(0);p=aR+4|0;do{if((a5&255)>(d[a6+p|0]|0)){f=a[aP+3|0]|0;if(f<<24>>24==0){ba=a5;bb=a6;break}k=e[(c[277225]|0)+((f&255)<<1)>>1]|0;f=(a[(c[277215]|0)+p|0]&32)==0;if(f){m=c[277228]|0;bc=m;bd=m&-2082}else{m=e[(c[277213]|0)+(p<<1)>>1]|0;bc=m;bd=m&63454}if(f){be=c[277228]|0}else{be=e[(c[277213]|0)+(p<<1)>>1]|0}b[(c[277218]|0)+(p<<1)>>1]=((be^k)&2081|e[(c[277220]|0)+((k&2081&bc)+((bd+(k&63454)|0)>>>1)<<1)>>1])&65535;a[(c[277219]|0)+p|0]=a[1108909]|0;ba=a[1108908]|0;bb=c[277219]|0}else{ba=a5;bb=a6}}while(0);p=aR+5|0;do{if((ba&255)>(d[bb+p|0]|0)){k=a[aP+2|0]|0;if(k<<24>>24==0){bf=ba;bg=bb;break}f=e[(c[277225]|0)+((k&255)<<1)>>1]|0;k=(a[(c[277215]|0)+p|0]&32)==0;if(k){m=c[277228]|0;bh=m;bi=m&-2082}else{m=e[(c[277213]|0)+(p<<1)>>1]|0;bh=m;bi=m&63454}if(k){bj=c[277228]|0}else{bj=e[(c[277213]|0)+(p<<1)>>1]|0}b[(c[277218]|0)+(p<<1)>>1]=((bj^f)&2081|e[(c[277220]|0)+((f&2081&bh)+((bi+(f&63454)|0)>>>1)<<1)>>1])&65535;a[(c[277219]|0)+p|0]=a[1108909]|0;bf=a[1108908]|0;bg=c[277219]|0}else{bf=ba;bg=bb}}while(0);p=aR+6|0;do{if((bf&255)>(d[bg+p|0]|0)){f=a[aP+1|0]|0;if(f<<24>>24==0){bk=bf;bl=bg;break}k=e[(c[277225]|0)+((f&255)<<1)>>1]|0;f=(a[(c[277215]|0)+p|0]&32)==0;if(f){m=c[277228]|0;bm=m;bn=m&-2082}else{m=e[(c[277213]|0)+(p<<1)>>1]|0;bm=m;bn=m&63454}if(f){bo=c[277228]|0}else{bo=e[(c[277213]|0)+(p<<1)>>1]|0}b[(c[277218]|0)+(p<<1)>>1]=((bo^k)&2081|e[(c[277220]|0)+((k&2081&bm)+((bn+(k&63454)|0)>>>1)<<1)>>1])&65535;a[(c[277219]|0)+p|0]=a[1108909]|0;bk=a[1108908]|0;bl=c[277219]|0}else{bk=bf;bl=bg}}while(0);p=aR+7|0;do{if((bk&255)>(d[bl+p|0]|0)){k=a[aP]|0;if(k<<24>>24==0){break}f=e[(c[277225]|0)+((k&255)<<1)>>1]|0;k=(a[(c[277215]|0)+p|0]&32)==0;if(k){m=c[277228]|0;bp=m;bq=m&-2082}else{m=e[(c[277213]|0)+(p<<1)>>1]|0;bp=m;bq=m&63454}if(k){br=c[277228]|0}else{br=e[(c[277213]|0)+(p<<1)>>1]|0}b[(c[277218]|0)+(p<<1)>>1]=((br^f)&2081|e[(c[277220]|0)+((f&2081&bp)+((bq+(f&63454)|0)>>>1)<<1)>>1])&65535;a[(c[277219]|0)+p|0]=a[1108909]|0}}while(0);p=aQ-1|0;if((p|0)<=0){break}aP=aP-8|0;aQ=p;aR=(c[277223]|0)+aR|0}return}else{if(h){bs=j;bt=i;bu=g}else{return}while(1){g=a[1108908]|0;i=c[277219]|0;do{if((g&255)>(d[i+bu|0]|0)){j=a[bs]|0;if(j<<24>>24==0){bv=g;bw=i;break}h=e[(c[277225]|0)+((j&255)<<1)>>1]|0;j=(a[(c[277215]|0)+bu|0]&32)==0;if(j){aR=c[277228]|0;bx=aR;by=aR&-2082}else{aR=e[(c[277213]|0)+(bu<<1)>>1]|0;bx=aR;by=aR&63454}if(j){bz=c[277228]|0}else{bz=e[(c[277213]|0)+(bu<<1)>>1]|0}b[(c[277218]|0)+(bu<<1)>>1]=((bz^h)&2081|e[(c[277220]|0)+((h&2081&bx)+((by+(h&63454)|0)>>>1)<<1)>>1])&65535;a[(c[277219]|0)+bu|0]=a[1108909]|0;bv=a[1108908]|0;bw=c[277219]|0}else{bv=g;bw=i}}while(0);i=bu+1|0;do{if((bv&255)>(d[bw+i|0]|0)){g=a[bs+1|0]|0;if(g<<24>>24==0){bA=bv;bB=bw;break}h=e[(c[277225]|0)+((g&255)<<1)>>1]|0;g=(a[(c[277215]|0)+i|0]&32)==0;if(g){j=c[277228]|0;bC=j;bD=j&-2082}else{j=e[(c[277213]|0)+(i<<1)>>1]|0;bC=j;bD=j&63454}if(g){bE=c[277228]|0}else{bE=e[(c[277213]|0)+(i<<1)>>1]|0}b[(c[277218]|0)+(i<<1)>>1]=((bE^h)&2081|e[(c[277220]|0)+((h&2081&bC)+((bD+(h&63454)|0)>>>1)<<1)>>1])&65535;a[(c[277219]|0)+i|0]=a[1108909]|0;bA=a[1108908]|0;bB=c[277219]|0}else{bA=bv;bB=bw}}while(0);i=bu+2|0;do{if((bA&255)>(d[bB+i|0]|0)){h=a[bs+2|0]|0;if(h<<24>>24==0){bF=bA;bG=bB;break}g=e[(c[277225]|0)+((h&255)<<1)>>1]|0;h=(a[(c[277215]|0)+i|0]&32)==0;if(h){j=c[277228]|0;bH=j;bI=j&-2082}else{j=e[(c[277213]|0)+(i<<1)>>1]|0;bH=j;bI=j&63454}if(h){bJ=c[277228]|0}else{bJ=e[(c[277213]|0)+(i<<1)>>1]|0}b[(c[277218]|0)+(i<<1)>>1]=((bJ^g)&2081|e[(c[277220]|0)+((g&2081&bH)+((bI+(g&63454)|0)>>>1)<<1)>>1])&65535;a[(c[277219]|0)+i|0]=a[1108909]|0;bF=a[1108908]|0;bG=c[277219]|0}else{bF=bA;bG=bB}}while(0);i=bu+3|0;do{if((bF&255)>(d[bG+i|0]|0)){g=a[bs+3|0]|0;if(g<<24>>24==0){bK=bF;bL=bG;break}h=e[(c[277225]|0)+((g&255)<<1)>>1]|0;g=(a[(c[277215]|0)+i|0]&32)==0;if(g){j=c[277228]|0;bM=j;bN=j&-2082}else{j=e[(c[277213]|0)+(i<<1)>>1]|0;bM=j;bN=j&63454}if(g){bO=c[277228]|0}else{bO=e[(c[277213]|0)+(i<<1)>>1]|0}b[(c[277218]|0)+(i<<1)>>1]=((bO^h)&2081|e[(c[277220]|0)+((h&2081&bM)+((bN+(h&63454)|0)>>>1)<<1)>>1])&65535;a[(c[277219]|0)+i|0]=a[1108909]|0;bK=a[1108908]|0;bL=c[277219]|0}else{bK=bF;bL=bG}}while(0);i=bu+4|0;do{if((bK&255)>(d[bL+i|0]|0)){h=a[bs+4|0]|0;if(h<<24>>24==0){bP=bK;bQ=bL;break}g=e[(c[277225]|0)+((h&255)<<1)>>1]|0;h=(a[(c[277215]|0)+i|0]&32)==0;if(h){j=c[277228]|0;bR=j;bS=j&-2082}else{j=e[(c[277213]|0)+(i<<1)>>1]|0;bR=j;bS=j&63454}if(h){bT=c[277228]|0}else{bT=e[(c[277213]|0)+(i<<1)>>1]|0}b[(c[277218]|0)+(i<<1)>>1]=((bT^g)&2081|e[(c[277220]|0)+((g&2081&bR)+((bS+(g&63454)|0)>>>1)<<1)>>1])&65535;a[(c[277219]|0)+i|0]=a[1108909]|0;bP=a[1108908]|0;bQ=c[277219]|0}else{bP=bK;bQ=bL}}while(0);i=bu+5|0;do{if((bP&255)>(d[bQ+i|0]|0)){g=a[bs+5|0]|0;if(g<<24>>24==0){bU=bP;bV=bQ;break}h=e[(c[277225]|0)+((g&255)<<1)>>1]|0;g=(a[(c[277215]|0)+i|0]&32)==0;if(g){j=c[277228]|0;bW=j;bX=j&-2082}else{j=e[(c[277213]|0)+(i<<1)>>1]|0;bW=j;bX=j&63454}if(g){bY=c[277228]|0}else{bY=e[(c[277213]|0)+(i<<1)>>1]|0}b[(c[277218]|0)+(i<<1)>>1]=((bY^h)&2081|e[(c[277220]|0)+((h&2081&bW)+((bX+(h&63454)|0)>>>1)<<1)>>1])&65535;a[(c[277219]|0)+i|0]=a[1108909]|0;bU=a[1108908]|0;bV=c[277219]|0}else{bU=bP;bV=bQ}}while(0);i=bu+6|0;do{if((bU&255)>(d[bV+i|0]|0)){h=a[bs+6|0]|0;if(h<<24>>24==0){bZ=bU;b_=bV;break}g=e[(c[277225]|0)+((h&255)<<1)>>1]|0;h=(a[(c[277215]|0)+i|0]&32)==0;if(h){j=c[277228]|0;b$=j;b0=j&-2082}else{j=e[(c[277213]|0)+(i<<1)>>1]|0;b$=j;b0=j&63454}if(h){b1=c[277228]|0}else{b1=e[(c[277213]|0)+(i<<1)>>1]|0}b[(c[277218]|0)+(i<<1)>>1]=((b1^g)&2081|e[(c[277220]|0)+((g&2081&b$)+((b0+(g&63454)|0)>>>1)<<1)>>1])&65535;a[(c[277219]|0)+i|0]=a[1108909]|0;bZ=a[1108908]|0;b_=c[277219]|0}else{bZ=bU;b_=bV}}while(0);i=bu+7|0;do{if((bZ&255)>(d[b_+i|0]|0)){g=a[bs+7|0]|0;if(g<<24>>24==0){break}h=e[(c[277225]|0)+((g&255)<<1)>>1]|0;g=(a[(c[277215]|0)+i|0]&32)==0;if(g){j=c[277228]|0;b2=j;b3=j&-2082}else{j=e[(c[277213]|0)+(i<<1)>>1]|0;b2=j;b3=j&63454}if(g){b4=c[277228]|0}else{b4=e[(c[277213]|0)+(i<<1)>>1]|0}b[(c[277218]|0)+(i<<1)>>1]=((b4^h)&2081|e[(c[277220]|0)+((h&2081&b2)+((b3+(h&63454)|0)>>>1)<<1)>>1])&65535;a[(c[277219]|0)+i|0]=a[1108909]|0}}while(0);i=bt-1|0;if((i|0)<=0){break}bs=bs-8|0;bt=i;bu=(c[277223]|0)+bu|0}return}}function Xt(f,g,h,i){f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0;j=f&1023;k=c[348606]|0;l=(j<<k)+(c[348604]|0)|0;if((f&256|0)==0){m=l}else{m=(c[348602]|0)+l|0}l=m&65535;m=l>>>(k>>>0);k=(f&16384|0)!=0;n=m<<6;do{if(k){o=(c[348622]|0)+n|0;if((a[(c[348618]|0)+m|0]|0)!=0){p=o;break}q=fi[c[348636]&63](o,l,j)|0;a[(c[348618]|0)+m|0]=q;p=o}else{o=(c[348624]|0)+n|0;if((a[(c[348620]|0)+m|0]|0)!=0){p=o;break}q=fi[c[348638]&63](o,l,j)|0;a[(c[348620]|0)+m|0]=q;p=o}}while(0);if((a[(c[348620]|0)+m|0]|0)==2){return}if((a[1394464]|0)==0){r=1106168+((f>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){m=d[1044485]|0;c[276541]=7080+(m<<5);j=0;do{l=j<<1&2;n=j&2;o=j&4;q=0;do{b[1125528+(j<<9)+(q<<1)>>1]=d[(q>>>1&28|n)+(7080+(m<<5))|0]<<6|d[(q<<2&28|l)+(7080+(m<<5))|0]<<11|d[(q>>>3&24|o)+(7080+(m<<5))|0];q=q+1|0;}while(q>>>0<256);j=j+1|0;}while(j>>>0<8);a[1106089]=0}r=1125528+((f>>>10&7)<<9)|0}c[277226]=r;c[277225]=(a[1108928]|0)!=0?1393712:r;if((f&49152|0)==0){if((i|0)<=0){return}r=p+h|0;j=i;m=g;while(1){q=a[1108908]|0;o=c[277219]|0;do{if((q&255)>(d[o+m|0]|0)){l=a[r]|0;if(l<<24>>24==0){s=q;t=o;break}n=e[(c[277225]|0)+((l&255)<<1)>>1]|0;l=c[277228]|0;u=(((n&63454)+(l&-2082)|0)>>>1)+(l&2081&n)|0;if((a[1108928]|0)==0){v=u&65535}else{v=(e[(c[277220]|0)+(u<<1)>>1]|(n^l)&2081)&65535}b[(c[277218]|0)+(m<<1)>>1]=v;a[(c[277219]|0)+m|0]=a[1108909]|0;s=a[1108908]|0;t=c[277219]|0}else{s=q;t=o}}while(0);o=m+1|0;do{if((s&255)>(d[t+o|0]|0)){q=a[r+1|0]|0;if(q<<24>>24==0){w=s;x=t;break}l=e[(c[277225]|0)+((q&255)<<1)>>1]|0;q=c[277228]|0;n=(((l&63454)+(q&-2082)|0)>>>1)+(q&2081&l)|0;if((a[1108928]|0)==0){y=n&65535}else{y=(e[(c[277220]|0)+(n<<1)>>1]|(l^q)&2081)&65535}b[(c[277218]|0)+(o<<1)>>1]=y;a[(c[277219]|0)+o|0]=a[1108909]|0;w=a[1108908]|0;x=c[277219]|0}else{w=s;x=t}}while(0);o=m+2|0;do{if((w&255)>(d[x+o|0]|0)){q=a[r+2|0]|0;if(q<<24>>24==0){z=w;A=x;break}l=e[(c[277225]|0)+((q&255)<<1)>>1]|0;q=c[277228]|0;n=(((l&63454)+(q&-2082)|0)>>>1)+(q&2081&l)|0;if((a[1108928]|0)==0){B=n&65535}else{B=(e[(c[277220]|0)+(n<<1)>>1]|(l^q)&2081)&65535}b[(c[277218]|0)+(o<<1)>>1]=B;a[(c[277219]|0)+o|0]=a[1108909]|0;z=a[1108908]|0;A=c[277219]|0}else{z=w;A=x}}while(0);o=m+3|0;do{if((z&255)>(d[A+o|0]|0)){q=a[r+3|0]|0;if(q<<24>>24==0){C=z;D=A;break}l=e[(c[277225]|0)+((q&255)<<1)>>1]|0;q=c[277228]|0;n=(((l&63454)+(q&-2082)|0)>>>1)+(q&2081&l)|0;if((a[1108928]|0)==0){E=n&65535}else{E=(e[(c[277220]|0)+(n<<1)>>1]|(l^q)&2081)&65535}b[(c[277218]|0)+(o<<1)>>1]=E;a[(c[277219]|0)+o|0]=a[1108909]|0;C=a[1108908]|0;D=c[277219]|0}else{C=z;D=A}}while(0);o=m+4|0;do{if((C&255)>(d[D+o|0]|0)){q=a[r+4|0]|0;if(q<<24>>24==0){F=C;G=D;break}l=e[(c[277225]|0)+((q&255)<<1)>>1]|0;q=c[277228]|0;n=(((l&63454)+(q&-2082)|0)>>>1)+(q&2081&l)|0;if((a[1108928]|0)==0){H=n&65535}else{H=(e[(c[277220]|0)+(n<<1)>>1]|(l^q)&2081)&65535}b[(c[277218]|0)+(o<<1)>>1]=H;a[(c[277219]|0)+o|0]=a[1108909]|0;F=a[1108908]|0;G=c[277219]|0}else{F=C;G=D}}while(0);o=m+5|0;do{if((F&255)>(d[G+o|0]|0)){q=a[r+5|0]|0;if(q<<24>>24==0){I=F;J=G;break}l=e[(c[277225]|0)+((q&255)<<1)>>1]|0;q=c[277228]|0;n=(((l&63454)+(q&-2082)|0)>>>1)+(q&2081&l)|0;if((a[1108928]|0)==0){K=n&65535}else{K=(e[(c[277220]|0)+(n<<1)>>1]|(l^q)&2081)&65535}b[(c[277218]|0)+(o<<1)>>1]=K;a[(c[277219]|0)+o|0]=a[1108909]|0;I=a[1108908]|0;J=c[277219]|0}else{I=F;J=G}}while(0);o=m+6|0;do{if((I&255)>(d[J+o|0]|0)){q=a[r+6|0]|0;if(q<<24>>24==0){L=I;M=J;break}l=e[(c[277225]|0)+((q&255)<<1)>>1]|0;q=c[277228]|0;n=(((l&63454)+(q&-2082)|0)>>>1)+(q&2081&l)|0;if((a[1108928]|0)==0){N=n&65535}else{N=(e[(c[277220]|0)+(n<<1)>>1]|(l^q)&2081)&65535}b[(c[277218]|0)+(o<<1)>>1]=N;a[(c[277219]|0)+o|0]=a[1108909]|0;L=a[1108908]|0;M=c[277219]|0}else{L=I;M=J}}while(0);o=m+7|0;do{if((L&255)>(d[M+o|0]|0)){q=a[r+7|0]|0;if(q<<24>>24==0){break}l=e[(c[277225]|0)+((q&255)<<1)>>1]|0;q=c[277228]|0;n=(((l&63454)+(q&-2082)|0)>>>1)+(q&2081&l)|0;if((a[1108928]|0)==0){O=n&65535}else{O=(e[(c[277220]|0)+(n<<1)>>1]|(l^q)&2081)&65535}b[(c[277218]|0)+(o<<1)>>1]=O;a[(c[277219]|0)+o|0]=a[1108909]|0}}while(0);o=j-1|0;if((o|0)<=0){break}r=r+8|0;j=o;m=(c[277223]|0)+m|0}return}if((f&32768|0)==0){if((i|0)<=0){return}f=p+h|0;m=i;j=g;while(1){r=a[1108908]|0;O=c[277219]|0;do{if((r&255)>(d[O+j|0]|0)){M=a[f+7|0]|0;if(M<<24>>24==0){P=r;Q=O;break}L=e[(c[277225]|0)+((M&255)<<1)>>1]|0;M=c[277228]|0;J=(((L&63454)+(M&-2082)|0)>>>1)+(M&2081&L)|0;if((a[1108928]|0)==0){R=J&65535}else{R=(e[(c[277220]|0)+(J<<1)>>1]|(L^M)&2081)&65535}b[(c[277218]|0)+(j<<1)>>1]=R;a[(c[277219]|0)+j|0]=a[1108909]|0;P=a[1108908]|0;Q=c[277219]|0}else{P=r;Q=O}}while(0);O=j+1|0;do{if((P&255)>(d[Q+O|0]|0)){r=a[f+6|0]|0;if(r<<24>>24==0){S=P;T=Q;break}M=e[(c[277225]|0)+((r&255)<<1)>>1]|0;r=c[277228]|0;L=(((M&63454)+(r&-2082)|0)>>>1)+(r&2081&M)|0;if((a[1108928]|0)==0){U=L&65535}else{U=(e[(c[277220]|0)+(L<<1)>>1]|(M^r)&2081)&65535}b[(c[277218]|0)+(O<<1)>>1]=U;a[(c[277219]|0)+O|0]=a[1108909]|0;S=a[1108908]|0;T=c[277219]|0}else{S=P;T=Q}}while(0);O=j+2|0;do{if((S&255)>(d[T+O|0]|0)){r=a[f+5|0]|0;if(r<<24>>24==0){V=S;W=T;break}M=e[(c[277225]|0)+((r&255)<<1)>>1]|0;r=c[277228]|0;L=(((M&63454)+(r&-2082)|0)>>>1)+(r&2081&M)|0;if((a[1108928]|0)==0){X=L&65535}else{X=(e[(c[277220]|0)+(L<<1)>>1]|(M^r)&2081)&65535}b[(c[277218]|0)+(O<<1)>>1]=X;a[(c[277219]|0)+O|0]=a[1108909]|0;V=a[1108908]|0;W=c[277219]|0}else{V=S;W=T}}while(0);O=j+3|0;do{if((V&255)>(d[W+O|0]|0)){r=a[f+4|0]|0;if(r<<24>>24==0){Y=V;Z=W;break}M=e[(c[277225]|0)+((r&255)<<1)>>1]|0;r=c[277228]|0;L=(((M&63454)+(r&-2082)|0)>>>1)+(r&2081&M)|0;if((a[1108928]|0)==0){_=L&65535}else{_=(e[(c[277220]|0)+(L<<1)>>1]|(M^r)&2081)&65535}b[(c[277218]|0)+(O<<1)>>1]=_;a[(c[277219]|0)+O|0]=a[1108909]|0;Y=a[1108908]|0;Z=c[277219]|0}else{Y=V;Z=W}}while(0);O=j+4|0;do{if((Y&255)>(d[Z+O|0]|0)){r=a[f+3|0]|0;if(r<<24>>24==0){$=Y;aa=Z;break}M=e[(c[277225]|0)+((r&255)<<1)>>1]|0;r=c[277228]|0;L=(((M&63454)+(r&-2082)|0)>>>1)+(r&2081&M)|0;if((a[1108928]|0)==0){ab=L&65535}else{ab=(e[(c[277220]|0)+(L<<1)>>1]|(M^r)&2081)&65535}b[(c[277218]|0)+(O<<1)>>1]=ab;a[(c[277219]|0)+O|0]=a[1108909]|0;$=a[1108908]|0;aa=c[277219]|0}else{$=Y;aa=Z}}while(0);O=j+5|0;do{if(($&255)>(d[aa+O|0]|0)){r=a[f+2|0]|0;if(r<<24>>24==0){ac=$;ad=aa;break}M=e[(c[277225]|0)+((r&255)<<1)>>1]|0;r=c[277228]|0;L=(((M&63454)+(r&-2082)|0)>>>1)+(r&2081&M)|0;if((a[1108928]|0)==0){ae=L&65535}else{ae=(e[(c[277220]|0)+(L<<1)>>1]|(M^r)&2081)&65535}b[(c[277218]|0)+(O<<1)>>1]=ae;a[(c[277219]|0)+O|0]=a[1108909]|0;ac=a[1108908]|0;ad=c[277219]|0}else{ac=$;ad=aa}}while(0);O=j+6|0;do{if((ac&255)>(d[ad+O|0]|0)){r=a[f+1|0]|0;if(r<<24>>24==0){af=ac;ag=ad;break}M=e[(c[277225]|0)+((r&255)<<1)>>1]|0;r=c[277228]|0;L=(((M&63454)+(r&-2082)|0)>>>1)+(r&2081&M)|0;if((a[1108928]|0)==0){ah=L&65535}else{ah=(e[(c[277220]|0)+(L<<1)>>1]|(M^r)&2081)&65535}b[(c[277218]|0)+(O<<1)>>1]=ah;a[(c[277219]|0)+O|0]=a[1108909]|0;af=a[1108908]|0;ag=c[277219]|0}else{af=ac;ag=ad}}while(0);O=j+7|0;do{if((af&255)>(d[ag+O|0]|0)){r=a[f]|0;if(r<<24>>24==0){break}M=e[(c[277225]|0)+((r&255)<<1)>>1]|0;r=c[277228]|0;L=(((M&63454)+(r&-2082)|0)>>>1)+(r&2081&M)|0;if((a[1108928]|0)==0){ai=L&65535}else{ai=(e[(c[277220]|0)+(L<<1)>>1]|(M^r)&2081)&65535}b[(c[277218]|0)+(O<<1)>>1]=ai;a[(c[277219]|0)+O|0]=a[1108909]|0}}while(0);O=m-1|0;if((O|0)<=0){break}f=f+8|0;m=O;j=(c[277223]|0)+j|0}return}j=p+(56-h)|0;h=(i|0)>0;if(k){if(h){aj=j;ak=i;al=g}else{return}while(1){k=a[1108908]|0;p=c[277219]|0;do{if((k&255)>(d[p+al|0]|0)){m=a[aj+7|0]|0;if(m<<24>>24==0){am=k;an=p;break}f=e[(c[277225]|0)+((m&255)<<1)>>1]|0;m=c[277228]|0;ai=(((f&63454)+(m&-2082)|0)>>>1)+(m&2081&f)|0;if((a[1108928]|0)==0){ao=ai&65535}else{ao=(e[(c[277220]|0)+(ai<<1)>>1]|(f^m)&2081)&65535}b[(c[277218]|0)+(al<<1)>>1]=ao;a[(c[277219]|0)+al|0]=a[1108909]|0;am=a[1108908]|0;an=c[277219]|0}else{am=k;an=p}}while(0);p=al+1|0;do{if((am&255)>(d[an+p|0]|0)){k=a[aj+6|0]|0;if(k<<24>>24==0){ap=am;aq=an;break}m=e[(c[277225]|0)+((k&255)<<1)>>1]|0;k=c[277228]|0;f=(((m&63454)+(k&-2082)|0)>>>1)+(k&2081&m)|0;if((a[1108928]|0)==0){ar=f&65535}else{ar=(e[(c[277220]|0)+(f<<1)>>1]|(m^k)&2081)&65535}b[(c[277218]|0)+(p<<1)>>1]=ar;a[(c[277219]|0)+p|0]=a[1108909]|0;ap=a[1108908]|0;aq=c[277219]|0}else{ap=am;aq=an}}while(0);p=al+2|0;do{if((ap&255)>(d[aq+p|0]|0)){k=a[aj+5|0]|0;if(k<<24>>24==0){as=ap;at=aq;break}m=e[(c[277225]|0)+((k&255)<<1)>>1]|0;k=c[277228]|0;f=(((m&63454)+(k&-2082)|0)>>>1)+(k&2081&m)|0;if((a[1108928]|0)==0){au=f&65535}else{au=(e[(c[277220]|0)+(f<<1)>>1]|(m^k)&2081)&65535}b[(c[277218]|0)+(p<<1)>>1]=au;a[(c[277219]|0)+p|0]=a[1108909]|0;as=a[1108908]|0;at=c[277219]|0}else{as=ap;at=aq}}while(0);p=al+3|0;do{if((as&255)>(d[at+p|0]|0)){k=a[aj+4|0]|0;if(k<<24>>24==0){av=as;aw=at;break}m=e[(c[277225]|0)+((k&255)<<1)>>1]|0;k=c[277228]|0;f=(((m&63454)+(k&-2082)|0)>>>1)+(k&2081&m)|0;if((a[1108928]|0)==0){ax=f&65535}else{ax=(e[(c[277220]|0)+(f<<1)>>1]|(m^k)&2081)&65535}b[(c[277218]|0)+(p<<1)>>1]=ax;a[(c[277219]|0)+p|0]=a[1108909]|0;av=a[1108908]|0;aw=c[277219]|0}else{av=as;aw=at}}while(0);p=al+4|0;do{if((av&255)>(d[aw+p|0]|0)){k=a[aj+3|0]|0;if(k<<24>>24==0){ay=av;az=aw;break}m=e[(c[277225]|0)+((k&255)<<1)>>1]|0;k=c[277228]|0;f=(((m&63454)+(k&-2082)|0)>>>1)+(k&2081&m)|0;if((a[1108928]|0)==0){aA=f&65535}else{aA=(e[(c[277220]|0)+(f<<1)>>1]|(m^k)&2081)&65535}b[(c[277218]|0)+(p<<1)>>1]=aA;a[(c[277219]|0)+p|0]=a[1108909]|0;ay=a[1108908]|0;az=c[277219]|0}else{ay=av;az=aw}}while(0);p=al+5|0;do{if((ay&255)>(d[az+p|0]|0)){k=a[aj+2|0]|0;if(k<<24>>24==0){aB=ay;aC=az;break}m=e[(c[277225]|0)+((k&255)<<1)>>1]|0;k=c[277228]|0;f=(((m&63454)+(k&-2082)|0)>>>1)+(k&2081&m)|0;if((a[1108928]|0)==0){aD=f&65535}else{aD=(e[(c[277220]|0)+(f<<1)>>1]|(m^k)&2081)&65535}b[(c[277218]|0)+(p<<1)>>1]=aD;a[(c[277219]|0)+p|0]=a[1108909]|0;aB=a[1108908]|0;aC=c[277219]|0}else{aB=ay;aC=az}}while(0);p=al+6|0;do{if((aB&255)>(d[aC+p|0]|0)){k=a[aj+1|0]|0;if(k<<24>>24==0){aE=aB;aF=aC;break}m=e[(c[277225]|0)+((k&255)<<1)>>1]|0;k=c[277228]|0;f=(((m&63454)+(k&-2082)|0)>>>1)+(k&2081&m)|0;if((a[1108928]|0)==0){aG=f&65535}else{aG=(e[(c[277220]|0)+(f<<1)>>1]|(m^k)&2081)&65535}b[(c[277218]|0)+(p<<1)>>1]=aG;a[(c[277219]|0)+p|0]=a[1108909]|0;aE=a[1108908]|0;aF=c[277219]|0}else{aE=aB;aF=aC}}while(0);p=al+7|0;do{if((aE&255)>(d[aF+p|0]|0)){k=a[aj]|0;if(k<<24>>24==0){break}m=e[(c[277225]|0)+((k&255)<<1)>>1]|0;k=c[277228]|0;f=(((m&63454)+(k&-2082)|0)>>>1)+(k&2081&m)|0;if((a[1108928]|0)==0){aH=f&65535}else{aH=(e[(c[277220]|0)+(f<<1)>>1]|(m^k)&2081)&65535}b[(c[277218]|0)+(p<<1)>>1]=aH;a[(c[277219]|0)+p|0]=a[1108909]|0}}while(0);p=ak-1|0;if((p|0)<=0){break}aj=aj-8|0;ak=p;al=(c[277223]|0)+al|0}return}else{if(h){aI=j;aJ=i;aK=g}else{return}while(1){g=a[1108908]|0;i=c[277219]|0;do{if((g&255)>(d[i+aK|0]|0)){j=a[aI]|0;if(j<<24>>24==0){aL=g;aM=i;break}h=e[(c[277225]|0)+((j&255)<<1)>>1]|0;j=c[277228]|0;al=(((h&63454)+(j&-2082)|0)>>>1)+(j&2081&h)|0;if((a[1108928]|0)==0){aN=al&65535}else{aN=(e[(c[277220]|0)+(al<<1)>>1]|(h^j)&2081)&65535}b[(c[277218]|0)+(aK<<1)>>1]=aN;a[(c[277219]|0)+aK|0]=a[1108909]|0;aL=a[1108908]|0;aM=c[277219]|0}else{aL=g;aM=i}}while(0);i=aK+1|0;do{if((aL&255)>(d[aM+i|0]|0)){g=a[aI+1|0]|0;if(g<<24>>24==0){aO=aL;aP=aM;break}j=e[(c[277225]|0)+((g&255)<<1)>>1]|0;g=c[277228]|0;h=(((j&63454)+(g&-2082)|0)>>>1)+(g&2081&j)|0;if((a[1108928]|0)==0){aQ=h&65535}else{aQ=(e[(c[277220]|0)+(h<<1)>>1]|(j^g)&2081)&65535}b[(c[277218]|0)+(i<<1)>>1]=aQ;a[(c[277219]|0)+i|0]=a[1108909]|0;aO=a[1108908]|0;aP=c[277219]|0}else{aO=aL;aP=aM}}while(0);i=aK+2|0;do{if((aO&255)>(d[aP+i|0]|0)){g=a[aI+2|0]|0;if(g<<24>>24==0){aR=aO;aS=aP;break}j=e[(c[277225]|0)+((g&255)<<1)>>1]|0;g=c[277228]|0;h=(((j&63454)+(g&-2082)|0)>>>1)+(g&2081&j)|0;if((a[1108928]|0)==0){aT=h&65535}else{aT=(e[(c[277220]|0)+(h<<1)>>1]|(j^g)&2081)&65535}b[(c[277218]|0)+(i<<1)>>1]=aT;a[(c[277219]|0)+i|0]=a[1108909]|0;aR=a[1108908]|0;aS=c[277219]|0}else{aR=aO;aS=aP}}while(0);i=aK+3|0;do{if((aR&255)>(d[aS+i|0]|0)){g=a[aI+3|0]|0;if(g<<24>>24==0){aU=aR;aV=aS;break}j=e[(c[277225]|0)+((g&255)<<1)>>1]|0;g=c[277228]|0;h=(((j&63454)+(g&-2082)|0)>>>1)+(g&2081&j)|0;if((a[1108928]|0)==0){aW=h&65535}else{aW=(e[(c[277220]|0)+(h<<1)>>1]|(j^g)&2081)&65535}b[(c[277218]|0)+(i<<1)>>1]=aW;a[(c[277219]|0)+i|0]=a[1108909]|0;aU=a[1108908]|0;aV=c[277219]|0}else{aU=aR;aV=aS}}while(0);i=aK+4|0;do{if((aU&255)>(d[aV+i|0]|0)){g=a[aI+4|0]|0;if(g<<24>>24==0){aX=aU;aY=aV;break}j=e[(c[277225]|0)+((g&255)<<1)>>1]|0;g=c[277228]|0;h=(((j&63454)+(g&-2082)|0)>>>1)+(g&2081&j)|0;if((a[1108928]|0)==0){aZ=h&65535}else{aZ=(e[(c[277220]|0)+(h<<1)>>1]|(j^g)&2081)&65535}b[(c[277218]|0)+(i<<1)>>1]=aZ;a[(c[277219]|0)+i|0]=a[1108909]|0;aX=a[1108908]|0;aY=c[277219]|0}else{aX=aU;aY=aV}}while(0);i=aK+5|0;do{if((aX&255)>(d[aY+i|0]|0)){g=a[aI+5|0]|0;if(g<<24>>24==0){a_=aX;a$=aY;break}j=e[(c[277225]|0)+((g&255)<<1)>>1]|0;g=c[277228]|0;h=(((j&63454)+(g&-2082)|0)>>>1)+(g&2081&j)|0;if((a[1108928]|0)==0){a0=h&65535}else{a0=(e[(c[277220]|0)+(h<<1)>>1]|(j^g)&2081)&65535}b[(c[277218]|0)+(i<<1)>>1]=a0;a[(c[277219]|0)+i|0]=a[1108909]|0;a_=a[1108908]|0;a$=c[277219]|0}else{a_=aX;a$=aY}}while(0);i=aK+6|0;do{if((a_&255)>(d[a$+i|0]|0)){g=a[aI+6|0]|0;if(g<<24>>24==0){a1=a_;a2=a$;break}j=e[(c[277225]|0)+((g&255)<<1)>>1]|0;g=c[277228]|0;h=(((j&63454)+(g&-2082)|0)>>>1)+(g&2081&j)|0;if((a[1108928]|0)==0){a3=h&65535}else{a3=(e[(c[277220]|0)+(h<<1)>>1]|(j^g)&2081)&65535}b[(c[277218]|0)+(i<<1)>>1]=a3;a[(c[277219]|0)+i|0]=a[1108909]|0;a1=a[1108908]|0;a2=c[277219]|0}else{a1=a_;a2=a$}}while(0);i=aK+7|0;do{if((a1&255)>(d[a2+i|0]|0)){g=a[aI+7|0]|0;if(g<<24>>24==0){break}j=e[(c[277225]|0)+((g&255)<<1)>>1]|0;g=c[277228]|0;h=(((j&63454)+(g&-2082)|0)>>>1)+(g&2081&j)|0;if((a[1108928]|0)==0){a4=h&65535}else{a4=(e[(c[277220]|0)+(h<<1)>>1]|(j^g)&2081)&65535}b[(c[277218]|0)+(i<<1)>>1]=a4;a[(c[277219]|0)+i|0]=a[1108909]|0}}while(0);i=aJ-1|0;if((i|0)<=0){break}aI=aI-8|0;aJ=i;aK=(c[277223]|0)+aK|0}return}}function Xu(f,g,h,i){f=f|0;g=g|0;h=h|0;i=i|0;var j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0,cf=0,cg=0,ch=0,ci=0,cj=0,ck=0,cl=0,cm=0,cn=0,co=0,cp=0,cq=0,cr=0,cs=0,ct=0,cu=0,cv=0,cw=0,cx=0,cy=0,cz=0,cA=0,cB=0,cC=0;j=f&1023;k=c[348606]|0;l=(j<<k)+(c[348604]|0)|0;if((f&256|0)==0){m=l}else{m=(c[348602]|0)+l|0}l=m&65535;m=l>>>(k>>>0);k=(f&16384|0)!=0;n=m<<6;do{if(k){o=(c[348622]|0)+n|0;if((a[(c[348618]|0)+m|0]|0)!=0){p=o;break}q=fi[c[348636]&63](o,l,j)|0;a[(c[348618]|0)+m|0]=q;p=o}else{o=(c[348624]|0)+n|0;if((a[(c[348620]|0)+m|0]|0)!=0){p=o;break}q=fi[c[348638]&63](o,l,j)|0;a[(c[348620]|0)+m|0]=q;p=o}}while(0);if((a[(c[348620]|0)+m|0]|0)==2){return}if((a[1394464]|0)==0){r=1106168+((f>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){m=d[1044485]|0;c[276541]=7080+(m<<5);j=0;do{l=j<<1&2;n=j&2;o=j&4;q=0;do{b[1125528+(j<<9)+(q<<1)>>1]=d[(q>>>1&28|n)+(7080+(m<<5))|0]<<6|d[(q<<2&28|l)+(7080+(m<<5))|0]<<11|d[(q>>>3&24|o)+(7080+(m<<5))|0];q=q+1|0;}while(q>>>0<256);j=j+1|0;}while(j>>>0<8);a[1106089]=0}r=1125528+((f>>>10&7)<<9)|0}c[277226]=r;c[277225]=(a[1108928]|0)!=0?1393712:r;if((f&49152|0)==0){if((i|0)<=0){return}r=p+h|0;j=i;m=g;while(1){q=a[1108908]|0;o=c[277219]|0;do{if((q&255)>(d[o+m|0]|0)){l=a[r]|0;n=l&255;if(l<<24>>24==0){s=q;t=o;break}do{if((a[1108928]|0)==0){l=b[(c[277225]|0)+(n<<1)>>1]|0;u=l&65535;v=u&63454;if((a[(c[277215]|0)+m|0]&32)==0){w=c[277228]|0;x=(e[(c[277220]|0)+((((w&-2082)+v|0)>>>1)+(u&2081&w)<<1)>>1]|(w^u)&2081)&65535;break}else{u=b[(c[277213]|0)+(m<<1)>>1]|0;x=(((u&63454)+v|0)>>>1)+(u&l&2081)&65535;break}}else{l=e[(c[277225]|0)+(n<<1)>>1]|0;u=(a[(c[277215]|0)+m|0]&32)==0;if(u){v=c[277228]|0;y=v;z=v&-2082}else{v=e[(c[277213]|0)+(m<<1)>>1]|0;y=v;z=v&63454}if(u){A=c[277228]|0}else{A=e[(c[277213]|0)+(m<<1)>>1]|0}x=((A^l)&2081|e[(c[277220]|0)+((l&2081&y)+((z+(l&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(m<<1)>>1]=x;a[(c[277219]|0)+m|0]=a[1108909]|0;s=a[1108908]|0;t=c[277219]|0}else{s=q;t=o}}while(0);o=m+1|0;do{if((s&255)>(d[t+o|0]|0)){q=a[r+1|0]|0;n=q&255;if(q<<24>>24==0){B=s;C=t;break}do{if((a[1108928]|0)==0){q=b[(c[277225]|0)+(n<<1)>>1]|0;l=q&65535;u=l&63454;if((a[(c[277215]|0)+o|0]&32)==0){v=c[277228]|0;D=(e[(c[277220]|0)+((((v&-2082)+u|0)>>>1)+(l&2081&v)<<1)>>1]|(v^l)&2081)&65535;break}else{l=b[(c[277213]|0)+(o<<1)>>1]|0;D=(((l&63454)+u|0)>>>1)+(l&q&2081)&65535;break}}else{q=e[(c[277225]|0)+(n<<1)>>1]|0;l=(a[(c[277215]|0)+o|0]&32)==0;if(l){u=c[277228]|0;E=u;F=u&-2082}else{u=e[(c[277213]|0)+(o<<1)>>1]|0;E=u;F=u&63454}if(l){G=c[277228]|0}else{G=e[(c[277213]|0)+(o<<1)>>1]|0}D=((G^q)&2081|e[(c[277220]|0)+((q&2081&E)+((F+(q&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=D;a[(c[277219]|0)+o|0]=a[1108909]|0;B=a[1108908]|0;C=c[277219]|0}else{B=s;C=t}}while(0);o=m+2|0;do{if((B&255)>(d[C+o|0]|0)){n=a[r+2|0]|0;q=n&255;if(n<<24>>24==0){H=B;I=C;break}do{if((a[1108928]|0)==0){n=b[(c[277225]|0)+(q<<1)>>1]|0;l=n&65535;u=l&63454;if((a[(c[277215]|0)+o|0]&32)==0){v=c[277228]|0;J=(e[(c[277220]|0)+((((v&-2082)+u|0)>>>1)+(l&2081&v)<<1)>>1]|(v^l)&2081)&65535;break}else{l=b[(c[277213]|0)+(o<<1)>>1]|0;J=(((l&63454)+u|0)>>>1)+(l&n&2081)&65535;break}}else{n=e[(c[277225]|0)+(q<<1)>>1]|0;l=(a[(c[277215]|0)+o|0]&32)==0;if(l){u=c[277228]|0;K=u;L=u&-2082}else{u=e[(c[277213]|0)+(o<<1)>>1]|0;K=u;L=u&63454}if(l){M=c[277228]|0}else{M=e[(c[277213]|0)+(o<<1)>>1]|0}J=((M^n)&2081|e[(c[277220]|0)+((n&2081&K)+((L+(n&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=J;a[(c[277219]|0)+o|0]=a[1108909]|0;H=a[1108908]|0;I=c[277219]|0}else{H=B;I=C}}while(0);o=m+3|0;do{if((H&255)>(d[I+o|0]|0)){q=a[r+3|0]|0;n=q&255;if(q<<24>>24==0){N=H;O=I;break}do{if((a[1108928]|0)==0){q=b[(c[277225]|0)+(n<<1)>>1]|0;l=q&65535;u=l&63454;if((a[(c[277215]|0)+o|0]&32)==0){v=c[277228]|0;P=(e[(c[277220]|0)+((((v&-2082)+u|0)>>>1)+(l&2081&v)<<1)>>1]|(v^l)&2081)&65535;break}else{l=b[(c[277213]|0)+(o<<1)>>1]|0;P=(((l&63454)+u|0)>>>1)+(l&q&2081)&65535;break}}else{q=e[(c[277225]|0)+(n<<1)>>1]|0;l=(a[(c[277215]|0)+o|0]&32)==0;if(l){u=c[277228]|0;Q=u;R=u&-2082}else{u=e[(c[277213]|0)+(o<<1)>>1]|0;Q=u;R=u&63454}if(l){S=c[277228]|0}else{S=e[(c[277213]|0)+(o<<1)>>1]|0}P=((S^q)&2081|e[(c[277220]|0)+((q&2081&Q)+((R+(q&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=P;a[(c[277219]|0)+o|0]=a[1108909]|0;N=a[1108908]|0;O=c[277219]|0}else{N=H;O=I}}while(0);o=m+4|0;do{if((N&255)>(d[O+o|0]|0)){n=a[r+4|0]|0;q=n&255;if(n<<24>>24==0){T=N;U=O;break}do{if((a[1108928]|0)==0){n=b[(c[277225]|0)+(q<<1)>>1]|0;l=n&65535;u=l&63454;if((a[(c[277215]|0)+o|0]&32)==0){v=c[277228]|0;V=(e[(c[277220]|0)+((((v&-2082)+u|0)>>>1)+(l&2081&v)<<1)>>1]|(v^l)&2081)&65535;break}else{l=b[(c[277213]|0)+(o<<1)>>1]|0;V=(((l&63454)+u|0)>>>1)+(l&n&2081)&65535;break}}else{n=e[(c[277225]|0)+(q<<1)>>1]|0;l=(a[(c[277215]|0)+o|0]&32)==0;if(l){u=c[277228]|0;W=u;X=u&-2082}else{u=e[(c[277213]|0)+(o<<1)>>1]|0;W=u;X=u&63454}if(l){Y=c[277228]|0}else{Y=e[(c[277213]|0)+(o<<1)>>1]|0}V=((Y^n)&2081|e[(c[277220]|0)+((n&2081&W)+((X+(n&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=V;a[(c[277219]|0)+o|0]=a[1108909]|0;T=a[1108908]|0;U=c[277219]|0}else{T=N;U=O}}while(0);o=m+5|0;do{if((T&255)>(d[U+o|0]|0)){q=a[r+5|0]|0;n=q&255;if(q<<24>>24==0){Z=T;_=U;break}do{if((a[1108928]|0)==0){q=b[(c[277225]|0)+(n<<1)>>1]|0;l=q&65535;u=l&63454;if((a[(c[277215]|0)+o|0]&32)==0){v=c[277228]|0;$=(e[(c[277220]|0)+((((v&-2082)+u|0)>>>1)+(l&2081&v)<<1)>>1]|(v^l)&2081)&65535;break}else{l=b[(c[277213]|0)+(o<<1)>>1]|0;$=(((l&63454)+u|0)>>>1)+(l&q&2081)&65535;break}}else{q=e[(c[277225]|0)+(n<<1)>>1]|0;l=(a[(c[277215]|0)+o|0]&32)==0;if(l){u=c[277228]|0;aa=u;ab=u&-2082}else{u=e[(c[277213]|0)+(o<<1)>>1]|0;aa=u;ab=u&63454}if(l){ac=c[277228]|0}else{ac=e[(c[277213]|0)+(o<<1)>>1]|0}$=((ac^q)&2081|e[(c[277220]|0)+((q&2081&aa)+((ab+(q&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=$;a[(c[277219]|0)+o|0]=a[1108909]|0;Z=a[1108908]|0;_=c[277219]|0}else{Z=T;_=U}}while(0);o=m+6|0;do{if((Z&255)>(d[_+o|0]|0)){n=a[r+6|0]|0;q=n&255;if(n<<24>>24==0){ad=Z;ae=_;break}do{if((a[1108928]|0)==0){n=b[(c[277225]|0)+(q<<1)>>1]|0;l=n&65535;u=l&63454;if((a[(c[277215]|0)+o|0]&32)==0){v=c[277228]|0;af=(e[(c[277220]|0)+((((v&-2082)+u|0)>>>1)+(l&2081&v)<<1)>>1]|(v^l)&2081)&65535;break}else{l=b[(c[277213]|0)+(o<<1)>>1]|0;af=(((l&63454)+u|0)>>>1)+(l&n&2081)&65535;break}}else{n=e[(c[277225]|0)+(q<<1)>>1]|0;l=(a[(c[277215]|0)+o|0]&32)==0;if(l){u=c[277228]|0;ag=u;ah=u&-2082}else{u=e[(c[277213]|0)+(o<<1)>>1]|0;ag=u;ah=u&63454}if(l){ai=c[277228]|0}else{ai=e[(c[277213]|0)+(o<<1)>>1]|0}af=((ai^n)&2081|e[(c[277220]|0)+((n&2081&ag)+((ah+(n&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=af;a[(c[277219]|0)+o|0]=a[1108909]|0;ad=a[1108908]|0;ae=c[277219]|0}else{ad=Z;ae=_}}while(0);o=m+7|0;do{if((ad&255)>(d[ae+o|0]|0)){q=a[r+7|0]|0;n=q&255;if(q<<24>>24==0){break}do{if((a[1108928]|0)==0){q=b[(c[277225]|0)+(n<<1)>>1]|0;l=q&65535;u=l&63454;if((a[(c[277215]|0)+o|0]&32)==0){v=c[277228]|0;aj=(e[(c[277220]|0)+((((v&-2082)+u|0)>>>1)+(l&2081&v)<<1)>>1]|(v^l)&2081)&65535;break}else{l=b[(c[277213]|0)+(o<<1)>>1]|0;aj=(((l&63454)+u|0)>>>1)+(l&q&2081)&65535;break}}else{q=e[(c[277225]|0)+(n<<1)>>1]|0;l=(a[(c[277215]|0)+o|0]&32)==0;if(l){u=c[277228]|0;ak=u;al=u&-2082}else{u=e[(c[277213]|0)+(o<<1)>>1]|0;ak=u;al=u&63454}if(l){am=c[277228]|0}else{am=e[(c[277213]|0)+(o<<1)>>1]|0}aj=((am^q)&2081|e[(c[277220]|0)+((q&2081&ak)+((al+(q&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=aj;a[(c[277219]|0)+o|0]=a[1108909]|0}}while(0);o=j-1|0;if((o|0)<=0){break}r=r+8|0;j=o;m=(c[277223]|0)+m|0}return}if((f&32768|0)==0){if((i|0)<=0){return}f=p+h|0;m=i;j=g;while(1){r=a[1108908]|0;aj=c[277219]|0;do{if((r&255)>(d[aj+j|0]|0)){al=a[f+7|0]|0;ak=al&255;if(al<<24>>24==0){an=r;ao=aj;break}do{if((a[1108928]|0)==0){al=b[(c[277225]|0)+(ak<<1)>>1]|0;am=al&65535;ae=am&63454;if((a[(c[277215]|0)+j|0]&32)==0){ad=c[277228]|0;ap=(e[(c[277220]|0)+((((ad&-2082)+ae|0)>>>1)+(am&2081&ad)<<1)>>1]|(ad^am)&2081)&65535;break}else{am=b[(c[277213]|0)+(j<<1)>>1]|0;ap=(((am&63454)+ae|0)>>>1)+(am&al&2081)&65535;break}}else{al=e[(c[277225]|0)+(ak<<1)>>1]|0;am=(a[(c[277215]|0)+j|0]&32)==0;if(am){ae=c[277228]|0;aq=ae;ar=ae&-2082}else{ae=e[(c[277213]|0)+(j<<1)>>1]|0;aq=ae;ar=ae&63454}if(am){as=c[277228]|0}else{as=e[(c[277213]|0)+(j<<1)>>1]|0}ap=((as^al)&2081|e[(c[277220]|0)+((al&2081&aq)+((ar+(al&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(j<<1)>>1]=ap;a[(c[277219]|0)+j|0]=a[1108909]|0;an=a[1108908]|0;ao=c[277219]|0}else{an=r;ao=aj}}while(0);aj=j+1|0;do{if((an&255)>(d[ao+aj|0]|0)){r=a[f+6|0]|0;ak=r&255;if(r<<24>>24==0){at=an;au=ao;break}do{if((a[1108928]|0)==0){r=b[(c[277225]|0)+(ak<<1)>>1]|0;al=r&65535;am=al&63454;if((a[(c[277215]|0)+aj|0]&32)==0){ae=c[277228]|0;av=(e[(c[277220]|0)+((((ae&-2082)+am|0)>>>1)+(al&2081&ae)<<1)>>1]|(ae^al)&2081)&65535;break}else{al=b[(c[277213]|0)+(aj<<1)>>1]|0;av=(((al&63454)+am|0)>>>1)+(al&r&2081)&65535;break}}else{r=e[(c[277225]|0)+(ak<<1)>>1]|0;al=(a[(c[277215]|0)+aj|0]&32)==0;if(al){am=c[277228]|0;aw=am;ax=am&-2082}else{am=e[(c[277213]|0)+(aj<<1)>>1]|0;aw=am;ax=am&63454}if(al){ay=c[277228]|0}else{ay=e[(c[277213]|0)+(aj<<1)>>1]|0}av=((ay^r)&2081|e[(c[277220]|0)+((r&2081&aw)+((ax+(r&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(aj<<1)>>1]=av;a[(c[277219]|0)+aj|0]=a[1108909]|0;at=a[1108908]|0;au=c[277219]|0}else{at=an;au=ao}}while(0);aj=j+2|0;do{if((at&255)>(d[au+aj|0]|0)){ak=a[f+5|0]|0;r=ak&255;if(ak<<24>>24==0){az=at;aA=au;break}do{if((a[1108928]|0)==0){ak=b[(c[277225]|0)+(r<<1)>>1]|0;al=ak&65535;am=al&63454;if((a[(c[277215]|0)+aj|0]&32)==0){ae=c[277228]|0;aB=(e[(c[277220]|0)+((((ae&-2082)+am|0)>>>1)+(al&2081&ae)<<1)>>1]|(ae^al)&2081)&65535;break}else{al=b[(c[277213]|0)+(aj<<1)>>1]|0;aB=(((al&63454)+am|0)>>>1)+(al&ak&2081)&65535;break}}else{ak=e[(c[277225]|0)+(r<<1)>>1]|0;al=(a[(c[277215]|0)+aj|0]&32)==0;if(al){am=c[277228]|0;aC=am;aD=am&-2082}else{am=e[(c[277213]|0)+(aj<<1)>>1]|0;aC=am;aD=am&63454}if(al){aE=c[277228]|0}else{aE=e[(c[277213]|0)+(aj<<1)>>1]|0}aB=((aE^ak)&2081|e[(c[277220]|0)+((ak&2081&aC)+((aD+(ak&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(aj<<1)>>1]=aB;a[(c[277219]|0)+aj|0]=a[1108909]|0;az=a[1108908]|0;aA=c[277219]|0}else{az=at;aA=au}}while(0);aj=j+3|0;do{if((az&255)>(d[aA+aj|0]|0)){r=a[f+4|0]|0;ak=r&255;if(r<<24>>24==0){aF=az;aG=aA;break}do{if((a[1108928]|0)==0){r=b[(c[277225]|0)+(ak<<1)>>1]|0;al=r&65535;am=al&63454;if((a[(c[277215]|0)+aj|0]&32)==0){ae=c[277228]|0;aH=(e[(c[277220]|0)+((((ae&-2082)+am|0)>>>1)+(al&2081&ae)<<1)>>1]|(ae^al)&2081)&65535;break}else{al=b[(c[277213]|0)+(aj<<1)>>1]|0;aH=(((al&63454)+am|0)>>>1)+(al&r&2081)&65535;break}}else{r=e[(c[277225]|0)+(ak<<1)>>1]|0;al=(a[(c[277215]|0)+aj|0]&32)==0;if(al){am=c[277228]|0;aI=am;aJ=am&-2082}else{am=e[(c[277213]|0)+(aj<<1)>>1]|0;aI=am;aJ=am&63454}if(al){aK=c[277228]|0}else{aK=e[(c[277213]|0)+(aj<<1)>>1]|0}aH=((aK^r)&2081|e[(c[277220]|0)+((r&2081&aI)+((aJ+(r&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(aj<<1)>>1]=aH;a[(c[277219]|0)+aj|0]=a[1108909]|0;aF=a[1108908]|0;aG=c[277219]|0}else{aF=az;aG=aA}}while(0);aj=j+4|0;do{if((aF&255)>(d[aG+aj|0]|0)){ak=a[f+3|0]|0;r=ak&255;if(ak<<24>>24==0){aL=aF;aM=aG;break}do{if((a[1108928]|0)==0){ak=b[(c[277225]|0)+(r<<1)>>1]|0;al=ak&65535;am=al&63454;if((a[(c[277215]|0)+aj|0]&32)==0){ae=c[277228]|0;aN=(e[(c[277220]|0)+((((ae&-2082)+am|0)>>>1)+(al&2081&ae)<<1)>>1]|(ae^al)&2081)&65535;break}else{al=b[(c[277213]|0)+(aj<<1)>>1]|0;aN=(((al&63454)+am|0)>>>1)+(al&ak&2081)&65535;break}}else{ak=e[(c[277225]|0)+(r<<1)>>1]|0;al=(a[(c[277215]|0)+aj|0]&32)==0;if(al){am=c[277228]|0;aO=am;aP=am&-2082}else{am=e[(c[277213]|0)+(aj<<1)>>1]|0;aO=am;aP=am&63454}if(al){aQ=c[277228]|0}else{aQ=e[(c[277213]|0)+(aj<<1)>>1]|0}aN=((aQ^ak)&2081|e[(c[277220]|0)+((ak&2081&aO)+((aP+(ak&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(aj<<1)>>1]=aN;a[(c[277219]|0)+aj|0]=a[1108909]|0;aL=a[1108908]|0;aM=c[277219]|0}else{aL=aF;aM=aG}}while(0);aj=j+5|0;do{if((aL&255)>(d[aM+aj|0]|0)){r=a[f+2|0]|0;ak=r&255;if(r<<24>>24==0){aR=aL;aS=aM;break}do{if((a[1108928]|0)==0){r=b[(c[277225]|0)+(ak<<1)>>1]|0;al=r&65535;am=al&63454;if((a[(c[277215]|0)+aj|0]&32)==0){ae=c[277228]|0;aT=(e[(c[277220]|0)+((((ae&-2082)+am|0)>>>1)+(al&2081&ae)<<1)>>1]|(ae^al)&2081)&65535;break}else{al=b[(c[277213]|0)+(aj<<1)>>1]|0;aT=(((al&63454)+am|0)>>>1)+(al&r&2081)&65535;break}}else{r=e[(c[277225]|0)+(ak<<1)>>1]|0;al=(a[(c[277215]|0)+aj|0]&32)==0;if(al){am=c[277228]|0;aU=am;aV=am&-2082}else{am=e[(c[277213]|0)+(aj<<1)>>1]|0;aU=am;aV=am&63454}if(al){aW=c[277228]|0}else{aW=e[(c[277213]|0)+(aj<<1)>>1]|0}aT=((aW^r)&2081|e[(c[277220]|0)+((r&2081&aU)+((aV+(r&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(aj<<1)>>1]=aT;a[(c[277219]|0)+aj|0]=a[1108909]|0;aR=a[1108908]|0;aS=c[277219]|0}else{aR=aL;aS=aM}}while(0);aj=j+6|0;do{if((aR&255)>(d[aS+aj|0]|0)){ak=a[f+1|0]|0;r=ak&255;if(ak<<24>>24==0){aX=aR;aY=aS;break}do{if((a[1108928]|0)==0){ak=b[(c[277225]|0)+(r<<1)>>1]|0;al=ak&65535;am=al&63454;if((a[(c[277215]|0)+aj|0]&32)==0){ae=c[277228]|0;aZ=(e[(c[277220]|0)+((((ae&-2082)+am|0)>>>1)+(al&2081&ae)<<1)>>1]|(ae^al)&2081)&65535;break}else{al=b[(c[277213]|0)+(aj<<1)>>1]|0;aZ=(((al&63454)+am|0)>>>1)+(al&ak&2081)&65535;break}}else{ak=e[(c[277225]|0)+(r<<1)>>1]|0;al=(a[(c[277215]|0)+aj|0]&32)==0;if(al){am=c[277228]|0;a_=am;a$=am&-2082}else{am=e[(c[277213]|0)+(aj<<1)>>1]|0;a_=am;a$=am&63454}if(al){a0=c[277228]|0}else{a0=e[(c[277213]|0)+(aj<<1)>>1]|0}aZ=((a0^ak)&2081|e[(c[277220]|0)+((ak&2081&a_)+((a$+(ak&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(aj<<1)>>1]=aZ;a[(c[277219]|0)+aj|0]=a[1108909]|0;aX=a[1108908]|0;aY=c[277219]|0}else{aX=aR;aY=aS}}while(0);aj=j+7|0;do{if((aX&255)>(d[aY+aj|0]|0)){r=a[f]|0;ak=r&255;if(r<<24>>24==0){break}do{if((a[1108928]|0)==0){r=b[(c[277225]|0)+(ak<<1)>>1]|0;al=r&65535;am=al&63454;if((a[(c[277215]|0)+aj|0]&32)==0){ae=c[277228]|0;a1=(e[(c[277220]|0)+((((ae&-2082)+am|0)>>>1)+(al&2081&ae)<<1)>>1]|(ae^al)&2081)&65535;break}else{al=b[(c[277213]|0)+(aj<<1)>>1]|0;a1=(((al&63454)+am|0)>>>1)+(al&r&2081)&65535;break}}else{r=e[(c[277225]|0)+(ak<<1)>>1]|0;al=(a[(c[277215]|0)+aj|0]&32)==0;if(al){am=c[277228]|0;a2=am;a3=am&-2082}else{am=e[(c[277213]|0)+(aj<<1)>>1]|0;a2=am;a3=am&63454}if(al){a4=c[277228]|0}else{a4=e[(c[277213]|0)+(aj<<1)>>1]|0}a1=((a4^r)&2081|e[(c[277220]|0)+((r&2081&a2)+((a3+(r&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(aj<<1)>>1]=a1;a[(c[277219]|0)+aj|0]=a[1108909]|0}}while(0);aj=m-1|0;if((aj|0)<=0){break}f=f+8|0;m=aj;j=(c[277223]|0)+j|0}return}j=p+(56-h)|0;h=(i|0)>0;if(k){if(h){a5=j;a6=i;a7=g}else{return}while(1){k=a[1108908]|0;p=c[277219]|0;do{if((k&255)>(d[p+a7|0]|0)){m=a[a5+7|0]|0;f=m&255;if(m<<24>>24==0){a8=k;a9=p;break}do{if((a[1108928]|0)==0){m=b[(c[277225]|0)+(f<<1)>>1]|0;a1=m&65535;a3=a1&63454;if((a[(c[277215]|0)+a7|0]&32)==0){a2=c[277228]|0;ba=(e[(c[277220]|0)+((((a2&-2082)+a3|0)>>>1)+(a1&2081&a2)<<1)>>1]|(a2^a1)&2081)&65535;break}else{a1=b[(c[277213]|0)+(a7<<1)>>1]|0;ba=(((a1&63454)+a3|0)>>>1)+(a1&m&2081)&65535;break}}else{m=e[(c[277225]|0)+(f<<1)>>1]|0;a1=(a[(c[277215]|0)+a7|0]&32)==0;if(a1){a3=c[277228]|0;bb=a3;bc=a3&-2082}else{a3=e[(c[277213]|0)+(a7<<1)>>1]|0;bb=a3;bc=a3&63454}if(a1){bd=c[277228]|0}else{bd=e[(c[277213]|0)+(a7<<1)>>1]|0}ba=((bd^m)&2081|e[(c[277220]|0)+((m&2081&bb)+((bc+(m&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(a7<<1)>>1]=ba;a[(c[277219]|0)+a7|0]=a[1108909]|0;a8=a[1108908]|0;a9=c[277219]|0}else{a8=k;a9=p}}while(0);p=a7+1|0;do{if((a8&255)>(d[a9+p|0]|0)){k=a[a5+6|0]|0;f=k&255;if(k<<24>>24==0){be=a8;bf=a9;break}do{if((a[1108928]|0)==0){k=b[(c[277225]|0)+(f<<1)>>1]|0;m=k&65535;a1=m&63454;if((a[(c[277215]|0)+p|0]&32)==0){a3=c[277228]|0;bg=(e[(c[277220]|0)+((((a3&-2082)+a1|0)>>>1)+(m&2081&a3)<<1)>>1]|(a3^m)&2081)&65535;break}else{m=b[(c[277213]|0)+(p<<1)>>1]|0;bg=(((m&63454)+a1|0)>>>1)+(m&k&2081)&65535;break}}else{k=e[(c[277225]|0)+(f<<1)>>1]|0;m=(a[(c[277215]|0)+p|0]&32)==0;if(m){a1=c[277228]|0;bh=a1;bi=a1&-2082}else{a1=e[(c[277213]|0)+(p<<1)>>1]|0;bh=a1;bi=a1&63454}if(m){bj=c[277228]|0}else{bj=e[(c[277213]|0)+(p<<1)>>1]|0}bg=((bj^k)&2081|e[(c[277220]|0)+((k&2081&bh)+((bi+(k&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=bg;a[(c[277219]|0)+p|0]=a[1108909]|0;be=a[1108908]|0;bf=c[277219]|0}else{be=a8;bf=a9}}while(0);p=a7+2|0;do{if((be&255)>(d[bf+p|0]|0)){f=a[a5+5|0]|0;k=f&255;if(f<<24>>24==0){bk=be;bl=bf;break}do{if((a[1108928]|0)==0){f=b[(c[277225]|0)+(k<<1)>>1]|0;m=f&65535;a1=m&63454;if((a[(c[277215]|0)+p|0]&32)==0){a3=c[277228]|0;bm=(e[(c[277220]|0)+((((a3&-2082)+a1|0)>>>1)+(m&2081&a3)<<1)>>1]|(a3^m)&2081)&65535;break}else{m=b[(c[277213]|0)+(p<<1)>>1]|0;bm=(((m&63454)+a1|0)>>>1)+(m&f&2081)&65535;break}}else{f=e[(c[277225]|0)+(k<<1)>>1]|0;m=(a[(c[277215]|0)+p|0]&32)==0;if(m){a1=c[277228]|0;bn=a1;bo=a1&-2082}else{a1=e[(c[277213]|0)+(p<<1)>>1]|0;bn=a1;bo=a1&63454}if(m){bp=c[277228]|0}else{bp=e[(c[277213]|0)+(p<<1)>>1]|0}bm=((bp^f)&2081|e[(c[277220]|0)+((f&2081&bn)+((bo+(f&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=bm;a[(c[277219]|0)+p|0]=a[1108909]|0;bk=a[1108908]|0;bl=c[277219]|0}else{bk=be;bl=bf}}while(0);p=a7+3|0;do{if((bk&255)>(d[bl+p|0]|0)){k=a[a5+4|0]|0;f=k&255;if(k<<24>>24==0){bq=bk;br=bl;break}do{if((a[1108928]|0)==0){k=b[(c[277225]|0)+(f<<1)>>1]|0;m=k&65535;a1=m&63454;if((a[(c[277215]|0)+p|0]&32)==0){a3=c[277228]|0;bs=(e[(c[277220]|0)+((((a3&-2082)+a1|0)>>>1)+(m&2081&a3)<<1)>>1]|(a3^m)&2081)&65535;break}else{m=b[(c[277213]|0)+(p<<1)>>1]|0;bs=(((m&63454)+a1|0)>>>1)+(m&k&2081)&65535;break}}else{k=e[(c[277225]|0)+(f<<1)>>1]|0;m=(a[(c[277215]|0)+p|0]&32)==0;if(m){a1=c[277228]|0;bt=a1;bu=a1&-2082}else{a1=e[(c[277213]|0)+(p<<1)>>1]|0;bt=a1;bu=a1&63454}if(m){bv=c[277228]|0}else{bv=e[(c[277213]|0)+(p<<1)>>1]|0}bs=((bv^k)&2081|e[(c[277220]|0)+((k&2081&bt)+((bu+(k&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=bs;a[(c[277219]|0)+p|0]=a[1108909]|0;bq=a[1108908]|0;br=c[277219]|0}else{bq=bk;br=bl}}while(0);p=a7+4|0;do{if((bq&255)>(d[br+p|0]|0)){f=a[a5+3|0]|0;k=f&255;if(f<<24>>24==0){bw=bq;bx=br;break}do{if((a[1108928]|0)==0){f=b[(c[277225]|0)+(k<<1)>>1]|0;m=f&65535;a1=m&63454;if((a[(c[277215]|0)+p|0]&32)==0){a3=c[277228]|0;by=(e[(c[277220]|0)+((((a3&-2082)+a1|0)>>>1)+(m&2081&a3)<<1)>>1]|(a3^m)&2081)&65535;break}else{m=b[(c[277213]|0)+(p<<1)>>1]|0;by=(((m&63454)+a1|0)>>>1)+(m&f&2081)&65535;break}}else{f=e[(c[277225]|0)+(k<<1)>>1]|0;m=(a[(c[277215]|0)+p|0]&32)==0;if(m){a1=c[277228]|0;bz=a1;bA=a1&-2082}else{a1=e[(c[277213]|0)+(p<<1)>>1]|0;bz=a1;bA=a1&63454}if(m){bB=c[277228]|0}else{bB=e[(c[277213]|0)+(p<<1)>>1]|0}by=((bB^f)&2081|e[(c[277220]|0)+((f&2081&bz)+((bA+(f&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=by;a[(c[277219]|0)+p|0]=a[1108909]|0;bw=a[1108908]|0;bx=c[277219]|0}else{bw=bq;bx=br}}while(0);p=a7+5|0;do{if((bw&255)>(d[bx+p|0]|0)){k=a[a5+2|0]|0;f=k&255;if(k<<24>>24==0){bC=bw;bD=bx;break}do{if((a[1108928]|0)==0){k=b[(c[277225]|0)+(f<<1)>>1]|0;m=k&65535;a1=m&63454;if((a[(c[277215]|0)+p|0]&32)==0){a3=c[277228]|0;bE=(e[(c[277220]|0)+((((a3&-2082)+a1|0)>>>1)+(m&2081&a3)<<1)>>1]|(a3^m)&2081)&65535;break}else{m=b[(c[277213]|0)+(p<<1)>>1]|0;bE=(((m&63454)+a1|0)>>>1)+(m&k&2081)&65535;break}}else{k=e[(c[277225]|0)+(f<<1)>>1]|0;m=(a[(c[277215]|0)+p|0]&32)==0;if(m){a1=c[277228]|0;bF=a1;bG=a1&-2082}else{a1=e[(c[277213]|0)+(p<<1)>>1]|0;bF=a1;bG=a1&63454}if(m){bH=c[277228]|0}else{bH=e[(c[277213]|0)+(p<<1)>>1]|0}bE=((bH^k)&2081|e[(c[277220]|0)+((k&2081&bF)+((bG+(k&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=bE;a[(c[277219]|0)+p|0]=a[1108909]|0;bC=a[1108908]|0;bD=c[277219]|0}else{bC=bw;bD=bx}}while(0);p=a7+6|0;do{if((bC&255)>(d[bD+p|0]|0)){f=a[a5+1|0]|0;k=f&255;if(f<<24>>24==0){bI=bC;bJ=bD;break}do{if((a[1108928]|0)==0){f=b[(c[277225]|0)+(k<<1)>>1]|0;m=f&65535;a1=m&63454;if((a[(c[277215]|0)+p|0]&32)==0){a3=c[277228]|0;bK=(e[(c[277220]|0)+((((a3&-2082)+a1|0)>>>1)+(m&2081&a3)<<1)>>1]|(a3^m)&2081)&65535;break}else{m=b[(c[277213]|0)+(p<<1)>>1]|0;bK=(((m&63454)+a1|0)>>>1)+(m&f&2081)&65535;break}}else{f=e[(c[277225]|0)+(k<<1)>>1]|0;m=(a[(c[277215]|0)+p|0]&32)==0;if(m){a1=c[277228]|0;bL=a1;bM=a1&-2082}else{a1=e[(c[277213]|0)+(p<<1)>>1]|0;bL=a1;bM=a1&63454}if(m){bN=c[277228]|0}else{bN=e[(c[277213]|0)+(p<<1)>>1]|0}bK=((bN^f)&2081|e[(c[277220]|0)+((f&2081&bL)+((bM+(f&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=bK;a[(c[277219]|0)+p|0]=a[1108909]|0;bI=a[1108908]|0;bJ=c[277219]|0}else{bI=bC;bJ=bD}}while(0);p=a7+7|0;do{if((bI&255)>(d[bJ+p|0]|0)){k=a[a5]|0;f=k&255;if(k<<24>>24==0){break}do{if((a[1108928]|0)==0){k=b[(c[277225]|0)+(f<<1)>>1]|0;m=k&65535;a1=m&63454;if((a[(c[277215]|0)+p|0]&32)==0){a3=c[277228]|0;bO=(e[(c[277220]|0)+((((a3&-2082)+a1|0)>>>1)+(m&2081&a3)<<1)>>1]|(a3^m)&2081)&65535;break}else{m=b[(c[277213]|0)+(p<<1)>>1]|0;bO=(((m&63454)+a1|0)>>>1)+(m&k&2081)&65535;break}}else{k=e[(c[277225]|0)+(f<<1)>>1]|0;m=(a[(c[277215]|0)+p|0]&32)==0;if(m){a1=c[277228]|0;bP=a1;bQ=a1&-2082}else{a1=e[(c[277213]|0)+(p<<1)>>1]|0;bP=a1;bQ=a1&63454}if(m){bR=c[277228]|0}else{bR=e[(c[277213]|0)+(p<<1)>>1]|0}bO=((bR^k)&2081|e[(c[277220]|0)+((k&2081&bP)+((bQ+(k&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=bO;a[(c[277219]|0)+p|0]=a[1108909]|0}}while(0);p=a6-1|0;if((p|0)<=0){break}a5=a5-8|0;a6=p;a7=(c[277223]|0)+a7|0}return}else{if(h){bS=j;bT=i;bU=g}else{return}while(1){g=a[1108908]|0;i=c[277219]|0;do{if((g&255)>(d[i+bU|0]|0)){j=a[bS]|0;h=j&255;if(j<<24>>24==0){bV=g;bW=i;break}do{if((a[1108928]|0)==0){j=b[(c[277225]|0)+(h<<1)>>1]|0;a7=j&65535;a6=a7&63454;if((a[(c[277215]|0)+bU|0]&32)==0){a5=c[277228]|0;bX=(e[(c[277220]|0)+((((a5&-2082)+a6|0)>>>1)+(a7&2081&a5)<<1)>>1]|(a5^a7)&2081)&65535;break}else{a7=b[(c[277213]|0)+(bU<<1)>>1]|0;bX=(((a7&63454)+a6|0)>>>1)+(a7&j&2081)&65535;break}}else{j=e[(c[277225]|0)+(h<<1)>>1]|0;a7=(a[(c[277215]|0)+bU|0]&32)==0;if(a7){a6=c[277228]|0;bY=a6;bZ=a6&-2082}else{a6=e[(c[277213]|0)+(bU<<1)>>1]|0;bY=a6;bZ=a6&63454}if(a7){b_=c[277228]|0}else{b_=e[(c[277213]|0)+(bU<<1)>>1]|0}bX=((b_^j)&2081|e[(c[277220]|0)+((j&2081&bY)+((bZ+(j&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(bU<<1)>>1]=bX;a[(c[277219]|0)+bU|0]=a[1108909]|0;bV=a[1108908]|0;bW=c[277219]|0}else{bV=g;bW=i}}while(0);i=bU+1|0;do{if((bV&255)>(d[bW+i|0]|0)){g=a[bS+1|0]|0;h=g&255;if(g<<24>>24==0){b$=bV;b0=bW;break}do{if((a[1108928]|0)==0){g=b[(c[277225]|0)+(h<<1)>>1]|0;j=g&65535;a7=j&63454;if((a[(c[277215]|0)+i|0]&32)==0){a6=c[277228]|0;b1=(e[(c[277220]|0)+((((a6&-2082)+a7|0)>>>1)+(j&2081&a6)<<1)>>1]|(a6^j)&2081)&65535;break}else{j=b[(c[277213]|0)+(i<<1)>>1]|0;b1=(((j&63454)+a7|0)>>>1)+(j&g&2081)&65535;break}}else{g=e[(c[277225]|0)+(h<<1)>>1]|0;j=(a[(c[277215]|0)+i|0]&32)==0;if(j){a7=c[277228]|0;b2=a7;b3=a7&-2082}else{a7=e[(c[277213]|0)+(i<<1)>>1]|0;b2=a7;b3=a7&63454}if(j){b4=c[277228]|0}else{b4=e[(c[277213]|0)+(i<<1)>>1]|0}b1=((b4^g)&2081|e[(c[277220]|0)+((g&2081&b2)+((b3+(g&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(i<<1)>>1]=b1;a[(c[277219]|0)+i|0]=a[1108909]|0;b$=a[1108908]|0;b0=c[277219]|0}else{b$=bV;b0=bW}}while(0);i=bU+2|0;do{if((b$&255)>(d[b0+i|0]|0)){h=a[bS+2|0]|0;g=h&255;if(h<<24>>24==0){b5=b$;b6=b0;break}do{if((a[1108928]|0)==0){h=b[(c[277225]|0)+(g<<1)>>1]|0;j=h&65535;a7=j&63454;if((a[(c[277215]|0)+i|0]&32)==0){a6=c[277228]|0;b7=(e[(c[277220]|0)+((((a6&-2082)+a7|0)>>>1)+(j&2081&a6)<<1)>>1]|(a6^j)&2081)&65535;break}else{j=b[(c[277213]|0)+(i<<1)>>1]|0;b7=(((j&63454)+a7|0)>>>1)+(j&h&2081)&65535;break}}else{h=e[(c[277225]|0)+(g<<1)>>1]|0;j=(a[(c[277215]|0)+i|0]&32)==0;if(j){a7=c[277228]|0;b8=a7;b9=a7&-2082}else{a7=e[(c[277213]|0)+(i<<1)>>1]|0;b8=a7;b9=a7&63454}if(j){ca=c[277228]|0}else{ca=e[(c[277213]|0)+(i<<1)>>1]|0}b7=((ca^h)&2081|e[(c[277220]|0)+((h&2081&b8)+((b9+(h&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(i<<1)>>1]=b7;a[(c[277219]|0)+i|0]=a[1108909]|0;b5=a[1108908]|0;b6=c[277219]|0}else{b5=b$;b6=b0}}while(0);i=bU+3|0;do{if((b5&255)>(d[b6+i|0]|0)){g=a[bS+3|0]|0;h=g&255;if(g<<24>>24==0){cb=b5;cc=b6;break}do{if((a[1108928]|0)==0){g=b[(c[277225]|0)+(h<<1)>>1]|0;j=g&65535;a7=j&63454;if((a[(c[277215]|0)+i|0]&32)==0){a6=c[277228]|0;cd=(e[(c[277220]|0)+((((a6&-2082)+a7|0)>>>1)+(j&2081&a6)<<1)>>1]|(a6^j)&2081)&65535;break}else{j=b[(c[277213]|0)+(i<<1)>>1]|0;cd=(((j&63454)+a7|0)>>>1)+(j&g&2081)&65535;break}}else{g=e[(c[277225]|0)+(h<<1)>>1]|0;j=(a[(c[277215]|0)+i|0]&32)==0;if(j){a7=c[277228]|0;ce=a7;cf=a7&-2082}else{a7=e[(c[277213]|0)+(i<<1)>>1]|0;ce=a7;cf=a7&63454}if(j){cg=c[277228]|0}else{cg=e[(c[277213]|0)+(i<<1)>>1]|0}cd=((cg^g)&2081|e[(c[277220]|0)+((g&2081&ce)+((cf+(g&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(i<<1)>>1]=cd;a[(c[277219]|0)+i|0]=a[1108909]|0;cb=a[1108908]|0;cc=c[277219]|0}else{cb=b5;cc=b6}}while(0);i=bU+4|0;do{if((cb&255)>(d[cc+i|0]|0)){h=a[bS+4|0]|0;g=h&255;if(h<<24>>24==0){ch=cb;ci=cc;break}do{if((a[1108928]|0)==0){h=b[(c[277225]|0)+(g<<1)>>1]|0;j=h&65535;a7=j&63454;if((a[(c[277215]|0)+i|0]&32)==0){a6=c[277228]|0;cj=(e[(c[277220]|0)+((((a6&-2082)+a7|0)>>>1)+(j&2081&a6)<<1)>>1]|(a6^j)&2081)&65535;break}else{j=b[(c[277213]|0)+(i<<1)>>1]|0;cj=(((j&63454)+a7|0)>>>1)+(j&h&2081)&65535;break}}else{h=e[(c[277225]|0)+(g<<1)>>1]|0;j=(a[(c[277215]|0)+i|0]&32)==0;if(j){a7=c[277228]|0;ck=a7;cl=a7&-2082}else{a7=e[(c[277213]|0)+(i<<1)>>1]|0;ck=a7;cl=a7&63454}if(j){cm=c[277228]|0}else{cm=e[(c[277213]|0)+(i<<1)>>1]|0}cj=((cm^h)&2081|e[(c[277220]|0)+((h&2081&ck)+((cl+(h&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(i<<1)>>1]=cj;a[(c[277219]|0)+i|0]=a[1108909]|0;ch=a[1108908]|0;ci=c[277219]|0}else{ch=cb;ci=cc}}while(0);i=bU+5|0;do{if((ch&255)>(d[ci+i|0]|0)){g=a[bS+5|0]|0;h=g&255;if(g<<24>>24==0){cn=ch;co=ci;break}do{if((a[1108928]|0)==0){g=b[(c[277225]|0)+(h<<1)>>1]|0;j=g&65535;a7=j&63454;if((a[(c[277215]|0)+i|0]&32)==0){a6=c[277228]|0;cp=(e[(c[277220]|0)+((((a6&-2082)+a7|0)>>>1)+(j&2081&a6)<<1)>>1]|(a6^j)&2081)&65535;break}else{j=b[(c[277213]|0)+(i<<1)>>1]|0;cp=(((j&63454)+a7|0)>>>1)+(j&g&2081)&65535;break}}else{g=e[(c[277225]|0)+(h<<1)>>1]|0;j=(a[(c[277215]|0)+i|0]&32)==0;if(j){a7=c[277228]|0;cq=a7;cr=a7&-2082}else{a7=e[(c[277213]|0)+(i<<1)>>1]|0;cq=a7;cr=a7&63454}if(j){cs=c[277228]|0}else{cs=e[(c[277213]|0)+(i<<1)>>1]|0}cp=((cs^g)&2081|e[(c[277220]|0)+((g&2081&cq)+((cr+(g&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(i<<1)>>1]=cp;a[(c[277219]|0)+i|0]=a[1108909]|0;cn=a[1108908]|0;co=c[277219]|0}else{cn=ch;co=ci}}while(0);i=bU+6|0;do{if((cn&255)>(d[co+i|0]|0)){h=a[bS+6|0]|0;g=h&255;if(h<<24>>24==0){ct=cn;cu=co;break}do{if((a[1108928]|0)==0){h=b[(c[277225]|0)+(g<<1)>>1]|0;j=h&65535;a7=j&63454;if((a[(c[277215]|0)+i|0]&32)==0){a6=c[277228]|0;cv=(e[(c[277220]|0)+((((a6&-2082)+a7|0)>>>1)+(j&2081&a6)<<1)>>1]|(a6^j)&2081)&65535;break}else{j=b[(c[277213]|0)+(i<<1)>>1]|0;cv=(((j&63454)+a7|0)>>>1)+(j&h&2081)&65535;break}}else{h=e[(c[277225]|0)+(g<<1)>>1]|0;j=(a[(c[277215]|0)+i|0]&32)==0;if(j){a7=c[277228]|0;cw=a7;cx=a7&-2082}else{a7=e[(c[277213]|0)+(i<<1)>>1]|0;cw=a7;cx=a7&63454}if(j){cy=c[277228]|0}else{cy=e[(c[277213]|0)+(i<<1)>>1]|0}cv=((cy^h)&2081|e[(c[277220]|0)+((h&2081&cw)+((cx+(h&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(i<<1)>>1]=cv;a[(c[277219]|0)+i|0]=a[1108909]|0;ct=a[1108908]|0;cu=c[277219]|0}else{ct=cn;cu=co}}while(0);i=bU+7|0;do{if((ct&255)>(d[cu+i|0]|0)){g=a[bS+7|0]|0;h=g&255;if(g<<24>>24==0){break}do{if((a[1108928]|0)==0){g=b[(c[277225]|0)+(h<<1)>>1]|0;j=g&65535;a7=j&63454;if((a[(c[277215]|0)+i|0]&32)==0){a6=c[277228]|0;cz=(e[(c[277220]|0)+((((a6&-2082)+a7|0)>>>1)+(j&2081&a6)<<1)>>1]|(a6^j)&2081)&65535;break}else{j=b[(c[277213]|0)+(i<<1)>>1]|0;cz=(((j&63454)+a7|0)>>>1)+(j&g&2081)&65535;break}}else{g=e[(c[277225]|0)+(h<<1)>>1]|0;j=(a[(c[277215]|0)+i|0]&32)==0;if(j){a7=c[277228]|0;cA=a7;cB=a7&-2082}else{a7=e[(c[277213]|0)+(i<<1)>>1]|0;cA=a7;cB=a7&63454}if(j){cC=c[277228]|0}else{cC=e[(c[277213]|0)+(i<<1)>>1]|0}cz=((cC^g)&2081|e[(c[277220]|0)+((g&2081&cA)+((cB+(g&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(i<<1)>>1]=cz;a[(c[277219]|0)+i|0]=a[1108909]|0}}while(0);i=bT-1|0;if((i|0)<=0){break}bS=bS-8|0;bT=i;bU=(c[277223]|0)+bU|0}return}}function Xv(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0;i=e&1023;j=c[348606]|0;k=(i<<j)+(c[348604]|0)|0;if((e&256|0)==0){l=k}else{l=(c[348602]|0)+k|0}k=l&65535;l=k>>>(j>>>0);j=(e&16384|0)!=0;m=l<<6;do{if(j){n=(c[348622]|0)+m|0;if((a[(c[348618]|0)+l|0]|0)!=0){o=n;break}p=fi[c[348636]&63](n,k,i)|0;a[(c[348618]|0)+l|0]=p;o=n}else{n=(c[348624]|0)+m|0;if((a[(c[348620]|0)+l|0]|0)!=0){o=n;break}p=fi[c[348638]&63](n,k,i)|0;a[(c[348620]|0)+l|0]=p;o=n}}while(0);if((a[(c[348620]|0)+l|0]|0)==2){return}if((a[1394464]|0)==0){q=1106168+((e>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){l=d[1044485]|0;c[276541]=7080+(l<<5);i=0;do{k=i<<1&2;m=i&2;n=i&4;p=0;do{b[1125528+(i<<9)+(p<<1)>>1]=d[(p>>>1&28|m)+(7080+(l<<5))|0]<<6|d[(p<<2&28|k)+(7080+(l<<5))|0]<<11|d[(p>>>3&24|n)+(7080+(l<<5))|0];p=p+1|0;}while(p>>>0<256);i=i+1|0;}while(i>>>0<8);a[1106089]=0}q=1125528+((e>>>10&7)<<9)|0}c[277226]=q;c[277225]=(a[1108928]|0)!=0?1393712:q;if((e&49152|0)==0){if((h|0)<=0){return}q=o+g|0;i=h;l=f;while(1){p=a[1108908]|0;n=c[277219]|0;do{if((p&255)>(d[n+l|0]|0)){k=a[q]|0;if(k<<24>>24==0){r=p;s=n;break}m=b[(c[277225]|0)+((k&255)<<1)>>1]|0;if((a[(c[277215]|0)+l|0]&32)==0){t=c[277228]&65535}else{t=b[(c[277213]|0)+(l<<1)>>1]|0}k=m&-2048;u=t&-2048;v=(k&65535)>(u&65535)?k-u&65535:0;u=m&2016;k=t&2016;if((u&65535)>(k&65535)){w=(u-k&65535)+v&65535}else{w=v}v=m&31;m=t&31;if((v&65535)>(m&65535)){x=(v-m&65535)+w&65535}else{x=w}b[(c[277218]|0)+(l<<1)>>1]=x;a[(c[277219]|0)+l|0]=a[1108909]|0;r=a[1108908]|0;s=c[277219]|0}else{r=p;s=n}}while(0);n=l+1|0;do{if((r&255)>(d[s+n|0]|0)){p=a[q+1|0]|0;if(p<<24>>24==0){y=r;z=s;break}m=b[(c[277225]|0)+((p&255)<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)==0){A=c[277228]&65535}else{A=b[(c[277213]|0)+(n<<1)>>1]|0}p=m&-2048;v=A&-2048;k=(p&65535)>(v&65535)?p-v&65535:0;v=m&2016;p=A&2016;if((v&65535)>(p&65535)){B=(v-p&65535)+k&65535}else{B=k}k=m&31;m=A&31;if((k&65535)>(m&65535)){C=(k-m&65535)+B&65535}else{C=B}b[(c[277218]|0)+(n<<1)>>1]=C;a[(c[277219]|0)+n|0]=a[1108909]|0;y=a[1108908]|0;z=c[277219]|0}else{y=r;z=s}}while(0);n=l+2|0;do{if((y&255)>(d[z+n|0]|0)){m=a[q+2|0]|0;if(m<<24>>24==0){D=y;E=z;break}k=b[(c[277225]|0)+((m&255)<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)==0){F=c[277228]&65535}else{F=b[(c[277213]|0)+(n<<1)>>1]|0}m=k&-2048;p=F&-2048;v=(m&65535)>(p&65535)?m-p&65535:0;p=k&2016;m=F&2016;if((p&65535)>(m&65535)){G=(p-m&65535)+v&65535}else{G=v}v=k&31;k=F&31;if((v&65535)>(k&65535)){H=(v-k&65535)+G&65535}else{H=G}b[(c[277218]|0)+(n<<1)>>1]=H;a[(c[277219]|0)+n|0]=a[1108909]|0;D=a[1108908]|0;E=c[277219]|0}else{D=y;E=z}}while(0);n=l+3|0;do{if((D&255)>(d[E+n|0]|0)){k=a[q+3|0]|0;if(k<<24>>24==0){I=D;J=E;break}v=b[(c[277225]|0)+((k&255)<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)==0){K=c[277228]&65535}else{K=b[(c[277213]|0)+(n<<1)>>1]|0}k=v&-2048;m=K&-2048;p=(k&65535)>(m&65535)?k-m&65535:0;m=v&2016;k=K&2016;if((m&65535)>(k&65535)){L=(m-k&65535)+p&65535}else{L=p}p=v&31;v=K&31;if((p&65535)>(v&65535)){M=(p-v&65535)+L&65535}else{M=L}b[(c[277218]|0)+(n<<1)>>1]=M;a[(c[277219]|0)+n|0]=a[1108909]|0;I=a[1108908]|0;J=c[277219]|0}else{I=D;J=E}}while(0);n=l+4|0;do{if((I&255)>(d[J+n|0]|0)){v=a[q+4|0]|0;if(v<<24>>24==0){N=I;O=J;break}p=b[(c[277225]|0)+((v&255)<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)==0){P=c[277228]&65535}else{P=b[(c[277213]|0)+(n<<1)>>1]|0}v=p&-2048;k=P&-2048;m=(v&65535)>(k&65535)?v-k&65535:0;k=p&2016;v=P&2016;if((k&65535)>(v&65535)){Q=(k-v&65535)+m&65535}else{Q=m}m=p&31;p=P&31;if((m&65535)>(p&65535)){R=(m-p&65535)+Q&65535}else{R=Q}b[(c[277218]|0)+(n<<1)>>1]=R;a[(c[277219]|0)+n|0]=a[1108909]|0;N=a[1108908]|0;O=c[277219]|0}else{N=I;O=J}}while(0);n=l+5|0;do{if((N&255)>(d[O+n|0]|0)){p=a[q+5|0]|0;if(p<<24>>24==0){S=N;T=O;break}m=b[(c[277225]|0)+((p&255)<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)==0){U=c[277228]&65535}else{U=b[(c[277213]|0)+(n<<1)>>1]|0}p=m&-2048;v=U&-2048;k=(p&65535)>(v&65535)?p-v&65535:0;v=m&2016;p=U&2016;if((v&65535)>(p&65535)){V=(v-p&65535)+k&65535}else{V=k}k=m&31;m=U&31;if((k&65535)>(m&65535)){W=(k-m&65535)+V&65535}else{W=V}b[(c[277218]|0)+(n<<1)>>1]=W;a[(c[277219]|0)+n|0]=a[1108909]|0;S=a[1108908]|0;T=c[277219]|0}else{S=N;T=O}}while(0);n=l+6|0;do{if((S&255)>(d[T+n|0]|0)){m=a[q+6|0]|0;if(m<<24>>24==0){X=S;Y=T;break}k=b[(c[277225]|0)+((m&255)<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)==0){Z=c[277228]&65535}else{Z=b[(c[277213]|0)+(n<<1)>>1]|0}m=k&-2048;p=Z&-2048;v=(m&65535)>(p&65535)?m-p&65535:0;p=k&2016;m=Z&2016;if((p&65535)>(m&65535)){_=(p-m&65535)+v&65535}else{_=v}v=k&31;k=Z&31;if((v&65535)>(k&65535)){$=(v-k&65535)+_&65535}else{$=_}b[(c[277218]|0)+(n<<1)>>1]=$;a[(c[277219]|0)+n|0]=a[1108909]|0;X=a[1108908]|0;Y=c[277219]|0}else{X=S;Y=T}}while(0);n=l+7|0;do{if((X&255)>(d[Y+n|0]|0)){k=a[q+7|0]|0;if(k<<24>>24==0){break}v=b[(c[277225]|0)+((k&255)<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)==0){aa=c[277228]&65535}else{aa=b[(c[277213]|0)+(n<<1)>>1]|0}k=v&-2048;m=aa&-2048;p=(k&65535)>(m&65535)?k-m&65535:0;m=v&2016;k=aa&2016;if((m&65535)>(k&65535)){ab=(m-k&65535)+p&65535}else{ab=p}p=v&31;v=aa&31;if((p&65535)>(v&65535)){ac=(p-v&65535)+ab&65535}else{ac=ab}b[(c[277218]|0)+(n<<1)>>1]=ac;a[(c[277219]|0)+n|0]=a[1108909]|0}}while(0);n=i-1|0;if((n|0)<=0){break}q=q+8|0;i=n;l=(c[277223]|0)+l|0}return}if((e&32768|0)==0){if((h|0)<=0){return}e=o+g|0;l=h;i=f;while(1){q=a[1108908]|0;ac=c[277219]|0;do{if((q&255)>(d[ac+i|0]|0)){ab=a[e+7|0]|0;if(ab<<24>>24==0){ad=q;ae=ac;break}aa=b[(c[277225]|0)+((ab&255)<<1)>>1]|0;if((a[(c[277215]|0)+i|0]&32)==0){af=c[277228]&65535}else{af=b[(c[277213]|0)+(i<<1)>>1]|0}ab=aa&-2048;Y=af&-2048;X=(ab&65535)>(Y&65535)?ab-Y&65535:0;Y=aa&2016;ab=af&2016;if((Y&65535)>(ab&65535)){ag=(Y-ab&65535)+X&65535}else{ag=X}X=aa&31;aa=af&31;if((X&65535)>(aa&65535)){ah=(X-aa&65535)+ag&65535}else{ah=ag}b[(c[277218]|0)+(i<<1)>>1]=ah;a[(c[277219]|0)+i|0]=a[1108909]|0;ad=a[1108908]|0;ae=c[277219]|0}else{ad=q;ae=ac}}while(0);ac=i+1|0;do{if((ad&255)>(d[ae+ac|0]|0)){q=a[e+6|0]|0;if(q<<24>>24==0){ai=ad;aj=ae;break}aa=b[(c[277225]|0)+((q&255)<<1)>>1]|0;if((a[(c[277215]|0)+ac|0]&32)==0){ak=c[277228]&65535}else{ak=b[(c[277213]|0)+(ac<<1)>>1]|0}q=aa&-2048;X=ak&-2048;ab=(q&65535)>(X&65535)?q-X&65535:0;X=aa&2016;q=ak&2016;if((X&65535)>(q&65535)){al=(X-q&65535)+ab&65535}else{al=ab}ab=aa&31;aa=ak&31;if((ab&65535)>(aa&65535)){am=(ab-aa&65535)+al&65535}else{am=al}b[(c[277218]|0)+(ac<<1)>>1]=am;a[(c[277219]|0)+ac|0]=a[1108909]|0;ai=a[1108908]|0;aj=c[277219]|0}else{ai=ad;aj=ae}}while(0);ac=i+2|0;do{if((ai&255)>(d[aj+ac|0]|0)){aa=a[e+5|0]|0;if(aa<<24>>24==0){an=ai;ao=aj;break}ab=b[(c[277225]|0)+((aa&255)<<1)>>1]|0;if((a[(c[277215]|0)+ac|0]&32)==0){ap=c[277228]&65535}else{ap=b[(c[277213]|0)+(ac<<1)>>1]|0}aa=ab&-2048;q=ap&-2048;X=(aa&65535)>(q&65535)?aa-q&65535:0;q=ab&2016;aa=ap&2016;if((q&65535)>(aa&65535)){aq=(q-aa&65535)+X&65535}else{aq=X}X=ab&31;ab=ap&31;if((X&65535)>(ab&65535)){ar=(X-ab&65535)+aq&65535}else{ar=aq}b[(c[277218]|0)+(ac<<1)>>1]=ar;a[(c[277219]|0)+ac|0]=a[1108909]|0;an=a[1108908]|0;ao=c[277219]|0}else{an=ai;ao=aj}}while(0);ac=i+3|0;do{if((an&255)>(d[ao+ac|0]|0)){ab=a[e+4|0]|0;if(ab<<24>>24==0){as=an;at=ao;break}X=b[(c[277225]|0)+((ab&255)<<1)>>1]|0;if((a[(c[277215]|0)+ac|0]&32)==0){au=c[277228]&65535}else{au=b[(c[277213]|0)+(ac<<1)>>1]|0}ab=X&-2048;aa=au&-2048;q=(ab&65535)>(aa&65535)?ab-aa&65535:0;aa=X&2016;ab=au&2016;if((aa&65535)>(ab&65535)){av=(aa-ab&65535)+q&65535}else{av=q}q=X&31;X=au&31;if((q&65535)>(X&65535)){aw=(q-X&65535)+av&65535}else{aw=av}b[(c[277218]|0)+(ac<<1)>>1]=aw;a[(c[277219]|0)+ac|0]=a[1108909]|0;as=a[1108908]|0;at=c[277219]|0}else{as=an;at=ao}}while(0);ac=i+4|0;do{if((as&255)>(d[at+ac|0]|0)){X=a[e+3|0]|0;if(X<<24>>24==0){ax=as;ay=at;break}q=b[(c[277225]|0)+((X&255)<<1)>>1]|0;if((a[(c[277215]|0)+ac|0]&32)==0){az=c[277228]&65535}else{az=b[(c[277213]|0)+(ac<<1)>>1]|0}X=q&-2048;ab=az&-2048;aa=(X&65535)>(ab&65535)?X-ab&65535:0;ab=q&2016;X=az&2016;if((ab&65535)>(X&65535)){aA=(ab-X&65535)+aa&65535}else{aA=aa}aa=q&31;q=az&31;if((aa&65535)>(q&65535)){aB=(aa-q&65535)+aA&65535}else{aB=aA}b[(c[277218]|0)+(ac<<1)>>1]=aB;a[(c[277219]|0)+ac|0]=a[1108909]|0;ax=a[1108908]|0;ay=c[277219]|0}else{ax=as;ay=at}}while(0);ac=i+5|0;do{if((ax&255)>(d[ay+ac|0]|0)){q=a[e+2|0]|0;if(q<<24>>24==0){aC=ax;aD=ay;break}aa=b[(c[277225]|0)+((q&255)<<1)>>1]|0;if((a[(c[277215]|0)+ac|0]&32)==0){aE=c[277228]&65535}else{aE=b[(c[277213]|0)+(ac<<1)>>1]|0}q=aa&-2048;X=aE&-2048;ab=(q&65535)>(X&65535)?q-X&65535:0;X=aa&2016;q=aE&2016;if((X&65535)>(q&65535)){aF=(X-q&65535)+ab&65535}else{aF=ab}ab=aa&31;aa=aE&31;if((ab&65535)>(aa&65535)){aG=(ab-aa&65535)+aF&65535}else{aG=aF}b[(c[277218]|0)+(ac<<1)>>1]=aG;a[(c[277219]|0)+ac|0]=a[1108909]|0;aC=a[1108908]|0;aD=c[277219]|0}else{aC=ax;aD=ay}}while(0);ac=i+6|0;do{if((aC&255)>(d[aD+ac|0]|0)){aa=a[e+1|0]|0;if(aa<<24>>24==0){aH=aC;aI=aD;break}ab=b[(c[277225]|0)+((aa&255)<<1)>>1]|0;if((a[(c[277215]|0)+ac|0]&32)==0){aJ=c[277228]&65535}else{aJ=b[(c[277213]|0)+(ac<<1)>>1]|0}aa=ab&-2048;q=aJ&-2048;X=(aa&65535)>(q&65535)?aa-q&65535:0;q=ab&2016;aa=aJ&2016;if((q&65535)>(aa&65535)){aK=(q-aa&65535)+X&65535}else{aK=X}X=ab&31;ab=aJ&31;if((X&65535)>(ab&65535)){aL=(X-ab&65535)+aK&65535}else{aL=aK}b[(c[277218]|0)+(ac<<1)>>1]=aL;a[(c[277219]|0)+ac|0]=a[1108909]|0;aH=a[1108908]|0;aI=c[277219]|0}else{aH=aC;aI=aD}}while(0);ac=i+7|0;do{if((aH&255)>(d[aI+ac|0]|0)){ab=a[e]|0;if(ab<<24>>24==0){break}X=b[(c[277225]|0)+((ab&255)<<1)>>1]|0;if((a[(c[277215]|0)+ac|0]&32)==0){aM=c[277228]&65535}else{aM=b[(c[277213]|0)+(ac<<1)>>1]|0}ab=X&-2048;aa=aM&-2048;q=(ab&65535)>(aa&65535)?ab-aa&65535:0;aa=X&2016;ab=aM&2016;if((aa&65535)>(ab&65535)){aN=(aa-ab&65535)+q&65535}else{aN=q}q=X&31;X=aM&31;if((q&65535)>(X&65535)){aO=(q-X&65535)+aN&65535}else{aO=aN}b[(c[277218]|0)+(ac<<1)>>1]=aO;a[(c[277219]|0)+ac|0]=a[1108909]|0}}while(0);ac=l-1|0;if((ac|0)<=0){break}e=e+8|0;l=ac;i=(c[277223]|0)+i|0}return}i=o+(56-g)|0;g=(h|0)>0;if(j){if(g){aP=i;aQ=h;aR=f}else{return}while(1){j=a[1108908]|0;o=c[277219]|0;do{if((j&255)>(d[o+aR|0]|0)){l=a[aP+7|0]|0;if(l<<24>>24==0){aS=j;aT=o;break}e=b[(c[277225]|0)+((l&255)<<1)>>1]|0;if((a[(c[277215]|0)+aR|0]&32)==0){aU=c[277228]&65535}else{aU=b[(c[277213]|0)+(aR<<1)>>1]|0}l=e&-2048;aO=aU&-2048;aN=(l&65535)>(aO&65535)?l-aO&65535:0;aO=e&2016;l=aU&2016;if((aO&65535)>(l&65535)){aV=(aO-l&65535)+aN&65535}else{aV=aN}aN=e&31;e=aU&31;if((aN&65535)>(e&65535)){aW=(aN-e&65535)+aV&65535}else{aW=aV}b[(c[277218]|0)+(aR<<1)>>1]=aW;a[(c[277219]|0)+aR|0]=a[1108909]|0;aS=a[1108908]|0;aT=c[277219]|0}else{aS=j;aT=o}}while(0);o=aR+1|0;do{if((aS&255)>(d[aT+o|0]|0)){j=a[aP+6|0]|0;if(j<<24>>24==0){aX=aS;aY=aT;break}e=b[(c[277225]|0)+((j&255)<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){aZ=c[277228]&65535}else{aZ=b[(c[277213]|0)+(o<<1)>>1]|0}j=e&-2048;aN=aZ&-2048;l=(j&65535)>(aN&65535)?j-aN&65535:0;aN=e&2016;j=aZ&2016;if((aN&65535)>(j&65535)){a_=(aN-j&65535)+l&65535}else{a_=l}l=e&31;e=aZ&31;if((l&65535)>(e&65535)){a$=(l-e&65535)+a_&65535}else{a$=a_}b[(c[277218]|0)+(o<<1)>>1]=a$;a[(c[277219]|0)+o|0]=a[1108909]|0;aX=a[1108908]|0;aY=c[277219]|0}else{aX=aS;aY=aT}}while(0);o=aR+2|0;do{if((aX&255)>(d[aY+o|0]|0)){e=a[aP+5|0]|0;if(e<<24>>24==0){a0=aX;a1=aY;break}l=b[(c[277225]|0)+((e&255)<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){a2=c[277228]&65535}else{a2=b[(c[277213]|0)+(o<<1)>>1]|0}e=l&-2048;j=a2&-2048;aN=(e&65535)>(j&65535)?e-j&65535:0;j=l&2016;e=a2&2016;if((j&65535)>(e&65535)){a3=(j-e&65535)+aN&65535}else{a3=aN}aN=l&31;l=a2&31;if((aN&65535)>(l&65535)){a4=(aN-l&65535)+a3&65535}else{a4=a3}b[(c[277218]|0)+(o<<1)>>1]=a4;a[(c[277219]|0)+o|0]=a[1108909]|0;a0=a[1108908]|0;a1=c[277219]|0}else{a0=aX;a1=aY}}while(0);o=aR+3|0;do{if((a0&255)>(d[a1+o|0]|0)){l=a[aP+4|0]|0;if(l<<24>>24==0){a5=a0;a6=a1;break}aN=b[(c[277225]|0)+((l&255)<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){a7=c[277228]&65535}else{a7=b[(c[277213]|0)+(o<<1)>>1]|0}l=aN&-2048;e=a7&-2048;j=(l&65535)>(e&65535)?l-e&65535:0;e=aN&2016;l=a7&2016;if((e&65535)>(l&65535)){a8=(e-l&65535)+j&65535}else{a8=j}j=aN&31;aN=a7&31;if((j&65535)>(aN&65535)){a9=(j-aN&65535)+a8&65535}else{a9=a8}b[(c[277218]|0)+(o<<1)>>1]=a9;a[(c[277219]|0)+o|0]=a[1108909]|0;a5=a[1108908]|0;a6=c[277219]|0}else{a5=a0;a6=a1}}while(0);o=aR+4|0;do{if((a5&255)>(d[a6+o|0]|0)){aN=a[aP+3|0]|0;if(aN<<24>>24==0){ba=a5;bb=a6;break}j=b[(c[277225]|0)+((aN&255)<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){bc=c[277228]&65535}else{bc=b[(c[277213]|0)+(o<<1)>>1]|0}aN=j&-2048;l=bc&-2048;e=(aN&65535)>(l&65535)?aN-l&65535:0;l=j&2016;aN=bc&2016;if((l&65535)>(aN&65535)){bd=(l-aN&65535)+e&65535}else{bd=e}e=j&31;j=bc&31;if((e&65535)>(j&65535)){be=(e-j&65535)+bd&65535}else{be=bd}b[(c[277218]|0)+(o<<1)>>1]=be;a[(c[277219]|0)+o|0]=a[1108909]|0;ba=a[1108908]|0;bb=c[277219]|0}else{ba=a5;bb=a6}}while(0);o=aR+5|0;do{if((ba&255)>(d[bb+o|0]|0)){j=a[aP+2|0]|0;if(j<<24>>24==0){bf=ba;bg=bb;break}e=b[(c[277225]|0)+((j&255)<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){bh=c[277228]&65535}else{bh=b[(c[277213]|0)+(o<<1)>>1]|0}j=e&-2048;aN=bh&-2048;l=(j&65535)>(aN&65535)?j-aN&65535:0;aN=e&2016;j=bh&2016;if((aN&65535)>(j&65535)){bi=(aN-j&65535)+l&65535}else{bi=l}l=e&31;e=bh&31;if((l&65535)>(e&65535)){bj=(l-e&65535)+bi&65535}else{bj=bi}b[(c[277218]|0)+(o<<1)>>1]=bj;a[(c[277219]|0)+o|0]=a[1108909]|0;bf=a[1108908]|0;bg=c[277219]|0}else{bf=ba;bg=bb}}while(0);o=aR+6|0;do{if((bf&255)>(d[bg+o|0]|0)){e=a[aP+1|0]|0;if(e<<24>>24==0){bk=bf;bl=bg;break}l=b[(c[277225]|0)+((e&255)<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){bm=c[277228]&65535}else{bm=b[(c[277213]|0)+(o<<1)>>1]|0}e=l&-2048;j=bm&-2048;aN=(e&65535)>(j&65535)?e-j&65535:0;j=l&2016;e=bm&2016;if((j&65535)>(e&65535)){bn=(j-e&65535)+aN&65535}else{bn=aN}aN=l&31;l=bm&31;if((aN&65535)>(l&65535)){bo=(aN-l&65535)+bn&65535}else{bo=bn}b[(c[277218]|0)+(o<<1)>>1]=bo;a[(c[277219]|0)+o|0]=a[1108909]|0;bk=a[1108908]|0;bl=c[277219]|0}else{bk=bf;bl=bg}}while(0);o=aR+7|0;do{if((bk&255)>(d[bl+o|0]|0)){l=a[aP]|0;if(l<<24>>24==0){break}aN=b[(c[277225]|0)+((l&255)<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){bp=c[277228]&65535}else{bp=b[(c[277213]|0)+(o<<1)>>1]|0}l=aN&-2048;e=bp&-2048;j=(l&65535)>(e&65535)?l-e&65535:0;e=aN&2016;l=bp&2016;if((e&65535)>(l&65535)){bq=(e-l&65535)+j&65535}else{bq=j}j=aN&31;aN=bp&31;if((j&65535)>(aN&65535)){br=(j-aN&65535)+bq&65535}else{br=bq}b[(c[277218]|0)+(o<<1)>>1]=br;a[(c[277219]|0)+o|0]=a[1108909]|0}}while(0);o=aQ-1|0;if((o|0)<=0){break}aP=aP-8|0;aQ=o;aR=(c[277223]|0)+aR|0}return}else{if(g){bs=i;bt=h;bu=f}else{return}while(1){f=a[1108908]|0;h=c[277219]|0;do{if((f&255)>(d[h+bu|0]|0)){i=a[bs]|0;if(i<<24>>24==0){bv=f;bw=h;break}g=b[(c[277225]|0)+((i&255)<<1)>>1]|0;if((a[(c[277215]|0)+bu|0]&32)==0){bx=c[277228]&65535}else{bx=b[(c[277213]|0)+(bu<<1)>>1]|0}i=g&-2048;aR=bx&-2048;aQ=(i&65535)>(aR&65535)?i-aR&65535:0;aR=g&2016;i=bx&2016;if((aR&65535)>(i&65535)){by=(aR-i&65535)+aQ&65535}else{by=aQ}aQ=g&31;g=bx&31;if((aQ&65535)>(g&65535)){bz=(aQ-g&65535)+by&65535}else{bz=by}b[(c[277218]|0)+(bu<<1)>>1]=bz;a[(c[277219]|0)+bu|0]=a[1108909]|0;bv=a[1108908]|0;bw=c[277219]|0}else{bv=f;bw=h}}while(0);h=bu+1|0;do{if((bv&255)>(d[bw+h|0]|0)){f=a[bs+1|0]|0;if(f<<24>>24==0){bA=bv;bB=bw;break}g=b[(c[277225]|0)+((f&255)<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)==0){bC=c[277228]&65535}else{bC=b[(c[277213]|0)+(h<<1)>>1]|0}f=g&-2048;aQ=bC&-2048;i=(f&65535)>(aQ&65535)?f-aQ&65535:0;aQ=g&2016;f=bC&2016;if((aQ&65535)>(f&65535)){bD=(aQ-f&65535)+i&65535}else{bD=i}i=g&31;g=bC&31;if((i&65535)>(g&65535)){bE=(i-g&65535)+bD&65535}else{bE=bD}b[(c[277218]|0)+(h<<1)>>1]=bE;a[(c[277219]|0)+h|0]=a[1108909]|0;bA=a[1108908]|0;bB=c[277219]|0}else{bA=bv;bB=bw}}while(0);h=bu+2|0;do{if((bA&255)>(d[bB+h|0]|0)){g=a[bs+2|0]|0;if(g<<24>>24==0){bF=bA;bG=bB;break}i=b[(c[277225]|0)+((g&255)<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)==0){bH=c[277228]&65535}else{bH=b[(c[277213]|0)+(h<<1)>>1]|0}g=i&-2048;f=bH&-2048;aQ=(g&65535)>(f&65535)?g-f&65535:0;f=i&2016;g=bH&2016;if((f&65535)>(g&65535)){bI=(f-g&65535)+aQ&65535}else{bI=aQ}aQ=i&31;i=bH&31;if((aQ&65535)>(i&65535)){bJ=(aQ-i&65535)+bI&65535}else{bJ=bI}b[(c[277218]|0)+(h<<1)>>1]=bJ;a[(c[277219]|0)+h|0]=a[1108909]|0;bF=a[1108908]|0;bG=c[277219]|0}else{bF=bA;bG=bB}}while(0);h=bu+3|0;do{if((bF&255)>(d[bG+h|0]|0)){i=a[bs+3|0]|0;if(i<<24>>24==0){bK=bF;bL=bG;break}aQ=b[(c[277225]|0)+((i&255)<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)==0){bM=c[277228]&65535}else{bM=b[(c[277213]|0)+(h<<1)>>1]|0}i=aQ&-2048;g=bM&-2048;f=(i&65535)>(g&65535)?i-g&65535:0;g=aQ&2016;i=bM&2016;if((g&65535)>(i&65535)){bN=(g-i&65535)+f&65535}else{bN=f}f=aQ&31;aQ=bM&31;if((f&65535)>(aQ&65535)){bO=(f-aQ&65535)+bN&65535}else{bO=bN}b[(c[277218]|0)+(h<<1)>>1]=bO;a[(c[277219]|0)+h|0]=a[1108909]|0;bK=a[1108908]|0;bL=c[277219]|0}else{bK=bF;bL=bG}}while(0);h=bu+4|0;do{if((bK&255)>(d[bL+h|0]|0)){aQ=a[bs+4|0]|0;if(aQ<<24>>24==0){bP=bK;bQ=bL;break}f=b[(c[277225]|0)+((aQ&255)<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)==0){bR=c[277228]&65535}else{bR=b[(c[277213]|0)+(h<<1)>>1]|0}aQ=f&-2048;i=bR&-2048;g=(aQ&65535)>(i&65535)?aQ-i&65535:0;i=f&2016;aQ=bR&2016;if((i&65535)>(aQ&65535)){bS=(i-aQ&65535)+g&65535}else{bS=g}g=f&31;f=bR&31;if((g&65535)>(f&65535)){bT=(g-f&65535)+bS&65535}else{bT=bS}b[(c[277218]|0)+(h<<1)>>1]=bT;a[(c[277219]|0)+h|0]=a[1108909]|0;bP=a[1108908]|0;bQ=c[277219]|0}else{bP=bK;bQ=bL}}while(0);h=bu+5|0;do{if((bP&255)>(d[bQ+h|0]|0)){f=a[bs+5|0]|0;if(f<<24>>24==0){bU=bP;bV=bQ;break}g=b[(c[277225]|0)+((f&255)<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)==0){bW=c[277228]&65535}else{bW=b[(c[277213]|0)+(h<<1)>>1]|0}f=g&-2048;aQ=bW&-2048;i=(f&65535)>(aQ&65535)?f-aQ&65535:0;aQ=g&2016;f=bW&2016;if((aQ&65535)>(f&65535)){bX=(aQ-f&65535)+i&65535}else{bX=i}i=g&31;g=bW&31;if((i&65535)>(g&65535)){bY=(i-g&65535)+bX&65535}else{bY=bX}b[(c[277218]|0)+(h<<1)>>1]=bY;a[(c[277219]|0)+h|0]=a[1108909]|0;bU=a[1108908]|0;bV=c[277219]|0}else{bU=bP;bV=bQ}}while(0);h=bu+6|0;do{if((bU&255)>(d[bV+h|0]|0)){g=a[bs+6|0]|0;if(g<<24>>24==0){bZ=bU;b_=bV;break}i=b[(c[277225]|0)+((g&255)<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)==0){b$=c[277228]&65535}else{b$=b[(c[277213]|0)+(h<<1)>>1]|0}g=i&-2048;f=b$&-2048;aQ=(g&65535)>(f&65535)?g-f&65535:0;f=i&2016;g=b$&2016;if((f&65535)>(g&65535)){b0=(f-g&65535)+aQ&65535}else{b0=aQ}aQ=i&31;i=b$&31;if((aQ&65535)>(i&65535)){b1=(aQ-i&65535)+b0&65535}else{b1=b0}b[(c[277218]|0)+(h<<1)>>1]=b1;a[(c[277219]|0)+h|0]=a[1108909]|0;bZ=a[1108908]|0;b_=c[277219]|0}else{bZ=bU;b_=bV}}while(0);h=bu+7|0;do{if((bZ&255)>(d[b_+h|0]|0)){i=a[bs+7|0]|0;if(i<<24>>24==0){break}aQ=b[(c[277225]|0)+((i&255)<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)==0){b2=c[277228]&65535}else{b2=b[(c[277213]|0)+(h<<1)>>1]|0}i=aQ&-2048;g=b2&-2048;f=(i&65535)>(g&65535)?i-g&65535:0;g=aQ&2016;i=b2&2016;if((g&65535)>(i&65535)){b3=(g-i&65535)+f&65535}else{b3=f}f=aQ&31;aQ=b2&31;if((f&65535)>(aQ&65535)){b4=(f-aQ&65535)+b3&65535}else{b4=b3}b[(c[277218]|0)+(h<<1)>>1]=b4;a[(c[277219]|0)+h|0]=a[1108909]|0}}while(0);h=bt-1|0;if((h|0)<=0){break}bs=bs-8|0;bt=h;bu=(c[277223]|0)+bu|0}return}}function Xw(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0;i=e&1023;j=c[348606]|0;k=(i<<j)+(c[348604]|0)|0;if((e&256|0)==0){l=k}else{l=(c[348602]|0)+k|0}k=l&65535;l=k>>>(j>>>0);j=(e&16384|0)!=0;m=l<<6;do{if(j){n=(c[348622]|0)+m|0;if((a[(c[348618]|0)+l|0]|0)!=0){o=n;break}p=fi[c[348636]&63](n,k,i)|0;a[(c[348618]|0)+l|0]=p;o=n}else{n=(c[348624]|0)+m|0;if((a[(c[348620]|0)+l|0]|0)!=0){o=n;break}p=fi[c[348638]&63](n,k,i)|0;a[(c[348620]|0)+l|0]=p;o=n}}while(0);if((a[(c[348620]|0)+l|0]|0)==2){return}if((a[1394464]|0)==0){q=1106168+((e>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){l=d[1044485]|0;c[276541]=7080+(l<<5);i=0;do{k=i<<1&2;m=i&2;n=i&4;p=0;do{b[1125528+(i<<9)+(p<<1)>>1]=d[(p>>>1&28|m)+(7080+(l<<5))|0]<<6|d[(p<<2&28|k)+(7080+(l<<5))|0]<<11|d[(p>>>3&24|n)+(7080+(l<<5))|0];p=p+1|0;}while(p>>>0<256);i=i+1|0;}while(i>>>0<8);a[1106089]=0}q=1125528+((e>>>10&7)<<9)|0}c[277226]=q;c[277225]=(a[1108928]|0)!=0?1393712:q;if((e&49152|0)==0){if((h|0)<=0){return}q=o+g|0;i=h;l=f;while(1){p=a[1108908]|0;n=c[277219]|0;do{if((p&255)>(d[n+l|0]|0)){k=a[q]|0;if(k<<24>>24==0){r=p;s=n;break}m=b[(c[277225]|0)+((k&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){t=b[(c[277221]|0)+(((m&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{k=c[277228]&65535;u=m&-2048;v=k&-2048;w=(u&65535)>(v&65535)?u-v&65535:0;v=m&2016;u=k&2016;if((v&65535)>(u&65535)){x=(v-u&65535)+w&65535}else{x=w}w=m&31;u=k&31;if((w&65535)<=(u&65535)){t=x;break}t=(w-u&65535)+x&65535}}while(0);b[(c[277218]|0)+(l<<1)>>1]=t;a[(c[277219]|0)+l|0]=a[1108909]|0;r=a[1108908]|0;s=c[277219]|0}else{r=p;s=n}}while(0);n=l+1|0;do{if((r&255)>(d[s+n|0]|0)){p=a[q+1|0]|0;if(p<<24>>24==0){y=r;z=s;break}m=b[(c[277225]|0)+((p&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){A=b[(c[277221]|0)+(((m&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{p=c[277228]&65535;u=m&-2048;w=p&-2048;k=(u&65535)>(w&65535)?u-w&65535:0;w=m&2016;u=p&2016;if((w&65535)>(u&65535)){B=(w-u&65535)+k&65535}else{B=k}k=m&31;u=p&31;if((k&65535)<=(u&65535)){A=B;break}A=(k-u&65535)+B&65535}}while(0);b[(c[277218]|0)+(n<<1)>>1]=A;a[(c[277219]|0)+n|0]=a[1108909]|0;y=a[1108908]|0;z=c[277219]|0}else{y=r;z=s}}while(0);n=l+2|0;do{if((y&255)>(d[z+n|0]|0)){m=a[q+2|0]|0;if(m<<24>>24==0){C=y;D=z;break}u=b[(c[277225]|0)+((m&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){E=b[(c[277221]|0)+(((u&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{m=c[277228]&65535;k=u&-2048;p=m&-2048;w=(k&65535)>(p&65535)?k-p&65535:0;p=u&2016;k=m&2016;if((p&65535)>(k&65535)){F=(p-k&65535)+w&65535}else{F=w}w=u&31;k=m&31;if((w&65535)<=(k&65535)){E=F;break}E=(w-k&65535)+F&65535}}while(0);b[(c[277218]|0)+(n<<1)>>1]=E;a[(c[277219]|0)+n|0]=a[1108909]|0;C=a[1108908]|0;D=c[277219]|0}else{C=y;D=z}}while(0);n=l+3|0;do{if((C&255)>(d[D+n|0]|0)){u=a[q+3|0]|0;if(u<<24>>24==0){G=C;H=D;break}k=b[(c[277225]|0)+((u&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){I=b[(c[277221]|0)+(((k&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{u=c[277228]&65535;w=k&-2048;m=u&-2048;p=(w&65535)>(m&65535)?w-m&65535:0;m=k&2016;w=u&2016;if((m&65535)>(w&65535)){J=(m-w&65535)+p&65535}else{J=p}p=k&31;w=u&31;if((p&65535)<=(w&65535)){I=J;break}I=(p-w&65535)+J&65535}}while(0);b[(c[277218]|0)+(n<<1)>>1]=I;a[(c[277219]|0)+n|0]=a[1108909]|0;G=a[1108908]|0;H=c[277219]|0}else{G=C;H=D}}while(0);n=l+4|0;do{if((G&255)>(d[H+n|0]|0)){k=a[q+4|0]|0;if(k<<24>>24==0){K=G;L=H;break}w=b[(c[277225]|0)+((k&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){M=b[(c[277221]|0)+(((w&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{k=c[277228]&65535;p=w&-2048;u=k&-2048;m=(p&65535)>(u&65535)?p-u&65535:0;u=w&2016;p=k&2016;if((u&65535)>(p&65535)){N=(u-p&65535)+m&65535}else{N=m}m=w&31;p=k&31;if((m&65535)<=(p&65535)){M=N;break}M=(m-p&65535)+N&65535}}while(0);b[(c[277218]|0)+(n<<1)>>1]=M;a[(c[277219]|0)+n|0]=a[1108909]|0;K=a[1108908]|0;L=c[277219]|0}else{K=G;L=H}}while(0);n=l+5|0;do{if((K&255)>(d[L+n|0]|0)){w=a[q+5|0]|0;if(w<<24>>24==0){O=K;P=L;break}p=b[(c[277225]|0)+((w&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){Q=b[(c[277221]|0)+(((p&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{w=c[277228]&65535;m=p&-2048;k=w&-2048;u=(m&65535)>(k&65535)?m-k&65535:0;k=p&2016;m=w&2016;if((k&65535)>(m&65535)){R=(k-m&65535)+u&65535}else{R=u}u=p&31;m=w&31;if((u&65535)<=(m&65535)){Q=R;break}Q=(u-m&65535)+R&65535}}while(0);b[(c[277218]|0)+(n<<1)>>1]=Q;a[(c[277219]|0)+n|0]=a[1108909]|0;O=a[1108908]|0;P=c[277219]|0}else{O=K;P=L}}while(0);n=l+6|0;do{if((O&255)>(d[P+n|0]|0)){p=a[q+6|0]|0;if(p<<24>>24==0){S=O;T=P;break}m=b[(c[277225]|0)+((p&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){U=b[(c[277221]|0)+(((m&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{p=c[277228]&65535;u=m&-2048;w=p&-2048;k=(u&65535)>(w&65535)?u-w&65535:0;w=m&2016;u=p&2016;if((w&65535)>(u&65535)){V=(w-u&65535)+k&65535}else{V=k}k=m&31;u=p&31;if((k&65535)<=(u&65535)){U=V;break}U=(k-u&65535)+V&65535}}while(0);b[(c[277218]|0)+(n<<1)>>1]=U;a[(c[277219]|0)+n|0]=a[1108909]|0;S=a[1108908]|0;T=c[277219]|0}else{S=O;T=P}}while(0);n=l+7|0;do{if((S&255)>(d[T+n|0]|0)){m=a[q+7|0]|0;if(m<<24>>24==0){break}u=b[(c[277225]|0)+((m&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){W=b[(c[277221]|0)+(((u&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{m=c[277228]&65535;k=u&-2048;p=m&-2048;w=(k&65535)>(p&65535)?k-p&65535:0;p=u&2016;k=m&2016;if((p&65535)>(k&65535)){X=(p-k&65535)+w&65535}else{X=w}w=u&31;k=m&31;if((w&65535)<=(k&65535)){W=X;break}W=(w-k&65535)+X&65535}}while(0);b[(c[277218]|0)+(n<<1)>>1]=W;a[(c[277219]|0)+n|0]=a[1108909]|0}}while(0);n=i-1|0;if((n|0)<=0){break}q=q+8|0;i=n;l=(c[277223]|0)+l|0}return}if((e&32768|0)==0){if((h|0)<=0){return}e=o+g|0;l=h;i=f;while(1){q=a[1108908]|0;W=c[277219]|0;do{if((q&255)>(d[W+i|0]|0)){X=a[e+7|0]|0;if(X<<24>>24==0){Y=q;Z=W;break}T=b[(c[277225]|0)+((X&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){_=b[(c[277221]|0)+(((T&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{X=c[277228]&65535;S=T&-2048;P=X&-2048;O=(S&65535)>(P&65535)?S-P&65535:0;P=T&2016;S=X&2016;if((P&65535)>(S&65535)){$=(P-S&65535)+O&65535}else{$=O}O=T&31;S=X&31;if((O&65535)<=(S&65535)){_=$;break}_=(O-S&65535)+$&65535}}while(0);b[(c[277218]|0)+(i<<1)>>1]=_;a[(c[277219]|0)+i|0]=a[1108909]|0;Y=a[1108908]|0;Z=c[277219]|0}else{Y=q;Z=W}}while(0);W=i+1|0;do{if((Y&255)>(d[Z+W|0]|0)){q=a[e+6|0]|0;if(q<<24>>24==0){aa=Y;ab=Z;break}T=b[(c[277225]|0)+((q&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){ac=b[(c[277221]|0)+(((T&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{q=c[277228]&65535;S=T&-2048;O=q&-2048;X=(S&65535)>(O&65535)?S-O&65535:0;O=T&2016;S=q&2016;if((O&65535)>(S&65535)){ad=(O-S&65535)+X&65535}else{ad=X}X=T&31;S=q&31;if((X&65535)<=(S&65535)){ac=ad;break}ac=(X-S&65535)+ad&65535}}while(0);b[(c[277218]|0)+(W<<1)>>1]=ac;a[(c[277219]|0)+W|0]=a[1108909]|0;aa=a[1108908]|0;ab=c[277219]|0}else{aa=Y;ab=Z}}while(0);W=i+2|0;do{if((aa&255)>(d[ab+W|0]|0)){T=a[e+5|0]|0;if(T<<24>>24==0){ae=aa;af=ab;break}S=b[(c[277225]|0)+((T&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){ag=b[(c[277221]|0)+(((S&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{T=c[277228]&65535;X=S&-2048;q=T&-2048;O=(X&65535)>(q&65535)?X-q&65535:0;q=S&2016;X=T&2016;if((q&65535)>(X&65535)){ah=(q-X&65535)+O&65535}else{ah=O}O=S&31;X=T&31;if((O&65535)<=(X&65535)){ag=ah;break}ag=(O-X&65535)+ah&65535}}while(0);b[(c[277218]|0)+(W<<1)>>1]=ag;a[(c[277219]|0)+W|0]=a[1108909]|0;ae=a[1108908]|0;af=c[277219]|0}else{ae=aa;af=ab}}while(0);W=i+3|0;do{if((ae&255)>(d[af+W|0]|0)){S=a[e+4|0]|0;if(S<<24>>24==0){ai=ae;aj=af;break}X=b[(c[277225]|0)+((S&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){ak=b[(c[277221]|0)+(((X&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{S=c[277228]&65535;O=X&-2048;T=S&-2048;q=(O&65535)>(T&65535)?O-T&65535:0;T=X&2016;O=S&2016;if((T&65535)>(O&65535)){al=(T-O&65535)+q&65535}else{al=q}q=X&31;O=S&31;if((q&65535)<=(O&65535)){ak=al;break}ak=(q-O&65535)+al&65535}}while(0);b[(c[277218]|0)+(W<<1)>>1]=ak;a[(c[277219]|0)+W|0]=a[1108909]|0;ai=a[1108908]|0;aj=c[277219]|0}else{ai=ae;aj=af}}while(0);W=i+4|0;do{if((ai&255)>(d[aj+W|0]|0)){X=a[e+3|0]|0;if(X<<24>>24==0){am=ai;an=aj;break}O=b[(c[277225]|0)+((X&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){ao=b[(c[277221]|0)+(((O&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{X=c[277228]&65535;q=O&-2048;S=X&-2048;T=(q&65535)>(S&65535)?q-S&65535:0;S=O&2016;q=X&2016;if((S&65535)>(q&65535)){ap=(S-q&65535)+T&65535}else{ap=T}T=O&31;q=X&31;if((T&65535)<=(q&65535)){ao=ap;break}ao=(T-q&65535)+ap&65535}}while(0);b[(c[277218]|0)+(W<<1)>>1]=ao;a[(c[277219]|0)+W|0]=a[1108909]|0;am=a[1108908]|0;an=c[277219]|0}else{am=ai;an=aj}}while(0);W=i+5|0;do{if((am&255)>(d[an+W|0]|0)){O=a[e+2|0]|0;if(O<<24>>24==0){aq=am;ar=an;break}q=b[(c[277225]|0)+((O&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){as=b[(c[277221]|0)+(((q&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{O=c[277228]&65535;T=q&-2048;X=O&-2048;S=(T&65535)>(X&65535)?T-X&65535:0;X=q&2016;T=O&2016;if((X&65535)>(T&65535)){at=(X-T&65535)+S&65535}else{at=S}S=q&31;T=O&31;if((S&65535)<=(T&65535)){as=at;break}as=(S-T&65535)+at&65535}}while(0);b[(c[277218]|0)+(W<<1)>>1]=as;a[(c[277219]|0)+W|0]=a[1108909]|0;aq=a[1108908]|0;ar=c[277219]|0}else{aq=am;ar=an}}while(0);W=i+6|0;do{if((aq&255)>(d[ar+W|0]|0)){q=a[e+1|0]|0;if(q<<24>>24==0){au=aq;av=ar;break}T=b[(c[277225]|0)+((q&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aw=b[(c[277221]|0)+(((T&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{q=c[277228]&65535;S=T&-2048;O=q&-2048;X=(S&65535)>(O&65535)?S-O&65535:0;O=T&2016;S=q&2016;if((O&65535)>(S&65535)){ax=(O-S&65535)+X&65535}else{ax=X}X=T&31;S=q&31;if((X&65535)<=(S&65535)){aw=ax;break}aw=(X-S&65535)+ax&65535}}while(0);b[(c[277218]|0)+(W<<1)>>1]=aw;a[(c[277219]|0)+W|0]=a[1108909]|0;au=a[1108908]|0;av=c[277219]|0}else{au=aq;av=ar}}while(0);W=i+7|0;do{if((au&255)>(d[av+W|0]|0)){T=a[e]|0;if(T<<24>>24==0){break}S=b[(c[277225]|0)+((T&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){ay=b[(c[277221]|0)+(((S&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{T=c[277228]&65535;X=S&-2048;q=T&-2048;O=(X&65535)>(q&65535)?X-q&65535:0;q=S&2016;X=T&2016;if((q&65535)>(X&65535)){az=(q-X&65535)+O&65535}else{az=O}O=S&31;X=T&31;if((O&65535)<=(X&65535)){ay=az;break}ay=(O-X&65535)+az&65535}}while(0);b[(c[277218]|0)+(W<<1)>>1]=ay;a[(c[277219]|0)+W|0]=a[1108909]|0}}while(0);W=l-1|0;if((W|0)<=0){break}e=e+8|0;l=W;i=(c[277223]|0)+i|0}return}i=o+(56-g)|0;g=(h|0)>0;if(j){if(g){aA=i;aB=h;aC=f}else{return}while(1){j=a[1108908]|0;o=c[277219]|0;do{if((j&255)>(d[o+aC|0]|0)){l=a[aA+7|0]|0;if(l<<24>>24==0){aD=j;aE=o;break}e=b[(c[277225]|0)+((l&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aF=b[(c[277221]|0)+(((e&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{l=c[277228]&65535;ay=e&-2048;az=l&-2048;av=(ay&65535)>(az&65535)?ay-az&65535:0;az=e&2016;ay=l&2016;if((az&65535)>(ay&65535)){aG=(az-ay&65535)+av&65535}else{aG=av}av=e&31;ay=l&31;if((av&65535)<=(ay&65535)){aF=aG;break}aF=(av-ay&65535)+aG&65535}}while(0);b[(c[277218]|0)+(aC<<1)>>1]=aF;a[(c[277219]|0)+aC|0]=a[1108909]|0;aD=a[1108908]|0;aE=c[277219]|0}else{aD=j;aE=o}}while(0);o=aC+1|0;do{if((aD&255)>(d[aE+o|0]|0)){j=a[aA+6|0]|0;if(j<<24>>24==0){aH=aD;aI=aE;break}e=b[(c[277225]|0)+((j&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aJ=b[(c[277221]|0)+(((e&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{j=c[277228]&65535;ay=e&-2048;av=j&-2048;l=(ay&65535)>(av&65535)?ay-av&65535:0;av=e&2016;ay=j&2016;if((av&65535)>(ay&65535)){aK=(av-ay&65535)+l&65535}else{aK=l}l=e&31;ay=j&31;if((l&65535)<=(ay&65535)){aJ=aK;break}aJ=(l-ay&65535)+aK&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=aJ;a[(c[277219]|0)+o|0]=a[1108909]|0;aH=a[1108908]|0;aI=c[277219]|0}else{aH=aD;aI=aE}}while(0);o=aC+2|0;do{if((aH&255)>(d[aI+o|0]|0)){e=a[aA+5|0]|0;if(e<<24>>24==0){aL=aH;aM=aI;break}ay=b[(c[277225]|0)+((e&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aN=b[(c[277221]|0)+(((ay&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{e=c[277228]&65535;l=ay&-2048;j=e&-2048;av=(l&65535)>(j&65535)?l-j&65535:0;j=ay&2016;l=e&2016;if((j&65535)>(l&65535)){aO=(j-l&65535)+av&65535}else{aO=av}av=ay&31;l=e&31;if((av&65535)<=(l&65535)){aN=aO;break}aN=(av-l&65535)+aO&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=aN;a[(c[277219]|0)+o|0]=a[1108909]|0;aL=a[1108908]|0;aM=c[277219]|0}else{aL=aH;aM=aI}}while(0);o=aC+3|0;do{if((aL&255)>(d[aM+o|0]|0)){ay=a[aA+4|0]|0;if(ay<<24>>24==0){aP=aL;aQ=aM;break}l=b[(c[277225]|0)+((ay&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aR=b[(c[277221]|0)+(((l&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{ay=c[277228]&65535;av=l&-2048;e=ay&-2048;j=(av&65535)>(e&65535)?av-e&65535:0;e=l&2016;av=ay&2016;if((e&65535)>(av&65535)){aS=(e-av&65535)+j&65535}else{aS=j}j=l&31;av=ay&31;if((j&65535)<=(av&65535)){aR=aS;break}aR=(j-av&65535)+aS&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=aR;a[(c[277219]|0)+o|0]=a[1108909]|0;aP=a[1108908]|0;aQ=c[277219]|0}else{aP=aL;aQ=aM}}while(0);o=aC+4|0;do{if((aP&255)>(d[aQ+o|0]|0)){l=a[aA+3|0]|0;if(l<<24>>24==0){aT=aP;aU=aQ;break}av=b[(c[277225]|0)+((l&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aV=b[(c[277221]|0)+(((av&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{l=c[277228]&65535;j=av&-2048;ay=l&-2048;e=(j&65535)>(ay&65535)?j-ay&65535:0;ay=av&2016;j=l&2016;if((ay&65535)>(j&65535)){aW=(ay-j&65535)+e&65535}else{aW=e}e=av&31;j=l&31;if((e&65535)<=(j&65535)){aV=aW;break}aV=(e-j&65535)+aW&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=aV;a[(c[277219]|0)+o|0]=a[1108909]|0;aT=a[1108908]|0;aU=c[277219]|0}else{aT=aP;aU=aQ}}while(0);o=aC+5|0;do{if((aT&255)>(d[aU+o|0]|0)){av=a[aA+2|0]|0;if(av<<24>>24==0){aX=aT;aY=aU;break}j=b[(c[277225]|0)+((av&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aZ=b[(c[277221]|0)+(((j&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{av=c[277228]&65535;e=j&-2048;l=av&-2048;ay=(e&65535)>(l&65535)?e-l&65535:0;l=j&2016;e=av&2016;if((l&65535)>(e&65535)){a_=(l-e&65535)+ay&65535}else{a_=ay}ay=j&31;e=av&31;if((ay&65535)<=(e&65535)){aZ=a_;break}aZ=(ay-e&65535)+a_&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=aZ;a[(c[277219]|0)+o|0]=a[1108909]|0;aX=a[1108908]|0;aY=c[277219]|0}else{aX=aT;aY=aU}}while(0);o=aC+6|0;do{if((aX&255)>(d[aY+o|0]|0)){j=a[aA+1|0]|0;if(j<<24>>24==0){a$=aX;a0=aY;break}e=b[(c[277225]|0)+((j&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){a1=b[(c[277221]|0)+(((e&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{j=c[277228]&65535;ay=e&-2048;av=j&-2048;l=(ay&65535)>(av&65535)?ay-av&65535:0;av=e&2016;ay=j&2016;if((av&65535)>(ay&65535)){a2=(av-ay&65535)+l&65535}else{a2=l}l=e&31;ay=j&31;if((l&65535)<=(ay&65535)){a1=a2;break}a1=(l-ay&65535)+a2&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=a1;a[(c[277219]|0)+o|0]=a[1108909]|0;a$=a[1108908]|0;a0=c[277219]|0}else{a$=aX;a0=aY}}while(0);o=aC+7|0;do{if((a$&255)>(d[a0+o|0]|0)){e=a[aA]|0;if(e<<24>>24==0){break}ay=b[(c[277225]|0)+((e&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){a3=b[(c[277221]|0)+(((ay&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{e=c[277228]&65535;l=ay&-2048;j=e&-2048;av=(l&65535)>(j&65535)?l-j&65535:0;j=ay&2016;l=e&2016;if((j&65535)>(l&65535)){a4=(j-l&65535)+av&65535}else{a4=av}av=ay&31;l=e&31;if((av&65535)<=(l&65535)){a3=a4;break}a3=(av-l&65535)+a4&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=a3;a[(c[277219]|0)+o|0]=a[1108909]|0}}while(0);o=aB-1|0;if((o|0)<=0){break}aA=aA-8|0;aB=o;aC=(c[277223]|0)+aC|0}return}else{if(g){a5=i;a6=h;a7=f}else{return}while(1){f=a[1108908]|0;h=c[277219]|0;do{if((f&255)>(d[h+a7|0]|0)){i=a[a5]|0;if(i<<24>>24==0){a8=f;a9=h;break}g=b[(c[277225]|0)+((i&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){ba=b[(c[277221]|0)+(((g&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{i=c[277228]&65535;aC=g&-2048;aB=i&-2048;aA=(aC&65535)>(aB&65535)?aC-aB&65535:0;aB=g&2016;aC=i&2016;if((aB&65535)>(aC&65535)){bb=(aB-aC&65535)+aA&65535}else{bb=aA}aA=g&31;aC=i&31;if((aA&65535)<=(aC&65535)){ba=bb;break}ba=(aA-aC&65535)+bb&65535}}while(0);b[(c[277218]|0)+(a7<<1)>>1]=ba;a[(c[277219]|0)+a7|0]=a[1108909]|0;a8=a[1108908]|0;a9=c[277219]|0}else{a8=f;a9=h}}while(0);h=a7+1|0;do{if((a8&255)>(d[a9+h|0]|0)){f=a[a5+1|0]|0;if(f<<24>>24==0){bc=a8;bd=a9;break}g=b[(c[277225]|0)+((f&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){be=b[(c[277221]|0)+(((g&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{f=c[277228]&65535;aC=g&-2048;aA=f&-2048;i=(aC&65535)>(aA&65535)?aC-aA&65535:0;aA=g&2016;aC=f&2016;if((aA&65535)>(aC&65535)){bf=(aA-aC&65535)+i&65535}else{bf=i}i=g&31;aC=f&31;if((i&65535)<=(aC&65535)){be=bf;break}be=(i-aC&65535)+bf&65535}}while(0);b[(c[277218]|0)+(h<<1)>>1]=be;a[(c[277219]|0)+h|0]=a[1108909]|0;bc=a[1108908]|0;bd=c[277219]|0}else{bc=a8;bd=a9}}while(0);h=a7+2|0;do{if((bc&255)>(d[bd+h|0]|0)){g=a[a5+2|0]|0;if(g<<24>>24==0){bg=bc;bh=bd;break}aC=b[(c[277225]|0)+((g&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){bi=b[(c[277221]|0)+(((aC&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{g=c[277228]&65535;i=aC&-2048;f=g&-2048;aA=(i&65535)>(f&65535)?i-f&65535:0;f=aC&2016;i=g&2016;if((f&65535)>(i&65535)){bj=(f-i&65535)+aA&65535}else{bj=aA}aA=aC&31;i=g&31;if((aA&65535)<=(i&65535)){bi=bj;break}bi=(aA-i&65535)+bj&65535}}while(0);b[(c[277218]|0)+(h<<1)>>1]=bi;a[(c[277219]|0)+h|0]=a[1108909]|0;bg=a[1108908]|0;bh=c[277219]|0}else{bg=bc;bh=bd}}while(0);h=a7+3|0;do{if((bg&255)>(d[bh+h|0]|0)){aC=a[a5+3|0]|0;if(aC<<24>>24==0){bk=bg;bl=bh;break}i=b[(c[277225]|0)+((aC&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){bm=b[(c[277221]|0)+(((i&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{aC=c[277228]&65535;aA=i&-2048;g=aC&-2048;f=(aA&65535)>(g&65535)?aA-g&65535:0;g=i&2016;aA=aC&2016;if((g&65535)>(aA&65535)){bn=(g-aA&65535)+f&65535}else{bn=f}f=i&31;aA=aC&31;if((f&65535)<=(aA&65535)){bm=bn;break}bm=(f-aA&65535)+bn&65535}}while(0);b[(c[277218]|0)+(h<<1)>>1]=bm;a[(c[277219]|0)+h|0]=a[1108909]|0;bk=a[1108908]|0;bl=c[277219]|0}else{bk=bg;bl=bh}}while(0);h=a7+4|0;do{if((bk&255)>(d[bl+h|0]|0)){i=a[a5+4|0]|0;if(i<<24>>24==0){bo=bk;bp=bl;break}aA=b[(c[277225]|0)+((i&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){bq=b[(c[277221]|0)+(((aA&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{i=c[277228]&65535;f=aA&-2048;aC=i&-2048;g=(f&65535)>(aC&65535)?f-aC&65535:0;aC=aA&2016;f=i&2016;if((aC&65535)>(f&65535)){br=(aC-f&65535)+g&65535}else{br=g}g=aA&31;f=i&31;if((g&65535)<=(f&65535)){bq=br;break}bq=(g-f&65535)+br&65535}}while(0);b[(c[277218]|0)+(h<<1)>>1]=bq;a[(c[277219]|0)+h|0]=a[1108909]|0;bo=a[1108908]|0;bp=c[277219]|0}else{bo=bk;bp=bl}}while(0);h=a7+5|0;do{if((bo&255)>(d[bp+h|0]|0)){aA=a[a5+5|0]|0;if(aA<<24>>24==0){bs=bo;bt=bp;break}f=b[(c[277225]|0)+((aA&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){bu=b[(c[277221]|0)+(((f&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{aA=c[277228]&65535;g=f&-2048;i=aA&-2048;aC=(g&65535)>(i&65535)?g-i&65535:0;i=f&2016;g=aA&2016;if((i&65535)>(g&65535)){bv=(i-g&65535)+aC&65535}else{bv=aC}aC=f&31;g=aA&31;if((aC&65535)<=(g&65535)){bu=bv;break}bu=(aC-g&65535)+bv&65535}}while(0);b[(c[277218]|0)+(h<<1)>>1]=bu;a[(c[277219]|0)+h|0]=a[1108909]|0;bs=a[1108908]|0;bt=c[277219]|0}else{bs=bo;bt=bp}}while(0);h=a7+6|0;do{if((bs&255)>(d[bt+h|0]|0)){f=a[a5+6|0]|0;if(f<<24>>24==0){bw=bs;bx=bt;break}g=b[(c[277225]|0)+((f&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){by=b[(c[277221]|0)+(((g&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{f=c[277228]&65535;aC=g&-2048;aA=f&-2048;i=(aC&65535)>(aA&65535)?aC-aA&65535:0;aA=g&2016;aC=f&2016;if((aA&65535)>(aC&65535)){bz=(aA-aC&65535)+i&65535}else{bz=i}i=g&31;aC=f&31;if((i&65535)<=(aC&65535)){by=bz;break}by=(i-aC&65535)+bz&65535}}while(0);b[(c[277218]|0)+(h<<1)>>1]=by;a[(c[277219]|0)+h|0]=a[1108909]|0;bw=a[1108908]|0;bx=c[277219]|0}else{bw=bs;bx=bt}}while(0);h=a7+7|0;do{if((bw&255)>(d[bx+h|0]|0)){g=a[a5+7|0]|0;if(g<<24>>24==0){break}aC=b[(c[277225]|0)+((g&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){bA=b[(c[277221]|0)+(((aC&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{g=c[277228]&65535;i=aC&-2048;f=g&-2048;aA=(i&65535)>(f&65535)?i-f&65535:0;f=aC&2016;i=g&2016;if((f&65535)>(i&65535)){bB=(f-i&65535)+aA&65535}else{bB=aA}aA=aC&31;i=g&31;if((aA&65535)<=(i&65535)){bA=bB;break}bA=(aA-i&65535)+bB&65535}}while(0);b[(c[277218]|0)+(h<<1)>>1]=bA;a[(c[277219]|0)+h|0]=a[1108909]|0}}while(0);h=a6-1|0;if((h|0)<=0){break}a5=a5-8|0;a6=h;a7=(c[277223]|0)+a7|0}return}}
function VW(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0;i=c[263194]|0;c[277226]=1106168;c[277225]=(a[1108928]|0)!=0?1393712:1106168;j=c[277230]|0;if((a[1044434]|0)==0){k=j;l=1;m=0}else{n=d[1044432]|0;o=((j-(d[1044433]|0)|0)>>>0)%(n>>>0)|0;k=j-o|0;l=n;m=o}if((a[1044435]|0)==0){p=f;q=g;r=1}else{o=d[1044432]|0;n=g-1+o|0;p=f-((f|0)%(o|0)|0)|0;q=n-((n|0)%(o|0)|0)|0;r=o}o=c[277231]|0;if(k>>>0>o>>>0){return}n=(p|0)<(q|0);j=r&255;s=q-1|0;t=r-1|0;r=m;m=l;l=ab(c[277223]|0,k)|0;u=k;v=1097960+(k<<4)|0;k=o;while(1){if((m+u|0)>>>0>k>>>0){w=k+1-u|0}else{w=m}o=e[v+12>>1]<<19>>19;x=e[v+8>>1]<<19;y=e[v+10>>1]<<19;z=u+1|0;A=(e[v+14>>1]<<19>>19)-(y>>19)|0;B=(A&8192|0)!=0?A|-1024:A&1023;A=b[v+2>>1]|0;C=((a[1044414]|0)==0?z:z^255)&255;z=(ab(C,A)|0)&-64;D=z+(x>>11)+((ab(B,A)|0)&-64)|0;A=b[v+6>>1]|0;z=(ab(A,C)|0)&-64;C=z+(y>>11)+((ab(B,A)|0)&-64)|0;A=b[v>>1]|0;if((a[1044413]|0)==0){B=b[v+4>>1]|0;E=A;F=B<<16>>16;G=p;H=B}else{B=b[v+4>>1]|0;E=-A|0;F=-(B<<16>>16)|0;G=s;H=B}B=o-(x>>19)|0;x=(B&8192|0)!=0?B|-1024:B&1023;B=ab(G,A)|0;o=B+((ab(A,x)|0)&-64)|0;A=H<<16>>16;B=ab(A,G)|0;y=((ab(A,x)|0)&-64)+B|0;do{if((a[1044415]|0)==0){if(!n){break}B=(r|0)>=(w|0);x=o;A=y;z=1;I=p;while(1){J=z-1&255;do{if(J<<24>>24==0){K=x+D|0;L=(A+C|0)>>>8;M=a[i+(L<<4&112|K>>>8<<1&14|d[(c[263194]|0)+(L<<5&32512|K>>>10&254)|0]<<7|1)|0]|0;K=M&127;if(K<<24>>24==0|B){N=j;break}L=t+I|0;O=(L|0)<(I|0);P=(M<<24>>24<0?11:3)+h|0;M=K&255;K=P&255;Q=r;while(1){if(!O){R=L;do{S=(R<<1)+l|0;T=(ab(c[277223]|0,Q)|0)+S|0;if((R|0)>=(f|0)&(P|0)>(d[(c[277219]|0)+T|0]|0)&(R|0)<(g|0)){U=e[(c[277225]|0)+(M<<1)>>1]|0;V=(a[(c[277215]|0)+T|0]&32)==0;if(V){W=c[277228]|0;X=W;Y=W&-2082}else{W=e[(c[277213]|0)+(T<<1)>>1]|0;X=W;Y=W&63454}if(V){Z=c[277228]|0}else{Z=e[(c[277213]|0)+(T<<1)>>1]|0}b[(c[277218]|0)+(T<<1)>>1]=((Z^U)&2081|e[(c[277220]|0)+((U&2081&X)+((Y+(U&63454)|0)>>>1)<<1)>>1])&65535;U=(a[1108928]|0)==0;T=ab(c[277223]|0,Q)|0;if(U){_=b[(c[277213]|0)+(S+2+T<<1)>>1]&63454}else{_=0}V=(a[(c[277215]|0)+(T+S)|0]&32)==0;if(V){$=c[277228]|0}else{$=e[(c[277226]|0)+(M<<1)>>1]|0}if(U){aa=b[(c[277213]|0)+(S+2+T<<1)>>1]&2081}else{aa=0}if(V){ac=c[277228]|0}else{ac=e[(c[277226]|0)+(M<<1)>>1]|0}if(U){ad=e[(c[277213]|0)+(S+2+T<<1)>>1]|0}else{ad=0}if(V){ae=c[277228]|0}else{ae=e[(c[277226]|0)+(M<<1)>>1]|0}V=S+1|0;b[(c[277218]|0)+(T+V<<1)>>1]=((ae^ad)&2081|e[(c[277220]|0)+((ac&aa)+((($&-2082)+_|0)>>>1)<<1)>>1])&65535;T=(ab(c[277223]|0,Q)|0)+V|0;a[(c[277219]|0)+T|0]=K;T=(ab(c[277223]|0,Q)|0)+S|0;a[(c[277219]|0)+T|0]=K}R=R-1|0;}while((R|0)>=(I|0))}R=Q+1|0;if((R|0)<(w|0)){Q=R}else{N=j;break}}}else{N=J}}while(0);J=I+1|0;if((J|0)<(q|0)){x=x+E|0;A=A+F|0;z=N;I=J}else{break}}}else{if(!n){break}I=(r|0)>=(w|0);z=o;A=y;x=1;B=p;while(1){J=x-1&255;do{if(J<<24>>24==0){Q=z+D|0;K=Q>>8;M=A+C>>8;if((K|M)>>>0<1024){af=K<<1&14|M<<4&112|d[(c[263194]|0)+((M<<5&-256)+(Q>>10&-2))|0]<<7}else{if((a[1044415]|0)!=3){ag=j;break}af=K<<1&14|M<<4&112}M=a[i+(af|1)|0]|0;K=M&127;if(K<<24>>24==0|I){ag=j;break}Q=t+B|0;P=(Q|0)<(B|0);L=(M<<24>>24<0?11:3)+h|0;M=K&255;K=L&255;O=r;while(1){if(!P){R=Q;do{T=(R<<1)+l|0;S=(ab(c[277223]|0,O)|0)+T|0;if((R|0)>=(f|0)&(L|0)>(d[(c[277219]|0)+S|0]|0)&(R|0)<(g|0)){V=e[(c[277225]|0)+(M<<1)>>1]|0;U=(a[(c[277215]|0)+S|0]&32)==0;if(U){W=c[277228]|0;ah=W;ai=W&-2082}else{W=e[(c[277213]|0)+(S<<1)>>1]|0;ah=W;ai=W&63454}if(U){aj=c[277228]|0}else{aj=e[(c[277213]|0)+(S<<1)>>1]|0}b[(c[277218]|0)+(S<<1)>>1]=((aj^V)&2081|e[(c[277220]|0)+((V&2081&ah)+((ai+(V&63454)|0)>>>1)<<1)>>1])&65535;V=(a[1108928]|0)==0;S=ab(c[277223]|0,O)|0;if(V){ak=b[(c[277213]|0)+(T+2+S<<1)>>1]&63454}else{ak=0}U=(a[(c[277215]|0)+(S+T)|0]&32)==0;if(U){al=c[277228]|0}else{al=e[(c[277226]|0)+(M<<1)>>1]|0}if(V){am=b[(c[277213]|0)+(T+2+S<<1)>>1]&2081}else{am=0}if(U){an=c[277228]|0}else{an=e[(c[277226]|0)+(M<<1)>>1]|0}if(V){ao=e[(c[277213]|0)+(T+2+S<<1)>>1]|0}else{ao=0}if(U){ap=c[277228]|0}else{ap=e[(c[277226]|0)+(M<<1)>>1]|0}U=T+1|0;b[(c[277218]|0)+(S+U<<1)>>1]=((ap^ao)&2081|e[(c[277220]|0)+((an&am)+(((al&-2082)+ak|0)>>>1)<<1)>>1])&65535;S=(ab(c[277223]|0,O)|0)+U|0;a[(c[277219]|0)+S|0]=K;S=(ab(c[277223]|0,O)|0)+T|0;a[(c[277219]|0)+S|0]=K}R=R-1|0;}while((R|0)>=(B|0))}R=O+1|0;if((R|0)<(w|0)){O=R}else{ag=j;break}}}else{ag=J}}while(0);J=B+1|0;if((J|0)<(q|0)){z=z+E|0;A=A+F|0;x=ag;B=J}else{break}}}}while(0);C=w+u|0;D=(ab(c[277223]|0,w)|0)+l|0;y=c[277231]|0;if(C>>>0>y>>>0){break}else{r=0;m=w;l=D;u=C;v=v+(w<<4)|0;k=y}}return}function VX(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ac=0,ad=0;i=c[263194]|0;c[277226]=1106168;c[277225]=(a[1108928]|0)!=0?1393712:1106168;j=c[277230]|0;if((a[1044434]|0)==0){k=j;l=1;m=0}else{n=d[1044432]|0;o=((j-(d[1044433]|0)|0)>>>0)%(n>>>0)|0;k=j-o|0;l=n;m=o}if((a[1044435]|0)==0){p=f;q=g;r=1}else{o=d[1044432]|0;n=g-1+o|0;p=f-((f|0)%(o|0)|0)|0;q=n-((n|0)%(o|0)|0)|0;r=o}o=c[277231]|0;if(k>>>0>o>>>0){return}n=(p|0)<(q|0);j=r&255;s=q-1|0;t=r-1|0;r=m;m=l;l=ab(c[277223]|0,k)|0;u=k;v=1097960+(k<<4)|0;k=o;while(1){if((m+u|0)>>>0>k>>>0){w=k+1-u|0}else{w=m}o=e[v+12>>1]<<19>>19;x=e[v+8>>1]<<19;y=e[v+10>>1]<<19;z=u+1|0;A=(e[v+14>>1]<<19>>19)-(y>>19)|0;B=(A&8192|0)!=0?A|-1024:A&1023;A=b[v+2>>1]|0;C=((a[1044414]|0)==0?z:z^255)&255;z=(ab(C,A)|0)&-64;D=z+(x>>11)+((ab(B,A)|0)&-64)|0;A=b[v+6>>1]|0;z=(ab(A,C)|0)&-64;C=z+(y>>11)+((ab(B,A)|0)&-64)|0;A=b[v>>1]|0;if((a[1044413]|0)==0){B=b[v+4>>1]|0;E=A;F=B<<16>>16;G=p;H=B}else{B=b[v+4>>1]|0;E=-A|0;F=-(B<<16>>16)|0;G=s;H=B}B=o-(x>>19)|0;x=(B&8192|0)!=0?B|-1024:B&1023;B=ab(G,A)|0;o=B+((ab(A,x)|0)&-64)|0;A=H<<16>>16;B=ab(A,G)|0;y=((ab(A,x)|0)&-64)+B|0;do{if((a[1044415]|0)==0){if(!n){break}B=(r|0)>=(w|0);x=o;A=y;z=1;I=p;while(1){J=z-1&255;do{if(J<<24>>24==0){K=x+D|0;L=(A+C|0)>>>8;M=a[i+(L<<4&112|K>>>8<<1&14|d[(c[263194]|0)+(L<<5&32512|K>>>10&254)|0]<<7|1)|0]|0;K=M&127;if(K<<24>>24==0|B){N=j;break}L=t+I|0;O=(L|0)<(I|0);P=(M<<24>>24<0?11:3)+h|0;M=K&255;K=P&255;Q=r;while(1){if(!O){R=L;do{S=(R<<1)+l|0;T=(ab(c[277223]|0,Q)|0)+S|0;if((R|0)>=(f|0)&(P|0)>(d[(c[277219]|0)+T|0]|0)&(R|0)<(g|0)){U=e[(c[277225]|0)+(M<<1)>>1]|0;V=c[277228]|0;W=(((U&63454)+(V&-2082)|0)>>>1)+(V&2081&U)|0;if((a[1108928]|0)==0){X=W&65535}else{X=(e[(c[277220]|0)+(W<<1)>>1]|(U^V)&2081)&65535}b[(c[277218]|0)+(T<<1)>>1]=X;if((a[1108928]|0)==0){T=c[277223]|0;V=S+2+(ab(T,Q)|0)|0;U=e[(c[277213]|0)+(V<<1)>>1]|0;V=c[277228]|0;Y=T;Z=(((U&63454)+(V&128990)|0)>>>1)+(V&2081&U)|0}else{U=c[277228]|0;Y=c[277223]|0;Z=e[(c[277220]|0)+((U>>>1&2147482607)<<1)>>1]|U&2081}U=S+1|0;V=(ab(Y,Q)|0)+U|0;b[(c[277218]|0)+(V<<1)>>1]=Z&65535;V=(ab(c[277223]|0,Q)|0)+U|0;a[(c[277219]|0)+V|0]=K;V=(ab(c[277223]|0,Q)|0)+S|0;a[(c[277219]|0)+V|0]=K}R=R-1|0;}while((R|0)>=(I|0))}R=Q+1|0;if((R|0)<(w|0)){Q=R}else{N=j;break}}}else{N=J}}while(0);J=I+1|0;if((J|0)<(q|0)){x=x+E|0;A=A+F|0;z=N;I=J}else{break}}}else{if(!n){break}I=(r|0)>=(w|0);z=o;A=y;x=1;B=p;while(1){J=x-1&255;do{if(J<<24>>24==0){Q=z+D|0;K=Q>>8;M=A+C>>8;if((K|M)>>>0<1024){_=K<<1&14|M<<4&112|d[(c[263194]|0)+((M<<5&-256)+(Q>>10&-2))|0]<<7}else{if((a[1044415]|0)!=3){$=j;break}_=K<<1&14|M<<4&112}M=a[i+(_|1)|0]|0;K=M&127;if(K<<24>>24==0|I){$=j;break}Q=t+B|0;P=(Q|0)<(B|0);L=(M<<24>>24<0?11:3)+h|0;M=K&255;K=L&255;O=r;while(1){if(!P){R=Q;do{V=(R<<1)+l|0;S=(ab(c[277223]|0,O)|0)+V|0;if((R|0)>=(f|0)&(L|0)>(d[(c[277219]|0)+S|0]|0)&(R|0)<(g|0)){U=e[(c[277225]|0)+(M<<1)>>1]|0;T=c[277228]|0;W=(((U&63454)+(T&-2082)|0)>>>1)+(T&2081&U)|0;if((a[1108928]|0)==0){aa=W&65535}else{aa=(e[(c[277220]|0)+(W<<1)>>1]|(U^T)&2081)&65535}b[(c[277218]|0)+(S<<1)>>1]=aa;if((a[1108928]|0)==0){S=c[277223]|0;T=V+2+(ab(S,O)|0)|0;U=e[(c[277213]|0)+(T<<1)>>1]|0;T=c[277228]|0;ac=S;ad=(((U&63454)+(T&128990)|0)>>>1)+(T&2081&U)|0}else{U=c[277228]|0;ac=c[277223]|0;ad=e[(c[277220]|0)+((U>>>1&2147482607)<<1)>>1]|U&2081}U=V+1|0;T=(ab(ac,O)|0)+U|0;b[(c[277218]|0)+(T<<1)>>1]=ad&65535;T=(ab(c[277223]|0,O)|0)+U|0;a[(c[277219]|0)+T|0]=K;T=(ab(c[277223]|0,O)|0)+V|0;a[(c[277219]|0)+T|0]=K}R=R-1|0;}while((R|0)>=(B|0))}R=O+1|0;if((R|0)<(w|0)){O=R}else{$=j;break}}}else{$=J}}while(0);J=B+1|0;if((J|0)<(q|0)){z=z+E|0;A=A+F|0;x=$;B=J}else{break}}}}while(0);C=w+u|0;D=(ab(c[277223]|0,w)|0)+l|0;y=c[277231]|0;if(C>>>0>y>>>0){break}else{r=0;m=w;l=D;u=C;v=v+(w<<4)|0;k=y}}return}function VY(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0;i=c[263194]|0;c[277226]=1106168;c[277225]=(a[1108928]|0)!=0?1393712:1106168;j=c[277230]|0;if((a[1044434]|0)==0){k=j;l=1;m=0}else{n=d[1044432]|0;o=((j-(d[1044433]|0)|0)>>>0)%(n>>>0)|0;k=j-o|0;l=n;m=o}if((a[1044435]|0)==0){p=f;q=g;r=1}else{o=d[1044432]|0;n=g-1+o|0;p=f-((f|0)%(o|0)|0)|0;q=n-((n|0)%(o|0)|0)|0;r=o}o=c[277231]|0;if(k>>>0>o>>>0){return}n=(p|0)<(q|0);j=r&255;s=q-1|0;t=r-1|0;r=m;m=l;l=ab(c[277223]|0,k)|0;u=k;v=1097960+(k<<4)|0;k=o;while(1){if((m+u|0)>>>0>k>>>0){w=k+1-u|0}else{w=m}o=e[v+12>>1]<<19>>19;x=e[v+8>>1]<<19;y=e[v+10>>1]<<19;z=u+1|0;A=(e[v+14>>1]<<19>>19)-(y>>19)|0;B=(A&8192|0)!=0?A|-1024:A&1023;A=b[v+2>>1]|0;C=((a[1044414]|0)==0?z:z^255)&255;z=(ab(C,A)|0)&-64;D=z+(x>>11)+((ab(B,A)|0)&-64)|0;A=b[v+6>>1]|0;z=(ab(A,C)|0)&-64;C=z+(y>>11)+((ab(B,A)|0)&-64)|0;A=b[v>>1]|0;if((a[1044413]|0)==0){B=b[v+4>>1]|0;E=A;F=B<<16>>16;G=p;H=B}else{B=b[v+4>>1]|0;E=-A|0;F=-(B<<16>>16)|0;G=s;H=B}B=o-(x>>19)|0;x=(B&8192|0)!=0?B|-1024:B&1023;B=ab(G,A)|0;o=B+((ab(A,x)|0)&-64)|0;A=H<<16>>16;B=ab(A,G)|0;y=((ab(A,x)|0)&-64)+B|0;do{if((a[1044415]|0)==0){if(!n){break}B=(r|0)>=(w|0);x=o;A=y;z=1;I=p;while(1){J=z-1&255;do{if(J<<24>>24==0){K=x+D|0;L=(A+C|0)>>>8;M=a[i+(L<<4&112|K>>>8<<1&14|d[(c[263194]|0)+(L<<5&32512|K>>>10&254)|0]<<7|1)|0]|0;K=M&127;if(K<<24>>24==0|B){N=j;break}L=t+I|0;O=(L|0)<(I|0);P=(M<<24>>24<0?11:3)+h|0;M=K&255;K=P&255;Q=r;while(1){if(!O){R=L;do{S=(R<<1)+l|0;T=(ab(c[277223]|0,Q)|0)+S|0;if((R|0)>=(f|0)&(P|0)>(d[(c[277219]|0)+T|0]|0)&(R|0)<(g|0)){do{if((a[1108928]|0)==0){U=b[(c[277225]|0)+(M<<1)>>1]|0;V=U&65535;W=V&63454;if((a[(c[277215]|0)+T|0]&32)==0){X=c[277228]|0;Y=(e[(c[277220]|0)+((((X&-2082)+W|0)>>>1)+(V&2081&X)<<1)>>1]|(X^V)&2081)&65535;break}else{V=b[(c[277213]|0)+(T<<1)>>1]|0;Y=(((V&63454)+W|0)>>>1)+(V&U&2081)&65535;break}}else{U=e[(c[277225]|0)+(M<<1)>>1]|0;V=(a[(c[277215]|0)+T|0]&32)==0;if(V){W=c[277228]|0;Z=W;_=W&-2082}else{W=e[(c[277213]|0)+(T<<1)>>1]|0;Z=W;_=W&63454}if(V){$=c[277228]|0}else{$=e[(c[277213]|0)+(T<<1)>>1]|0}Y=(($^U)&2081|e[(c[277220]|0)+((U&2081&Z)+((_+(U&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(T<<1)>>1]=Y;U=(a[1108928]|0)==0;V=ab(c[277223]|0,Q)|0;W=V+S|0;X=(a[(c[277215]|0)+W|0]&32)==0;do{if(U){aa=c[277213]|0;ac=b[aa+(W+2<<1)>>1]&63454;if(X){ad=c[277228]|0;ae=e[aa+(S+2+V<<1)>>1]|0;af=((ae^ad)&2081|e[(c[277220]|0)+((ad&2081&ae)+(((ad&-2082)+ac|0)>>>1)<<1)>>1])&65535;break}else{ad=e[(c[277226]|0)+(M<<1)>>1]|0;af=(((ad&63454)+ac|0)>>>1)+(ad&2081&e[aa+(S+2+V<<1)>>1])&65535;break}}else{if(X){aa=c[277228]|0;ag=aa;ah=(c[277220]|0)+((aa>>>1&2147482607)<<1)|0}else{aa=e[(c[277226]|0)+(M<<1)>>1]|0;ag=aa;ah=(c[277220]|0)+((aa>>>1&31727)<<1)|0}af=(e[ah>>1]|ag&2081)&65535}}while(0);X=S+1|0;b[(c[277218]|0)+(V+X<<1)>>1]=af;W=(ab(c[277223]|0,Q)|0)+X|0;a[(c[277219]|0)+W|0]=K;W=(ab(c[277223]|0,Q)|0)+S|0;a[(c[277219]|0)+W|0]=K}R=R-1|0;}while((R|0)>=(I|0))}R=Q+1|0;if((R|0)<(w|0)){Q=R}else{N=j;break}}}else{N=J}}while(0);J=I+1|0;if((J|0)<(q|0)){x=x+E|0;A=A+F|0;z=N;I=J}else{break}}}else{if(!n){break}I=(r|0)>=(w|0);z=o;A=y;x=1;B=p;while(1){J=x-1&255;do{if(J<<24>>24==0){Q=z+D|0;K=Q>>8;M=A+C>>8;if((K|M)>>>0<1024){ai=K<<1&14|M<<4&112|d[(c[263194]|0)+((M<<5&-256)+(Q>>10&-2))|0]<<7}else{if((a[1044415]|0)!=3){aj=j;break}ai=K<<1&14|M<<4&112}M=a[i+(ai|1)|0]|0;K=M&127;if(K<<24>>24==0|I){aj=j;break}Q=t+B|0;P=(Q|0)<(B|0);L=(M<<24>>24<0?11:3)+h|0;M=K&255;K=L&255;O=r;while(1){if(!P){R=Q;do{W=(R<<1)+l|0;X=(ab(c[277223]|0,O)|0)+W|0;if((R|0)>=(f|0)&(L|0)>(d[(c[277219]|0)+X|0]|0)&(R|0)<(g|0)){do{if((a[1108928]|0)==0){U=b[(c[277225]|0)+(M<<1)>>1]|0;T=U&65535;aa=T&63454;if((a[(c[277215]|0)+X|0]&32)==0){ad=c[277228]|0;ak=(e[(c[277220]|0)+((((ad&-2082)+aa|0)>>>1)+(T&2081&ad)<<1)>>1]|(ad^T)&2081)&65535;break}else{T=b[(c[277213]|0)+(X<<1)>>1]|0;ak=(((T&63454)+aa|0)>>>1)+(T&U&2081)&65535;break}}else{U=e[(c[277225]|0)+(M<<1)>>1]|0;T=(a[(c[277215]|0)+X|0]&32)==0;if(T){aa=c[277228]|0;al=aa;am=aa&-2082}else{aa=e[(c[277213]|0)+(X<<1)>>1]|0;al=aa;am=aa&63454}if(T){an=c[277228]|0}else{an=e[(c[277213]|0)+(X<<1)>>1]|0}ak=((an^U)&2081|e[(c[277220]|0)+((U&2081&al)+((am+(U&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(X<<1)>>1]=ak;S=(a[1108928]|0)==0;V=ab(c[277223]|0,O)|0;U=V+W|0;T=(a[(c[277215]|0)+U|0]&32)==0;do{if(S){aa=c[277213]|0;ad=b[aa+(U+2<<1)>>1]&63454;if(T){ac=c[277228]|0;ae=e[aa+(W+2+V<<1)>>1]|0;ao=((ae^ac)&2081|e[(c[277220]|0)+((ac&2081&ae)+(((ac&-2082)+ad|0)>>>1)<<1)>>1])&65535;break}else{ac=e[(c[277226]|0)+(M<<1)>>1]|0;ao=(((ac&63454)+ad|0)>>>1)+(ac&2081&e[aa+(W+2+V<<1)>>1])&65535;break}}else{if(T){aa=c[277228]|0;ap=aa;aq=(c[277220]|0)+((aa>>>1&2147482607)<<1)|0}else{aa=e[(c[277226]|0)+(M<<1)>>1]|0;ap=aa;aq=(c[277220]|0)+((aa>>>1&31727)<<1)|0}ao=(e[aq>>1]|ap&2081)&65535}}while(0);T=W+1|0;b[(c[277218]|0)+(V+T<<1)>>1]=ao;U=(ab(c[277223]|0,O)|0)+T|0;a[(c[277219]|0)+U|0]=K;U=(ab(c[277223]|0,O)|0)+W|0;a[(c[277219]|0)+U|0]=K}R=R-1|0;}while((R|0)>=(B|0))}R=O+1|0;if((R|0)<(w|0)){O=R}else{aj=j;break}}}else{aj=J}}while(0);J=B+1|0;if((J|0)<(q|0)){z=z+E|0;A=A+F|0;x=aj;B=J}else{break}}}}while(0);C=w+u|0;D=(ab(c[277223]|0,w)|0)+l|0;y=c[277231]|0;if(C>>>0>y>>>0){break}else{r=0;m=w;l=D;u=C;v=v+(w<<4)|0;k=y}}return}function VZ(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0;i=c[263194]|0;c[277226]=1106168;c[277225]=(a[1108928]|0)!=0?1393712:1106168;j=c[277230]|0;if((a[1044434]|0)==0){k=j;l=1;m=0}else{n=d[1044432]|0;o=((j-(d[1044433]|0)|0)>>>0)%(n>>>0)|0;k=j-o|0;l=n;m=o}if((a[1044435]|0)==0){p=f;q=g;r=1}else{o=d[1044432]|0;n=g-1+o|0;p=f-((f|0)%(o|0)|0)|0;q=n-((n|0)%(o|0)|0)|0;r=o}o=c[277231]|0;if(k>>>0>o>>>0){return}n=(p|0)<(q|0);j=r&255;s=q-1|0;t=r-1|0;r=m;m=l;l=ab(c[277223]|0,k)|0;u=k;v=1097960+(k<<4)|0;k=o;while(1){if((m+u|0)>>>0>k>>>0){w=k+1-u|0}else{w=m}o=e[v+12>>1]<<19>>19;x=e[v+8>>1]<<19;y=e[v+10>>1]<<19;z=u+1|0;A=(e[v+14>>1]<<19>>19)-(y>>19)|0;B=(A&8192|0)!=0?A|-1024:A&1023;A=b[v+2>>1]|0;C=((a[1044414]|0)==0?z:z^255)&255;z=(ab(C,A)|0)&-64;D=z+(x>>11)+((ab(B,A)|0)&-64)|0;A=b[v+6>>1]|0;z=(ab(A,C)|0)&-64;C=z+(y>>11)+((ab(B,A)|0)&-64)|0;A=b[v>>1]|0;if((a[1044413]|0)==0){B=b[v+4>>1]|0;E=A;F=B<<16>>16;G=p;H=B}else{B=b[v+4>>1]|0;E=-A|0;F=-(B<<16>>16)|0;G=s;H=B}B=o-(x>>19)|0;x=(B&8192|0)!=0?B|-1024:B&1023;B=ab(G,A)|0;o=B+((ab(A,x)|0)&-64)|0;A=H<<16>>16;B=ab(A,G)|0;y=((ab(A,x)|0)&-64)+B|0;do{if((a[1044415]|0)==0){if(!n){break}B=(r|0)>=(w|0);x=o;A=y;z=1;I=p;while(1){J=z-1&255;do{if(J<<24>>24==0){K=x+D|0;L=(A+C|0)>>>8;M=a[i+(L<<4&112|K>>>8<<1&14|d[(c[263194]|0)+(L<<5&32512|K>>>10&254)|0]<<7|1)|0]|0;K=M&127;if(K<<24>>24==0|B){N=j;break}L=t+I|0;O=(L|0)<(I|0);P=(M<<24>>24<0?11:3)+h|0;M=K&255;K=P&255;Q=r;while(1){if(!O){R=L;do{S=(R<<1)+l|0;T=(ab(c[277223]|0,Q)|0)+S|0;if((R|0)>=(f|0)&(P|0)>(d[(c[277219]|0)+T|0]|0)&(R|0)<(g|0)){U=b[(c[277225]|0)+(M<<1)>>1]|0;if((a[(c[277215]|0)+T|0]&32)==0){V=c[277228]&65535}else{V=b[(c[277213]|0)+(T<<1)>>1]|0}W=U&-2048;X=V&-2048;Y=(W&65535)>(X&65535)?W-X&65535:0;X=U&2016;W=V&2016;if((X&65535)>(W&65535)){Z=(X-W&65535)+Y&65535}else{Z=Y}Y=U&31;U=V&31;if((Y&65535)>(U&65535)){_=(Y-U&65535)+Z&65535}else{_=Z}b[(c[277218]|0)+(T<<1)>>1]=_;T=(a[1108928]|0)==0;U=ab(c[277223]|0,Q)|0;if(T){$=b[(c[277213]|0)+(S+2+U<<1)>>1]|0}else{$=0}if((a[(c[277215]|0)+(U+S)|0]&32)==0){aa=c[277228]&65535}else{aa=b[(c[277226]|0)+(M<<1)>>1]|0}T=$&-2048;Y=aa&-2048;W=(T&65535)>(Y&65535)?T-Y&65535:0;Y=$&2016;T=aa&2016;if((Y&65535)>(T&65535)){ac=(Y-T&65535)+W&65535}else{ac=W}W=$&31;T=aa&31;if((W&65535)>(T&65535)){ad=(W-T&65535)+ac&65535}else{ad=ac}T=S+1|0;b[(c[277218]|0)+(U+T<<1)>>1]=ad;U=(ab(c[277223]|0,Q)|0)+T|0;a[(c[277219]|0)+U|0]=K;U=(ab(c[277223]|0,Q)|0)+S|0;a[(c[277219]|0)+U|0]=K}R=R-1|0;}while((R|0)>=(I|0))}R=Q+1|0;if((R|0)<(w|0)){Q=R}else{N=j;break}}}else{N=J}}while(0);J=I+1|0;if((J|0)<(q|0)){x=x+E|0;A=A+F|0;z=N;I=J}else{break}}}else{if(!n){break}I=(r|0)>=(w|0);z=o;A=y;x=1;B=p;while(1){J=x-1&255;do{if(J<<24>>24==0){Q=z+D|0;K=Q>>8;M=A+C>>8;if((K|M)>>>0<1024){ae=K<<1&14|M<<4&112|d[(c[263194]|0)+((M<<5&-256)+(Q>>10&-2))|0]<<7}else{if((a[1044415]|0)!=3){af=j;break}ae=K<<1&14|M<<4&112}M=a[i+(ae|1)|0]|0;K=M&127;if(K<<24>>24==0|I){af=j;break}Q=t+B|0;P=(Q|0)<(B|0);L=(M<<24>>24<0?11:3)+h|0;M=K&255;K=L&255;O=r;while(1){if(!P){R=Q;do{U=(R<<1)+l|0;S=(ab(c[277223]|0,O)|0)+U|0;if((R|0)>=(f|0)&(L|0)>(d[(c[277219]|0)+S|0]|0)&(R|0)<(g|0)){T=b[(c[277225]|0)+(M<<1)>>1]|0;if((a[(c[277215]|0)+S|0]&32)==0){ag=c[277228]&65535}else{ag=b[(c[277213]|0)+(S<<1)>>1]|0}W=T&-2048;Y=ag&-2048;X=(W&65535)>(Y&65535)?W-Y&65535:0;Y=T&2016;W=ag&2016;if((Y&65535)>(W&65535)){ah=(Y-W&65535)+X&65535}else{ah=X}X=T&31;T=ag&31;if((X&65535)>(T&65535)){ai=(X-T&65535)+ah&65535}else{ai=ah}b[(c[277218]|0)+(S<<1)>>1]=ai;S=(a[1108928]|0)==0;T=ab(c[277223]|0,O)|0;if(S){aj=b[(c[277213]|0)+(U+2+T<<1)>>1]|0}else{aj=0}if((a[(c[277215]|0)+(T+U)|0]&32)==0){ak=c[277228]&65535}else{ak=b[(c[277226]|0)+(M<<1)>>1]|0}S=aj&-2048;X=ak&-2048;W=(S&65535)>(X&65535)?S-X&65535:0;X=aj&2016;S=ak&2016;if((X&65535)>(S&65535)){al=(X-S&65535)+W&65535}else{al=W}W=aj&31;S=ak&31;if((W&65535)>(S&65535)){am=(W-S&65535)+al&65535}else{am=al}S=U+1|0;b[(c[277218]|0)+(T+S<<1)>>1]=am;T=(ab(c[277223]|0,O)|0)+S|0;a[(c[277219]|0)+T|0]=K;T=(ab(c[277223]|0,O)|0)+U|0;a[(c[277219]|0)+T|0]=K}R=R-1|0;}while((R|0)>=(B|0))}R=O+1|0;if((R|0)<(w|0)){O=R}else{af=j;break}}}else{af=J}}while(0);J=B+1|0;if((J|0)<(q|0)){z=z+E|0;A=A+F|0;x=af;B=J}else{break}}}}while(0);C=w+u|0;D=(ab(c[277223]|0,w)|0)+l|0;y=c[277231]|0;if(C>>>0>y>>>0){break}else{r=0;m=w;l=D;u=C;v=v+(w<<4)|0;k=y}}return}function V_(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0;i=c[263194]|0;c[277226]=1106168;c[277225]=(a[1108928]|0)!=0?1393712:1106168;j=c[277230]|0;if((a[1044434]|0)==0){k=j;l=1;m=0}else{n=d[1044432]|0;o=((j-(d[1044433]|0)|0)>>>0)%(n>>>0)|0;k=j-o|0;l=n;m=o}if((a[1044435]|0)==0){p=f;q=g;r=1}else{o=d[1044432]|0;n=g-1+o|0;p=f-((f|0)%(o|0)|0)|0;q=n-((n|0)%(o|0)|0)|0;r=o}o=c[277231]|0;if(k>>>0>o>>>0){return}n=(p|0)<(q|0);j=r&255;s=q-1|0;t=r-1|0;r=m;m=l;l=ab(c[277223]|0,k)|0;u=k;v=1097960+(k<<4)|0;k=o;while(1){if((m+u|0)>>>0>k>>>0){w=k+1-u|0}else{w=m}o=e[v+12>>1]<<19>>19;x=e[v+8>>1]<<19;y=e[v+10>>1]<<19;z=u+1|0;A=(e[v+14>>1]<<19>>19)-(y>>19)|0;B=(A&8192|0)!=0?A|-1024:A&1023;A=b[v+2>>1]|0;C=((a[1044414]|0)==0?z:z^255)&255;z=(ab(C,A)|0)&-64;D=z+(x>>11)+((ab(B,A)|0)&-64)|0;A=b[v+6>>1]|0;z=(ab(A,C)|0)&-64;C=z+(y>>11)+((ab(B,A)|0)&-64)|0;A=b[v>>1]|0;if((a[1044413]|0)==0){B=b[v+4>>1]|0;E=A;F=B<<16>>16;G=p;H=B}else{B=b[v+4>>1]|0;E=-A|0;F=-(B<<16>>16)|0;G=s;H=B}B=o-(x>>19)|0;x=(B&8192|0)!=0?B|-1024:B&1023;B=ab(G,A)|0;o=B+((ab(A,x)|0)&-64)|0;A=H<<16>>16;B=ab(A,G)|0;y=((ab(A,x)|0)&-64)+B|0;do{if((a[1044415]|0)==0){if(!n){break}B=(r|0)>=(w|0);x=o;A=y;z=1;I=p;while(1){J=z-1&255;do{if(J<<24>>24==0){K=x+D|0;L=(A+C|0)>>>8;M=a[i+(L<<4&112|K>>>8<<1&14|d[(c[263194]|0)+(L<<5&32512|K>>>10&254)|0]<<7|1)|0]|0;K=M&127;if(K<<24>>24==0|B){N=j;break}L=t+I|0;O=(L|0)<(I|0);P=(M<<24>>24<0?11:3)+h|0;M=K&255;K=P&255;Q=r;while(1){if(!O){R=L;do{S=(R<<1)+l|0;T=(ab(c[277223]|0,Q)|0)+S|0;if((R|0)>=(f|0)&(P|0)>(d[(c[277219]|0)+T|0]|0)&(R|0)<(g|0)){U=b[(c[277225]|0)+(M<<1)>>1]|0;do{if((a[1108928]|0)==0){V=b[(c[277221]|0)+(((U&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{W=c[277228]&65535;X=U&-2048;Y=W&-2048;Z=(X&65535)>(Y&65535)?X-Y&65535:0;Y=U&2016;X=W&2016;if((Y&65535)>(X&65535)){_=(Y-X&65535)+Z&65535}else{_=Z}Z=U&31;X=W&31;if((Z&65535)<=(X&65535)){V=_;break}V=(Z-X&65535)+_&65535}}while(0);b[(c[277218]|0)+(T<<1)>>1]=V;U=(a[1108928]|0)==0;X=ab(c[277223]|0,Q)|0;if(U){$=b[(c[277221]|0)+(((e[(c[277213]|0)+(S+2+X<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{$=0}U=S+1|0;b[(c[277218]|0)+(X+U<<1)>>1]=$;X=(ab(c[277223]|0,Q)|0)+U|0;a[(c[277219]|0)+X|0]=K;X=(ab(c[277223]|0,Q)|0)+S|0;a[(c[277219]|0)+X|0]=K}R=R-1|0;}while((R|0)>=(I|0))}R=Q+1|0;if((R|0)<(w|0)){Q=R}else{N=j;break}}}else{N=J}}while(0);J=I+1|0;if((J|0)<(q|0)){x=x+E|0;A=A+F|0;z=N;I=J}else{break}}}else{if(!n){break}I=(r|0)>=(w|0);z=o;A=y;x=1;B=p;while(1){J=x-1&255;do{if(J<<24>>24==0){Q=z+D|0;K=Q>>8;M=A+C>>8;if((K|M)>>>0<1024){aa=K<<1&14|M<<4&112|d[(c[263194]|0)+((M<<5&-256)+(Q>>10&-2))|0]<<7}else{if((a[1044415]|0)!=3){ac=j;break}aa=K<<1&14|M<<4&112}M=a[i+(aa|1)|0]|0;K=M&127;if(K<<24>>24==0|I){ac=j;break}Q=t+B|0;P=(Q|0)<(B|0);L=(M<<24>>24<0?11:3)+h|0;M=K&255;K=L&255;O=r;while(1){if(!P){R=Q;do{X=(R<<1)+l|0;U=(ab(c[277223]|0,O)|0)+X|0;if((R|0)>=(f|0)&(L|0)>(d[(c[277219]|0)+U|0]|0)&(R|0)<(g|0)){Z=b[(c[277225]|0)+(M<<1)>>1]|0;do{if((a[1108928]|0)==0){ad=b[(c[277221]|0)+(((Z&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{W=c[277228]&65535;Y=Z&-2048;ae=W&-2048;af=(Y&65535)>(ae&65535)?Y-ae&65535:0;ae=Z&2016;Y=W&2016;if((ae&65535)>(Y&65535)){ag=(ae-Y&65535)+af&65535}else{ag=af}af=Z&31;Y=W&31;if((af&65535)<=(Y&65535)){ad=ag;break}ad=(af-Y&65535)+ag&65535}}while(0);b[(c[277218]|0)+(U<<1)>>1]=ad;Z=(a[1108928]|0)==0;S=ab(c[277223]|0,O)|0;if(Z){ah=b[(c[277221]|0)+(((e[(c[277213]|0)+(X+2+S<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{ah=0}Z=X+1|0;b[(c[277218]|0)+(S+Z<<1)>>1]=ah;S=(ab(c[277223]|0,O)|0)+Z|0;a[(c[277219]|0)+S|0]=K;S=(ab(c[277223]|0,O)|0)+X|0;a[(c[277219]|0)+S|0]=K}R=R-1|0;}while((R|0)>=(B|0))}R=O+1|0;if((R|0)<(w|0)){O=R}else{ac=j;break}}}else{ac=J}}while(0);J=B+1|0;if((J|0)<(q|0)){z=z+E|0;A=A+F|0;x=ac;B=J}else{break}}}}while(0);C=w+u|0;D=(ab(c[277223]|0,w)|0)+l|0;y=c[277231]|0;if(C>>>0>y>>>0){break}else{r=0;m=w;l=D;u=C;v=v+(w<<4)|0;k=y}}return}function V$(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0;i=c[263194]|0;c[277226]=1106168;c[277225]=(a[1108928]|0)!=0?1393712:1106168;j=c[277230]|0;if((a[1044434]|0)==0){k=j;l=1;m=0}else{n=d[1044432]|0;o=((j-(d[1044433]|0)|0)>>>0)%(n>>>0)|0;k=j-o|0;l=n;m=o}if((a[1044435]|0)==0){p=f;q=g;r=1}else{o=d[1044432]|0;n=g-1+o|0;p=f-((f|0)%(o|0)|0)|0;q=n-((n|0)%(o|0)|0)|0;r=o}o=c[277231]|0;if(k>>>0>o>>>0){return}n=(p|0)<(q|0);j=r&255;s=q-1|0;t=r-1|0;r=m;m=l;l=ab(c[277223]|0,k)|0;u=k;v=1097960+(k<<4)|0;k=o;while(1){if((m+u|0)>>>0>k>>>0){w=k+1-u|0}else{w=m}o=e[v+12>>1]<<19>>19;x=e[v+8>>1]<<19;y=e[v+10>>1]<<19;z=u+1|0;A=(e[v+14>>1]<<19>>19)-(y>>19)|0;B=(A&8192|0)!=0?A|-1024:A&1023;A=b[v+2>>1]|0;C=((a[1044414]|0)==0?z:z^255)&255;z=(ab(C,A)|0)&-64;D=z+(x>>11)+((ab(B,A)|0)&-64)|0;A=b[v+6>>1]|0;z=(ab(A,C)|0)&-64;C=z+(y>>11)+((ab(B,A)|0)&-64)|0;A=b[v>>1]|0;if((a[1044413]|0)==0){B=b[v+4>>1]|0;E=A;F=B<<16>>16;G=p;H=B}else{B=b[v+4>>1]|0;E=-A|0;F=-(B<<16>>16)|0;G=s;H=B}B=o-(x>>19)|0;x=(B&8192|0)!=0?B|-1024:B&1023;B=ab(G,A)|0;o=B+((ab(A,x)|0)&-64)|0;A=H<<16>>16;B=ab(A,G)|0;y=((ab(A,x)|0)&-64)+B|0;do{if((a[1044415]|0)==0){if(!n){break}B=(r|0)>=(w|0);x=o;A=y;z=1;I=p;while(1){J=z-1&255;do{if(J<<24>>24==0){K=x+D|0;L=(A+C|0)>>>8;M=a[i+(L<<4&112|K>>>8<<1&14|d[(c[263194]|0)+(L<<5&32512|K>>>10&254)|0]<<7|1)|0]|0;K=M&127;if(K<<24>>24==0|B){N=j;break}L=t+I|0;O=(L|0)<(I|0);P=(M<<24>>24<0?11:3)+h|0;M=K&255;K=P&255;Q=r;while(1){if(!O){R=L;do{S=(R<<1)+l|0;T=(ab(c[277223]|0,Q)|0)+S|0;if((R|0)>=(f|0)&(P|0)>(d[(c[277219]|0)+T|0]|0)&(R|0)<(g|0)){do{if((a[1108928]|0)==0){U=b[(c[277225]|0)+(M<<1)>>1]|0;if((a[(c[277215]|0)+T|0]&32)!=0){V=b[(c[277221]|0)+((U&65535|67616)-(b[(c[277213]|0)+(T<<1)>>1]&63454)>>1<<1)>>1]|0;break}W=c[277228]&65535;X=U&-2048;Y=W&-2048;Z=(X&65535)>(Y&65535)?X-Y&65535:0;Y=U&2016;X=W&2016;if((Y&65535)>(X&65535)){_=(Y-X&65535)+Z&65535}else{_=Z}Z=U&31;U=W&31;if((Z&65535)<=(U&65535)){V=_;break}V=(Z-U&65535)+_&65535}else{U=b[(c[277225]|0)+(M<<1)>>1]|0;if((a[(c[277215]|0)+T|0]&32)==0){$=c[277228]&65535}else{$=b[(c[277213]|0)+(T<<1)>>1]|0}Z=U&-2048;W=$&-2048;X=(Z&65535)>(W&65535)?Z-W&65535:0;W=U&2016;Z=$&2016;if((W&65535)>(Z&65535)){aa=(W-Z&65535)+X&65535}else{aa=X}X=U&31;U=$&31;if((X&65535)<=(U&65535)){V=aa;break}V=(X-U&65535)+aa&65535}}while(0);b[(c[277218]|0)+(T<<1)>>1]=V;U=(a[1108928]|0)==0;X=ab(c[277223]|0,Q)|0;Z=X+S|0;do{if(U){W=b[(c[277213]|0)+(Z+2<<1)>>1]|0;if((a[(c[277215]|0)+Z|0]&32)!=0){ac=b[(c[277221]|0)+((W&65535|67616)-(b[(c[277226]|0)+(M<<1)>>1]&63454)>>1<<1)>>1]|0;break}Y=c[277228]&65535;ad=W&-2048;ae=Y&-2048;af=(ad&65535)>(ae&65535)?ad-ae&65535:0;ae=W&2016;ad=Y&2016;if((ae&65535)>(ad&65535)){ag=(ae-ad&65535)+af&65535}else{ag=af}af=W&31;W=Y&31;if((af&65535)<=(W&65535)){ac=ag;break}ac=(af-W&65535)+ag&65535}else{ac=0}}while(0);Z=S+1|0;b[(c[277218]|0)+(X+Z<<1)>>1]=ac;U=(ab(c[277223]|0,Q)|0)+Z|0;a[(c[277219]|0)+U|0]=K;U=(ab(c[277223]|0,Q)|0)+S|0;a[(c[277219]|0)+U|0]=K}R=R-1|0;}while((R|0)>=(I|0))}R=Q+1|0;if((R|0)<(w|0)){Q=R}else{N=j;break}}}else{N=J}}while(0);J=I+1|0;if((J|0)<(q|0)){x=x+E|0;A=A+F|0;z=N;I=J}else{break}}}else{if(!n){break}I=(r|0)>=(w|0);z=o;A=y;x=1;B=p;while(1){J=x-1&255;do{if(J<<24>>24==0){Q=z+D|0;K=Q>>8;M=A+C>>8;if((K|M)>>>0<1024){ah=K<<1&14|M<<4&112|d[(c[263194]|0)+((M<<5&-256)+(Q>>10&-2))|0]<<7}else{if((a[1044415]|0)!=3){ai=j;break}ah=K<<1&14|M<<4&112}M=a[i+(ah|1)|0]|0;K=M&127;if(K<<24>>24==0|I){ai=j;break}Q=t+B|0;P=(Q|0)<(B|0);L=(M<<24>>24<0?11:3)+h|0;M=K&255;K=L&255;O=r;while(1){if(!P){R=Q;do{U=(R<<1)+l|0;Z=(ab(c[277223]|0,O)|0)+U|0;if((R|0)>=(f|0)&(L|0)>(d[(c[277219]|0)+Z|0]|0)&(R|0)<(g|0)){do{if((a[1108928]|0)==0){T=b[(c[277225]|0)+(M<<1)>>1]|0;if((a[(c[277215]|0)+Z|0]&32)!=0){aj=b[(c[277221]|0)+((T&65535|67616)-(b[(c[277213]|0)+(Z<<1)>>1]&63454)>>1<<1)>>1]|0;break}W=c[277228]&65535;af=T&-2048;Y=W&-2048;ad=(af&65535)>(Y&65535)?af-Y&65535:0;Y=T&2016;af=W&2016;if((Y&65535)>(af&65535)){ak=(Y-af&65535)+ad&65535}else{ak=ad}ad=T&31;T=W&31;if((ad&65535)<=(T&65535)){aj=ak;break}aj=(ad-T&65535)+ak&65535}else{T=b[(c[277225]|0)+(M<<1)>>1]|0;if((a[(c[277215]|0)+Z|0]&32)==0){al=c[277228]&65535}else{al=b[(c[277213]|0)+(Z<<1)>>1]|0}ad=T&-2048;W=al&-2048;af=(ad&65535)>(W&65535)?ad-W&65535:0;W=T&2016;ad=al&2016;if((W&65535)>(ad&65535)){am=(W-ad&65535)+af&65535}else{am=af}af=T&31;T=al&31;if((af&65535)<=(T&65535)){aj=am;break}aj=(af-T&65535)+am&65535}}while(0);b[(c[277218]|0)+(Z<<1)>>1]=aj;S=(a[1108928]|0)==0;X=ab(c[277223]|0,O)|0;T=X+U|0;do{if(S){af=b[(c[277213]|0)+(T+2<<1)>>1]|0;if((a[(c[277215]|0)+T|0]&32)!=0){an=b[(c[277221]|0)+((af&65535|67616)-(b[(c[277226]|0)+(M<<1)>>1]&63454)>>1<<1)>>1]|0;break}ad=c[277228]&65535;W=af&-2048;Y=ad&-2048;ae=(W&65535)>(Y&65535)?W-Y&65535:0;Y=af&2016;W=ad&2016;if((Y&65535)>(W&65535)){ao=(Y-W&65535)+ae&65535}else{ao=ae}ae=af&31;af=ad&31;if((ae&65535)<=(af&65535)){an=ao;break}an=(ae-af&65535)+ao&65535}else{an=0}}while(0);T=U+1|0;b[(c[277218]|0)+(X+T<<1)>>1]=an;S=(ab(c[277223]|0,O)|0)+T|0;a[(c[277219]|0)+S|0]=K;S=(ab(c[277223]|0,O)|0)+U|0;a[(c[277219]|0)+S|0]=K}R=R-1|0;}while((R|0)>=(B|0))}R=O+1|0;if((R|0)<(w|0)){O=R}else{ai=j;break}}}else{ai=J}}while(0);J=B+1|0;if((J|0)<(q|0)){z=z+E|0;A=A+F|0;x=ai;B=J}else{break}}}}while(0);C=w+u|0;D=(ab(c[277223]|0,w)|0)+l|0;y=c[277231]|0;if(C>>>0>y>>>0){break}else{r=0;m=w;l=D;u=C;v=v+(w<<4)|0;k=y}}return}function V0(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;i=c[263194]|0;do{if((a[(c[263195]|0)+8496|0]&1)==0){j=1106168}else{if((a[1106089]|0)==0){j=1125528;break}k=d[1044485]|0;c[276541]=7080+(k<<5);l=0;do{m=l<<1&2;n=l&2;o=l&4;p=0;do{b[1125528+(l<<9)+(p<<1)>>1]=d[(p>>>1&28|n)+(7080+(k<<5))|0]<<6|d[(p<<2&28|m)+(7080+(k<<5))|0]<<11|d[(p>>>3&24|o)+(7080+(k<<5))|0];p=p+1|0;}while(p>>>0<256);l=l+1|0;}while(l>>>0<8);a[1106089]=0;j=1125528}}while(0);c[277226]=j;c[277225]=(a[1108928]|0)!=0?1393712:j;j=c[277230]|0;if(j>>>0>(c[277231]|0)>>>0){return}l=f>>>0<g>>>0;k=h+7|0;h=k&255;p=g-1|0;o=ab(c[277223]|0,j)|0;m=j;n=1097960+(j<<4)|0;while(1){j=e[n+12>>1]<<19>>19;q=e[n+8>>1]<<19;r=e[n+10>>1]<<19;s=m+1|0;t=(e[n+14>>1]<<19>>19)-(r>>19)|0;u=(t&8192|0)!=0?t|-1024:t&1023;t=b[n+2>>1]|0;v=((a[1044414]|0)==0?s:s^255)&255;w=(ab(v,t)|0)&-64;x=w+(q>>11)+((ab(u,t)|0)&-64)|0;t=b[n+6>>1]|0;w=(ab(t,v)|0)&-64;v=w+(r>>11)+((ab(u,t)|0)&-64)|0;t=b[n>>1]|0;if((a[1044413]|0)==0){u=b[n+4>>1]|0;y=t;z=u<<16>>16;A=f;B=u}else{u=b[n+4>>1]|0;y=-t|0;z=-(u<<16>>16)|0;A=p;B=u}u=j-(q>>19)|0;q=(u&8192|0)!=0?u|-1024:u&1023;u=ab(A,t)|0;j=u+((ab(t,q)|0)&-64)|0;t=B<<16>>16;u=ab(t,A)|0;r=((ab(t,q)|0)&-64)+u|0;L2855:do{if((a[1044415]|0)==0){if(l){C=r;D=j;E=f}else{break}while(1){u=D+x|0;q=(C+v|0)>>>8;t=(E<<1)+o|0;do{if((k|0)>(d[(c[277219]|0)+t|0]|0)){w=a[i+(u>>>8<<1&14|q<<4&112|d[(c[263194]|0)+(q<<5&32512|u>>>10&254)|0]<<7|1)|0]|0;if(w<<24>>24==0){break}b[(c[277218]|0)+(t<<1)>>1]=b[(c[277225]|0)+((w&255)<<1)>>1]|0;if((a[1108928]|0)==0){F=b[(c[277213]|0)+(t+2<<1)>>1]|0}else{F=0}w=t+1|0;b[(c[277218]|0)+(w<<1)>>1]=F;a[(c[277219]|0)+w|0]=h;a[(c[277219]|0)+t|0]=h}}while(0);t=E+1|0;if(t>>>0>=g>>>0){break L2855}C=C+z|0;D=D+y|0;E=t}}else{if(l){G=r;H=j;I=f}else{break}while(1){t=H+x|0;u=t>>8;q=G+v>>8;do{if((q|u)>>>0<1024){J=q<<4&112|u<<1&14|d[(c[263194]|0)+((q<<5&-256)+(t>>10&-2))|0]<<7;K=2079}else{if((a[1044415]|0)!=3){break}J=q<<4&112|u<<1&14;K=2079}}while(0);do{if((K|0)==2079){K=0;u=(I<<1)+o|0;if((k|0)<=(d[(c[277219]|0)+u|0]|0)){break}q=a[i+(J|1)|0]|0;if(q<<24>>24==0){break}b[(c[277218]|0)+(u<<1)>>1]=b[(c[277225]|0)+((q&255)<<1)>>1]|0;if((a[1108928]|0)==0){L=b[(c[277213]|0)+(u+2<<1)>>1]|0}else{L=0}q=u+1|0;b[(c[277218]|0)+(q<<1)>>1]=L;a[(c[277219]|0)+q|0]=h;a[(c[277219]|0)+u|0]=h}}while(0);u=I+1|0;if(u>>>0<g>>>0){G=G+z|0;H=H+y|0;I=u}else{break}}}}while(0);if(s>>>0>(c[277231]|0)>>>0){break}o=(c[277223]|0)+o|0;m=s;n=n+16|0}return}function V1(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ac=0,ad=0;i=c[263194]|0;do{if((a[(c[263195]|0)+8496|0]&1)==0){j=1106168}else{if((a[1106089]|0)==0){j=1125528;break}k=d[1044485]|0;c[276541]=7080+(k<<5);l=0;do{m=l<<1&2;n=l&2;o=l&4;p=0;do{b[1125528+(l<<9)+(p<<1)>>1]=d[(p>>>1&28|n)+(7080+(k<<5))|0]<<6|d[(p<<2&28|m)+(7080+(k<<5))|0]<<11|d[(p>>>3&24|o)+(7080+(k<<5))|0];p=p+1|0;}while(p>>>0<256);l=l+1|0;}while(l>>>0<8);a[1106089]=0;j=1125528}}while(0);c[277226]=j;c[277225]=(a[1108928]|0)!=0?1393712:j;j=c[277230]|0;if(j>>>0>(c[277231]|0)>>>0){return}l=f>>>0<g>>>0;k=h+7|0;h=k&255;p=g-1|0;o=ab(c[277223]|0,j)|0;m=j;n=1097960+(j<<4)|0;while(1){j=e[n+12>>1]<<19>>19;q=e[n+8>>1]<<19;r=e[n+10>>1]<<19;s=m+1|0;t=(e[n+14>>1]<<19>>19)-(r>>19)|0;u=(t&8192|0)!=0?t|-1024:t&1023;t=b[n+2>>1]|0;v=((a[1044414]|0)==0?s:s^255)&255;w=(ab(v,t)|0)&-64;x=w+(q>>11)+((ab(u,t)|0)&-64)|0;t=b[n+6>>1]|0;w=(ab(t,v)|0)&-64;v=w+(r>>11)+((ab(u,t)|0)&-64)|0;t=b[n>>1]|0;if((a[1044413]|0)==0){u=b[n+4>>1]|0;y=t;z=u<<16>>16;A=f;B=u}else{u=b[n+4>>1]|0;y=-t|0;z=-(u<<16>>16)|0;A=p;B=u}u=j-(q>>19)|0;q=(u&8192|0)!=0?u|-1024:u&1023;u=ab(A,t)|0;j=u+((ab(t,q)|0)&-64)|0;t=B<<16>>16;u=ab(t,A)|0;r=((ab(t,q)|0)&-64)+u|0;L2905:do{if((a[1044415]|0)==0){if(l){C=r;D=j;E=f}else{break}while(1){u=D+x|0;q=(C+v|0)>>>8;t=(E<<1)+o|0;do{if((k|0)>(d[(c[277219]|0)+t|0]|0)){w=a[i+(u>>>8<<1&14|q<<4&112|d[(c[263194]|0)+(q<<5&32512|u>>>10&254)|0]<<7|1)|0]|0;F=w&255;if(w<<24>>24==0){break}w=e[(c[277225]|0)+(F<<1)>>1]|0;G=(a[(c[277215]|0)+t|0]&32)==0;if(G){H=c[277228]|0;I=H;J=H&-2082}else{H=e[(c[277213]|0)+(t<<1)>>1]|0;I=H;J=H&63454}if(G){K=c[277228]|0}else{K=e[(c[277213]|0)+(t<<1)>>1]|0}b[(c[277218]|0)+(t<<1)>>1]=((K^w)&2081|e[(c[277220]|0)+((w&2081&I)+((J+(w&63454)|0)>>>1)<<1)>>1])&65535;w=(a[1108928]|0)==0;if(w){L=b[(c[277213]|0)+(t+2<<1)>>1]&63454}else{L=0}G=(a[(c[277215]|0)+t|0]&32)==0;if(G){M=c[277228]|0}else{M=e[(c[277226]|0)+(F<<1)>>1]|0}if(w){N=b[(c[277213]|0)+(t+2<<1)>>1]&2081}else{N=0}if(G){O=c[277228]|0}else{O=e[(c[277226]|0)+(F<<1)>>1]|0}if(w){P=e[(c[277213]|0)+(t+2<<1)>>1]|0}else{P=0}if(G){Q=c[277228]|0}else{Q=e[(c[277226]|0)+(F<<1)>>1]|0}F=t+1|0;b[(c[277218]|0)+(F<<1)>>1]=((Q^P)&2081|e[(c[277220]|0)+((O&N)+(((M&-2082)+L|0)>>>1)<<1)>>1])&65535;a[(c[277219]|0)+F|0]=h;a[(c[277219]|0)+t|0]=h}}while(0);t=E+1|0;if(t>>>0>=g>>>0){break L2905}C=C+z|0;D=D+y|0;E=t}}else{if(l){R=r;S=j;T=f}else{break}while(1){t=S+x|0;u=t>>8;q=R+v>>8;do{if((q|u)>>>0<1024){U=q<<4&112|u<<1&14|d[(c[263194]|0)+((q<<5&-256)+(t>>10&-2))|0]<<7;V=2135}else{if((a[1044415]|0)!=3){break}U=q<<4&112|u<<1&14;V=2135}}while(0);do{if((V|0)==2135){V=0;u=(T<<1)+o|0;if((k|0)<=(d[(c[277219]|0)+u|0]|0)){break}q=a[i+(U|1)|0]|0;t=q&255;if(q<<24>>24==0){break}q=e[(c[277225]|0)+(t<<1)>>1]|0;F=(a[(c[277215]|0)+u|0]&32)==0;if(F){G=c[277228]|0;W=G;X=G&-2082}else{G=e[(c[277213]|0)+(u<<1)>>1]|0;W=G;X=G&63454}if(F){Y=c[277228]|0}else{Y=e[(c[277213]|0)+(u<<1)>>1]|0}b[(c[277218]|0)+(u<<1)>>1]=((Y^q)&2081|e[(c[277220]|0)+((q&2081&W)+((X+(q&63454)|0)>>>1)<<1)>>1])&65535;q=(a[1108928]|0)==0;if(q){Z=b[(c[277213]|0)+(u+2<<1)>>1]&63454}else{Z=0}F=(a[(c[277215]|0)+u|0]&32)==0;if(F){_=c[277228]|0}else{_=e[(c[277226]|0)+(t<<1)>>1]|0}if(q){$=b[(c[277213]|0)+(u+2<<1)>>1]&2081}else{$=0}if(F){aa=c[277228]|0}else{aa=e[(c[277226]|0)+(t<<1)>>1]|0}if(q){ac=e[(c[277213]|0)+(u+2<<1)>>1]|0}else{ac=0}if(F){ad=c[277228]|0}else{ad=e[(c[277226]|0)+(t<<1)>>1]|0}t=u+1|0;b[(c[277218]|0)+(t<<1)>>1]=((ad^ac)&2081|e[(c[277220]|0)+((aa&$)+(((_&-2082)+Z|0)>>>1)<<1)>>1])&65535;a[(c[277219]|0)+t|0]=h;a[(c[277219]|0)+u|0]=h}}while(0);u=T+1|0;if(u>>>0<g>>>0){R=R+z|0;S=S+y|0;T=u}else{break}}}}while(0);if(s>>>0>(c[277231]|0)>>>0){break}o=(c[277223]|0)+o|0;m=s;n=n+16|0}return}function V2(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0;i=c[263194]|0;do{if((a[(c[263195]|0)+8496|0]&1)==0){j=1106168}else{if((a[1106089]|0)==0){j=1125528;break}k=d[1044485]|0;c[276541]=7080+(k<<5);l=0;do{m=l<<1&2;n=l&2;o=l&4;p=0;do{b[1125528+(l<<9)+(p<<1)>>1]=d[(p>>>1&28|n)+(7080+(k<<5))|0]<<6|d[(p<<2&28|m)+(7080+(k<<5))|0]<<11|d[(p>>>3&24|o)+(7080+(k<<5))|0];p=p+1|0;}while(p>>>0<256);l=l+1|0;}while(l>>>0<8);a[1106089]=0;j=1125528}}while(0);c[277226]=j;c[277225]=(a[1108928]|0)!=0?1393712:j;j=c[277230]|0;if(j>>>0>(c[277231]|0)>>>0){return}l=f>>>0<g>>>0;k=h+7|0;h=k&255;p=g-1|0;o=ab(c[277223]|0,j)|0;m=j;n=1097960+(j<<4)|0;while(1){j=e[n+12>>1]<<19>>19;q=e[n+8>>1]<<19;r=e[n+10>>1]<<19;s=m+1|0;t=(e[n+14>>1]<<19>>19)-(r>>19)|0;u=(t&8192|0)!=0?t|-1024:t&1023;t=b[n+2>>1]|0;v=((a[1044414]|0)==0?s:s^255)&255;w=(ab(v,t)|0)&-64;x=w+(q>>11)+((ab(u,t)|0)&-64)|0;t=b[n+6>>1]|0;w=(ab(t,v)|0)&-64;v=w+(r>>11)+((ab(u,t)|0)&-64)|0;t=b[n>>1]|0;if((a[1044413]|0)==0){u=b[n+4>>1]|0;y=t;z=u<<16>>16;A=f;B=u}else{u=b[n+4>>1]|0;y=-t|0;z=-(u<<16>>16)|0;A=p;B=u}u=j-(q>>19)|0;q=(u&8192|0)!=0?u|-1024:u&1023;u=ab(A,t)|0;j=u+((ab(t,q)|0)&-64)|0;t=B<<16>>16;u=ab(t,A)|0;r=((ab(t,q)|0)&-64)+u|0;L3007:do{if((a[1044415]|0)==0){if(l){C=r;D=j;E=f}else{break}while(1){u=D+x|0;q=(C+v|0)>>>8;t=(E<<1)+o|0;do{if((k|0)>(d[(c[277219]|0)+t|0]|0)){w=a[i+(u>>>8<<1&14|q<<4&112|d[(c[263194]|0)+(q<<5&32512|u>>>10&254)|0]<<7|1)|0]|0;if(w<<24>>24==0){break}F=e[(c[277225]|0)+((w&255)<<1)>>1]|0;w=c[277228]|0;G=(((F&63454)+(w&-2082)|0)>>>1)+(w&2081&F)|0;if((a[1108928]|0)==0){H=G&65535}else{H=(e[(c[277220]|0)+(G<<1)>>1]|(F^w)&2081)&65535}b[(c[277218]|0)+(t<<1)>>1]=H;if((a[1108928]|0)==0){w=e[(c[277213]|0)+(t+2<<1)>>1]|0;F=c[277228]|0;I=(((w&63454)+(F&128990)|0)>>>1)+(F&2081&w)|0}else{w=c[277228]|0;I=e[(c[277220]|0)+((w>>>1&2147482607)<<1)>>1]|w&2081}w=t+1|0;b[(c[277218]|0)+(w<<1)>>1]=I&65535;a[(c[277219]|0)+w|0]=h;a[(c[277219]|0)+t|0]=h}}while(0);t=E+1|0;if(t>>>0>=g>>>0){break L3007}C=C+z|0;D=D+y|0;E=t}}else{if(l){J=r;K=j;L=f}else{break}while(1){t=K+x|0;u=t>>8;q=J+v>>8;do{if((q|u)>>>0<1024){M=q<<4&112|u<<1&14|d[(c[263194]|0)+((q<<5&-256)+(t>>10&-2))|0]<<7;N=2194}else{if((a[1044415]|0)!=3){break}M=q<<4&112|u<<1&14;N=2194}}while(0);do{if((N|0)==2194){N=0;u=(L<<1)+o|0;if((k|0)<=(d[(c[277219]|0)+u|0]|0)){break}q=a[i+(M|1)|0]|0;if(q<<24>>24==0){break}t=e[(c[277225]|0)+((q&255)<<1)>>1]|0;q=c[277228]|0;w=(((t&63454)+(q&-2082)|0)>>>1)+(q&2081&t)|0;if((a[1108928]|0)==0){O=w&65535}else{O=(e[(c[277220]|0)+(w<<1)>>1]|(t^q)&2081)&65535}b[(c[277218]|0)+(u<<1)>>1]=O;if((a[1108928]|0)==0){q=e[(c[277213]|0)+(u+2<<1)>>1]|0;t=c[277228]|0;P=(((q&63454)+(t&128990)|0)>>>1)+(t&2081&q)|0}else{q=c[277228]|0;P=e[(c[277220]|0)+((q>>>1&2147482607)<<1)>>1]|q&2081}q=u+1|0;b[(c[277218]|0)+(q<<1)>>1]=P&65535;a[(c[277219]|0)+q|0]=h;a[(c[277219]|0)+u|0]=h}}while(0);u=L+1|0;if(u>>>0<g>>>0){J=J+z|0;K=K+y|0;L=u}else{break}}}}while(0);if(s>>>0>(c[277231]|0)>>>0){break}o=(c[277223]|0)+o|0;m=s;n=n+16|0}return}function V3(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0;i=c[263194]|0;do{if((a[(c[263195]|0)+8496|0]&1)==0){j=1106168}else{if((a[1106089]|0)==0){j=1125528;break}k=d[1044485]|0;c[276541]=7080+(k<<5);l=0;do{m=l<<1&2;n=l&2;o=l&4;p=0;do{b[1125528+(l<<9)+(p<<1)>>1]=d[(p>>>1&28|n)+(7080+(k<<5))|0]<<6|d[(p<<2&28|m)+(7080+(k<<5))|0]<<11|d[(p>>>3&24|o)+(7080+(k<<5))|0];p=p+1|0;}while(p>>>0<256);l=l+1|0;}while(l>>>0<8);a[1106089]=0;j=1125528}}while(0);c[277226]=j;c[277225]=(a[1108928]|0)!=0?1393712:j;j=c[277230]|0;if(j>>>0>(c[277231]|0)>>>0){return}l=f>>>0<g>>>0;k=h+7|0;h=k&255;p=g-1|0;o=ab(c[277223]|0,j)|0;m=j;n=1097960+(j<<4)|0;while(1){j=e[n+12>>1]<<19>>19;q=e[n+8>>1]<<19;r=e[n+10>>1]<<19;s=m+1|0;t=(e[n+14>>1]<<19>>19)-(r>>19)|0;u=(t&8192|0)!=0?t|-1024:t&1023;t=b[n+2>>1]|0;v=((a[1044414]|0)==0?s:s^255)&255;w=(ab(v,t)|0)&-64;x=w+(q>>11)+((ab(u,t)|0)&-64)|0;t=b[n+6>>1]|0;w=(ab(t,v)|0)&-64;v=w+(r>>11)+((ab(u,t)|0)&-64)|0;t=b[n>>1]|0;if((a[1044413]|0)==0){u=b[n+4>>1]|0;y=t;z=u<<16>>16;A=f;B=u}else{u=b[n+4>>1]|0;y=-t|0;z=-(u<<16>>16)|0;A=p;B=u}u=j-(q>>19)|0;q=(u&8192|0)!=0?u|-1024:u&1023;u=ab(A,t)|0;j=u+((ab(t,q)|0)&-64)|0;t=B<<16>>16;u=ab(t,A)|0;r=((ab(t,q)|0)&-64)+u|0;L3065:do{if((a[1044415]|0)==0){if(l){C=r;D=j;E=f}else{break}while(1){u=D+x|0;q=(C+v|0)>>>8;t=(E<<1)+o|0;do{if((k|0)>(d[(c[277219]|0)+t|0]|0)){w=a[i+(u>>>8<<1&14|q<<4&112|d[(c[263194]|0)+(q<<5&32512|u>>>10&254)|0]<<7|1)|0]|0;F=w&255;if(w<<24>>24==0){break}do{if((a[1108928]|0)==0){w=b[(c[277225]|0)+(F<<1)>>1]|0;G=w&65535;H=G&63454;if((a[(c[277215]|0)+t|0]&32)==0){I=c[277228]|0;J=(e[(c[277220]|0)+((((I&-2082)+H|0)>>>1)+(G&2081&I)<<1)>>1]|(I^G)&2081)&65535;break}else{G=b[(c[277213]|0)+(t<<1)>>1]|0;J=(((G&63454)+H|0)>>>1)+(G&w&2081)&65535;break}}else{w=e[(c[277225]|0)+(F<<1)>>1]|0;G=(a[(c[277215]|0)+t|0]&32)==0;if(G){H=c[277228]|0;K=H;L=H&-2082}else{H=e[(c[277213]|0)+(t<<1)>>1]|0;K=H;L=H&63454}if(G){M=c[277228]|0}else{M=e[(c[277213]|0)+(t<<1)>>1]|0}J=((M^w)&2081|e[(c[277220]|0)+((w&2081&K)+((L+(w&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(t<<1)>>1]=J;w=(a[(c[277215]|0)+t|0]&32)==0;do{if((a[1108928]|0)==0){G=e[(c[277213]|0)+(t+2<<1)>>1]|0;H=G&63454;if(w){I=c[277228]|0;N=(e[(c[277220]|0)+((((I&-2082)+H|0)>>>1)+(G&2081&I)<<1)>>1]|(I^G)&2081)&65535;break}else{I=e[(c[277226]|0)+(F<<1)>>1]|0;N=(((I&63454)+H|0)>>>1)+(G&2081&I)&65535;break}}else{if(w){I=c[277228]|0;O=I;P=(c[277220]|0)+((I>>>1&2147482607)<<1)|0}else{I=e[(c[277226]|0)+(F<<1)>>1]|0;O=I;P=(c[277220]|0)+((I>>>1&31727)<<1)|0}N=(e[P>>1]|O&2081)&65535}}while(0);F=t+1|0;b[(c[277218]|0)+(F<<1)>>1]=N;a[(c[277219]|0)+F|0]=h;a[(c[277219]|0)+t|0]=h}}while(0);t=E+1|0;if(t>>>0>=g>>>0){break L3065}C=C+z|0;D=D+y|0;E=t}}else{if(l){Q=r;R=j;S=f}else{break}while(1){t=R+x|0;u=t>>8;q=Q+v>>8;do{if((q|u)>>>0<1024){T=q<<4&112|u<<1&14|d[(c[263194]|0)+((q<<5&-256)+(t>>10&-2))|0]<<7;U=2251}else{if((a[1044415]|0)!=3){break}T=q<<4&112|u<<1&14;U=2251}}while(0);do{if((U|0)==2251){U=0;u=(S<<1)+o|0;if((k|0)<=(d[(c[277219]|0)+u|0]|0)){break}q=a[i+(T|1)|0]|0;t=q&255;if(q<<24>>24==0){break}do{if((a[1108928]|0)==0){q=b[(c[277225]|0)+(t<<1)>>1]|0;F=q&65535;w=F&63454;if((a[(c[277215]|0)+u|0]&32)==0){I=c[277228]|0;V=(e[(c[277220]|0)+((((I&-2082)+w|0)>>>1)+(F&2081&I)<<1)>>1]|(I^F)&2081)&65535;break}else{F=b[(c[277213]|0)+(u<<1)>>1]|0;V=(((F&63454)+w|0)>>>1)+(F&q&2081)&65535;break}}else{q=e[(c[277225]|0)+(t<<1)>>1]|0;F=(a[(c[277215]|0)+u|0]&32)==0;if(F){w=c[277228]|0;W=w;X=w&-2082}else{w=e[(c[277213]|0)+(u<<1)>>1]|0;W=w;X=w&63454}if(F){Y=c[277228]|0}else{Y=e[(c[277213]|0)+(u<<1)>>1]|0}V=((Y^q)&2081|e[(c[277220]|0)+((q&2081&W)+((X+(q&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(u<<1)>>1]=V;q=(a[(c[277215]|0)+u|0]&32)==0;do{if((a[1108928]|0)==0){F=e[(c[277213]|0)+(u+2<<1)>>1]|0;w=F&63454;if(q){I=c[277228]|0;Z=(e[(c[277220]|0)+((((I&-2082)+w|0)>>>1)+(F&2081&I)<<1)>>1]|(I^F)&2081)&65535;break}else{I=e[(c[277226]|0)+(t<<1)>>1]|0;Z=(((I&63454)+w|0)>>>1)+(F&2081&I)&65535;break}}else{if(q){I=c[277228]|0;_=I;$=(c[277220]|0)+((I>>>1&2147482607)<<1)|0}else{I=e[(c[277226]|0)+(t<<1)>>1]|0;_=I;$=(c[277220]|0)+((I>>>1&31727)<<1)|0}Z=(e[$>>1]|_&2081)&65535}}while(0);t=u+1|0;b[(c[277218]|0)+(t<<1)>>1]=Z;a[(c[277219]|0)+t|0]=h;a[(c[277219]|0)+u|0]=h}}while(0);t=S+1|0;if(t>>>0<g>>>0){Q=Q+z|0;R=R+y|0;S=t}else{break}}}}while(0);if(s>>>0>(c[277231]|0)>>>0){break}o=(c[277223]|0)+o|0;m=s;n=n+16|0}return}function V4(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0;i=c[263194]|0;do{if((a[(c[263195]|0)+8496|0]&1)==0){j=1106168}else{if((a[1106089]|0)==0){j=1125528;break}k=d[1044485]|0;c[276541]=7080+(k<<5);l=0;do{m=l<<1&2;n=l&2;o=l&4;p=0;do{b[1125528+(l<<9)+(p<<1)>>1]=d[(p>>>1&28|n)+(7080+(k<<5))|0]<<6|d[(p<<2&28|m)+(7080+(k<<5))|0]<<11|d[(p>>>3&24|o)+(7080+(k<<5))|0];p=p+1|0;}while(p>>>0<256);l=l+1|0;}while(l>>>0<8);a[1106089]=0;j=1125528}}while(0);c[277226]=j;c[277225]=(a[1108928]|0)!=0?1393712:j;j=c[277230]|0;if(j>>>0>(c[277231]|0)>>>0){return}l=f>>>0<g>>>0;k=h+7|0;h=k&255;p=g-1|0;o=ab(c[277223]|0,j)|0;m=j;n=1097960+(j<<4)|0;while(1){j=e[n+12>>1]<<19>>19;q=e[n+8>>1]<<19;r=e[n+10>>1]<<19;s=m+1|0;t=(e[n+14>>1]<<19>>19)-(r>>19)|0;u=(t&8192|0)!=0?t|-1024:t&1023;t=b[n+2>>1]|0;v=((a[1044414]|0)==0?s:s^255)&255;w=(ab(v,t)|0)&-64;x=w+(q>>11)+((ab(u,t)|0)&-64)|0;t=b[n+6>>1]|0;w=(ab(t,v)|0)&-64;v=w+(r>>11)+((ab(u,t)|0)&-64)|0;t=b[n>>1]|0;if((a[1044413]|0)==0){u=b[n+4>>1]|0;y=t;z=u<<16>>16;A=f;B=u}else{u=b[n+4>>1]|0;y=-t|0;z=-(u<<16>>16)|0;A=p;B=u}u=j-(q>>19)|0;q=(u&8192|0)!=0?u|-1024:u&1023;u=ab(A,t)|0;j=u+((ab(t,q)|0)&-64)|0;t=B<<16>>16;u=ab(t,A)|0;r=((ab(t,q)|0)&-64)+u|0;L3161:do{if((a[1044415]|0)==0){if(l){C=r;D=j;E=f}else{break}while(1){u=D+x|0;q=(C+v|0)>>>8;t=(E<<1)+o|0;do{if((k|0)>(d[(c[277219]|0)+t|0]|0)){w=a[i+(u>>>8<<1&14|q<<4&112|d[(c[263194]|0)+(q<<5&32512|u>>>10&254)|0]<<7|1)|0]|0;F=w&255;if(w<<24>>24==0){break}w=b[(c[277225]|0)+(F<<1)>>1]|0;if((a[(c[277215]|0)+t|0]&32)==0){G=c[277228]&65535}else{G=b[(c[277213]|0)+(t<<1)>>1]|0}H=w&-2048;I=G&-2048;J=(H&65535)>(I&65535)?H-I&65535:0;I=w&2016;H=G&2016;if((I&65535)>(H&65535)){K=(I-H&65535)+J&65535}else{K=J}J=w&31;w=G&31;if((J&65535)>(w&65535)){L=(J-w&65535)+K&65535}else{L=K}b[(c[277218]|0)+(t<<1)>>1]=L;if((a[1108928]|0)==0){M=b[(c[277213]|0)+(t+2<<1)>>1]|0}else{M=0}if((a[(c[277215]|0)+t|0]&32)==0){N=c[277228]&65535}else{N=b[(c[277226]|0)+(F<<1)>>1]|0}F=M&-2048;w=N&-2048;J=(F&65535)>(w&65535)?F-w&65535:0;w=M&2016;F=N&2016;if((w&65535)>(F&65535)){O=(w-F&65535)+J&65535}else{O=J}J=M&31;F=N&31;if((J&65535)>(F&65535)){P=(J-F&65535)+O&65535}else{P=O}F=t+1|0;b[(c[277218]|0)+(F<<1)>>1]=P;a[(c[277219]|0)+F|0]=h;a[(c[277219]|0)+t|0]=h}}while(0);t=E+1|0;if(t>>>0>=g>>>0){break L3161}C=C+z|0;D=D+y|0;E=t}}else{if(l){Q=r;R=j;S=f}else{break}while(1){t=R+x|0;u=t>>8;q=Q+v>>8;do{if((q|u)>>>0<1024){T=q<<4&112|u<<1&14|d[(c[263194]|0)+((q<<5&-256)+(t>>10&-2))|0]<<7;U=2319}else{if((a[1044415]|0)!=3){break}T=q<<4&112|u<<1&14;U=2319}}while(0);do{if((U|0)==2319){U=0;u=(S<<1)+o|0;if((k|0)<=(d[(c[277219]|0)+u|0]|0)){break}q=a[i+(T|1)|0]|0;t=q&255;if(q<<24>>24==0){break}q=b[(c[277225]|0)+(t<<1)>>1]|0;if((a[(c[277215]|0)+u|0]&32)==0){V=c[277228]&65535}else{V=b[(c[277213]|0)+(u<<1)>>1]|0}F=q&-2048;J=V&-2048;w=(F&65535)>(J&65535)?F-J&65535:0;J=q&2016;F=V&2016;if((J&65535)>(F&65535)){W=(J-F&65535)+w&65535}else{W=w}w=q&31;q=V&31;if((w&65535)>(q&65535)){X=(w-q&65535)+W&65535}else{X=W}b[(c[277218]|0)+(u<<1)>>1]=X;if((a[1108928]|0)==0){Y=b[(c[277213]|0)+(u+2<<1)>>1]|0}else{Y=0}if((a[(c[277215]|0)+u|0]&32)==0){Z=c[277228]&65535}else{Z=b[(c[277226]|0)+(t<<1)>>1]|0}t=Y&-2048;q=Z&-2048;w=(t&65535)>(q&65535)?t-q&65535:0;q=Y&2016;t=Z&2016;if((q&65535)>(t&65535)){_=(q-t&65535)+w&65535}else{_=w}w=Y&31;t=Z&31;if((w&65535)>(t&65535)){$=(w-t&65535)+_&65535}else{$=_}t=u+1|0;b[(c[277218]|0)+(t<<1)>>1]=$;a[(c[277219]|0)+t|0]=h;a[(c[277219]|0)+u|0]=h}}while(0);u=S+1|0;if(u>>>0<g>>>0){Q=Q+z|0;R=R+y|0;S=u}else{break}}}}while(0);if(s>>>0>(c[277231]|0)>>>0){break}o=(c[277223]|0)+o|0;m=s;n=n+16|0}return}function V5(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0;i=c[263194]|0;do{if((a[(c[263195]|0)+8496|0]&1)==0){j=1106168}else{if((a[1106089]|0)==0){j=1125528;break}k=d[1044485]|0;c[276541]=7080+(k<<5);l=0;do{m=l<<1&2;n=l&2;o=l&4;p=0;do{b[1125528+(l<<9)+(p<<1)>>1]=d[(p>>>1&28|n)+(7080+(k<<5))|0]<<6|d[(p<<2&28|m)+(7080+(k<<5))|0]<<11|d[(p>>>3&24|o)+(7080+(k<<5))|0];p=p+1|0;}while(p>>>0<256);l=l+1|0;}while(l>>>0<8);a[1106089]=0;j=1125528}}while(0);c[277226]=j;c[277225]=(a[1108928]|0)!=0?1393712:j;j=c[277230]|0;if(j>>>0>(c[277231]|0)>>>0){return}l=f>>>0<g>>>0;k=h+7|0;h=k&255;p=g-1|0;o=ab(c[277223]|0,j)|0;m=j;n=1097960+(j<<4)|0;while(1){j=e[n+12>>1]<<19>>19;q=e[n+8>>1]<<19;r=e[n+10>>1]<<19;s=m+1|0;t=(e[n+14>>1]<<19>>19)-(r>>19)|0;u=(t&8192|0)!=0?t|-1024:t&1023;t=b[n+2>>1]|0;v=((a[1044414]|0)==0?s:s^255)&255;w=(ab(v,t)|0)&-64;x=w+(q>>11)+((ab(u,t)|0)&-64)|0;t=b[n+6>>1]|0;w=(ab(t,v)|0)&-64;v=w+(r>>11)+((ab(u,t)|0)&-64)|0;t=b[n>>1]|0;if((a[1044413]|0)==0){u=b[n+4>>1]|0;y=t;z=u<<16>>16;A=f;B=u}else{u=b[n+4>>1]|0;y=-t|0;z=-(u<<16>>16)|0;A=p;B=u}u=j-(q>>19)|0;q=(u&8192|0)!=0?u|-1024:u&1023;u=ab(A,t)|0;j=u+((ab(t,q)|0)&-64)|0;t=B<<16>>16;u=ab(t,A)|0;r=((ab(t,q)|0)&-64)+u|0;L3251:do{if((a[1044415]|0)==0){if(l){C=r;D=j;E=f}else{break}while(1){u=D+x|0;q=(C+v|0)>>>8;t=(E<<1)+o|0;do{if((k|0)>(d[(c[277219]|0)+t|0]|0)){w=a[i+(u>>>8<<1&14|q<<4&112|d[(c[263194]|0)+(q<<5&32512|u>>>10&254)|0]<<7|1)|0]|0;if(w<<24>>24==0){break}F=b[(c[277225]|0)+((w&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){G=b[(c[277221]|0)+(((F&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{w=c[277228]&65535;H=F&-2048;I=w&-2048;J=(H&65535)>(I&65535)?H-I&65535:0;I=F&2016;H=w&2016;if((I&65535)>(H&65535)){K=(I-H&65535)+J&65535}else{K=J}J=F&31;H=w&31;if((J&65535)<=(H&65535)){G=K;break}G=(J-H&65535)+K&65535}}while(0);b[(c[277218]|0)+(t<<1)>>1]=G;if((a[1108928]|0)==0){L=b[(c[277221]|0)+(((e[(c[277213]|0)+(t+2<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{L=0}F=t+1|0;b[(c[277218]|0)+(F<<1)>>1]=L;a[(c[277219]|0)+F|0]=h;a[(c[277219]|0)+t|0]=h}}while(0);t=E+1|0;if(t>>>0>=g>>>0){break L3251}C=C+z|0;D=D+y|0;E=t}}else{if(l){M=r;N=j;O=f}else{break}while(1){t=N+x|0;u=t>>8;q=M+v>>8;do{if((q|u)>>>0<1024){P=q<<4&112|u<<1&14|d[(c[263194]|0)+((q<<5&-256)+(t>>10&-2))|0]<<7;Q=2376}else{if((a[1044415]|0)!=3){break}P=q<<4&112|u<<1&14;Q=2376}}while(0);do{if((Q|0)==2376){Q=0;u=(O<<1)+o|0;if((k|0)<=(d[(c[277219]|0)+u|0]|0)){break}q=a[i+(P|1)|0]|0;if(q<<24>>24==0){break}t=b[(c[277225]|0)+((q&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){R=b[(c[277221]|0)+(((t&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{q=c[277228]&65535;F=t&-2048;H=q&-2048;J=(F&65535)>(H&65535)?F-H&65535:0;H=t&2016;F=q&2016;if((H&65535)>(F&65535)){S=(H-F&65535)+J&65535}else{S=J}J=t&31;F=q&31;if((J&65535)<=(F&65535)){R=S;break}R=(J-F&65535)+S&65535}}while(0);b[(c[277218]|0)+(u<<1)>>1]=R;if((a[1108928]|0)==0){T=b[(c[277221]|0)+(((e[(c[277213]|0)+(u+2<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{T=0}t=u+1|0;b[(c[277218]|0)+(t<<1)>>1]=T;a[(c[277219]|0)+t|0]=h;a[(c[277219]|0)+u|0]=h}}while(0);t=O+1|0;if(t>>>0<g>>>0){M=M+z|0;N=N+y|0;O=t}else{break}}}}while(0);if(s>>>0>(c[277231]|0)>>>0){break}o=(c[277223]|0)+o|0;m=s;n=n+16|0}return}function V6(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0;i=c[263194]|0;do{if((a[(c[263195]|0)+8496|0]&1)==0){j=1106168}else{if((a[1106089]|0)==0){j=1125528;break}k=d[1044485]|0;c[276541]=7080+(k<<5);l=0;do{m=l<<1&2;n=l&2;o=l&4;p=0;do{b[1125528+(l<<9)+(p<<1)>>1]=d[(p>>>1&28|n)+(7080+(k<<5))|0]<<6|d[(p<<2&28|m)+(7080+(k<<5))|0]<<11|d[(p>>>3&24|o)+(7080+(k<<5))|0];p=p+1|0;}while(p>>>0<256);l=l+1|0;}while(l>>>0<8);a[1106089]=0;j=1125528}}while(0);c[277226]=j;c[277225]=(a[1108928]|0)!=0?1393712:j;j=c[277230]|0;if(j>>>0>(c[277231]|0)>>>0){return}l=f>>>0<g>>>0;k=h+7|0;h=k&255;p=g-1|0;o=ab(c[277223]|0,j)|0;m=j;n=1097960+(j<<4)|0;while(1){j=e[n+12>>1]<<19>>19;q=e[n+8>>1]<<19;r=e[n+10>>1]<<19;s=m+1|0;t=(e[n+14>>1]<<19>>19)-(r>>19)|0;u=(t&8192|0)!=0?t|-1024:t&1023;t=b[n+2>>1]|0;v=((a[1044414]|0)==0?s:s^255)&255;w=(ab(v,t)|0)&-64;x=w+(q>>11)+((ab(u,t)|0)&-64)|0;t=b[n+6>>1]|0;w=(ab(t,v)|0)&-64;v=w+(r>>11)+((ab(u,t)|0)&-64)|0;t=b[n>>1]|0;if((a[1044413]|0)==0){u=b[n+4>>1]|0;y=t;z=u<<16>>16;A=f;B=u}else{u=b[n+4>>1]|0;y=-t|0;z=-(u<<16>>16)|0;A=p;B=u}u=j-(q>>19)|0;q=(u&8192|0)!=0?u|-1024:u&1023;u=ab(A,t)|0;j=u+((ab(t,q)|0)&-64)|0;t=B<<16>>16;u=ab(t,A)|0;r=((ab(t,q)|0)&-64)+u|0;L3317:do{if((a[1044415]|0)==0){if(l){C=r;D=j;E=f}else{break}while(1){u=D+x|0;q=(C+v|0)>>>8;t=(E<<1)+o|0;do{if((k|0)>(d[(c[277219]|0)+t|0]|0)){w=a[i+(u>>>8<<1&14|q<<4&112|d[(c[263194]|0)+(q<<5&32512|u>>>10&254)|0]<<7|1)|0]|0;F=w&255;if(w<<24>>24==0){break}do{if((a[1108928]|0)==0){w=b[(c[277225]|0)+(F<<1)>>1]|0;if((a[(c[277215]|0)+t|0]&32)!=0){G=b[(c[277221]|0)+((w&65535|67616)-(b[(c[277213]|0)+(t<<1)>>1]&63454)>>1<<1)>>1]|0;break}H=c[277228]&65535;I=w&-2048;J=H&-2048;K=(I&65535)>(J&65535)?I-J&65535:0;J=w&2016;I=H&2016;if((J&65535)>(I&65535)){L=(J-I&65535)+K&65535}else{L=K}K=w&31;w=H&31;if((K&65535)<=(w&65535)){G=L;break}G=(K-w&65535)+L&65535}else{w=b[(c[277225]|0)+(F<<1)>>1]|0;if((a[(c[277215]|0)+t|0]&32)==0){M=c[277228]&65535}else{M=b[(c[277213]|0)+(t<<1)>>1]|0}K=w&-2048;H=M&-2048;I=(K&65535)>(H&65535)?K-H&65535:0;H=w&2016;K=M&2016;if((H&65535)>(K&65535)){N=(H-K&65535)+I&65535}else{N=I}I=w&31;w=M&31;if((I&65535)<=(w&65535)){G=N;break}G=(I-w&65535)+N&65535}}while(0);b[(c[277218]|0)+(t<<1)>>1]=G;do{if((a[1108928]|0)==0){w=b[(c[277213]|0)+(t+2<<1)>>1]|0;if((a[(c[277215]|0)+t|0]&32)!=0){O=b[(c[277221]|0)+((w&65535|67616)-(b[(c[277226]|0)+(F<<1)>>1]&63454)>>1<<1)>>1]|0;break}I=c[277228]&65535;K=w&-2048;H=I&-2048;J=(K&65535)>(H&65535)?K-H&65535:0;H=w&2016;K=I&2016;if((H&65535)>(K&65535)){P=(H-K&65535)+J&65535}else{P=J}J=w&31;w=I&31;if((J&65535)<=(w&65535)){O=P;break}O=(J-w&65535)+P&65535}else{O=0}}while(0);F=t+1|0;b[(c[277218]|0)+(F<<1)>>1]=O;a[(c[277219]|0)+F|0]=h;a[(c[277219]|0)+t|0]=h}}while(0);t=E+1|0;if(t>>>0>=g>>>0){break L3317}C=C+z|0;D=D+y|0;E=t}}else{if(l){Q=r;R=j;S=f}else{break}while(1){t=R+x|0;u=t>>8;q=Q+v>>8;do{if((q|u)>>>0<1024){T=q<<4&112|u<<1&14|d[(c[263194]|0)+((q<<5&-256)+(t>>10&-2))|0]<<7;U=2438}else{if((a[1044415]|0)!=3){break}T=q<<4&112|u<<1&14;U=2438}}while(0);do{if((U|0)==2438){U=0;u=(S<<1)+o|0;if((k|0)<=(d[(c[277219]|0)+u|0]|0)){break}q=a[i+(T|1)|0]|0;t=q&255;if(q<<24>>24==0){break}do{if((a[1108928]|0)==0){q=b[(c[277225]|0)+(t<<1)>>1]|0;if((a[(c[277215]|0)+u|0]&32)!=0){V=b[(c[277221]|0)+((q&65535|67616)-(b[(c[277213]|0)+(u<<1)>>1]&63454)>>1<<1)>>1]|0;break}F=c[277228]&65535;w=q&-2048;J=F&-2048;I=(w&65535)>(J&65535)?w-J&65535:0;J=q&2016;w=F&2016;if((J&65535)>(w&65535)){W=(J-w&65535)+I&65535}else{W=I}I=q&31;q=F&31;if((I&65535)<=(q&65535)){V=W;break}V=(I-q&65535)+W&65535}else{q=b[(c[277225]|0)+(t<<1)>>1]|0;if((a[(c[277215]|0)+u|0]&32)==0){X=c[277228]&65535}else{X=b[(c[277213]|0)+(u<<1)>>1]|0}I=q&-2048;F=X&-2048;w=(I&65535)>(F&65535)?I-F&65535:0;F=q&2016;I=X&2016;if((F&65535)>(I&65535)){Y=(F-I&65535)+w&65535}else{Y=w}w=q&31;q=X&31;if((w&65535)<=(q&65535)){V=Y;break}V=(w-q&65535)+Y&65535}}while(0);b[(c[277218]|0)+(u<<1)>>1]=V;do{if((a[1108928]|0)==0){q=b[(c[277213]|0)+(u+2<<1)>>1]|0;if((a[(c[277215]|0)+u|0]&32)!=0){Z=b[(c[277221]|0)+((q&65535|67616)-(b[(c[277226]|0)+(t<<1)>>1]&63454)>>1<<1)>>1]|0;break}w=c[277228]&65535;I=q&-2048;F=w&-2048;J=(I&65535)>(F&65535)?I-F&65535:0;F=q&2016;I=w&2016;if((F&65535)>(I&65535)){_=(F-I&65535)+J&65535}else{_=J}J=q&31;q=w&31;if((J&65535)<=(q&65535)){Z=_;break}Z=(J-q&65535)+_&65535}else{Z=0}}while(0);t=u+1|0;b[(c[277218]|0)+(t<<1)>>1]=Z;a[(c[277219]|0)+t|0]=h;a[(c[277219]|0)+u|0]=h}}while(0);t=S+1|0;if(t>>>0<g>>>0){Q=Q+z|0;R=R+y|0;S=t}else{break}}}}while(0);if(s>>>0>(c[277231]|0)>>>0){break}o=(c[277223]|0)+o|0;m=s;n=n+16|0}return}function V7(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0;i=c[263194]|0;do{if((a[(c[263195]|0)+8496|0]&1)==0){j=1106168}else{if((a[1106089]|0)==0){j=1125528;break}k=d[1044485]|0;c[276541]=7080+(k<<5);l=0;do{m=l<<1&2;n=l&2;o=l&4;p=0;do{b[1125528+(l<<9)+(p<<1)>>1]=d[(p>>>1&28|n)+(7080+(k<<5))|0]<<6|d[(p<<2&28|m)+(7080+(k<<5))|0]<<11|d[(p>>>3&24|o)+(7080+(k<<5))|0];p=p+1|0;}while(p>>>0<256);l=l+1|0;}while(l>>>0<8);a[1106089]=0;j=1125528}}while(0);c[277226]=j;c[277225]=(a[1108928]|0)!=0?1393712:j;j=c[277230]|0;if((a[1044434]|0)==0){q=f;r=g;s=0;t=1;u=j}else{l=d[1044432]|0;k=((j-(d[1044433]|0)|0)>>>0)%(l>>>0)|0;p=g-1+l|0;q=f-((f|0)%(l|0)|0)|0;r=p-((p|0)%(l|0)|0)|0;s=k;t=l;u=j-k|0}k=c[277231]|0;if(u>>>0>k>>>0){return}j=(q|0)<(r|0);l=t&255;p=h+7|0;h=p&255;o=r-1|0;m=t-1|0;n=s;s=t;t=ab(c[277223]|0,u)|0;v=u;w=1097960+(u<<4)|0;u=k;while(1){if((s+v|0)>>>0>u>>>0){x=u+1-v|0}else{x=s}k=e[w+12>>1]<<19>>19;y=e[w+8>>1]<<19;z=e[w+10>>1]<<19;A=v+1|0;B=(e[w+14>>1]<<19>>19)-(z>>19)|0;C=(B&8192|0)!=0?B|-1024:B&1023;B=b[w+2>>1]|0;D=((a[1044414]|0)==0?A:A^255)&255;A=(ab(D,B)|0)&-64;E=A+(y>>11)+((ab(C,B)|0)&-64)|0;B=b[w+6>>1]|0;A=(ab(B,D)|0)&-64;D=A+(z>>11)+((ab(C,B)|0)&-64)|0;B=b[w>>1]|0;if((a[1044413]|0)==0){C=b[w+4>>1]|0;F=B;G=C<<16>>16;H=q;I=C}else{C=b[w+4>>1]|0;F=-B|0;G=-(C<<16>>16)|0;H=o;I=C}C=k-(y>>19)|0;y=(C&8192|0)!=0?C|-1024:C&1023;C=ab(H,B)|0;k=C+((ab(B,y)|0)&-64)|0;B=I<<16>>16;C=ab(B,H)|0;z=((ab(B,y)|0)&-64)+C|0;do{if((a[1044415]|0)==0){if(!j){break}C=(n|0)>=(x|0);y=k;B=z;A=1;J=q;while(1){K=A-1&255;do{if(K<<24>>24==0){L=y+E|0;M=(B+D|0)>>>8;N=a[i+(M<<4&112|L>>>8<<1&14|d[(c[263194]|0)+(M<<5&32512|L>>>10&254)|0]<<7|1)|0]|0;if(N<<24>>24==0|C){O=l;break}L=m+J|0;M=(L|0)<(J|0);P=N&255;N=n;while(1){if(!M){Q=L;do{R=(Q<<1)+t|0;S=(ab(c[277223]|0,N)|0)+R|0;if((Q|0)>=(f|0)&(p|0)>(d[(c[277219]|0)+S|0]|0)&(Q|0)<(g|0)){b[(c[277218]|0)+(S<<1)>>1]=b[(c[277225]|0)+(P<<1)>>1]|0;S=(a[1108928]|0)==0;T=ab(c[277223]|0,N)|0;if(S){U=b[(c[277213]|0)+(R+2+T<<1)>>1]|0}else{U=0}S=R+1|0;b[(c[277218]|0)+(T+S<<1)>>1]=U;T=(ab(c[277223]|0,N)|0)+S|0;a[(c[277219]|0)+T|0]=h;T=(ab(c[277223]|0,N)|0)+R|0;a[(c[277219]|0)+T|0]=h}Q=Q-1|0;}while((Q|0)>=(J|0))}Q=N+1|0;if((Q|0)<(x|0)){N=Q}else{O=l;break}}}else{O=K}}while(0);K=J+1|0;if((K|0)<(r|0)){y=y+F|0;B=B+G|0;A=O;J=K}else{break}}}else{if(!j){break}J=(n|0)>=(x|0);A=k;B=z;y=1;C=q;while(1){K=y-1&255;do{if(K<<24>>24==0){N=A+E|0;P=N>>8;L=B+D>>8;if((P|L)>>>0<1024){V=P<<1&14|L<<4&112|d[(c[263194]|0)+((L<<5&-256)+(N>>10&-2))|0]<<7}else{if((a[1044415]|0)!=3){W=l;break}V=P<<1&14|L<<4&112}L=a[i+(V|1)|0]|0;if(L<<24>>24==0|J){W=l;break}P=m+C|0;N=(P|0)<(C|0);M=L&255;L=n;while(1){if(!N){Q=P;do{T=(Q<<1)+t|0;R=(ab(c[277223]|0,L)|0)+T|0;if((Q|0)>=(f|0)&(p|0)>(d[(c[277219]|0)+R|0]|0)&(Q|0)<(g|0)){b[(c[277218]|0)+(R<<1)>>1]=b[(c[277225]|0)+(M<<1)>>1]|0;R=(a[1108928]|0)==0;S=ab(c[277223]|0,L)|0;if(R){X=b[(c[277213]|0)+(T+2+S<<1)>>1]|0}else{X=0}R=T+1|0;b[(c[277218]|0)+(S+R<<1)>>1]=X;S=(ab(c[277223]|0,L)|0)+R|0;a[(c[277219]|0)+S|0]=h;S=(ab(c[277223]|0,L)|0)+T|0;a[(c[277219]|0)+S|0]=h}Q=Q-1|0;}while((Q|0)>=(C|0))}Q=L+1|0;if((Q|0)<(x|0)){L=Q}else{W=l;break}}}else{W=K}}while(0);K=C+1|0;if((K|0)<(r|0)){A=A+F|0;B=B+G|0;y=W;C=K}else{break}}}}while(0);D=x+v|0;E=(ab(c[277223]|0,x)|0)+t|0;z=c[277231]|0;if(D>>>0>z>>>0){break}else{n=0;s=x;t=E;v=D;w=w+(x<<4)|0;u=z}}return}function V8(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0;i=c[263194]|0;do{if((a[(c[263195]|0)+8496|0]&1)==0){j=1106168}else{if((a[1106089]|0)==0){j=1125528;break}k=d[1044485]|0;c[276541]=7080+(k<<5);l=0;do{m=l<<1&2;n=l&2;o=l&4;p=0;do{b[1125528+(l<<9)+(p<<1)>>1]=d[(p>>>1&28|n)+(7080+(k<<5))|0]<<6|d[(p<<2&28|m)+(7080+(k<<5))|0]<<11|d[(p>>>3&24|o)+(7080+(k<<5))|0];p=p+1|0;}while(p>>>0<256);l=l+1|0;}while(l>>>0<8);a[1106089]=0;j=1125528}}while(0);c[277226]=j;c[277225]=(a[1108928]|0)!=0?1393712:j;j=c[277230]|0;if((a[1044434]|0)==0){q=f;r=g;s=0;t=1;u=j}else{l=d[1044432]|0;k=((j-(d[1044433]|0)|0)>>>0)%(l>>>0)|0;p=g-1+l|0;q=f-((f|0)%(l|0)|0)|0;r=p-((p|0)%(l|0)|0)|0;s=k;t=l;u=j-k|0}k=c[277231]|0;if(u>>>0>k>>>0){return}j=(q|0)<(r|0);l=t&255;p=h+7|0;h=p&255;o=r-1|0;m=t-1|0;n=s;s=t;t=ab(c[277223]|0,u)|0;v=u;w=1097960+(u<<4)|0;u=k;while(1){if((s+v|0)>>>0>u>>>0){x=u+1-v|0}else{x=s}k=e[w+12>>1]<<19>>19;y=e[w+8>>1]<<19;z=e[w+10>>1]<<19;A=v+1|0;B=(e[w+14>>1]<<19>>19)-(z>>19)|0;C=(B&8192|0)!=0?B|-1024:B&1023;B=b[w+2>>1]|0;D=((a[1044414]|0)==0?A:A^255)&255;A=(ab(D,B)|0)&-64;E=A+(y>>11)+((ab(C,B)|0)&-64)|0;B=b[w+6>>1]|0;A=(ab(B,D)|0)&-64;D=A+(z>>11)+((ab(C,B)|0)&-64)|0;B=b[w>>1]|0;if((a[1044413]|0)==0){C=b[w+4>>1]|0;F=B;G=C<<16>>16;H=q;I=C}else{C=b[w+4>>1]|0;F=-B|0;G=-(C<<16>>16)|0;H=o;I=C}C=k-(y>>19)|0;y=(C&8192|0)!=0?C|-1024:C&1023;C=ab(H,B)|0;k=C+((ab(B,y)|0)&-64)|0;B=I<<16>>16;C=ab(B,H)|0;z=((ab(B,y)|0)&-64)+C|0;do{if((a[1044415]|0)==0){if(!j){break}C=(n|0)>=(x|0);y=k;B=z;A=1;J=q;while(1){K=A-1&255;do{if(K<<24>>24==0){L=y+E|0;M=(B+D|0)>>>8;N=a[i+(M<<4&112|L>>>8<<1&14|d[(c[263194]|0)+(M<<5&32512|L>>>10&254)|0]<<7|1)|0]|0;if(N<<24>>24==0|C){O=l;break}L=m+J|0;M=(L|0)<(J|0);P=N&255;N=n;while(1){if(!M){Q=L;do{R=(Q<<1)+t|0;S=(ab(c[277223]|0,N)|0)+R|0;if((Q|0)>=(f|0)&(p|0)>(d[(c[277219]|0)+S|0]|0)&(Q|0)<(g|0)){T=e[(c[277225]|0)+(P<<1)>>1]|0;U=(a[(c[277215]|0)+S|0]&32)==0;if(U){V=c[277228]|0;W=V;X=V&-2082}else{V=e[(c[277213]|0)+(S<<1)>>1]|0;W=V;X=V&63454}if(U){Y=c[277228]|0}else{Y=e[(c[277213]|0)+(S<<1)>>1]|0}b[(c[277218]|0)+(S<<1)>>1]=((Y^T)&2081|e[(c[277220]|0)+((T&2081&W)+((X+(T&63454)|0)>>>1)<<1)>>1])&65535;T=(a[1108928]|0)==0;S=ab(c[277223]|0,N)|0;if(T){Z=b[(c[277213]|0)+(R+2+S<<1)>>1]&63454}else{Z=0}U=(a[(c[277215]|0)+(S+R)|0]&32)==0;if(U){_=c[277228]|0}else{_=e[(c[277226]|0)+(P<<1)>>1]|0}if(T){$=b[(c[277213]|0)+(R+2+S<<1)>>1]&2081}else{$=0}if(U){aa=c[277228]|0}else{aa=e[(c[277226]|0)+(P<<1)>>1]|0}if(T){ac=e[(c[277213]|0)+(R+2+S<<1)>>1]|0}else{ac=0}if(U){ad=c[277228]|0}else{ad=e[(c[277226]|0)+(P<<1)>>1]|0}U=R+1|0;b[(c[277218]|0)+(S+U<<1)>>1]=((ad^ac)&2081|e[(c[277220]|0)+((aa&$)+(((_&-2082)+Z|0)>>>1)<<1)>>1])&65535;S=(ab(c[277223]|0,N)|0)+U|0;a[(c[277219]|0)+S|0]=h;S=(ab(c[277223]|0,N)|0)+R|0;a[(c[277219]|0)+S|0]=h}Q=Q-1|0;}while((Q|0)>=(J|0))}Q=N+1|0;if((Q|0)<(x|0)){N=Q}else{O=l;break}}}else{O=K}}while(0);K=J+1|0;if((K|0)<(r|0)){y=y+F|0;B=B+G|0;A=O;J=K}else{break}}}else{if(!j){break}J=(n|0)>=(x|0);A=k;B=z;y=1;C=q;while(1){K=y-1&255;do{if(K<<24>>24==0){N=A+E|0;P=N>>8;L=B+D>>8;if((P|L)>>>0<1024){ae=P<<1&14|L<<4&112|d[(c[263194]|0)+((L<<5&-256)+(N>>10&-2))|0]<<7}else{if((a[1044415]|0)!=3){af=l;break}ae=P<<1&14|L<<4&112}L=a[i+(ae|1)|0]|0;if(L<<24>>24==0|J){af=l;break}P=m+C|0;N=(P|0)<(C|0);M=L&255;L=n;while(1){if(!N){Q=P;do{S=(Q<<1)+t|0;R=(ab(c[277223]|0,L)|0)+S|0;if((Q|0)>=(f|0)&(p|0)>(d[(c[277219]|0)+R|0]|0)&(Q|0)<(g|0)){U=e[(c[277225]|0)+(M<<1)>>1]|0;T=(a[(c[277215]|0)+R|0]&32)==0;if(T){V=c[277228]|0;ag=V;ah=V&-2082}else{V=e[(c[277213]|0)+(R<<1)>>1]|0;ag=V;ah=V&63454}if(T){ai=c[277228]|0}else{ai=e[(c[277213]|0)+(R<<1)>>1]|0}b[(c[277218]|0)+(R<<1)>>1]=((ai^U)&2081|e[(c[277220]|0)+((U&2081&ag)+((ah+(U&63454)|0)>>>1)<<1)>>1])&65535;U=(a[1108928]|0)==0;R=ab(c[277223]|0,L)|0;if(U){aj=b[(c[277213]|0)+(S+2+R<<1)>>1]&63454}else{aj=0}T=(a[(c[277215]|0)+(R+S)|0]&32)==0;if(T){ak=c[277228]|0}else{ak=e[(c[277226]|0)+(M<<1)>>1]|0}if(U){al=b[(c[277213]|0)+(S+2+R<<1)>>1]&2081}else{al=0}if(T){am=c[277228]|0}else{am=e[(c[277226]|0)+(M<<1)>>1]|0}if(U){an=e[(c[277213]|0)+(S+2+R<<1)>>1]|0}else{an=0}if(T){ao=c[277228]|0}else{ao=e[(c[277226]|0)+(M<<1)>>1]|0}T=S+1|0;b[(c[277218]|0)+(R+T<<1)>>1]=((ao^an)&2081|e[(c[277220]|0)+((am&al)+(((ak&-2082)+aj|0)>>>1)<<1)>>1])&65535;R=(ab(c[277223]|0,L)|0)+T|0;a[(c[277219]|0)+R|0]=h;R=(ab(c[277223]|0,L)|0)+S|0;a[(c[277219]|0)+R|0]=h}Q=Q-1|0;}while((Q|0)>=(C|0))}Q=L+1|0;if((Q|0)<(x|0)){L=Q}else{af=l;break}}}else{af=K}}while(0);K=C+1|0;if((K|0)<(r|0)){A=A+F|0;B=B+G|0;y=af;C=K}else{break}}}}while(0);D=x+v|0;E=(ab(c[277223]|0,x)|0)+t|0;z=c[277231]|0;if(D>>>0>z>>>0){break}else{n=0;s=x;t=E;v=D;w=w+(x<<4)|0;u=z}}return}function V9(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ac=0;i=c[263194]|0;do{if((a[(c[263195]|0)+8496|0]&1)==0){j=1106168}else{if((a[1106089]|0)==0){j=1125528;break}k=d[1044485]|0;c[276541]=7080+(k<<5);l=0;do{m=l<<1&2;n=l&2;o=l&4;p=0;do{b[1125528+(l<<9)+(p<<1)>>1]=d[(p>>>1&28|n)+(7080+(k<<5))|0]<<6|d[(p<<2&28|m)+(7080+(k<<5))|0]<<11|d[(p>>>3&24|o)+(7080+(k<<5))|0];p=p+1|0;}while(p>>>0<256);l=l+1|0;}while(l>>>0<8);a[1106089]=0;j=1125528}}while(0);c[277226]=j;c[277225]=(a[1108928]|0)!=0?1393712:j;j=c[277230]|0;if((a[1044434]|0)==0){q=f;r=g;s=0;t=1;u=j}else{l=d[1044432]|0;k=((j-(d[1044433]|0)|0)>>>0)%(l>>>0)|0;p=g-1+l|0;q=f-((f|0)%(l|0)|0)|0;r=p-((p|0)%(l|0)|0)|0;s=k;t=l;u=j-k|0}k=c[277231]|0;if(u>>>0>k>>>0){return}j=(q|0)<(r|0);l=t&255;p=h+7|0;h=p&255;o=r-1|0;m=t-1|0;n=s;s=t;t=ab(c[277223]|0,u)|0;v=u;w=1097960+(u<<4)|0;u=k;while(1){if((s+v|0)>>>0>u>>>0){x=u+1-v|0}else{x=s}k=e[w+12>>1]<<19>>19;y=e[w+8>>1]<<19;z=e[w+10>>1]<<19;A=v+1|0;B=(e[w+14>>1]<<19>>19)-(z>>19)|0;C=(B&8192|0)!=0?B|-1024:B&1023;B=b[w+2>>1]|0;D=((a[1044414]|0)==0?A:A^255)&255;A=(ab(D,B)|0)&-64;E=A+(y>>11)+((ab(C,B)|0)&-64)|0;B=b[w+6>>1]|0;A=(ab(B,D)|0)&-64;D=A+(z>>11)+((ab(C,B)|0)&-64)|0;B=b[w>>1]|0;if((a[1044413]|0)==0){C=b[w+4>>1]|0;F=B;G=C<<16>>16;H=q;I=C}else{C=b[w+4>>1]|0;F=-B|0;G=-(C<<16>>16)|0;H=o;I=C}C=k-(y>>19)|0;y=(C&8192|0)!=0?C|-1024:C&1023;C=ab(H,B)|0;k=C+((ab(B,y)|0)&-64)|0;B=I<<16>>16;C=ab(B,H)|0;z=((ab(B,y)|0)&-64)+C|0;do{if((a[1044415]|0)==0){if(!j){break}C=(n|0)>=(x|0);y=k;B=z;A=1;J=q;while(1){K=A-1&255;do{if(K<<24>>24==0){L=y+E|0;M=(B+D|0)>>>8;N=a[i+(M<<4&112|L>>>8<<1&14|d[(c[263194]|0)+(M<<5&32512|L>>>10&254)|0]<<7|1)|0]|0;if(N<<24>>24==0|C){O=l;break}L=m+J|0;M=(L|0)<(J|0);P=N&255;N=n;while(1){if(!M){Q=L;do{R=(Q<<1)+t|0;S=(ab(c[277223]|0,N)|0)+R|0;if((Q|0)>=(f|0)&(p|0)>(d[(c[277219]|0)+S|0]|0)&(Q|0)<(g|0)){T=e[(c[277225]|0)+(P<<1)>>1]|0;U=c[277228]|0;V=(((T&63454)+(U&-2082)|0)>>>1)+(U&2081&T)|0;if((a[1108928]|0)==0){W=V&65535}else{W=(e[(c[277220]|0)+(V<<1)>>1]|(T^U)&2081)&65535}b[(c[277218]|0)+(S<<1)>>1]=W;if((a[1108928]|0)==0){S=c[277223]|0;U=R+2+(ab(S,N)|0)|0;T=e[(c[277213]|0)+(U<<1)>>1]|0;U=c[277228]|0;X=S;Y=(((T&63454)+(U&128990)|0)>>>1)+(U&2081&T)|0}else{T=c[277228]|0;X=c[277223]|0;Y=e[(c[277220]|0)+((T>>>1&2147482607)<<1)>>1]|T&2081}T=R+1|0;U=(ab(X,N)|0)+T|0;b[(c[277218]|0)+(U<<1)>>1]=Y&65535;U=(ab(c[277223]|0,N)|0)+T|0;a[(c[277219]|0)+U|0]=h;U=(ab(c[277223]|0,N)|0)+R|0;a[(c[277219]|0)+U|0]=h}Q=Q-1|0;}while((Q|0)>=(J|0))}Q=N+1|0;if((Q|0)<(x|0)){N=Q}else{O=l;break}}}else{O=K}}while(0);K=J+1|0;if((K|0)<(r|0)){y=y+F|0;B=B+G|0;A=O;J=K}else{break}}}else{if(!j){break}J=(n|0)>=(x|0);A=k;B=z;y=1;C=q;while(1){K=y-1&255;do{if(K<<24>>24==0){N=A+E|0;P=N>>8;L=B+D>>8;if((P|L)>>>0<1024){Z=P<<1&14|L<<4&112|d[(c[263194]|0)+((L<<5&-256)+(N>>10&-2))|0]<<7}else{if((a[1044415]|0)!=3){_=l;break}Z=P<<1&14|L<<4&112}L=a[i+(Z|1)|0]|0;if(L<<24>>24==0|J){_=l;break}P=m+C|0;N=(P|0)<(C|0);M=L&255;L=n;while(1){if(!N){Q=P;do{U=(Q<<1)+t|0;R=(ab(c[277223]|0,L)|0)+U|0;if((Q|0)>=(f|0)&(p|0)>(d[(c[277219]|0)+R|0]|0)&(Q|0)<(g|0)){T=e[(c[277225]|0)+(M<<1)>>1]|0;S=c[277228]|0;V=(((T&63454)+(S&-2082)|0)>>>1)+(S&2081&T)|0;if((a[1108928]|0)==0){$=V&65535}else{$=(e[(c[277220]|0)+(V<<1)>>1]|(T^S)&2081)&65535}b[(c[277218]|0)+(R<<1)>>1]=$;if((a[1108928]|0)==0){R=c[277223]|0;S=U+2+(ab(R,L)|0)|0;T=e[(c[277213]|0)+(S<<1)>>1]|0;S=c[277228]|0;aa=R;ac=(((T&63454)+(S&128990)|0)>>>1)+(S&2081&T)|0}else{T=c[277228]|0;aa=c[277223]|0;ac=e[(c[277220]|0)+((T>>>1&2147482607)<<1)>>1]|T&2081}T=U+1|0;S=(ab(aa,L)|0)+T|0;b[(c[277218]|0)+(S<<1)>>1]=ac&65535;S=(ab(c[277223]|0,L)|0)+T|0;a[(c[277219]|0)+S|0]=h;S=(ab(c[277223]|0,L)|0)+U|0;a[(c[277219]|0)+S|0]=h}Q=Q-1|0;}while((Q|0)>=(C|0))}Q=L+1|0;if((Q|0)<(x|0)){L=Q}else{_=l;break}}}else{_=K}}while(0);K=C+1|0;if((K|0)<(r|0)){A=A+F|0;B=B+G|0;y=_;C=K}else{break}}}}while(0);D=x+v|0;E=(ab(c[277223]|0,x)|0)+t|0;z=c[277231]|0;if(D>>>0>z>>>0){break}else{n=0;s=x;t=E;v=D;w=w+(x<<4)|0;u=z}}return}function Wa(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0;i=c[263194]|0;do{if((a[(c[263195]|0)+8496|0]&1)==0){j=1106168}else{if((a[1106089]|0)==0){j=1125528;break}k=d[1044485]|0;c[276541]=7080+(k<<5);l=0;do{m=l<<1&2;n=l&2;o=l&4;p=0;do{b[1125528+(l<<9)+(p<<1)>>1]=d[(p>>>1&28|n)+(7080+(k<<5))|0]<<6|d[(p<<2&28|m)+(7080+(k<<5))|0]<<11|d[(p>>>3&24|o)+(7080+(k<<5))|0];p=p+1|0;}while(p>>>0<256);l=l+1|0;}while(l>>>0<8);a[1106089]=0;j=1125528}}while(0);c[277226]=j;c[277225]=(a[1108928]|0)!=0?1393712:j;j=c[277230]|0;if((a[1044434]|0)==0){q=f;r=g;s=0;t=1;u=j}else{l=d[1044432]|0;k=((j-(d[1044433]|0)|0)>>>0)%(l>>>0)|0;p=g-1+l|0;q=f-((f|0)%(l|0)|0)|0;r=p-((p|0)%(l|0)|0)|0;s=k;t=l;u=j-k|0}k=c[277231]|0;if(u>>>0>k>>>0){return}j=(q|0)<(r|0);l=t&255;p=h+7|0;h=p&255;o=r-1|0;m=t-1|0;n=s;s=t;t=ab(c[277223]|0,u)|0;v=u;w=1097960+(u<<4)|0;u=k;while(1){if((s+v|0)>>>0>u>>>0){x=u+1-v|0}else{x=s}k=e[w+12>>1]<<19>>19;y=e[w+8>>1]<<19;z=e[w+10>>1]<<19;A=v+1|0;B=(e[w+14>>1]<<19>>19)-(z>>19)|0;C=(B&8192|0)!=0?B|-1024:B&1023;B=b[w+2>>1]|0;D=((a[1044414]|0)==0?A:A^255)&255;A=(ab(D,B)|0)&-64;E=A+(y>>11)+((ab(C,B)|0)&-64)|0;B=b[w+6>>1]|0;A=(ab(B,D)|0)&-64;D=A+(z>>11)+((ab(C,B)|0)&-64)|0;B=b[w>>1]|0;if((a[1044413]|0)==0){C=b[w+4>>1]|0;F=B;G=C<<16>>16;H=q;I=C}else{C=b[w+4>>1]|0;F=-B|0;G=-(C<<16>>16)|0;H=o;I=C}C=k-(y>>19)|0;y=(C&8192|0)!=0?C|-1024:C&1023;C=ab(H,B)|0;k=C+((ab(B,y)|0)&-64)|0;B=I<<16>>16;C=ab(B,H)|0;z=((ab(B,y)|0)&-64)+C|0;do{if((a[1044415]|0)==0){if(!j){break}C=(n|0)>=(x|0);y=k;B=z;A=1;J=q;while(1){K=A-1&255;do{if(K<<24>>24==0){L=y+E|0;M=(B+D|0)>>>8;N=a[i+(M<<4&112|L>>>8<<1&14|d[(c[263194]|0)+(M<<5&32512|L>>>10&254)|0]<<7|1)|0]|0;if(N<<24>>24==0|C){O=l;break}L=m+J|0;M=(L|0)<(J|0);P=N&255;N=n;while(1){if(!M){Q=L;do{R=(Q<<1)+t|0;S=(ab(c[277223]|0,N)|0)+R|0;if((Q|0)>=(f|0)&(p|0)>(d[(c[277219]|0)+S|0]|0)&(Q|0)<(g|0)){do{if((a[1108928]|0)==0){T=b[(c[277225]|0)+(P<<1)>>1]|0;U=T&65535;V=U&63454;if((a[(c[277215]|0)+S|0]&32)==0){W=c[277228]|0;X=(e[(c[277220]|0)+((((W&-2082)+V|0)>>>1)+(U&2081&W)<<1)>>1]|(W^U)&2081)&65535;break}else{U=b[(c[277213]|0)+(S<<1)>>1]|0;X=(((U&63454)+V|0)>>>1)+(U&T&2081)&65535;break}}else{T=e[(c[277225]|0)+(P<<1)>>1]|0;U=(a[(c[277215]|0)+S|0]&32)==0;if(U){V=c[277228]|0;Y=V;Z=V&-2082}else{V=e[(c[277213]|0)+(S<<1)>>1]|0;Y=V;Z=V&63454}if(U){_=c[277228]|0}else{_=e[(c[277213]|0)+(S<<1)>>1]|0}X=((_^T)&2081|e[(c[277220]|0)+((T&2081&Y)+((Z+(T&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(S<<1)>>1]=X;T=(a[1108928]|0)==0;U=ab(c[277223]|0,N)|0;V=U+R|0;W=(a[(c[277215]|0)+V|0]&32)==0;do{if(T){$=c[277213]|0;aa=b[$+(V+2<<1)>>1]&63454;if(W){ac=c[277228]|0;ad=e[$+(R+2+U<<1)>>1]|0;ae=((ad^ac)&2081|e[(c[277220]|0)+((ac&2081&ad)+(((ac&-2082)+aa|0)>>>1)<<1)>>1])&65535;break}else{ac=e[(c[277226]|0)+(P<<1)>>1]|0;ae=(((ac&63454)+aa|0)>>>1)+(ac&2081&e[$+(R+2+U<<1)>>1])&65535;break}}else{if(W){$=c[277228]|0;af=$;ag=(c[277220]|0)+(($>>>1&2147482607)<<1)|0}else{$=e[(c[277226]|0)+(P<<1)>>1]|0;af=$;ag=(c[277220]|0)+(($>>>1&31727)<<1)|0}ae=(e[ag>>1]|af&2081)&65535}}while(0);W=R+1|0;b[(c[277218]|0)+(U+W<<1)>>1]=ae;V=(ab(c[277223]|0,N)|0)+W|0;a[(c[277219]|0)+V|0]=h;V=(ab(c[277223]|0,N)|0)+R|0;a[(c[277219]|0)+V|0]=h}Q=Q-1|0;}while((Q|0)>=(J|0))}Q=N+1|0;if((Q|0)<(x|0)){N=Q}else{O=l;break}}}else{O=K}}while(0);K=J+1|0;if((K|0)<(r|0)){y=y+F|0;B=B+G|0;A=O;J=K}else{break}}}else{if(!j){break}J=(n|0)>=(x|0);A=k;B=z;y=1;C=q;while(1){K=y-1&255;do{if(K<<24>>24==0){N=A+E|0;P=N>>8;L=B+D>>8;if((P|L)>>>0<1024){ah=P<<1&14|L<<4&112|d[(c[263194]|0)+((L<<5&-256)+(N>>10&-2))|0]<<7}else{if((a[1044415]|0)!=3){ai=l;break}ah=P<<1&14|L<<4&112}L=a[i+(ah|1)|0]|0;if(L<<24>>24==0|J){ai=l;break}P=m+C|0;N=(P|0)<(C|0);M=L&255;L=n;while(1){if(!N){Q=P;do{V=(Q<<1)+t|0;W=(ab(c[277223]|0,L)|0)+V|0;if((Q|0)>=(f|0)&(p|0)>(d[(c[277219]|0)+W|0]|0)&(Q|0)<(g|0)){do{if((a[1108928]|0)==0){T=b[(c[277225]|0)+(M<<1)>>1]|0;S=T&65535;$=S&63454;if((a[(c[277215]|0)+W|0]&32)==0){ac=c[277228]|0;aj=(e[(c[277220]|0)+((((ac&-2082)+$|0)>>>1)+(S&2081&ac)<<1)>>1]|(ac^S)&2081)&65535;break}else{S=b[(c[277213]|0)+(W<<1)>>1]|0;aj=(((S&63454)+$|0)>>>1)+(S&T&2081)&65535;break}}else{T=e[(c[277225]|0)+(M<<1)>>1]|0;S=(a[(c[277215]|0)+W|0]&32)==0;if(S){$=c[277228]|0;ak=$;al=$&-2082}else{$=e[(c[277213]|0)+(W<<1)>>1]|0;ak=$;al=$&63454}if(S){am=c[277228]|0}else{am=e[(c[277213]|0)+(W<<1)>>1]|0}aj=((am^T)&2081|e[(c[277220]|0)+((T&2081&ak)+((al+(T&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(W<<1)>>1]=aj;R=(a[1108928]|0)==0;U=ab(c[277223]|0,L)|0;T=U+V|0;S=(a[(c[277215]|0)+T|0]&32)==0;do{if(R){$=c[277213]|0;ac=b[$+(T+2<<1)>>1]&63454;if(S){aa=c[277228]|0;ad=e[$+(V+2+U<<1)>>1]|0;an=((ad^aa)&2081|e[(c[277220]|0)+((aa&2081&ad)+(((aa&-2082)+ac|0)>>>1)<<1)>>1])&65535;break}else{aa=e[(c[277226]|0)+(M<<1)>>1]|0;an=(((aa&63454)+ac|0)>>>1)+(aa&2081&e[$+(V+2+U<<1)>>1])&65535;break}}else{if(S){$=c[277228]|0;ao=$;ap=(c[277220]|0)+(($>>>1&2147482607)<<1)|0}else{$=e[(c[277226]|0)+(M<<1)>>1]|0;ao=$;ap=(c[277220]|0)+(($>>>1&31727)<<1)|0}an=(e[ap>>1]|ao&2081)&65535}}while(0);S=V+1|0;b[(c[277218]|0)+(U+S<<1)>>1]=an;T=(ab(c[277223]|0,L)|0)+S|0;a[(c[277219]|0)+T|0]=h;T=(ab(c[277223]|0,L)|0)+V|0;a[(c[277219]|0)+T|0]=h}Q=Q-1|0;}while((Q|0)>=(C|0))}Q=L+1|0;if((Q|0)<(x|0)){L=Q}else{ai=l;break}}}else{ai=K}}while(0);K=C+1|0;if((K|0)<(r|0)){A=A+F|0;B=B+G|0;y=ai;C=K}else{break}}}}while(0);D=x+v|0;E=(ab(c[277223]|0,x)|0)+t|0;z=c[277231]|0;if(D>>>0>z>>>0){break}else{n=0;s=x;t=E;v=D;w=w+(x<<4)|0;u=z}}return}function Wb(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0;i=c[263194]|0;do{if((a[(c[263195]|0)+8496|0]&1)==0){j=1106168}else{if((a[1106089]|0)==0){j=1125528;break}k=d[1044485]|0;c[276541]=7080+(k<<5);l=0;do{m=l<<1&2;n=l&2;o=l&4;p=0;do{b[1125528+(l<<9)+(p<<1)>>1]=d[(p>>>1&28|n)+(7080+(k<<5))|0]<<6|d[(p<<2&28|m)+(7080+(k<<5))|0]<<11|d[(p>>>3&24|o)+(7080+(k<<5))|0];p=p+1|0;}while(p>>>0<256);l=l+1|0;}while(l>>>0<8);a[1106089]=0;j=1125528}}while(0);c[277226]=j;c[277225]=(a[1108928]|0)!=0?1393712:j;j=c[277230]|0;if((a[1044434]|0)==0){q=f;r=g;s=0;t=1;u=j}else{l=d[1044432]|0;k=((j-(d[1044433]|0)|0)>>>0)%(l>>>0)|0;p=g-1+l|0;q=f-((f|0)%(l|0)|0)|0;r=p-((p|0)%(l|0)|0)|0;s=k;t=l;u=j-k|0}k=c[277231]|0;if(u>>>0>k>>>0){return}j=(q|0)<(r|0);l=t&255;p=h+7|0;h=p&255;o=r-1|0;m=t-1|0;n=s;s=t;t=ab(c[277223]|0,u)|0;v=u;w=1097960+(u<<4)|0;u=k;while(1){if((s+v|0)>>>0>u>>>0){x=u+1-v|0}else{x=s}k=e[w+12>>1]<<19>>19;y=e[w+8>>1]<<19;z=e[w+10>>1]<<19;A=v+1|0;B=(e[w+14>>1]<<19>>19)-(z>>19)|0;C=(B&8192|0)!=0?B|-1024:B&1023;B=b[w+2>>1]|0;D=((a[1044414]|0)==0?A:A^255)&255;A=(ab(D,B)|0)&-64;E=A+(y>>11)+((ab(C,B)|0)&-64)|0;B=b[w+6>>1]|0;A=(ab(B,D)|0)&-64;D=A+(z>>11)+((ab(C,B)|0)&-64)|0;B=b[w>>1]|0;if((a[1044413]|0)==0){C=b[w+4>>1]|0;F=B;G=C<<16>>16;H=q;I=C}else{C=b[w+4>>1]|0;F=-B|0;G=-(C<<16>>16)|0;H=o;I=C}C=k-(y>>19)|0;y=(C&8192|0)!=0?C|-1024:C&1023;C=ab(H,B)|0;k=C+((ab(B,y)|0)&-64)|0;B=I<<16>>16;C=ab(B,H)|0;z=((ab(B,y)|0)&-64)+C|0;do{if((a[1044415]|0)==0){if(!j){break}C=(n|0)>=(x|0);y=k;B=z;A=1;J=q;while(1){K=A-1&255;do{if(K<<24>>24==0){L=y+E|0;M=(B+D|0)>>>8;N=a[i+(M<<4&112|L>>>8<<1&14|d[(c[263194]|0)+(M<<5&32512|L>>>10&254)|0]<<7|1)|0]|0;if(N<<24>>24==0|C){O=l;break}L=m+J|0;M=(L|0)<(J|0);P=N&255;N=n;while(1){if(!M){Q=L;do{R=(Q<<1)+t|0;S=(ab(c[277223]|0,N)|0)+R|0;if((Q|0)>=(f|0)&(p|0)>(d[(c[277219]|0)+S|0]|0)&(Q|0)<(g|0)){T=b[(c[277225]|0)+(P<<1)>>1]|0;if((a[(c[277215]|0)+S|0]&32)==0){U=c[277228]&65535}else{U=b[(c[277213]|0)+(S<<1)>>1]|0}V=T&-2048;W=U&-2048;X=(V&65535)>(W&65535)?V-W&65535:0;W=T&2016;V=U&2016;if((W&65535)>(V&65535)){Y=(W-V&65535)+X&65535}else{Y=X}X=T&31;T=U&31;if((X&65535)>(T&65535)){Z=(X-T&65535)+Y&65535}else{Z=Y}b[(c[277218]|0)+(S<<1)>>1]=Z;S=(a[1108928]|0)==0;T=ab(c[277223]|0,N)|0;if(S){_=b[(c[277213]|0)+(R+2+T<<1)>>1]|0}else{_=0}if((a[(c[277215]|0)+(T+R)|0]&32)==0){$=c[277228]&65535}else{$=b[(c[277226]|0)+(P<<1)>>1]|0}S=_&-2048;X=$&-2048;V=(S&65535)>(X&65535)?S-X&65535:0;X=_&2016;S=$&2016;if((X&65535)>(S&65535)){aa=(X-S&65535)+V&65535}else{aa=V}V=_&31;S=$&31;if((V&65535)>(S&65535)){ac=(V-S&65535)+aa&65535}else{ac=aa}S=R+1|0;b[(c[277218]|0)+(T+S<<1)>>1]=ac;T=(ab(c[277223]|0,N)|0)+S|0;a[(c[277219]|0)+T|0]=h;T=(ab(c[277223]|0,N)|0)+R|0;a[(c[277219]|0)+T|0]=h}Q=Q-1|0;}while((Q|0)>=(J|0))}Q=N+1|0;if((Q|0)<(x|0)){N=Q}else{O=l;break}}}else{O=K}}while(0);K=J+1|0;if((K|0)<(r|0)){y=y+F|0;B=B+G|0;A=O;J=K}else{break}}}else{if(!j){break}J=(n|0)>=(x|0);A=k;B=z;y=1;C=q;while(1){K=y-1&255;do{if(K<<24>>24==0){N=A+E|0;P=N>>8;L=B+D>>8;if((P|L)>>>0<1024){ad=P<<1&14|L<<4&112|d[(c[263194]|0)+((L<<5&-256)+(N>>10&-2))|0]<<7}else{if((a[1044415]|0)!=3){ae=l;break}ad=P<<1&14|L<<4&112}L=a[i+(ad|1)|0]|0;if(L<<24>>24==0|J){ae=l;break}P=m+C|0;N=(P|0)<(C|0);M=L&255;L=n;while(1){if(!N){Q=P;do{T=(Q<<1)+t|0;R=(ab(c[277223]|0,L)|0)+T|0;if((Q|0)>=(f|0)&(p|0)>(d[(c[277219]|0)+R|0]|0)&(Q|0)<(g|0)){S=b[(c[277225]|0)+(M<<1)>>1]|0;if((a[(c[277215]|0)+R|0]&32)==0){af=c[277228]&65535}else{af=b[(c[277213]|0)+(R<<1)>>1]|0}V=S&-2048;X=af&-2048;W=(V&65535)>(X&65535)?V-X&65535:0;X=S&2016;V=af&2016;if((X&65535)>(V&65535)){ag=(X-V&65535)+W&65535}else{ag=W}W=S&31;S=af&31;if((W&65535)>(S&65535)){ah=(W-S&65535)+ag&65535}else{ah=ag}b[(c[277218]|0)+(R<<1)>>1]=ah;R=(a[1108928]|0)==0;S=ab(c[277223]|0,L)|0;if(R){ai=b[(c[277213]|0)+(T+2+S<<1)>>1]|0}else{ai=0}if((a[(c[277215]|0)+(S+T)|0]&32)==0){aj=c[277228]&65535}else{aj=b[(c[277226]|0)+(M<<1)>>1]|0}R=ai&-2048;W=aj&-2048;V=(R&65535)>(W&65535)?R-W&65535:0;W=ai&2016;R=aj&2016;if((W&65535)>(R&65535)){ak=(W-R&65535)+V&65535}else{ak=V}V=ai&31;R=aj&31;if((V&65535)>(R&65535)){al=(V-R&65535)+ak&65535}else{al=ak}R=T+1|0;b[(c[277218]|0)+(S+R<<1)>>1]=al;S=(ab(c[277223]|0,L)|0)+R|0;a[(c[277219]|0)+S|0]=h;S=(ab(c[277223]|0,L)|0)+T|0;a[(c[277219]|0)+S|0]=h}Q=Q-1|0;}while((Q|0)>=(C|0))}Q=L+1|0;if((Q|0)<(x|0)){L=Q}else{ae=l;break}}}else{ae=K}}while(0);K=C+1|0;if((K|0)<(r|0)){A=A+F|0;B=B+G|0;y=ae;C=K}else{break}}}}while(0);D=x+v|0;E=(ab(c[277223]|0,x)|0)+t|0;z=c[277231]|0;if(D>>>0>z>>>0){break}else{n=0;s=x;t=E;v=D;w=w+(x<<4)|0;u=z}}return}function Wc(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ac=0,ad=0,ae=0,af=0,ag=0;i=c[263194]|0;do{if((a[(c[263195]|0)+8496|0]&1)==0){j=1106168}else{if((a[1106089]|0)==0){j=1125528;break}k=d[1044485]|0;c[276541]=7080+(k<<5);l=0;do{m=l<<1&2;n=l&2;o=l&4;p=0;do{b[1125528+(l<<9)+(p<<1)>>1]=d[(p>>>1&28|n)+(7080+(k<<5))|0]<<6|d[(p<<2&28|m)+(7080+(k<<5))|0]<<11|d[(p>>>3&24|o)+(7080+(k<<5))|0];p=p+1|0;}while(p>>>0<256);l=l+1|0;}while(l>>>0<8);a[1106089]=0;j=1125528}}while(0);c[277226]=j;c[277225]=(a[1108928]|0)!=0?1393712:j;j=c[277230]|0;if((a[1044434]|0)==0){q=f;r=g;s=0;t=1;u=j}else{l=d[1044432]|0;k=((j-(d[1044433]|0)|0)>>>0)%(l>>>0)|0;p=g-1+l|0;q=f-((f|0)%(l|0)|0)|0;r=p-((p|0)%(l|0)|0)|0;s=k;t=l;u=j-k|0}k=c[277231]|0;if(u>>>0>k>>>0){return}j=(q|0)<(r|0);l=t&255;p=h+7|0;h=p&255;o=r-1|0;m=t-1|0;n=s;s=t;t=ab(c[277223]|0,u)|0;v=u;w=1097960+(u<<4)|0;u=k;while(1){if((s+v|0)>>>0>u>>>0){x=u+1-v|0}else{x=s}k=e[w+12>>1]<<19>>19;y=e[w+8>>1]<<19;z=e[w+10>>1]<<19;A=v+1|0;B=(e[w+14>>1]<<19>>19)-(z>>19)|0;C=(B&8192|0)!=0?B|-1024:B&1023;B=b[w+2>>1]|0;D=((a[1044414]|0)==0?A:A^255)&255;A=(ab(D,B)|0)&-64;E=A+(y>>11)+((ab(C,B)|0)&-64)|0;B=b[w+6>>1]|0;A=(ab(B,D)|0)&-64;D=A+(z>>11)+((ab(C,B)|0)&-64)|0;B=b[w>>1]|0;if((a[1044413]|0)==0){C=b[w+4>>1]|0;F=B;G=C<<16>>16;H=q;I=C}else{C=b[w+4>>1]|0;F=-B|0;G=-(C<<16>>16)|0;H=o;I=C}C=k-(y>>19)|0;y=(C&8192|0)!=0?C|-1024:C&1023;C=ab(H,B)|0;k=C+((ab(B,y)|0)&-64)|0;B=I<<16>>16;C=ab(B,H)|0;z=((ab(B,y)|0)&-64)+C|0;do{if((a[1044415]|0)==0){if(!j){break}C=(n|0)>=(x|0);y=k;B=z;A=1;J=q;while(1){K=A-1&255;do{if(K<<24>>24==0){L=y+E|0;M=(B+D|0)>>>8;N=a[i+(M<<4&112|L>>>8<<1&14|d[(c[263194]|0)+(M<<5&32512|L>>>10&254)|0]<<7|1)|0]|0;if(N<<24>>24==0|C){O=l;break}L=m+J|0;M=(L|0)<(J|0);P=N&255;N=n;while(1){if(!M){Q=L;do{R=(Q<<1)+t|0;S=(ab(c[277223]|0,N)|0)+R|0;if((Q|0)>=(f|0)&(p|0)>(d[(c[277219]|0)+S|0]|0)&(Q|0)<(g|0)){T=b[(c[277225]|0)+(P<<1)>>1]|0;do{if((a[1108928]|0)==0){U=b[(c[277221]|0)+(((T&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{V=c[277228]&65535;W=T&-2048;X=V&-2048;Y=(W&65535)>(X&65535)?W-X&65535:0;X=T&2016;W=V&2016;if((X&65535)>(W&65535)){Z=(X-W&65535)+Y&65535}else{Z=Y}Y=T&31;W=V&31;if((Y&65535)<=(W&65535)){U=Z;break}U=(Y-W&65535)+Z&65535}}while(0);b[(c[277218]|0)+(S<<1)>>1]=U;T=(a[1108928]|0)==0;W=ab(c[277223]|0,N)|0;if(T){_=b[(c[277221]|0)+(((e[(c[277213]|0)+(R+2+W<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{_=0}T=R+1|0;b[(c[277218]|0)+(W+T<<1)>>1]=_;W=(ab(c[277223]|0,N)|0)+T|0;a[(c[277219]|0)+W|0]=h;W=(ab(c[277223]|0,N)|0)+R|0;a[(c[277219]|0)+W|0]=h}Q=Q-1|0;}while((Q|0)>=(J|0))}Q=N+1|0;if((Q|0)<(x|0)){N=Q}else{O=l;break}}}else{O=K}}while(0);K=J+1|0;if((K|0)<(r|0)){y=y+F|0;B=B+G|0;A=O;J=K}else{break}}}else{if(!j){break}J=(n|0)>=(x|0);A=k;B=z;y=1;C=q;while(1){K=y-1&255;do{if(K<<24>>24==0){N=A+E|0;P=N>>8;L=B+D>>8;if((P|L)>>>0<1024){$=P<<1&14|L<<4&112|d[(c[263194]|0)+((L<<5&-256)+(N>>10&-2))|0]<<7}else{if((a[1044415]|0)!=3){aa=l;break}$=P<<1&14|L<<4&112}L=a[i+($|1)|0]|0;if(L<<24>>24==0|J){aa=l;break}P=m+C|0;N=(P|0)<(C|0);M=L&255;L=n;while(1){if(!N){Q=P;do{W=(Q<<1)+t|0;T=(ab(c[277223]|0,L)|0)+W|0;if((Q|0)>=(f|0)&(p|0)>(d[(c[277219]|0)+T|0]|0)&(Q|0)<(g|0)){Y=b[(c[277225]|0)+(M<<1)>>1]|0;do{if((a[1108928]|0)==0){ac=b[(c[277221]|0)+(((Y&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{V=c[277228]&65535;X=Y&-2048;ad=V&-2048;ae=(X&65535)>(ad&65535)?X-ad&65535:0;ad=Y&2016;X=V&2016;if((ad&65535)>(X&65535)){af=(ad-X&65535)+ae&65535}else{af=ae}ae=Y&31;X=V&31;if((ae&65535)<=(X&65535)){ac=af;break}ac=(ae-X&65535)+af&65535}}while(0);b[(c[277218]|0)+(T<<1)>>1]=ac;Y=(a[1108928]|0)==0;R=ab(c[277223]|0,L)|0;if(Y){ag=b[(c[277221]|0)+(((e[(c[277213]|0)+(W+2+R<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{ag=0}Y=W+1|0;b[(c[277218]|0)+(R+Y<<1)>>1]=ag;R=(ab(c[277223]|0,L)|0)+Y|0;a[(c[277219]|0)+R|0]=h;R=(ab(c[277223]|0,L)|0)+W|0;a[(c[277219]|0)+R|0]=h}Q=Q-1|0;}while((Q|0)>=(C|0))}Q=L+1|0;if((Q|0)<(x|0)){L=Q}else{aa=l;break}}}else{aa=K}}while(0);K=C+1|0;if((K|0)<(r|0)){A=A+F|0;B=B+G|0;y=aa;C=K}else{break}}}}while(0);D=x+v|0;E=(ab(c[277223]|0,x)|0)+t|0;z=c[277231]|0;if(D>>>0>z>>>0){break}else{n=0;s=x;t=E;v=D;w=w+(x<<4)|0;u=z}}return}function Wd(f,g,h){f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0;i=c[263194]|0;do{if((a[(c[263195]|0)+8496|0]&1)==0){j=1106168}else{if((a[1106089]|0)==0){j=1125528;break}k=d[1044485]|0;c[276541]=7080+(k<<5);l=0;do{m=l<<1&2;n=l&2;o=l&4;p=0;do{b[1125528+(l<<9)+(p<<1)>>1]=d[(p>>>1&28|n)+(7080+(k<<5))|0]<<6|d[(p<<2&28|m)+(7080+(k<<5))|0]<<11|d[(p>>>3&24|o)+(7080+(k<<5))|0];p=p+1|0;}while(p>>>0<256);l=l+1|0;}while(l>>>0<8);a[1106089]=0;j=1125528}}while(0);c[277226]=j;c[277225]=(a[1108928]|0)!=0?1393712:j;j=c[277230]|0;if((a[1044434]|0)==0){q=f;r=g;s=0;t=1;u=j}else{l=d[1044432]|0;k=((j-(d[1044433]|0)|0)>>>0)%(l>>>0)|0;p=g-1+l|0;q=f-((f|0)%(l|0)|0)|0;r=p-((p|0)%(l|0)|0)|0;s=k;t=l;u=j-k|0}k=c[277231]|0;if(u>>>0>k>>>0){return}j=(q|0)<(r|0);l=t&255;p=h+7|0;h=p&255;o=r-1|0;m=t-1|0;n=s;s=t;t=ab(c[277223]|0,u)|0;v=u;w=1097960+(u<<4)|0;u=k;while(1){if((s+v|0)>>>0>u>>>0){x=u+1-v|0}else{x=s}k=e[w+12>>1]<<19>>19;y=e[w+8>>1]<<19;z=e[w+10>>1]<<19;A=v+1|0;B=(e[w+14>>1]<<19>>19)-(z>>19)|0;C=(B&8192|0)!=0?B|-1024:B&1023;B=b[w+2>>1]|0;D=((a[1044414]|0)==0?A:A^255)&255;A=(ab(D,B)|0)&-64;E=A+(y>>11)+((ab(C,B)|0)&-64)|0;B=b[w+6>>1]|0;A=(ab(B,D)|0)&-64;D=A+(z>>11)+((ab(C,B)|0)&-64)|0;B=b[w>>1]|0;if((a[1044413]|0)==0){C=b[w+4>>1]|0;F=B;G=C<<16>>16;H=q;I=C}else{C=b[w+4>>1]|0;F=-B|0;G=-(C<<16>>16)|0;H=o;I=C}C=k-(y>>19)|0;y=(C&8192|0)!=0?C|-1024:C&1023;C=ab(H,B)|0;k=C+((ab(B,y)|0)&-64)|0;B=I<<16>>16;C=ab(B,H)|0;z=((ab(B,y)|0)&-64)+C|0;do{if((a[1044415]|0)==0){if(!j){break}C=(n|0)>=(x|0);y=k;B=z;A=1;J=q;while(1){K=A-1&255;do{if(K<<24>>24==0){L=y+E|0;M=(B+D|0)>>>8;N=a[i+(M<<4&112|L>>>8<<1&14|d[(c[263194]|0)+(M<<5&32512|L>>>10&254)|0]<<7|1)|0]|0;if(N<<24>>24==0|C){O=l;break}L=m+J|0;M=(L|0)<(J|0);P=N&255;N=n;while(1){if(!M){Q=L;do{R=(Q<<1)+t|0;S=(ab(c[277223]|0,N)|0)+R|0;if((Q|0)>=(f|0)&(p|0)>(d[(c[277219]|0)+S|0]|0)&(Q|0)<(g|0)){do{if((a[1108928]|0)==0){T=b[(c[277225]|0)+(P<<1)>>1]|0;if((a[(c[277215]|0)+S|0]&32)!=0){U=b[(c[277221]|0)+((T&65535|67616)-(b[(c[277213]|0)+(S<<1)>>1]&63454)>>1<<1)>>1]|0;break}V=c[277228]&65535;W=T&-2048;X=V&-2048;Y=(W&65535)>(X&65535)?W-X&65535:0;X=T&2016;W=V&2016;if((X&65535)>(W&65535)){Z=(X-W&65535)+Y&65535}else{Z=Y}Y=T&31;T=V&31;if((Y&65535)<=(T&65535)){U=Z;break}U=(Y-T&65535)+Z&65535}else{T=b[(c[277225]|0)+(P<<1)>>1]|0;if((a[(c[277215]|0)+S|0]&32)==0){_=c[277228]&65535}else{_=b[(c[277213]|0)+(S<<1)>>1]|0}Y=T&-2048;V=_&-2048;W=(Y&65535)>(V&65535)?Y-V&65535:0;V=T&2016;Y=_&2016;if((V&65535)>(Y&65535)){$=(V-Y&65535)+W&65535}else{$=W}W=T&31;T=_&31;if((W&65535)<=(T&65535)){U=$;break}U=(W-T&65535)+$&65535}}while(0);b[(c[277218]|0)+(S<<1)>>1]=U;T=(a[1108928]|0)==0;W=ab(c[277223]|0,N)|0;Y=W+R|0;do{if(T){V=b[(c[277213]|0)+(Y+2<<1)>>1]|0;if((a[(c[277215]|0)+Y|0]&32)!=0){aa=b[(c[277221]|0)+((V&65535|67616)-(b[(c[277226]|0)+(P<<1)>>1]&63454)>>1<<1)>>1]|0;break}X=c[277228]&65535;ac=V&-2048;ad=X&-2048;ae=(ac&65535)>(ad&65535)?ac-ad&65535:0;ad=V&2016;ac=X&2016;if((ad&65535)>(ac&65535)){af=(ad-ac&65535)+ae&65535}else{af=ae}ae=V&31;V=X&31;if((ae&65535)<=(V&65535)){aa=af;break}aa=(ae-V&65535)+af&65535}else{aa=0}}while(0);Y=R+1|0;b[(c[277218]|0)+(W+Y<<1)>>1]=aa;T=(ab(c[277223]|0,N)|0)+Y|0;a[(c[277219]|0)+T|0]=h;T=(ab(c[277223]|0,N)|0)+R|0;a[(c[277219]|0)+T|0]=h}Q=Q-1|0;}while((Q|0)>=(J|0))}Q=N+1|0;if((Q|0)<(x|0)){N=Q}else{O=l;break}}}else{O=K}}while(0);K=J+1|0;if((K|0)<(r|0)){y=y+F|0;B=B+G|0;A=O;J=K}else{break}}}else{if(!j){break}J=(n|0)>=(x|0);A=k;B=z;y=1;C=q;while(1){K=y-1&255;do{if(K<<24>>24==0){N=A+E|0;P=N>>8;L=B+D>>8;if((P|L)>>>0<1024){ag=P<<1&14|L<<4&112|d[(c[263194]|0)+((L<<5&-256)+(N>>10&-2))|0]<<7}else{if((a[1044415]|0)!=3){ah=l;break}ag=P<<1&14|L<<4&112}L=a[i+(ag|1)|0]|0;if(L<<24>>24==0|J){ah=l;break}P=m+C|0;N=(P|0)<(C|0);M=L&255;L=n;while(1){if(!N){Q=P;do{T=(Q<<1)+t|0;Y=(ab(c[277223]|0,L)|0)+T|0;if((Q|0)>=(f|0)&(p|0)>(d[(c[277219]|0)+Y|0]|0)&(Q|0)<(g|0)){do{if((a[1108928]|0)==0){S=b[(c[277225]|0)+(M<<1)>>1]|0;if((a[(c[277215]|0)+Y|0]&32)!=0){ai=b[(c[277221]|0)+((S&65535|67616)-(b[(c[277213]|0)+(Y<<1)>>1]&63454)>>1<<1)>>1]|0;break}V=c[277228]&65535;ae=S&-2048;X=V&-2048;ac=(ae&65535)>(X&65535)?ae-X&65535:0;X=S&2016;ae=V&2016;if((X&65535)>(ae&65535)){aj=(X-ae&65535)+ac&65535}else{aj=ac}ac=S&31;S=V&31;if((ac&65535)<=(S&65535)){ai=aj;break}ai=(ac-S&65535)+aj&65535}else{S=b[(c[277225]|0)+(M<<1)>>1]|0;if((a[(c[277215]|0)+Y|0]&32)==0){ak=c[277228]&65535}else{ak=b[(c[277213]|0)+(Y<<1)>>1]|0}ac=S&-2048;V=ak&-2048;ae=(ac&65535)>(V&65535)?ac-V&65535:0;V=S&2016;ac=ak&2016;if((V&65535)>(ac&65535)){al=(V-ac&65535)+ae&65535}else{al=ae}ae=S&31;S=ak&31;if((ae&65535)<=(S&65535)){ai=al;break}ai=(ae-S&65535)+al&65535}}while(0);b[(c[277218]|0)+(Y<<1)>>1]=ai;R=(a[1108928]|0)==0;W=ab(c[277223]|0,L)|0;S=W+T|0;do{if(R){ae=b[(c[277213]|0)+(S+2<<1)>>1]|0;if((a[(c[277215]|0)+S|0]&32)!=0){am=b[(c[277221]|0)+((ae&65535|67616)-(b[(c[277226]|0)+(M<<1)>>1]&63454)>>1<<1)>>1]|0;break}ac=c[277228]&65535;V=ae&-2048;X=ac&-2048;ad=(V&65535)>(X&65535)?V-X&65535:0;X=ae&2016;V=ac&2016;if((X&65535)>(V&65535)){an=(X-V&65535)+ad&65535}else{an=ad}ad=ae&31;ae=ac&31;if((ad&65535)<=(ae&65535)){am=an;break}am=(ad-ae&65535)+an&65535}else{am=0}}while(0);S=T+1|0;b[(c[277218]|0)+(W+S<<1)>>1]=am;R=(ab(c[277223]|0,L)|0)+S|0;a[(c[277219]|0)+R|0]=h;R=(ab(c[277223]|0,L)|0)+T|0;a[(c[277219]|0)+R|0]=h}Q=Q-1|0;}while((Q|0)>=(C|0))}Q=L+1|0;if((Q|0)<(x|0)){L=Q}else{ah=l;break}}}else{ah=K}}while(0);K=C+1|0;if((K|0)<(r|0)){A=A+F|0;B=B+G|0;y=ah;C=K}else{break}}}}while(0);D=x+v|0;E=(ab(c[277223]|0,x)|0)+t|0;z=c[277231]|0;if(D>>>0>z>>>0){break}else{n=0;s=x;t=E;v=D;w=w+(x<<4)|0;u=z}}return}function We(d,e,f){d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0;c[277226]=1106168;c[277225]=(a[1108928]|0)!=0?1393712:1106168;g=c[277230]|0;h=c[277231]|0;if(g>>>0>h>>>0){return}i=e>>>0<f>>>0;j=d;d=g;g=h;while(1){if(i){h=e;do{k=(h<<1)+j|0;if((a[(c[277219]|0)+k|0]|0)==0){b[(c[277218]|0)+(k<<1)>>1]=b[c[277225]>>1]|0;if((a[1108928]|0)==0){l=b[(c[277213]|0)+(k+2<<1)>>1]|0}else{l=0}m=k+1|0;b[(c[277218]|0)+(m<<1)>>1]=l;a[(c[277219]|0)+m|0]=1;a[(c[277219]|0)+k|0]=1}h=h+1|0;}while(h>>>0<f>>>0);n=c[277231]|0}else{n=g}h=d+1|0;if(h>>>0>n>>>0){break}else{j=(c[277223]|0)+j|0;d=h;g=n}}return}function Wf(d,f,g){d=d|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;c[277226]=1106168;c[277225]=(a[1108928]|0)!=0?1393712:1106168;h=c[277230]|0;i=c[277231]|0;if(h>>>0>i>>>0){return}j=f>>>0<g>>>0;k=d;d=h;h=i;while(1){if(j){i=f;do{l=(i<<1)+k|0;if((a[(c[277219]|0)+l|0]|0)==0){m=e[c[277225]>>1]|0;n=(a[(c[277215]|0)+l|0]&32)==0;if(n){o=c[277228]|0;p=o;q=o&-2082}else{o=e[(c[277213]|0)+(l<<1)>>1]|0;p=o;q=o&63454}if(n){r=c[277228]|0}else{r=e[(c[277213]|0)+(l<<1)>>1]|0}b[(c[277218]|0)+(l<<1)>>1]=((r^m)&2081|e[(c[277220]|0)+((m&2081&p)+((q+(m&63454)|0)>>>1)<<1)>>1])&65535;m=(a[1108928]|0)==0;if(m){s=b[(c[277213]|0)+(l+2<<1)>>1]&63454}else{s=0}n=(a[(c[277215]|0)+l|0]&32)==0;if(n){t=c[277228]|0}else{t=e[c[277226]>>1]|0}if(m){u=b[(c[277213]|0)+(l+2<<1)>>1]&2081}else{u=0}if(n){v=c[277228]|0}else{v=e[c[277226]>>1]|0}if(m){w=e[(c[277213]|0)+(l+2<<1)>>1]|0}else{w=0}if(n){x=c[277228]|0}else{x=e[c[277226]>>1]|0}n=l+1|0;b[(c[277218]|0)+(n<<1)>>1]=((x^w)&2081|e[(c[277220]|0)+((v&u)+(((t&-2082)+s|0)>>>1)<<1)>>1])&65535;a[(c[277219]|0)+n|0]=1;a[(c[277219]|0)+l|0]=1}i=i+1|0;}while(i>>>0<g>>>0);y=c[277231]|0}else{y=h}i=d+1|0;if(i>>>0>y>>>0){break}else{k=(c[277223]|0)+k|0;d=i;h=y}}return}function Wg(d,f,g){d=d|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0;c[277226]=1106168;c[277225]=(a[1108928]|0)!=0?1393712:1106168;h=c[277230]|0;i=c[277231]|0;if(h>>>0>i>>>0){return}j=f>>>0<g>>>0;k=d;d=h;h=i;while(1){if(j){i=f;do{l=(i<<1)+k|0;if((a[(c[277219]|0)+l|0]|0)==0){m=e[c[277225]>>1]|0;n=c[277228]|0;o=(((m&63454)+(n&-2082)|0)>>>1)+(n&2081&m)|0;if((a[1108928]|0)==0){p=o&65535}else{p=(e[(c[277220]|0)+(o<<1)>>1]|(m^n)&2081)&65535}b[(c[277218]|0)+(l<<1)>>1]=p;if((a[1108928]|0)==0){n=e[(c[277213]|0)+(l+2<<1)>>1]|0;m=c[277228]|0;q=(((n&63454)+(m&128990)|0)>>>1)+(m&2081&n)|0}else{n=c[277228]|0;q=e[(c[277220]|0)+((n>>>1&2147482607)<<1)>>1]|n&2081}n=l+1|0;b[(c[277218]|0)+(n<<1)>>1]=q&65535;a[(c[277219]|0)+n|0]=1;a[(c[277219]|0)+l|0]=1}i=i+1|0;}while(i>>>0<g>>>0);r=c[277231]|0}else{r=h}i=d+1|0;if(i>>>0>r>>>0){break}else{k=(c[277223]|0)+k|0;d=i;h=r}}return}function Wh(d,f,g){d=d|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;c[277226]=1106168;c[277225]=(a[1108928]|0)!=0?1393712:1106168;h=c[277230]|0;i=c[277231]|0;if(h>>>0>i>>>0){return}j=f>>>0<g>>>0;k=d;d=h;h=i;while(1){if(j){i=f;do{l=(i<<1)+k|0;if((a[(c[277219]|0)+l|0]|0)==0){do{if((a[1108928]|0)==0){m=b[c[277225]>>1]|0;n=m&65535;o=n&63454;if((a[(c[277215]|0)+l|0]&32)==0){p=c[277228]|0;q=(e[(c[277220]|0)+((((p&-2082)+o|0)>>>1)+(n&2081&p)<<1)>>1]|(p^n)&2081)&65535;break}else{n=b[(c[277213]|0)+(l<<1)>>1]|0;q=(((n&63454)+o|0)>>>1)+(n&m&2081)&65535;break}}else{m=e[c[277225]>>1]|0;n=(a[(c[277215]|0)+l|0]&32)==0;if(n){o=c[277228]|0;r=o;s=o&-2082}else{o=e[(c[277213]|0)+(l<<1)>>1]|0;r=o;s=o&63454}if(n){t=c[277228]|0}else{t=e[(c[277213]|0)+(l<<1)>>1]|0}q=((t^m)&2081|e[(c[277220]|0)+((m&2081&r)+((s+(m&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(l<<1)>>1]=q;m=(a[(c[277215]|0)+l|0]&32)==0;do{if((a[1108928]|0)==0){n=e[(c[277213]|0)+(l+2<<1)>>1]|0;o=n&63454;if(m){p=c[277228]|0;u=(e[(c[277220]|0)+((((p&-2082)+o|0)>>>1)+(n&2081&p)<<1)>>1]|(p^n)&2081)&65535;break}else{p=e[c[277226]>>1]|0;u=(((p&63454)+o|0)>>>1)+(n&2081&p)&65535;break}}else{if(m){p=c[277228]|0;v=p;w=(c[277220]|0)+((p>>>1&2147482607)<<1)|0}else{p=e[c[277226]>>1]|0;v=p;w=(c[277220]|0)+((p>>>1&31727)<<1)|0}u=(e[w>>1]|v&2081)&65535}}while(0);m=l+1|0;b[(c[277218]|0)+(m<<1)>>1]=u;a[(c[277219]|0)+m|0]=1;a[(c[277219]|0)+l|0]=1}i=i+1|0;}while(i>>>0<g>>>0);x=c[277231]|0}else{x=h}i=d+1|0;if(i>>>0>x>>>0){break}else{k=(c[277223]|0)+k|0;d=i;h=x}}return}function Wi(d,e,f){d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;c[277226]=1106168;c[277225]=(a[1108928]|0)!=0?1393712:1106168;g=c[277230]|0;h=c[277231]|0;if(g>>>0>h>>>0){return}i=e>>>0<f>>>0;j=d;d=g;g=h;while(1){if(i){h=e;do{k=(h<<1)+j|0;if((a[(c[277219]|0)+k|0]|0)==0){l=b[c[277225]>>1]|0;if((a[(c[277215]|0)+k|0]&32)==0){m=c[277228]&65535}else{m=b[(c[277213]|0)+(k<<1)>>1]|0}n=l&-2048;o=m&-2048;p=(n&65535)>(o&65535)?n-o&65535:0;o=l&2016;n=m&2016;if((o&65535)>(n&65535)){q=(o-n&65535)+p&65535}else{q=p}p=l&31;l=m&31;if((p&65535)>(l&65535)){r=(p-l&65535)+q&65535}else{r=q}b[(c[277218]|0)+(k<<1)>>1]=r;if((a[1108928]|0)==0){s=b[(c[277213]|0)+(k+2<<1)>>1]|0}else{s=0}if((a[(c[277215]|0)+k|0]&32)==0){t=c[277228]&65535}else{t=b[c[277226]>>1]|0}l=s&-2048;p=t&-2048;n=(l&65535)>(p&65535)?l-p&65535:0;p=s&2016;l=t&2016;if((p&65535)>(l&65535)){u=(p-l&65535)+n&65535}else{u=n}n=s&31;l=t&31;if((n&65535)>(l&65535)){v=(n-l&65535)+u&65535}else{v=u}l=k+1|0;b[(c[277218]|0)+(l<<1)>>1]=v;a[(c[277219]|0)+l|0]=1;a[(c[277219]|0)+k|0]=1}h=h+1|0;}while(h>>>0<f>>>0);w=c[277231]|0}else{w=g}h=d+1|0;if(h>>>0>w>>>0){break}else{j=(c[277223]|0)+j|0;d=h;g=w}}return}function Wj(d,f,g){d=d|0;f=f|0;g=g|0;var h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0;c[277226]=1106168;c[277225]=(a[1108928]|0)!=0?1393712:1106168;h=c[277230]|0;i=c[277231]|0;if(h>>>0>i>>>0){return}j=f>>>0<g>>>0;k=d;d=h;h=i;while(1){if(j){i=f;do{l=(i<<1)+k|0;if((a[(c[277219]|0)+l|0]|0)==0){m=b[c[277225]>>1]|0;do{if((a[1108928]|0)==0){n=b[(c[277221]|0)+(((m&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{o=c[277228]&65535;p=m&-2048;q=o&-2048;r=(p&65535)>(q&65535)?p-q&65535:0;q=m&2016;p=o&2016;if((q&65535)>(p&65535)){s=(q-p&65535)+r&65535}else{s=r}r=m&31;p=o&31;if((r&65535)<=(p&65535)){n=s;break}n=(r-p&65535)+s&65535}}while(0);b[(c[277218]|0)+(l<<1)>>1]=n;if((a[1108928]|0)==0){t=b[(c[277221]|0)+(((e[(c[277213]|0)+(l+2<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{t=0}m=l+1|0;b[(c[277218]|0)+(m<<1)>>1]=t;a[(c[277219]|0)+m|0]=1;a[(c[277219]|0)+l|0]=1}i=i+1|0;}while(i>>>0<g>>>0);u=c[277231]|0}else{u=h}i=d+1|0;if(i>>>0>u>>>0){break}else{k=(c[277223]|0)+k|0;d=i;h=u}}return}function Wk(d,e,f){d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;c[277226]=1106168;c[277225]=(a[1108928]|0)!=0?1393712:1106168;g=c[277230]|0;h=c[277231]|0;if(g>>>0>h>>>0){return}i=e>>>0<f>>>0;j=d;d=g;g=h;while(1){if(i){h=e;do{k=(h<<1)+j|0;if((a[(c[277219]|0)+k|0]|0)==0){do{if((a[1108928]|0)==0){l=b[c[277225]>>1]|0;if((a[(c[277215]|0)+k|0]&32)!=0){m=b[(c[277221]|0)+((l&65535|67616)-(b[(c[277213]|0)+(k<<1)>>1]&63454)>>1<<1)>>1]|0;break}n=c[277228]&65535;o=l&-2048;p=n&-2048;q=(o&65535)>(p&65535)?o-p&65535:0;p=l&2016;o=n&2016;if((p&65535)>(o&65535)){r=(p-o&65535)+q&65535}else{r=q}q=l&31;l=n&31;if((q&65535)<=(l&65535)){m=r;break}m=(q-l&65535)+r&65535}else{l=b[c[277225]>>1]|0;if((a[(c[277215]|0)+k|0]&32)==0){s=c[277228]&65535}else{s=b[(c[277213]|0)+(k<<1)>>1]|0}q=l&-2048;n=s&-2048;o=(q&65535)>(n&65535)?q-n&65535:0;n=l&2016;q=s&2016;if((n&65535)>(q&65535)){t=(n-q&65535)+o&65535}else{t=o}o=l&31;l=s&31;if((o&65535)<=(l&65535)){m=t;break}m=(o-l&65535)+t&65535}}while(0);b[(c[277218]|0)+(k<<1)>>1]=m;do{if((a[1108928]|0)==0){l=b[(c[277213]|0)+(k+2<<1)>>1]|0;if((a[(c[277215]|0)+k|0]&32)!=0){u=b[(c[277221]|0)+((l&65535|67616)-(b[c[277226]>>1]&63454)>>1<<1)>>1]|0;break}o=c[277228]&65535;q=l&-2048;n=o&-2048;p=(q&65535)>(n&65535)?q-n&65535:0;n=l&2016;q=o&2016;if((n&65535)>(q&65535)){v=(n-q&65535)+p&65535}else{v=p}p=l&31;l=o&31;if((p&65535)<=(l&65535)){u=v;break}u=(p-l&65535)+v&65535}else{u=0}}while(0);l=k+1|0;b[(c[277218]|0)+(l<<1)>>1]=u;a[(c[277219]|0)+l|0]=1;a[(c[277219]|0)+k|0]=1}h=h+1|0;}while(h>>>0<f>>>0);w=c[277231]|0}else{w=g}h=d+1|0;if(h>>>0>w>>>0){break}else{j=(c[277223]|0)+j|0;d=h;g=w}}return}function Wl(e,f,g,h,i,j){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0;k=e&1023;l=c[348606]|0;m=(k<<l)+(c[348604]|0)|0;if((e&256|0)==0){n=m}else{n=(c[348602]|0)+m|0}m=n&65535;n=m>>>(l>>>0);l=(e&16384|0)!=0;o=n<<6;do{if(l){p=(c[348622]|0)+o|0;if((a[(c[348618]|0)+n|0]|0)!=0){q=p;break}r=fi[c[348636]&63](p,m,k)|0;a[(c[348618]|0)+n|0]=r;q=p}else{p=(c[348624]|0)+o|0;if((a[(c[348620]|0)+n|0]|0)!=0){q=p;break}r=fi[c[348638]&63](p,m,k)|0;a[(c[348620]|0)+n|0]=r;q=p}}while(0);if((a[(c[348620]|0)+n|0]|0)==2){return}if((a[1394464]|0)==0){s=1106168+((e>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){n=d[1044485]|0;c[276541]=7080+(n<<5);k=0;do{m=k<<1&2;o=k&2;p=k&4;r=0;do{b[1125528+(k<<9)+(r<<1)>>1]=d[(r>>>1&28|o)+(7080+(n<<5))|0]<<6|d[(r<<2&28|m)+(7080+(n<<5))|0]<<11|d[(r>>>3&24|p)+(7080+(n<<5))|0];r=r+1|0;}while(r>>>0<256);k=k+1|0;}while(k>>>0<8);a[1106089]=0}s=1125528+((e>>>10&7)<<9)|0}c[277226]=s;c[277225]=(a[1108928]|0)!=0?1393712:s;s=(d[1394504]|0)+(g<<1)|0;g=a[q+(((e&32768|0)==0?s:56-s|0)+(l?7-h|0:h))|0]|0;if(!(g<<24>>24!=0&(j|0)>0)){return}h=i-1|0;i=(h|0)>-1;l=g&255;g=j;j=f;while(1){if(i){f=h;do{s=(f<<1)+j|0;if((d[1108908]|0)>(d[(c[277219]|0)+s|0]|0)){b[(c[277218]|0)+(s<<1)>>1]=b[(c[277225]|0)+(l<<1)>>1]|0;if((a[1108928]|0)==0){t=b[(c[277213]|0)+(s+2<<1)>>1]|0}else{t=0}e=s+1|0;b[(c[277218]|0)+(e<<1)>>1]=t;q=a[1108909]|0;a[(c[277219]|0)+e|0]=q;a[(c[277219]|0)+s|0]=q}f=f-1|0;}while((f|0)>-1)}f=g-1|0;if((f|0)>0){g=f;j=(c[277223]|0)+j|0}else{break}}return}function Wm(f,g,h,i,j,k){f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0;l=f&1023;m=c[348606]|0;n=(l<<m)+(c[348604]|0)|0;if((f&256|0)==0){o=n}else{o=(c[348602]|0)+n|0}n=o&65535;o=n>>>(m>>>0);m=(f&16384|0)!=0;p=o<<6;do{if(m){q=(c[348622]|0)+p|0;if((a[(c[348618]|0)+o|0]|0)!=0){r=q;break}s=fi[c[348636]&63](q,n,l)|0;a[(c[348618]|0)+o|0]=s;r=q}else{q=(c[348624]|0)+p|0;if((a[(c[348620]|0)+o|0]|0)!=0){r=q;break}s=fi[c[348638]&63](q,n,l)|0;a[(c[348620]|0)+o|0]=s;r=q}}while(0);if((a[(c[348620]|0)+o|0]|0)==2){return}if((a[1394464]|0)==0){t=1106168+((f>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){o=d[1044485]|0;c[276541]=7080+(o<<5);l=0;do{n=l<<1&2;p=l&2;q=l&4;s=0;do{b[1125528+(l<<9)+(s<<1)>>1]=d[(s>>>1&28|p)+(7080+(o<<5))|0]<<6|d[(s<<2&28|n)+(7080+(o<<5))|0]<<11|d[(s>>>3&24|q)+(7080+(o<<5))|0];s=s+1|0;}while(s>>>0<256);l=l+1|0;}while(l>>>0<8);a[1106089]=0}t=1125528+((f>>>10&7)<<9)|0}c[277226]=t;c[277225]=(a[1108928]|0)!=0?1393712:t;t=(d[1394504]|0)+(h<<1)|0;h=a[r+(((f&32768|0)==0?t:56-t|0)+(m?7-i|0:i))|0]|0;if(!(h<<24>>24!=0&(k|0)>0)){return}i=j-1|0;j=(i|0)>-1;m=h&255;h=k;k=g;while(1){if(j){g=i;do{t=(g<<1)+k|0;if((d[1108908]|0)>(d[(c[277219]|0)+t|0]|0)){f=e[(c[277225]|0)+(m<<1)>>1]|0;r=(a[(c[277215]|0)+t|0]&32)==0;if(r){l=c[277228]|0;u=l;v=l&-2082}else{l=e[(c[277213]|0)+(t<<1)>>1]|0;u=l;v=l&63454}if(r){w=c[277228]|0}else{w=e[(c[277213]|0)+(t<<1)>>1]|0}b[(c[277218]|0)+(t<<1)>>1]=((w^f)&2081|e[(c[277220]|0)+((f&2081&u)+((v+(f&63454)|0)>>>1)<<1)>>1])&65535;f=(a[1108928]|0)==0;if(f){x=b[(c[277213]|0)+(t+2<<1)>>1]&63454}else{x=0}r=(a[(c[277215]|0)+t|0]&32)==0;if(r){y=c[277228]|0}else{y=e[(c[277226]|0)+(m<<1)>>1]|0}if(f){z=b[(c[277213]|0)+(t+2<<1)>>1]&2081}else{z=0}if(r){A=c[277228]|0}else{A=e[(c[277226]|0)+(m<<1)>>1]|0}if(f){B=e[(c[277213]|0)+(t+2<<1)>>1]|0}else{B=0}if(r){C=c[277228]|0}else{C=e[(c[277226]|0)+(m<<1)>>1]|0}r=t+1|0;b[(c[277218]|0)+(r<<1)>>1]=((C^B)&2081|e[(c[277220]|0)+((A&z)+(((y&-2082)+x|0)>>>1)<<1)>>1])&65535;f=a[1108909]|0;a[(c[277219]|0)+r|0]=f;a[(c[277219]|0)+t|0]=f}g=g-1|0;}while((g|0)>-1)}g=h-1|0;if((g|0)>0){h=g;k=(c[277223]|0)+k|0}else{break}}return}function Wn(f,g,h,i,j,k){f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0;l=f&1023;m=c[348606]|0;n=(l<<m)+(c[348604]|0)|0;if((f&256|0)==0){o=n}else{o=(c[348602]|0)+n|0}n=o&65535;o=n>>>(m>>>0);m=(f&16384|0)!=0;p=o<<6;do{if(m){q=(c[348622]|0)+p|0;if((a[(c[348618]|0)+o|0]|0)!=0){r=q;break}s=fi[c[348636]&63](q,n,l)|0;a[(c[348618]|0)+o|0]=s;r=q}else{q=(c[348624]|0)+p|0;if((a[(c[348620]|0)+o|0]|0)!=0){r=q;break}s=fi[c[348638]&63](q,n,l)|0;a[(c[348620]|0)+o|0]=s;r=q}}while(0);if((a[(c[348620]|0)+o|0]|0)==2){return}if((a[1394464]|0)==0){t=1106168+((f>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){o=d[1044485]|0;c[276541]=7080+(o<<5);l=0;do{n=l<<1&2;p=l&2;q=l&4;s=0;do{b[1125528+(l<<9)+(s<<1)>>1]=d[(s>>>1&28|p)+(7080+(o<<5))|0]<<6|d[(s<<2&28|n)+(7080+(o<<5))|0]<<11|d[(s>>>3&24|q)+(7080+(o<<5))|0];s=s+1|0;}while(s>>>0<256);l=l+1|0;}while(l>>>0<8);a[1106089]=0}t=1125528+((f>>>10&7)<<9)|0}c[277226]=t;c[277225]=(a[1108928]|0)!=0?1393712:t;t=(d[1394504]|0)+(h<<1)|0;h=a[r+(((f&32768|0)==0?t:56-t|0)+(m?7-i|0:i))|0]|0;if(!(h<<24>>24!=0&(k|0)>0)){return}i=j-1|0;j=(i|0)>-1;m=h&255;h=k;k=g;while(1){if(j){g=i;do{t=(g<<1)+k|0;if((d[1108908]|0)>(d[(c[277219]|0)+t|0]|0)){f=e[(c[277225]|0)+(m<<1)>>1]|0;r=c[277228]|0;l=(((f&63454)+(r&-2082)|0)>>>1)+(r&2081&f)|0;if((a[1108928]|0)==0){u=l&65535}else{u=(e[(c[277220]|0)+(l<<1)>>1]|(f^r)&2081)&65535}b[(c[277218]|0)+(t<<1)>>1]=u;if((a[1108928]|0)==0){r=e[(c[277213]|0)+(t+2<<1)>>1]|0;f=c[277228]|0;v=(((r&63454)+(f&128990)|0)>>>1)+(f&2081&r)|0}else{r=c[277228]|0;v=e[(c[277220]|0)+((r>>>1&2147482607)<<1)>>1]|r&2081}r=t+1|0;b[(c[277218]|0)+(r<<1)>>1]=v&65535;f=a[1108909]|0;a[(c[277219]|0)+r|0]=f;a[(c[277219]|0)+t|0]=f}g=g-1|0;}while((g|0)>-1)}g=h-1|0;if((g|0)>0){h=g;k=(c[277223]|0)+k|0}else{break}}return}function Wo(f,g,h,i,j,k){f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0;l=f&1023;m=c[348606]|0;n=(l<<m)+(c[348604]|0)|0;if((f&256|0)==0){o=n}else{o=(c[348602]|0)+n|0}n=o&65535;o=n>>>(m>>>0);m=(f&16384|0)!=0;p=o<<6;do{if(m){q=(c[348622]|0)+p|0;if((a[(c[348618]|0)+o|0]|0)!=0){r=q;break}s=fi[c[348636]&63](q,n,l)|0;a[(c[348618]|0)+o|0]=s;r=q}else{q=(c[348624]|0)+p|0;if((a[(c[348620]|0)+o|0]|0)!=0){r=q;break}s=fi[c[348638]&63](q,n,l)|0;a[(c[348620]|0)+o|0]=s;r=q}}while(0);if((a[(c[348620]|0)+o|0]|0)==2){return}if((a[1394464]|0)==0){t=1106168+((f>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){o=d[1044485]|0;c[276541]=7080+(o<<5);l=0;do{n=l<<1&2;p=l&2;q=l&4;s=0;do{b[1125528+(l<<9)+(s<<1)>>1]=d[(s>>>1&28|p)+(7080+(o<<5))|0]<<6|d[(s<<2&28|n)+(7080+(o<<5))|0]<<11|d[(s>>>3&24|q)+(7080+(o<<5))|0];s=s+1|0;}while(s>>>0<256);l=l+1|0;}while(l>>>0<8);a[1106089]=0}t=1125528+((f>>>10&7)<<9)|0}c[277226]=t;c[277225]=(a[1108928]|0)!=0?1393712:t;t=(d[1394504]|0)+(h<<1)|0;h=a[r+(((f&32768|0)==0?t:56-t|0)+(m?7-i|0:i))|0]|0;if(!(h<<24>>24!=0&(k|0)>0)){return}i=j-1|0;j=(i|0)>-1;m=h&255;h=k;k=g;while(1){if(j){g=i;do{t=(g<<1)+k|0;if((d[1108908]|0)>(d[(c[277219]|0)+t|0]|0)){do{if((a[1108928]|0)==0){f=b[(c[277225]|0)+(m<<1)>>1]|0;r=f&65535;l=r&63454;if((a[(c[277215]|0)+t|0]&32)==0){o=c[277228]|0;u=(e[(c[277220]|0)+((((o&-2082)+l|0)>>>1)+(r&2081&o)<<1)>>1]|(o^r)&2081)&65535;break}else{r=b[(c[277213]|0)+(t<<1)>>1]|0;u=(((r&63454)+l|0)>>>1)+(r&f&2081)&65535;break}}else{f=e[(c[277225]|0)+(m<<1)>>1]|0;r=(a[(c[277215]|0)+t|0]&32)==0;if(r){l=c[277228]|0;v=l;w=l&-2082}else{l=e[(c[277213]|0)+(t<<1)>>1]|0;v=l;w=l&63454}if(r){x=c[277228]|0}else{x=e[(c[277213]|0)+(t<<1)>>1]|0}u=((x^f)&2081|e[(c[277220]|0)+((f&2081&v)+((w+(f&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(t<<1)>>1]=u;f=(a[(c[277215]|0)+t|0]&32)==0;do{if((a[1108928]|0)==0){r=e[(c[277213]|0)+(t+2<<1)>>1]|0;l=r&63454;if(f){o=c[277228]|0;y=(e[(c[277220]|0)+((((o&-2082)+l|0)>>>1)+(r&2081&o)<<1)>>1]|(o^r)&2081)&65535;break}else{o=e[(c[277226]|0)+(m<<1)>>1]|0;y=(((o&63454)+l|0)>>>1)+(r&2081&o)&65535;break}}else{if(f){o=c[277228]|0;z=o;A=(c[277220]|0)+((o>>>1&2147482607)<<1)|0}else{o=e[(c[277226]|0)+(m<<1)>>1]|0;z=o;A=(c[277220]|0)+((o>>>1&31727)<<1)|0}y=(e[A>>1]|z&2081)&65535}}while(0);f=t+1|0;b[(c[277218]|0)+(f<<1)>>1]=y;o=a[1108909]|0;a[(c[277219]|0)+f|0]=o;a[(c[277219]|0)+t|0]=o}g=g-1|0;}while((g|0)>-1)}g=h-1|0;if((g|0)>0){h=g;k=(c[277223]|0)+k|0}else{break}}return}function Wp(e,f,g,h,i,j){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0;k=e&1023;l=c[348606]|0;m=(k<<l)+(c[348604]|0)|0;if((e&256|0)==0){n=m}else{n=(c[348602]|0)+m|0}m=n&65535;n=m>>>(l>>>0);l=(e&16384|0)!=0;o=n<<6;do{if(l){p=(c[348622]|0)+o|0;if((a[(c[348618]|0)+n|0]|0)!=0){q=p;break}r=fi[c[348636]&63](p,m,k)|0;a[(c[348618]|0)+n|0]=r;q=p}else{p=(c[348624]|0)+o|0;if((a[(c[348620]|0)+n|0]|0)!=0){q=p;break}r=fi[c[348638]&63](p,m,k)|0;a[(c[348620]|0)+n|0]=r;q=p}}while(0);if((a[(c[348620]|0)+n|0]|0)==2){return}if((a[1394464]|0)==0){s=1106168+((e>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){n=d[1044485]|0;c[276541]=7080+(n<<5);k=0;do{m=k<<1&2;o=k&2;p=k&4;r=0;do{b[1125528+(k<<9)+(r<<1)>>1]=d[(r>>>1&28|o)+(7080+(n<<5))|0]<<6|d[(r<<2&28|m)+(7080+(n<<5))|0]<<11|d[(r>>>3&24|p)+(7080+(n<<5))|0];r=r+1|0;}while(r>>>0<256);k=k+1|0;}while(k>>>0<8);a[1106089]=0}s=1125528+((e>>>10&7)<<9)|0}c[277226]=s;c[277225]=(a[1108928]|0)!=0?1393712:s;s=(d[1394504]|0)+(g<<1)|0;g=a[q+(((e&32768|0)==0?s:56-s|0)+(l?7-h|0:h))|0]|0;if(!(g<<24>>24!=0&(j|0)>0)){return}h=i-1|0;i=(h|0)>-1;l=g&255;g=j;j=f;while(1){if(i){f=h;do{s=(f<<1)+j|0;if((d[1108908]|0)>(d[(c[277219]|0)+s|0]|0)){e=b[(c[277225]|0)+(l<<1)>>1]|0;if((a[(c[277215]|0)+s|0]&32)==0){t=c[277228]&65535}else{t=b[(c[277213]|0)+(s<<1)>>1]|0}q=e&-2048;k=t&-2048;n=(q&65535)>(k&65535)?q-k&65535:0;k=e&2016;q=t&2016;if((k&65535)>(q&65535)){u=(k-q&65535)+n&65535}else{u=n}n=e&31;e=t&31;if((n&65535)>(e&65535)){v=(n-e&65535)+u&65535}else{v=u}b[(c[277218]|0)+(s<<1)>>1]=v;if((a[1108928]|0)==0){w=b[(c[277213]|0)+(s+2<<1)>>1]|0}else{w=0}if((a[(c[277215]|0)+s|0]&32)==0){x=c[277228]&65535}else{x=b[(c[277226]|0)+(l<<1)>>1]|0}e=w&-2048;n=x&-2048;q=(e&65535)>(n&65535)?e-n&65535:0;n=w&2016;e=x&2016;if((n&65535)>(e&65535)){y=(n-e&65535)+q&65535}else{y=q}q=w&31;e=x&31;if((q&65535)>(e&65535)){z=(q-e&65535)+y&65535}else{z=y}e=s+1|0;b[(c[277218]|0)+(e<<1)>>1]=z;q=a[1108909]|0;a[(c[277219]|0)+e|0]=q;a[(c[277219]|0)+s|0]=q}f=f-1|0;}while((f|0)>-1)}f=g-1|0;if((f|0)>0){g=f;j=(c[277223]|0)+j|0}else{break}}return}function Wq(f,g,h,i,j,k){f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0;l=f&1023;m=c[348606]|0;n=(l<<m)+(c[348604]|0)|0;if((f&256|0)==0){o=n}else{o=(c[348602]|0)+n|0}n=o&65535;o=n>>>(m>>>0);m=(f&16384|0)!=0;p=o<<6;do{if(m){q=(c[348622]|0)+p|0;if((a[(c[348618]|0)+o|0]|0)!=0){r=q;break}s=fi[c[348636]&63](q,n,l)|0;a[(c[348618]|0)+o|0]=s;r=q}else{q=(c[348624]|0)+p|0;if((a[(c[348620]|0)+o|0]|0)!=0){r=q;break}s=fi[c[348638]&63](q,n,l)|0;a[(c[348620]|0)+o|0]=s;r=q}}while(0);if((a[(c[348620]|0)+o|0]|0)==2){return}if((a[1394464]|0)==0){t=1106168+((f>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){o=d[1044485]|0;c[276541]=7080+(o<<5);l=0;do{n=l<<1&2;p=l&2;q=l&4;s=0;do{b[1125528+(l<<9)+(s<<1)>>1]=d[(s>>>1&28|p)+(7080+(o<<5))|0]<<6|d[(s<<2&28|n)+(7080+(o<<5))|0]<<11|d[(s>>>3&24|q)+(7080+(o<<5))|0];s=s+1|0;}while(s>>>0<256);l=l+1|0;}while(l>>>0<8);a[1106089]=0}t=1125528+((f>>>10&7)<<9)|0}c[277226]=t;c[277225]=(a[1108928]|0)!=0?1393712:t;t=(d[1394504]|0)+(h<<1)|0;h=a[r+(((f&32768|0)==0?t:56-t|0)+(m?7-i|0:i))|0]|0;if(!(h<<24>>24!=0&(k|0)>0)){return}i=j-1|0;j=(i|0)>-1;m=h&255;h=k;k=g;while(1){if(j){g=i;do{t=(g<<1)+k|0;if((d[1108908]|0)>(d[(c[277219]|0)+t|0]|0)){f=b[(c[277225]|0)+(m<<1)>>1]|0;do{if((a[1108928]|0)==0){u=b[(c[277221]|0)+(((f&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{r=c[277228]&65535;l=f&-2048;o=r&-2048;s=(l&65535)>(o&65535)?l-o&65535:0;o=f&2016;l=r&2016;if((o&65535)>(l&65535)){v=(o-l&65535)+s&65535}else{v=s}s=f&31;l=r&31;if((s&65535)<=(l&65535)){u=v;break}u=(s-l&65535)+v&65535}}while(0);b[(c[277218]|0)+(t<<1)>>1]=u;if((a[1108928]|0)==0){w=b[(c[277221]|0)+(((e[(c[277213]|0)+(t+2<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{w=0}f=t+1|0;b[(c[277218]|0)+(f<<1)>>1]=w;l=a[1108909]|0;a[(c[277219]|0)+f|0]=l;a[(c[277219]|0)+t|0]=l}g=g-1|0;}while((g|0)>-1)}g=h-1|0;if((g|0)>0){h=g;k=(c[277223]|0)+k|0}else{break}}return}function Wr(e,f,g,h,i,j){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0;k=e&1023;l=c[348606]|0;m=(k<<l)+(c[348604]|0)|0;if((e&256|0)==0){n=m}else{n=(c[348602]|0)+m|0}m=n&65535;n=m>>>(l>>>0);l=(e&16384|0)!=0;o=n<<6;do{if(l){p=(c[348622]|0)+o|0;if((a[(c[348618]|0)+n|0]|0)!=0){q=p;break}r=fi[c[348636]&63](p,m,k)|0;a[(c[348618]|0)+n|0]=r;q=p}else{p=(c[348624]|0)+o|0;if((a[(c[348620]|0)+n|0]|0)!=0){q=p;break}r=fi[c[348638]&63](p,m,k)|0;a[(c[348620]|0)+n|0]=r;q=p}}while(0);if((a[(c[348620]|0)+n|0]|0)==2){return}if((a[1394464]|0)==0){s=1106168+((e>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){n=d[1044485]|0;c[276541]=7080+(n<<5);k=0;do{m=k<<1&2;o=k&2;p=k&4;r=0;do{b[1125528+(k<<9)+(r<<1)>>1]=d[(r>>>1&28|o)+(7080+(n<<5))|0]<<6|d[(r<<2&28|m)+(7080+(n<<5))|0]<<11|d[(r>>>3&24|p)+(7080+(n<<5))|0];r=r+1|0;}while(r>>>0<256);k=k+1|0;}while(k>>>0<8);a[1106089]=0}s=1125528+((e>>>10&7)<<9)|0}c[277226]=s;c[277225]=(a[1108928]|0)!=0?1393712:s;s=(d[1394504]|0)+(g<<1)|0;g=a[q+(((e&32768|0)==0?s:56-s|0)+(l?7-h|0:h))|0]|0;if(!(g<<24>>24!=0&(j|0)>0)){return}h=i-1|0;i=(h|0)>-1;l=g&255;g=j;j=f;while(1){if(i){f=h;do{s=(f<<1)+j|0;if((d[1108908]|0)>(d[(c[277219]|0)+s|0]|0)){do{if((a[1108928]|0)==0){e=b[(c[277225]|0)+(l<<1)>>1]|0;if((a[(c[277215]|0)+s|0]&32)!=0){t=b[(c[277221]|0)+((e&65535|67616)-(b[(c[277213]|0)+(s<<1)>>1]&63454)>>1<<1)>>1]|0;break}q=c[277228]&65535;k=e&-2048;n=q&-2048;r=(k&65535)>(n&65535)?k-n&65535:0;n=e&2016;k=q&2016;if((n&65535)>(k&65535)){u=(n-k&65535)+r&65535}else{u=r}r=e&31;e=q&31;if((r&65535)<=(e&65535)){t=u;break}t=(r-e&65535)+u&65535}else{e=b[(c[277225]|0)+(l<<1)>>1]|0;if((a[(c[277215]|0)+s|0]&32)==0){v=c[277228]&65535}else{v=b[(c[277213]|0)+(s<<1)>>1]|0}r=e&-2048;q=v&-2048;k=(r&65535)>(q&65535)?r-q&65535:0;q=e&2016;r=v&2016;if((q&65535)>(r&65535)){w=(q-r&65535)+k&65535}else{w=k}k=e&31;e=v&31;if((k&65535)<=(e&65535)){t=w;break}t=(k-e&65535)+w&65535}}while(0);b[(c[277218]|0)+(s<<1)>>1]=t;do{if((a[1108928]|0)==0){e=b[(c[277213]|0)+(s+2<<1)>>1]|0;if((a[(c[277215]|0)+s|0]&32)!=0){x=b[(c[277221]|0)+((e&65535|67616)-(b[(c[277226]|0)+(l<<1)>>1]&63454)>>1<<1)>>1]|0;break}k=c[277228]&65535;r=e&-2048;q=k&-2048;n=(r&65535)>(q&65535)?r-q&65535:0;q=e&2016;r=k&2016;if((q&65535)>(r&65535)){y=(q-r&65535)+n&65535}else{y=n}n=e&31;e=k&31;if((n&65535)<=(e&65535)){x=y;break}x=(n-e&65535)+y&65535}else{x=0}}while(0);e=s+1|0;b[(c[277218]|0)+(e<<1)>>1]=x;n=a[1108909]|0;a[(c[277219]|0)+e|0]=n;a[(c[277219]|0)+s|0]=n}f=f-1|0;}while((f|0)>-1)}f=g-1|0;if((f|0)>0){g=f;j=(c[277223]|0)+j|0}else{break}}return}function Ws(e,f,g,h,i,j){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0;k=e&1023;l=c[348606]|0;m=(k<<l)+(c[348604]|0)|0;if((e&256|0)==0){n=m}else{n=(c[348602]|0)+m|0}m=n&65535;n=m>>>(l>>>0);l=(e&16384|0)!=0;o=n<<6;do{if(l){p=(c[348622]|0)+o|0;if((a[(c[348618]|0)+n|0]|0)!=0){q=p;break}r=fi[c[348636]&63](p,m,k)|0;a[(c[348618]|0)+n|0]=r;q=p}else{p=(c[348624]|0)+o|0;if((a[(c[348620]|0)+n|0]|0)!=0){q=p;break}r=fi[c[348638]&63](p,m,k)|0;a[(c[348620]|0)+n|0]=r;q=p}}while(0);if((a[(c[348620]|0)+n|0]|0)==2){return}if((a[1394464]|0)==0){s=1106168+((e>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){n=d[1044485]|0;c[276541]=7080+(n<<5);k=0;do{m=k<<1&2;o=k&2;p=k&4;r=0;do{b[1125528+(k<<9)+(r<<1)>>1]=d[(r>>>1&28|o)+(7080+(n<<5))|0]<<6|d[(r<<2&28|m)+(7080+(n<<5))|0]<<11|d[(r>>>3&24|p)+(7080+(n<<5))|0];r=r+1|0;}while(r>>>0<256);k=k+1|0;}while(k>>>0<8);a[1106089]=0}s=1125528+((e>>>10&7)<<9)|0}c[277226]=s;c[277225]=(a[1108928]|0)!=0?1393712:s;if((e&49152|0)==0){if((j|0)<=0){return}s=h&255;k=s-1&255;n=k<<24>>24==0;r=q+((d[1394504]|0)+(i<<1))|0;p=j;m=f;while(1){switch(g|0){case 7:{t=3501;break};case 2:{u=s;t=3471;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+m|0]|0)){o=a[r]|0;if(o<<24>>24==0){break}b[(c[277218]|0)+(m<<1)>>1]=b[(c[277225]|0)+((o&255)<<1)>>1]|0;if((a[1108928]|0)==0){v=b[(c[277213]|0)+(m+2<<1)>>1]|0}else{v=0}o=m+1|0;b[(c[277218]|0)+(o<<1)>>1]=v;w=a[1108909]|0;a[(c[277219]|0)+o|0]=w;a[(c[277219]|0)+m|0]=w}}while(0);if(!n){x=k;t=3465}break};case 6:{y=s;t=3495;break};case 1:{x=s;t=3465;break};case 5:{z=s;t=3489;break};case 3:{A=s;t=3477;break};case 4:{B=s;t=3483;break};default:{}}if((t|0)==3465){t=0;w=m+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+w|0]|0)){o=a[r+1|0]|0;if(o<<24>>24==0){break}b[(c[277218]|0)+(w<<1)>>1]=b[(c[277225]|0)+((o&255)<<1)>>1]|0;if((a[1108928]|0)==0){C=b[(c[277213]|0)+(m+4<<1)>>1]|0}else{C=0}o=m+3|0;b[(c[277218]|0)+(o<<1)>>1]=C;D=a[1108909]|0;a[(c[277219]|0)+o|0]=D;a[(c[277219]|0)+w|0]=D}}while(0);w=x-1&255;if(w<<24>>24!=0){u=w;t=3471}}if((t|0)==3471){t=0;w=m+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+w|0]|0)){D=a[r+2|0]|0;if(D<<24>>24==0){break}b[(c[277218]|0)+(w<<1)>>1]=b[(c[277225]|0)+((D&255)<<1)>>1]|0;if((a[1108928]|0)==0){E=b[(c[277213]|0)+(m+6<<1)>>1]|0}else{E=0}D=m+5|0;b[(c[277218]|0)+(D<<1)>>1]=E;o=a[1108909]|0;a[(c[277219]|0)+D|0]=o;a[(c[277219]|0)+w|0]=o}}while(0);w=u-1&255;if(w<<24>>24!=0){A=w;t=3477}}if((t|0)==3477){t=0;w=m+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+w|0]|0)){o=a[r+3|0]|0;if(o<<24>>24==0){break}b[(c[277218]|0)+(w<<1)>>1]=b[(c[277225]|0)+((o&255)<<1)>>1]|0;if((a[1108928]|0)==0){F=b[(c[277213]|0)+(m+8<<1)>>1]|0}else{F=0}o=m+7|0;b[(c[277218]|0)+(o<<1)>>1]=F;D=a[1108909]|0;a[(c[277219]|0)+o|0]=D;a[(c[277219]|0)+w|0]=D}}while(0);w=A-1&255;if(w<<24>>24!=0){B=w;t=3483}}if((t|0)==3483){t=0;w=m+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+w|0]|0)){D=a[r+4|0]|0;if(D<<24>>24==0){break}b[(c[277218]|0)+(w<<1)>>1]=b[(c[277225]|0)+((D&255)<<1)>>1]|0;if((a[1108928]|0)==0){G=b[(c[277213]|0)+(m+10<<1)>>1]|0}else{G=0}D=m+9|0;b[(c[277218]|0)+(D<<1)>>1]=G;o=a[1108909]|0;a[(c[277219]|0)+D|0]=o;a[(c[277219]|0)+w|0]=o}}while(0);w=B-1&255;if(w<<24>>24!=0){z=w;t=3489}}if((t|0)==3489){t=0;w=m+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+w|0]|0)){o=a[r+5|0]|0;if(o<<24>>24==0){break}b[(c[277218]|0)+(w<<1)>>1]=b[(c[277225]|0)+((o&255)<<1)>>1]|0;if((a[1108928]|0)==0){H=b[(c[277213]|0)+(m+12<<1)>>1]|0}else{H=0}o=m+11|0;b[(c[277218]|0)+(o<<1)>>1]=H;D=a[1108909]|0;a[(c[277219]|0)+o|0]=D;a[(c[277219]|0)+w|0]=D}}while(0);w=z-1&255;if(w<<24>>24!=0){y=w;t=3495}}if((t|0)==3495){t=0;w=m+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+w|0]|0)){D=a[r+6|0]|0;if(D<<24>>24==0){break}b[(c[277218]|0)+(w<<1)>>1]=b[(c[277225]|0)+((D&255)<<1)>>1]|0;if((a[1108928]|0)==0){I=b[(c[277213]|0)+(m+14<<1)>>1]|0}else{I=0}D=m+13|0;b[(c[277218]|0)+(D<<1)>>1]=I;o=a[1108909]|0;a[(c[277219]|0)+D|0]=o;a[(c[277219]|0)+w|0]=o}}while(0);if(y<<24>>24!=1){t=3501}}do{if((t|0)==3501){t=0;w=m+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+w|0]|0)){break}o=a[r+7|0]|0;if(o<<24>>24==0){break}b[(c[277218]|0)+(w<<1)>>1]=b[(c[277225]|0)+((o&255)<<1)>>1]|0;if((a[1108928]|0)==0){J=b[(c[277213]|0)+(m+16<<1)>>1]|0}else{J=0}o=m+15|0;b[(c[277218]|0)+(o<<1)>>1]=J;D=a[1108909]|0;a[(c[277219]|0)+o|0]=D;a[(c[277219]|0)+w|0]=D}}while(0);D=p-1|0;if((D|0)>0){r=r+16|0;p=D;m=(c[277223]|0)+m|0}else{break}}return}m=(d[1394504]|0)+(i<<1)|0;if((e&32768|0)==0){if((j|0)<=0){return}e=h&255;i=e-1&255;p=i<<24>>24==0;r=q+m|0;J=j;y=f;while(1){switch(g|0){case 3:{K=e;t=3529;break};case 5:{L=e;t=3541;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+y|0]|0)){I=a[r+7|0]|0;if(I<<24>>24==0){break}b[(c[277218]|0)+(y<<1)>>1]=b[(c[277225]|0)+((I&255)<<1)>>1]|0;if((a[1108928]|0)==0){M=b[(c[277213]|0)+(y+2<<1)>>1]|0}else{M=0}I=y+1|0;b[(c[277218]|0)+(I<<1)>>1]=M;z=a[1108909]|0;a[(c[277219]|0)+I|0]=z;a[(c[277219]|0)+y|0]=z}}while(0);if(!p){N=i;t=3517}break};case 6:{O=e;t=3547;break};case 7:{t=3553;break};case 4:{P=e;t=3535;break};case 2:{Q=e;t=3523;break};case 1:{N=e;t=3517;break};default:{}}if((t|0)==3517){t=0;z=y+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+z|0]|0)){I=a[r+6|0]|0;if(I<<24>>24==0){break}b[(c[277218]|0)+(z<<1)>>1]=b[(c[277225]|0)+((I&255)<<1)>>1]|0;if((a[1108928]|0)==0){R=b[(c[277213]|0)+(y+4<<1)>>1]|0}else{R=0}I=y+3|0;b[(c[277218]|0)+(I<<1)>>1]=R;H=a[1108909]|0;a[(c[277219]|0)+I|0]=H;a[(c[277219]|0)+z|0]=H}}while(0);z=N-1&255;if(z<<24>>24!=0){Q=z;t=3523}}if((t|0)==3523){t=0;z=y+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+z|0]|0)){H=a[r+5|0]|0;if(H<<24>>24==0){break}b[(c[277218]|0)+(z<<1)>>1]=b[(c[277225]|0)+((H&255)<<1)>>1]|0;if((a[1108928]|0)==0){S=b[(c[277213]|0)+(y+6<<1)>>1]|0}else{S=0}H=y+5|0;b[(c[277218]|0)+(H<<1)>>1]=S;I=a[1108909]|0;a[(c[277219]|0)+H|0]=I;a[(c[277219]|0)+z|0]=I}}while(0);z=Q-1&255;if(z<<24>>24!=0){K=z;t=3529}}if((t|0)==3529){t=0;z=y+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+z|0]|0)){I=a[r+4|0]|0;if(I<<24>>24==0){break}b[(c[277218]|0)+(z<<1)>>1]=b[(c[277225]|0)+((I&255)<<1)>>1]|0;if((a[1108928]|0)==0){T=b[(c[277213]|0)+(y+8<<1)>>1]|0}else{T=0}I=y+7|0;b[(c[277218]|0)+(I<<1)>>1]=T;H=a[1108909]|0;a[(c[277219]|0)+I|0]=H;a[(c[277219]|0)+z|0]=H}}while(0);z=K-1&255;if(z<<24>>24!=0){P=z;t=3535}}if((t|0)==3535){t=0;z=y+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+z|0]|0)){H=a[r+3|0]|0;if(H<<24>>24==0){break}b[(c[277218]|0)+(z<<1)>>1]=b[(c[277225]|0)+((H&255)<<1)>>1]|0;if((a[1108928]|0)==0){U=b[(c[277213]|0)+(y+10<<1)>>1]|0}else{U=0}H=y+9|0;b[(c[277218]|0)+(H<<1)>>1]=U;I=a[1108909]|0;a[(c[277219]|0)+H|0]=I;a[(c[277219]|0)+z|0]=I}}while(0);z=P-1&255;if(z<<24>>24!=0){L=z;t=3541}}if((t|0)==3541){t=0;z=y+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+z|0]|0)){I=a[r+2|0]|0;if(I<<24>>24==0){break}b[(c[277218]|0)+(z<<1)>>1]=b[(c[277225]|0)+((I&255)<<1)>>1]|0;if((a[1108928]|0)==0){V=b[(c[277213]|0)+(y+12<<1)>>1]|0}else{V=0}I=y+11|0;b[(c[277218]|0)+(I<<1)>>1]=V;H=a[1108909]|0;a[(c[277219]|0)+I|0]=H;a[(c[277219]|0)+z|0]=H}}while(0);z=L-1&255;if(z<<24>>24!=0){O=z;t=3547}}if((t|0)==3547){t=0;z=y+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+z|0]|0)){H=a[r+1|0]|0;if(H<<24>>24==0){break}b[(c[277218]|0)+(z<<1)>>1]=b[(c[277225]|0)+((H&255)<<1)>>1]|0;if((a[1108928]|0)==0){W=b[(c[277213]|0)+(y+14<<1)>>1]|0}else{W=0}H=y+13|0;b[(c[277218]|0)+(H<<1)>>1]=W;I=a[1108909]|0;a[(c[277219]|0)+H|0]=I;a[(c[277219]|0)+z|0]=I}}while(0);if(O<<24>>24!=1){t=3553}}do{if((t|0)==3553){t=0;z=y+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+z|0]|0)){break}I=a[r]|0;if(I<<24>>24==0){break}b[(c[277218]|0)+(z<<1)>>1]=b[(c[277225]|0)+((I&255)<<1)>>1]|0;if((a[1108928]|0)==0){X=b[(c[277213]|0)+(y+16<<1)>>1]|0}else{X=0}I=y+15|0;b[(c[277218]|0)+(I<<1)>>1]=X;H=a[1108909]|0;a[(c[277219]|0)+I|0]=H;a[(c[277219]|0)+z|0]=H}}while(0);H=J-1|0;if((H|0)>0){r=r+16|0;J=H;y=(c[277223]|0)+y|0}else{break}}return}y=q+(56-m)|0;m=(j|0)>0;if(l){if(!m){return}l=h&255;q=l-1&255;J=q<<24>>24==0;r=y;X=j;O=f;while(1){switch(g|0){case 2:{Y=l;t=3626;break};case 3:{Z=l;t=3632;break};case 4:{_=l;t=3638;break};case 5:{$=l;t=3644;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+O|0]|0)){W=a[r+7|0]|0;if(W<<24>>24==0){break}b[(c[277218]|0)+(O<<1)>>1]=b[(c[277225]|0)+((W&255)<<1)>>1]|0;if((a[1108928]|0)==0){aa=b[(c[277213]|0)+(O+2<<1)>>1]|0}else{aa=0}W=O+1|0;b[(c[277218]|0)+(W<<1)>>1]=aa;L=a[1108909]|0;a[(c[277219]|0)+W|0]=L;a[(c[277219]|0)+O|0]=L}}while(0);if(!J){ab=q;t=3620}break};case 1:{ab=l;t=3620;break};case 6:{ac=l;t=3650;break};case 7:{t=3656;break};default:{}}if((t|0)==3620){t=0;L=O+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+L|0]|0)){W=a[r+6|0]|0;if(W<<24>>24==0){break}b[(c[277218]|0)+(L<<1)>>1]=b[(c[277225]|0)+((W&255)<<1)>>1]|0;if((a[1108928]|0)==0){ad=b[(c[277213]|0)+(O+4<<1)>>1]|0}else{ad=0}W=O+3|0;b[(c[277218]|0)+(W<<1)>>1]=ad;V=a[1108909]|0;a[(c[277219]|0)+W|0]=V;a[(c[277219]|0)+L|0]=V}}while(0);L=ab-1&255;if(L<<24>>24!=0){Y=L;t=3626}}if((t|0)==3626){t=0;L=O+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+L|0]|0)){V=a[r+5|0]|0;if(V<<24>>24==0){break}b[(c[277218]|0)+(L<<1)>>1]=b[(c[277225]|0)+((V&255)<<1)>>1]|0;if((a[1108928]|0)==0){ae=b[(c[277213]|0)+(O+6<<1)>>1]|0}else{ae=0}V=O+5|0;b[(c[277218]|0)+(V<<1)>>1]=ae;W=a[1108909]|0;a[(c[277219]|0)+V|0]=W;a[(c[277219]|0)+L|0]=W}}while(0);L=Y-1&255;if(L<<24>>24!=0){Z=L;t=3632}}if((t|0)==3632){t=0;L=O+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+L|0]|0)){W=a[r+4|0]|0;if(W<<24>>24==0){break}b[(c[277218]|0)+(L<<1)>>1]=b[(c[277225]|0)+((W&255)<<1)>>1]|0;if((a[1108928]|0)==0){af=b[(c[277213]|0)+(O+8<<1)>>1]|0}else{af=0}W=O+7|0;b[(c[277218]|0)+(W<<1)>>1]=af;V=a[1108909]|0;a[(c[277219]|0)+W|0]=V;a[(c[277219]|0)+L|0]=V}}while(0);L=Z-1&255;if(L<<24>>24!=0){_=L;t=3638}}if((t|0)==3638){t=0;L=O+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+L|0]|0)){V=a[r+3|0]|0;if(V<<24>>24==0){break}b[(c[277218]|0)+(L<<1)>>1]=b[(c[277225]|0)+((V&255)<<1)>>1]|0;if((a[1108928]|0)==0){ag=b[(c[277213]|0)+(O+10<<1)>>1]|0}else{ag=0}V=O+9|0;b[(c[277218]|0)+(V<<1)>>1]=ag;W=a[1108909]|0;a[(c[277219]|0)+V|0]=W;a[(c[277219]|0)+L|0]=W}}while(0);L=_-1&255;if(L<<24>>24!=0){$=L;t=3644}}if((t|0)==3644){t=0;L=O+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+L|0]|0)){W=a[r+2|0]|0;if(W<<24>>24==0){break}b[(c[277218]|0)+(L<<1)>>1]=b[(c[277225]|0)+((W&255)<<1)>>1]|0;if((a[1108928]|0)==0){ah=b[(c[277213]|0)+(O+12<<1)>>1]|0}else{ah=0}W=O+11|0;b[(c[277218]|0)+(W<<1)>>1]=ah;V=a[1108909]|0;a[(c[277219]|0)+W|0]=V;a[(c[277219]|0)+L|0]=V}}while(0);L=$-1&255;if(L<<24>>24!=0){ac=L;t=3650}}if((t|0)==3650){t=0;L=O+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+L|0]|0)){V=a[r+1|0]|0;if(V<<24>>24==0){break}b[(c[277218]|0)+(L<<1)>>1]=b[(c[277225]|0)+((V&255)<<1)>>1]|0;if((a[1108928]|0)==0){ai=b[(c[277213]|0)+(O+14<<1)>>1]|0}else{ai=0}V=O+13|0;b[(c[277218]|0)+(V<<1)>>1]=ai;W=a[1108909]|0;a[(c[277219]|0)+V|0]=W;a[(c[277219]|0)+L|0]=W}}while(0);if(ac<<24>>24!=1){t=3656}}do{if((t|0)==3656){t=0;L=O+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+L|0]|0)){break}W=a[r]|0;if(W<<24>>24==0){break}b[(c[277218]|0)+(L<<1)>>1]=b[(c[277225]|0)+((W&255)<<1)>>1]|0;if((a[1108928]|0)==0){aj=b[(c[277213]|0)+(O+16<<1)>>1]|0}else{aj=0}W=O+15|0;b[(c[277218]|0)+(W<<1)>>1]=aj;V=a[1108909]|0;a[(c[277219]|0)+W|0]=V;a[(c[277219]|0)+L|0]=V}}while(0);V=X-1|0;if((V|0)>0){r=r-16|0;X=V;O=(c[277223]|0)+O|0}else{break}}return}else{if(!m){return}m=h&255;h=m-1&255;O=h<<24>>24==0;X=y;y=j;j=f;while(1){switch(g|0){case 2:{ak=m;t=3577;break};case 3:{al=m;t=3583;break};case 4:{am=m;t=3589;break};case 5:{an=m;t=3595;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+j|0]|0)){f=a[X]|0;if(f<<24>>24==0){break}b[(c[277218]|0)+(j<<1)>>1]=b[(c[277225]|0)+((f&255)<<1)>>1]|0;if((a[1108928]|0)==0){ao=b[(c[277213]|0)+(j+2<<1)>>1]|0}else{ao=0}f=j+1|0;b[(c[277218]|0)+(f<<1)>>1]=ao;r=a[1108909]|0;a[(c[277219]|0)+f|0]=r;a[(c[277219]|0)+j|0]=r}}while(0);if(!O){ap=h;t=3571}break};case 1:{ap=m;t=3571;break};case 6:{aq=m;t=3601;break};case 7:{t=3607;break};default:{}}if((t|0)==3571){t=0;r=j+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+r|0]|0)){f=a[X+1|0]|0;if(f<<24>>24==0){break}b[(c[277218]|0)+(r<<1)>>1]=b[(c[277225]|0)+((f&255)<<1)>>1]|0;if((a[1108928]|0)==0){ar=b[(c[277213]|0)+(j+4<<1)>>1]|0}else{ar=0}f=j+3|0;b[(c[277218]|0)+(f<<1)>>1]=ar;aj=a[1108909]|0;a[(c[277219]|0)+f|0]=aj;a[(c[277219]|0)+r|0]=aj}}while(0);r=ap-1&255;if(r<<24>>24!=0){ak=r;t=3577}}if((t|0)==3577){t=0;r=j+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+r|0]|0)){aj=a[X+2|0]|0;if(aj<<24>>24==0){break}b[(c[277218]|0)+(r<<1)>>1]=b[(c[277225]|0)+((aj&255)<<1)>>1]|0;if((a[1108928]|0)==0){as=b[(c[277213]|0)+(j+6<<1)>>1]|0}else{as=0}aj=j+5|0;b[(c[277218]|0)+(aj<<1)>>1]=as;f=a[1108909]|0;a[(c[277219]|0)+aj|0]=f;a[(c[277219]|0)+r|0]=f}}while(0);r=ak-1&255;if(r<<24>>24!=0){al=r;t=3583}}if((t|0)==3583){t=0;r=j+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+r|0]|0)){f=a[X+3|0]|0;if(f<<24>>24==0){break}b[(c[277218]|0)+(r<<1)>>1]=b[(c[277225]|0)+((f&255)<<1)>>1]|0;if((a[1108928]|0)==0){at=b[(c[277213]|0)+(j+8<<1)>>1]|0}else{at=0}f=j+7|0;b[(c[277218]|0)+(f<<1)>>1]=at;aj=a[1108909]|0;a[(c[277219]|0)+f|0]=aj;a[(c[277219]|0)+r|0]=aj}}while(0);r=al-1&255;if(r<<24>>24!=0){am=r;t=3589}}if((t|0)==3589){t=0;r=j+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+r|0]|0)){aj=a[X+4|0]|0;if(aj<<24>>24==0){break}b[(c[277218]|0)+(r<<1)>>1]=b[(c[277225]|0)+((aj&255)<<1)>>1]|0;if((a[1108928]|0)==0){au=b[(c[277213]|0)+(j+10<<1)>>1]|0}else{au=0}aj=j+9|0;b[(c[277218]|0)+(aj<<1)>>1]=au;f=a[1108909]|0;a[(c[277219]|0)+aj|0]=f;a[(c[277219]|0)+r|0]=f}}while(0);r=am-1&255;if(r<<24>>24!=0){an=r;t=3595}}if((t|0)==3595){t=0;r=j+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+r|0]|0)){f=a[X+5|0]|0;if(f<<24>>24==0){break}b[(c[277218]|0)+(r<<1)>>1]=b[(c[277225]|0)+((f&255)<<1)>>1]|0;if((a[1108928]|0)==0){av=b[(c[277213]|0)+(j+12<<1)>>1]|0}else{av=0}f=j+11|0;b[(c[277218]|0)+(f<<1)>>1]=av;aj=a[1108909]|0;a[(c[277219]|0)+f|0]=aj;a[(c[277219]|0)+r|0]=aj}}while(0);r=an-1&255;if(r<<24>>24!=0){aq=r;t=3601}}if((t|0)==3601){t=0;r=j+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+r|0]|0)){aj=a[X+6|0]|0;if(aj<<24>>24==0){break}b[(c[277218]|0)+(r<<1)>>1]=b[(c[277225]|0)+((aj&255)<<1)>>1]|0;if((a[1108928]|0)==0){aw=b[(c[277213]|0)+(j+14<<1)>>1]|0}else{aw=0}aj=j+13|0;b[(c[277218]|0)+(aj<<1)>>1]=aw;f=a[1108909]|0;a[(c[277219]|0)+aj|0]=f;a[(c[277219]|0)+r|0]=f}}while(0);if(aq<<24>>24!=1){t=3607}}do{if((t|0)==3607){t=0;r=j+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+r|0]|0)){break}f=a[X+7|0]|0;if(f<<24>>24==0){break}b[(c[277218]|0)+(r<<1)>>1]=b[(c[277225]|0)+((f&255)<<1)>>1]|0;if((a[1108928]|0)==0){ax=b[(c[277213]|0)+(j+16<<1)>>1]|0}else{ax=0}f=j+15|0;b[(c[277218]|0)+(f<<1)>>1]=ax;aj=a[1108909]|0;a[(c[277219]|0)+f|0]=aj;a[(c[277219]|0)+r|0]=aj}}while(0);aj=y-1|0;if((aj|0)>0){X=X-16|0;y=aj;j=(c[277223]|0)+j|0}else{break}}return}}function Wt(f,g,h,i,j,k){f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0,cf=0,cg=0,ch=0,ci=0,cj=0,ck=0,cl=0,cm=0,cn=0,co=0,cp=0,cq=0,cr=0,cs=0,ct=0,cu=0,cv=0,cw=0,cx=0,cy=0,cz=0,cA=0,cB=0,cC=0,cD=0,cE=0,cF=0,cG=0,cH=0,cI=0,cJ=0,cK=0,cL=0,cM=0,cN=0,cO=0,cP=0,cQ=0,cR=0,cS=0,cT=0,cU=0,cV=0,cW=0,cX=0,cY=0,cZ=0,c_=0,c$=0,c0=0,c1=0,c2=0,c3=0,c4=0,c5=0,c6=0,c7=0,c8=0,c9=0,da=0,db=0,dc=0,dd=0,de=0,df=0,dg=0,dh=0,di=0,dj=0,dk=0,dl=0,dm=0,dn=0,dp=0,dq=0,dr=0,ds=0,dt=0,du=0,dv=0,dw=0,dx=0,dy=0,dz=0,dA=0,dB=0,dC=0,dD=0,dE=0,dF=0,dG=0,dH=0,dI=0,dJ=0,dK=0,dL=0,dM=0,dN=0,dO=0,dP=0,dQ=0,dR=0,dS=0,dT=0,dU=0,dV=0,dW=0,dX=0,dY=0,dZ=0,d_=0,d$=0,d0=0,d1=0,d2=0,d3=0,d4=0,d5=0,d6=0,d7=0,d8=0,d9=0,ea=0,eb=0,ec=0,ed=0,ee=0,ef=0,eg=0,eh=0,ei=0,ej=0,ek=0,el=0,em=0,en=0,eo=0,ep=0,eq=0,er=0,es=0,et=0,eu=0,ev=0,ew=0,ex=0,ey=0,ez=0,eA=0,eB=0;l=f&1023;m=c[348606]|0;n=(l<<m)+(c[348604]|0)|0;if((f&256|0)==0){o=n}else{o=(c[348602]|0)+n|0}n=o&65535;o=n>>>(m>>>0);m=(f&16384|0)!=0;p=o<<6;do{if(m){q=(c[348622]|0)+p|0;if((a[(c[348618]|0)+o|0]|0)!=0){r=q;break}s=fi[c[348636]&63](q,n,l)|0;a[(c[348618]|0)+o|0]=s;r=q}else{q=(c[348624]|0)+p|0;if((a[(c[348620]|0)+o|0]|0)!=0){r=q;break}s=fi[c[348638]&63](q,n,l)|0;a[(c[348620]|0)+o|0]=s;r=q}}while(0);if((a[(c[348620]|0)+o|0]|0)==2){return}if((a[1394464]|0)==0){t=1106168+((f>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){o=d[1044485]|0;c[276541]=7080+(o<<5);l=0;do{n=l<<1&2;p=l&2;q=l&4;s=0;do{b[1125528+(l<<9)+(s<<1)>>1]=d[(s>>>1&28|p)+(7080+(o<<5))|0]<<6|d[(s<<2&28|n)+(7080+(o<<5))|0]<<11|d[(s>>>3&24|q)+(7080+(o<<5))|0];s=s+1|0;}while(s>>>0<256);l=l+1|0;}while(l>>>0<8);a[1106089]=0}t=1125528+((f>>>10&7)<<9)|0}c[277226]=t;c[277225]=(a[1108928]|0)!=0?1393712:t;if((f&49152|0)==0){if((k|0)<=0){return}t=i&255;l=t-1&255;o=l<<24>>24==0;s=r+((d[1394504]|0)+(j<<1))|0;q=k;n=g;while(1){switch(h|0){case 6:{u=t;v=3843;break};case 7:{v=3868;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+n|0]|0)){p=a[s]|0;w=p&255;if(p<<24>>24==0){break}p=e[(c[277225]|0)+(w<<1)>>1]|0;x=(a[(c[277215]|0)+n|0]&32)==0;if(x){y=c[277228]|0;z=y;A=y&-2082}else{y=e[(c[277213]|0)+(n<<1)>>1]|0;z=y;A=y&63454}if(x){B=c[277228]|0}else{B=e[(c[277213]|0)+(n<<1)>>1]|0}b[(c[277218]|0)+(n<<1)>>1]=((B^p)&2081|e[(c[277220]|0)+((p&2081&z)+((A+(p&63454)|0)>>>1)<<1)>>1])&65535;p=(a[1108928]|0)==0;if(p){C=b[(c[277213]|0)+(n+2<<1)>>1]&63454}else{C=0}x=(a[(c[277215]|0)+n|0]&32)==0;if(x){D=c[277228]|0}else{D=e[(c[277226]|0)+(w<<1)>>1]|0}if(p){E=b[(c[277213]|0)+(n+2<<1)>>1]&2081}else{E=0}if(x){F=c[277228]|0}else{F=e[(c[277226]|0)+(w<<1)>>1]|0}if(p){G=e[(c[277213]|0)+(n+2<<1)>>1]|0}else{G=0}if(x){H=c[277228]|0}else{H=e[(c[277226]|0)+(w<<1)>>1]|0}w=n+1|0;b[(c[277218]|0)+(w<<1)>>1]=((H^G)&2081|e[(c[277220]|0)+((F&E)+(((D&-2082)+C|0)>>>1)<<1)>>1])&65535;x=a[1108909]|0;a[(c[277219]|0)+w|0]=x;a[(c[277219]|0)+n|0]=x}}while(0);if(!o){I=l;v=3718}break};case 1:{I=t;v=3718;break};case 2:{J=t;v=3743;break};case 3:{K=t;v=3768;break};case 4:{L=t;v=3793;break};case 5:{M=t;v=3818;break};default:{}}if((v|0)==3718){v=0;x=n+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+x|0]|0)){w=a[s+1|0]|0;p=w&255;if(w<<24>>24==0){break}w=e[(c[277225]|0)+(p<<1)>>1]|0;y=(a[(c[277215]|0)+x|0]&32)==0;if(y){N=c[277228]|0;O=N;P=N&-2082}else{N=e[(c[277213]|0)+(x<<1)>>1]|0;O=N;P=N&63454}if(y){Q=c[277228]|0}else{Q=e[(c[277213]|0)+(x<<1)>>1]|0}b[(c[277218]|0)+(x<<1)>>1]=((Q^w)&2081|e[(c[277220]|0)+((w&2081&O)+((P+(w&63454)|0)>>>1)<<1)>>1])&65535;w=(a[1108928]|0)==0;if(w){R=b[(c[277213]|0)+(n+4<<1)>>1]&63454}else{R=0}y=(a[(c[277215]|0)+x|0]&32)==0;if(y){S=c[277228]|0}else{S=e[(c[277226]|0)+(p<<1)>>1]|0}if(w){T=b[(c[277213]|0)+(n+4<<1)>>1]&2081}else{T=0}if(y){U=c[277228]|0}else{U=e[(c[277226]|0)+(p<<1)>>1]|0}if(w){V=e[(c[277213]|0)+(n+4<<1)>>1]|0}else{V=0}if(y){W=c[277228]|0}else{W=e[(c[277226]|0)+(p<<1)>>1]|0}p=n+3|0;b[(c[277218]|0)+(p<<1)>>1]=((W^V)&2081|e[(c[277220]|0)+((U&T)+(((S&-2082)+R|0)>>>1)<<1)>>1])&65535;y=a[1108909]|0;a[(c[277219]|0)+p|0]=y;a[(c[277219]|0)+x|0]=y}}while(0);x=I-1&255;if(x<<24>>24!=0){J=x;v=3743}}if((v|0)==3743){v=0;x=n+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+x|0]|0)){y=a[s+2|0]|0;p=y&255;if(y<<24>>24==0){break}y=e[(c[277225]|0)+(p<<1)>>1]|0;w=(a[(c[277215]|0)+x|0]&32)==0;if(w){N=c[277228]|0;X=N;Y=N&-2082}else{N=e[(c[277213]|0)+(x<<1)>>1]|0;X=N;Y=N&63454}if(w){Z=c[277228]|0}else{Z=e[(c[277213]|0)+(x<<1)>>1]|0}b[(c[277218]|0)+(x<<1)>>1]=((Z^y)&2081|e[(c[277220]|0)+((y&2081&X)+((Y+(y&63454)|0)>>>1)<<1)>>1])&65535;y=(a[1108928]|0)==0;if(y){_=b[(c[277213]|0)+(n+6<<1)>>1]&63454}else{_=0}w=(a[(c[277215]|0)+x|0]&32)==0;if(w){$=c[277228]|0}else{$=e[(c[277226]|0)+(p<<1)>>1]|0}if(y){aa=b[(c[277213]|0)+(n+6<<1)>>1]&2081}else{aa=0}if(w){ab=c[277228]|0}else{ab=e[(c[277226]|0)+(p<<1)>>1]|0}if(y){ac=e[(c[277213]|0)+(n+6<<1)>>1]|0}else{ac=0}if(w){ad=c[277228]|0}else{ad=e[(c[277226]|0)+(p<<1)>>1]|0}p=n+5|0;b[(c[277218]|0)+(p<<1)>>1]=((ad^ac)&2081|e[(c[277220]|0)+((ab&aa)+((($&-2082)+_|0)>>>1)<<1)>>1])&65535;w=a[1108909]|0;a[(c[277219]|0)+p|0]=w;a[(c[277219]|0)+x|0]=w}}while(0);x=J-1&255;if(x<<24>>24!=0){K=x;v=3768}}if((v|0)==3768){v=0;x=n+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+x|0]|0)){w=a[s+3|0]|0;p=w&255;if(w<<24>>24==0){break}w=e[(c[277225]|0)+(p<<1)>>1]|0;y=(a[(c[277215]|0)+x|0]&32)==0;if(y){N=c[277228]|0;ae=N;af=N&-2082}else{N=e[(c[277213]|0)+(x<<1)>>1]|0;ae=N;af=N&63454}if(y){ag=c[277228]|0}else{ag=e[(c[277213]|0)+(x<<1)>>1]|0}b[(c[277218]|0)+(x<<1)>>1]=((ag^w)&2081|e[(c[277220]|0)+((w&2081&ae)+((af+(w&63454)|0)>>>1)<<1)>>1])&65535;w=(a[1108928]|0)==0;if(w){ah=b[(c[277213]|0)+(n+8<<1)>>1]&63454}else{ah=0}y=(a[(c[277215]|0)+x|0]&32)==0;if(y){ai=c[277228]|0}else{ai=e[(c[277226]|0)+(p<<1)>>1]|0}if(w){aj=b[(c[277213]|0)+(n+8<<1)>>1]&2081}else{aj=0}if(y){ak=c[277228]|0}else{ak=e[(c[277226]|0)+(p<<1)>>1]|0}if(w){al=e[(c[277213]|0)+(n+8<<1)>>1]|0}else{al=0}if(y){am=c[277228]|0}else{am=e[(c[277226]|0)+(p<<1)>>1]|0}p=n+7|0;b[(c[277218]|0)+(p<<1)>>1]=((am^al)&2081|e[(c[277220]|0)+((ak&aj)+(((ai&-2082)+ah|0)>>>1)<<1)>>1])&65535;y=a[1108909]|0;a[(c[277219]|0)+p|0]=y;a[(c[277219]|0)+x|0]=y}}while(0);x=K-1&255;if(x<<24>>24!=0){L=x;v=3793}}if((v|0)==3793){v=0;x=n+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+x|0]|0)){y=a[s+4|0]|0;p=y&255;if(y<<24>>24==0){break}y=e[(c[277225]|0)+(p<<1)>>1]|0;w=(a[(c[277215]|0)+x|0]&32)==0;if(w){N=c[277228]|0;an=N;ao=N&-2082}else{N=e[(c[277213]|0)+(x<<1)>>1]|0;an=N;ao=N&63454}if(w){ap=c[277228]|0}else{ap=e[(c[277213]|0)+(x<<1)>>1]|0}b[(c[277218]|0)+(x<<1)>>1]=((ap^y)&2081|e[(c[277220]|0)+((y&2081&an)+((ao+(y&63454)|0)>>>1)<<1)>>1])&65535;y=(a[1108928]|0)==0;if(y){aq=b[(c[277213]|0)+(n+10<<1)>>1]&63454}else{aq=0}w=(a[(c[277215]|0)+x|0]&32)==0;if(w){ar=c[277228]|0}else{ar=e[(c[277226]|0)+(p<<1)>>1]|0}if(y){as=b[(c[277213]|0)+(n+10<<1)>>1]&2081}else{as=0}if(w){at=c[277228]|0}else{at=e[(c[277226]|0)+(p<<1)>>1]|0}if(y){au=e[(c[277213]|0)+(n+10<<1)>>1]|0}else{au=0}if(w){av=c[277228]|0}else{av=e[(c[277226]|0)+(p<<1)>>1]|0}p=n+9|0;b[(c[277218]|0)+(p<<1)>>1]=((av^au)&2081|e[(c[277220]|0)+((at&as)+(((ar&-2082)+aq|0)>>>1)<<1)>>1])&65535;w=a[1108909]|0;a[(c[277219]|0)+p|0]=w;a[(c[277219]|0)+x|0]=w}}while(0);x=L-1&255;if(x<<24>>24!=0){M=x;v=3818}}if((v|0)==3818){v=0;x=n+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+x|0]|0)){w=a[s+5|0]|0;p=w&255;if(w<<24>>24==0){break}w=e[(c[277225]|0)+(p<<1)>>1]|0;y=(a[(c[277215]|0)+x|0]&32)==0;if(y){N=c[277228]|0;aw=N;ax=N&-2082}else{N=e[(c[277213]|0)+(x<<1)>>1]|0;aw=N;ax=N&63454}if(y){ay=c[277228]|0}else{ay=e[(c[277213]|0)+(x<<1)>>1]|0}b[(c[277218]|0)+(x<<1)>>1]=((ay^w)&2081|e[(c[277220]|0)+((w&2081&aw)+((ax+(w&63454)|0)>>>1)<<1)>>1])&65535;w=(a[1108928]|0)==0;if(w){az=b[(c[277213]|0)+(n+12<<1)>>1]&63454}else{az=0}y=(a[(c[277215]|0)+x|0]&32)==0;if(y){aA=c[277228]|0}else{aA=e[(c[277226]|0)+(p<<1)>>1]|0}if(w){aB=b[(c[277213]|0)+(n+12<<1)>>1]&2081}else{aB=0}if(y){aC=c[277228]|0}else{aC=e[(c[277226]|0)+(p<<1)>>1]|0}if(w){aD=e[(c[277213]|0)+(n+12<<1)>>1]|0}else{aD=0}if(y){aE=c[277228]|0}else{aE=e[(c[277226]|0)+(p<<1)>>1]|0}p=n+11|0;b[(c[277218]|0)+(p<<1)>>1]=((aE^aD)&2081|e[(c[277220]|0)+((aC&aB)+(((aA&-2082)+az|0)>>>1)<<1)>>1])&65535;y=a[1108909]|0;a[(c[277219]|0)+p|0]=y;a[(c[277219]|0)+x|0]=y}}while(0);x=M-1&255;if(x<<24>>24!=0){u=x;v=3843}}if((v|0)==3843){v=0;x=n+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+x|0]|0)){y=a[s+6|0]|0;p=y&255;if(y<<24>>24==0){break}y=e[(c[277225]|0)+(p<<1)>>1]|0;w=(a[(c[277215]|0)+x|0]&32)==0;if(w){N=c[277228]|0;aF=N;aG=N&-2082}else{N=e[(c[277213]|0)+(x<<1)>>1]|0;aF=N;aG=N&63454}if(w){aH=c[277228]|0}else{aH=e[(c[277213]|0)+(x<<1)>>1]|0}b[(c[277218]|0)+(x<<1)>>1]=((aH^y)&2081|e[(c[277220]|0)+((y&2081&aF)+((aG+(y&63454)|0)>>>1)<<1)>>1])&65535;y=(a[1108928]|0)==0;if(y){aI=b[(c[277213]|0)+(n+14<<1)>>1]&63454}else{aI=0}w=(a[(c[277215]|0)+x|0]&32)==0;if(w){aJ=c[277228]|0}else{aJ=e[(c[277226]|0)+(p<<1)>>1]|0}if(y){aK=b[(c[277213]|0)+(n+14<<1)>>1]&2081}else{aK=0}if(w){aL=c[277228]|0}else{aL=e[(c[277226]|0)+(p<<1)>>1]|0}if(y){aM=e[(c[277213]|0)+(n+14<<1)>>1]|0}else{aM=0}if(w){aN=c[277228]|0}else{aN=e[(c[277226]|0)+(p<<1)>>1]|0}p=n+13|0;b[(c[277218]|0)+(p<<1)>>1]=((aN^aM)&2081|e[(c[277220]|0)+((aL&aK)+(((aJ&-2082)+aI|0)>>>1)<<1)>>1])&65535;w=a[1108909]|0;a[(c[277219]|0)+p|0]=w;a[(c[277219]|0)+x|0]=w}}while(0);if(u<<24>>24!=1){v=3868}}do{if((v|0)==3868){v=0;x=n+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+x|0]|0)){break}w=a[s+7|0]|0;p=w&255;if(w<<24>>24==0){break}w=e[(c[277225]|0)+(p<<1)>>1]|0;y=(a[(c[277215]|0)+x|0]&32)==0;if(y){N=c[277228]|0;aO=N;aP=N&-2082}else{N=e[(c[277213]|0)+(x<<1)>>1]|0;aO=N;aP=N&63454}if(y){aQ=c[277228]|0}else{aQ=e[(c[277213]|0)+(x<<1)>>1]|0}b[(c[277218]|0)+(x<<1)>>1]=((aQ^w)&2081|e[(c[277220]|0)+((w&2081&aO)+((aP+(w&63454)|0)>>>1)<<1)>>1])&65535;w=(a[1108928]|0)==0;if(w){aR=b[(c[277213]|0)+(n+16<<1)>>1]&63454}else{aR=0}y=(a[(c[277215]|0)+x|0]&32)==0;if(y){aS=c[277228]|0}else{aS=e[(c[277226]|0)+(p<<1)>>1]|0}if(w){aT=b[(c[277213]|0)+(n+16<<1)>>1]&2081}else{aT=0}if(y){aU=c[277228]|0}else{aU=e[(c[277226]|0)+(p<<1)>>1]|0}if(w){aV=e[(c[277213]|0)+(n+16<<1)>>1]|0}else{aV=0}if(y){aW=c[277228]|0}else{aW=e[(c[277226]|0)+(p<<1)>>1]|0}p=n+15|0;b[(c[277218]|0)+(p<<1)>>1]=((aW^aV)&2081|e[(c[277220]|0)+((aU&aT)+(((aS&-2082)+aR|0)>>>1)<<1)>>1])&65535;y=a[1108909]|0;a[(c[277219]|0)+p|0]=y;a[(c[277219]|0)+x|0]=y}}while(0);y=q-1|0;if((y|0)>0){s=s+16|0;q=y;n=(c[277223]|0)+n|0}else{break}}return}n=(d[1394504]|0)+(j<<1)|0;if((f&32768|0)==0){if((k|0)<=0){return}f=i&255;j=f-1&255;q=j<<24>>24==0;s=r+n|0;aR=k;aS=g;while(1){switch(h|0){case 1:{aX=f;v=3922;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+aS|0]|0)){aT=a[s+7|0]|0;aU=aT&255;if(aT<<24>>24==0){break}aT=e[(c[277225]|0)+(aU<<1)>>1]|0;aV=(a[(c[277215]|0)+aS|0]&32)==0;if(aV){aW=c[277228]|0;aY=aW;aZ=aW&-2082}else{aW=e[(c[277213]|0)+(aS<<1)>>1]|0;aY=aW;aZ=aW&63454}if(aV){a_=c[277228]|0}else{a_=e[(c[277213]|0)+(aS<<1)>>1]|0}b[(c[277218]|0)+(aS<<1)>>1]=((a_^aT)&2081|e[(c[277220]|0)+((aT&2081&aY)+((aZ+(aT&63454)|0)>>>1)<<1)>>1])&65535;aT=(a[1108928]|0)==0;if(aT){a$=b[(c[277213]|0)+(aS+2<<1)>>1]&63454}else{a$=0}aV=(a[(c[277215]|0)+aS|0]&32)==0;if(aV){a0=c[277228]|0}else{a0=e[(c[277226]|0)+(aU<<1)>>1]|0}if(aT){a1=b[(c[277213]|0)+(aS+2<<1)>>1]&2081}else{a1=0}if(aV){a2=c[277228]|0}else{a2=e[(c[277226]|0)+(aU<<1)>>1]|0}if(aT){a3=e[(c[277213]|0)+(aS+2<<1)>>1]|0}else{a3=0}if(aV){a4=c[277228]|0}else{a4=e[(c[277226]|0)+(aU<<1)>>1]|0}aU=aS+1|0;b[(c[277218]|0)+(aU<<1)>>1]=((a4^a3)&2081|e[(c[277220]|0)+((a2&a1)+(((a0&-2082)+a$|0)>>>1)<<1)>>1])&65535;aV=a[1108909]|0;a[(c[277219]|0)+aU|0]=aV;a[(c[277219]|0)+aS|0]=aV}}while(0);if(!q){aX=j;v=3922}break};case 3:{a5=f;v=3972;break};case 4:{a6=f;v=3997;break};case 2:{a7=f;v=3947;break};case 6:{a8=f;v=4047;break};case 5:{a9=f;v=4022;break};case 7:{v=4072;break};default:{}}if((v|0)==3922){v=0;aV=aS+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+aV|0]|0)){aU=a[s+6|0]|0;aT=aU&255;if(aU<<24>>24==0){break}aU=e[(c[277225]|0)+(aT<<1)>>1]|0;aW=(a[(c[277215]|0)+aV|0]&32)==0;if(aW){aP=c[277228]|0;ba=aP;bb=aP&-2082}else{aP=e[(c[277213]|0)+(aV<<1)>>1]|0;ba=aP;bb=aP&63454}if(aW){bc=c[277228]|0}else{bc=e[(c[277213]|0)+(aV<<1)>>1]|0}b[(c[277218]|0)+(aV<<1)>>1]=((bc^aU)&2081|e[(c[277220]|0)+((aU&2081&ba)+((bb+(aU&63454)|0)>>>1)<<1)>>1])&65535;aU=(a[1108928]|0)==0;if(aU){bd=b[(c[277213]|0)+(aS+4<<1)>>1]&63454}else{bd=0}aW=(a[(c[277215]|0)+aV|0]&32)==0;if(aW){be=c[277228]|0}else{be=e[(c[277226]|0)+(aT<<1)>>1]|0}if(aU){bf=b[(c[277213]|0)+(aS+4<<1)>>1]&2081}else{bf=0}if(aW){bg=c[277228]|0}else{bg=e[(c[277226]|0)+(aT<<1)>>1]|0}if(aU){bh=e[(c[277213]|0)+(aS+4<<1)>>1]|0}else{bh=0}if(aW){bi=c[277228]|0}else{bi=e[(c[277226]|0)+(aT<<1)>>1]|0}aT=aS+3|0;b[(c[277218]|0)+(aT<<1)>>1]=((bi^bh)&2081|e[(c[277220]|0)+((bg&bf)+(((be&-2082)+bd|0)>>>1)<<1)>>1])&65535;aW=a[1108909]|0;a[(c[277219]|0)+aT|0]=aW;a[(c[277219]|0)+aV|0]=aW}}while(0);aV=aX-1&255;if(aV<<24>>24!=0){a7=aV;v=3947}}if((v|0)==3947){v=0;aV=aS+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+aV|0]|0)){aW=a[s+5|0]|0;aT=aW&255;if(aW<<24>>24==0){break}aW=e[(c[277225]|0)+(aT<<1)>>1]|0;aU=(a[(c[277215]|0)+aV|0]&32)==0;if(aU){aP=c[277228]|0;bj=aP;bk=aP&-2082}else{aP=e[(c[277213]|0)+(aV<<1)>>1]|0;bj=aP;bk=aP&63454}if(aU){bl=c[277228]|0}else{bl=e[(c[277213]|0)+(aV<<1)>>1]|0}b[(c[277218]|0)+(aV<<1)>>1]=((bl^aW)&2081|e[(c[277220]|0)+((aW&2081&bj)+((bk+(aW&63454)|0)>>>1)<<1)>>1])&65535;aW=(a[1108928]|0)==0;if(aW){bm=b[(c[277213]|0)+(aS+6<<1)>>1]&63454}else{bm=0}aU=(a[(c[277215]|0)+aV|0]&32)==0;if(aU){bn=c[277228]|0}else{bn=e[(c[277226]|0)+(aT<<1)>>1]|0}if(aW){bo=b[(c[277213]|0)+(aS+6<<1)>>1]&2081}else{bo=0}if(aU){bp=c[277228]|0}else{bp=e[(c[277226]|0)+(aT<<1)>>1]|0}if(aW){bq=e[(c[277213]|0)+(aS+6<<1)>>1]|0}else{bq=0}if(aU){br=c[277228]|0}else{br=e[(c[277226]|0)+(aT<<1)>>1]|0}aT=aS+5|0;b[(c[277218]|0)+(aT<<1)>>1]=((br^bq)&2081|e[(c[277220]|0)+((bp&bo)+(((bn&-2082)+bm|0)>>>1)<<1)>>1])&65535;aU=a[1108909]|0;a[(c[277219]|0)+aT|0]=aU;a[(c[277219]|0)+aV|0]=aU}}while(0);aV=a7-1&255;if(aV<<24>>24!=0){a5=aV;v=3972}}if((v|0)==3972){v=0;aV=aS+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+aV|0]|0)){aU=a[s+4|0]|0;aT=aU&255;if(aU<<24>>24==0){break}aU=e[(c[277225]|0)+(aT<<1)>>1]|0;aW=(a[(c[277215]|0)+aV|0]&32)==0;if(aW){aP=c[277228]|0;bs=aP;bt=aP&-2082}else{aP=e[(c[277213]|0)+(aV<<1)>>1]|0;bs=aP;bt=aP&63454}if(aW){bu=c[277228]|0}else{bu=e[(c[277213]|0)+(aV<<1)>>1]|0}b[(c[277218]|0)+(aV<<1)>>1]=((bu^aU)&2081|e[(c[277220]|0)+((aU&2081&bs)+((bt+(aU&63454)|0)>>>1)<<1)>>1])&65535;aU=(a[1108928]|0)==0;if(aU){bv=b[(c[277213]|0)+(aS+8<<1)>>1]&63454}else{bv=0}aW=(a[(c[277215]|0)+aV|0]&32)==0;if(aW){bw=c[277228]|0}else{bw=e[(c[277226]|0)+(aT<<1)>>1]|0}if(aU){bx=b[(c[277213]|0)+(aS+8<<1)>>1]&2081}else{bx=0}if(aW){by=c[277228]|0}else{by=e[(c[277226]|0)+(aT<<1)>>1]|0}if(aU){bz=e[(c[277213]|0)+(aS+8<<1)>>1]|0}else{bz=0}if(aW){bA=c[277228]|0}else{bA=e[(c[277226]|0)+(aT<<1)>>1]|0}aT=aS+7|0;b[(c[277218]|0)+(aT<<1)>>1]=((bA^bz)&2081|e[(c[277220]|0)+((by&bx)+(((bw&-2082)+bv|0)>>>1)<<1)>>1])&65535;aW=a[1108909]|0;a[(c[277219]|0)+aT|0]=aW;a[(c[277219]|0)+aV|0]=aW}}while(0);aV=a5-1&255;if(aV<<24>>24!=0){a6=aV;v=3997}}if((v|0)==3997){v=0;aV=aS+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+aV|0]|0)){aW=a[s+3|0]|0;aT=aW&255;if(aW<<24>>24==0){break}aW=e[(c[277225]|0)+(aT<<1)>>1]|0;aU=(a[(c[277215]|0)+aV|0]&32)==0;if(aU){aP=c[277228]|0;bB=aP;bC=aP&-2082}else{aP=e[(c[277213]|0)+(aV<<1)>>1]|0;bB=aP;bC=aP&63454}if(aU){bD=c[277228]|0}else{bD=e[(c[277213]|0)+(aV<<1)>>1]|0}b[(c[277218]|0)+(aV<<1)>>1]=((bD^aW)&2081|e[(c[277220]|0)+((aW&2081&bB)+((bC+(aW&63454)|0)>>>1)<<1)>>1])&65535;aW=(a[1108928]|0)==0;if(aW){bE=b[(c[277213]|0)+(aS+10<<1)>>1]&63454}else{bE=0}aU=(a[(c[277215]|0)+aV|0]&32)==0;if(aU){bF=c[277228]|0}else{bF=e[(c[277226]|0)+(aT<<1)>>1]|0}if(aW){bG=b[(c[277213]|0)+(aS+10<<1)>>1]&2081}else{bG=0}if(aU){bH=c[277228]|0}else{bH=e[(c[277226]|0)+(aT<<1)>>1]|0}if(aW){bI=e[(c[277213]|0)+(aS+10<<1)>>1]|0}else{bI=0}if(aU){bJ=c[277228]|0}else{bJ=e[(c[277226]|0)+(aT<<1)>>1]|0}aT=aS+9|0;b[(c[277218]|0)+(aT<<1)>>1]=((bJ^bI)&2081|e[(c[277220]|0)+((bH&bG)+(((bF&-2082)+bE|0)>>>1)<<1)>>1])&65535;aU=a[1108909]|0;a[(c[277219]|0)+aT|0]=aU;a[(c[277219]|0)+aV|0]=aU}}while(0);aV=a6-1&255;if(aV<<24>>24!=0){a9=aV;v=4022}}if((v|0)==4022){v=0;aV=aS+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+aV|0]|0)){aU=a[s+2|0]|0;aT=aU&255;if(aU<<24>>24==0){break}aU=e[(c[277225]|0)+(aT<<1)>>1]|0;aW=(a[(c[277215]|0)+aV|0]&32)==0;if(aW){aP=c[277228]|0;bK=aP;bL=aP&-2082}else{aP=e[(c[277213]|0)+(aV<<1)>>1]|0;bK=aP;bL=aP&63454}if(aW){bM=c[277228]|0}else{bM=e[(c[277213]|0)+(aV<<1)>>1]|0}b[(c[277218]|0)+(aV<<1)>>1]=((bM^aU)&2081|e[(c[277220]|0)+((aU&2081&bK)+((bL+(aU&63454)|0)>>>1)<<1)>>1])&65535;aU=(a[1108928]|0)==0;if(aU){bN=b[(c[277213]|0)+(aS+12<<1)>>1]&63454}else{bN=0}aW=(a[(c[277215]|0)+aV|0]&32)==0;if(aW){bO=c[277228]|0}else{bO=e[(c[277226]|0)+(aT<<1)>>1]|0}if(aU){bP=b[(c[277213]|0)+(aS+12<<1)>>1]&2081}else{bP=0}if(aW){bQ=c[277228]|0}else{bQ=e[(c[277226]|0)+(aT<<1)>>1]|0}if(aU){bR=e[(c[277213]|0)+(aS+12<<1)>>1]|0}else{bR=0}if(aW){bS=c[277228]|0}else{bS=e[(c[277226]|0)+(aT<<1)>>1]|0}aT=aS+11|0;b[(c[277218]|0)+(aT<<1)>>1]=((bS^bR)&2081|e[(c[277220]|0)+((bQ&bP)+(((bO&-2082)+bN|0)>>>1)<<1)>>1])&65535;aW=a[1108909]|0;a[(c[277219]|0)+aT|0]=aW;a[(c[277219]|0)+aV|0]=aW}}while(0);aV=a9-1&255;if(aV<<24>>24!=0){a8=aV;v=4047}}if((v|0)==4047){v=0;aV=aS+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+aV|0]|0)){aW=a[s+1|0]|0;aT=aW&255;if(aW<<24>>24==0){break}aW=e[(c[277225]|0)+(aT<<1)>>1]|0;aU=(a[(c[277215]|0)+aV|0]&32)==0;if(aU){aP=c[277228]|0;bT=aP;bU=aP&-2082}else{aP=e[(c[277213]|0)+(aV<<1)>>1]|0;bT=aP;bU=aP&63454}if(aU){bV=c[277228]|0}else{bV=e[(c[277213]|0)+(aV<<1)>>1]|0}b[(c[277218]|0)+(aV<<1)>>1]=((bV^aW)&2081|e[(c[277220]|0)+((aW&2081&bT)+((bU+(aW&63454)|0)>>>1)<<1)>>1])&65535;aW=(a[1108928]|0)==0;if(aW){bW=b[(c[277213]|0)+(aS+14<<1)>>1]&63454}else{bW=0}aU=(a[(c[277215]|0)+aV|0]&32)==0;if(aU){bX=c[277228]|0}else{bX=e[(c[277226]|0)+(aT<<1)>>1]|0}if(aW){bY=b[(c[277213]|0)+(aS+14<<1)>>1]&2081}else{bY=0}if(aU){bZ=c[277228]|0}else{bZ=e[(c[277226]|0)+(aT<<1)>>1]|0}if(aW){b_=e[(c[277213]|0)+(aS+14<<1)>>1]|0}else{b_=0}if(aU){b$=c[277228]|0}else{b$=e[(c[277226]|0)+(aT<<1)>>1]|0}aT=aS+13|0;b[(c[277218]|0)+(aT<<1)>>1]=((b$^b_)&2081|e[(c[277220]|0)+((bZ&bY)+(((bX&-2082)+bW|0)>>>1)<<1)>>1])&65535;aU=a[1108909]|0;a[(c[277219]|0)+aT|0]=aU;a[(c[277219]|0)+aV|0]=aU}}while(0);if(a8<<24>>24!=1){v=4072}}do{if((v|0)==4072){v=0;aV=aS+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+aV|0]|0)){break}aU=a[s]|0;aT=aU&255;if(aU<<24>>24==0){break}aU=e[(c[277225]|0)+(aT<<1)>>1]|0;aW=(a[(c[277215]|0)+aV|0]&32)==0;if(aW){aP=c[277228]|0;b0=aP;b1=aP&-2082}else{aP=e[(c[277213]|0)+(aV<<1)>>1]|0;b0=aP;b1=aP&63454}if(aW){b2=c[277228]|0}else{b2=e[(c[277213]|0)+(aV<<1)>>1]|0}b[(c[277218]|0)+(aV<<1)>>1]=((b2^aU)&2081|e[(c[277220]|0)+((aU&2081&b0)+((b1+(aU&63454)|0)>>>1)<<1)>>1])&65535;aU=(a[1108928]|0)==0;if(aU){b3=b[(c[277213]|0)+(aS+16<<1)>>1]&63454}else{b3=0}aW=(a[(c[277215]|0)+aV|0]&32)==0;if(aW){b4=c[277228]|0}else{b4=e[(c[277226]|0)+(aT<<1)>>1]|0}if(aU){b5=b[(c[277213]|0)+(aS+16<<1)>>1]&2081}else{b5=0}if(aW){b6=c[277228]|0}else{b6=e[(c[277226]|0)+(aT<<1)>>1]|0}if(aU){b7=e[(c[277213]|0)+(aS+16<<1)>>1]|0}else{b7=0}if(aW){b8=c[277228]|0}else{b8=e[(c[277226]|0)+(aT<<1)>>1]|0}aT=aS+15|0;b[(c[277218]|0)+(aT<<1)>>1]=((b8^b7)&2081|e[(c[277220]|0)+((b6&b5)+(((b4&-2082)+b3|0)>>>1)<<1)>>1])&65535;aW=a[1108909]|0;a[(c[277219]|0)+aT|0]=aW;a[(c[277219]|0)+aV|0]=aW}}while(0);aW=aR-1|0;if((aW|0)>0){s=s+16|0;aR=aW;aS=(c[277223]|0)+aS|0}else{break}}return}aS=r+(56-n)|0;n=(k|0)>0;if(m){if(!n){return}m=i&255;r=m-1&255;aR=r<<24>>24==0;s=aS;b3=k;b4=g;while(1){switch(h|0){case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+b4|0]|0)){b5=a[s+7|0]|0;b6=b5&255;if(b5<<24>>24==0){break}b5=e[(c[277225]|0)+(b6<<1)>>1]|0;b7=(a[(c[277215]|0)+b4|0]&32)==0;if(b7){b8=c[277228]|0;b9=b8;ca=b8&-2082}else{b8=e[(c[277213]|0)+(b4<<1)>>1]|0;b9=b8;ca=b8&63454}if(b7){cb=c[277228]|0}else{cb=e[(c[277213]|0)+(b4<<1)>>1]|0}b[(c[277218]|0)+(b4<<1)>>1]=((cb^b5)&2081|e[(c[277220]|0)+((b5&2081&b9)+((ca+(b5&63454)|0)>>>1)<<1)>>1])&65535;b5=(a[1108928]|0)==0;if(b5){cc=b[(c[277213]|0)+(b4+2<<1)>>1]&63454}else{cc=0}b7=(a[(c[277215]|0)+b4|0]&32)==0;if(b7){cd=c[277228]|0}else{cd=e[(c[277226]|0)+(b6<<1)>>1]|0}if(b5){ce=b[(c[277213]|0)+(b4+2<<1)>>1]&2081}else{ce=0}if(b7){cf=c[277228]|0}else{cf=e[(c[277226]|0)+(b6<<1)>>1]|0}if(b5){cg=e[(c[277213]|0)+(b4+2<<1)>>1]|0}else{cg=0}if(b7){ch=c[277228]|0}else{ch=e[(c[277226]|0)+(b6<<1)>>1]|0}b6=b4+1|0;b[(c[277218]|0)+(b6<<1)>>1]=((ch^cg)&2081|e[(c[277220]|0)+((cf&ce)+(((cd&-2082)+cc|0)>>>1)<<1)>>1])&65535;b7=a[1108909]|0;a[(c[277219]|0)+b6|0]=b7;a[(c[277219]|0)+b4|0]=b7}}while(0);if(!aR){ci=r;v=4329}break};case 1:{ci=m;v=4329;break};case 2:{cj=m;v=4354;break};case 3:{ck=m;v=4379;break};case 4:{cl=m;v=4404;break};case 5:{cm=m;v=4429;break};case 6:{cn=m;v=4454;break};case 7:{v=4479;break};default:{}}if((v|0)==4329){v=0;b7=b4+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+b7|0]|0)){b6=a[s+6|0]|0;b5=b6&255;if(b6<<24>>24==0){break}b6=e[(c[277225]|0)+(b5<<1)>>1]|0;b8=(a[(c[277215]|0)+b7|0]&32)==0;if(b8){b1=c[277228]|0;co=b1;cp=b1&-2082}else{b1=e[(c[277213]|0)+(b7<<1)>>1]|0;co=b1;cp=b1&63454}if(b8){cq=c[277228]|0}else{cq=e[(c[277213]|0)+(b7<<1)>>1]|0}b[(c[277218]|0)+(b7<<1)>>1]=((cq^b6)&2081|e[(c[277220]|0)+((b6&2081&co)+((cp+(b6&63454)|0)>>>1)<<1)>>1])&65535;b6=(a[1108928]|0)==0;if(b6){cr=b[(c[277213]|0)+(b4+4<<1)>>1]&63454}else{cr=0}b8=(a[(c[277215]|0)+b7|0]&32)==0;if(b8){cs=c[277228]|0}else{cs=e[(c[277226]|0)+(b5<<1)>>1]|0}if(b6){ct=b[(c[277213]|0)+(b4+4<<1)>>1]&2081}else{ct=0}if(b8){cu=c[277228]|0}else{cu=e[(c[277226]|0)+(b5<<1)>>1]|0}if(b6){cv=e[(c[277213]|0)+(b4+4<<1)>>1]|0}else{cv=0}if(b8){cw=c[277228]|0}else{cw=e[(c[277226]|0)+(b5<<1)>>1]|0}b5=b4+3|0;b[(c[277218]|0)+(b5<<1)>>1]=((cw^cv)&2081|e[(c[277220]|0)+((cu&ct)+(((cs&-2082)+cr|0)>>>1)<<1)>>1])&65535;b8=a[1108909]|0;a[(c[277219]|0)+b5|0]=b8;a[(c[277219]|0)+b7|0]=b8}}while(0);b7=ci-1&255;if(b7<<24>>24!=0){cj=b7;v=4354}}if((v|0)==4354){v=0;b7=b4+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+b7|0]|0)){b8=a[s+5|0]|0;b5=b8&255;if(b8<<24>>24==0){break}b8=e[(c[277225]|0)+(b5<<1)>>1]|0;b6=(a[(c[277215]|0)+b7|0]&32)==0;if(b6){b1=c[277228]|0;cx=b1;cy=b1&-2082}else{b1=e[(c[277213]|0)+(b7<<1)>>1]|0;cx=b1;cy=b1&63454}if(b6){cz=c[277228]|0}else{cz=e[(c[277213]|0)+(b7<<1)>>1]|0}b[(c[277218]|0)+(b7<<1)>>1]=((cz^b8)&2081|e[(c[277220]|0)+((b8&2081&cx)+((cy+(b8&63454)|0)>>>1)<<1)>>1])&65535;b8=(a[1108928]|0)==0;if(b8){cA=b[(c[277213]|0)+(b4+6<<1)>>1]&63454}else{cA=0}b6=(a[(c[277215]|0)+b7|0]&32)==0;if(b6){cB=c[277228]|0}else{cB=e[(c[277226]|0)+(b5<<1)>>1]|0}if(b8){cC=b[(c[277213]|0)+(b4+6<<1)>>1]&2081}else{cC=0}if(b6){cD=c[277228]|0}else{cD=e[(c[277226]|0)+(b5<<1)>>1]|0}if(b8){cE=e[(c[277213]|0)+(b4+6<<1)>>1]|0}else{cE=0}if(b6){cF=c[277228]|0}else{cF=e[(c[277226]|0)+(b5<<1)>>1]|0}b5=b4+5|0;b[(c[277218]|0)+(b5<<1)>>1]=((cF^cE)&2081|e[(c[277220]|0)+((cD&cC)+(((cB&-2082)+cA|0)>>>1)<<1)>>1])&65535;b6=a[1108909]|0;a[(c[277219]|0)+b5|0]=b6;a[(c[277219]|0)+b7|0]=b6}}while(0);b7=cj-1&255;if(b7<<24>>24!=0){ck=b7;v=4379}}if((v|0)==4379){v=0;b7=b4+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+b7|0]|0)){b6=a[s+4|0]|0;b5=b6&255;if(b6<<24>>24==0){break}b6=e[(c[277225]|0)+(b5<<1)>>1]|0;b8=(a[(c[277215]|0)+b7|0]&32)==0;if(b8){b1=c[277228]|0;cG=b1;cH=b1&-2082}else{b1=e[(c[277213]|0)+(b7<<1)>>1]|0;cG=b1;cH=b1&63454}if(b8){cI=c[277228]|0}else{cI=e[(c[277213]|0)+(b7<<1)>>1]|0}b[(c[277218]|0)+(b7<<1)>>1]=((cI^b6)&2081|e[(c[277220]|0)+((b6&2081&cG)+((cH+(b6&63454)|0)>>>1)<<1)>>1])&65535;b6=(a[1108928]|0)==0;if(b6){cJ=b[(c[277213]|0)+(b4+8<<1)>>1]&63454}else{cJ=0}b8=(a[(c[277215]|0)+b7|0]&32)==0;if(b8){cK=c[277228]|0}else{cK=e[(c[277226]|0)+(b5<<1)>>1]|0}if(b6){cL=b[(c[277213]|0)+(b4+8<<1)>>1]&2081}else{cL=0}if(b8){cM=c[277228]|0}else{cM=e[(c[277226]|0)+(b5<<1)>>1]|0}if(b6){cN=e[(c[277213]|0)+(b4+8<<1)>>1]|0}else{cN=0}if(b8){cO=c[277228]|0}else{cO=e[(c[277226]|0)+(b5<<1)>>1]|0}b5=b4+7|0;b[(c[277218]|0)+(b5<<1)>>1]=((cO^cN)&2081|e[(c[277220]|0)+((cM&cL)+(((cK&-2082)+cJ|0)>>>1)<<1)>>1])&65535;b8=a[1108909]|0;a[(c[277219]|0)+b5|0]=b8;a[(c[277219]|0)+b7|0]=b8}}while(0);b7=ck-1&255;if(b7<<24>>24!=0){cl=b7;v=4404}}if((v|0)==4404){v=0;b7=b4+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+b7|0]|0)){b8=a[s+3|0]|0;b5=b8&255;if(b8<<24>>24==0){break}b8=e[(c[277225]|0)+(b5<<1)>>1]|0;b6=(a[(c[277215]|0)+b7|0]&32)==0;if(b6){b1=c[277228]|0;cP=b1;cQ=b1&-2082}else{b1=e[(c[277213]|0)+(b7<<1)>>1]|0;cP=b1;cQ=b1&63454}if(b6){cR=c[277228]|0}else{cR=e[(c[277213]|0)+(b7<<1)>>1]|0}b[(c[277218]|0)+(b7<<1)>>1]=((cR^b8)&2081|e[(c[277220]|0)+((b8&2081&cP)+((cQ+(b8&63454)|0)>>>1)<<1)>>1])&65535;b8=(a[1108928]|0)==0;if(b8){cS=b[(c[277213]|0)+(b4+10<<1)>>1]&63454}else{cS=0}b6=(a[(c[277215]|0)+b7|0]&32)==0;if(b6){cT=c[277228]|0}else{cT=e[(c[277226]|0)+(b5<<1)>>1]|0}if(b8){cU=b[(c[277213]|0)+(b4+10<<1)>>1]&2081}else{cU=0}if(b6){cV=c[277228]|0}else{cV=e[(c[277226]|0)+(b5<<1)>>1]|0}if(b8){cW=e[(c[277213]|0)+(b4+10<<1)>>1]|0}else{cW=0}if(b6){cX=c[277228]|0}else{cX=e[(c[277226]|0)+(b5<<1)>>1]|0}b5=b4+9|0;b[(c[277218]|0)+(b5<<1)>>1]=((cX^cW)&2081|e[(c[277220]|0)+((cV&cU)+(((cT&-2082)+cS|0)>>>1)<<1)>>1])&65535;b6=a[1108909]|0;a[(c[277219]|0)+b5|0]=b6;a[(c[277219]|0)+b7|0]=b6}}while(0);b7=cl-1&255;if(b7<<24>>24!=0){cm=b7;v=4429}}if((v|0)==4429){v=0;b7=b4+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+b7|0]|0)){b6=a[s+2|0]|0;b5=b6&255;if(b6<<24>>24==0){break}b6=e[(c[277225]|0)+(b5<<1)>>1]|0;b8=(a[(c[277215]|0)+b7|0]&32)==0;if(b8){b1=c[277228]|0;cY=b1;cZ=b1&-2082}else{b1=e[(c[277213]|0)+(b7<<1)>>1]|0;cY=b1;cZ=b1&63454}if(b8){c_=c[277228]|0}else{c_=e[(c[277213]|0)+(b7<<1)>>1]|0}b[(c[277218]|0)+(b7<<1)>>1]=((c_^b6)&2081|e[(c[277220]|0)+((b6&2081&cY)+((cZ+(b6&63454)|0)>>>1)<<1)>>1])&65535;b6=(a[1108928]|0)==0;if(b6){c$=b[(c[277213]|0)+(b4+12<<1)>>1]&63454}else{c$=0}b8=(a[(c[277215]|0)+b7|0]&32)==0;if(b8){c0=c[277228]|0}else{c0=e[(c[277226]|0)+(b5<<1)>>1]|0}if(b6){c1=b[(c[277213]|0)+(b4+12<<1)>>1]&2081}else{c1=0}if(b8){c2=c[277228]|0}else{c2=e[(c[277226]|0)+(b5<<1)>>1]|0}if(b6){c3=e[(c[277213]|0)+(b4+12<<1)>>1]|0}else{c3=0}if(b8){c4=c[277228]|0}else{c4=e[(c[277226]|0)+(b5<<1)>>1]|0}b5=b4+11|0;b[(c[277218]|0)+(b5<<1)>>1]=((c4^c3)&2081|e[(c[277220]|0)+((c2&c1)+(((c0&-2082)+c$|0)>>>1)<<1)>>1])&65535;b8=a[1108909]|0;a[(c[277219]|0)+b5|0]=b8;a[(c[277219]|0)+b7|0]=b8}}while(0);b7=cm-1&255;if(b7<<24>>24!=0){cn=b7;v=4454}}if((v|0)==4454){v=0;b7=b4+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+b7|0]|0)){b8=a[s+1|0]|0;b5=b8&255;if(b8<<24>>24==0){break}b8=e[(c[277225]|0)+(b5<<1)>>1]|0;b6=(a[(c[277215]|0)+b7|0]&32)==0;if(b6){b1=c[277228]|0;c5=b1;c6=b1&-2082}else{b1=e[(c[277213]|0)+(b7<<1)>>1]|0;c5=b1;c6=b1&63454}if(b6){c7=c[277228]|0}else{c7=e[(c[277213]|0)+(b7<<1)>>1]|0}b[(c[277218]|0)+(b7<<1)>>1]=((c7^b8)&2081|e[(c[277220]|0)+((b8&2081&c5)+((c6+(b8&63454)|0)>>>1)<<1)>>1])&65535;b8=(a[1108928]|0)==0;if(b8){c8=b[(c[277213]|0)+(b4+14<<1)>>1]&63454}else{c8=0}b6=(a[(c[277215]|0)+b7|0]&32)==0;if(b6){c9=c[277228]|0}else{c9=e[(c[277226]|0)+(b5<<1)>>1]|0}if(b8){da=b[(c[277213]|0)+(b4+14<<1)>>1]&2081}else{da=0}if(b6){db=c[277228]|0}else{db=e[(c[277226]|0)+(b5<<1)>>1]|0}if(b8){dc=e[(c[277213]|0)+(b4+14<<1)>>1]|0}else{dc=0}if(b6){dd=c[277228]|0}else{dd=e[(c[277226]|0)+(b5<<1)>>1]|0}b5=b4+13|0;b[(c[277218]|0)+(b5<<1)>>1]=((dd^dc)&2081|e[(c[277220]|0)+((db&da)+(((c9&-2082)+c8|0)>>>1)<<1)>>1])&65535;b6=a[1108909]|0;a[(c[277219]|0)+b5|0]=b6;a[(c[277219]|0)+b7|0]=b6}}while(0);if(cn<<24>>24!=1){v=4479}}do{if((v|0)==4479){v=0;b7=b4+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+b7|0]|0)){break}b6=a[s]|0;b5=b6&255;if(b6<<24>>24==0){break}b6=e[(c[277225]|0)+(b5<<1)>>1]|0;b8=(a[(c[277215]|0)+b7|0]&32)==0;if(b8){b1=c[277228]|0;de=b1;df=b1&-2082}else{b1=e[(c[277213]|0)+(b7<<1)>>1]|0;de=b1;df=b1&63454}if(b8){dg=c[277228]|0}else{dg=e[(c[277213]|0)+(b7<<1)>>1]|0}b[(c[277218]|0)+(b7<<1)>>1]=((dg^b6)&2081|e[(c[277220]|0)+((b6&2081&de)+((df+(b6&63454)|0)>>>1)<<1)>>1])&65535;b6=(a[1108928]|0)==0;if(b6){dh=b[(c[277213]|0)+(b4+16<<1)>>1]&63454}else{dh=0}b8=(a[(c[277215]|0)+b7|0]&32)==0;if(b8){di=c[277228]|0}else{di=e[(c[277226]|0)+(b5<<1)>>1]|0}if(b6){dj=b[(c[277213]|0)+(b4+16<<1)>>1]&2081}else{dj=0}if(b8){dk=c[277228]|0}else{dk=e[(c[277226]|0)+(b5<<1)>>1]|0}if(b6){dl=e[(c[277213]|0)+(b4+16<<1)>>1]|0}else{dl=0}if(b8){dm=c[277228]|0}else{dm=e[(c[277226]|0)+(b5<<1)>>1]|0}b5=b4+15|0;b[(c[277218]|0)+(b5<<1)>>1]=((dm^dl)&2081|e[(c[277220]|0)+((dk&dj)+(((di&-2082)+dh|0)>>>1)<<1)>>1])&65535;b8=a[1108909]|0;a[(c[277219]|0)+b5|0]=b8;a[(c[277219]|0)+b7|0]=b8}}while(0);b8=b3-1|0;if((b8|0)>0){s=s-16|0;b3=b8;b4=(c[277223]|0)+b4|0}else{break}}return}else{if(!n){return}n=i&255;i=n-1&255;b4=i<<24>>24==0;b3=aS;aS=k;k=g;while(1){switch(h|0){case 3:{dn=n;v=4178;break};case 2:{dp=n;v=4153;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+k|0]|0)){g=a[b3]|0;s=g&255;if(g<<24>>24==0){break}g=e[(c[277225]|0)+(s<<1)>>1]|0;dh=(a[(c[277215]|0)+k|0]&32)==0;if(dh){di=c[277228]|0;dq=di;dr=di&-2082}else{di=e[(c[277213]|0)+(k<<1)>>1]|0;dq=di;dr=di&63454}if(dh){ds=c[277228]|0}else{ds=e[(c[277213]|0)+(k<<1)>>1]|0}b[(c[277218]|0)+(k<<1)>>1]=((ds^g)&2081|e[(c[277220]|0)+((g&2081&dq)+((dr+(g&63454)|0)>>>1)<<1)>>1])&65535;g=(a[1108928]|0)==0;if(g){dt=b[(c[277213]|0)+(k+2<<1)>>1]&63454}else{dt=0}dh=(a[(c[277215]|0)+k|0]&32)==0;if(dh){du=c[277228]|0}else{du=e[(c[277226]|0)+(s<<1)>>1]|0}if(g){dv=b[(c[277213]|0)+(k+2<<1)>>1]&2081}else{dv=0}if(dh){dw=c[277228]|0}else{dw=e[(c[277226]|0)+(s<<1)>>1]|0}if(g){dx=e[(c[277213]|0)+(k+2<<1)>>1]|0}else{dx=0}if(dh){dy=c[277228]|0}else{dy=e[(c[277226]|0)+(s<<1)>>1]|0}s=k+1|0;b[(c[277218]|0)+(s<<1)>>1]=((dy^dx)&2081|e[(c[277220]|0)+((dw&dv)+(((du&-2082)+dt|0)>>>1)<<1)>>1])&65535;dh=a[1108909]|0;a[(c[277219]|0)+s|0]=dh;a[(c[277219]|0)+k|0]=dh}}while(0);if(!b4){dz=i;v=4128}break};case 1:{dz=n;v=4128;break};case 4:{dA=n;v=4203;break};case 5:{dB=n;v=4228;break};case 6:{dC=n;v=4253;break};case 7:{v=4278;break};default:{}}if((v|0)==4128){v=0;dh=k+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+dh|0]|0)){s=a[b3+1|0]|0;g=s&255;if(s<<24>>24==0){break}s=e[(c[277225]|0)+(g<<1)>>1]|0;di=(a[(c[277215]|0)+dh|0]&32)==0;if(di){dj=c[277228]|0;dD=dj;dE=dj&-2082}else{dj=e[(c[277213]|0)+(dh<<1)>>1]|0;dD=dj;dE=dj&63454}if(di){dF=c[277228]|0}else{dF=e[(c[277213]|0)+(dh<<1)>>1]|0}b[(c[277218]|0)+(dh<<1)>>1]=((dF^s)&2081|e[(c[277220]|0)+((s&2081&dD)+((dE+(s&63454)|0)>>>1)<<1)>>1])&65535;s=(a[1108928]|0)==0;if(s){dG=b[(c[277213]|0)+(k+4<<1)>>1]&63454}else{dG=0}di=(a[(c[277215]|0)+dh|0]&32)==0;if(di){dH=c[277228]|0}else{dH=e[(c[277226]|0)+(g<<1)>>1]|0}if(s){dI=b[(c[277213]|0)+(k+4<<1)>>1]&2081}else{dI=0}if(di){dJ=c[277228]|0}else{dJ=e[(c[277226]|0)+(g<<1)>>1]|0}if(s){dK=e[(c[277213]|0)+(k+4<<1)>>1]|0}else{dK=0}if(di){dL=c[277228]|0}else{dL=e[(c[277226]|0)+(g<<1)>>1]|0}g=k+3|0;b[(c[277218]|0)+(g<<1)>>1]=((dL^dK)&2081|e[(c[277220]|0)+((dJ&dI)+(((dH&-2082)+dG|0)>>>1)<<1)>>1])&65535;di=a[1108909]|0;a[(c[277219]|0)+g|0]=di;a[(c[277219]|0)+dh|0]=di}}while(0);dh=dz-1&255;if(dh<<24>>24!=0){dp=dh;v=4153}}if((v|0)==4153){v=0;dh=k+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+dh|0]|0)){di=a[b3+2|0]|0;g=di&255;if(di<<24>>24==0){break}di=e[(c[277225]|0)+(g<<1)>>1]|0;s=(a[(c[277215]|0)+dh|0]&32)==0;if(s){dj=c[277228]|0;dM=dj;dN=dj&-2082}else{dj=e[(c[277213]|0)+(dh<<1)>>1]|0;dM=dj;dN=dj&63454}if(s){dO=c[277228]|0}else{dO=e[(c[277213]|0)+(dh<<1)>>1]|0}b[(c[277218]|0)+(dh<<1)>>1]=((dO^di)&2081|e[(c[277220]|0)+((di&2081&dM)+((dN+(di&63454)|0)>>>1)<<1)>>1])&65535;di=(a[1108928]|0)==0;if(di){dP=b[(c[277213]|0)+(k+6<<1)>>1]&63454}else{dP=0}s=(a[(c[277215]|0)+dh|0]&32)==0;if(s){dQ=c[277228]|0}else{dQ=e[(c[277226]|0)+(g<<1)>>1]|0}if(di){dR=b[(c[277213]|0)+(k+6<<1)>>1]&2081}else{dR=0}if(s){dS=c[277228]|0}else{dS=e[(c[277226]|0)+(g<<1)>>1]|0}if(di){dT=e[(c[277213]|0)+(k+6<<1)>>1]|0}else{dT=0}if(s){dU=c[277228]|0}else{dU=e[(c[277226]|0)+(g<<1)>>1]|0}g=k+5|0;b[(c[277218]|0)+(g<<1)>>1]=((dU^dT)&2081|e[(c[277220]|0)+((dS&dR)+(((dQ&-2082)+dP|0)>>>1)<<1)>>1])&65535;s=a[1108909]|0;a[(c[277219]|0)+g|0]=s;a[(c[277219]|0)+dh|0]=s}}while(0);dh=dp-1&255;if(dh<<24>>24!=0){dn=dh;v=4178}}if((v|0)==4178){v=0;dh=k+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+dh|0]|0)){s=a[b3+3|0]|0;g=s&255;if(s<<24>>24==0){break}s=e[(c[277225]|0)+(g<<1)>>1]|0;di=(a[(c[277215]|0)+dh|0]&32)==0;if(di){dj=c[277228]|0;dV=dj;dW=dj&-2082}else{dj=e[(c[277213]|0)+(dh<<1)>>1]|0;dV=dj;dW=dj&63454}if(di){dX=c[277228]|0}else{dX=e[(c[277213]|0)+(dh<<1)>>1]|0}b[(c[277218]|0)+(dh<<1)>>1]=((dX^s)&2081|e[(c[277220]|0)+((s&2081&dV)+((dW+(s&63454)|0)>>>1)<<1)>>1])&65535;s=(a[1108928]|0)==0;if(s){dY=b[(c[277213]|0)+(k+8<<1)>>1]&63454}else{dY=0}di=(a[(c[277215]|0)+dh|0]&32)==0;if(di){dZ=c[277228]|0}else{dZ=e[(c[277226]|0)+(g<<1)>>1]|0}if(s){d_=b[(c[277213]|0)+(k+8<<1)>>1]&2081}else{d_=0}if(di){d$=c[277228]|0}else{d$=e[(c[277226]|0)+(g<<1)>>1]|0}if(s){d0=e[(c[277213]|0)+(k+8<<1)>>1]|0}else{d0=0}if(di){d1=c[277228]|0}else{d1=e[(c[277226]|0)+(g<<1)>>1]|0}g=k+7|0;b[(c[277218]|0)+(g<<1)>>1]=((d1^d0)&2081|e[(c[277220]|0)+((d$&d_)+(((dZ&-2082)+dY|0)>>>1)<<1)>>1])&65535;di=a[1108909]|0;a[(c[277219]|0)+g|0]=di;a[(c[277219]|0)+dh|0]=di}}while(0);dh=dn-1&255;if(dh<<24>>24!=0){dA=dh;v=4203}}if((v|0)==4203){v=0;dh=k+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+dh|0]|0)){di=a[b3+4|0]|0;g=di&255;if(di<<24>>24==0){break}di=e[(c[277225]|0)+(g<<1)>>1]|0;s=(a[(c[277215]|0)+dh|0]&32)==0;if(s){dj=c[277228]|0;d2=dj;d3=dj&-2082}else{dj=e[(c[277213]|0)+(dh<<1)>>1]|0;d2=dj;d3=dj&63454}if(s){d4=c[277228]|0}else{d4=e[(c[277213]|0)+(dh<<1)>>1]|0}b[(c[277218]|0)+(dh<<1)>>1]=((d4^di)&2081|e[(c[277220]|0)+((di&2081&d2)+((d3+(di&63454)|0)>>>1)<<1)>>1])&65535;di=(a[1108928]|0)==0;if(di){d5=b[(c[277213]|0)+(k+10<<1)>>1]&63454}else{d5=0}s=(a[(c[277215]|0)+dh|0]&32)==0;if(s){d6=c[277228]|0}else{d6=e[(c[277226]|0)+(g<<1)>>1]|0}if(di){d7=b[(c[277213]|0)+(k+10<<1)>>1]&2081}else{d7=0}if(s){d8=c[277228]|0}else{d8=e[(c[277226]|0)+(g<<1)>>1]|0}if(di){d9=e[(c[277213]|0)+(k+10<<1)>>1]|0}else{d9=0}if(s){ea=c[277228]|0}else{ea=e[(c[277226]|0)+(g<<1)>>1]|0}g=k+9|0;b[(c[277218]|0)+(g<<1)>>1]=((ea^d9)&2081|e[(c[277220]|0)+((d8&d7)+(((d6&-2082)+d5|0)>>>1)<<1)>>1])&65535;s=a[1108909]|0;a[(c[277219]|0)+g|0]=s;a[(c[277219]|0)+dh|0]=s}}while(0);dh=dA-1&255;if(dh<<24>>24!=0){dB=dh;v=4228}}if((v|0)==4228){v=0;dh=k+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+dh|0]|0)){s=a[b3+5|0]|0;g=s&255;if(s<<24>>24==0){break}s=e[(c[277225]|0)+(g<<1)>>1]|0;di=(a[(c[277215]|0)+dh|0]&32)==0;if(di){dj=c[277228]|0;eb=dj;ec=dj&-2082}else{dj=e[(c[277213]|0)+(dh<<1)>>1]|0;eb=dj;ec=dj&63454}if(di){ed=c[277228]|0}else{ed=e[(c[277213]|0)+(dh<<1)>>1]|0}b[(c[277218]|0)+(dh<<1)>>1]=((ed^s)&2081|e[(c[277220]|0)+((s&2081&eb)+((ec+(s&63454)|0)>>>1)<<1)>>1])&65535;s=(a[1108928]|0)==0;if(s){ee=b[(c[277213]|0)+(k+12<<1)>>1]&63454}else{ee=0}di=(a[(c[277215]|0)+dh|0]&32)==0;if(di){ef=c[277228]|0}else{ef=e[(c[277226]|0)+(g<<1)>>1]|0}if(s){eg=b[(c[277213]|0)+(k+12<<1)>>1]&2081}else{eg=0}if(di){eh=c[277228]|0}else{eh=e[(c[277226]|0)+(g<<1)>>1]|0}if(s){ei=e[(c[277213]|0)+(k+12<<1)>>1]|0}else{ei=0}if(di){ej=c[277228]|0}else{ej=e[(c[277226]|0)+(g<<1)>>1]|0}g=k+11|0;b[(c[277218]|0)+(g<<1)>>1]=((ej^ei)&2081|e[(c[277220]|0)+((eh&eg)+(((ef&-2082)+ee|0)>>>1)<<1)>>1])&65535;di=a[1108909]|0;a[(c[277219]|0)+g|0]=di;a[(c[277219]|0)+dh|0]=di}}while(0);dh=dB-1&255;if(dh<<24>>24!=0){dC=dh;v=4253}}if((v|0)==4253){v=0;dh=k+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+dh|0]|0)){di=a[b3+6|0]|0;g=di&255;if(di<<24>>24==0){break}di=e[(c[277225]|0)+(g<<1)>>1]|0;s=(a[(c[277215]|0)+dh|0]&32)==0;if(s){dj=c[277228]|0;ek=dj;el=dj&-2082}else{dj=e[(c[277213]|0)+(dh<<1)>>1]|0;ek=dj;el=dj&63454}if(s){em=c[277228]|0}else{em=e[(c[277213]|0)+(dh<<1)>>1]|0}b[(c[277218]|0)+(dh<<1)>>1]=((em^di)&2081|e[(c[277220]|0)+((di&2081&ek)+((el+(di&63454)|0)>>>1)<<1)>>1])&65535;di=(a[1108928]|0)==0;if(di){en=b[(c[277213]|0)+(k+14<<1)>>1]&63454}else{en=0}s=(a[(c[277215]|0)+dh|0]&32)==0;if(s){eo=c[277228]|0}else{eo=e[(c[277226]|0)+(g<<1)>>1]|0}if(di){ep=b[(c[277213]|0)+(k+14<<1)>>1]&2081}else{ep=0}if(s){eq=c[277228]|0}else{eq=e[(c[277226]|0)+(g<<1)>>1]|0}if(di){er=e[(c[277213]|0)+(k+14<<1)>>1]|0}else{er=0}if(s){es=c[277228]|0}else{es=e[(c[277226]|0)+(g<<1)>>1]|0}g=k+13|0;b[(c[277218]|0)+(g<<1)>>1]=((es^er)&2081|e[(c[277220]|0)+((eq&ep)+(((eo&-2082)+en|0)>>>1)<<1)>>1])&65535;s=a[1108909]|0;a[(c[277219]|0)+g|0]=s;a[(c[277219]|0)+dh|0]=s}}while(0);if(dC<<24>>24!=1){v=4278}}do{if((v|0)==4278){v=0;dh=k+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+dh|0]|0)){break}s=a[b3+7|0]|0;g=s&255;if(s<<24>>24==0){break}s=e[(c[277225]|0)+(g<<1)>>1]|0;di=(a[(c[277215]|0)+dh|0]&32)==0;if(di){dj=c[277228]|0;et=dj;eu=dj&-2082}else{dj=e[(c[277213]|0)+(dh<<1)>>1]|0;et=dj;eu=dj&63454}if(di){ev=c[277228]|0}else{ev=e[(c[277213]|0)+(dh<<1)>>1]|0}b[(c[277218]|0)+(dh<<1)>>1]=((ev^s)&2081|e[(c[277220]|0)+((s&2081&et)+((eu+(s&63454)|0)>>>1)<<1)>>1])&65535;s=(a[1108928]|0)==0;if(s){ew=b[(c[277213]|0)+(k+16<<1)>>1]&63454}else{ew=0}di=(a[(c[277215]|0)+dh|0]&32)==0;if(di){ex=c[277228]|0}else{ex=e[(c[277226]|0)+(g<<1)>>1]|0}if(s){ey=b[(c[277213]|0)+(k+16<<1)>>1]&2081}else{ey=0}if(di){ez=c[277228]|0}else{ez=e[(c[277226]|0)+(g<<1)>>1]|0}if(s){eA=e[(c[277213]|0)+(k+16<<1)>>1]|0}else{eA=0}if(di){eB=c[277228]|0}else{eB=e[(c[277226]|0)+(g<<1)>>1]|0}g=k+15|0;b[(c[277218]|0)+(g<<1)>>1]=((eB^eA)&2081|e[(c[277220]|0)+((ez&ey)+(((ex&-2082)+ew|0)>>>1)<<1)>>1])&65535;di=a[1108909]|0;a[(c[277219]|0)+g|0]=di;a[(c[277219]|0)+dh|0]=di}}while(0);di=aS-1|0;if((di|0)>0){b3=b3-16|0;aS=di;k=(c[277223]|0)+k|0}else{break}}return}}function Wu(f,g,h,i,j,k){f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0;l=f&1023;m=c[348606]|0;n=(l<<m)+(c[348604]|0)|0;if((f&256|0)==0){o=n}else{o=(c[348602]|0)+n|0}n=o&65535;o=n>>>(m>>>0);m=(f&16384|0)!=0;p=o<<6;do{if(m){q=(c[348622]|0)+p|0;if((a[(c[348618]|0)+o|0]|0)!=0){r=q;break}s=fi[c[348636]&63](q,n,l)|0;a[(c[348618]|0)+o|0]=s;r=q}else{q=(c[348624]|0)+p|0;if((a[(c[348620]|0)+o|0]|0)!=0){r=q;break}s=fi[c[348638]&63](q,n,l)|0;a[(c[348620]|0)+o|0]=s;r=q}}while(0);if((a[(c[348620]|0)+o|0]|0)==2){return}if((a[1394464]|0)==0){t=1106168+((f>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){o=d[1044485]|0;c[276541]=7080+(o<<5);l=0;do{n=l<<1&2;p=l&2;q=l&4;s=0;do{b[1125528+(l<<9)+(s<<1)>>1]=d[(s>>>1&28|p)+(7080+(o<<5))|0]<<6|d[(s<<2&28|n)+(7080+(o<<5))|0]<<11|d[(s>>>3&24|q)+(7080+(o<<5))|0];s=s+1|0;}while(s>>>0<256);l=l+1|0;}while(l>>>0<8);a[1106089]=0}t=1125528+((f>>>10&7)<<9)|0}c[277226]=t;c[277225]=(a[1108928]|0)!=0?1393712:t;if((f&49152|0)==0){if((k|0)<=0){return}t=i&255;l=t-1&255;o=l<<24>>24==0;s=r+((d[1394504]|0)+(j<<1))|0;q=k;n=g;while(1){switch(h|0){case 4:{u=t;v=4571;break};case 1:{w=t;v=4544;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+n|0]|0)){p=a[s]|0;if(p<<24>>24==0){break}x=e[(c[277225]|0)+((p&255)<<1)>>1]|0;p=c[277228]|0;y=(((x&63454)+(p&-2082)|0)>>>1)+(p&2081&x)|0;if((a[1108928]|0)==0){z=y&65535}else{z=(e[(c[277220]|0)+(y<<1)>>1]|(x^p)&2081)&65535}b[(c[277218]|0)+(n<<1)>>1]=z;if((a[1108928]|0)==0){p=e[(c[277213]|0)+(n+2<<1)>>1]|0;x=c[277228]|0;A=(((p&63454)+(x&128990)|0)>>>1)+(x&2081&p)|0}else{p=c[277228]|0;A=e[(c[277220]|0)+((p>>>1&2147482607)<<1)>>1]|p&2081}p=n+1|0;b[(c[277218]|0)+(p<<1)>>1]=A&65535;x=a[1108909]|0;a[(c[277219]|0)+p|0]=x;a[(c[277219]|0)+n|0]=x}}while(0);if(!o){w=l;v=4544}break};case 2:{B=t;v=4553;break};case 7:{v=4598;break};case 3:{C=t;v=4562;break};case 6:{D=t;v=4589;break};case 5:{E=t;v=4580;break};default:{}}if((v|0)==4544){v=0;x=n+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+x|0]|0)){p=a[s+1|0]|0;if(p<<24>>24==0){break}y=e[(c[277225]|0)+((p&255)<<1)>>1]|0;p=c[277228]|0;F=(((y&63454)+(p&-2082)|0)>>>1)+(p&2081&y)|0;if((a[1108928]|0)==0){G=F&65535}else{G=(e[(c[277220]|0)+(F<<1)>>1]|(y^p)&2081)&65535}b[(c[277218]|0)+(x<<1)>>1]=G;if((a[1108928]|0)==0){p=e[(c[277213]|0)+(n+4<<1)>>1]|0;y=c[277228]|0;H=(((p&63454)+(y&128990)|0)>>>1)+(y&2081&p)|0}else{p=c[277228]|0;H=e[(c[277220]|0)+((p>>>1&2147482607)<<1)>>1]|p&2081}p=n+3|0;b[(c[277218]|0)+(p<<1)>>1]=H&65535;y=a[1108909]|0;a[(c[277219]|0)+p|0]=y;a[(c[277219]|0)+x|0]=y}}while(0);x=w-1&255;if(x<<24>>24!=0){B=x;v=4553}}if((v|0)==4553){v=0;x=n+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+x|0]|0)){y=a[s+2|0]|0;if(y<<24>>24==0){break}p=e[(c[277225]|0)+((y&255)<<1)>>1]|0;y=c[277228]|0;F=(((p&63454)+(y&-2082)|0)>>>1)+(y&2081&p)|0;if((a[1108928]|0)==0){I=F&65535}else{I=(e[(c[277220]|0)+(F<<1)>>1]|(p^y)&2081)&65535}b[(c[277218]|0)+(x<<1)>>1]=I;if((a[1108928]|0)==0){y=e[(c[277213]|0)+(n+6<<1)>>1]|0;p=c[277228]|0;J=(((y&63454)+(p&128990)|0)>>>1)+(p&2081&y)|0}else{y=c[277228]|0;J=e[(c[277220]|0)+((y>>>1&2147482607)<<1)>>1]|y&2081}y=n+5|0;b[(c[277218]|0)+(y<<1)>>1]=J&65535;p=a[1108909]|0;a[(c[277219]|0)+y|0]=p;a[(c[277219]|0)+x|0]=p}}while(0);x=B-1&255;if(x<<24>>24!=0){C=x;v=4562}}if((v|0)==4562){v=0;x=n+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+x|0]|0)){p=a[s+3|0]|0;if(p<<24>>24==0){break}y=e[(c[277225]|0)+((p&255)<<1)>>1]|0;p=c[277228]|0;F=(((y&63454)+(p&-2082)|0)>>>1)+(p&2081&y)|0;if((a[1108928]|0)==0){K=F&65535}else{K=(e[(c[277220]|0)+(F<<1)>>1]|(y^p)&2081)&65535}b[(c[277218]|0)+(x<<1)>>1]=K;if((a[1108928]|0)==0){p=e[(c[277213]|0)+(n+8<<1)>>1]|0;y=c[277228]|0;L=(((p&63454)+(y&128990)|0)>>>1)+(y&2081&p)|0}else{p=c[277228]|0;L=e[(c[277220]|0)+((p>>>1&2147482607)<<1)>>1]|p&2081}p=n+7|0;b[(c[277218]|0)+(p<<1)>>1]=L&65535;y=a[1108909]|0;a[(c[277219]|0)+p|0]=y;a[(c[277219]|0)+x|0]=y}}while(0);x=C-1&255;if(x<<24>>24!=0){u=x;v=4571}}if((v|0)==4571){v=0;x=n+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+x|0]|0)){y=a[s+4|0]|0;if(y<<24>>24==0){break}p=e[(c[277225]|0)+((y&255)<<1)>>1]|0;y=c[277228]|0;F=(((p&63454)+(y&-2082)|0)>>>1)+(y&2081&p)|0;if((a[1108928]|0)==0){M=F&65535}else{M=(e[(c[277220]|0)+(F<<1)>>1]|(p^y)&2081)&65535}b[(c[277218]|0)+(x<<1)>>1]=M;if((a[1108928]|0)==0){y=e[(c[277213]|0)+(n+10<<1)>>1]|0;p=c[277228]|0;N=(((y&63454)+(p&128990)|0)>>>1)+(p&2081&y)|0}else{y=c[277228]|0;N=e[(c[277220]|0)+((y>>>1&2147482607)<<1)>>1]|y&2081}y=n+9|0;b[(c[277218]|0)+(y<<1)>>1]=N&65535;p=a[1108909]|0;a[(c[277219]|0)+y|0]=p;a[(c[277219]|0)+x|0]=p}}while(0);x=u-1&255;if(x<<24>>24!=0){E=x;v=4580}}if((v|0)==4580){v=0;x=n+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+x|0]|0)){p=a[s+5|0]|0;if(p<<24>>24==0){break}y=e[(c[277225]|0)+((p&255)<<1)>>1]|0;p=c[277228]|0;F=(((y&63454)+(p&-2082)|0)>>>1)+(p&2081&y)|0;if((a[1108928]|0)==0){O=F&65535}else{O=(e[(c[277220]|0)+(F<<1)>>1]|(y^p)&2081)&65535}b[(c[277218]|0)+(x<<1)>>1]=O;if((a[1108928]|0)==0){p=e[(c[277213]|0)+(n+12<<1)>>1]|0;y=c[277228]|0;P=(((p&63454)+(y&128990)|0)>>>1)+(y&2081&p)|0}else{p=c[277228]|0;P=e[(c[277220]|0)+((p>>>1&2147482607)<<1)>>1]|p&2081}p=n+11|0;b[(c[277218]|0)+(p<<1)>>1]=P&65535;y=a[1108909]|0;a[(c[277219]|0)+p|0]=y;a[(c[277219]|0)+x|0]=y}}while(0);x=E-1&255;if(x<<24>>24!=0){D=x;v=4589}}if((v|0)==4589){v=0;x=n+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+x|0]|0)){y=a[s+6|0]|0;if(y<<24>>24==0){break}p=e[(c[277225]|0)+((y&255)<<1)>>1]|0;y=c[277228]|0;F=(((p&63454)+(y&-2082)|0)>>>1)+(y&2081&p)|0;if((a[1108928]|0)==0){Q=F&65535}else{Q=(e[(c[277220]|0)+(F<<1)>>1]|(p^y)&2081)&65535}b[(c[277218]|0)+(x<<1)>>1]=Q;if((a[1108928]|0)==0){y=e[(c[277213]|0)+(n+14<<1)>>1]|0;p=c[277228]|0;R=(((y&63454)+(p&128990)|0)>>>1)+(p&2081&y)|0}else{y=c[277228]|0;R=e[(c[277220]|0)+((y>>>1&2147482607)<<1)>>1]|y&2081}y=n+13|0;b[(c[277218]|0)+(y<<1)>>1]=R&65535;p=a[1108909]|0;a[(c[277219]|0)+y|0]=p;a[(c[277219]|0)+x|0]=p}}while(0);if(D<<24>>24!=1){v=4598}}do{if((v|0)==4598){v=0;x=n+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+x|0]|0)){break}p=a[s+7|0]|0;if(p<<24>>24==0){break}y=e[(c[277225]|0)+((p&255)<<1)>>1]|0;p=c[277228]|0;F=(((y&63454)+(p&-2082)|0)>>>1)+(p&2081&y)|0;if((a[1108928]|0)==0){S=F&65535}else{S=(e[(c[277220]|0)+(F<<1)>>1]|(y^p)&2081)&65535}b[(c[277218]|0)+(x<<1)>>1]=S;if((a[1108928]|0)==0){p=e[(c[277213]|0)+(n+16<<1)>>1]|0;y=c[277228]|0;T=(((p&63454)+(y&128990)|0)>>>1)+(y&2081&p)|0}else{p=c[277228]|0;T=e[(c[277220]|0)+((p>>>1&2147482607)<<1)>>1]|p&2081}p=n+15|0;b[(c[277218]|0)+(p<<1)>>1]=T&65535;y=a[1108909]|0;a[(c[277219]|0)+p|0]=y;a[(c[277219]|0)+x|0]=y}}while(0);y=q-1|0;if((y|0)>0){s=s+16|0;q=y;n=(c[277223]|0)+n|0}else{break}}return}n=(d[1394504]|0)+(j<<1)|0;if((f&32768|0)==0){if((k|0)<=0){return}f=i&255;j=f-1&255;q=j<<24>>24==0;s=r+n|0;T=k;S=g;while(1){switch(h|0){case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+S|0]|0)){D=a[s+7|0]|0;if(D<<24>>24==0){break}R=e[(c[277225]|0)+((D&255)<<1)>>1]|0;D=c[277228]|0;Q=(((R&63454)+(D&-2082)|0)>>>1)+(D&2081&R)|0;if((a[1108928]|0)==0){U=Q&65535}else{U=(e[(c[277220]|0)+(Q<<1)>>1]|(R^D)&2081)&65535}b[(c[277218]|0)+(S<<1)>>1]=U;if((a[1108928]|0)==0){D=e[(c[277213]|0)+(S+2<<1)>>1]|0;R=c[277228]|0;V=(((D&63454)+(R&128990)|0)>>>1)+(R&2081&D)|0}else{D=c[277228]|0;V=e[(c[277220]|0)+((D>>>1&2147482607)<<1)>>1]|D&2081}D=S+1|0;b[(c[277218]|0)+(D<<1)>>1]=V&65535;R=a[1108909]|0;a[(c[277219]|0)+D|0]=R;a[(c[277219]|0)+S|0]=R}}while(0);if(!q){W=j;v=4620}break};case 1:{W=f;v=4620;break};case 2:{X=f;v=4629;break};case 5:{Y=f;v=4656;break};case 6:{Z=f;v=4665;break};case 7:{v=4674;break};case 3:{_=f;v=4638;break};case 4:{$=f;v=4647;break};default:{}}if((v|0)==4620){v=0;R=S+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+R|0]|0)){D=a[s+6|0]|0;if(D<<24>>24==0){break}Q=e[(c[277225]|0)+((D&255)<<1)>>1]|0;D=c[277228]|0;E=(((Q&63454)+(D&-2082)|0)>>>1)+(D&2081&Q)|0;if((a[1108928]|0)==0){aa=E&65535}else{aa=(e[(c[277220]|0)+(E<<1)>>1]|(Q^D)&2081)&65535}b[(c[277218]|0)+(R<<1)>>1]=aa;if((a[1108928]|0)==0){D=e[(c[277213]|0)+(S+4<<1)>>1]|0;Q=c[277228]|0;ab=(((D&63454)+(Q&128990)|0)>>>1)+(Q&2081&D)|0}else{D=c[277228]|0;ab=e[(c[277220]|0)+((D>>>1&2147482607)<<1)>>1]|D&2081}D=S+3|0;b[(c[277218]|0)+(D<<1)>>1]=ab&65535;Q=a[1108909]|0;a[(c[277219]|0)+D|0]=Q;a[(c[277219]|0)+R|0]=Q}}while(0);R=W-1&255;if(R<<24>>24!=0){X=R;v=4629}}if((v|0)==4629){v=0;R=S+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+R|0]|0)){Q=a[s+5|0]|0;if(Q<<24>>24==0){break}D=e[(c[277225]|0)+((Q&255)<<1)>>1]|0;Q=c[277228]|0;E=(((D&63454)+(Q&-2082)|0)>>>1)+(Q&2081&D)|0;if((a[1108928]|0)==0){ac=E&65535}else{ac=(e[(c[277220]|0)+(E<<1)>>1]|(D^Q)&2081)&65535}b[(c[277218]|0)+(R<<1)>>1]=ac;if((a[1108928]|0)==0){Q=e[(c[277213]|0)+(S+6<<1)>>1]|0;D=c[277228]|0;ad=(((Q&63454)+(D&128990)|0)>>>1)+(D&2081&Q)|0}else{Q=c[277228]|0;ad=e[(c[277220]|0)+((Q>>>1&2147482607)<<1)>>1]|Q&2081}Q=S+5|0;b[(c[277218]|0)+(Q<<1)>>1]=ad&65535;D=a[1108909]|0;a[(c[277219]|0)+Q|0]=D;a[(c[277219]|0)+R|0]=D}}while(0);R=X-1&255;if(R<<24>>24!=0){_=R;v=4638}}if((v|0)==4638){v=0;R=S+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+R|0]|0)){D=a[s+4|0]|0;if(D<<24>>24==0){break}Q=e[(c[277225]|0)+((D&255)<<1)>>1]|0;D=c[277228]|0;E=(((Q&63454)+(D&-2082)|0)>>>1)+(D&2081&Q)|0;if((a[1108928]|0)==0){ae=E&65535}else{ae=(e[(c[277220]|0)+(E<<1)>>1]|(Q^D)&2081)&65535}b[(c[277218]|0)+(R<<1)>>1]=ae;if((a[1108928]|0)==0){D=e[(c[277213]|0)+(S+8<<1)>>1]|0;Q=c[277228]|0;af=(((D&63454)+(Q&128990)|0)>>>1)+(Q&2081&D)|0}else{D=c[277228]|0;af=e[(c[277220]|0)+((D>>>1&2147482607)<<1)>>1]|D&2081}D=S+7|0;b[(c[277218]|0)+(D<<1)>>1]=af&65535;Q=a[1108909]|0;a[(c[277219]|0)+D|0]=Q;a[(c[277219]|0)+R|0]=Q}}while(0);R=_-1&255;if(R<<24>>24!=0){$=R;v=4647}}if((v|0)==4647){v=0;R=S+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+R|0]|0)){Q=a[s+3|0]|0;if(Q<<24>>24==0){break}D=e[(c[277225]|0)+((Q&255)<<1)>>1]|0;Q=c[277228]|0;E=(((D&63454)+(Q&-2082)|0)>>>1)+(Q&2081&D)|0;if((a[1108928]|0)==0){ag=E&65535}else{ag=(e[(c[277220]|0)+(E<<1)>>1]|(D^Q)&2081)&65535}b[(c[277218]|0)+(R<<1)>>1]=ag;if((a[1108928]|0)==0){Q=e[(c[277213]|0)+(S+10<<1)>>1]|0;D=c[277228]|0;ah=(((Q&63454)+(D&128990)|0)>>>1)+(D&2081&Q)|0}else{Q=c[277228]|0;ah=e[(c[277220]|0)+((Q>>>1&2147482607)<<1)>>1]|Q&2081}Q=S+9|0;b[(c[277218]|0)+(Q<<1)>>1]=ah&65535;D=a[1108909]|0;a[(c[277219]|0)+Q|0]=D;a[(c[277219]|0)+R|0]=D}}while(0);R=$-1&255;if(R<<24>>24!=0){Y=R;v=4656}}if((v|0)==4656){v=0;R=S+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+R|0]|0)){D=a[s+2|0]|0;if(D<<24>>24==0){break}Q=e[(c[277225]|0)+((D&255)<<1)>>1]|0;D=c[277228]|0;E=(((Q&63454)+(D&-2082)|0)>>>1)+(D&2081&Q)|0;if((a[1108928]|0)==0){ai=E&65535}else{ai=(e[(c[277220]|0)+(E<<1)>>1]|(Q^D)&2081)&65535}b[(c[277218]|0)+(R<<1)>>1]=ai;if((a[1108928]|0)==0){D=e[(c[277213]|0)+(S+12<<1)>>1]|0;Q=c[277228]|0;aj=(((D&63454)+(Q&128990)|0)>>>1)+(Q&2081&D)|0}else{D=c[277228]|0;aj=e[(c[277220]|0)+((D>>>1&2147482607)<<1)>>1]|D&2081}D=S+11|0;b[(c[277218]|0)+(D<<1)>>1]=aj&65535;Q=a[1108909]|0;a[(c[277219]|0)+D|0]=Q;a[(c[277219]|0)+R|0]=Q}}while(0);R=Y-1&255;if(R<<24>>24!=0){Z=R;v=4665}}if((v|0)==4665){v=0;R=S+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+R|0]|0)){Q=a[s+1|0]|0;if(Q<<24>>24==0){break}D=e[(c[277225]|0)+((Q&255)<<1)>>1]|0;Q=c[277228]|0;E=(((D&63454)+(Q&-2082)|0)>>>1)+(Q&2081&D)|0;if((a[1108928]|0)==0){ak=E&65535}else{ak=(e[(c[277220]|0)+(E<<1)>>1]|(D^Q)&2081)&65535}b[(c[277218]|0)+(R<<1)>>1]=ak;if((a[1108928]|0)==0){Q=e[(c[277213]|0)+(S+14<<1)>>1]|0;D=c[277228]|0;al=(((Q&63454)+(D&128990)|0)>>>1)+(D&2081&Q)|0}else{Q=c[277228]|0;al=e[(c[277220]|0)+((Q>>>1&2147482607)<<1)>>1]|Q&2081}Q=S+13|0;b[(c[277218]|0)+(Q<<1)>>1]=al&65535;D=a[1108909]|0;a[(c[277219]|0)+Q|0]=D;a[(c[277219]|0)+R|0]=D}}while(0);if(Z<<24>>24!=1){v=4674}}do{if((v|0)==4674){v=0;R=S+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+R|0]|0)){break}D=a[s]|0;if(D<<24>>24==0){break}Q=e[(c[277225]|0)+((D&255)<<1)>>1]|0;D=c[277228]|0;E=(((Q&63454)+(D&-2082)|0)>>>1)+(D&2081&Q)|0;if((a[1108928]|0)==0){am=E&65535}else{am=(e[(c[277220]|0)+(E<<1)>>1]|(Q^D)&2081)&65535}b[(c[277218]|0)+(R<<1)>>1]=am;if((a[1108928]|0)==0){D=e[(c[277213]|0)+(S+16<<1)>>1]|0;Q=c[277228]|0;an=(((D&63454)+(Q&128990)|0)>>>1)+(Q&2081&D)|0}else{D=c[277228]|0;an=e[(c[277220]|0)+((D>>>1&2147482607)<<1)>>1]|D&2081}D=S+15|0;b[(c[277218]|0)+(D<<1)>>1]=an&65535;Q=a[1108909]|0;a[(c[277219]|0)+D|0]=Q;a[(c[277219]|0)+R|0]=Q}}while(0);Q=T-1|0;if((Q|0)>0){s=s+16|0;T=Q;S=(c[277223]|0)+S|0}else{break}}return}S=r+(56-n)|0;n=(k|0)>0;if(m){if(!n){return}m=i&255;r=m-1&255;T=r<<24>>24==0;s=S;an=k;am=g;while(1){switch(h|0){case 5:{ao=m;v=4807;break};case 6:{ap=m;v=4816;break};case 7:{v=4825;break};case 3:{aq=m;v=4789;break};case 4:{ar=m;v=4798;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+am|0]|0)){Z=a[s+7|0]|0;if(Z<<24>>24==0){break}al=e[(c[277225]|0)+((Z&255)<<1)>>1]|0;Z=c[277228]|0;ak=(((al&63454)+(Z&-2082)|0)>>>1)+(Z&2081&al)|0;if((a[1108928]|0)==0){as=ak&65535}else{as=(e[(c[277220]|0)+(ak<<1)>>1]|(al^Z)&2081)&65535}b[(c[277218]|0)+(am<<1)>>1]=as;if((a[1108928]|0)==0){Z=e[(c[277213]|0)+(am+2<<1)>>1]|0;al=c[277228]|0;at=(((Z&63454)+(al&128990)|0)>>>1)+(al&2081&Z)|0}else{Z=c[277228]|0;at=e[(c[277220]|0)+((Z>>>1&2147482607)<<1)>>1]|Z&2081}Z=am+1|0;b[(c[277218]|0)+(Z<<1)>>1]=at&65535;al=a[1108909]|0;a[(c[277219]|0)+Z|0]=al;a[(c[277219]|0)+am|0]=al}}while(0);if(!T){au=r;v=4771}break};case 1:{au=m;v=4771;break};case 2:{av=m;v=4780;break};default:{}}if((v|0)==4771){v=0;al=am+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+al|0]|0)){Z=a[s+6|0]|0;if(Z<<24>>24==0){break}ak=e[(c[277225]|0)+((Z&255)<<1)>>1]|0;Z=c[277228]|0;Y=(((ak&63454)+(Z&-2082)|0)>>>1)+(Z&2081&ak)|0;if((a[1108928]|0)==0){aw=Y&65535}else{aw=(e[(c[277220]|0)+(Y<<1)>>1]|(ak^Z)&2081)&65535}b[(c[277218]|0)+(al<<1)>>1]=aw;if((a[1108928]|0)==0){Z=e[(c[277213]|0)+(am+4<<1)>>1]|0;ak=c[277228]|0;ax=(((Z&63454)+(ak&128990)|0)>>>1)+(ak&2081&Z)|0}else{Z=c[277228]|0;ax=e[(c[277220]|0)+((Z>>>1&2147482607)<<1)>>1]|Z&2081}Z=am+3|0;b[(c[277218]|0)+(Z<<1)>>1]=ax&65535;ak=a[1108909]|0;a[(c[277219]|0)+Z|0]=ak;a[(c[277219]|0)+al|0]=ak}}while(0);al=au-1&255;if(al<<24>>24!=0){av=al;v=4780}}if((v|0)==4780){v=0;al=am+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+al|0]|0)){ak=a[s+5|0]|0;if(ak<<24>>24==0){break}Z=e[(c[277225]|0)+((ak&255)<<1)>>1]|0;ak=c[277228]|0;Y=(((Z&63454)+(ak&-2082)|0)>>>1)+(ak&2081&Z)|0;if((a[1108928]|0)==0){ay=Y&65535}else{ay=(e[(c[277220]|0)+(Y<<1)>>1]|(Z^ak)&2081)&65535}b[(c[277218]|0)+(al<<1)>>1]=ay;if((a[1108928]|0)==0){ak=e[(c[277213]|0)+(am+6<<1)>>1]|0;Z=c[277228]|0;az=(((ak&63454)+(Z&128990)|0)>>>1)+(Z&2081&ak)|0}else{ak=c[277228]|0;az=e[(c[277220]|0)+((ak>>>1&2147482607)<<1)>>1]|ak&2081}ak=am+5|0;b[(c[277218]|0)+(ak<<1)>>1]=az&65535;Z=a[1108909]|0;a[(c[277219]|0)+ak|0]=Z;a[(c[277219]|0)+al|0]=Z}}while(0);al=av-1&255;if(al<<24>>24!=0){aq=al;v=4789}}if((v|0)==4789){v=0;al=am+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+al|0]|0)){Z=a[s+4|0]|0;if(Z<<24>>24==0){break}ak=e[(c[277225]|0)+((Z&255)<<1)>>1]|0;Z=c[277228]|0;Y=(((ak&63454)+(Z&-2082)|0)>>>1)+(Z&2081&ak)|0;if((a[1108928]|0)==0){aA=Y&65535}else{aA=(e[(c[277220]|0)+(Y<<1)>>1]|(ak^Z)&2081)&65535}b[(c[277218]|0)+(al<<1)>>1]=aA;if((a[1108928]|0)==0){Z=e[(c[277213]|0)+(am+8<<1)>>1]|0;ak=c[277228]|0;aB=(((Z&63454)+(ak&128990)|0)>>>1)+(ak&2081&Z)|0}else{Z=c[277228]|0;aB=e[(c[277220]|0)+((Z>>>1&2147482607)<<1)>>1]|Z&2081}Z=am+7|0;b[(c[277218]|0)+(Z<<1)>>1]=aB&65535;ak=a[1108909]|0;a[(c[277219]|0)+Z|0]=ak;a[(c[277219]|0)+al|0]=ak}}while(0);al=aq-1&255;if(al<<24>>24!=0){ar=al;v=4798}}if((v|0)==4798){v=0;al=am+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+al|0]|0)){ak=a[s+3|0]|0;if(ak<<24>>24==0){break}Z=e[(c[277225]|0)+((ak&255)<<1)>>1]|0;ak=c[277228]|0;Y=(((Z&63454)+(ak&-2082)|0)>>>1)+(ak&2081&Z)|0;if((a[1108928]|0)==0){aC=Y&65535}else{aC=(e[(c[277220]|0)+(Y<<1)>>1]|(Z^ak)&2081)&65535}b[(c[277218]|0)+(al<<1)>>1]=aC;if((a[1108928]|0)==0){ak=e[(c[277213]|0)+(am+10<<1)>>1]|0;Z=c[277228]|0;aD=(((ak&63454)+(Z&128990)|0)>>>1)+(Z&2081&ak)|0}else{ak=c[277228]|0;aD=e[(c[277220]|0)+((ak>>>1&2147482607)<<1)>>1]|ak&2081}ak=am+9|0;b[(c[277218]|0)+(ak<<1)>>1]=aD&65535;Z=a[1108909]|0;a[(c[277219]|0)+ak|0]=Z;a[(c[277219]|0)+al|0]=Z}}while(0);al=ar-1&255;if(al<<24>>24!=0){ao=al;v=4807}}if((v|0)==4807){v=0;al=am+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+al|0]|0)){Z=a[s+2|0]|0;if(Z<<24>>24==0){break}ak=e[(c[277225]|0)+((Z&255)<<1)>>1]|0;Z=c[277228]|0;Y=(((ak&63454)+(Z&-2082)|0)>>>1)+(Z&2081&ak)|0;if((a[1108928]|0)==0){aE=Y&65535}else{aE=(e[(c[277220]|0)+(Y<<1)>>1]|(ak^Z)&2081)&65535}b[(c[277218]|0)+(al<<1)>>1]=aE;if((a[1108928]|0)==0){Z=e[(c[277213]|0)+(am+12<<1)>>1]|0;ak=c[277228]|0;aF=(((Z&63454)+(ak&128990)|0)>>>1)+(ak&2081&Z)|0}else{Z=c[277228]|0;aF=e[(c[277220]|0)+((Z>>>1&2147482607)<<1)>>1]|Z&2081}Z=am+11|0;b[(c[277218]|0)+(Z<<1)>>1]=aF&65535;ak=a[1108909]|0;a[(c[277219]|0)+Z|0]=ak;a[(c[277219]|0)+al|0]=ak}}while(0);al=ao-1&255;if(al<<24>>24!=0){ap=al;v=4816}}if((v|0)==4816){v=0;al=am+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+al|0]|0)){ak=a[s+1|0]|0;if(ak<<24>>24==0){break}Z=e[(c[277225]|0)+((ak&255)<<1)>>1]|0;ak=c[277228]|0;Y=(((Z&63454)+(ak&-2082)|0)>>>1)+(ak&2081&Z)|0;if((a[1108928]|0)==0){aG=Y&65535}else{aG=(e[(c[277220]|0)+(Y<<1)>>1]|(Z^ak)&2081)&65535}b[(c[277218]|0)+(al<<1)>>1]=aG;if((a[1108928]|0)==0){ak=e[(c[277213]|0)+(am+14<<1)>>1]|0;Z=c[277228]|0;aH=(((ak&63454)+(Z&128990)|0)>>>1)+(Z&2081&ak)|0}else{ak=c[277228]|0;aH=e[(c[277220]|0)+((ak>>>1&2147482607)<<1)>>1]|ak&2081}ak=am+13|0;b[(c[277218]|0)+(ak<<1)>>1]=aH&65535;Z=a[1108909]|0;a[(c[277219]|0)+ak|0]=Z;a[(c[277219]|0)+al|0]=Z}}while(0);if(ap<<24>>24!=1){v=4825}}do{if((v|0)==4825){v=0;al=am+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+al|0]|0)){break}Z=a[s]|0;if(Z<<24>>24==0){break}ak=e[(c[277225]|0)+((Z&255)<<1)>>1]|0;Z=c[277228]|0;Y=(((ak&63454)+(Z&-2082)|0)>>>1)+(Z&2081&ak)|0;if((a[1108928]|0)==0){aI=Y&65535}else{aI=(e[(c[277220]|0)+(Y<<1)>>1]|(ak^Z)&2081)&65535}b[(c[277218]|0)+(al<<1)>>1]=aI;if((a[1108928]|0)==0){Z=e[(c[277213]|0)+(am+16<<1)>>1]|0;ak=c[277228]|0;aJ=(((Z&63454)+(ak&128990)|0)>>>1)+(ak&2081&Z)|0}else{Z=c[277228]|0;aJ=e[(c[277220]|0)+((Z>>>1&2147482607)<<1)>>1]|Z&2081}Z=am+15|0;b[(c[277218]|0)+(Z<<1)>>1]=aJ&65535;ak=a[1108909]|0;a[(c[277219]|0)+Z|0]=ak;a[(c[277219]|0)+al|0]=ak}}while(0);ak=an-1|0;if((ak|0)>0){s=s-16|0;an=ak;am=(c[277223]|0)+am|0}else{break}}return}else{if(!n){return}n=i&255;i=n-1&255;am=i<<24>>24==0;an=S;S=k;k=g;while(1){switch(h|0){case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+k|0]|0)){g=a[an]|0;if(g<<24>>24==0){break}s=e[(c[277225]|0)+((g&255)<<1)>>1]|0;g=c[277228]|0;aJ=(((s&63454)+(g&-2082)|0)>>>1)+(g&2081&s)|0;if((a[1108928]|0)==0){aK=aJ&65535}else{aK=(e[(c[277220]|0)+(aJ<<1)>>1]|(s^g)&2081)&65535}b[(c[277218]|0)+(k<<1)>>1]=aK;if((a[1108928]|0)==0){g=e[(c[277213]|0)+(k+2<<1)>>1]|0;s=c[277228]|0;aL=(((g&63454)+(s&128990)|0)>>>1)+(s&2081&g)|0}else{g=c[277228]|0;aL=e[(c[277220]|0)+((g>>>1&2147482607)<<1)>>1]|g&2081}g=k+1|0;b[(c[277218]|0)+(g<<1)>>1]=aL&65535;s=a[1108909]|0;a[(c[277219]|0)+g|0]=s;a[(c[277219]|0)+k|0]=s}}while(0);if(!am){aM=i;v=4698}break};case 3:{aN=n;v=4716;break};case 1:{aM=n;v=4698;break};case 2:{aO=n;v=4707;break};case 4:{aP=n;v=4725;break};case 7:{v=4752;break};case 5:{aQ=n;v=4734;break};case 6:{aR=n;v=4743;break};default:{}}if((v|0)==4698){v=0;s=k+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+s|0]|0)){g=a[an+1|0]|0;if(g<<24>>24==0){break}aJ=e[(c[277225]|0)+((g&255)<<1)>>1]|0;g=c[277228]|0;aI=(((aJ&63454)+(g&-2082)|0)>>>1)+(g&2081&aJ)|0;if((a[1108928]|0)==0){aS=aI&65535}else{aS=(e[(c[277220]|0)+(aI<<1)>>1]|(aJ^g)&2081)&65535}b[(c[277218]|0)+(s<<1)>>1]=aS;if((a[1108928]|0)==0){g=e[(c[277213]|0)+(k+4<<1)>>1]|0;aJ=c[277228]|0;aT=(((g&63454)+(aJ&128990)|0)>>>1)+(aJ&2081&g)|0}else{g=c[277228]|0;aT=e[(c[277220]|0)+((g>>>1&2147482607)<<1)>>1]|g&2081}g=k+3|0;b[(c[277218]|0)+(g<<1)>>1]=aT&65535;aJ=a[1108909]|0;a[(c[277219]|0)+g|0]=aJ;a[(c[277219]|0)+s|0]=aJ}}while(0);s=aM-1&255;if(s<<24>>24!=0){aO=s;v=4707}}if((v|0)==4707){v=0;s=k+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+s|0]|0)){aJ=a[an+2|0]|0;if(aJ<<24>>24==0){break}g=e[(c[277225]|0)+((aJ&255)<<1)>>1]|0;aJ=c[277228]|0;aI=(((g&63454)+(aJ&-2082)|0)>>>1)+(aJ&2081&g)|0;if((a[1108928]|0)==0){aU=aI&65535}else{aU=(e[(c[277220]|0)+(aI<<1)>>1]|(g^aJ)&2081)&65535}b[(c[277218]|0)+(s<<1)>>1]=aU;if((a[1108928]|0)==0){aJ=e[(c[277213]|0)+(k+6<<1)>>1]|0;g=c[277228]|0;aV=(((aJ&63454)+(g&128990)|0)>>>1)+(g&2081&aJ)|0}else{aJ=c[277228]|0;aV=e[(c[277220]|0)+((aJ>>>1&2147482607)<<1)>>1]|aJ&2081}aJ=k+5|0;b[(c[277218]|0)+(aJ<<1)>>1]=aV&65535;g=a[1108909]|0;a[(c[277219]|0)+aJ|0]=g;a[(c[277219]|0)+s|0]=g}}while(0);s=aO-1&255;if(s<<24>>24!=0){aN=s;v=4716}}if((v|0)==4716){v=0;s=k+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+s|0]|0)){g=a[an+3|0]|0;if(g<<24>>24==0){break}aJ=e[(c[277225]|0)+((g&255)<<1)>>1]|0;g=c[277228]|0;aI=(((aJ&63454)+(g&-2082)|0)>>>1)+(g&2081&aJ)|0;if((a[1108928]|0)==0){aW=aI&65535}else{aW=(e[(c[277220]|0)+(aI<<1)>>1]|(aJ^g)&2081)&65535}b[(c[277218]|0)+(s<<1)>>1]=aW;if((a[1108928]|0)==0){g=e[(c[277213]|0)+(k+8<<1)>>1]|0;aJ=c[277228]|0;aX=(((g&63454)+(aJ&128990)|0)>>>1)+(aJ&2081&g)|0}else{g=c[277228]|0;aX=e[(c[277220]|0)+((g>>>1&2147482607)<<1)>>1]|g&2081}g=k+7|0;b[(c[277218]|0)+(g<<1)>>1]=aX&65535;aJ=a[1108909]|0;a[(c[277219]|0)+g|0]=aJ;a[(c[277219]|0)+s|0]=aJ}}while(0);s=aN-1&255;if(s<<24>>24!=0){aP=s;v=4725}}if((v|0)==4725){v=0;s=k+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+s|0]|0)){aJ=a[an+4|0]|0;if(aJ<<24>>24==0){break}g=e[(c[277225]|0)+((aJ&255)<<1)>>1]|0;aJ=c[277228]|0;aI=(((g&63454)+(aJ&-2082)|0)>>>1)+(aJ&2081&g)|0;if((a[1108928]|0)==0){aY=aI&65535}else{aY=(e[(c[277220]|0)+(aI<<1)>>1]|(g^aJ)&2081)&65535}b[(c[277218]|0)+(s<<1)>>1]=aY;if((a[1108928]|0)==0){aJ=e[(c[277213]|0)+(k+10<<1)>>1]|0;g=c[277228]|0;aZ=(((aJ&63454)+(g&128990)|0)>>>1)+(g&2081&aJ)|0}else{aJ=c[277228]|0;aZ=e[(c[277220]|0)+((aJ>>>1&2147482607)<<1)>>1]|aJ&2081}aJ=k+9|0;b[(c[277218]|0)+(aJ<<1)>>1]=aZ&65535;g=a[1108909]|0;a[(c[277219]|0)+aJ|0]=g;a[(c[277219]|0)+s|0]=g}}while(0);s=aP-1&255;if(s<<24>>24!=0){aQ=s;v=4734}}if((v|0)==4734){v=0;s=k+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+s|0]|0)){g=a[an+5|0]|0;if(g<<24>>24==0){break}aJ=e[(c[277225]|0)+((g&255)<<1)>>1]|0;g=c[277228]|0;aI=(((aJ&63454)+(g&-2082)|0)>>>1)+(g&2081&aJ)|0;if((a[1108928]|0)==0){a_=aI&65535}else{a_=(e[(c[277220]|0)+(aI<<1)>>1]|(aJ^g)&2081)&65535}b[(c[277218]|0)+(s<<1)>>1]=a_;if((a[1108928]|0)==0){g=e[(c[277213]|0)+(k+12<<1)>>1]|0;aJ=c[277228]|0;a$=(((g&63454)+(aJ&128990)|0)>>>1)+(aJ&2081&g)|0}else{g=c[277228]|0;a$=e[(c[277220]|0)+((g>>>1&2147482607)<<1)>>1]|g&2081}g=k+11|0;b[(c[277218]|0)+(g<<1)>>1]=a$&65535;aJ=a[1108909]|0;a[(c[277219]|0)+g|0]=aJ;a[(c[277219]|0)+s|0]=aJ}}while(0);s=aQ-1&255;if(s<<24>>24!=0){aR=s;v=4743}}if((v|0)==4743){v=0;s=k+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+s|0]|0)){aJ=a[an+6|0]|0;if(aJ<<24>>24==0){break}g=e[(c[277225]|0)+((aJ&255)<<1)>>1]|0;aJ=c[277228]|0;aI=(((g&63454)+(aJ&-2082)|0)>>>1)+(aJ&2081&g)|0;if((a[1108928]|0)==0){a0=aI&65535}else{a0=(e[(c[277220]|0)+(aI<<1)>>1]|(g^aJ)&2081)&65535}b[(c[277218]|0)+(s<<1)>>1]=a0;if((a[1108928]|0)==0){aJ=e[(c[277213]|0)+(k+14<<1)>>1]|0;g=c[277228]|0;a1=(((aJ&63454)+(g&128990)|0)>>>1)+(g&2081&aJ)|0}else{aJ=c[277228]|0;a1=e[(c[277220]|0)+((aJ>>>1&2147482607)<<1)>>1]|aJ&2081}aJ=k+13|0;b[(c[277218]|0)+(aJ<<1)>>1]=a1&65535;g=a[1108909]|0;a[(c[277219]|0)+aJ|0]=g;a[(c[277219]|0)+s|0]=g}}while(0);if(aR<<24>>24!=1){v=4752}}do{if((v|0)==4752){v=0;s=k+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+s|0]|0)){break}g=a[an+7|0]|0;if(g<<24>>24==0){break}aJ=e[(c[277225]|0)+((g&255)<<1)>>1]|0;g=c[277228]|0;aI=(((aJ&63454)+(g&-2082)|0)>>>1)+(g&2081&aJ)|0;if((a[1108928]|0)==0){a2=aI&65535}else{a2=(e[(c[277220]|0)+(aI<<1)>>1]|(aJ^g)&2081)&65535}b[(c[277218]|0)+(s<<1)>>1]=a2;if((a[1108928]|0)==0){g=e[(c[277213]|0)+(k+16<<1)>>1]|0;aJ=c[277228]|0;a3=(((g&63454)+(aJ&128990)|0)>>>1)+(aJ&2081&g)|0}else{g=c[277228]|0;a3=e[(c[277220]|0)+((g>>>1&2147482607)<<1)>>1]|g&2081}g=k+15|0;b[(c[277218]|0)+(g<<1)>>1]=a3&65535;aJ=a[1108909]|0;a[(c[277219]|0)+g|0]=aJ;a[(c[277219]|0)+s|0]=aJ}}while(0);aJ=S-1|0;if((aJ|0)>0){an=an-16|0;S=aJ;k=(c[277223]|0)+k|0}else{break}}return}}function Wv(f,g,h,i,j,k){f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0,cf=0,cg=0,ch=0,ci=0,cj=0,ck=0,cl=0,cm=0,cn=0,co=0,cp=0,cq=0,cr=0,cs=0,ct=0,cu=0,cv=0,cw=0,cx=0,cy=0,cz=0,cA=0,cB=0,cC=0,cD=0,cE=0,cF=0,cG=0,cH=0,cI=0,cJ=0,cK=0,cL=0,cM=0,cN=0,cO=0,cP=0,cQ=0,cR=0,cS=0,cT=0,cU=0,cV=0,cW=0,cX=0,cY=0,cZ=0,c_=0,c$=0,c0=0,c1=0,c2=0,c3=0,c4=0,c5=0,c6=0,c7=0,c8=0,c9=0,da=0,db=0,dc=0,dd=0,de=0,df=0,dg=0,dh=0,di=0,dj=0,dk=0,dl=0,dm=0,dn=0,dp=0,dq=0,dr=0,ds=0,dt=0,du=0,dv=0,dw=0,dx=0,dy=0,dz=0,dA=0,dB=0,dC=0;l=f&1023;m=c[348606]|0;n=(l<<m)+(c[348604]|0)|0;if((f&256|0)==0){o=n}else{o=(c[348602]|0)+n|0}n=o&65535;o=n>>>(m>>>0);m=(f&16384|0)!=0;p=o<<6;do{if(m){q=(c[348622]|0)+p|0;if((a[(c[348618]|0)+o|0]|0)!=0){r=q;break}s=fi[c[348636]&63](q,n,l)|0;a[(c[348618]|0)+o|0]=s;r=q}else{q=(c[348624]|0)+p|0;if((a[(c[348620]|0)+o|0]|0)!=0){r=q;break}s=fi[c[348638]&63](q,n,l)|0;a[(c[348620]|0)+o|0]=s;r=q}}while(0);if((a[(c[348620]|0)+o|0]|0)==2){return}if((a[1394464]|0)==0){t=1106168+((f>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){o=d[1044485]|0;c[276541]=7080+(o<<5);l=0;do{n=l<<1&2;p=l&2;q=l&4;s=0;do{b[1125528+(l<<9)+(s<<1)>>1]=d[(s>>>1&28|p)+(7080+(o<<5))|0]<<6|d[(s<<2&28|n)+(7080+(o<<5))|0]<<11|d[(s>>>3&24|q)+(7080+(o<<5))|0];s=s+1|0;}while(s>>>0<256);l=l+1|0;}while(l>>>0<8);a[1106089]=0}t=1125528+((f>>>10&7)<<9)|0}c[277226]=t;c[277225]=(a[1108928]|0)!=0?1393712:t;if((f&49152|0)==0){if((k|0)<=0){return}t=i&255;l=t-1&255;o=l<<24>>24==0;s=r+((d[1394504]|0)+(j<<1))|0;q=k;n=g;while(1){switch(h|0){case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+n|0]|0)){p=a[s]|0;u=p&255;if(p<<24>>24==0){break}do{if((a[1108928]|0)==0){p=b[(c[277225]|0)+(u<<1)>>1]|0;v=p&65535;w=v&63454;if((a[(c[277215]|0)+n|0]&32)==0){x=c[277228]|0;y=(e[(c[277220]|0)+((((x&-2082)+w|0)>>>1)+(v&2081&x)<<1)>>1]|(x^v)&2081)&65535;break}else{v=b[(c[277213]|0)+(n<<1)>>1]|0;y=(((v&63454)+w|0)>>>1)+(v&p&2081)&65535;break}}else{p=e[(c[277225]|0)+(u<<1)>>1]|0;v=(a[(c[277215]|0)+n|0]&32)==0;if(v){w=c[277228]|0;z=w;A=w&-2082}else{w=e[(c[277213]|0)+(n<<1)>>1]|0;z=w;A=w&63454}if(v){B=c[277228]|0}else{B=e[(c[277213]|0)+(n<<1)>>1]|0}y=((B^p)&2081|e[(c[277220]|0)+((p&2081&z)+((A+(p&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(n<<1)>>1]=y;p=(a[(c[277215]|0)+n|0]&32)==0;do{if((a[1108928]|0)==0){v=e[(c[277213]|0)+(n+2<<1)>>1]|0;w=v&63454;if(p){x=c[277228]|0;C=(e[(c[277220]|0)+((((x&-2082)+w|0)>>>1)+(v&2081&x)<<1)>>1]|(x^v)&2081)&65535;break}else{x=e[(c[277226]|0)+(u<<1)>>1]|0;C=(((x&63454)+w|0)>>>1)+(v&2081&x)&65535;break}}else{if(p){x=c[277228]|0;D=x;E=(c[277220]|0)+((x>>>1&2147482607)<<1)|0}else{x=e[(c[277226]|0)+(u<<1)>>1]|0;D=x;E=(c[277220]|0)+((x>>>1&31727)<<1)|0}C=(e[E>>1]|D&2081)&65535}}while(0);u=n+1|0;b[(c[277218]|0)+(u<<1)>>1]=C;p=a[1108909]|0;a[(c[277219]|0)+u|0]=p;a[(c[277219]|0)+n|0]=p}}while(0);if(!o){F=l;G=4888}break};case 1:{F=t;G=4888;break};case 2:{H=t;G=4911;break};case 3:{I=t;G=4934;break};case 4:{J=t;G=4957;break};case 5:{K=t;G=4980;break};case 6:{L=t;G=5003;break};case 7:{G=5026;break};default:{}}if((G|0)==4888){G=0;p=n+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){u=a[s+1|0]|0;x=u&255;if(u<<24>>24==0){break}do{if((a[1108928]|0)==0){u=b[(c[277225]|0)+(x<<1)>>1]|0;v=u&65535;w=v&63454;if((a[(c[277215]|0)+p|0]&32)==0){M=c[277228]|0;N=(e[(c[277220]|0)+((((M&-2082)+w|0)>>>1)+(v&2081&M)<<1)>>1]|(M^v)&2081)&65535;break}else{v=b[(c[277213]|0)+(p<<1)>>1]|0;N=(((v&63454)+w|0)>>>1)+(v&u&2081)&65535;break}}else{u=e[(c[277225]|0)+(x<<1)>>1]|0;v=(a[(c[277215]|0)+p|0]&32)==0;if(v){w=c[277228]|0;O=w;P=w&-2082}else{w=e[(c[277213]|0)+(p<<1)>>1]|0;O=w;P=w&63454}if(v){Q=c[277228]|0}else{Q=e[(c[277213]|0)+(p<<1)>>1]|0}N=((Q^u)&2081|e[(c[277220]|0)+((u&2081&O)+((P+(u&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=N;u=(a[(c[277215]|0)+p|0]&32)==0;do{if((a[1108928]|0)==0){v=e[(c[277213]|0)+(n+4<<1)>>1]|0;w=v&63454;if(u){M=c[277228]|0;R=(e[(c[277220]|0)+((((M&-2082)+w|0)>>>1)+(v&2081&M)<<1)>>1]|(M^v)&2081)&65535;break}else{M=e[(c[277226]|0)+(x<<1)>>1]|0;R=(((M&63454)+w|0)>>>1)+(v&2081&M)&65535;break}}else{if(u){M=c[277228]|0;S=M;T=(c[277220]|0)+((M>>>1&2147482607)<<1)|0}else{M=e[(c[277226]|0)+(x<<1)>>1]|0;S=M;T=(c[277220]|0)+((M>>>1&31727)<<1)|0}R=(e[T>>1]|S&2081)&65535}}while(0);x=n+3|0;b[(c[277218]|0)+(x<<1)>>1]=R;u=a[1108909]|0;a[(c[277219]|0)+x|0]=u;a[(c[277219]|0)+p|0]=u}}while(0);p=F-1&255;if(p<<24>>24!=0){H=p;G=4911}}if((G|0)==4911){G=0;p=n+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){u=a[s+2|0]|0;x=u&255;if(u<<24>>24==0){break}do{if((a[1108928]|0)==0){u=b[(c[277225]|0)+(x<<1)>>1]|0;M=u&65535;v=M&63454;if((a[(c[277215]|0)+p|0]&32)==0){w=c[277228]|0;U=(e[(c[277220]|0)+((((w&-2082)+v|0)>>>1)+(M&2081&w)<<1)>>1]|(w^M)&2081)&65535;break}else{M=b[(c[277213]|0)+(p<<1)>>1]|0;U=(((M&63454)+v|0)>>>1)+(M&u&2081)&65535;break}}else{u=e[(c[277225]|0)+(x<<1)>>1]|0;M=(a[(c[277215]|0)+p|0]&32)==0;if(M){v=c[277228]|0;V=v;W=v&-2082}else{v=e[(c[277213]|0)+(p<<1)>>1]|0;V=v;W=v&63454}if(M){X=c[277228]|0}else{X=e[(c[277213]|0)+(p<<1)>>1]|0}U=((X^u)&2081|e[(c[277220]|0)+((u&2081&V)+((W+(u&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=U;u=(a[(c[277215]|0)+p|0]&32)==0;do{if((a[1108928]|0)==0){M=e[(c[277213]|0)+(n+6<<1)>>1]|0;v=M&63454;if(u){w=c[277228]|0;Y=(e[(c[277220]|0)+((((w&-2082)+v|0)>>>1)+(M&2081&w)<<1)>>1]|(w^M)&2081)&65535;break}else{w=e[(c[277226]|0)+(x<<1)>>1]|0;Y=(((w&63454)+v|0)>>>1)+(M&2081&w)&65535;break}}else{if(u){w=c[277228]|0;Z=w;_=(c[277220]|0)+((w>>>1&2147482607)<<1)|0}else{w=e[(c[277226]|0)+(x<<1)>>1]|0;Z=w;_=(c[277220]|0)+((w>>>1&31727)<<1)|0}Y=(e[_>>1]|Z&2081)&65535}}while(0);x=n+5|0;b[(c[277218]|0)+(x<<1)>>1]=Y;u=a[1108909]|0;a[(c[277219]|0)+x|0]=u;a[(c[277219]|0)+p|0]=u}}while(0);p=H-1&255;if(p<<24>>24!=0){I=p;G=4934}}if((G|0)==4934){G=0;p=n+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){u=a[s+3|0]|0;x=u&255;if(u<<24>>24==0){break}do{if((a[1108928]|0)==0){u=b[(c[277225]|0)+(x<<1)>>1]|0;w=u&65535;M=w&63454;if((a[(c[277215]|0)+p|0]&32)==0){v=c[277228]|0;$=(e[(c[277220]|0)+((((v&-2082)+M|0)>>>1)+(w&2081&v)<<1)>>1]|(v^w)&2081)&65535;break}else{w=b[(c[277213]|0)+(p<<1)>>1]|0;$=(((w&63454)+M|0)>>>1)+(w&u&2081)&65535;break}}else{u=e[(c[277225]|0)+(x<<1)>>1]|0;w=(a[(c[277215]|0)+p|0]&32)==0;if(w){M=c[277228]|0;aa=M;ab=M&-2082}else{M=e[(c[277213]|0)+(p<<1)>>1]|0;aa=M;ab=M&63454}if(w){ac=c[277228]|0}else{ac=e[(c[277213]|0)+(p<<1)>>1]|0}$=((ac^u)&2081|e[(c[277220]|0)+((u&2081&aa)+((ab+(u&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=$;u=(a[(c[277215]|0)+p|0]&32)==0;do{if((a[1108928]|0)==0){w=e[(c[277213]|0)+(n+8<<1)>>1]|0;M=w&63454;if(u){v=c[277228]|0;ad=(e[(c[277220]|0)+((((v&-2082)+M|0)>>>1)+(w&2081&v)<<1)>>1]|(v^w)&2081)&65535;break}else{v=e[(c[277226]|0)+(x<<1)>>1]|0;ad=(((v&63454)+M|0)>>>1)+(w&2081&v)&65535;break}}else{if(u){v=c[277228]|0;ae=v;af=(c[277220]|0)+((v>>>1&2147482607)<<1)|0}else{v=e[(c[277226]|0)+(x<<1)>>1]|0;ae=v;af=(c[277220]|0)+((v>>>1&31727)<<1)|0}ad=(e[af>>1]|ae&2081)&65535}}while(0);x=n+7|0;b[(c[277218]|0)+(x<<1)>>1]=ad;u=a[1108909]|0;a[(c[277219]|0)+x|0]=u;a[(c[277219]|0)+p|0]=u}}while(0);p=I-1&255;if(p<<24>>24!=0){J=p;G=4957}}if((G|0)==4957){G=0;p=n+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){u=a[s+4|0]|0;x=u&255;if(u<<24>>24==0){break}do{if((a[1108928]|0)==0){u=b[(c[277225]|0)+(x<<1)>>1]|0;v=u&65535;w=v&63454;if((a[(c[277215]|0)+p|0]&32)==0){M=c[277228]|0;ag=(e[(c[277220]|0)+((((M&-2082)+w|0)>>>1)+(v&2081&M)<<1)>>1]|(M^v)&2081)&65535;break}else{v=b[(c[277213]|0)+(p<<1)>>1]|0;ag=(((v&63454)+w|0)>>>1)+(v&u&2081)&65535;break}}else{u=e[(c[277225]|0)+(x<<1)>>1]|0;v=(a[(c[277215]|0)+p|0]&32)==0;if(v){w=c[277228]|0;ah=w;ai=w&-2082}else{w=e[(c[277213]|0)+(p<<1)>>1]|0;ah=w;ai=w&63454}if(v){aj=c[277228]|0}else{aj=e[(c[277213]|0)+(p<<1)>>1]|0}ag=((aj^u)&2081|e[(c[277220]|0)+((u&2081&ah)+((ai+(u&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=ag;u=(a[(c[277215]|0)+p|0]&32)==0;do{if((a[1108928]|0)==0){v=e[(c[277213]|0)+(n+10<<1)>>1]|0;w=v&63454;if(u){M=c[277228]|0;ak=(e[(c[277220]|0)+((((M&-2082)+w|0)>>>1)+(v&2081&M)<<1)>>1]|(M^v)&2081)&65535;break}else{M=e[(c[277226]|0)+(x<<1)>>1]|0;ak=(((M&63454)+w|0)>>>1)+(v&2081&M)&65535;break}}else{if(u){M=c[277228]|0;al=M;am=(c[277220]|0)+((M>>>1&2147482607)<<1)|0}else{M=e[(c[277226]|0)+(x<<1)>>1]|0;al=M;am=(c[277220]|0)+((M>>>1&31727)<<1)|0}ak=(e[am>>1]|al&2081)&65535}}while(0);x=n+9|0;b[(c[277218]|0)+(x<<1)>>1]=ak;u=a[1108909]|0;a[(c[277219]|0)+x|0]=u;a[(c[277219]|0)+p|0]=u}}while(0);p=J-1&255;if(p<<24>>24!=0){K=p;G=4980}}if((G|0)==4980){G=0;p=n+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){u=a[s+5|0]|0;x=u&255;if(u<<24>>24==0){break}do{if((a[1108928]|0)==0){u=b[(c[277225]|0)+(x<<1)>>1]|0;M=u&65535;v=M&63454;if((a[(c[277215]|0)+p|0]&32)==0){w=c[277228]|0;an=(e[(c[277220]|0)+((((w&-2082)+v|0)>>>1)+(M&2081&w)<<1)>>1]|(w^M)&2081)&65535;break}else{M=b[(c[277213]|0)+(p<<1)>>1]|0;an=(((M&63454)+v|0)>>>1)+(M&u&2081)&65535;break}}else{u=e[(c[277225]|0)+(x<<1)>>1]|0;M=(a[(c[277215]|0)+p|0]&32)==0;if(M){v=c[277228]|0;ao=v;ap=v&-2082}else{v=e[(c[277213]|0)+(p<<1)>>1]|0;ao=v;ap=v&63454}if(M){aq=c[277228]|0}else{aq=e[(c[277213]|0)+(p<<1)>>1]|0}an=((aq^u)&2081|e[(c[277220]|0)+((u&2081&ao)+((ap+(u&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=an;u=(a[(c[277215]|0)+p|0]&32)==0;do{if((a[1108928]|0)==0){M=e[(c[277213]|0)+(n+12<<1)>>1]|0;v=M&63454;if(u){w=c[277228]|0;ar=(e[(c[277220]|0)+((((w&-2082)+v|0)>>>1)+(M&2081&w)<<1)>>1]|(w^M)&2081)&65535;break}else{w=e[(c[277226]|0)+(x<<1)>>1]|0;ar=(((w&63454)+v|0)>>>1)+(M&2081&w)&65535;break}}else{if(u){w=c[277228]|0;as=w;at=(c[277220]|0)+((w>>>1&2147482607)<<1)|0}else{w=e[(c[277226]|0)+(x<<1)>>1]|0;as=w;at=(c[277220]|0)+((w>>>1&31727)<<1)|0}ar=(e[at>>1]|as&2081)&65535}}while(0);x=n+11|0;b[(c[277218]|0)+(x<<1)>>1]=ar;u=a[1108909]|0;a[(c[277219]|0)+x|0]=u;a[(c[277219]|0)+p|0]=u}}while(0);p=K-1&255;if(p<<24>>24!=0){L=p;G=5003}}if((G|0)==5003){G=0;p=n+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){u=a[s+6|0]|0;x=u&255;if(u<<24>>24==0){break}do{if((a[1108928]|0)==0){u=b[(c[277225]|0)+(x<<1)>>1]|0;w=u&65535;M=w&63454;if((a[(c[277215]|0)+p|0]&32)==0){v=c[277228]|0;au=(e[(c[277220]|0)+((((v&-2082)+M|0)>>>1)+(w&2081&v)<<1)>>1]|(v^w)&2081)&65535;break}else{w=b[(c[277213]|0)+(p<<1)>>1]|0;au=(((w&63454)+M|0)>>>1)+(w&u&2081)&65535;break}}else{u=e[(c[277225]|0)+(x<<1)>>1]|0;w=(a[(c[277215]|0)+p|0]&32)==0;if(w){M=c[277228]|0;av=M;aw=M&-2082}else{M=e[(c[277213]|0)+(p<<1)>>1]|0;av=M;aw=M&63454}if(w){ax=c[277228]|0}else{ax=e[(c[277213]|0)+(p<<1)>>1]|0}au=((ax^u)&2081|e[(c[277220]|0)+((u&2081&av)+((aw+(u&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=au;u=(a[(c[277215]|0)+p|0]&32)==0;do{if((a[1108928]|0)==0){w=e[(c[277213]|0)+(n+14<<1)>>1]|0;M=w&63454;if(u){v=c[277228]|0;ay=(e[(c[277220]|0)+((((v&-2082)+M|0)>>>1)+(w&2081&v)<<1)>>1]|(v^w)&2081)&65535;break}else{v=e[(c[277226]|0)+(x<<1)>>1]|0;ay=(((v&63454)+M|0)>>>1)+(w&2081&v)&65535;break}}else{if(u){v=c[277228]|0;az=v;aA=(c[277220]|0)+((v>>>1&2147482607)<<1)|0}else{v=e[(c[277226]|0)+(x<<1)>>1]|0;az=v;aA=(c[277220]|0)+((v>>>1&31727)<<1)|0}ay=(e[aA>>1]|az&2081)&65535}}while(0);x=n+13|0;b[(c[277218]|0)+(x<<1)>>1]=ay;u=a[1108909]|0;a[(c[277219]|0)+x|0]=u;a[(c[277219]|0)+p|0]=u}}while(0);if(L<<24>>24!=1){G=5026}}do{if((G|0)==5026){G=0;p=n+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+p|0]|0)){break}u=a[s+7|0]|0;x=u&255;if(u<<24>>24==0){break}do{if((a[1108928]|0)==0){u=b[(c[277225]|0)+(x<<1)>>1]|0;v=u&65535;w=v&63454;if((a[(c[277215]|0)+p|0]&32)==0){M=c[277228]|0;aB=(e[(c[277220]|0)+((((M&-2082)+w|0)>>>1)+(v&2081&M)<<1)>>1]|(M^v)&2081)&65535;break}else{v=b[(c[277213]|0)+(p<<1)>>1]|0;aB=(((v&63454)+w|0)>>>1)+(v&u&2081)&65535;break}}else{u=e[(c[277225]|0)+(x<<1)>>1]|0;v=(a[(c[277215]|0)+p|0]&32)==0;if(v){w=c[277228]|0;aC=w;aD=w&-2082}else{w=e[(c[277213]|0)+(p<<1)>>1]|0;aC=w;aD=w&63454}if(v){aE=c[277228]|0}else{aE=e[(c[277213]|0)+(p<<1)>>1]|0}aB=((aE^u)&2081|e[(c[277220]|0)+((u&2081&aC)+((aD+(u&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=aB;u=(a[(c[277215]|0)+p|0]&32)==0;do{if((a[1108928]|0)==0){v=e[(c[277213]|0)+(n+16<<1)>>1]|0;w=v&63454;if(u){M=c[277228]|0;aF=(e[(c[277220]|0)+((((M&-2082)+w|0)>>>1)+(v&2081&M)<<1)>>1]|(M^v)&2081)&65535;break}else{M=e[(c[277226]|0)+(x<<1)>>1]|0;aF=(((M&63454)+w|0)>>>1)+(v&2081&M)&65535;break}}else{if(u){M=c[277228]|0;aG=M;aH=(c[277220]|0)+((M>>>1&2147482607)<<1)|0}else{M=e[(c[277226]|0)+(x<<1)>>1]|0;aG=M;aH=(c[277220]|0)+((M>>>1&31727)<<1)|0}aF=(e[aH>>1]|aG&2081)&65535}}while(0);x=n+15|0;b[(c[277218]|0)+(x<<1)>>1]=aF;u=a[1108909]|0;a[(c[277219]|0)+x|0]=u;a[(c[277219]|0)+p|0]=u}}while(0);u=q-1|0;if((u|0)>0){s=s+16|0;q=u;n=(c[277223]|0)+n|0}else{break}}return}n=(d[1394504]|0)+(j<<1)|0;if((f&32768|0)==0){if((k|0)<=0){return}f=i&255;j=f-1&255;q=j<<24>>24==0;s=r+n|0;aF=k;aG=g;while(1){switch(h|0){case 5:{aI=f;G=5168;break};case 3:{aJ=f;G=5122;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+aG|0]|0)){aH=a[s+7|0]|0;aB=aH&255;if(aH<<24>>24==0){break}do{if((a[1108928]|0)==0){aH=b[(c[277225]|0)+(aB<<1)>>1]|0;aD=aH&65535;aC=aD&63454;if((a[(c[277215]|0)+aG|0]&32)==0){aE=c[277228]|0;aK=(e[(c[277220]|0)+((((aE&-2082)+aC|0)>>>1)+(aD&2081&aE)<<1)>>1]|(aE^aD)&2081)&65535;break}else{aD=b[(c[277213]|0)+(aG<<1)>>1]|0;aK=(((aD&63454)+aC|0)>>>1)+(aD&aH&2081)&65535;break}}else{aH=e[(c[277225]|0)+(aB<<1)>>1]|0;aD=(a[(c[277215]|0)+aG|0]&32)==0;if(aD){aC=c[277228]|0;aL=aC;aM=aC&-2082}else{aC=e[(c[277213]|0)+(aG<<1)>>1]|0;aL=aC;aM=aC&63454}if(aD){aN=c[277228]|0}else{aN=e[(c[277213]|0)+(aG<<1)>>1]|0}aK=((aN^aH)&2081|e[(c[277220]|0)+((aH&2081&aL)+((aM+(aH&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(aG<<1)>>1]=aK;p=(a[(c[277215]|0)+aG|0]&32)==0;do{if((a[1108928]|0)==0){aH=e[(c[277213]|0)+(aG+2<<1)>>1]|0;aD=aH&63454;if(p){aC=c[277228]|0;aO=(e[(c[277220]|0)+((((aC&-2082)+aD|0)>>>1)+(aH&2081&aC)<<1)>>1]|(aC^aH)&2081)&65535;break}else{aC=e[(c[277226]|0)+(aB<<1)>>1]|0;aO=(((aC&63454)+aD|0)>>>1)+(aH&2081&aC)&65535;break}}else{if(p){aC=c[277228]|0;aP=aC;aQ=(c[277220]|0)+((aC>>>1&2147482607)<<1)|0}else{aC=e[(c[277226]|0)+(aB<<1)>>1]|0;aP=aC;aQ=(c[277220]|0)+((aC>>>1&31727)<<1)|0}aO=(e[aQ>>1]|aP&2081)&65535}}while(0);aB=aG+1|0;b[(c[277218]|0)+(aB<<1)>>1]=aO;p=a[1108909]|0;a[(c[277219]|0)+aB|0]=p;a[(c[277219]|0)+aG|0]=p}}while(0);if(!q){aR=j;G=5076}break};case 4:{aS=f;G=5145;break};case 2:{aT=f;G=5099;break};case 1:{aR=f;G=5076;break};case 6:{aU=f;G=5191;break};case 7:{G=5214;break};default:{}}if((G|0)==5076){G=0;p=aG+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){aB=a[s+6|0]|0;aC=aB&255;if(aB<<24>>24==0){break}do{if((a[1108928]|0)==0){aB=b[(c[277225]|0)+(aC<<1)>>1]|0;aH=aB&65535;aD=aH&63454;if((a[(c[277215]|0)+p|0]&32)==0){aE=c[277228]|0;aV=(e[(c[277220]|0)+((((aE&-2082)+aD|0)>>>1)+(aH&2081&aE)<<1)>>1]|(aE^aH)&2081)&65535;break}else{aH=b[(c[277213]|0)+(p<<1)>>1]|0;aV=(((aH&63454)+aD|0)>>>1)+(aH&aB&2081)&65535;break}}else{aB=e[(c[277225]|0)+(aC<<1)>>1]|0;aH=(a[(c[277215]|0)+p|0]&32)==0;if(aH){aD=c[277228]|0;aW=aD;aX=aD&-2082}else{aD=e[(c[277213]|0)+(p<<1)>>1]|0;aW=aD;aX=aD&63454}if(aH){aY=c[277228]|0}else{aY=e[(c[277213]|0)+(p<<1)>>1]|0}aV=((aY^aB)&2081|e[(c[277220]|0)+((aB&2081&aW)+((aX+(aB&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=aV;aB=(a[(c[277215]|0)+p|0]&32)==0;do{if((a[1108928]|0)==0){aH=e[(c[277213]|0)+(aG+4<<1)>>1]|0;aD=aH&63454;if(aB){aE=c[277228]|0;aZ=(e[(c[277220]|0)+((((aE&-2082)+aD|0)>>>1)+(aH&2081&aE)<<1)>>1]|(aE^aH)&2081)&65535;break}else{aE=e[(c[277226]|0)+(aC<<1)>>1]|0;aZ=(((aE&63454)+aD|0)>>>1)+(aH&2081&aE)&65535;break}}else{if(aB){aE=c[277228]|0;a_=aE;a$=(c[277220]|0)+((aE>>>1&2147482607)<<1)|0}else{aE=e[(c[277226]|0)+(aC<<1)>>1]|0;a_=aE;a$=(c[277220]|0)+((aE>>>1&31727)<<1)|0}aZ=(e[a$>>1]|a_&2081)&65535}}while(0);aC=aG+3|0;b[(c[277218]|0)+(aC<<1)>>1]=aZ;aB=a[1108909]|0;a[(c[277219]|0)+aC|0]=aB;a[(c[277219]|0)+p|0]=aB}}while(0);p=aR-1&255;if(p<<24>>24!=0){aT=p;G=5099}}if((G|0)==5099){G=0;p=aG+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){aB=a[s+5|0]|0;aC=aB&255;if(aB<<24>>24==0){break}do{if((a[1108928]|0)==0){aB=b[(c[277225]|0)+(aC<<1)>>1]|0;aE=aB&65535;aH=aE&63454;if((a[(c[277215]|0)+p|0]&32)==0){aD=c[277228]|0;a0=(e[(c[277220]|0)+((((aD&-2082)+aH|0)>>>1)+(aE&2081&aD)<<1)>>1]|(aD^aE)&2081)&65535;break}else{aE=b[(c[277213]|0)+(p<<1)>>1]|0;a0=(((aE&63454)+aH|0)>>>1)+(aE&aB&2081)&65535;break}}else{aB=e[(c[277225]|0)+(aC<<1)>>1]|0;aE=(a[(c[277215]|0)+p|0]&32)==0;if(aE){aH=c[277228]|0;a1=aH;a2=aH&-2082}else{aH=e[(c[277213]|0)+(p<<1)>>1]|0;a1=aH;a2=aH&63454}if(aE){a3=c[277228]|0}else{a3=e[(c[277213]|0)+(p<<1)>>1]|0}a0=((a3^aB)&2081|e[(c[277220]|0)+((aB&2081&a1)+((a2+(aB&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=a0;aB=(a[(c[277215]|0)+p|0]&32)==0;do{if((a[1108928]|0)==0){aE=e[(c[277213]|0)+(aG+6<<1)>>1]|0;aH=aE&63454;if(aB){aD=c[277228]|0;a4=(e[(c[277220]|0)+((((aD&-2082)+aH|0)>>>1)+(aE&2081&aD)<<1)>>1]|(aD^aE)&2081)&65535;break}else{aD=e[(c[277226]|0)+(aC<<1)>>1]|0;a4=(((aD&63454)+aH|0)>>>1)+(aE&2081&aD)&65535;break}}else{if(aB){aD=c[277228]|0;a5=aD;a6=(c[277220]|0)+((aD>>>1&2147482607)<<1)|0}else{aD=e[(c[277226]|0)+(aC<<1)>>1]|0;a5=aD;a6=(c[277220]|0)+((aD>>>1&31727)<<1)|0}a4=(e[a6>>1]|a5&2081)&65535}}while(0);aC=aG+5|0;b[(c[277218]|0)+(aC<<1)>>1]=a4;aB=a[1108909]|0;a[(c[277219]|0)+aC|0]=aB;a[(c[277219]|0)+p|0]=aB}}while(0);p=aT-1&255;if(p<<24>>24!=0){aJ=p;G=5122}}if((G|0)==5122){G=0;p=aG+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){aB=a[s+4|0]|0;aC=aB&255;if(aB<<24>>24==0){break}do{if((a[1108928]|0)==0){aB=b[(c[277225]|0)+(aC<<1)>>1]|0;aD=aB&65535;aE=aD&63454;if((a[(c[277215]|0)+p|0]&32)==0){aH=c[277228]|0;a7=(e[(c[277220]|0)+((((aH&-2082)+aE|0)>>>1)+(aD&2081&aH)<<1)>>1]|(aH^aD)&2081)&65535;break}else{aD=b[(c[277213]|0)+(p<<1)>>1]|0;a7=(((aD&63454)+aE|0)>>>1)+(aD&aB&2081)&65535;break}}else{aB=e[(c[277225]|0)+(aC<<1)>>1]|0;aD=(a[(c[277215]|0)+p|0]&32)==0;if(aD){aE=c[277228]|0;a8=aE;a9=aE&-2082}else{aE=e[(c[277213]|0)+(p<<1)>>1]|0;a8=aE;a9=aE&63454}if(aD){ba=c[277228]|0}else{ba=e[(c[277213]|0)+(p<<1)>>1]|0}a7=((ba^aB)&2081|e[(c[277220]|0)+((aB&2081&a8)+((a9+(aB&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=a7;aB=(a[(c[277215]|0)+p|0]&32)==0;do{if((a[1108928]|0)==0){aD=e[(c[277213]|0)+(aG+8<<1)>>1]|0;aE=aD&63454;if(aB){aH=c[277228]|0;bb=(e[(c[277220]|0)+((((aH&-2082)+aE|0)>>>1)+(aD&2081&aH)<<1)>>1]|(aH^aD)&2081)&65535;break}else{aH=e[(c[277226]|0)+(aC<<1)>>1]|0;bb=(((aH&63454)+aE|0)>>>1)+(aD&2081&aH)&65535;break}}else{if(aB){aH=c[277228]|0;bc=aH;bd=(c[277220]|0)+((aH>>>1&2147482607)<<1)|0}else{aH=e[(c[277226]|0)+(aC<<1)>>1]|0;bc=aH;bd=(c[277220]|0)+((aH>>>1&31727)<<1)|0}bb=(e[bd>>1]|bc&2081)&65535}}while(0);aC=aG+7|0;b[(c[277218]|0)+(aC<<1)>>1]=bb;aB=a[1108909]|0;a[(c[277219]|0)+aC|0]=aB;a[(c[277219]|0)+p|0]=aB}}while(0);p=aJ-1&255;if(p<<24>>24!=0){aS=p;G=5145}}if((G|0)==5145){G=0;p=aG+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){aB=a[s+3|0]|0;aC=aB&255;if(aB<<24>>24==0){break}do{if((a[1108928]|0)==0){aB=b[(c[277225]|0)+(aC<<1)>>1]|0;aH=aB&65535;aD=aH&63454;if((a[(c[277215]|0)+p|0]&32)==0){aE=c[277228]|0;be=(e[(c[277220]|0)+((((aE&-2082)+aD|0)>>>1)+(aH&2081&aE)<<1)>>1]|(aE^aH)&2081)&65535;break}else{aH=b[(c[277213]|0)+(p<<1)>>1]|0;be=(((aH&63454)+aD|0)>>>1)+(aH&aB&2081)&65535;break}}else{aB=e[(c[277225]|0)+(aC<<1)>>1]|0;aH=(a[(c[277215]|0)+p|0]&32)==0;if(aH){aD=c[277228]|0;bf=aD;bg=aD&-2082}else{aD=e[(c[277213]|0)+(p<<1)>>1]|0;bf=aD;bg=aD&63454}if(aH){bh=c[277228]|0}else{bh=e[(c[277213]|0)+(p<<1)>>1]|0}be=((bh^aB)&2081|e[(c[277220]|0)+((aB&2081&bf)+((bg+(aB&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=be;aB=(a[(c[277215]|0)+p|0]&32)==0;do{if((a[1108928]|0)==0){aH=e[(c[277213]|0)+(aG+10<<1)>>1]|0;aD=aH&63454;if(aB){aE=c[277228]|0;bi=(e[(c[277220]|0)+((((aE&-2082)+aD|0)>>>1)+(aH&2081&aE)<<1)>>1]|(aE^aH)&2081)&65535;break}else{aE=e[(c[277226]|0)+(aC<<1)>>1]|0;bi=(((aE&63454)+aD|0)>>>1)+(aH&2081&aE)&65535;break}}else{if(aB){aE=c[277228]|0;bj=aE;bk=(c[277220]|0)+((aE>>>1&2147482607)<<1)|0}else{aE=e[(c[277226]|0)+(aC<<1)>>1]|0;bj=aE;bk=(c[277220]|0)+((aE>>>1&31727)<<1)|0}bi=(e[bk>>1]|bj&2081)&65535}}while(0);aC=aG+9|0;b[(c[277218]|0)+(aC<<1)>>1]=bi;aB=a[1108909]|0;a[(c[277219]|0)+aC|0]=aB;a[(c[277219]|0)+p|0]=aB}}while(0);p=aS-1&255;if(p<<24>>24!=0){aI=p;G=5168}}if((G|0)==5168){G=0;p=aG+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){aB=a[s+2|0]|0;aC=aB&255;if(aB<<24>>24==0){break}do{if((a[1108928]|0)==0){aB=b[(c[277225]|0)+(aC<<1)>>1]|0;aE=aB&65535;aH=aE&63454;if((a[(c[277215]|0)+p|0]&32)==0){aD=c[277228]|0;bl=(e[(c[277220]|0)+((((aD&-2082)+aH|0)>>>1)+(aE&2081&aD)<<1)>>1]|(aD^aE)&2081)&65535;break}else{aE=b[(c[277213]|0)+(p<<1)>>1]|0;bl=(((aE&63454)+aH|0)>>>1)+(aE&aB&2081)&65535;break}}else{aB=e[(c[277225]|0)+(aC<<1)>>1]|0;aE=(a[(c[277215]|0)+p|0]&32)==0;if(aE){aH=c[277228]|0;bm=aH;bn=aH&-2082}else{aH=e[(c[277213]|0)+(p<<1)>>1]|0;bm=aH;bn=aH&63454}if(aE){bo=c[277228]|0}else{bo=e[(c[277213]|0)+(p<<1)>>1]|0}bl=((bo^aB)&2081|e[(c[277220]|0)+((aB&2081&bm)+((bn+(aB&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=bl;aB=(a[(c[277215]|0)+p|0]&32)==0;do{if((a[1108928]|0)==0){aE=e[(c[277213]|0)+(aG+12<<1)>>1]|0;aH=aE&63454;if(aB){aD=c[277228]|0;bp=(e[(c[277220]|0)+((((aD&-2082)+aH|0)>>>1)+(aE&2081&aD)<<1)>>1]|(aD^aE)&2081)&65535;break}else{aD=e[(c[277226]|0)+(aC<<1)>>1]|0;bp=(((aD&63454)+aH|0)>>>1)+(aE&2081&aD)&65535;break}}else{if(aB){aD=c[277228]|0;bq=aD;br=(c[277220]|0)+((aD>>>1&2147482607)<<1)|0}else{aD=e[(c[277226]|0)+(aC<<1)>>1]|0;bq=aD;br=(c[277220]|0)+((aD>>>1&31727)<<1)|0}bp=(e[br>>1]|bq&2081)&65535}}while(0);aC=aG+11|0;b[(c[277218]|0)+(aC<<1)>>1]=bp;aB=a[1108909]|0;a[(c[277219]|0)+aC|0]=aB;a[(c[277219]|0)+p|0]=aB}}while(0);p=aI-1&255;if(p<<24>>24!=0){aU=p;G=5191}}if((G|0)==5191){G=0;p=aG+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){aB=a[s+1|0]|0;aC=aB&255;if(aB<<24>>24==0){break}do{if((a[1108928]|0)==0){aB=b[(c[277225]|0)+(aC<<1)>>1]|0;aD=aB&65535;aE=aD&63454;if((a[(c[277215]|0)+p|0]&32)==0){aH=c[277228]|0;bs=(e[(c[277220]|0)+((((aH&-2082)+aE|0)>>>1)+(aD&2081&aH)<<1)>>1]|(aH^aD)&2081)&65535;break}else{aD=b[(c[277213]|0)+(p<<1)>>1]|0;bs=(((aD&63454)+aE|0)>>>1)+(aD&aB&2081)&65535;break}}else{aB=e[(c[277225]|0)+(aC<<1)>>1]|0;aD=(a[(c[277215]|0)+p|0]&32)==0;if(aD){aE=c[277228]|0;bt=aE;bu=aE&-2082}else{aE=e[(c[277213]|0)+(p<<1)>>1]|0;bt=aE;bu=aE&63454}if(aD){bv=c[277228]|0}else{bv=e[(c[277213]|0)+(p<<1)>>1]|0}bs=((bv^aB)&2081|e[(c[277220]|0)+((aB&2081&bt)+((bu+(aB&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=bs;aB=(a[(c[277215]|0)+p|0]&32)==0;do{if((a[1108928]|0)==0){aD=e[(c[277213]|0)+(aG+14<<1)>>1]|0;aE=aD&63454;if(aB){aH=c[277228]|0;bw=(e[(c[277220]|0)+((((aH&-2082)+aE|0)>>>1)+(aD&2081&aH)<<1)>>1]|(aH^aD)&2081)&65535;break}else{aH=e[(c[277226]|0)+(aC<<1)>>1]|0;bw=(((aH&63454)+aE|0)>>>1)+(aD&2081&aH)&65535;break}}else{if(aB){aH=c[277228]|0;bx=aH;by=(c[277220]|0)+((aH>>>1&2147482607)<<1)|0}else{aH=e[(c[277226]|0)+(aC<<1)>>1]|0;bx=aH;by=(c[277220]|0)+((aH>>>1&31727)<<1)|0}bw=(e[by>>1]|bx&2081)&65535}}while(0);aC=aG+13|0;b[(c[277218]|0)+(aC<<1)>>1]=bw;aB=a[1108909]|0;a[(c[277219]|0)+aC|0]=aB;a[(c[277219]|0)+p|0]=aB}}while(0);if(aU<<24>>24!=1){G=5214}}do{if((G|0)==5214){G=0;p=aG+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+p|0]|0)){break}aB=a[s]|0;aC=aB&255;if(aB<<24>>24==0){break}do{if((a[1108928]|0)==0){aB=b[(c[277225]|0)+(aC<<1)>>1]|0;aH=aB&65535;aD=aH&63454;if((a[(c[277215]|0)+p|0]&32)==0){aE=c[277228]|0;bz=(e[(c[277220]|0)+((((aE&-2082)+aD|0)>>>1)+(aH&2081&aE)<<1)>>1]|(aE^aH)&2081)&65535;break}else{aH=b[(c[277213]|0)+(p<<1)>>1]|0;bz=(((aH&63454)+aD|0)>>>1)+(aH&aB&2081)&65535;break}}else{aB=e[(c[277225]|0)+(aC<<1)>>1]|0;aH=(a[(c[277215]|0)+p|0]&32)==0;if(aH){aD=c[277228]|0;bA=aD;bB=aD&-2082}else{aD=e[(c[277213]|0)+(p<<1)>>1]|0;bA=aD;bB=aD&63454}if(aH){bC=c[277228]|0}else{bC=e[(c[277213]|0)+(p<<1)>>1]|0}bz=((bC^aB)&2081|e[(c[277220]|0)+((aB&2081&bA)+((bB+(aB&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=bz;aB=(a[(c[277215]|0)+p|0]&32)==0;do{if((a[1108928]|0)==0){aH=e[(c[277213]|0)+(aG+16<<1)>>1]|0;aD=aH&63454;if(aB){aE=c[277228]|0;bD=(e[(c[277220]|0)+((((aE&-2082)+aD|0)>>>1)+(aH&2081&aE)<<1)>>1]|(aE^aH)&2081)&65535;break}else{aE=e[(c[277226]|0)+(aC<<1)>>1]|0;bD=(((aE&63454)+aD|0)>>>1)+(aH&2081&aE)&65535;break}}else{if(aB){aE=c[277228]|0;bE=aE;bF=(c[277220]|0)+((aE>>>1&2147482607)<<1)|0}else{aE=e[(c[277226]|0)+(aC<<1)>>1]|0;bE=aE;bF=(c[277220]|0)+((aE>>>1&31727)<<1)|0}bD=(e[bF>>1]|bE&2081)&65535}}while(0);aC=aG+15|0;b[(c[277218]|0)+(aC<<1)>>1]=bD;aB=a[1108909]|0;a[(c[277219]|0)+aC|0]=aB;a[(c[277219]|0)+p|0]=aB}}while(0);aB=aF-1|0;if((aB|0)>0){s=s+16|0;aF=aB;aG=(c[277223]|0)+aG|0}else{break}}return}aG=r+(56-n)|0;n=(k|0)>0;if(m){if(!n){return}m=i&255;r=m-1&255;aF=r<<24>>24==0;s=aG;bD=k;bE=g;while(1){switch(h|0){case 3:{bG=m;G=5497;break};case 4:{bH=m;G=5520;break};case 5:{bI=m;G=5543;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+bE|0]|0)){bF=a[s+7|0]|0;bz=bF&255;if(bF<<24>>24==0){break}do{if((a[1108928]|0)==0){bF=b[(c[277225]|0)+(bz<<1)>>1]|0;bB=bF&65535;bA=bB&63454;if((a[(c[277215]|0)+bE|0]&32)==0){bC=c[277228]|0;bJ=(e[(c[277220]|0)+((((bC&-2082)+bA|0)>>>1)+(bB&2081&bC)<<1)>>1]|(bC^bB)&2081)&65535;break}else{bB=b[(c[277213]|0)+(bE<<1)>>1]|0;bJ=(((bB&63454)+bA|0)>>>1)+(bB&bF&2081)&65535;break}}else{bF=e[(c[277225]|0)+(bz<<1)>>1]|0;bB=(a[(c[277215]|0)+bE|0]&32)==0;if(bB){bA=c[277228]|0;bK=bA;bL=bA&-2082}else{bA=e[(c[277213]|0)+(bE<<1)>>1]|0;bK=bA;bL=bA&63454}if(bB){bM=c[277228]|0}else{bM=e[(c[277213]|0)+(bE<<1)>>1]|0}bJ=((bM^bF)&2081|e[(c[277220]|0)+((bF&2081&bK)+((bL+(bF&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(bE<<1)>>1]=bJ;p=(a[(c[277215]|0)+bE|0]&32)==0;do{if((a[1108928]|0)==0){bF=e[(c[277213]|0)+(bE+2<<1)>>1]|0;bB=bF&63454;if(p){bA=c[277228]|0;bN=(e[(c[277220]|0)+((((bA&-2082)+bB|0)>>>1)+(bF&2081&bA)<<1)>>1]|(bA^bF)&2081)&65535;break}else{bA=e[(c[277226]|0)+(bz<<1)>>1]|0;bN=(((bA&63454)+bB|0)>>>1)+(bF&2081&bA)&65535;break}}else{if(p){bA=c[277228]|0;bO=bA;bP=(c[277220]|0)+((bA>>>1&2147482607)<<1)|0}else{bA=e[(c[277226]|0)+(bz<<1)>>1]|0;bO=bA;bP=(c[277220]|0)+((bA>>>1&31727)<<1)|0}bN=(e[bP>>1]|bO&2081)&65535}}while(0);bz=bE+1|0;b[(c[277218]|0)+(bz<<1)>>1]=bN;p=a[1108909]|0;a[(c[277219]|0)+bz|0]=p;a[(c[277219]|0)+bE|0]=p}}while(0);if(!aF){bQ=r;G=5451}break};case 1:{bQ=m;G=5451;break};case 2:{bR=m;G=5474;break};case 6:{bS=m;G=5566;break};case 7:{G=5589;break};default:{}}if((G|0)==5451){G=0;p=bE+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){bz=a[s+6|0]|0;bA=bz&255;if(bz<<24>>24==0){break}do{if((a[1108928]|0)==0){bz=b[(c[277225]|0)+(bA<<1)>>1]|0;bF=bz&65535;bB=bF&63454;if((a[(c[277215]|0)+p|0]&32)==0){bC=c[277228]|0;bT=(e[(c[277220]|0)+((((bC&-2082)+bB|0)>>>1)+(bF&2081&bC)<<1)>>1]|(bC^bF)&2081)&65535;break}else{bF=b[(c[277213]|0)+(p<<1)>>1]|0;bT=(((bF&63454)+bB|0)>>>1)+(bF&bz&2081)&65535;break}}else{bz=e[(c[277225]|0)+(bA<<1)>>1]|0;bF=(a[(c[277215]|0)+p|0]&32)==0;if(bF){bB=c[277228]|0;bU=bB;bV=bB&-2082}else{bB=e[(c[277213]|0)+(p<<1)>>1]|0;bU=bB;bV=bB&63454}if(bF){bW=c[277228]|0}else{bW=e[(c[277213]|0)+(p<<1)>>1]|0}bT=((bW^bz)&2081|e[(c[277220]|0)+((bz&2081&bU)+((bV+(bz&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=bT;bz=(a[(c[277215]|0)+p|0]&32)==0;do{if((a[1108928]|0)==0){bF=e[(c[277213]|0)+(bE+4<<1)>>1]|0;bB=bF&63454;if(bz){bC=c[277228]|0;bX=(e[(c[277220]|0)+((((bC&-2082)+bB|0)>>>1)+(bF&2081&bC)<<1)>>1]|(bC^bF)&2081)&65535;break}else{bC=e[(c[277226]|0)+(bA<<1)>>1]|0;bX=(((bC&63454)+bB|0)>>>1)+(bF&2081&bC)&65535;break}}else{if(bz){bC=c[277228]|0;bY=bC;bZ=(c[277220]|0)+((bC>>>1&2147482607)<<1)|0}else{bC=e[(c[277226]|0)+(bA<<1)>>1]|0;bY=bC;bZ=(c[277220]|0)+((bC>>>1&31727)<<1)|0}bX=(e[bZ>>1]|bY&2081)&65535}}while(0);bA=bE+3|0;b[(c[277218]|0)+(bA<<1)>>1]=bX;bz=a[1108909]|0;a[(c[277219]|0)+bA|0]=bz;a[(c[277219]|0)+p|0]=bz}}while(0);p=bQ-1&255;if(p<<24>>24!=0){bR=p;G=5474}}if((G|0)==5474){G=0;p=bE+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){bz=a[s+5|0]|0;bA=bz&255;if(bz<<24>>24==0){break}do{if((a[1108928]|0)==0){bz=b[(c[277225]|0)+(bA<<1)>>1]|0;bC=bz&65535;bF=bC&63454;if((a[(c[277215]|0)+p|0]&32)==0){bB=c[277228]|0;b_=(e[(c[277220]|0)+((((bB&-2082)+bF|0)>>>1)+(bC&2081&bB)<<1)>>1]|(bB^bC)&2081)&65535;break}else{bC=b[(c[277213]|0)+(p<<1)>>1]|0;b_=(((bC&63454)+bF|0)>>>1)+(bC&bz&2081)&65535;break}}else{bz=e[(c[277225]|0)+(bA<<1)>>1]|0;bC=(a[(c[277215]|0)+p|0]&32)==0;if(bC){bF=c[277228]|0;b$=bF;b0=bF&-2082}else{bF=e[(c[277213]|0)+(p<<1)>>1]|0;b$=bF;b0=bF&63454}if(bC){b1=c[277228]|0}else{b1=e[(c[277213]|0)+(p<<1)>>1]|0}b_=((b1^bz)&2081|e[(c[277220]|0)+((bz&2081&b$)+((b0+(bz&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=b_;bz=(a[(c[277215]|0)+p|0]&32)==0;do{if((a[1108928]|0)==0){bC=e[(c[277213]|0)+(bE+6<<1)>>1]|0;bF=bC&63454;if(bz){bB=c[277228]|0;b2=(e[(c[277220]|0)+((((bB&-2082)+bF|0)>>>1)+(bC&2081&bB)<<1)>>1]|(bB^bC)&2081)&65535;break}else{bB=e[(c[277226]|0)+(bA<<1)>>1]|0;b2=(((bB&63454)+bF|0)>>>1)+(bC&2081&bB)&65535;break}}else{if(bz){bB=c[277228]|0;b3=bB;b4=(c[277220]|0)+((bB>>>1&2147482607)<<1)|0}else{bB=e[(c[277226]|0)+(bA<<1)>>1]|0;b3=bB;b4=(c[277220]|0)+((bB>>>1&31727)<<1)|0}b2=(e[b4>>1]|b3&2081)&65535}}while(0);bA=bE+5|0;b[(c[277218]|0)+(bA<<1)>>1]=b2;bz=a[1108909]|0;a[(c[277219]|0)+bA|0]=bz;a[(c[277219]|0)+p|0]=bz}}while(0);p=bR-1&255;if(p<<24>>24!=0){bG=p;G=5497}}if((G|0)==5497){G=0;p=bE+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){bz=a[s+4|0]|0;bA=bz&255;if(bz<<24>>24==0){break}do{if((a[1108928]|0)==0){bz=b[(c[277225]|0)+(bA<<1)>>1]|0;bB=bz&65535;bC=bB&63454;if((a[(c[277215]|0)+p|0]&32)==0){bF=c[277228]|0;b5=(e[(c[277220]|0)+((((bF&-2082)+bC|0)>>>1)+(bB&2081&bF)<<1)>>1]|(bF^bB)&2081)&65535;break}else{bB=b[(c[277213]|0)+(p<<1)>>1]|0;b5=(((bB&63454)+bC|0)>>>1)+(bB&bz&2081)&65535;break}}else{bz=e[(c[277225]|0)+(bA<<1)>>1]|0;bB=(a[(c[277215]|0)+p|0]&32)==0;if(bB){bC=c[277228]|0;b6=bC;b7=bC&-2082}else{bC=e[(c[277213]|0)+(p<<1)>>1]|0;b6=bC;b7=bC&63454}if(bB){b8=c[277228]|0}else{b8=e[(c[277213]|0)+(p<<1)>>1]|0}b5=((b8^bz)&2081|e[(c[277220]|0)+((bz&2081&b6)+((b7+(bz&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=b5;bz=(a[(c[277215]|0)+p|0]&32)==0;do{if((a[1108928]|0)==0){bB=e[(c[277213]|0)+(bE+8<<1)>>1]|0;bC=bB&63454;if(bz){bF=c[277228]|0;b9=(e[(c[277220]|0)+((((bF&-2082)+bC|0)>>>1)+(bB&2081&bF)<<1)>>1]|(bF^bB)&2081)&65535;break}else{bF=e[(c[277226]|0)+(bA<<1)>>1]|0;b9=(((bF&63454)+bC|0)>>>1)+(bB&2081&bF)&65535;break}}else{if(bz){bF=c[277228]|0;ca=bF;cb=(c[277220]|0)+((bF>>>1&2147482607)<<1)|0}else{bF=e[(c[277226]|0)+(bA<<1)>>1]|0;ca=bF;cb=(c[277220]|0)+((bF>>>1&31727)<<1)|0}b9=(e[cb>>1]|ca&2081)&65535}}while(0);bA=bE+7|0;b[(c[277218]|0)+(bA<<1)>>1]=b9;bz=a[1108909]|0;a[(c[277219]|0)+bA|0]=bz;a[(c[277219]|0)+p|0]=bz}}while(0);p=bG-1&255;if(p<<24>>24!=0){bH=p;G=5520}}if((G|0)==5520){G=0;p=bE+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){bz=a[s+3|0]|0;bA=bz&255;if(bz<<24>>24==0){break}do{if((a[1108928]|0)==0){bz=b[(c[277225]|0)+(bA<<1)>>1]|0;bF=bz&65535;bB=bF&63454;if((a[(c[277215]|0)+p|0]&32)==0){bC=c[277228]|0;cc=(e[(c[277220]|0)+((((bC&-2082)+bB|0)>>>1)+(bF&2081&bC)<<1)>>1]|(bC^bF)&2081)&65535;break}else{bF=b[(c[277213]|0)+(p<<1)>>1]|0;cc=(((bF&63454)+bB|0)>>>1)+(bF&bz&2081)&65535;break}}else{bz=e[(c[277225]|0)+(bA<<1)>>1]|0;bF=(a[(c[277215]|0)+p|0]&32)==0;if(bF){bB=c[277228]|0;cd=bB;ce=bB&-2082}else{bB=e[(c[277213]|0)+(p<<1)>>1]|0;cd=bB;ce=bB&63454}if(bF){cf=c[277228]|0}else{cf=e[(c[277213]|0)+(p<<1)>>1]|0}cc=((cf^bz)&2081|e[(c[277220]|0)+((bz&2081&cd)+((ce+(bz&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=cc;bz=(a[(c[277215]|0)+p|0]&32)==0;do{if((a[1108928]|0)==0){bF=e[(c[277213]|0)+(bE+10<<1)>>1]|0;bB=bF&63454;if(bz){bC=c[277228]|0;cg=(e[(c[277220]|0)+((((bC&-2082)+bB|0)>>>1)+(bF&2081&bC)<<1)>>1]|(bC^bF)&2081)&65535;break}else{bC=e[(c[277226]|0)+(bA<<1)>>1]|0;cg=(((bC&63454)+bB|0)>>>1)+(bF&2081&bC)&65535;break}}else{if(bz){bC=c[277228]|0;ch=bC;ci=(c[277220]|0)+((bC>>>1&2147482607)<<1)|0}else{bC=e[(c[277226]|0)+(bA<<1)>>1]|0;ch=bC;ci=(c[277220]|0)+((bC>>>1&31727)<<1)|0}cg=(e[ci>>1]|ch&2081)&65535}}while(0);bA=bE+9|0;b[(c[277218]|0)+(bA<<1)>>1]=cg;bz=a[1108909]|0;a[(c[277219]|0)+bA|0]=bz;a[(c[277219]|0)+p|0]=bz}}while(0);p=bH-1&255;if(p<<24>>24!=0){bI=p;G=5543}}if((G|0)==5543){G=0;p=bE+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){bz=a[s+2|0]|0;bA=bz&255;if(bz<<24>>24==0){break}do{if((a[1108928]|0)==0){bz=b[(c[277225]|0)+(bA<<1)>>1]|0;bC=bz&65535;bF=bC&63454;if((a[(c[277215]|0)+p|0]&32)==0){bB=c[277228]|0;cj=(e[(c[277220]|0)+((((bB&-2082)+bF|0)>>>1)+(bC&2081&bB)<<1)>>1]|(bB^bC)&2081)&65535;break}else{bC=b[(c[277213]|0)+(p<<1)>>1]|0;cj=(((bC&63454)+bF|0)>>>1)+(bC&bz&2081)&65535;break}}else{bz=e[(c[277225]|0)+(bA<<1)>>1]|0;bC=(a[(c[277215]|0)+p|0]&32)==0;if(bC){bF=c[277228]|0;ck=bF;cl=bF&-2082}else{bF=e[(c[277213]|0)+(p<<1)>>1]|0;ck=bF;cl=bF&63454}if(bC){cm=c[277228]|0}else{cm=e[(c[277213]|0)+(p<<1)>>1]|0}cj=((cm^bz)&2081|e[(c[277220]|0)+((bz&2081&ck)+((cl+(bz&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=cj;bz=(a[(c[277215]|0)+p|0]&32)==0;do{if((a[1108928]|0)==0){bC=e[(c[277213]|0)+(bE+12<<1)>>1]|0;bF=bC&63454;if(bz){bB=c[277228]|0;cn=(e[(c[277220]|0)+((((bB&-2082)+bF|0)>>>1)+(bC&2081&bB)<<1)>>1]|(bB^bC)&2081)&65535;break}else{bB=e[(c[277226]|0)+(bA<<1)>>1]|0;cn=(((bB&63454)+bF|0)>>>1)+(bC&2081&bB)&65535;break}}else{if(bz){bB=c[277228]|0;co=bB;cp=(c[277220]|0)+((bB>>>1&2147482607)<<1)|0}else{bB=e[(c[277226]|0)+(bA<<1)>>1]|0;co=bB;cp=(c[277220]|0)+((bB>>>1&31727)<<1)|0}cn=(e[cp>>1]|co&2081)&65535}}while(0);bA=bE+11|0;b[(c[277218]|0)+(bA<<1)>>1]=cn;bz=a[1108909]|0;a[(c[277219]|0)+bA|0]=bz;a[(c[277219]|0)+p|0]=bz}}while(0);p=bI-1&255;if(p<<24>>24!=0){bS=p;G=5566}}if((G|0)==5566){G=0;p=bE+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){bz=a[s+1|0]|0;bA=bz&255;if(bz<<24>>24==0){break}do{if((a[1108928]|0)==0){bz=b[(c[277225]|0)+(bA<<1)>>1]|0;bB=bz&65535;bC=bB&63454;if((a[(c[277215]|0)+p|0]&32)==0){bF=c[277228]|0;cq=(e[(c[277220]|0)+((((bF&-2082)+bC|0)>>>1)+(bB&2081&bF)<<1)>>1]|(bF^bB)&2081)&65535;break}else{bB=b[(c[277213]|0)+(p<<1)>>1]|0;cq=(((bB&63454)+bC|0)>>>1)+(bB&bz&2081)&65535;break}}else{bz=e[(c[277225]|0)+(bA<<1)>>1]|0;bB=(a[(c[277215]|0)+p|0]&32)==0;if(bB){bC=c[277228]|0;cr=bC;cs=bC&-2082}else{bC=e[(c[277213]|0)+(p<<1)>>1]|0;cr=bC;cs=bC&63454}if(bB){ct=c[277228]|0}else{ct=e[(c[277213]|0)+(p<<1)>>1]|0}cq=((ct^bz)&2081|e[(c[277220]|0)+((bz&2081&cr)+((cs+(bz&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=cq;bz=(a[(c[277215]|0)+p|0]&32)==0;do{if((a[1108928]|0)==0){bB=e[(c[277213]|0)+(bE+14<<1)>>1]|0;bC=bB&63454;if(bz){bF=c[277228]|0;cu=(e[(c[277220]|0)+((((bF&-2082)+bC|0)>>>1)+(bB&2081&bF)<<1)>>1]|(bF^bB)&2081)&65535;break}else{bF=e[(c[277226]|0)+(bA<<1)>>1]|0;cu=(((bF&63454)+bC|0)>>>1)+(bB&2081&bF)&65535;break}}else{if(bz){bF=c[277228]|0;cv=bF;cw=(c[277220]|0)+((bF>>>1&2147482607)<<1)|0}else{bF=e[(c[277226]|0)+(bA<<1)>>1]|0;cv=bF;cw=(c[277220]|0)+((bF>>>1&31727)<<1)|0}cu=(e[cw>>1]|cv&2081)&65535}}while(0);bA=bE+13|0;b[(c[277218]|0)+(bA<<1)>>1]=cu;bz=a[1108909]|0;a[(c[277219]|0)+bA|0]=bz;a[(c[277219]|0)+p|0]=bz}}while(0);if(bS<<24>>24!=1){G=5589}}do{if((G|0)==5589){G=0;p=bE+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+p|0]|0)){break}bz=a[s]|0;bA=bz&255;if(bz<<24>>24==0){break}do{if((a[1108928]|0)==0){bz=b[(c[277225]|0)+(bA<<1)>>1]|0;bF=bz&65535;bB=bF&63454;if((a[(c[277215]|0)+p|0]&32)==0){bC=c[277228]|0;cx=(e[(c[277220]|0)+((((bC&-2082)+bB|0)>>>1)+(bF&2081&bC)<<1)>>1]|(bC^bF)&2081)&65535;break}else{bF=b[(c[277213]|0)+(p<<1)>>1]|0;cx=(((bF&63454)+bB|0)>>>1)+(bF&bz&2081)&65535;break}}else{bz=e[(c[277225]|0)+(bA<<1)>>1]|0;bF=(a[(c[277215]|0)+p|0]&32)==0;if(bF){bB=c[277228]|0;cy=bB;cz=bB&-2082}else{bB=e[(c[277213]|0)+(p<<1)>>1]|0;cy=bB;cz=bB&63454}if(bF){cA=c[277228]|0}else{cA=e[(c[277213]|0)+(p<<1)>>1]|0}cx=((cA^bz)&2081|e[(c[277220]|0)+((bz&2081&cy)+((cz+(bz&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=cx;bz=(a[(c[277215]|0)+p|0]&32)==0;do{if((a[1108928]|0)==0){bF=e[(c[277213]|0)+(bE+16<<1)>>1]|0;bB=bF&63454;if(bz){bC=c[277228]|0;cB=(e[(c[277220]|0)+((((bC&-2082)+bB|0)>>>1)+(bF&2081&bC)<<1)>>1]|(bC^bF)&2081)&65535;break}else{bC=e[(c[277226]|0)+(bA<<1)>>1]|0;cB=(((bC&63454)+bB|0)>>>1)+(bF&2081&bC)&65535;break}}else{if(bz){bC=c[277228]|0;cC=bC;cD=(c[277220]|0)+((bC>>>1&2147482607)<<1)|0}else{bC=e[(c[277226]|0)+(bA<<1)>>1]|0;cC=bC;cD=(c[277220]|0)+((bC>>>1&31727)<<1)|0}cB=(e[cD>>1]|cC&2081)&65535}}while(0);bA=bE+15|0;b[(c[277218]|0)+(bA<<1)>>1]=cB;bz=a[1108909]|0;a[(c[277219]|0)+bA|0]=bz;a[(c[277219]|0)+p|0]=bz}}while(0);bz=bD-1|0;if((bz|0)>0){s=s-16|0;bD=bz;bE=(c[277223]|0)+bE|0}else{break}}return}else{if(!n){return}n=i&255;i=n-1&255;bE=i<<24>>24==0;bD=aG;aG=k;k=g;while(1){switch(h|0){case 7:{G=5404;break};case 4:{cE=n;G=5335;break};case 3:{cF=n;G=5312;break};case 5:{cG=n;G=5358;break};case 6:{cH=n;G=5381;break};case 2:{cI=n;G=5289;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+k|0]|0)){g=a[bD]|0;s=g&255;if(g<<24>>24==0){break}do{if((a[1108928]|0)==0){g=b[(c[277225]|0)+(s<<1)>>1]|0;cB=g&65535;cC=cB&63454;if((a[(c[277215]|0)+k|0]&32)==0){cD=c[277228]|0;cJ=(e[(c[277220]|0)+((((cD&-2082)+cC|0)>>>1)+(cB&2081&cD)<<1)>>1]|(cD^cB)&2081)&65535;break}else{cB=b[(c[277213]|0)+(k<<1)>>1]|0;cJ=(((cB&63454)+cC|0)>>>1)+(cB&g&2081)&65535;break}}else{g=e[(c[277225]|0)+(s<<1)>>1]|0;cB=(a[(c[277215]|0)+k|0]&32)==0;if(cB){cC=c[277228]|0;cK=cC;cL=cC&-2082}else{cC=e[(c[277213]|0)+(k<<1)>>1]|0;cK=cC;cL=cC&63454}if(cB){cM=c[277228]|0}else{cM=e[(c[277213]|0)+(k<<1)>>1]|0}cJ=((cM^g)&2081|e[(c[277220]|0)+((g&2081&cK)+((cL+(g&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(k<<1)>>1]=cJ;p=(a[(c[277215]|0)+k|0]&32)==0;do{if((a[1108928]|0)==0){g=e[(c[277213]|0)+(k+2<<1)>>1]|0;cB=g&63454;if(p){cC=c[277228]|0;cN=(e[(c[277220]|0)+((((cC&-2082)+cB|0)>>>1)+(g&2081&cC)<<1)>>1]|(cC^g)&2081)&65535;break}else{cC=e[(c[277226]|0)+(s<<1)>>1]|0;cN=(((cC&63454)+cB|0)>>>1)+(g&2081&cC)&65535;break}}else{if(p){cC=c[277228]|0;cO=cC;cP=(c[277220]|0)+((cC>>>1&2147482607)<<1)|0}else{cC=e[(c[277226]|0)+(s<<1)>>1]|0;cO=cC;cP=(c[277220]|0)+((cC>>>1&31727)<<1)|0}cN=(e[cP>>1]|cO&2081)&65535}}while(0);s=k+1|0;b[(c[277218]|0)+(s<<1)>>1]=cN;p=a[1108909]|0;a[(c[277219]|0)+s|0]=p;a[(c[277219]|0)+k|0]=p}}while(0);if(!bE){cQ=i;G=5266}break};case 1:{cQ=n;G=5266;break};default:{}}if((G|0)==5266){G=0;p=k+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){s=a[bD+1|0]|0;cC=s&255;if(s<<24>>24==0){break}do{if((a[1108928]|0)==0){s=b[(c[277225]|0)+(cC<<1)>>1]|0;g=s&65535;cB=g&63454;if((a[(c[277215]|0)+p|0]&32)==0){cD=c[277228]|0;cR=(e[(c[277220]|0)+((((cD&-2082)+cB|0)>>>1)+(g&2081&cD)<<1)>>1]|(cD^g)&2081)&65535;break}else{g=b[(c[277213]|0)+(p<<1)>>1]|0;cR=(((g&63454)+cB|0)>>>1)+(g&s&2081)&65535;break}}else{s=e[(c[277225]|0)+(cC<<1)>>1]|0;g=(a[(c[277215]|0)+p|0]&32)==0;if(g){cB=c[277228]|0;cS=cB;cT=cB&-2082}else{cB=e[(c[277213]|0)+(p<<1)>>1]|0;cS=cB;cT=cB&63454}if(g){cU=c[277228]|0}else{cU=e[(c[277213]|0)+(p<<1)>>1]|0}cR=((cU^s)&2081|e[(c[277220]|0)+((s&2081&cS)+((cT+(s&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=cR;s=(a[(c[277215]|0)+p|0]&32)==0;do{if((a[1108928]|0)==0){g=e[(c[277213]|0)+(k+4<<1)>>1]|0;cB=g&63454;if(s){cD=c[277228]|0;cV=(e[(c[277220]|0)+((((cD&-2082)+cB|0)>>>1)+(g&2081&cD)<<1)>>1]|(cD^g)&2081)&65535;break}else{cD=e[(c[277226]|0)+(cC<<1)>>1]|0;cV=(((cD&63454)+cB|0)>>>1)+(g&2081&cD)&65535;break}}else{if(s){cD=c[277228]|0;cW=cD;cX=(c[277220]|0)+((cD>>>1&2147482607)<<1)|0}else{cD=e[(c[277226]|0)+(cC<<1)>>1]|0;cW=cD;cX=(c[277220]|0)+((cD>>>1&31727)<<1)|0}cV=(e[cX>>1]|cW&2081)&65535}}while(0);cC=k+3|0;b[(c[277218]|0)+(cC<<1)>>1]=cV;s=a[1108909]|0;a[(c[277219]|0)+cC|0]=s;a[(c[277219]|0)+p|0]=s}}while(0);p=cQ-1&255;if(p<<24>>24!=0){cI=p;G=5289}}if((G|0)==5289){G=0;p=k+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){s=a[bD+2|0]|0;cC=s&255;if(s<<24>>24==0){break}do{if((a[1108928]|0)==0){s=b[(c[277225]|0)+(cC<<1)>>1]|0;cD=s&65535;g=cD&63454;if((a[(c[277215]|0)+p|0]&32)==0){cB=c[277228]|0;cY=(e[(c[277220]|0)+((((cB&-2082)+g|0)>>>1)+(cD&2081&cB)<<1)>>1]|(cB^cD)&2081)&65535;break}else{cD=b[(c[277213]|0)+(p<<1)>>1]|0;cY=(((cD&63454)+g|0)>>>1)+(cD&s&2081)&65535;break}}else{s=e[(c[277225]|0)+(cC<<1)>>1]|0;cD=(a[(c[277215]|0)+p|0]&32)==0;if(cD){g=c[277228]|0;cZ=g;c_=g&-2082}else{g=e[(c[277213]|0)+(p<<1)>>1]|0;cZ=g;c_=g&63454}if(cD){c$=c[277228]|0}else{c$=e[(c[277213]|0)+(p<<1)>>1]|0}cY=((c$^s)&2081|e[(c[277220]|0)+((s&2081&cZ)+((c_+(s&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=cY;s=(a[(c[277215]|0)+p|0]&32)==0;do{if((a[1108928]|0)==0){cD=e[(c[277213]|0)+(k+6<<1)>>1]|0;g=cD&63454;if(s){cB=c[277228]|0;c0=(e[(c[277220]|0)+((((cB&-2082)+g|0)>>>1)+(cD&2081&cB)<<1)>>1]|(cB^cD)&2081)&65535;break}else{cB=e[(c[277226]|0)+(cC<<1)>>1]|0;c0=(((cB&63454)+g|0)>>>1)+(cD&2081&cB)&65535;break}}else{if(s){cB=c[277228]|0;c1=cB;c2=(c[277220]|0)+((cB>>>1&2147482607)<<1)|0}else{cB=e[(c[277226]|0)+(cC<<1)>>1]|0;c1=cB;c2=(c[277220]|0)+((cB>>>1&31727)<<1)|0}c0=(e[c2>>1]|c1&2081)&65535}}while(0);cC=k+5|0;b[(c[277218]|0)+(cC<<1)>>1]=c0;s=a[1108909]|0;a[(c[277219]|0)+cC|0]=s;a[(c[277219]|0)+p|0]=s}}while(0);p=cI-1&255;if(p<<24>>24!=0){cF=p;G=5312}}if((G|0)==5312){G=0;p=k+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){s=a[bD+3|0]|0;cC=s&255;if(s<<24>>24==0){break}do{if((a[1108928]|0)==0){s=b[(c[277225]|0)+(cC<<1)>>1]|0;cB=s&65535;cD=cB&63454;if((a[(c[277215]|0)+p|0]&32)==0){g=c[277228]|0;c3=(e[(c[277220]|0)+((((g&-2082)+cD|0)>>>1)+(cB&2081&g)<<1)>>1]|(g^cB)&2081)&65535;break}else{cB=b[(c[277213]|0)+(p<<1)>>1]|0;c3=(((cB&63454)+cD|0)>>>1)+(cB&s&2081)&65535;break}}else{s=e[(c[277225]|0)+(cC<<1)>>1]|0;cB=(a[(c[277215]|0)+p|0]&32)==0;if(cB){cD=c[277228]|0;c4=cD;c5=cD&-2082}else{cD=e[(c[277213]|0)+(p<<1)>>1]|0;c4=cD;c5=cD&63454}if(cB){c6=c[277228]|0}else{c6=e[(c[277213]|0)+(p<<1)>>1]|0}c3=((c6^s)&2081|e[(c[277220]|0)+((s&2081&c4)+((c5+(s&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=c3;s=(a[(c[277215]|0)+p|0]&32)==0;do{if((a[1108928]|0)==0){cB=e[(c[277213]|0)+(k+8<<1)>>1]|0;cD=cB&63454;if(s){g=c[277228]|0;c7=(e[(c[277220]|0)+((((g&-2082)+cD|0)>>>1)+(cB&2081&g)<<1)>>1]|(g^cB)&2081)&65535;break}else{g=e[(c[277226]|0)+(cC<<1)>>1]|0;c7=(((g&63454)+cD|0)>>>1)+(cB&2081&g)&65535;break}}else{if(s){g=c[277228]|0;c8=g;c9=(c[277220]|0)+((g>>>1&2147482607)<<1)|0}else{g=e[(c[277226]|0)+(cC<<1)>>1]|0;c8=g;c9=(c[277220]|0)+((g>>>1&31727)<<1)|0}c7=(e[c9>>1]|c8&2081)&65535}}while(0);cC=k+7|0;b[(c[277218]|0)+(cC<<1)>>1]=c7;s=a[1108909]|0;a[(c[277219]|0)+cC|0]=s;a[(c[277219]|0)+p|0]=s}}while(0);p=cF-1&255;if(p<<24>>24!=0){cE=p;G=5335}}if((G|0)==5335){G=0;p=k+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){s=a[bD+4|0]|0;cC=s&255;if(s<<24>>24==0){break}do{if((a[1108928]|0)==0){s=b[(c[277225]|0)+(cC<<1)>>1]|0;g=s&65535;cB=g&63454;if((a[(c[277215]|0)+p|0]&32)==0){cD=c[277228]|0;da=(e[(c[277220]|0)+((((cD&-2082)+cB|0)>>>1)+(g&2081&cD)<<1)>>1]|(cD^g)&2081)&65535;break}else{g=b[(c[277213]|0)+(p<<1)>>1]|0;da=(((g&63454)+cB|0)>>>1)+(g&s&2081)&65535;break}}else{s=e[(c[277225]|0)+(cC<<1)>>1]|0;g=(a[(c[277215]|0)+p|0]&32)==0;if(g){cB=c[277228]|0;db=cB;dc=cB&-2082}else{cB=e[(c[277213]|0)+(p<<1)>>1]|0;db=cB;dc=cB&63454}if(g){dd=c[277228]|0}else{dd=e[(c[277213]|0)+(p<<1)>>1]|0}da=((dd^s)&2081|e[(c[277220]|0)+((s&2081&db)+((dc+(s&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=da;s=(a[(c[277215]|0)+p|0]&32)==0;do{if((a[1108928]|0)==0){g=e[(c[277213]|0)+(k+10<<1)>>1]|0;cB=g&63454;if(s){cD=c[277228]|0;de=(e[(c[277220]|0)+((((cD&-2082)+cB|0)>>>1)+(g&2081&cD)<<1)>>1]|(cD^g)&2081)&65535;break}else{cD=e[(c[277226]|0)+(cC<<1)>>1]|0;de=(((cD&63454)+cB|0)>>>1)+(g&2081&cD)&65535;break}}else{if(s){cD=c[277228]|0;df=cD;dg=(c[277220]|0)+((cD>>>1&2147482607)<<1)|0}else{cD=e[(c[277226]|0)+(cC<<1)>>1]|0;df=cD;dg=(c[277220]|0)+((cD>>>1&31727)<<1)|0}de=(e[dg>>1]|df&2081)&65535}}while(0);cC=k+9|0;b[(c[277218]|0)+(cC<<1)>>1]=de;s=a[1108909]|0;a[(c[277219]|0)+cC|0]=s;a[(c[277219]|0)+p|0]=s}}while(0);p=cE-1&255;if(p<<24>>24!=0){cG=p;G=5358}}if((G|0)==5358){G=0;p=k+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){s=a[bD+5|0]|0;cC=s&255;if(s<<24>>24==0){break}do{if((a[1108928]|0)==0){s=b[(c[277225]|0)+(cC<<1)>>1]|0;cD=s&65535;g=cD&63454;if((a[(c[277215]|0)+p|0]&32)==0){cB=c[277228]|0;dh=(e[(c[277220]|0)+((((cB&-2082)+g|0)>>>1)+(cD&2081&cB)<<1)>>1]|(cB^cD)&2081)&65535;break}else{cD=b[(c[277213]|0)+(p<<1)>>1]|0;dh=(((cD&63454)+g|0)>>>1)+(cD&s&2081)&65535;break}}else{s=e[(c[277225]|0)+(cC<<1)>>1]|0;cD=(a[(c[277215]|0)+p|0]&32)==0;if(cD){g=c[277228]|0;di=g;dj=g&-2082}else{g=e[(c[277213]|0)+(p<<1)>>1]|0;di=g;dj=g&63454}if(cD){dk=c[277228]|0}else{dk=e[(c[277213]|0)+(p<<1)>>1]|0}dh=((dk^s)&2081|e[(c[277220]|0)+((s&2081&di)+((dj+(s&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=dh;s=(a[(c[277215]|0)+p|0]&32)==0;do{if((a[1108928]|0)==0){cD=e[(c[277213]|0)+(k+12<<1)>>1]|0;g=cD&63454;if(s){cB=c[277228]|0;dl=(e[(c[277220]|0)+((((cB&-2082)+g|0)>>>1)+(cD&2081&cB)<<1)>>1]|(cB^cD)&2081)&65535;break}else{cB=e[(c[277226]|0)+(cC<<1)>>1]|0;dl=(((cB&63454)+g|0)>>>1)+(cD&2081&cB)&65535;break}}else{if(s){cB=c[277228]|0;dm=cB;dn=(c[277220]|0)+((cB>>>1&2147482607)<<1)|0}else{cB=e[(c[277226]|0)+(cC<<1)>>1]|0;dm=cB;dn=(c[277220]|0)+((cB>>>1&31727)<<1)|0}dl=(e[dn>>1]|dm&2081)&65535}}while(0);cC=k+11|0;b[(c[277218]|0)+(cC<<1)>>1]=dl;s=a[1108909]|0;a[(c[277219]|0)+cC|0]=s;a[(c[277219]|0)+p|0]=s}}while(0);p=cG-1&255;if(p<<24>>24!=0){cH=p;G=5381}}if((G|0)==5381){G=0;p=k+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+p|0]|0)){s=a[bD+6|0]|0;cC=s&255;if(s<<24>>24==0){break}do{if((a[1108928]|0)==0){s=b[(c[277225]|0)+(cC<<1)>>1]|0;cB=s&65535;cD=cB&63454;if((a[(c[277215]|0)+p|0]&32)==0){g=c[277228]|0;dp=(e[(c[277220]|0)+((((g&-2082)+cD|0)>>>1)+(cB&2081&g)<<1)>>1]|(g^cB)&2081)&65535;break}else{cB=b[(c[277213]|0)+(p<<1)>>1]|0;dp=(((cB&63454)+cD|0)>>>1)+(cB&s&2081)&65535;break}}else{s=e[(c[277225]|0)+(cC<<1)>>1]|0;cB=(a[(c[277215]|0)+p|0]&32)==0;if(cB){cD=c[277228]|0;dq=cD;dr=cD&-2082}else{cD=e[(c[277213]|0)+(p<<1)>>1]|0;dq=cD;dr=cD&63454}if(cB){ds=c[277228]|0}else{ds=e[(c[277213]|0)+(p<<1)>>1]|0}dp=((ds^s)&2081|e[(c[277220]|0)+((s&2081&dq)+((dr+(s&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=dp;s=(a[(c[277215]|0)+p|0]&32)==0;do{if((a[1108928]|0)==0){cB=e[(c[277213]|0)+(k+14<<1)>>1]|0;cD=cB&63454;if(s){g=c[277228]|0;dt=(e[(c[277220]|0)+((((g&-2082)+cD|0)>>>1)+(cB&2081&g)<<1)>>1]|(g^cB)&2081)&65535;break}else{g=e[(c[277226]|0)+(cC<<1)>>1]|0;dt=(((g&63454)+cD|0)>>>1)+(cB&2081&g)&65535;break}}else{if(s){g=c[277228]|0;du=g;dv=(c[277220]|0)+((g>>>1&2147482607)<<1)|0}else{g=e[(c[277226]|0)+(cC<<1)>>1]|0;du=g;dv=(c[277220]|0)+((g>>>1&31727)<<1)|0}dt=(e[dv>>1]|du&2081)&65535}}while(0);cC=k+13|0;b[(c[277218]|0)+(cC<<1)>>1]=dt;s=a[1108909]|0;a[(c[277219]|0)+cC|0]=s;a[(c[277219]|0)+p|0]=s}}while(0);if(cH<<24>>24!=1){G=5404}}do{if((G|0)==5404){G=0;p=k+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+p|0]|0)){break}s=a[bD+7|0]|0;cC=s&255;if(s<<24>>24==0){break}do{if((a[1108928]|0)==0){s=b[(c[277225]|0)+(cC<<1)>>1]|0;g=s&65535;cB=g&63454;if((a[(c[277215]|0)+p|0]&32)==0){cD=c[277228]|0;dw=(e[(c[277220]|0)+((((cD&-2082)+cB|0)>>>1)+(g&2081&cD)<<1)>>1]|(cD^g)&2081)&65535;break}else{g=b[(c[277213]|0)+(p<<1)>>1]|0;dw=(((g&63454)+cB|0)>>>1)+(g&s&2081)&65535;break}}else{s=e[(c[277225]|0)+(cC<<1)>>1]|0;g=(a[(c[277215]|0)+p|0]&32)==0;if(g){cB=c[277228]|0;dx=cB;dy=cB&-2082}else{cB=e[(c[277213]|0)+(p<<1)>>1]|0;dx=cB;dy=cB&63454}if(g){dz=c[277228]|0}else{dz=e[(c[277213]|0)+(p<<1)>>1]|0}dw=((dz^s)&2081|e[(c[277220]|0)+((s&2081&dx)+((dy+(s&63454)|0)>>>1)<<1)>>1])&65535}}while(0);b[(c[277218]|0)+(p<<1)>>1]=dw;s=(a[(c[277215]|0)+p|0]&32)==0;do{if((a[1108928]|0)==0){g=e[(c[277213]|0)+(k+16<<1)>>1]|0;cB=g&63454;if(s){cD=c[277228]|0;dA=(e[(c[277220]|0)+((((cD&-2082)+cB|0)>>>1)+(g&2081&cD)<<1)>>1]|(cD^g)&2081)&65535;break}else{cD=e[(c[277226]|0)+(cC<<1)>>1]|0;dA=(((cD&63454)+cB|0)>>>1)+(g&2081&cD)&65535;break}}else{if(s){cD=c[277228]|0;dB=cD;dC=(c[277220]|0)+((cD>>>1&2147482607)<<1)|0}else{cD=e[(c[277226]|0)+(cC<<1)>>1]|0;dB=cD;dC=(c[277220]|0)+((cD>>>1&31727)<<1)|0}dA=(e[dC>>1]|dB&2081)&65535}}while(0);cC=k+15|0;b[(c[277218]|0)+(cC<<1)>>1]=dA;s=a[1108909]|0;a[(c[277219]|0)+cC|0]=s;a[(c[277219]|0)+p|0]=s}}while(0);s=aG-1|0;if((s|0)>0){bD=bD-16|0;aG=s;k=(c[277223]|0)+k|0}else{break}}return}}function Ww(e,f,g,h,i,j){e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;var k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0,cf=0,cg=0,ch=0,ci=0,cj=0,ck=0,cl=0,cm=0,cn=0,co=0,cp=0,cq=0,cr=0,cs=0,ct=0,cu=0,cv=0,cw=0,cx=0,cy=0,cz=0,cA=0,cB=0,cC=0,cD=0,cE=0,cF=0,cG=0,cH=0,cI=0,cJ=0,cK=0,cL=0,cM=0,cN=0,cO=0,cP=0,cQ=0,cR=0,cS=0,cT=0,cU=0,cV=0,cW=0,cX=0,cY=0,cZ=0,c_=0,c$=0,c0=0,c1=0,c2=0,c3=0,c4=0,c5=0,c6=0,c7=0,c8=0,c9=0,da=0,db=0,dc=0,dd=0,de=0,df=0,dg=0,dh=0,di=0,dj=0,dk=0,dl=0,dm=0,dn=0,dp=0,dq=0,dr=0,ds=0,dt=0,du=0,dv=0,dw=0,dx=0,dy=0,dz=0,dA=0,dB=0;k=e&1023;l=c[348606]|0;m=(k<<l)+(c[348604]|0)|0;if((e&256|0)==0){n=m}else{n=(c[348602]|0)+m|0}m=n&65535;n=m>>>(l>>>0);l=(e&16384|0)!=0;o=n<<6;do{if(l){p=(c[348622]|0)+o|0;if((a[(c[348618]|0)+n|0]|0)!=0){q=p;break}r=fi[c[348636]&63](p,m,k)|0;a[(c[348618]|0)+n|0]=r;q=p}else{p=(c[348624]|0)+o|0;if((a[(c[348620]|0)+n|0]|0)!=0){q=p;break}r=fi[c[348638]&63](p,m,k)|0;a[(c[348620]|0)+n|0]=r;q=p}}while(0);if((a[(c[348620]|0)+n|0]|0)==2){return}if((a[1394464]|0)==0){s=1106168+((e>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){n=d[1044485]|0;c[276541]=7080+(n<<5);k=0;do{m=k<<1&2;o=k&2;p=k&4;r=0;do{b[1125528+(k<<9)+(r<<1)>>1]=d[(r>>>1&28|o)+(7080+(n<<5))|0]<<6|d[(r<<2&28|m)+(7080+(n<<5))|0]<<11|d[(r>>>3&24|p)+(7080+(n<<5))|0];r=r+1|0;}while(r>>>0<256);k=k+1|0;}while(k>>>0<8);a[1106089]=0}s=1125528+((e>>>10&7)<<9)|0}c[277226]=s;c[277225]=(a[1108928]|0)!=0?1393712:s;if((e&49152|0)==0){if((j|0)<=0){return}s=h&255;k=s-1&255;n=k<<24>>24==0;r=q+((d[1394504]|0)+(i<<1))|0;p=j;m=f;while(1){switch(g|0){case 2:{t=s;u=5683;break};case 7:{u=5783;break};case 6:{v=s;u=5763;break};case 4:{w=s;u=5723;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+m|0]|0)){o=a[r]|0;x=o&255;if(o<<24>>24==0){break}o=b[(c[277225]|0)+(x<<1)>>1]|0;if((a[(c[277215]|0)+m|0]&32)==0){y=c[277228]&65535}else{y=b[(c[277213]|0)+(m<<1)>>1]|0}z=o&-2048;A=y&-2048;B=(z&65535)>(A&65535)?z-A&65535:0;A=o&2016;z=y&2016;if((A&65535)>(z&65535)){C=(A-z&65535)+B&65535}else{C=B}B=o&31;o=y&31;if((B&65535)>(o&65535)){D=(B-o&65535)+C&65535}else{D=C}b[(c[277218]|0)+(m<<1)>>1]=D;if((a[1108928]|0)==0){E=b[(c[277213]|0)+(m+2<<1)>>1]|0}else{E=0}if((a[(c[277215]|0)+m|0]&32)==0){F=c[277228]&65535}else{F=b[(c[277226]|0)+(x<<1)>>1]|0}x=E&-2048;o=F&-2048;B=(x&65535)>(o&65535)?x-o&65535:0;o=E&2016;x=F&2016;if((o&65535)>(x&65535)){G=(o-x&65535)+B&65535}else{G=B}B=E&31;x=F&31;if((B&65535)>(x&65535)){H=(B-x&65535)+G&65535}else{H=G}x=m+1|0;b[(c[277218]|0)+(x<<1)>>1]=H;B=a[1108909]|0;a[(c[277219]|0)+x|0]=B;a[(c[277219]|0)+m|0]=B}}while(0);if(!n){I=k;u=5663}break};case 5:{J=s;u=5743;break};case 1:{I=s;u=5663;break};case 3:{K=s;u=5703;break};default:{}}if((u|0)==5663){u=0;B=m+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+B|0]|0)){x=a[r+1|0]|0;o=x&255;if(x<<24>>24==0){break}x=b[(c[277225]|0)+(o<<1)>>1]|0;if((a[(c[277215]|0)+B|0]&32)==0){L=c[277228]&65535}else{L=b[(c[277213]|0)+(B<<1)>>1]|0}z=x&-2048;A=L&-2048;M=(z&65535)>(A&65535)?z-A&65535:0;A=x&2016;z=L&2016;if((A&65535)>(z&65535)){N=(A-z&65535)+M&65535}else{N=M}M=x&31;x=L&31;if((M&65535)>(x&65535)){O=(M-x&65535)+N&65535}else{O=N}b[(c[277218]|0)+(B<<1)>>1]=O;if((a[1108928]|0)==0){P=b[(c[277213]|0)+(m+4<<1)>>1]|0}else{P=0}if((a[(c[277215]|0)+B|0]&32)==0){Q=c[277228]&65535}else{Q=b[(c[277226]|0)+(o<<1)>>1]|0}o=P&-2048;x=Q&-2048;M=(o&65535)>(x&65535)?o-x&65535:0;x=P&2016;o=Q&2016;if((x&65535)>(o&65535)){R=(x-o&65535)+M&65535}else{R=M}M=P&31;o=Q&31;if((M&65535)>(o&65535)){S=(M-o&65535)+R&65535}else{S=R}o=m+3|0;b[(c[277218]|0)+(o<<1)>>1]=S;M=a[1108909]|0;a[(c[277219]|0)+o|0]=M;a[(c[277219]|0)+B|0]=M}}while(0);B=I-1&255;if(B<<24>>24!=0){t=B;u=5683}}if((u|0)==5683){u=0;B=m+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+B|0]|0)){M=a[r+2|0]|0;o=M&255;if(M<<24>>24==0){break}M=b[(c[277225]|0)+(o<<1)>>1]|0;if((a[(c[277215]|0)+B|0]&32)==0){T=c[277228]&65535}else{T=b[(c[277213]|0)+(B<<1)>>1]|0}x=M&-2048;z=T&-2048;A=(x&65535)>(z&65535)?x-z&65535:0;z=M&2016;x=T&2016;if((z&65535)>(x&65535)){U=(z-x&65535)+A&65535}else{U=A}A=M&31;M=T&31;if((A&65535)>(M&65535)){V=(A-M&65535)+U&65535}else{V=U}b[(c[277218]|0)+(B<<1)>>1]=V;if((a[1108928]|0)==0){W=b[(c[277213]|0)+(m+6<<1)>>1]|0}else{W=0}if((a[(c[277215]|0)+B|0]&32)==0){X=c[277228]&65535}else{X=b[(c[277226]|0)+(o<<1)>>1]|0}o=W&-2048;M=X&-2048;A=(o&65535)>(M&65535)?o-M&65535:0;M=W&2016;o=X&2016;if((M&65535)>(o&65535)){Y=(M-o&65535)+A&65535}else{Y=A}A=W&31;o=X&31;if((A&65535)>(o&65535)){Z=(A-o&65535)+Y&65535}else{Z=Y}o=m+5|0;b[(c[277218]|0)+(o<<1)>>1]=Z;A=a[1108909]|0;a[(c[277219]|0)+o|0]=A;a[(c[277219]|0)+B|0]=A}}while(0);B=t-1&255;if(B<<24>>24!=0){K=B;u=5703}}if((u|0)==5703){u=0;B=m+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+B|0]|0)){A=a[r+3|0]|0;o=A&255;if(A<<24>>24==0){break}A=b[(c[277225]|0)+(o<<1)>>1]|0;if((a[(c[277215]|0)+B|0]&32)==0){_=c[277228]&65535}else{_=b[(c[277213]|0)+(B<<1)>>1]|0}M=A&-2048;x=_&-2048;z=(M&65535)>(x&65535)?M-x&65535:0;x=A&2016;M=_&2016;if((x&65535)>(M&65535)){$=(x-M&65535)+z&65535}else{$=z}z=A&31;A=_&31;if((z&65535)>(A&65535)){aa=(z-A&65535)+$&65535}else{aa=$}b[(c[277218]|0)+(B<<1)>>1]=aa;if((a[1108928]|0)==0){ab=b[(c[277213]|0)+(m+8<<1)>>1]|0}else{ab=0}if((a[(c[277215]|0)+B|0]&32)==0){ac=c[277228]&65535}else{ac=b[(c[277226]|0)+(o<<1)>>1]|0}o=ab&-2048;A=ac&-2048;z=(o&65535)>(A&65535)?o-A&65535:0;A=ab&2016;o=ac&2016;if((A&65535)>(o&65535)){ad=(A-o&65535)+z&65535}else{ad=z}z=ab&31;o=ac&31;if((z&65535)>(o&65535)){ae=(z-o&65535)+ad&65535}else{ae=ad}o=m+7|0;b[(c[277218]|0)+(o<<1)>>1]=ae;z=a[1108909]|0;a[(c[277219]|0)+o|0]=z;a[(c[277219]|0)+B|0]=z}}while(0);B=K-1&255;if(B<<24>>24!=0){w=B;u=5723}}if((u|0)==5723){u=0;B=m+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+B|0]|0)){z=a[r+4|0]|0;o=z&255;if(z<<24>>24==0){break}z=b[(c[277225]|0)+(o<<1)>>1]|0;if((a[(c[277215]|0)+B|0]&32)==0){af=c[277228]&65535}else{af=b[(c[277213]|0)+(B<<1)>>1]|0}A=z&-2048;M=af&-2048;x=(A&65535)>(M&65535)?A-M&65535:0;M=z&2016;A=af&2016;if((M&65535)>(A&65535)){ag=(M-A&65535)+x&65535}else{ag=x}x=z&31;z=af&31;if((x&65535)>(z&65535)){ah=(x-z&65535)+ag&65535}else{ah=ag}b[(c[277218]|0)+(B<<1)>>1]=ah;if((a[1108928]|0)==0){ai=b[(c[277213]|0)+(m+10<<1)>>1]|0}else{ai=0}if((a[(c[277215]|0)+B|0]&32)==0){aj=c[277228]&65535}else{aj=b[(c[277226]|0)+(o<<1)>>1]|0}o=ai&-2048;z=aj&-2048;x=(o&65535)>(z&65535)?o-z&65535:0;z=ai&2016;o=aj&2016;if((z&65535)>(o&65535)){ak=(z-o&65535)+x&65535}else{ak=x}x=ai&31;o=aj&31;if((x&65535)>(o&65535)){al=(x-o&65535)+ak&65535}else{al=ak}o=m+9|0;b[(c[277218]|0)+(o<<1)>>1]=al;x=a[1108909]|0;a[(c[277219]|0)+o|0]=x;a[(c[277219]|0)+B|0]=x}}while(0);B=w-1&255;if(B<<24>>24!=0){J=B;u=5743}}if((u|0)==5743){u=0;B=m+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+B|0]|0)){x=a[r+5|0]|0;o=x&255;if(x<<24>>24==0){break}x=b[(c[277225]|0)+(o<<1)>>1]|0;if((a[(c[277215]|0)+B|0]&32)==0){am=c[277228]&65535}else{am=b[(c[277213]|0)+(B<<1)>>1]|0}z=x&-2048;A=am&-2048;M=(z&65535)>(A&65535)?z-A&65535:0;A=x&2016;z=am&2016;if((A&65535)>(z&65535)){an=(A-z&65535)+M&65535}else{an=M}M=x&31;x=am&31;if((M&65535)>(x&65535)){ao=(M-x&65535)+an&65535}else{ao=an}b[(c[277218]|0)+(B<<1)>>1]=ao;if((a[1108928]|0)==0){ap=b[(c[277213]|0)+(m+12<<1)>>1]|0}else{ap=0}if((a[(c[277215]|0)+B|0]&32)==0){aq=c[277228]&65535}else{aq=b[(c[277226]|0)+(o<<1)>>1]|0}o=ap&-2048;x=aq&-2048;M=(o&65535)>(x&65535)?o-x&65535:0;x=ap&2016;o=aq&2016;if((x&65535)>(o&65535)){ar=(x-o&65535)+M&65535}else{ar=M}M=ap&31;o=aq&31;if((M&65535)>(o&65535)){as=(M-o&65535)+ar&65535}else{as=ar}o=m+11|0;b[(c[277218]|0)+(o<<1)>>1]=as;M=a[1108909]|0;a[(c[277219]|0)+o|0]=M;a[(c[277219]|0)+B|0]=M}}while(0);B=J-1&255;if(B<<24>>24!=0){v=B;u=5763}}if((u|0)==5763){u=0;B=m+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+B|0]|0)){M=a[r+6|0]|0;o=M&255;if(M<<24>>24==0){break}M=b[(c[277225]|0)+(o<<1)>>1]|0;if((a[(c[277215]|0)+B|0]&32)==0){at=c[277228]&65535}else{at=b[(c[277213]|0)+(B<<1)>>1]|0}x=M&-2048;z=at&-2048;A=(x&65535)>(z&65535)?x-z&65535:0;z=M&2016;x=at&2016;if((z&65535)>(x&65535)){au=(z-x&65535)+A&65535}else{au=A}A=M&31;M=at&31;if((A&65535)>(M&65535)){av=(A-M&65535)+au&65535}else{av=au}b[(c[277218]|0)+(B<<1)>>1]=av;if((a[1108928]|0)==0){aw=b[(c[277213]|0)+(m+14<<1)>>1]|0}else{aw=0}if((a[(c[277215]|0)+B|0]&32)==0){ax=c[277228]&65535}else{ax=b[(c[277226]|0)+(o<<1)>>1]|0}o=aw&-2048;M=ax&-2048;A=(o&65535)>(M&65535)?o-M&65535:0;M=aw&2016;o=ax&2016;if((M&65535)>(o&65535)){ay=(M-o&65535)+A&65535}else{ay=A}A=aw&31;o=ax&31;if((A&65535)>(o&65535)){az=(A-o&65535)+ay&65535}else{az=ay}o=m+13|0;b[(c[277218]|0)+(o<<1)>>1]=az;A=a[1108909]|0;a[(c[277219]|0)+o|0]=A;a[(c[277219]|0)+B|0]=A}}while(0);if(v<<24>>24!=1){u=5783}}do{if((u|0)==5783){u=0;B=m+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+B|0]|0)){break}A=a[r+7|0]|0;o=A&255;if(A<<24>>24==0){break}A=b[(c[277225]|0)+(o<<1)>>1]|0;if((a[(c[277215]|0)+B|0]&32)==0){aA=c[277228]&65535}else{aA=b[(c[277213]|0)+(B<<1)>>1]|0}M=A&-2048;x=aA&-2048;z=(M&65535)>(x&65535)?M-x&65535:0;x=A&2016;M=aA&2016;if((x&65535)>(M&65535)){aB=(x-M&65535)+z&65535}else{aB=z}z=A&31;A=aA&31;if((z&65535)>(A&65535)){aC=(z-A&65535)+aB&65535}else{aC=aB}b[(c[277218]|0)+(B<<1)>>1]=aC;if((a[1108928]|0)==0){aD=b[(c[277213]|0)+(m+16<<1)>>1]|0}else{aD=0}if((a[(c[277215]|0)+B|0]&32)==0){aE=c[277228]&65535}else{aE=b[(c[277226]|0)+(o<<1)>>1]|0}o=aD&-2048;A=aE&-2048;z=(o&65535)>(A&65535)?o-A&65535:0;A=aD&2016;o=aE&2016;if((A&65535)>(o&65535)){aF=(A-o&65535)+z&65535}else{aF=z}z=aD&31;o=aE&31;if((z&65535)>(o&65535)){aG=(z-o&65535)+aF&65535}else{aG=aF}o=m+15|0;b[(c[277218]|0)+(o<<1)>>1]=aG;z=a[1108909]|0;a[(c[277219]|0)+o|0]=z;a[(c[277219]|0)+B|0]=z}}while(0);z=p-1|0;if((z|0)>0){r=r+16|0;p=z;m=(c[277223]|0)+m|0}else{break}}return}m=(d[1394504]|0)+(i<<1)|0;if((e&32768|0)==0){if((j|0)<=0){return}e=h&255;i=e-1&255;p=i<<24>>24==0;r=q+m|0;aG=j;aF=f;while(1){switch(g|0){case 7:{u=5947;break};case 4:{aH=e;u=5887;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+aF|0]|0)){aE=a[r+7|0]|0;aD=aE&255;if(aE<<24>>24==0){break}aE=b[(c[277225]|0)+(aD<<1)>>1]|0;if((a[(c[277215]|0)+aF|0]&32)==0){aI=c[277228]&65535}else{aI=b[(c[277213]|0)+(aF<<1)>>1]|0}aC=aE&-2048;aB=aI&-2048;aA=(aC&65535)>(aB&65535)?aC-aB&65535:0;aB=aE&2016;aC=aI&2016;if((aB&65535)>(aC&65535)){aJ=(aB-aC&65535)+aA&65535}else{aJ=aA}aA=aE&31;aE=aI&31;if((aA&65535)>(aE&65535)){aK=(aA-aE&65535)+aJ&65535}else{aK=aJ}b[(c[277218]|0)+(aF<<1)>>1]=aK;if((a[1108928]|0)==0){aL=b[(c[277213]|0)+(aF+2<<1)>>1]|0}else{aL=0}if((a[(c[277215]|0)+aF|0]&32)==0){aM=c[277228]&65535}else{aM=b[(c[277226]|0)+(aD<<1)>>1]|0}aD=aL&-2048;aE=aM&-2048;aA=(aD&65535)>(aE&65535)?aD-aE&65535:0;aE=aL&2016;aD=aM&2016;if((aE&65535)>(aD&65535)){aN=(aE-aD&65535)+aA&65535}else{aN=aA}aA=aL&31;aD=aM&31;if((aA&65535)>(aD&65535)){aO=(aA-aD&65535)+aN&65535}else{aO=aN}aD=aF+1|0;b[(c[277218]|0)+(aD<<1)>>1]=aO;aA=a[1108909]|0;a[(c[277219]|0)+aD|0]=aA;a[(c[277219]|0)+aF|0]=aA}}while(0);if(!p){aP=i;u=5827}break};case 2:{aQ=e;u=5847;break};case 3:{aR=e;u=5867;break};case 5:{aS=e;u=5907;break};case 6:{aT=e;u=5927;break};case 1:{aP=e;u=5827;break};default:{}}if((u|0)==5827){u=0;aA=aF+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+aA|0]|0)){aD=a[r+6|0]|0;aE=aD&255;if(aD<<24>>24==0){break}aD=b[(c[277225]|0)+(aE<<1)>>1]|0;if((a[(c[277215]|0)+aA|0]&32)==0){aU=c[277228]&65535}else{aU=b[(c[277213]|0)+(aA<<1)>>1]|0}aC=aD&-2048;aB=aU&-2048;v=(aC&65535)>(aB&65535)?aC-aB&65535:0;aB=aD&2016;aC=aU&2016;if((aB&65535)>(aC&65535)){aV=(aB-aC&65535)+v&65535}else{aV=v}v=aD&31;aD=aU&31;if((v&65535)>(aD&65535)){aW=(v-aD&65535)+aV&65535}else{aW=aV}b[(c[277218]|0)+(aA<<1)>>1]=aW;if((a[1108928]|0)==0){aX=b[(c[277213]|0)+(aF+4<<1)>>1]|0}else{aX=0}if((a[(c[277215]|0)+aA|0]&32)==0){aY=c[277228]&65535}else{aY=b[(c[277226]|0)+(aE<<1)>>1]|0}aE=aX&-2048;aD=aY&-2048;v=(aE&65535)>(aD&65535)?aE-aD&65535:0;aD=aX&2016;aE=aY&2016;if((aD&65535)>(aE&65535)){aZ=(aD-aE&65535)+v&65535}else{aZ=v}v=aX&31;aE=aY&31;if((v&65535)>(aE&65535)){a_=(v-aE&65535)+aZ&65535}else{a_=aZ}aE=aF+3|0;b[(c[277218]|0)+(aE<<1)>>1]=a_;v=a[1108909]|0;a[(c[277219]|0)+aE|0]=v;a[(c[277219]|0)+aA|0]=v}}while(0);aA=aP-1&255;if(aA<<24>>24!=0){aQ=aA;u=5847}}if((u|0)==5847){u=0;aA=aF+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+aA|0]|0)){v=a[r+5|0]|0;aE=v&255;if(v<<24>>24==0){break}v=b[(c[277225]|0)+(aE<<1)>>1]|0;if((a[(c[277215]|0)+aA|0]&32)==0){a$=c[277228]&65535}else{a$=b[(c[277213]|0)+(aA<<1)>>1]|0}aD=v&-2048;aC=a$&-2048;aB=(aD&65535)>(aC&65535)?aD-aC&65535:0;aC=v&2016;aD=a$&2016;if((aC&65535)>(aD&65535)){a0=(aC-aD&65535)+aB&65535}else{a0=aB}aB=v&31;v=a$&31;if((aB&65535)>(v&65535)){a1=(aB-v&65535)+a0&65535}else{a1=a0}b[(c[277218]|0)+(aA<<1)>>1]=a1;if((a[1108928]|0)==0){a2=b[(c[277213]|0)+(aF+6<<1)>>1]|0}else{a2=0}if((a[(c[277215]|0)+aA|0]&32)==0){a3=c[277228]&65535}else{a3=b[(c[277226]|0)+(aE<<1)>>1]|0}aE=a2&-2048;v=a3&-2048;aB=(aE&65535)>(v&65535)?aE-v&65535:0;v=a2&2016;aE=a3&2016;if((v&65535)>(aE&65535)){a4=(v-aE&65535)+aB&65535}else{a4=aB}aB=a2&31;aE=a3&31;if((aB&65535)>(aE&65535)){a5=(aB-aE&65535)+a4&65535}else{a5=a4}aE=aF+5|0;b[(c[277218]|0)+(aE<<1)>>1]=a5;aB=a[1108909]|0;a[(c[277219]|0)+aE|0]=aB;a[(c[277219]|0)+aA|0]=aB}}while(0);aA=aQ-1&255;if(aA<<24>>24!=0){aR=aA;u=5867}}if((u|0)==5867){u=0;aA=aF+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+aA|0]|0)){aB=a[r+4|0]|0;aE=aB&255;if(aB<<24>>24==0){break}aB=b[(c[277225]|0)+(aE<<1)>>1]|0;if((a[(c[277215]|0)+aA|0]&32)==0){a6=c[277228]&65535}else{a6=b[(c[277213]|0)+(aA<<1)>>1]|0}v=aB&-2048;aD=a6&-2048;aC=(v&65535)>(aD&65535)?v-aD&65535:0;aD=aB&2016;v=a6&2016;if((aD&65535)>(v&65535)){a7=(aD-v&65535)+aC&65535}else{a7=aC}aC=aB&31;aB=a6&31;if((aC&65535)>(aB&65535)){a8=(aC-aB&65535)+a7&65535}else{a8=a7}b[(c[277218]|0)+(aA<<1)>>1]=a8;if((a[1108928]|0)==0){a9=b[(c[277213]|0)+(aF+8<<1)>>1]|0}else{a9=0}if((a[(c[277215]|0)+aA|0]&32)==0){ba=c[277228]&65535}else{ba=b[(c[277226]|0)+(aE<<1)>>1]|0}aE=a9&-2048;aB=ba&-2048;aC=(aE&65535)>(aB&65535)?aE-aB&65535:0;aB=a9&2016;aE=ba&2016;if((aB&65535)>(aE&65535)){bb=(aB-aE&65535)+aC&65535}else{bb=aC}aC=a9&31;aE=ba&31;if((aC&65535)>(aE&65535)){bc=(aC-aE&65535)+bb&65535}else{bc=bb}aE=aF+7|0;b[(c[277218]|0)+(aE<<1)>>1]=bc;aC=a[1108909]|0;a[(c[277219]|0)+aE|0]=aC;a[(c[277219]|0)+aA|0]=aC}}while(0);aA=aR-1&255;if(aA<<24>>24!=0){aH=aA;u=5887}}if((u|0)==5887){u=0;aA=aF+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+aA|0]|0)){aC=a[r+3|0]|0;aE=aC&255;if(aC<<24>>24==0){break}aC=b[(c[277225]|0)+(aE<<1)>>1]|0;if((a[(c[277215]|0)+aA|0]&32)==0){bd=c[277228]&65535}else{bd=b[(c[277213]|0)+(aA<<1)>>1]|0}aB=aC&-2048;v=bd&-2048;aD=(aB&65535)>(v&65535)?aB-v&65535:0;v=aC&2016;aB=bd&2016;if((v&65535)>(aB&65535)){be=(v-aB&65535)+aD&65535}else{be=aD}aD=aC&31;aC=bd&31;if((aD&65535)>(aC&65535)){bf=(aD-aC&65535)+be&65535}else{bf=be}b[(c[277218]|0)+(aA<<1)>>1]=bf;if((a[1108928]|0)==0){bg=b[(c[277213]|0)+(aF+10<<1)>>1]|0}else{bg=0}if((a[(c[277215]|0)+aA|0]&32)==0){bh=c[277228]&65535}else{bh=b[(c[277226]|0)+(aE<<1)>>1]|0}aE=bg&-2048;aC=bh&-2048;aD=(aE&65535)>(aC&65535)?aE-aC&65535:0;aC=bg&2016;aE=bh&2016;if((aC&65535)>(aE&65535)){bi=(aC-aE&65535)+aD&65535}else{bi=aD}aD=bg&31;aE=bh&31;if((aD&65535)>(aE&65535)){bj=(aD-aE&65535)+bi&65535}else{bj=bi}aE=aF+9|0;b[(c[277218]|0)+(aE<<1)>>1]=bj;aD=a[1108909]|0;a[(c[277219]|0)+aE|0]=aD;a[(c[277219]|0)+aA|0]=aD}}while(0);aA=aH-1&255;if(aA<<24>>24!=0){aS=aA;u=5907}}if((u|0)==5907){u=0;aA=aF+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+aA|0]|0)){aD=a[r+2|0]|0;aE=aD&255;if(aD<<24>>24==0){break}aD=b[(c[277225]|0)+(aE<<1)>>1]|0;if((a[(c[277215]|0)+aA|0]&32)==0){bk=c[277228]&65535}else{bk=b[(c[277213]|0)+(aA<<1)>>1]|0}aC=aD&-2048;aB=bk&-2048;v=(aC&65535)>(aB&65535)?aC-aB&65535:0;aB=aD&2016;aC=bk&2016;if((aB&65535)>(aC&65535)){bl=(aB-aC&65535)+v&65535}else{bl=v}v=aD&31;aD=bk&31;if((v&65535)>(aD&65535)){bm=(v-aD&65535)+bl&65535}else{bm=bl}b[(c[277218]|0)+(aA<<1)>>1]=bm;if((a[1108928]|0)==0){bn=b[(c[277213]|0)+(aF+12<<1)>>1]|0}else{bn=0}if((a[(c[277215]|0)+aA|0]&32)==0){bo=c[277228]&65535}else{bo=b[(c[277226]|0)+(aE<<1)>>1]|0}aE=bn&-2048;aD=bo&-2048;v=(aE&65535)>(aD&65535)?aE-aD&65535:0;aD=bn&2016;aE=bo&2016;if((aD&65535)>(aE&65535)){bp=(aD-aE&65535)+v&65535}else{bp=v}v=bn&31;aE=bo&31;if((v&65535)>(aE&65535)){bq=(v-aE&65535)+bp&65535}else{bq=bp}aE=aF+11|0;b[(c[277218]|0)+(aE<<1)>>1]=bq;v=a[1108909]|0;a[(c[277219]|0)+aE|0]=v;a[(c[277219]|0)+aA|0]=v}}while(0);aA=aS-1&255;if(aA<<24>>24!=0){aT=aA;u=5927}}if((u|0)==5927){u=0;aA=aF+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+aA|0]|0)){v=a[r+1|0]|0;aE=v&255;if(v<<24>>24==0){break}v=b[(c[277225]|0)+(aE<<1)>>1]|0;if((a[(c[277215]|0)+aA|0]&32)==0){br=c[277228]&65535}else{br=b[(c[277213]|0)+(aA<<1)>>1]|0}aD=v&-2048;aC=br&-2048;aB=(aD&65535)>(aC&65535)?aD-aC&65535:0;aC=v&2016;aD=br&2016;if((aC&65535)>(aD&65535)){bs=(aC-aD&65535)+aB&65535}else{bs=aB}aB=v&31;v=br&31;if((aB&65535)>(v&65535)){bt=(aB-v&65535)+bs&65535}else{bt=bs}b[(c[277218]|0)+(aA<<1)>>1]=bt;if((a[1108928]|0)==0){bu=b[(c[277213]|0)+(aF+14<<1)>>1]|0}else{bu=0}if((a[(c[277215]|0)+aA|0]&32)==0){bv=c[277228]&65535}else{bv=b[(c[277226]|0)+(aE<<1)>>1]|0}aE=bu&-2048;v=bv&-2048;aB=(aE&65535)>(v&65535)?aE-v&65535:0;v=bu&2016;aE=bv&2016;if((v&65535)>(aE&65535)){bw=(v-aE&65535)+aB&65535}else{bw=aB}aB=bu&31;aE=bv&31;if((aB&65535)>(aE&65535)){bx=(aB-aE&65535)+bw&65535}else{bx=bw}aE=aF+13|0;b[(c[277218]|0)+(aE<<1)>>1]=bx;aB=a[1108909]|0;a[(c[277219]|0)+aE|0]=aB;a[(c[277219]|0)+aA|0]=aB}}while(0);if(aT<<24>>24!=1){u=5947}}do{if((u|0)==5947){u=0;aA=aF+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+aA|0]|0)){break}aB=a[r]|0;aE=aB&255;if(aB<<24>>24==0){break}aB=b[(c[277225]|0)+(aE<<1)>>1]|0;if((a[(c[277215]|0)+aA|0]&32)==0){by=c[277228]&65535}else{by=b[(c[277213]|0)+(aA<<1)>>1]|0}v=aB&-2048;aD=by&-2048;aC=(v&65535)>(aD&65535)?v-aD&65535:0;aD=aB&2016;v=by&2016;if((aD&65535)>(v&65535)){bz=(aD-v&65535)+aC&65535}else{bz=aC}aC=aB&31;aB=by&31;if((aC&65535)>(aB&65535)){bA=(aC-aB&65535)+bz&65535}else{bA=bz}b[(c[277218]|0)+(aA<<1)>>1]=bA;if((a[1108928]|0)==0){bB=b[(c[277213]|0)+(aF+16<<1)>>1]|0}else{bB=0}if((a[(c[277215]|0)+aA|0]&32)==0){bC=c[277228]&65535}else{bC=b[(c[277226]|0)+(aE<<1)>>1]|0}aE=bB&-2048;aB=bC&-2048;aC=(aE&65535)>(aB&65535)?aE-aB&65535:0;aB=bB&2016;aE=bC&2016;if((aB&65535)>(aE&65535)){bD=(aB-aE&65535)+aC&65535}else{bD=aC}aC=bB&31;aE=bC&31;if((aC&65535)>(aE&65535)){bE=(aC-aE&65535)+bD&65535}else{bE=bD}aE=aF+15|0;b[(c[277218]|0)+(aE<<1)>>1]=bE;aC=a[1108909]|0;a[(c[277219]|0)+aE|0]=aC;a[(c[277219]|0)+aA|0]=aC}}while(0);aC=aG-1|0;if((aC|0)>0){r=r+16|0;aG=aC;aF=(c[277223]|0)+aF|0}else{break}}return}aF=q+(56-m)|0;m=(j|0)>0;if(l){if(!m){return}l=h&255;q=l-1&255;aG=q<<24>>24==0;r=aF;bE=j;bD=f;while(1){switch(g|0){case 4:{bF=l;u=6214;break};case 5:{bG=l;u=6234;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+bD|0]|0)){bC=a[r+7|0]|0;bB=bC&255;if(bC<<24>>24==0){break}bC=b[(c[277225]|0)+(bB<<1)>>1]|0;if((a[(c[277215]|0)+bD|0]&32)==0){bH=c[277228]&65535}else{bH=b[(c[277213]|0)+(bD<<1)>>1]|0}bA=bC&-2048;bz=bH&-2048;by=(bA&65535)>(bz&65535)?bA-bz&65535:0;bz=bC&2016;bA=bH&2016;if((bz&65535)>(bA&65535)){bI=(bz-bA&65535)+by&65535}else{bI=by}by=bC&31;bC=bH&31;if((by&65535)>(bC&65535)){bJ=(by-bC&65535)+bI&65535}else{bJ=bI}b[(c[277218]|0)+(bD<<1)>>1]=bJ;if((a[1108928]|0)==0){bK=b[(c[277213]|0)+(bD+2<<1)>>1]|0}else{bK=0}if((a[(c[277215]|0)+bD|0]&32)==0){bL=c[277228]&65535}else{bL=b[(c[277226]|0)+(bB<<1)>>1]|0}bB=bK&-2048;bC=bL&-2048;by=(bB&65535)>(bC&65535)?bB-bC&65535:0;bC=bK&2016;bB=bL&2016;if((bC&65535)>(bB&65535)){bM=(bC-bB&65535)+by&65535}else{bM=by}by=bK&31;bB=bL&31;if((by&65535)>(bB&65535)){bN=(by-bB&65535)+bM&65535}else{bN=bM}bB=bD+1|0;b[(c[277218]|0)+(bB<<1)>>1]=bN;by=a[1108909]|0;a[(c[277219]|0)+bB|0]=by;a[(c[277219]|0)+bD|0]=by}}while(0);if(!aG){bO=q;u=6154}break};case 1:{bO=l;u=6154;break};case 6:{bP=l;u=6254;break};case 7:{u=6274;break};case 2:{bQ=l;u=6174;break};case 3:{bR=l;u=6194;break};default:{}}if((u|0)==6154){u=0;by=bD+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+by|0]|0)){bB=a[r+6|0]|0;bC=bB&255;if(bB<<24>>24==0){break}bB=b[(c[277225]|0)+(bC<<1)>>1]|0;if((a[(c[277215]|0)+by|0]&32)==0){bS=c[277228]&65535}else{bS=b[(c[277213]|0)+(by<<1)>>1]|0}bA=bB&-2048;bz=bS&-2048;aT=(bA&65535)>(bz&65535)?bA-bz&65535:0;bz=bB&2016;bA=bS&2016;if((bz&65535)>(bA&65535)){bT=(bz-bA&65535)+aT&65535}else{bT=aT}aT=bB&31;bB=bS&31;if((aT&65535)>(bB&65535)){bU=(aT-bB&65535)+bT&65535}else{bU=bT}b[(c[277218]|0)+(by<<1)>>1]=bU;if((a[1108928]|0)==0){bV=b[(c[277213]|0)+(bD+4<<1)>>1]|0}else{bV=0}if((a[(c[277215]|0)+by|0]&32)==0){bW=c[277228]&65535}else{bW=b[(c[277226]|0)+(bC<<1)>>1]|0}bC=bV&-2048;bB=bW&-2048;aT=(bC&65535)>(bB&65535)?bC-bB&65535:0;bB=bV&2016;bC=bW&2016;if((bB&65535)>(bC&65535)){bX=(bB-bC&65535)+aT&65535}else{bX=aT}aT=bV&31;bC=bW&31;if((aT&65535)>(bC&65535)){bY=(aT-bC&65535)+bX&65535}else{bY=bX}bC=bD+3|0;b[(c[277218]|0)+(bC<<1)>>1]=bY;aT=a[1108909]|0;a[(c[277219]|0)+bC|0]=aT;a[(c[277219]|0)+by|0]=aT}}while(0);by=bO-1&255;if(by<<24>>24!=0){bQ=by;u=6174}}if((u|0)==6174){u=0;by=bD+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+by|0]|0)){aT=a[r+5|0]|0;bC=aT&255;if(aT<<24>>24==0){break}aT=b[(c[277225]|0)+(bC<<1)>>1]|0;if((a[(c[277215]|0)+by|0]&32)==0){bZ=c[277228]&65535}else{bZ=b[(c[277213]|0)+(by<<1)>>1]|0}bB=aT&-2048;bA=bZ&-2048;bz=(bB&65535)>(bA&65535)?bB-bA&65535:0;bA=aT&2016;bB=bZ&2016;if((bA&65535)>(bB&65535)){b_=(bA-bB&65535)+bz&65535}else{b_=bz}bz=aT&31;aT=bZ&31;if((bz&65535)>(aT&65535)){b$=(bz-aT&65535)+b_&65535}else{b$=b_}b[(c[277218]|0)+(by<<1)>>1]=b$;if((a[1108928]|0)==0){b0=b[(c[277213]|0)+(bD+6<<1)>>1]|0}else{b0=0}if((a[(c[277215]|0)+by|0]&32)==0){b1=c[277228]&65535}else{b1=b[(c[277226]|0)+(bC<<1)>>1]|0}bC=b0&-2048;aT=b1&-2048;bz=(bC&65535)>(aT&65535)?bC-aT&65535:0;aT=b0&2016;bC=b1&2016;if((aT&65535)>(bC&65535)){b2=(aT-bC&65535)+bz&65535}else{b2=bz}bz=b0&31;bC=b1&31;if((bz&65535)>(bC&65535)){b3=(bz-bC&65535)+b2&65535}else{b3=b2}bC=bD+5|0;b[(c[277218]|0)+(bC<<1)>>1]=b3;bz=a[1108909]|0;a[(c[277219]|0)+bC|0]=bz;a[(c[277219]|0)+by|0]=bz}}while(0);by=bQ-1&255;if(by<<24>>24!=0){bR=by;u=6194}}if((u|0)==6194){u=0;by=bD+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+by|0]|0)){bz=a[r+4|0]|0;bC=bz&255;if(bz<<24>>24==0){break}bz=b[(c[277225]|0)+(bC<<1)>>1]|0;if((a[(c[277215]|0)+by|0]&32)==0){b4=c[277228]&65535}else{b4=b[(c[277213]|0)+(by<<1)>>1]|0}aT=bz&-2048;bB=b4&-2048;bA=(aT&65535)>(bB&65535)?aT-bB&65535:0;bB=bz&2016;aT=b4&2016;if((bB&65535)>(aT&65535)){b5=(bB-aT&65535)+bA&65535}else{b5=bA}bA=bz&31;bz=b4&31;if((bA&65535)>(bz&65535)){b6=(bA-bz&65535)+b5&65535}else{b6=b5}b[(c[277218]|0)+(by<<1)>>1]=b6;if((a[1108928]|0)==0){b7=b[(c[277213]|0)+(bD+8<<1)>>1]|0}else{b7=0}if((a[(c[277215]|0)+by|0]&32)==0){b8=c[277228]&65535}else{b8=b[(c[277226]|0)+(bC<<1)>>1]|0}bC=b7&-2048;bz=b8&-2048;bA=(bC&65535)>(bz&65535)?bC-bz&65535:0;bz=b7&2016;bC=b8&2016;if((bz&65535)>(bC&65535)){b9=(bz-bC&65535)+bA&65535}else{b9=bA}bA=b7&31;bC=b8&31;if((bA&65535)>(bC&65535)){ca=(bA-bC&65535)+b9&65535}else{ca=b9}bC=bD+7|0;b[(c[277218]|0)+(bC<<1)>>1]=ca;bA=a[1108909]|0;a[(c[277219]|0)+bC|0]=bA;a[(c[277219]|0)+by|0]=bA}}while(0);by=bR-1&255;if(by<<24>>24!=0){bF=by;u=6214}}if((u|0)==6214){u=0;by=bD+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+by|0]|0)){bA=a[r+3|0]|0;bC=bA&255;if(bA<<24>>24==0){break}bA=b[(c[277225]|0)+(bC<<1)>>1]|0;if((a[(c[277215]|0)+by|0]&32)==0){cb=c[277228]&65535}else{cb=b[(c[277213]|0)+(by<<1)>>1]|0}bz=bA&-2048;aT=cb&-2048;bB=(bz&65535)>(aT&65535)?bz-aT&65535:0;aT=bA&2016;bz=cb&2016;if((aT&65535)>(bz&65535)){cc=(aT-bz&65535)+bB&65535}else{cc=bB}bB=bA&31;bA=cb&31;if((bB&65535)>(bA&65535)){cd=(bB-bA&65535)+cc&65535}else{cd=cc}b[(c[277218]|0)+(by<<1)>>1]=cd;if((a[1108928]|0)==0){ce=b[(c[277213]|0)+(bD+10<<1)>>1]|0}else{ce=0}if((a[(c[277215]|0)+by|0]&32)==0){cf=c[277228]&65535}else{cf=b[(c[277226]|0)+(bC<<1)>>1]|0}bC=ce&-2048;bA=cf&-2048;bB=(bC&65535)>(bA&65535)?bC-bA&65535:0;bA=ce&2016;bC=cf&2016;if((bA&65535)>(bC&65535)){cg=(bA-bC&65535)+bB&65535}else{cg=bB}bB=ce&31;bC=cf&31;if((bB&65535)>(bC&65535)){ch=(bB-bC&65535)+cg&65535}else{ch=cg}bC=bD+9|0;b[(c[277218]|0)+(bC<<1)>>1]=ch;bB=a[1108909]|0;a[(c[277219]|0)+bC|0]=bB;a[(c[277219]|0)+by|0]=bB}}while(0);by=bF-1&255;if(by<<24>>24!=0){bG=by;u=6234}}if((u|0)==6234){u=0;by=bD+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+by|0]|0)){bB=a[r+2|0]|0;bC=bB&255;if(bB<<24>>24==0){break}bB=b[(c[277225]|0)+(bC<<1)>>1]|0;if((a[(c[277215]|0)+by|0]&32)==0){ci=c[277228]&65535}else{ci=b[(c[277213]|0)+(by<<1)>>1]|0}bA=bB&-2048;bz=ci&-2048;aT=(bA&65535)>(bz&65535)?bA-bz&65535:0;bz=bB&2016;bA=ci&2016;if((bz&65535)>(bA&65535)){cj=(bz-bA&65535)+aT&65535}else{cj=aT}aT=bB&31;bB=ci&31;if((aT&65535)>(bB&65535)){ck=(aT-bB&65535)+cj&65535}else{ck=cj}b[(c[277218]|0)+(by<<1)>>1]=ck;if((a[1108928]|0)==0){cl=b[(c[277213]|0)+(bD+12<<1)>>1]|0}else{cl=0}if((a[(c[277215]|0)+by|0]&32)==0){cm=c[277228]&65535}else{cm=b[(c[277226]|0)+(bC<<1)>>1]|0}bC=cl&-2048;bB=cm&-2048;aT=(bC&65535)>(bB&65535)?bC-bB&65535:0;bB=cl&2016;bC=cm&2016;if((bB&65535)>(bC&65535)){cn=(bB-bC&65535)+aT&65535}else{cn=aT}aT=cl&31;bC=cm&31;if((aT&65535)>(bC&65535)){co=(aT-bC&65535)+cn&65535}else{co=cn}bC=bD+11|0;b[(c[277218]|0)+(bC<<1)>>1]=co;aT=a[1108909]|0;a[(c[277219]|0)+bC|0]=aT;a[(c[277219]|0)+by|0]=aT}}while(0);by=bG-1&255;if(by<<24>>24!=0){bP=by;u=6254}}if((u|0)==6254){u=0;by=bD+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+by|0]|0)){aT=a[r+1|0]|0;bC=aT&255;if(aT<<24>>24==0){break}aT=b[(c[277225]|0)+(bC<<1)>>1]|0;if((a[(c[277215]|0)+by|0]&32)==0){cp=c[277228]&65535}else{cp=b[(c[277213]|0)+(by<<1)>>1]|0}bB=aT&-2048;bA=cp&-2048;bz=(bB&65535)>(bA&65535)?bB-bA&65535:0;bA=aT&2016;bB=cp&2016;if((bA&65535)>(bB&65535)){cq=(bA-bB&65535)+bz&65535}else{cq=bz}bz=aT&31;aT=cp&31;if((bz&65535)>(aT&65535)){cr=(bz-aT&65535)+cq&65535}else{cr=cq}b[(c[277218]|0)+(by<<1)>>1]=cr;if((a[1108928]|0)==0){cs=b[(c[277213]|0)+(bD+14<<1)>>1]|0}else{cs=0}if((a[(c[277215]|0)+by|0]&32)==0){ct=c[277228]&65535}else{ct=b[(c[277226]|0)+(bC<<1)>>1]|0}bC=cs&-2048;aT=ct&-2048;bz=(bC&65535)>(aT&65535)?bC-aT&65535:0;aT=cs&2016;bC=ct&2016;if((aT&65535)>(bC&65535)){cu=(aT-bC&65535)+bz&65535}else{cu=bz}bz=cs&31;bC=ct&31;if((bz&65535)>(bC&65535)){cv=(bz-bC&65535)+cu&65535}else{cv=cu}bC=bD+13|0;b[(c[277218]|0)+(bC<<1)>>1]=cv;bz=a[1108909]|0;a[(c[277219]|0)+bC|0]=bz;a[(c[277219]|0)+by|0]=bz}}while(0);if(bP<<24>>24!=1){u=6274}}do{if((u|0)==6274){u=0;by=bD+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+by|0]|0)){break}bz=a[r]|0;bC=bz&255;if(bz<<24>>24==0){break}bz=b[(c[277225]|0)+(bC<<1)>>1]|0;if((a[(c[277215]|0)+by|0]&32)==0){cw=c[277228]&65535}else{cw=b[(c[277213]|0)+(by<<1)>>1]|0}aT=bz&-2048;bB=cw&-2048;bA=(aT&65535)>(bB&65535)?aT-bB&65535:0;bB=bz&2016;aT=cw&2016;if((bB&65535)>(aT&65535)){cx=(bB-aT&65535)+bA&65535}else{cx=bA}bA=bz&31;bz=cw&31;if((bA&65535)>(bz&65535)){cy=(bA-bz&65535)+cx&65535}else{cy=cx}b[(c[277218]|0)+(by<<1)>>1]=cy;if((a[1108928]|0)==0){cz=b[(c[277213]|0)+(bD+16<<1)>>1]|0}else{cz=0}if((a[(c[277215]|0)+by|0]&32)==0){cA=c[277228]&65535}else{cA=b[(c[277226]|0)+(bC<<1)>>1]|0}bC=cz&-2048;bz=cA&-2048;bA=(bC&65535)>(bz&65535)?bC-bz&65535:0;bz=cz&2016;bC=cA&2016;if((bz&65535)>(bC&65535)){cB=(bz-bC&65535)+bA&65535}else{cB=bA}bA=cz&31;bC=cA&31;if((bA&65535)>(bC&65535)){cC=(bA-bC&65535)+cB&65535}else{cC=cB}bC=bD+15|0;b[(c[277218]|0)+(bC<<1)>>1]=cC;bA=a[1108909]|0;a[(c[277219]|0)+bC|0]=bA;a[(c[277219]|0)+by|0]=bA}}while(0);bA=bE-1|0;if((bA|0)>0){r=r-16|0;bE=bA;bD=(c[277223]|0)+bD|0}else{break}}return}else{if(!m){return}m=h&255;h=m-1&255;bD=h<<24>>24==0;bE=aF;aF=j;j=f;while(1){switch(g|0){case 7:{u=6113;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+j|0]|0)){f=a[bE]|0;r=f&255;if(f<<24>>24==0){break}f=b[(c[277225]|0)+(r<<1)>>1]|0;if((a[(c[277215]|0)+j|0]&32)==0){cD=c[277228]&65535}else{cD=b[(c[277213]|0)+(j<<1)>>1]|0}cC=f&-2048;cB=cD&-2048;cA=(cC&65535)>(cB&65535)?cC-cB&65535:0;cB=f&2016;cC=cD&2016;if((cB&65535)>(cC&65535)){cE=(cB-cC&65535)+cA&65535}else{cE=cA}cA=f&31;f=cD&31;if((cA&65535)>(f&65535)){cF=(cA-f&65535)+cE&65535}else{cF=cE}b[(c[277218]|0)+(j<<1)>>1]=cF;if((a[1108928]|0)==0){cG=b[(c[277213]|0)+(j+2<<1)>>1]|0}else{cG=0}if((a[(c[277215]|0)+j|0]&32)==0){cH=c[277228]&65535}else{cH=b[(c[277226]|0)+(r<<1)>>1]|0}r=cG&-2048;f=cH&-2048;cA=(r&65535)>(f&65535)?r-f&65535:0;f=cG&2016;r=cH&2016;if((f&65535)>(r&65535)){cI=(f-r&65535)+cA&65535}else{cI=cA}cA=cG&31;r=cH&31;if((cA&65535)>(r&65535)){cJ=(cA-r&65535)+cI&65535}else{cJ=cI}r=j+1|0;b[(c[277218]|0)+(r<<1)>>1]=cJ;cA=a[1108909]|0;a[(c[277219]|0)+r|0]=cA;a[(c[277219]|0)+j|0]=cA}}while(0);if(!bD){cK=h;u=5993}break};case 4:{cL=m;u=6053;break};case 5:{cM=m;u=6073;break};case 6:{cN=m;u=6093;break};case 2:{cO=m;u=6013;break};case 3:{cP=m;u=6033;break};case 1:{cK=m;u=5993;break};default:{}}if((u|0)==5993){u=0;cA=j+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+cA|0]|0)){r=a[bE+1|0]|0;f=r&255;if(r<<24>>24==0){break}r=b[(c[277225]|0)+(f<<1)>>1]|0;if((a[(c[277215]|0)+cA|0]&32)==0){cQ=c[277228]&65535}else{cQ=b[(c[277213]|0)+(cA<<1)>>1]|0}cC=r&-2048;cB=cQ&-2048;cz=(cC&65535)>(cB&65535)?cC-cB&65535:0;cB=r&2016;cC=cQ&2016;if((cB&65535)>(cC&65535)){cR=(cB-cC&65535)+cz&65535}else{cR=cz}cz=r&31;r=cQ&31;if((cz&65535)>(r&65535)){cS=(cz-r&65535)+cR&65535}else{cS=cR}b[(c[277218]|0)+(cA<<1)>>1]=cS;if((a[1108928]|0)==0){cT=b[(c[277213]|0)+(j+4<<1)>>1]|0}else{cT=0}if((a[(c[277215]|0)+cA|0]&32)==0){cU=c[277228]&65535}else{cU=b[(c[277226]|0)+(f<<1)>>1]|0}f=cT&-2048;r=cU&-2048;cz=(f&65535)>(r&65535)?f-r&65535:0;r=cT&2016;f=cU&2016;if((r&65535)>(f&65535)){cV=(r-f&65535)+cz&65535}else{cV=cz}cz=cT&31;f=cU&31;if((cz&65535)>(f&65535)){cW=(cz-f&65535)+cV&65535}else{cW=cV}f=j+3|0;b[(c[277218]|0)+(f<<1)>>1]=cW;cz=a[1108909]|0;a[(c[277219]|0)+f|0]=cz;a[(c[277219]|0)+cA|0]=cz}}while(0);cA=cK-1&255;if(cA<<24>>24!=0){cO=cA;u=6013}}if((u|0)==6013){u=0;cA=j+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+cA|0]|0)){cz=a[bE+2|0]|0;f=cz&255;if(cz<<24>>24==0){break}cz=b[(c[277225]|0)+(f<<1)>>1]|0;if((a[(c[277215]|0)+cA|0]&32)==0){cX=c[277228]&65535}else{cX=b[(c[277213]|0)+(cA<<1)>>1]|0}r=cz&-2048;cC=cX&-2048;cB=(r&65535)>(cC&65535)?r-cC&65535:0;cC=cz&2016;r=cX&2016;if((cC&65535)>(r&65535)){cY=(cC-r&65535)+cB&65535}else{cY=cB}cB=cz&31;cz=cX&31;if((cB&65535)>(cz&65535)){cZ=(cB-cz&65535)+cY&65535}else{cZ=cY}b[(c[277218]|0)+(cA<<1)>>1]=cZ;if((a[1108928]|0)==0){c_=b[(c[277213]|0)+(j+6<<1)>>1]|0}else{c_=0}if((a[(c[277215]|0)+cA|0]&32)==0){c$=c[277228]&65535}else{c$=b[(c[277226]|0)+(f<<1)>>1]|0}f=c_&-2048;cz=c$&-2048;cB=(f&65535)>(cz&65535)?f-cz&65535:0;cz=c_&2016;f=c$&2016;if((cz&65535)>(f&65535)){c0=(cz-f&65535)+cB&65535}else{c0=cB}cB=c_&31;f=c$&31;if((cB&65535)>(f&65535)){c1=(cB-f&65535)+c0&65535}else{c1=c0}f=j+5|0;b[(c[277218]|0)+(f<<1)>>1]=c1;cB=a[1108909]|0;a[(c[277219]|0)+f|0]=cB;a[(c[277219]|0)+cA|0]=cB}}while(0);cA=cO-1&255;if(cA<<24>>24!=0){cP=cA;u=6033}}if((u|0)==6033){u=0;cA=j+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+cA|0]|0)){cB=a[bE+3|0]|0;f=cB&255;if(cB<<24>>24==0){break}cB=b[(c[277225]|0)+(f<<1)>>1]|0;if((a[(c[277215]|0)+cA|0]&32)==0){c2=c[277228]&65535}else{c2=b[(c[277213]|0)+(cA<<1)>>1]|0}cz=cB&-2048;r=c2&-2048;cC=(cz&65535)>(r&65535)?cz-r&65535:0;r=cB&2016;cz=c2&2016;if((r&65535)>(cz&65535)){c3=(r-cz&65535)+cC&65535}else{c3=cC}cC=cB&31;cB=c2&31;if((cC&65535)>(cB&65535)){c4=(cC-cB&65535)+c3&65535}else{c4=c3}b[(c[277218]|0)+(cA<<1)>>1]=c4;if((a[1108928]|0)==0){c5=b[(c[277213]|0)+(j+8<<1)>>1]|0}else{c5=0}if((a[(c[277215]|0)+cA|0]&32)==0){c6=c[277228]&65535}else{c6=b[(c[277226]|0)+(f<<1)>>1]|0}f=c5&-2048;cB=c6&-2048;cC=(f&65535)>(cB&65535)?f-cB&65535:0;cB=c5&2016;f=c6&2016;if((cB&65535)>(f&65535)){c7=(cB-f&65535)+cC&65535}else{c7=cC}cC=c5&31;f=c6&31;if((cC&65535)>(f&65535)){c8=(cC-f&65535)+c7&65535}else{c8=c7}f=j+7|0;b[(c[277218]|0)+(f<<1)>>1]=c8;cC=a[1108909]|0;a[(c[277219]|0)+f|0]=cC;a[(c[277219]|0)+cA|0]=cC}}while(0);cA=cP-1&255;if(cA<<24>>24!=0){cL=cA;u=6053}}if((u|0)==6053){u=0;cA=j+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+cA|0]|0)){cC=a[bE+4|0]|0;f=cC&255;if(cC<<24>>24==0){break}cC=b[(c[277225]|0)+(f<<1)>>1]|0;if((a[(c[277215]|0)+cA|0]&32)==0){c9=c[277228]&65535}else{c9=b[(c[277213]|0)+(cA<<1)>>1]|0}cB=cC&-2048;cz=c9&-2048;r=(cB&65535)>(cz&65535)?cB-cz&65535:0;cz=cC&2016;cB=c9&2016;if((cz&65535)>(cB&65535)){da=(cz-cB&65535)+r&65535}else{da=r}r=cC&31;cC=c9&31;if((r&65535)>(cC&65535)){db=(r-cC&65535)+da&65535}else{db=da}b[(c[277218]|0)+(cA<<1)>>1]=db;if((a[1108928]|0)==0){dc=b[(c[277213]|0)+(j+10<<1)>>1]|0}else{dc=0}if((a[(c[277215]|0)+cA|0]&32)==0){dd=c[277228]&65535}else{dd=b[(c[277226]|0)+(f<<1)>>1]|0}f=dc&-2048;cC=dd&-2048;r=(f&65535)>(cC&65535)?f-cC&65535:0;cC=dc&2016;f=dd&2016;if((cC&65535)>(f&65535)){de=(cC-f&65535)+r&65535}else{de=r}r=dc&31;f=dd&31;if((r&65535)>(f&65535)){df=(r-f&65535)+de&65535}else{df=de}f=j+9|0;b[(c[277218]|0)+(f<<1)>>1]=df;r=a[1108909]|0;a[(c[277219]|0)+f|0]=r;a[(c[277219]|0)+cA|0]=r}}while(0);cA=cL-1&255;if(cA<<24>>24!=0){cM=cA;u=6073}}if((u|0)==6073){u=0;cA=j+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+cA|0]|0)){r=a[bE+5|0]|0;f=r&255;if(r<<24>>24==0){break}r=b[(c[277225]|0)+(f<<1)>>1]|0;if((a[(c[277215]|0)+cA|0]&32)==0){dg=c[277228]&65535}else{dg=b[(c[277213]|0)+(cA<<1)>>1]|0}cC=r&-2048;cB=dg&-2048;cz=(cC&65535)>(cB&65535)?cC-cB&65535:0;cB=r&2016;cC=dg&2016;if((cB&65535)>(cC&65535)){dh=(cB-cC&65535)+cz&65535}else{dh=cz}cz=r&31;r=dg&31;if((cz&65535)>(r&65535)){di=(cz-r&65535)+dh&65535}else{di=dh}b[(c[277218]|0)+(cA<<1)>>1]=di;if((a[1108928]|0)==0){dj=b[(c[277213]|0)+(j+12<<1)>>1]|0}else{dj=0}if((a[(c[277215]|0)+cA|0]&32)==0){dk=c[277228]&65535}else{dk=b[(c[277226]|0)+(f<<1)>>1]|0}f=dj&-2048;r=dk&-2048;cz=(f&65535)>(r&65535)?f-r&65535:0;r=dj&2016;f=dk&2016;if((r&65535)>(f&65535)){dl=(r-f&65535)+cz&65535}else{dl=cz}cz=dj&31;f=dk&31;if((cz&65535)>(f&65535)){dm=(cz-f&65535)+dl&65535}else{dm=dl}f=j+11|0;b[(c[277218]|0)+(f<<1)>>1]=dm;cz=a[1108909]|0;a[(c[277219]|0)+f|0]=cz;a[(c[277219]|0)+cA|0]=cz}}while(0);cA=cM-1&255;if(cA<<24>>24!=0){cN=cA;u=6093}}if((u|0)==6093){u=0;cA=j+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+cA|0]|0)){cz=a[bE+6|0]|0;f=cz&255;if(cz<<24>>24==0){break}cz=b[(c[277225]|0)+(f<<1)>>1]|0;if((a[(c[277215]|0)+cA|0]&32)==0){dn=c[277228]&65535}else{dn=b[(c[277213]|0)+(cA<<1)>>1]|0}r=cz&-2048;cC=dn&-2048;cB=(r&65535)>(cC&65535)?r-cC&65535:0;cC=cz&2016;r=dn&2016;if((cC&65535)>(r&65535)){dp=(cC-r&65535)+cB&65535}else{dp=cB}cB=cz&31;cz=dn&31;if((cB&65535)>(cz&65535)){dq=(cB-cz&65535)+dp&65535}else{dq=dp}b[(c[277218]|0)+(cA<<1)>>1]=dq;if((a[1108928]|0)==0){dr=b[(c[277213]|0)+(j+14<<1)>>1]|0}else{dr=0}if((a[(c[277215]|0)+cA|0]&32)==0){ds=c[277228]&65535}else{ds=b[(c[277226]|0)+(f<<1)>>1]|0}f=dr&-2048;cz=ds&-2048;cB=(f&65535)>(cz&65535)?f-cz&65535:0;cz=dr&2016;f=ds&2016;if((cz&65535)>(f&65535)){dt=(cz-f&65535)+cB&65535}else{dt=cB}cB=dr&31;f=ds&31;if((cB&65535)>(f&65535)){du=(cB-f&65535)+dt&65535}else{du=dt}f=j+13|0;b[(c[277218]|0)+(f<<1)>>1]=du;cB=a[1108909]|0;a[(c[277219]|0)+f|0]=cB;a[(c[277219]|0)+cA|0]=cB}}while(0);if(cN<<24>>24!=1){u=6113}}do{if((u|0)==6113){u=0;cA=j+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+cA|0]|0)){break}cB=a[bE+7|0]|0;f=cB&255;if(cB<<24>>24==0){break}cB=b[(c[277225]|0)+(f<<1)>>1]|0;if((a[(c[277215]|0)+cA|0]&32)==0){dv=c[277228]&65535}else{dv=b[(c[277213]|0)+(cA<<1)>>1]|0}cz=cB&-2048;r=dv&-2048;cC=(cz&65535)>(r&65535)?cz-r&65535:0;r=cB&2016;cz=dv&2016;if((r&65535)>(cz&65535)){dw=(r-cz&65535)+cC&65535}else{dw=cC}cC=cB&31;cB=dv&31;if((cC&65535)>(cB&65535)){dx=(cC-cB&65535)+dw&65535}else{dx=dw}b[(c[277218]|0)+(cA<<1)>>1]=dx;if((a[1108928]|0)==0){dy=b[(c[277213]|0)+(j+16<<1)>>1]|0}else{dy=0}if((a[(c[277215]|0)+cA|0]&32)==0){dz=c[277228]&65535}else{dz=b[(c[277226]|0)+(f<<1)>>1]|0}f=dy&-2048;cB=dz&-2048;cC=(f&65535)>(cB&65535)?f-cB&65535:0;cB=dy&2016;f=dz&2016;if((cB&65535)>(f&65535)){dA=(cB-f&65535)+cC&65535}else{dA=cC}cC=dy&31;f=dz&31;if((cC&65535)>(f&65535)){dB=(cC-f&65535)+dA&65535}else{dB=dA}f=j+15|0;b[(c[277218]|0)+(f<<1)>>1]=dB;cC=a[1108909]|0;a[(c[277219]|0)+f|0]=cC;a[(c[277219]|0)+cA|0]=cC}}while(0);cC=aF-1|0;if((cC|0)>0){bE=bE-16|0;aF=cC;j=(c[277223]|0)+j|0}else{break}}return}}function Wx(f,g,h,i,j,k){f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;var l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0;l=f&1023;m=c[348606]|0;n=(l<<m)+(c[348604]|0)|0;if((f&256|0)==0){o=n}else{o=(c[348602]|0)+n|0}n=o&65535;o=n>>>(m>>>0);m=(f&16384|0)!=0;p=o<<6;do{if(m){q=(c[348622]|0)+p|0;if((a[(c[348618]|0)+o|0]|0)!=0){r=q;break}s=fi[c[348636]&63](q,n,l)|0;a[(c[348618]|0)+o|0]=s;r=q}else{q=(c[348624]|0)+p|0;if((a[(c[348620]|0)+o|0]|0)!=0){r=q;break}s=fi[c[348638]&63](q,n,l)|0;a[(c[348620]|0)+o|0]=s;r=q}}while(0);if((a[(c[348620]|0)+o|0]|0)==2){return}if((a[1394464]|0)==0){t=1106168+((f>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){o=d[1044485]|0;c[276541]=7080+(o<<5);l=0;do{n=l<<1&2;p=l&2;q=l&4;s=0;do{b[1125528+(l<<9)+(s<<1)>>1]=d[(s>>>1&28|p)+(7080+(o<<5))|0]<<6|d[(s<<2&28|n)+(7080+(o<<5))|0]<<11|d[(s>>>3&24|q)+(7080+(o<<5))|0];s=s+1|0;}while(s>>>0<256);l=l+1|0;}while(l>>>0<8);a[1106089]=0}t=1125528+((f>>>10&7)<<9)|0}c[277226]=t;c[277225]=(a[1108928]|0)!=0?1393712:t;if((f&49152|0)==0){if((k|0)<=0){return}t=i&255;l=t-1&255;o=l<<24>>24==0;s=r+((d[1394504]|0)+(j<<1))|0;q=k;n=g;while(1){switch(h|0){case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+n|0]|0)){p=a[s]|0;if(p<<24>>24==0){break}u=b[(c[277225]|0)+((p&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){v=b[(c[277221]|0)+(((u&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{p=c[277228]&65535;w=u&-2048;x=p&-2048;y=(w&65535)>(x&65535)?w-x&65535:0;x=u&2016;w=p&2016;if((x&65535)>(w&65535)){z=(x-w&65535)+y&65535}else{z=y}y=u&31;w=p&31;if((y&65535)<=(w&65535)){v=z;break}v=(y-w&65535)+z&65535}}while(0);b[(c[277218]|0)+(n<<1)>>1]=v;if((a[1108928]|0)==0){A=b[(c[277221]|0)+(((e[(c[277213]|0)+(n+2<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{A=0}u=n+1|0;b[(c[277218]|0)+(u<<1)>>1]=A;w=a[1108909]|0;a[(c[277219]|0)+u|0]=w;a[(c[277219]|0)+n|0]=w}}while(0);if(!o){B=l;C=6337}break};case 1:{B=t;C=6337;break};case 2:{D=t;C=6349;break};case 3:{E=t;C=6361;break};case 4:{F=t;C=6373;break};case 5:{G=t;C=6385;break};case 6:{H=t;C=6397;break};case 7:{C=6409;break};default:{}}if((C|0)==6337){C=0;w=n+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+w|0]|0)){u=a[s+1|0]|0;if(u<<24>>24==0){break}y=b[(c[277225]|0)+((u&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){I=b[(c[277221]|0)+(((y&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{u=c[277228]&65535;p=y&-2048;x=u&-2048;J=(p&65535)>(x&65535)?p-x&65535:0;x=y&2016;p=u&2016;if((x&65535)>(p&65535)){K=(x-p&65535)+J&65535}else{K=J}J=y&31;p=u&31;if((J&65535)<=(p&65535)){I=K;break}I=(J-p&65535)+K&65535}}while(0);b[(c[277218]|0)+(w<<1)>>1]=I;if((a[1108928]|0)==0){L=b[(c[277221]|0)+(((e[(c[277213]|0)+(n+4<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{L=0}y=n+3|0;b[(c[277218]|0)+(y<<1)>>1]=L;p=a[1108909]|0;a[(c[277219]|0)+y|0]=p;a[(c[277219]|0)+w|0]=p}}while(0);w=B-1&255;if(w<<24>>24!=0){D=w;C=6349}}if((C|0)==6349){C=0;w=n+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+w|0]|0)){p=a[s+2|0]|0;if(p<<24>>24==0){break}y=b[(c[277225]|0)+((p&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){M=b[(c[277221]|0)+(((y&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{p=c[277228]&65535;J=y&-2048;u=p&-2048;x=(J&65535)>(u&65535)?J-u&65535:0;u=y&2016;J=p&2016;if((u&65535)>(J&65535)){N=(u-J&65535)+x&65535}else{N=x}x=y&31;J=p&31;if((x&65535)<=(J&65535)){M=N;break}M=(x-J&65535)+N&65535}}while(0);b[(c[277218]|0)+(w<<1)>>1]=M;if((a[1108928]|0)==0){O=b[(c[277221]|0)+(((e[(c[277213]|0)+(n+6<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{O=0}y=n+5|0;b[(c[277218]|0)+(y<<1)>>1]=O;J=a[1108909]|0;a[(c[277219]|0)+y|0]=J;a[(c[277219]|0)+w|0]=J}}while(0);w=D-1&255;if(w<<24>>24!=0){E=w;C=6361}}if((C|0)==6361){C=0;w=n+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+w|0]|0)){J=a[s+3|0]|0;if(J<<24>>24==0){break}y=b[(c[277225]|0)+((J&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){P=b[(c[277221]|0)+(((y&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{J=c[277228]&65535;x=y&-2048;p=J&-2048;u=(x&65535)>(p&65535)?x-p&65535:0;p=y&2016;x=J&2016;if((p&65535)>(x&65535)){Q=(p-x&65535)+u&65535}else{Q=u}u=y&31;x=J&31;if((u&65535)<=(x&65535)){P=Q;break}P=(u-x&65535)+Q&65535}}while(0);b[(c[277218]|0)+(w<<1)>>1]=P;if((a[1108928]|0)==0){R=b[(c[277221]|0)+(((e[(c[277213]|0)+(n+8<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{R=0}y=n+7|0;b[(c[277218]|0)+(y<<1)>>1]=R;x=a[1108909]|0;a[(c[277219]|0)+y|0]=x;a[(c[277219]|0)+w|0]=x}}while(0);w=E-1&255;if(w<<24>>24!=0){F=w;C=6373}}if((C|0)==6373){C=0;w=n+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+w|0]|0)){x=a[s+4|0]|0;if(x<<24>>24==0){break}y=b[(c[277225]|0)+((x&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){S=b[(c[277221]|0)+(((y&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{x=c[277228]&65535;u=y&-2048;J=x&-2048;p=(u&65535)>(J&65535)?u-J&65535:0;J=y&2016;u=x&2016;if((J&65535)>(u&65535)){T=(J-u&65535)+p&65535}else{T=p}p=y&31;u=x&31;if((p&65535)<=(u&65535)){S=T;break}S=(p-u&65535)+T&65535}}while(0);b[(c[277218]|0)+(w<<1)>>1]=S;if((a[1108928]|0)==0){U=b[(c[277221]|0)+(((e[(c[277213]|0)+(n+10<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{U=0}y=n+9|0;b[(c[277218]|0)+(y<<1)>>1]=U;u=a[1108909]|0;a[(c[277219]|0)+y|0]=u;a[(c[277219]|0)+w|0]=u}}while(0);w=F-1&255;if(w<<24>>24!=0){G=w;C=6385}}if((C|0)==6385){C=0;w=n+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+w|0]|0)){u=a[s+5|0]|0;if(u<<24>>24==0){break}y=b[(c[277225]|0)+((u&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){V=b[(c[277221]|0)+(((y&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{u=c[277228]&65535;p=y&-2048;x=u&-2048;J=(p&65535)>(x&65535)?p-x&65535:0;x=y&2016;p=u&2016;if((x&65535)>(p&65535)){W=(x-p&65535)+J&65535}else{W=J}J=y&31;p=u&31;if((J&65535)<=(p&65535)){V=W;break}V=(J-p&65535)+W&65535}}while(0);b[(c[277218]|0)+(w<<1)>>1]=V;if((a[1108928]|0)==0){X=b[(c[277221]|0)+(((e[(c[277213]|0)+(n+12<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{X=0}y=n+11|0;b[(c[277218]|0)+(y<<1)>>1]=X;p=a[1108909]|0;a[(c[277219]|0)+y|0]=p;a[(c[277219]|0)+w|0]=p}}while(0);w=G-1&255;if(w<<24>>24!=0){H=w;C=6397}}if((C|0)==6397){C=0;w=n+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+w|0]|0)){p=a[s+6|0]|0;if(p<<24>>24==0){break}y=b[(c[277225]|0)+((p&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){Y=b[(c[277221]|0)+(((y&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{p=c[277228]&65535;J=y&-2048;u=p&-2048;x=(J&65535)>(u&65535)?J-u&65535:0;u=y&2016;J=p&2016;if((u&65535)>(J&65535)){Z=(u-J&65535)+x&65535}else{Z=x}x=y&31;J=p&31;if((x&65535)<=(J&65535)){Y=Z;break}Y=(x-J&65535)+Z&65535}}while(0);b[(c[277218]|0)+(w<<1)>>1]=Y;if((a[1108928]|0)==0){_=b[(c[277221]|0)+(((e[(c[277213]|0)+(n+14<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{_=0}y=n+13|0;b[(c[277218]|0)+(y<<1)>>1]=_;J=a[1108909]|0;a[(c[277219]|0)+y|0]=J;a[(c[277219]|0)+w|0]=J}}while(0);if(H<<24>>24!=1){C=6409}}do{if((C|0)==6409){C=0;w=n+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+w|0]|0)){break}J=a[s+7|0]|0;if(J<<24>>24==0){break}y=b[(c[277225]|0)+((J&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){$=b[(c[277221]|0)+(((y&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{J=c[277228]&65535;x=y&-2048;p=J&-2048;u=(x&65535)>(p&65535)?x-p&65535:0;p=y&2016;x=J&2016;if((p&65535)>(x&65535)){aa=(p-x&65535)+u&65535}else{aa=u}u=y&31;x=J&31;if((u&65535)<=(x&65535)){$=aa;break}$=(u-x&65535)+aa&65535}}while(0);b[(c[277218]|0)+(w<<1)>>1]=$;if((a[1108928]|0)==0){ab=b[(c[277221]|0)+(((e[(c[277213]|0)+(n+16<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{ab=0}y=n+15|0;b[(c[277218]|0)+(y<<1)>>1]=ab;x=a[1108909]|0;a[(c[277219]|0)+y|0]=x;a[(c[277219]|0)+w|0]=x}}while(0);x=q-1|0;if((x|0)>0){s=s+16|0;q=x;n=(c[277223]|0)+n|0}else{break}}return}n=(d[1394504]|0)+(j<<1)|0;if((f&32768|0)==0){if((k|0)<=0){return}f=i&255;j=f-1&255;q=j<<24>>24==0;s=r+n|0;ab=k;$=g;while(1){switch(h|0){case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+$|0]|0)){aa=a[s+7|0]|0;if(aa<<24>>24==0){break}H=b[(c[277225]|0)+((aa&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){ac=b[(c[277221]|0)+(((H&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{aa=c[277228]&65535;_=H&-2048;Y=aa&-2048;Z=(_&65535)>(Y&65535)?_-Y&65535:0;Y=H&2016;_=aa&2016;if((Y&65535)>(_&65535)){ad=(Y-_&65535)+Z&65535}else{ad=Z}Z=H&31;_=aa&31;if((Z&65535)<=(_&65535)){ac=ad;break}ac=(Z-_&65535)+ad&65535}}while(0);b[(c[277218]|0)+($<<1)>>1]=ac;if((a[1108928]|0)==0){ae=b[(c[277221]|0)+(((e[(c[277213]|0)+($+2<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{ae=0}H=$+1|0;b[(c[277218]|0)+(H<<1)>>1]=ae;w=a[1108909]|0;a[(c[277219]|0)+H|0]=w;a[(c[277219]|0)+$|0]=w}}while(0);if(!q){af=j;C=6437}break};case 1:{af=f;C=6437;break};case 2:{ag=f;C=6449;break};case 3:{ah=f;C=6461;break};case 5:{ai=f;C=6485;break};case 6:{aj=f;C=6497;break};case 4:{ak=f;C=6473;break};case 7:{C=6509;break};default:{}}if((C|0)==6437){C=0;w=$+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+w|0]|0)){H=a[s+6|0]|0;if(H<<24>>24==0){break}_=b[(c[277225]|0)+((H&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){al=b[(c[277221]|0)+(((_&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{H=c[277228]&65535;Z=_&-2048;aa=H&-2048;Y=(Z&65535)>(aa&65535)?Z-aa&65535:0;aa=_&2016;Z=H&2016;if((aa&65535)>(Z&65535)){am=(aa-Z&65535)+Y&65535}else{am=Y}Y=_&31;Z=H&31;if((Y&65535)<=(Z&65535)){al=am;break}al=(Y-Z&65535)+am&65535}}while(0);b[(c[277218]|0)+(w<<1)>>1]=al;if((a[1108928]|0)==0){an=b[(c[277221]|0)+(((e[(c[277213]|0)+($+4<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{an=0}_=$+3|0;b[(c[277218]|0)+(_<<1)>>1]=an;Z=a[1108909]|0;a[(c[277219]|0)+_|0]=Z;a[(c[277219]|0)+w|0]=Z}}while(0);w=af-1&255;if(w<<24>>24!=0){ag=w;C=6449}}if((C|0)==6449){C=0;w=$+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+w|0]|0)){Z=a[s+5|0]|0;if(Z<<24>>24==0){break}_=b[(c[277225]|0)+((Z&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){ao=b[(c[277221]|0)+(((_&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{Z=c[277228]&65535;Y=_&-2048;H=Z&-2048;aa=(Y&65535)>(H&65535)?Y-H&65535:0;H=_&2016;Y=Z&2016;if((H&65535)>(Y&65535)){ap=(H-Y&65535)+aa&65535}else{ap=aa}aa=_&31;Y=Z&31;if((aa&65535)<=(Y&65535)){ao=ap;break}ao=(aa-Y&65535)+ap&65535}}while(0);b[(c[277218]|0)+(w<<1)>>1]=ao;if((a[1108928]|0)==0){aq=b[(c[277221]|0)+(((e[(c[277213]|0)+($+6<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{aq=0}_=$+5|0;b[(c[277218]|0)+(_<<1)>>1]=aq;Y=a[1108909]|0;a[(c[277219]|0)+_|0]=Y;a[(c[277219]|0)+w|0]=Y}}while(0);w=ag-1&255;if(w<<24>>24!=0){ah=w;C=6461}}if((C|0)==6461){C=0;w=$+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+w|0]|0)){Y=a[s+4|0]|0;if(Y<<24>>24==0){break}_=b[(c[277225]|0)+((Y&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){ar=b[(c[277221]|0)+(((_&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{Y=c[277228]&65535;aa=_&-2048;Z=Y&-2048;H=(aa&65535)>(Z&65535)?aa-Z&65535:0;Z=_&2016;aa=Y&2016;if((Z&65535)>(aa&65535)){as=(Z-aa&65535)+H&65535}else{as=H}H=_&31;aa=Y&31;if((H&65535)<=(aa&65535)){ar=as;break}ar=(H-aa&65535)+as&65535}}while(0);b[(c[277218]|0)+(w<<1)>>1]=ar;if((a[1108928]|0)==0){at=b[(c[277221]|0)+(((e[(c[277213]|0)+($+8<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{at=0}_=$+7|0;b[(c[277218]|0)+(_<<1)>>1]=at;aa=a[1108909]|0;a[(c[277219]|0)+_|0]=aa;a[(c[277219]|0)+w|0]=aa}}while(0);w=ah-1&255;if(w<<24>>24!=0){ak=w;C=6473}}if((C|0)==6473){C=0;w=$+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+w|0]|0)){aa=a[s+3|0]|0;if(aa<<24>>24==0){break}_=b[(c[277225]|0)+((aa&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){au=b[(c[277221]|0)+(((_&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{aa=c[277228]&65535;H=_&-2048;Y=aa&-2048;Z=(H&65535)>(Y&65535)?H-Y&65535:0;Y=_&2016;H=aa&2016;if((Y&65535)>(H&65535)){av=(Y-H&65535)+Z&65535}else{av=Z}Z=_&31;H=aa&31;if((Z&65535)<=(H&65535)){au=av;break}au=(Z-H&65535)+av&65535}}while(0);b[(c[277218]|0)+(w<<1)>>1]=au;if((a[1108928]|0)==0){aw=b[(c[277221]|0)+(((e[(c[277213]|0)+($+10<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{aw=0}_=$+9|0;b[(c[277218]|0)+(_<<1)>>1]=aw;H=a[1108909]|0;a[(c[277219]|0)+_|0]=H;a[(c[277219]|0)+w|0]=H}}while(0);w=ak-1&255;if(w<<24>>24!=0){ai=w;C=6485}}if((C|0)==6485){C=0;w=$+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+w|0]|0)){H=a[s+2|0]|0;if(H<<24>>24==0){break}_=b[(c[277225]|0)+((H&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){ax=b[(c[277221]|0)+(((_&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{H=c[277228]&65535;Z=_&-2048;aa=H&-2048;Y=(Z&65535)>(aa&65535)?Z-aa&65535:0;aa=_&2016;Z=H&2016;if((aa&65535)>(Z&65535)){ay=(aa-Z&65535)+Y&65535}else{ay=Y}Y=_&31;Z=H&31;if((Y&65535)<=(Z&65535)){ax=ay;break}ax=(Y-Z&65535)+ay&65535}}while(0);b[(c[277218]|0)+(w<<1)>>1]=ax;if((a[1108928]|0)==0){az=b[(c[277221]|0)+(((e[(c[277213]|0)+($+12<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{az=0}_=$+11|0;b[(c[277218]|0)+(_<<1)>>1]=az;Z=a[1108909]|0;a[(c[277219]|0)+_|0]=Z;a[(c[277219]|0)+w|0]=Z}}while(0);w=ai-1&255;if(w<<24>>24!=0){aj=w;C=6497}}if((C|0)==6497){C=0;w=$+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+w|0]|0)){Z=a[s+1|0]|0;if(Z<<24>>24==0){break}_=b[(c[277225]|0)+((Z&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aA=b[(c[277221]|0)+(((_&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{Z=c[277228]&65535;Y=_&-2048;H=Z&-2048;aa=(Y&65535)>(H&65535)?Y-H&65535:0;H=_&2016;Y=Z&2016;if((H&65535)>(Y&65535)){aB=(H-Y&65535)+aa&65535}else{aB=aa}aa=_&31;Y=Z&31;if((aa&65535)<=(Y&65535)){aA=aB;break}aA=(aa-Y&65535)+aB&65535}}while(0);b[(c[277218]|0)+(w<<1)>>1]=aA;if((a[1108928]|0)==0){aC=b[(c[277221]|0)+(((e[(c[277213]|0)+($+14<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{aC=0}_=$+13|0;b[(c[277218]|0)+(_<<1)>>1]=aC;Y=a[1108909]|0;a[(c[277219]|0)+_|0]=Y;a[(c[277219]|0)+w|0]=Y}}while(0);if(aj<<24>>24!=1){C=6509}}do{if((C|0)==6509){C=0;w=$+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+w|0]|0)){break}Y=a[s]|0;if(Y<<24>>24==0){break}_=b[(c[277225]|0)+((Y&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aD=b[(c[277221]|0)+(((_&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{Y=c[277228]&65535;aa=_&-2048;Z=Y&-2048;H=(aa&65535)>(Z&65535)?aa-Z&65535:0;Z=_&2016;aa=Y&2016;if((Z&65535)>(aa&65535)){aE=(Z-aa&65535)+H&65535}else{aE=H}H=_&31;aa=Y&31;if((H&65535)<=(aa&65535)){aD=aE;break}aD=(H-aa&65535)+aE&65535}}while(0);b[(c[277218]|0)+(w<<1)>>1]=aD;if((a[1108928]|0)==0){aF=b[(c[277221]|0)+(((e[(c[277213]|0)+($+16<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{aF=0}_=$+15|0;b[(c[277218]|0)+(_<<1)>>1]=aF;aa=a[1108909]|0;a[(c[277219]|0)+_|0]=aa;a[(c[277219]|0)+w|0]=aa}}while(0);aa=ab-1|0;if((aa|0)>0){s=s+16|0;ab=aa;$=(c[277223]|0)+$|0}else{break}}return}$=r+(56-n)|0;n=(k|0)>0;if(m){if(!n){return}m=i&255;r=m-1&255;ab=r<<24>>24==0;s=$;aF=k;aD=g;while(1){switch(h|0){case 6:{aG=m;C=6696;break};case 7:{C=6708;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+aD|0]|0)){aE=a[s+7|0]|0;if(aE<<24>>24==0){break}aj=b[(c[277225]|0)+((aE&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aH=b[(c[277221]|0)+(((aj&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{aE=c[277228]&65535;aC=aj&-2048;aA=aE&-2048;aB=(aC&65535)>(aA&65535)?aC-aA&65535:0;aA=aj&2016;aC=aE&2016;if((aA&65535)>(aC&65535)){aI=(aA-aC&65535)+aB&65535}else{aI=aB}aB=aj&31;aC=aE&31;if((aB&65535)<=(aC&65535)){aH=aI;break}aH=(aB-aC&65535)+aI&65535}}while(0);b[(c[277218]|0)+(aD<<1)>>1]=aH;if((a[1108928]|0)==0){aJ=b[(c[277221]|0)+(((e[(c[277213]|0)+(aD+2<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{aJ=0}aj=aD+1|0;b[(c[277218]|0)+(aj<<1)>>1]=aJ;w=a[1108909]|0;a[(c[277219]|0)+aj|0]=w;a[(c[277219]|0)+aD|0]=w}}while(0);if(!ab){aK=r;C=6636}break};case 2:{aL=m;C=6648;break};case 3:{aM=m;C=6660;break};case 4:{aN=m;C=6672;break};case 1:{aK=m;C=6636;break};case 5:{aO=m;C=6684;break};default:{}}if((C|0)==6636){C=0;w=aD+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+w|0]|0)){aj=a[s+6|0]|0;if(aj<<24>>24==0){break}aC=b[(c[277225]|0)+((aj&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aP=b[(c[277221]|0)+(((aC&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{aj=c[277228]&65535;aB=aC&-2048;aE=aj&-2048;aA=(aB&65535)>(aE&65535)?aB-aE&65535:0;aE=aC&2016;aB=aj&2016;if((aE&65535)>(aB&65535)){aQ=(aE-aB&65535)+aA&65535}else{aQ=aA}aA=aC&31;aB=aj&31;if((aA&65535)<=(aB&65535)){aP=aQ;break}aP=(aA-aB&65535)+aQ&65535}}while(0);b[(c[277218]|0)+(w<<1)>>1]=aP;if((a[1108928]|0)==0){aR=b[(c[277221]|0)+(((e[(c[277213]|0)+(aD+4<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{aR=0}aC=aD+3|0;b[(c[277218]|0)+(aC<<1)>>1]=aR;aB=a[1108909]|0;a[(c[277219]|0)+aC|0]=aB;a[(c[277219]|0)+w|0]=aB}}while(0);w=aK-1&255;if(w<<24>>24!=0){aL=w;C=6648}}if((C|0)==6648){C=0;w=aD+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+w|0]|0)){aB=a[s+5|0]|0;if(aB<<24>>24==0){break}aC=b[(c[277225]|0)+((aB&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aS=b[(c[277221]|0)+(((aC&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{aB=c[277228]&65535;aA=aC&-2048;aj=aB&-2048;aE=(aA&65535)>(aj&65535)?aA-aj&65535:0;aj=aC&2016;aA=aB&2016;if((aj&65535)>(aA&65535)){aT=(aj-aA&65535)+aE&65535}else{aT=aE}aE=aC&31;aA=aB&31;if((aE&65535)<=(aA&65535)){aS=aT;break}aS=(aE-aA&65535)+aT&65535}}while(0);b[(c[277218]|0)+(w<<1)>>1]=aS;if((a[1108928]|0)==0){aU=b[(c[277221]|0)+(((e[(c[277213]|0)+(aD+6<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{aU=0}aC=aD+5|0;b[(c[277218]|0)+(aC<<1)>>1]=aU;aA=a[1108909]|0;a[(c[277219]|0)+aC|0]=aA;a[(c[277219]|0)+w|0]=aA}}while(0);w=aL-1&255;if(w<<24>>24!=0){aM=w;C=6660}}if((C|0)==6660){C=0;w=aD+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+w|0]|0)){aA=a[s+4|0]|0;if(aA<<24>>24==0){break}aC=b[(c[277225]|0)+((aA&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aV=b[(c[277221]|0)+(((aC&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{aA=c[277228]&65535;aE=aC&-2048;aB=aA&-2048;aj=(aE&65535)>(aB&65535)?aE-aB&65535:0;aB=aC&2016;aE=aA&2016;if((aB&65535)>(aE&65535)){aW=(aB-aE&65535)+aj&65535}else{aW=aj}aj=aC&31;aE=aA&31;if((aj&65535)<=(aE&65535)){aV=aW;break}aV=(aj-aE&65535)+aW&65535}}while(0);b[(c[277218]|0)+(w<<1)>>1]=aV;if((a[1108928]|0)==0){aX=b[(c[277221]|0)+(((e[(c[277213]|0)+(aD+8<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{aX=0}aC=aD+7|0;b[(c[277218]|0)+(aC<<1)>>1]=aX;aE=a[1108909]|0;a[(c[277219]|0)+aC|0]=aE;a[(c[277219]|0)+w|0]=aE}}while(0);w=aM-1&255;if(w<<24>>24!=0){aN=w;C=6672}}if((C|0)==6672){C=0;w=aD+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+w|0]|0)){aE=a[s+3|0]|0;if(aE<<24>>24==0){break}aC=b[(c[277225]|0)+((aE&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){aY=b[(c[277221]|0)+(((aC&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{aE=c[277228]&65535;aj=aC&-2048;aA=aE&-2048;aB=(aj&65535)>(aA&65535)?aj-aA&65535:0;aA=aC&2016;aj=aE&2016;if((aA&65535)>(aj&65535)){aZ=(aA-aj&65535)+aB&65535}else{aZ=aB}aB=aC&31;aj=aE&31;if((aB&65535)<=(aj&65535)){aY=aZ;break}aY=(aB-aj&65535)+aZ&65535}}while(0);b[(c[277218]|0)+(w<<1)>>1]=aY;if((a[1108928]|0)==0){a_=b[(c[277221]|0)+(((e[(c[277213]|0)+(aD+10<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{a_=0}aC=aD+9|0;b[(c[277218]|0)+(aC<<1)>>1]=a_;aj=a[1108909]|0;a[(c[277219]|0)+aC|0]=aj;a[(c[277219]|0)+w|0]=aj}}while(0);w=aN-1&255;if(w<<24>>24!=0){aO=w;C=6684}}if((C|0)==6684){C=0;w=aD+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+w|0]|0)){aj=a[s+2|0]|0;if(aj<<24>>24==0){break}aC=b[(c[277225]|0)+((aj&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){a$=b[(c[277221]|0)+(((aC&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{aj=c[277228]&65535;aB=aC&-2048;aE=aj&-2048;aA=(aB&65535)>(aE&65535)?aB-aE&65535:0;aE=aC&2016;aB=aj&2016;if((aE&65535)>(aB&65535)){a0=(aE-aB&65535)+aA&65535}else{a0=aA}aA=aC&31;aB=aj&31;if((aA&65535)<=(aB&65535)){a$=a0;break}a$=(aA-aB&65535)+a0&65535}}while(0);b[(c[277218]|0)+(w<<1)>>1]=a$;if((a[1108928]|0)==0){a1=b[(c[277221]|0)+(((e[(c[277213]|0)+(aD+12<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{a1=0}aC=aD+11|0;b[(c[277218]|0)+(aC<<1)>>1]=a1;aB=a[1108909]|0;a[(c[277219]|0)+aC|0]=aB;a[(c[277219]|0)+w|0]=aB}}while(0);w=aO-1&255;if(w<<24>>24!=0){aG=w;C=6696}}if((C|0)==6696){C=0;w=aD+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+w|0]|0)){aB=a[s+1|0]|0;if(aB<<24>>24==0){break}aC=b[(c[277225]|0)+((aB&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){a2=b[(c[277221]|0)+(((aC&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{aB=c[277228]&65535;aA=aC&-2048;aj=aB&-2048;aE=(aA&65535)>(aj&65535)?aA-aj&65535:0;aj=aC&2016;aA=aB&2016;if((aj&65535)>(aA&65535)){a3=(aj-aA&65535)+aE&65535}else{a3=aE}aE=aC&31;aA=aB&31;if((aE&65535)<=(aA&65535)){a2=a3;break}a2=(aE-aA&65535)+a3&65535}}while(0);b[(c[277218]|0)+(w<<1)>>1]=a2;if((a[1108928]|0)==0){a4=b[(c[277221]|0)+(((e[(c[277213]|0)+(aD+14<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{a4=0}aC=aD+13|0;b[(c[277218]|0)+(aC<<1)>>1]=a4;aA=a[1108909]|0;a[(c[277219]|0)+aC|0]=aA;a[(c[277219]|0)+w|0]=aA}}while(0);if(aG<<24>>24!=1){C=6708}}do{if((C|0)==6708){C=0;w=aD+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+w|0]|0)){break}aA=a[s]|0;if(aA<<24>>24==0){break}aC=b[(c[277225]|0)+((aA&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){a5=b[(c[277221]|0)+(((aC&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{aA=c[277228]&65535;aE=aC&-2048;aB=aA&-2048;aj=(aE&65535)>(aB&65535)?aE-aB&65535:0;aB=aC&2016;aE=aA&2016;if((aB&65535)>(aE&65535)){a6=(aB-aE&65535)+aj&65535}else{a6=aj}aj=aC&31;aE=aA&31;if((aj&65535)<=(aE&65535)){a5=a6;break}a5=(aj-aE&65535)+a6&65535}}while(0);b[(c[277218]|0)+(w<<1)>>1]=a5;if((a[1108928]|0)==0){a7=b[(c[277221]|0)+(((e[(c[277213]|0)+(aD+16<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{a7=0}aC=aD+15|0;b[(c[277218]|0)+(aC<<1)>>1]=a7;aE=a[1108909]|0;a[(c[277219]|0)+aC|0]=aE;a[(c[277219]|0)+w|0]=aE}}while(0);aE=aF-1|0;if((aE|0)>0){s=s-16|0;aF=aE;aD=(c[277223]|0)+aD|0}else{break}}return}else{if(!n){return}n=i&255;i=n-1&255;aD=i<<24>>24==0;aF=$;$=k;k=g;while(1){switch(h|0){case 1:{a8=n;C=6539;break};case 3:{a9=n;C=6563;break};case 7:{C=6611;break};case 4:{ba=n;C=6575;break};case 2:{bb=n;C=6551;break};case 5:{bc=n;C=6587;break};case 6:{bd=n;C=6599;break};case 0:{do{if((d[1108908]|0)>(d[(c[277219]|0)+k|0]|0)){g=a[aF]|0;if(g<<24>>24==0){break}s=b[(c[277225]|0)+((g&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){be=b[(c[277221]|0)+(((s&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{g=c[277228]&65535;a7=s&-2048;a5=g&-2048;a6=(a7&65535)>(a5&65535)?a7-a5&65535:0;a5=s&2016;a7=g&2016;if((a5&65535)>(a7&65535)){bf=(a5-a7&65535)+a6&65535}else{bf=a6}a6=s&31;a7=g&31;if((a6&65535)<=(a7&65535)){be=bf;break}be=(a6-a7&65535)+bf&65535}}while(0);b[(c[277218]|0)+(k<<1)>>1]=be;if((a[1108928]|0)==0){bg=b[(c[277221]|0)+(((e[(c[277213]|0)+(k+2<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{bg=0}s=k+1|0;b[(c[277218]|0)+(s<<1)>>1]=bg;w=a[1108909]|0;a[(c[277219]|0)+s|0]=w;a[(c[277219]|0)+k|0]=w}}while(0);if(!aD){a8=i;C=6539}break};default:{}}if((C|0)==6539){C=0;w=k+2|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+w|0]|0)){s=a[aF+1|0]|0;if(s<<24>>24==0){break}a7=b[(c[277225]|0)+((s&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){bh=b[(c[277221]|0)+(((a7&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{s=c[277228]&65535;a6=a7&-2048;g=s&-2048;a5=(a6&65535)>(g&65535)?a6-g&65535:0;g=a7&2016;a6=s&2016;if((g&65535)>(a6&65535)){bi=(g-a6&65535)+a5&65535}else{bi=a5}a5=a7&31;a6=s&31;if((a5&65535)<=(a6&65535)){bh=bi;break}bh=(a5-a6&65535)+bi&65535}}while(0);b[(c[277218]|0)+(w<<1)>>1]=bh;if((a[1108928]|0)==0){bj=b[(c[277221]|0)+(((e[(c[277213]|0)+(k+4<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{bj=0}a7=k+3|0;b[(c[277218]|0)+(a7<<1)>>1]=bj;a6=a[1108909]|0;a[(c[277219]|0)+a7|0]=a6;a[(c[277219]|0)+w|0]=a6}}while(0);w=a8-1&255;if(w<<24>>24!=0){bb=w;C=6551}}if((C|0)==6551){C=0;w=k+4|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+w|0]|0)){a6=a[aF+2|0]|0;if(a6<<24>>24==0){break}a7=b[(c[277225]|0)+((a6&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){bk=b[(c[277221]|0)+(((a7&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{a6=c[277228]&65535;a5=a7&-2048;s=a6&-2048;g=(a5&65535)>(s&65535)?a5-s&65535:0;s=a7&2016;a5=a6&2016;if((s&65535)>(a5&65535)){bl=(s-a5&65535)+g&65535}else{bl=g}g=a7&31;a5=a6&31;if((g&65535)<=(a5&65535)){bk=bl;break}bk=(g-a5&65535)+bl&65535}}while(0);b[(c[277218]|0)+(w<<1)>>1]=bk;if((a[1108928]|0)==0){bm=b[(c[277221]|0)+(((e[(c[277213]|0)+(k+6<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{bm=0}a7=k+5|0;b[(c[277218]|0)+(a7<<1)>>1]=bm;a5=a[1108909]|0;a[(c[277219]|0)+a7|0]=a5;a[(c[277219]|0)+w|0]=a5}}while(0);w=bb-1&255;if(w<<24>>24!=0){a9=w;C=6563}}if((C|0)==6563){C=0;w=k+6|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+w|0]|0)){a5=a[aF+3|0]|0;if(a5<<24>>24==0){break}a7=b[(c[277225]|0)+((a5&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){bn=b[(c[277221]|0)+(((a7&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{a5=c[277228]&65535;g=a7&-2048;a6=a5&-2048;s=(g&65535)>(a6&65535)?g-a6&65535:0;a6=a7&2016;g=a5&2016;if((a6&65535)>(g&65535)){bo=(a6-g&65535)+s&65535}else{bo=s}s=a7&31;g=a5&31;if((s&65535)<=(g&65535)){bn=bo;break}bn=(s-g&65535)+bo&65535}}while(0);b[(c[277218]|0)+(w<<1)>>1]=bn;if((a[1108928]|0)==0){bp=b[(c[277221]|0)+(((e[(c[277213]|0)+(k+8<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{bp=0}a7=k+7|0;b[(c[277218]|0)+(a7<<1)>>1]=bp;g=a[1108909]|0;a[(c[277219]|0)+a7|0]=g;a[(c[277219]|0)+w|0]=g}}while(0);w=a9-1&255;if(w<<24>>24!=0){ba=w;C=6575}}if((C|0)==6575){C=0;w=k+8|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+w|0]|0)){g=a[aF+4|0]|0;if(g<<24>>24==0){break}a7=b[(c[277225]|0)+((g&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){bq=b[(c[277221]|0)+(((a7&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{g=c[277228]&65535;s=a7&-2048;a5=g&-2048;a6=(s&65535)>(a5&65535)?s-a5&65535:0;a5=a7&2016;s=g&2016;if((a5&65535)>(s&65535)){br=(a5-s&65535)+a6&65535}else{br=a6}a6=a7&31;s=g&31;if((a6&65535)<=(s&65535)){bq=br;break}bq=(a6-s&65535)+br&65535}}while(0);b[(c[277218]|0)+(w<<1)>>1]=bq;if((a[1108928]|0)==0){bs=b[(c[277221]|0)+(((e[(c[277213]|0)+(k+10<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{bs=0}a7=k+9|0;b[(c[277218]|0)+(a7<<1)>>1]=bs;s=a[1108909]|0;a[(c[277219]|0)+a7|0]=s;a[(c[277219]|0)+w|0]=s}}while(0);w=ba-1&255;if(w<<24>>24!=0){bc=w;C=6587}}if((C|0)==6587){C=0;w=k+10|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+w|0]|0)){s=a[aF+5|0]|0;if(s<<24>>24==0){break}a7=b[(c[277225]|0)+((s&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){bt=b[(c[277221]|0)+(((a7&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{s=c[277228]&65535;a6=a7&-2048;g=s&-2048;a5=(a6&65535)>(g&65535)?a6-g&65535:0;g=a7&2016;a6=s&2016;if((g&65535)>(a6&65535)){bu=(g-a6&65535)+a5&65535}else{bu=a5}a5=a7&31;a6=s&31;if((a5&65535)<=(a6&65535)){bt=bu;break}bt=(a5-a6&65535)+bu&65535}}while(0);b[(c[277218]|0)+(w<<1)>>1]=bt;if((a[1108928]|0)==0){bv=b[(c[277221]|0)+(((e[(c[277213]|0)+(k+12<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{bv=0}a7=k+11|0;b[(c[277218]|0)+(a7<<1)>>1]=bv;a6=a[1108909]|0;a[(c[277219]|0)+a7|0]=a6;a[(c[277219]|0)+w|0]=a6}}while(0);w=bc-1&255;if(w<<24>>24!=0){bd=w;C=6599}}if((C|0)==6599){C=0;w=k+12|0;do{if((d[1108908]|0)>(d[(c[277219]|0)+w|0]|0)){a6=a[aF+6|0]|0;if(a6<<24>>24==0){break}a7=b[(c[277225]|0)+((a6&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){bw=b[(c[277221]|0)+(((a7&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{a6=c[277228]&65535;a5=a7&-2048;s=a6&-2048;g=(a5&65535)>(s&65535)?a5-s&65535:0;s=a7&2016;a5=a6&2016;if((s&65535)>(a5&65535)){bx=(s-a5&65535)+g&65535}else{bx=g}g=a7&31;a5=a6&31;if((g&65535)<=(a5&65535)){bw=bx;break}bw=(g-a5&65535)+bx&65535}}while(0);b[(c[277218]|0)+(w<<1)>>1]=bw;if((a[1108928]|0)==0){by=b[(c[277221]|0)+(((e[(c[277213]|0)+(k+14<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{by=0}a7=k+13|0;b[(c[277218]|0)+(a7<<1)>>1]=by;a5=a[1108909]|0;a[(c[277219]|0)+a7|0]=a5;a[(c[277219]|0)+w|0]=a5}}while(0);if(bd<<24>>24!=1){C=6611}}do{if((C|0)==6611){C=0;w=k+14|0;if((d[1108908]|0)<=(d[(c[277219]|0)+w|0]|0)){break}a5=a[aF+7|0]|0;if(a5<<24>>24==0){break}a7=b[(c[277225]|0)+((a5&255)<<1)>>1]|0;do{if((a[1108928]|0)==0){bz=b[(c[277221]|0)+(((a7&65535|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{a5=c[277228]&65535;g=a7&-2048;a6=a5&-2048;s=(g&65535)>(a6&65535)?g-a6&65535:0;a6=a7&2016;g=a5&2016;if((a6&65535)>(g&65535)){bA=(a6-g&65535)+s&65535}else{bA=s}s=a7&31;g=a5&31;if((s&65535)<=(g&65535)){bz=bA;break}bz=(s-g&65535)+bA&65535}}while(0);b[(c[277218]|0)+(w<<1)>>1]=bz;if((a[1108928]|0)==0){bB=b[(c[277221]|0)+(((e[(c[277213]|0)+(k+16<<1)>>1]|67616)-(c[277228]&-2082)|0)>>>1<<1)>>1]|0}else{bB=0}a7=k+15|0;b[(c[277218]|0)+(a7<<1)>>1]=bB;g=a[1108909]|0;a[(c[277219]|0)+a7|0]=g;a[(c[277219]|0)+w|0]=g}}while(0);g=$-1|0;if((g|0)>0){aF=aF-16|0;$=g;k=(c[277223]|0)+k|0}else{break}}return}}
function Xx(e,f,g,h){e=e|0;f=f|0;g=g|0;h=h|0;var i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,cd=0,ce=0,cf=0,cg=0,ch=0,ci=0,cj=0,ck=0,cl=0,cm=0,cn=0,co=0,cp=0,cq=0,cr=0,cs=0,ct=0,cu=0,cv=0,cw=0,cx=0,cy=0,cz=0,cA=0,cB=0,cC=0;i=e&1023;j=c[348606]|0;k=(i<<j)+(c[348604]|0)|0;if((e&256|0)==0){l=k}else{l=(c[348602]|0)+k|0}k=l&65535;l=k>>>(j>>>0);j=(e&16384|0)!=0;m=l<<6;do{if(j){n=(c[348622]|0)+m|0;if((a[(c[348618]|0)+l|0]|0)!=0){o=n;break}p=fi[c[348636]&63](n,k,i)|0;a[(c[348618]|0)+l|0]=p;o=n}else{n=(c[348624]|0)+m|0;if((a[(c[348620]|0)+l|0]|0)!=0){o=n;break}p=fi[c[348638]&63](n,k,i)|0;a[(c[348620]|0)+l|0]=p;o=n}}while(0);if((a[(c[348620]|0)+l|0]|0)==2){return}if((a[1394464]|0)==0){q=1106168+((e>>>((c[348632]|0)>>>0)&c[348630])+(c[348634]|0)<<1)|0}else{if((a[1106089]|0)!=0){l=d[1044485]|0;c[276541]=7080+(l<<5);i=0;do{k=i<<1&2;m=i&2;n=i&4;p=0;do{b[1125528+(i<<9)+(p<<1)>>1]=d[(p>>>1&28|m)+(7080+(l<<5))|0]<<6|d[(p<<2&28|k)+(7080+(l<<5))|0]<<11|d[(p>>>3&24|n)+(7080+(l<<5))|0];p=p+1|0;}while(p>>>0<256);i=i+1|0;}while(i>>>0<8);a[1106089]=0}q=1125528+((e>>>10&7)<<9)|0}c[277226]=q;c[277225]=(a[1108928]|0)!=0?1393712:q;if((e&49152|0)==0){if((h|0)<=0){return}q=o+g|0;i=h;l=f;while(1){p=a[1108908]|0;n=c[277219]|0;do{if((p&255)>(d[n+l|0]|0)){k=a[q]|0;m=k&255;if(k<<24>>24==0){r=p;s=n;break}do{if((a[1108928]|0)==0){k=b[(c[277225]|0)+(m<<1)>>1]|0;if((a[(c[277215]|0)+l|0]&32)!=0){t=b[(c[277221]|0)+((k&65535|67616)-(b[(c[277213]|0)+(l<<1)>>1]&63454)>>1<<1)>>1]|0;break}u=c[277228]&65535;v=k&-2048;w=u&-2048;x=(v&65535)>(w&65535)?v-w&65535:0;w=k&2016;v=u&2016;if((w&65535)>(v&65535)){y=(w-v&65535)+x&65535}else{y=x}x=k&31;k=u&31;if((x&65535)<=(k&65535)){t=y;break}t=(x-k&65535)+y&65535}else{k=b[(c[277225]|0)+(m<<1)>>1]|0;if((a[(c[277215]|0)+l|0]&32)==0){z=c[277228]&65535}else{z=b[(c[277213]|0)+(l<<1)>>1]|0}x=k&-2048;u=z&-2048;v=(x&65535)>(u&65535)?x-u&65535:0;u=k&2016;x=z&2016;if((u&65535)>(x&65535)){A=(u-x&65535)+v&65535}else{A=v}v=k&31;k=z&31;if((v&65535)<=(k&65535)){t=A;break}t=(v-k&65535)+A&65535}}while(0);b[(c[277218]|0)+(l<<1)>>1]=t;a[(c[277219]|0)+l|0]=a[1108909]|0;r=a[1108908]|0;s=c[277219]|0}else{r=p;s=n}}while(0);n=l+1|0;do{if((r&255)>(d[s+n|0]|0)){p=a[q+1|0]|0;m=p&255;if(p<<24>>24==0){B=r;C=s;break}do{if((a[1108928]|0)==0){p=b[(c[277225]|0)+(m<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)!=0){D=b[(c[277221]|0)+((p&65535|67616)-(b[(c[277213]|0)+(n<<1)>>1]&63454)>>1<<1)>>1]|0;break}k=c[277228]&65535;v=p&-2048;x=k&-2048;u=(v&65535)>(x&65535)?v-x&65535:0;x=p&2016;v=k&2016;if((x&65535)>(v&65535)){E=(x-v&65535)+u&65535}else{E=u}u=p&31;p=k&31;if((u&65535)<=(p&65535)){D=E;break}D=(u-p&65535)+E&65535}else{p=b[(c[277225]|0)+(m<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)==0){F=c[277228]&65535}else{F=b[(c[277213]|0)+(n<<1)>>1]|0}u=p&-2048;k=F&-2048;v=(u&65535)>(k&65535)?u-k&65535:0;k=p&2016;u=F&2016;if((k&65535)>(u&65535)){G=(k-u&65535)+v&65535}else{G=v}v=p&31;p=F&31;if((v&65535)<=(p&65535)){D=G;break}D=(v-p&65535)+G&65535}}while(0);b[(c[277218]|0)+(n<<1)>>1]=D;a[(c[277219]|0)+n|0]=a[1108909]|0;B=a[1108908]|0;C=c[277219]|0}else{B=r;C=s}}while(0);n=l+2|0;do{if((B&255)>(d[C+n|0]|0)){m=a[q+2|0]|0;p=m&255;if(m<<24>>24==0){H=B;I=C;break}do{if((a[1108928]|0)==0){m=b[(c[277225]|0)+(p<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)!=0){J=b[(c[277221]|0)+((m&65535|67616)-(b[(c[277213]|0)+(n<<1)>>1]&63454)>>1<<1)>>1]|0;break}v=c[277228]&65535;u=m&-2048;k=v&-2048;x=(u&65535)>(k&65535)?u-k&65535:0;k=m&2016;u=v&2016;if((k&65535)>(u&65535)){K=(k-u&65535)+x&65535}else{K=x}x=m&31;m=v&31;if((x&65535)<=(m&65535)){J=K;break}J=(x-m&65535)+K&65535}else{m=b[(c[277225]|0)+(p<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)==0){L=c[277228]&65535}else{L=b[(c[277213]|0)+(n<<1)>>1]|0}x=m&-2048;v=L&-2048;u=(x&65535)>(v&65535)?x-v&65535:0;v=m&2016;x=L&2016;if((v&65535)>(x&65535)){M=(v-x&65535)+u&65535}else{M=u}u=m&31;m=L&31;if((u&65535)<=(m&65535)){J=M;break}J=(u-m&65535)+M&65535}}while(0);b[(c[277218]|0)+(n<<1)>>1]=J;a[(c[277219]|0)+n|0]=a[1108909]|0;H=a[1108908]|0;I=c[277219]|0}else{H=B;I=C}}while(0);n=l+3|0;do{if((H&255)>(d[I+n|0]|0)){p=a[q+3|0]|0;m=p&255;if(p<<24>>24==0){N=H;O=I;break}do{if((a[1108928]|0)==0){p=b[(c[277225]|0)+(m<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)!=0){P=b[(c[277221]|0)+((p&65535|67616)-(b[(c[277213]|0)+(n<<1)>>1]&63454)>>1<<1)>>1]|0;break}u=c[277228]&65535;x=p&-2048;v=u&-2048;k=(x&65535)>(v&65535)?x-v&65535:0;v=p&2016;x=u&2016;if((v&65535)>(x&65535)){Q=(v-x&65535)+k&65535}else{Q=k}k=p&31;p=u&31;if((k&65535)<=(p&65535)){P=Q;break}P=(k-p&65535)+Q&65535}else{p=b[(c[277225]|0)+(m<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)==0){R=c[277228]&65535}else{R=b[(c[277213]|0)+(n<<1)>>1]|0}k=p&-2048;u=R&-2048;x=(k&65535)>(u&65535)?k-u&65535:0;u=p&2016;k=R&2016;if((u&65535)>(k&65535)){S=(u-k&65535)+x&65535}else{S=x}x=p&31;p=R&31;if((x&65535)<=(p&65535)){P=S;break}P=(x-p&65535)+S&65535}}while(0);b[(c[277218]|0)+(n<<1)>>1]=P;a[(c[277219]|0)+n|0]=a[1108909]|0;N=a[1108908]|0;O=c[277219]|0}else{N=H;O=I}}while(0);n=l+4|0;do{if((N&255)>(d[O+n|0]|0)){m=a[q+4|0]|0;p=m&255;if(m<<24>>24==0){T=N;U=O;break}do{if((a[1108928]|0)==0){m=b[(c[277225]|0)+(p<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)!=0){V=b[(c[277221]|0)+((m&65535|67616)-(b[(c[277213]|0)+(n<<1)>>1]&63454)>>1<<1)>>1]|0;break}x=c[277228]&65535;k=m&-2048;u=x&-2048;v=(k&65535)>(u&65535)?k-u&65535:0;u=m&2016;k=x&2016;if((u&65535)>(k&65535)){W=(u-k&65535)+v&65535}else{W=v}v=m&31;m=x&31;if((v&65535)<=(m&65535)){V=W;break}V=(v-m&65535)+W&65535}else{m=b[(c[277225]|0)+(p<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)==0){X=c[277228]&65535}else{X=b[(c[277213]|0)+(n<<1)>>1]|0}v=m&-2048;x=X&-2048;k=(v&65535)>(x&65535)?v-x&65535:0;x=m&2016;v=X&2016;if((x&65535)>(v&65535)){Y=(x-v&65535)+k&65535}else{Y=k}k=m&31;m=X&31;if((k&65535)<=(m&65535)){V=Y;break}V=(k-m&65535)+Y&65535}}while(0);b[(c[277218]|0)+(n<<1)>>1]=V;a[(c[277219]|0)+n|0]=a[1108909]|0;T=a[1108908]|0;U=c[277219]|0}else{T=N;U=O}}while(0);n=l+5|0;do{if((T&255)>(d[U+n|0]|0)){p=a[q+5|0]|0;m=p&255;if(p<<24>>24==0){Z=T;_=U;break}do{if((a[1108928]|0)==0){p=b[(c[277225]|0)+(m<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)!=0){$=b[(c[277221]|0)+((p&65535|67616)-(b[(c[277213]|0)+(n<<1)>>1]&63454)>>1<<1)>>1]|0;break}k=c[277228]&65535;v=p&-2048;x=k&-2048;u=(v&65535)>(x&65535)?v-x&65535:0;x=p&2016;v=k&2016;if((x&65535)>(v&65535)){aa=(x-v&65535)+u&65535}else{aa=u}u=p&31;p=k&31;if((u&65535)<=(p&65535)){$=aa;break}$=(u-p&65535)+aa&65535}else{p=b[(c[277225]|0)+(m<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)==0){ab=c[277228]&65535}else{ab=b[(c[277213]|0)+(n<<1)>>1]|0}u=p&-2048;k=ab&-2048;v=(u&65535)>(k&65535)?u-k&65535:0;k=p&2016;u=ab&2016;if((k&65535)>(u&65535)){ac=(k-u&65535)+v&65535}else{ac=v}v=p&31;p=ab&31;if((v&65535)<=(p&65535)){$=ac;break}$=(v-p&65535)+ac&65535}}while(0);b[(c[277218]|0)+(n<<1)>>1]=$;a[(c[277219]|0)+n|0]=a[1108909]|0;Z=a[1108908]|0;_=c[277219]|0}else{Z=T;_=U}}while(0);n=l+6|0;do{if((Z&255)>(d[_+n|0]|0)){m=a[q+6|0]|0;p=m&255;if(m<<24>>24==0){ad=Z;ae=_;break}do{if((a[1108928]|0)==0){m=b[(c[277225]|0)+(p<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)!=0){af=b[(c[277221]|0)+((m&65535|67616)-(b[(c[277213]|0)+(n<<1)>>1]&63454)>>1<<1)>>1]|0;break}v=c[277228]&65535;u=m&-2048;k=v&-2048;x=(u&65535)>(k&65535)?u-k&65535:0;k=m&2016;u=v&2016;if((k&65535)>(u&65535)){ag=(k-u&65535)+x&65535}else{ag=x}x=m&31;m=v&31;if((x&65535)<=(m&65535)){af=ag;break}af=(x-m&65535)+ag&65535}else{m=b[(c[277225]|0)+(p<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)==0){ah=c[277228]&65535}else{ah=b[(c[277213]|0)+(n<<1)>>1]|0}x=m&-2048;v=ah&-2048;u=(x&65535)>(v&65535)?x-v&65535:0;v=m&2016;x=ah&2016;if((v&65535)>(x&65535)){ai=(v-x&65535)+u&65535}else{ai=u}u=m&31;m=ah&31;if((u&65535)<=(m&65535)){af=ai;break}af=(u-m&65535)+ai&65535}}while(0);b[(c[277218]|0)+(n<<1)>>1]=af;a[(c[277219]|0)+n|0]=a[1108909]|0;ad=a[1108908]|0;ae=c[277219]|0}else{ad=Z;ae=_}}while(0);n=l+7|0;do{if((ad&255)>(d[ae+n|0]|0)){p=a[q+7|0]|0;m=p&255;if(p<<24>>24==0){break}do{if((a[1108928]|0)==0){p=b[(c[277225]|0)+(m<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)!=0){aj=b[(c[277221]|0)+((p&65535|67616)-(b[(c[277213]|0)+(n<<1)>>1]&63454)>>1<<1)>>1]|0;break}u=c[277228]&65535;x=p&-2048;v=u&-2048;k=(x&65535)>(v&65535)?x-v&65535:0;v=p&2016;x=u&2016;if((v&65535)>(x&65535)){ak=(v-x&65535)+k&65535}else{ak=k}k=p&31;p=u&31;if((k&65535)<=(p&65535)){aj=ak;break}aj=(k-p&65535)+ak&65535}else{p=b[(c[277225]|0)+(m<<1)>>1]|0;if((a[(c[277215]|0)+n|0]&32)==0){al=c[277228]&65535}else{al=b[(c[277213]|0)+(n<<1)>>1]|0}k=p&-2048;u=al&-2048;x=(k&65535)>(u&65535)?k-u&65535:0;u=p&2016;k=al&2016;if((u&65535)>(k&65535)){am=(u-k&65535)+x&65535}else{am=x}x=p&31;p=al&31;if((x&65535)<=(p&65535)){aj=am;break}aj=(x-p&65535)+am&65535}}while(0);b[(c[277218]|0)+(n<<1)>>1]=aj;a[(c[277219]|0)+n|0]=a[1108909]|0}}while(0);n=i-1|0;if((n|0)<=0){break}q=q+8|0;i=n;l=(c[277223]|0)+l|0}return}if((e&32768|0)==0){if((h|0)<=0){return}e=o+g|0;l=h;i=f;while(1){q=a[1108908]|0;aj=c[277219]|0;do{if((q&255)>(d[aj+i|0]|0)){am=a[e+7|0]|0;al=am&255;if(am<<24>>24==0){an=q;ao=aj;break}do{if((a[1108928]|0)==0){am=b[(c[277225]|0)+(al<<1)>>1]|0;if((a[(c[277215]|0)+i|0]&32)!=0){ap=b[(c[277221]|0)+((am&65535|67616)-(b[(c[277213]|0)+(i<<1)>>1]&63454)>>1<<1)>>1]|0;break}ak=c[277228]&65535;ae=am&-2048;ad=ak&-2048;_=(ae&65535)>(ad&65535)?ae-ad&65535:0;ad=am&2016;ae=ak&2016;if((ad&65535)>(ae&65535)){aq=(ad-ae&65535)+_&65535}else{aq=_}_=am&31;am=ak&31;if((_&65535)<=(am&65535)){ap=aq;break}ap=(_-am&65535)+aq&65535}else{am=b[(c[277225]|0)+(al<<1)>>1]|0;if((a[(c[277215]|0)+i|0]&32)==0){ar=c[277228]&65535}else{ar=b[(c[277213]|0)+(i<<1)>>1]|0}_=am&-2048;ak=ar&-2048;ae=(_&65535)>(ak&65535)?_-ak&65535:0;ak=am&2016;_=ar&2016;if((ak&65535)>(_&65535)){as=(ak-_&65535)+ae&65535}else{as=ae}ae=am&31;am=ar&31;if((ae&65535)<=(am&65535)){ap=as;break}ap=(ae-am&65535)+as&65535}}while(0);b[(c[277218]|0)+(i<<1)>>1]=ap;a[(c[277219]|0)+i|0]=a[1108909]|0;an=a[1108908]|0;ao=c[277219]|0}else{an=q;ao=aj}}while(0);aj=i+1|0;do{if((an&255)>(d[ao+aj|0]|0)){q=a[e+6|0]|0;al=q&255;if(q<<24>>24==0){at=an;au=ao;break}do{if((a[1108928]|0)==0){q=b[(c[277225]|0)+(al<<1)>>1]|0;if((a[(c[277215]|0)+aj|0]&32)!=0){av=b[(c[277221]|0)+((q&65535|67616)-(b[(c[277213]|0)+(aj<<1)>>1]&63454)>>1<<1)>>1]|0;break}am=c[277228]&65535;ae=q&-2048;_=am&-2048;ak=(ae&65535)>(_&65535)?ae-_&65535:0;_=q&2016;ae=am&2016;if((_&65535)>(ae&65535)){aw=(_-ae&65535)+ak&65535}else{aw=ak}ak=q&31;q=am&31;if((ak&65535)<=(q&65535)){av=aw;break}av=(ak-q&65535)+aw&65535}else{q=b[(c[277225]|0)+(al<<1)>>1]|0;if((a[(c[277215]|0)+aj|0]&32)==0){ax=c[277228]&65535}else{ax=b[(c[277213]|0)+(aj<<1)>>1]|0}ak=q&-2048;am=ax&-2048;ae=(ak&65535)>(am&65535)?ak-am&65535:0;am=q&2016;ak=ax&2016;if((am&65535)>(ak&65535)){ay=(am-ak&65535)+ae&65535}else{ay=ae}ae=q&31;q=ax&31;if((ae&65535)<=(q&65535)){av=ay;break}av=(ae-q&65535)+ay&65535}}while(0);b[(c[277218]|0)+(aj<<1)>>1]=av;a[(c[277219]|0)+aj|0]=a[1108909]|0;at=a[1108908]|0;au=c[277219]|0}else{at=an;au=ao}}while(0);aj=i+2|0;do{if((at&255)>(d[au+aj|0]|0)){al=a[e+5|0]|0;q=al&255;if(al<<24>>24==0){az=at;aA=au;break}do{if((a[1108928]|0)==0){al=b[(c[277225]|0)+(q<<1)>>1]|0;if((a[(c[277215]|0)+aj|0]&32)!=0){aB=b[(c[277221]|0)+((al&65535|67616)-(b[(c[277213]|0)+(aj<<1)>>1]&63454)>>1<<1)>>1]|0;break}ae=c[277228]&65535;ak=al&-2048;am=ae&-2048;_=(ak&65535)>(am&65535)?ak-am&65535:0;am=al&2016;ak=ae&2016;if((am&65535)>(ak&65535)){aC=(am-ak&65535)+_&65535}else{aC=_}_=al&31;al=ae&31;if((_&65535)<=(al&65535)){aB=aC;break}aB=(_-al&65535)+aC&65535}else{al=b[(c[277225]|0)+(q<<1)>>1]|0;if((a[(c[277215]|0)+aj|0]&32)==0){aD=c[277228]&65535}else{aD=b[(c[277213]|0)+(aj<<1)>>1]|0}_=al&-2048;ae=aD&-2048;ak=(_&65535)>(ae&65535)?_-ae&65535:0;ae=al&2016;_=aD&2016;if((ae&65535)>(_&65535)){aE=(ae-_&65535)+ak&65535}else{aE=ak}ak=al&31;al=aD&31;if((ak&65535)<=(al&65535)){aB=aE;break}aB=(ak-al&65535)+aE&65535}}while(0);b[(c[277218]|0)+(aj<<1)>>1]=aB;a[(c[277219]|0)+aj|0]=a[1108909]|0;az=a[1108908]|0;aA=c[277219]|0}else{az=at;aA=au}}while(0);aj=i+3|0;do{if((az&255)>(d[aA+aj|0]|0)){q=a[e+4|0]|0;al=q&255;if(q<<24>>24==0){aF=az;aG=aA;break}do{if((a[1108928]|0)==0){q=b[(c[277225]|0)+(al<<1)>>1]|0;if((a[(c[277215]|0)+aj|0]&32)!=0){aH=b[(c[277221]|0)+((q&65535|67616)-(b[(c[277213]|0)+(aj<<1)>>1]&63454)>>1<<1)>>1]|0;break}ak=c[277228]&65535;_=q&-2048;ae=ak&-2048;am=(_&65535)>(ae&65535)?_-ae&65535:0;ae=q&2016;_=ak&2016;if((ae&65535)>(_&65535)){aI=(ae-_&65535)+am&65535}else{aI=am}am=q&31;q=ak&31;if((am&65535)<=(q&65535)){aH=aI;break}aH=(am-q&65535)+aI&65535}else{q=b[(c[277225]|0)+(al<<1)>>1]|0;if((a[(c[277215]|0)+aj|0]&32)==0){aJ=c[277228]&65535}else{aJ=b[(c[277213]|0)+(aj<<1)>>1]|0}am=q&-2048;ak=aJ&-2048;_=(am&65535)>(ak&65535)?am-ak&65535:0;ak=q&2016;am=aJ&2016;if((ak&65535)>(am&65535)){aK=(ak-am&65535)+_&65535}else{aK=_}_=q&31;q=aJ&31;if((_&65535)<=(q&65535)){aH=aK;break}aH=(_-q&65535)+aK&65535}}while(0);b[(c[277218]|0)+(aj<<1)>>1]=aH;a[(c[277219]|0)+aj|0]=a[1108909]|0;aF=a[1108908]|0;aG=c[277219]|0}else{aF=az;aG=aA}}while(0);aj=i+4|0;do{if((aF&255)>(d[aG+aj|0]|0)){al=a[e+3|0]|0;q=al&255;if(al<<24>>24==0){aL=aF;aM=aG;break}do{if((a[1108928]|0)==0){al=b[(c[277225]|0)+(q<<1)>>1]|0;if((a[(c[277215]|0)+aj|0]&32)!=0){aN=b[(c[277221]|0)+((al&65535|67616)-(b[(c[277213]|0)+(aj<<1)>>1]&63454)>>1<<1)>>1]|0;break}_=c[277228]&65535;am=al&-2048;ak=_&-2048;ae=(am&65535)>(ak&65535)?am-ak&65535:0;ak=al&2016;am=_&2016;if((ak&65535)>(am&65535)){aO=(ak-am&65535)+ae&65535}else{aO=ae}ae=al&31;al=_&31;if((ae&65535)<=(al&65535)){aN=aO;break}aN=(ae-al&65535)+aO&65535}else{al=b[(c[277225]|0)+(q<<1)>>1]|0;if((a[(c[277215]|0)+aj|0]&32)==0){aP=c[277228]&65535}else{aP=b[(c[277213]|0)+(aj<<1)>>1]|0}ae=al&-2048;_=aP&-2048;am=(ae&65535)>(_&65535)?ae-_&65535:0;_=al&2016;ae=aP&2016;if((_&65535)>(ae&65535)){aQ=(_-ae&65535)+am&65535}else{aQ=am}am=al&31;al=aP&31;if((am&65535)<=(al&65535)){aN=aQ;break}aN=(am-al&65535)+aQ&65535}}while(0);b[(c[277218]|0)+(aj<<1)>>1]=aN;a[(c[277219]|0)+aj|0]=a[1108909]|0;aL=a[1108908]|0;aM=c[277219]|0}else{aL=aF;aM=aG}}while(0);aj=i+5|0;do{if((aL&255)>(d[aM+aj|0]|0)){q=a[e+2|0]|0;al=q&255;if(q<<24>>24==0){aR=aL;aS=aM;break}do{if((a[1108928]|0)==0){q=b[(c[277225]|0)+(al<<1)>>1]|0;if((a[(c[277215]|0)+aj|0]&32)!=0){aT=b[(c[277221]|0)+((q&65535|67616)-(b[(c[277213]|0)+(aj<<1)>>1]&63454)>>1<<1)>>1]|0;break}am=c[277228]&65535;ae=q&-2048;_=am&-2048;ak=(ae&65535)>(_&65535)?ae-_&65535:0;_=q&2016;ae=am&2016;if((_&65535)>(ae&65535)){aU=(_-ae&65535)+ak&65535}else{aU=ak}ak=q&31;q=am&31;if((ak&65535)<=(q&65535)){aT=aU;break}aT=(ak-q&65535)+aU&65535}else{q=b[(c[277225]|0)+(al<<1)>>1]|0;if((a[(c[277215]|0)+aj|0]&32)==0){aV=c[277228]&65535}else{aV=b[(c[277213]|0)+(aj<<1)>>1]|0}ak=q&-2048;am=aV&-2048;ae=(ak&65535)>(am&65535)?ak-am&65535:0;am=q&2016;ak=aV&2016;if((am&65535)>(ak&65535)){aW=(am-ak&65535)+ae&65535}else{aW=ae}ae=q&31;q=aV&31;if((ae&65535)<=(q&65535)){aT=aW;break}aT=(ae-q&65535)+aW&65535}}while(0);b[(c[277218]|0)+(aj<<1)>>1]=aT;a[(c[277219]|0)+aj|0]=a[1108909]|0;aR=a[1108908]|0;aS=c[277219]|0}else{aR=aL;aS=aM}}while(0);aj=i+6|0;do{if((aR&255)>(d[aS+aj|0]|0)){al=a[e+1|0]|0;q=al&255;if(al<<24>>24==0){aX=aR;aY=aS;break}do{if((a[1108928]|0)==0){al=b[(c[277225]|0)+(q<<1)>>1]|0;if((a[(c[277215]|0)+aj|0]&32)!=0){aZ=b[(c[277221]|0)+((al&65535|67616)-(b[(c[277213]|0)+(aj<<1)>>1]&63454)>>1<<1)>>1]|0;break}ae=c[277228]&65535;ak=al&-2048;am=ae&-2048;_=(ak&65535)>(am&65535)?ak-am&65535:0;am=al&2016;ak=ae&2016;if((am&65535)>(ak&65535)){a_=(am-ak&65535)+_&65535}else{a_=_}_=al&31;al=ae&31;if((_&65535)<=(al&65535)){aZ=a_;break}aZ=(_-al&65535)+a_&65535}else{al=b[(c[277225]|0)+(q<<1)>>1]|0;if((a[(c[277215]|0)+aj|0]&32)==0){a$=c[277228]&65535}else{a$=b[(c[277213]|0)+(aj<<1)>>1]|0}_=al&-2048;ae=a$&-2048;ak=(_&65535)>(ae&65535)?_-ae&65535:0;ae=al&2016;_=a$&2016;if((ae&65535)>(_&65535)){a0=(ae-_&65535)+ak&65535}else{a0=ak}ak=al&31;al=a$&31;if((ak&65535)<=(al&65535)){aZ=a0;break}aZ=(ak-al&65535)+a0&65535}}while(0);b[(c[277218]|0)+(aj<<1)>>1]=aZ;a[(c[277219]|0)+aj|0]=a[1108909]|0;aX=a[1108908]|0;aY=c[277219]|0}else{aX=aR;aY=aS}}while(0);aj=i+7|0;do{if((aX&255)>(d[aY+aj|0]|0)){q=a[e]|0;al=q&255;if(q<<24>>24==0){break}do{if((a[1108928]|0)==0){q=b[(c[277225]|0)+(al<<1)>>1]|0;if((a[(c[277215]|0)+aj|0]&32)!=0){a1=b[(c[277221]|0)+((q&65535|67616)-(b[(c[277213]|0)+(aj<<1)>>1]&63454)>>1<<1)>>1]|0;break}ak=c[277228]&65535;_=q&-2048;ae=ak&-2048;am=(_&65535)>(ae&65535)?_-ae&65535:0;ae=q&2016;_=ak&2016;if((ae&65535)>(_&65535)){a2=(ae-_&65535)+am&65535}else{a2=am}am=q&31;q=ak&31;if((am&65535)<=(q&65535)){a1=a2;break}a1=(am-q&65535)+a2&65535}else{q=b[(c[277225]|0)+(al<<1)>>1]|0;if((a[(c[277215]|0)+aj|0]&32)==0){a3=c[277228]&65535}else{a3=b[(c[277213]|0)+(aj<<1)>>1]|0}am=q&-2048;ak=a3&-2048;_=(am&65535)>(ak&65535)?am-ak&65535:0;ak=q&2016;am=a3&2016;if((ak&65535)>(am&65535)){a4=(ak-am&65535)+_&65535}else{a4=_}_=q&31;q=a3&31;if((_&65535)<=(q&65535)){a1=a4;break}a1=(_-q&65535)+a4&65535}}while(0);b[(c[277218]|0)+(aj<<1)>>1]=a1;a[(c[277219]|0)+aj|0]=a[1108909]|0}}while(0);aj=l-1|0;if((aj|0)<=0){break}e=e+8|0;l=aj;i=(c[277223]|0)+i|0}return}i=o+(56-g)|0;g=(h|0)>0;if(j){if(g){a5=i;a6=h;a7=f}else{return}while(1){j=a[1108908]|0;o=c[277219]|0;do{if((j&255)>(d[o+a7|0]|0)){l=a[a5+7|0]|0;e=l&255;if(l<<24>>24==0){a8=j;a9=o;break}do{if((a[1108928]|0)==0){l=b[(c[277225]|0)+(e<<1)>>1]|0;if((a[(c[277215]|0)+a7|0]&32)!=0){ba=b[(c[277221]|0)+((l&65535|67616)-(b[(c[277213]|0)+(a7<<1)>>1]&63454)>>1<<1)>>1]|0;break}a1=c[277228]&65535;a4=l&-2048;a3=a1&-2048;a2=(a4&65535)>(a3&65535)?a4-a3&65535:0;a3=l&2016;a4=a1&2016;if((a3&65535)>(a4&65535)){bb=(a3-a4&65535)+a2&65535}else{bb=a2}a2=l&31;l=a1&31;if((a2&65535)<=(l&65535)){ba=bb;break}ba=(a2-l&65535)+bb&65535}else{l=b[(c[277225]|0)+(e<<1)>>1]|0;if((a[(c[277215]|0)+a7|0]&32)==0){bc=c[277228]&65535}else{bc=b[(c[277213]|0)+(a7<<1)>>1]|0}a2=l&-2048;a1=bc&-2048;a4=(a2&65535)>(a1&65535)?a2-a1&65535:0;a1=l&2016;a2=bc&2016;if((a1&65535)>(a2&65535)){bd=(a1-a2&65535)+a4&65535}else{bd=a4}a4=l&31;l=bc&31;if((a4&65535)<=(l&65535)){ba=bd;break}ba=(a4-l&65535)+bd&65535}}while(0);b[(c[277218]|0)+(a7<<1)>>1]=ba;a[(c[277219]|0)+a7|0]=a[1108909]|0;a8=a[1108908]|0;a9=c[277219]|0}else{a8=j;a9=o}}while(0);o=a7+1|0;do{if((a8&255)>(d[a9+o|0]|0)){j=a[a5+6|0]|0;e=j&255;if(j<<24>>24==0){be=a8;bf=a9;break}do{if((a[1108928]|0)==0){j=b[(c[277225]|0)+(e<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){bg=b[(c[277221]|0)+((j&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}l=c[277228]&65535;a4=j&-2048;a2=l&-2048;a1=(a4&65535)>(a2&65535)?a4-a2&65535:0;a2=j&2016;a4=l&2016;if((a2&65535)>(a4&65535)){bh=(a2-a4&65535)+a1&65535}else{bh=a1}a1=j&31;j=l&31;if((a1&65535)<=(j&65535)){bg=bh;break}bg=(a1-j&65535)+bh&65535}else{j=b[(c[277225]|0)+(e<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){bi=c[277228]&65535}else{bi=b[(c[277213]|0)+(o<<1)>>1]|0}a1=j&-2048;l=bi&-2048;a4=(a1&65535)>(l&65535)?a1-l&65535:0;l=j&2016;a1=bi&2016;if((l&65535)>(a1&65535)){bj=(l-a1&65535)+a4&65535}else{bj=a4}a4=j&31;j=bi&31;if((a4&65535)<=(j&65535)){bg=bj;break}bg=(a4-j&65535)+bj&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=bg;a[(c[277219]|0)+o|0]=a[1108909]|0;be=a[1108908]|0;bf=c[277219]|0}else{be=a8;bf=a9}}while(0);o=a7+2|0;do{if((be&255)>(d[bf+o|0]|0)){e=a[a5+5|0]|0;j=e&255;if(e<<24>>24==0){bk=be;bl=bf;break}do{if((a[1108928]|0)==0){e=b[(c[277225]|0)+(j<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){bm=b[(c[277221]|0)+((e&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}a4=c[277228]&65535;a1=e&-2048;l=a4&-2048;a2=(a1&65535)>(l&65535)?a1-l&65535:0;l=e&2016;a1=a4&2016;if((l&65535)>(a1&65535)){bn=(l-a1&65535)+a2&65535}else{bn=a2}a2=e&31;e=a4&31;if((a2&65535)<=(e&65535)){bm=bn;break}bm=(a2-e&65535)+bn&65535}else{e=b[(c[277225]|0)+(j<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){bo=c[277228]&65535}else{bo=b[(c[277213]|0)+(o<<1)>>1]|0}a2=e&-2048;a4=bo&-2048;a1=(a2&65535)>(a4&65535)?a2-a4&65535:0;a4=e&2016;a2=bo&2016;if((a4&65535)>(a2&65535)){bp=(a4-a2&65535)+a1&65535}else{bp=a1}a1=e&31;e=bo&31;if((a1&65535)<=(e&65535)){bm=bp;break}bm=(a1-e&65535)+bp&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=bm;a[(c[277219]|0)+o|0]=a[1108909]|0;bk=a[1108908]|0;bl=c[277219]|0}else{bk=be;bl=bf}}while(0);o=a7+3|0;do{if((bk&255)>(d[bl+o|0]|0)){j=a[a5+4|0]|0;e=j&255;if(j<<24>>24==0){bq=bk;br=bl;break}do{if((a[1108928]|0)==0){j=b[(c[277225]|0)+(e<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){bs=b[(c[277221]|0)+((j&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}a1=c[277228]&65535;a2=j&-2048;a4=a1&-2048;l=(a2&65535)>(a4&65535)?a2-a4&65535:0;a4=j&2016;a2=a1&2016;if((a4&65535)>(a2&65535)){bt=(a4-a2&65535)+l&65535}else{bt=l}l=j&31;j=a1&31;if((l&65535)<=(j&65535)){bs=bt;break}bs=(l-j&65535)+bt&65535}else{j=b[(c[277225]|0)+(e<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){bu=c[277228]&65535}else{bu=b[(c[277213]|0)+(o<<1)>>1]|0}l=j&-2048;a1=bu&-2048;a2=(l&65535)>(a1&65535)?l-a1&65535:0;a1=j&2016;l=bu&2016;if((a1&65535)>(l&65535)){bv=(a1-l&65535)+a2&65535}else{bv=a2}a2=j&31;j=bu&31;if((a2&65535)<=(j&65535)){bs=bv;break}bs=(a2-j&65535)+bv&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=bs;a[(c[277219]|0)+o|0]=a[1108909]|0;bq=a[1108908]|0;br=c[277219]|0}else{bq=bk;br=bl}}while(0);o=a7+4|0;do{if((bq&255)>(d[br+o|0]|0)){e=a[a5+3|0]|0;j=e&255;if(e<<24>>24==0){bw=bq;bx=br;break}do{if((a[1108928]|0)==0){e=b[(c[277225]|0)+(j<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){by=b[(c[277221]|0)+((e&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}a2=c[277228]&65535;l=e&-2048;a1=a2&-2048;a4=(l&65535)>(a1&65535)?l-a1&65535:0;a1=e&2016;l=a2&2016;if((a1&65535)>(l&65535)){bz=(a1-l&65535)+a4&65535}else{bz=a4}a4=e&31;e=a2&31;if((a4&65535)<=(e&65535)){by=bz;break}by=(a4-e&65535)+bz&65535}else{e=b[(c[277225]|0)+(j<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){bA=c[277228]&65535}else{bA=b[(c[277213]|0)+(o<<1)>>1]|0}a4=e&-2048;a2=bA&-2048;l=(a4&65535)>(a2&65535)?a4-a2&65535:0;a2=e&2016;a4=bA&2016;if((a2&65535)>(a4&65535)){bB=(a2-a4&65535)+l&65535}else{bB=l}l=e&31;e=bA&31;if((l&65535)<=(e&65535)){by=bB;break}by=(l-e&65535)+bB&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=by;a[(c[277219]|0)+o|0]=a[1108909]|0;bw=a[1108908]|0;bx=c[277219]|0}else{bw=bq;bx=br}}while(0);o=a7+5|0;do{if((bw&255)>(d[bx+o|0]|0)){j=a[a5+2|0]|0;e=j&255;if(j<<24>>24==0){bC=bw;bD=bx;break}do{if((a[1108928]|0)==0){j=b[(c[277225]|0)+(e<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){bE=b[(c[277221]|0)+((j&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}l=c[277228]&65535;a4=j&-2048;a2=l&-2048;a1=(a4&65535)>(a2&65535)?a4-a2&65535:0;a2=j&2016;a4=l&2016;if((a2&65535)>(a4&65535)){bF=(a2-a4&65535)+a1&65535}else{bF=a1}a1=j&31;j=l&31;if((a1&65535)<=(j&65535)){bE=bF;break}bE=(a1-j&65535)+bF&65535}else{j=b[(c[277225]|0)+(e<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){bG=c[277228]&65535}else{bG=b[(c[277213]|0)+(o<<1)>>1]|0}a1=j&-2048;l=bG&-2048;a4=(a1&65535)>(l&65535)?a1-l&65535:0;l=j&2016;a1=bG&2016;if((l&65535)>(a1&65535)){bH=(l-a1&65535)+a4&65535}else{bH=a4}a4=j&31;j=bG&31;if((a4&65535)<=(j&65535)){bE=bH;break}bE=(a4-j&65535)+bH&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=bE;a[(c[277219]|0)+o|0]=a[1108909]|0;bC=a[1108908]|0;bD=c[277219]|0}else{bC=bw;bD=bx}}while(0);o=a7+6|0;do{if((bC&255)>(d[bD+o|0]|0)){e=a[a5+1|0]|0;j=e&255;if(e<<24>>24==0){bI=bC;bJ=bD;break}do{if((a[1108928]|0)==0){e=b[(c[277225]|0)+(j<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){bK=b[(c[277221]|0)+((e&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}a4=c[277228]&65535;a1=e&-2048;l=a4&-2048;a2=(a1&65535)>(l&65535)?a1-l&65535:0;l=e&2016;a1=a4&2016;if((l&65535)>(a1&65535)){bL=(l-a1&65535)+a2&65535}else{bL=a2}a2=e&31;e=a4&31;if((a2&65535)<=(e&65535)){bK=bL;break}bK=(a2-e&65535)+bL&65535}else{e=b[(c[277225]|0)+(j<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){bM=c[277228]&65535}else{bM=b[(c[277213]|0)+(o<<1)>>1]|0}a2=e&-2048;a4=bM&-2048;a1=(a2&65535)>(a4&65535)?a2-a4&65535:0;a4=e&2016;a2=bM&2016;if((a4&65535)>(a2&65535)){bN=(a4-a2&65535)+a1&65535}else{bN=a1}a1=e&31;e=bM&31;if((a1&65535)<=(e&65535)){bK=bN;break}bK=(a1-e&65535)+bN&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=bK;a[(c[277219]|0)+o|0]=a[1108909]|0;bI=a[1108908]|0;bJ=c[277219]|0}else{bI=bC;bJ=bD}}while(0);o=a7+7|0;do{if((bI&255)>(d[bJ+o|0]|0)){j=a[a5]|0;e=j&255;if(j<<24>>24==0){break}do{if((a[1108928]|0)==0){j=b[(c[277225]|0)+(e<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)!=0){bO=b[(c[277221]|0)+((j&65535|67616)-(b[(c[277213]|0)+(o<<1)>>1]&63454)>>1<<1)>>1]|0;break}a1=c[277228]&65535;a2=j&-2048;a4=a1&-2048;l=(a2&65535)>(a4&65535)?a2-a4&65535:0;a4=j&2016;a2=a1&2016;if((a4&65535)>(a2&65535)){bP=(a4-a2&65535)+l&65535}else{bP=l}l=j&31;j=a1&31;if((l&65535)<=(j&65535)){bO=bP;break}bO=(l-j&65535)+bP&65535}else{j=b[(c[277225]|0)+(e<<1)>>1]|0;if((a[(c[277215]|0)+o|0]&32)==0){bQ=c[277228]&65535}else{bQ=b[(c[277213]|0)+(o<<1)>>1]|0}l=j&-2048;a1=bQ&-2048;a2=(l&65535)>(a1&65535)?l-a1&65535:0;a1=j&2016;l=bQ&2016;if((a1&65535)>(l&65535)){bR=(a1-l&65535)+a2&65535}else{bR=a2}a2=j&31;j=bQ&31;if((a2&65535)<=(j&65535)){bO=bR;break}bO=(a2-j&65535)+bR&65535}}while(0);b[(c[277218]|0)+(o<<1)>>1]=bO;a[(c[277219]|0)+o|0]=a[1108909]|0}}while(0);o=a6-1|0;if((o|0)<=0){break}a5=a5-8|0;a6=o;a7=(c[277223]|0)+a7|0}return}else{if(g){bS=i;bT=h;bU=f}else{return}while(1){f=a[1108908]|0;h=c[277219]|0;do{if((f&255)>(d[h+bU|0]|0)){i=a[bS]|0;g=i&255;if(i<<24>>24==0){bV=f;bW=h;break}do{if((a[1108928]|0)==0){i=b[(c[277225]|0)+(g<<1)>>1]|0;if((a[(c[277215]|0)+bU|0]&32)!=0){bX=b[(c[277221]|0)+((i&65535|67616)-(b[(c[277213]|0)+(bU<<1)>>1]&63454)>>1<<1)>>1]|0;break}a7=c[277228]&65535;a6=i&-2048;a5=a7&-2048;bO=(a6&65535)>(a5&65535)?a6-a5&65535:0;a5=i&2016;a6=a7&2016;if((a5&65535)>(a6&65535)){bY=(a5-a6&65535)+bO&65535}else{bY=bO}bO=i&31;i=a7&31;if((bO&65535)<=(i&65535)){bX=bY;break}bX=(bO-i&65535)+bY&65535}else{i=b[(c[277225]|0)+(g<<1)>>1]|0;if((a[(c[277215]|0)+bU|0]&32)==0){bZ=c[277228]&65535}else{bZ=b[(c[277213]|0)+(bU<<1)>>1]|0}bO=i&-2048;a7=bZ&-2048;a6=(bO&65535)>(a7&65535)?bO-a7&65535:0;a7=i&2016;bO=bZ&2016;if((a7&65535)>(bO&65535)){b_=(a7-bO&65535)+a6&65535}else{b_=a6}a6=i&31;i=bZ&31;if((a6&65535)<=(i&65535)){bX=b_;break}bX=(a6-i&65535)+b_&65535}}while(0);b[(c[277218]|0)+(bU<<1)>>1]=bX;a[(c[277219]|0)+bU|0]=a[1108909]|0;bV=a[1108908]|0;bW=c[277219]|0}else{bV=f;bW=h}}while(0);h=bU+1|0;do{if((bV&255)>(d[bW+h|0]|0)){f=a[bS+1|0]|0;g=f&255;if(f<<24>>24==0){b$=bV;b0=bW;break}do{if((a[1108928]|0)==0){f=b[(c[277225]|0)+(g<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)!=0){b1=b[(c[277221]|0)+((f&65535|67616)-(b[(c[277213]|0)+(h<<1)>>1]&63454)>>1<<1)>>1]|0;break}i=c[277228]&65535;a6=f&-2048;bO=i&-2048;a7=(a6&65535)>(bO&65535)?a6-bO&65535:0;bO=f&2016;a6=i&2016;if((bO&65535)>(a6&65535)){b2=(bO-a6&65535)+a7&65535}else{b2=a7}a7=f&31;f=i&31;if((a7&65535)<=(f&65535)){b1=b2;break}b1=(a7-f&65535)+b2&65535}else{f=b[(c[277225]|0)+(g<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)==0){b3=c[277228]&65535}else{b3=b[(c[277213]|0)+(h<<1)>>1]|0}a7=f&-2048;i=b3&-2048;a6=(a7&65535)>(i&65535)?a7-i&65535:0;i=f&2016;a7=b3&2016;if((i&65535)>(a7&65535)){b4=(i-a7&65535)+a6&65535}else{b4=a6}a6=f&31;f=b3&31;if((a6&65535)<=(f&65535)){b1=b4;break}b1=(a6-f&65535)+b4&65535}}while(0);b[(c[277218]|0)+(h<<1)>>1]=b1;a[(c[277219]|0)+h|0]=a[1108909]|0;b$=a[1108908]|0;b0=c[277219]|0}else{b$=bV;b0=bW}}while(0);h=bU+2|0;do{if((b$&255)>(d[b0+h|0]|0)){g=a[bS+2|0]|0;f=g&255;if(g<<24>>24==0){b5=b$;b6=b0;break}do{if((a[1108928]|0)==0){g=b[(c[277225]|0)+(f<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)!=0){b7=b[(c[277221]|0)+((g&65535|67616)-(b[(c[277213]|0)+(h<<1)>>1]&63454)>>1<<1)>>1]|0;break}a6=c[277228]&65535;a7=g&-2048;i=a6&-2048;bO=(a7&65535)>(i&65535)?a7-i&65535:0;i=g&2016;a7=a6&2016;if((i&65535)>(a7&65535)){b8=(i-a7&65535)+bO&65535}else{b8=bO}bO=g&31;g=a6&31;if((bO&65535)<=(g&65535)){b7=b8;break}b7=(bO-g&65535)+b8&65535}else{g=b[(c[277225]|0)+(f<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)==0){b9=c[277228]&65535}else{b9=b[(c[277213]|0)+(h<<1)>>1]|0}bO=g&-2048;a6=b9&-2048;a7=(bO&65535)>(a6&65535)?bO-a6&65535:0;a6=g&2016;bO=b9&2016;if((a6&65535)>(bO&65535)){ca=(a6-bO&65535)+a7&65535}else{ca=a7}a7=g&31;g=b9&31;if((a7&65535)<=(g&65535)){b7=ca;break}b7=(a7-g&65535)+ca&65535}}while(0);b[(c[277218]|0)+(h<<1)>>1]=b7;a[(c[277219]|0)+h|0]=a[1108909]|0;b5=a[1108908]|0;b6=c[277219]|0}else{b5=b$;b6=b0}}while(0);h=bU+3|0;do{if((b5&255)>(d[b6+h|0]|0)){f=a[bS+3|0]|0;g=f&255;if(f<<24>>24==0){cb=b5;cc=b6;break}do{if((a[1108928]|0)==0){f=b[(c[277225]|0)+(g<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)!=0){cd=b[(c[277221]|0)+((f&65535|67616)-(b[(c[277213]|0)+(h<<1)>>1]&63454)>>1<<1)>>1]|0;break}a7=c[277228]&65535;bO=f&-2048;a6=a7&-2048;i=(bO&65535)>(a6&65535)?bO-a6&65535:0;a6=f&2016;bO=a7&2016;if((a6&65535)>(bO&65535)){ce=(a6-bO&65535)+i&65535}else{ce=i}i=f&31;f=a7&31;if((i&65535)<=(f&65535)){cd=ce;break}cd=(i-f&65535)+ce&65535}else{f=b[(c[277225]|0)+(g<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)==0){cf=c[277228]&65535}else{cf=b[(c[277213]|0)+(h<<1)>>1]|0}i=f&-2048;a7=cf&-2048;bO=(i&65535)>(a7&65535)?i-a7&65535:0;a7=f&2016;i=cf&2016;if((a7&65535)>(i&65535)){cg=(a7-i&65535)+bO&65535}else{cg=bO}bO=f&31;f=cf&31;if((bO&65535)<=(f&65535)){cd=cg;break}cd=(bO-f&65535)+cg&65535}}while(0);b[(c[277218]|0)+(h<<1)>>1]=cd;a[(c[277219]|0)+h|0]=a[1108909]|0;cb=a[1108908]|0;cc=c[277219]|0}else{cb=b5;cc=b6}}while(0);h=bU+4|0;do{if((cb&255)>(d[cc+h|0]|0)){g=a[bS+4|0]|0;f=g&255;if(g<<24>>24==0){ch=cb;ci=cc;break}do{if((a[1108928]|0)==0){g=b[(c[277225]|0)+(f<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)!=0){cj=b[(c[277221]|0)+((g&65535|67616)-(b[(c[277213]|0)+(h<<1)>>1]&63454)>>1<<1)>>1]|0;break}bO=c[277228]&65535;i=g&-2048;a7=bO&-2048;a6=(i&65535)>(a7&65535)?i-a7&65535:0;a7=g&2016;i=bO&2016;if((a7&65535)>(i&65535)){ck=(a7-i&65535)+a6&65535}else{ck=a6}a6=g&31;g=bO&31;if((a6&65535)<=(g&65535)){cj=ck;break}cj=(a6-g&65535)+ck&65535}else{g=b[(c[277225]|0)+(f<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)==0){cl=c[277228]&65535}else{cl=b[(c[277213]|0)+(h<<1)>>1]|0}a6=g&-2048;bO=cl&-2048;i=(a6&65535)>(bO&65535)?a6-bO&65535:0;bO=g&2016;a6=cl&2016;if((bO&65535)>(a6&65535)){cm=(bO-a6&65535)+i&65535}else{cm=i}i=g&31;g=cl&31;if((i&65535)<=(g&65535)){cj=cm;break}cj=(i-g&65535)+cm&65535}}while(0);b[(c[277218]|0)+(h<<1)>>1]=cj;a[(c[277219]|0)+h|0]=a[1108909]|0;ch=a[1108908]|0;ci=c[277219]|0}else{ch=cb;ci=cc}}while(0);h=bU+5|0;do{if((ch&255)>(d[ci+h|0]|0)){f=a[bS+5|0]|0;g=f&255;if(f<<24>>24==0){cn=ch;co=ci;break}do{if((a[1108928]|0)==0){f=b[(c[277225]|0)+(g<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)!=0){cp=b[(c[277221]|0)+((f&65535|67616)-(b[(c[277213]|0)+(h<<1)>>1]&63454)>>1<<1)>>1]|0;break}i=c[277228]&65535;a6=f&-2048;bO=i&-2048;a7=(a6&65535)>(bO&65535)?a6-bO&65535:0;bO=f&2016;a6=i&2016;if((bO&65535)>(a6&65535)){cq=(bO-a6&65535)+a7&65535}else{cq=a7}a7=f&31;f=i&31;if((a7&65535)<=(f&65535)){cp=cq;break}cp=(a7-f&65535)+cq&65535}else{f=b[(c[277225]|0)+(g<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)==0){cr=c[277228]&65535}else{cr=b[(c[277213]|0)+(h<<1)>>1]|0}a7=f&-2048;i=cr&-2048;a6=(a7&65535)>(i&65535)?a7-i&65535:0;i=f&2016;a7=cr&2016;if((i&65535)>(a7&65535)){cs=(i-a7&65535)+a6&65535}else{cs=a6}a6=f&31;f=cr&31;if((a6&65535)<=(f&65535)){cp=cs;break}cp=(a6-f&65535)+cs&65535}}while(0);b[(c[277218]|0)+(h<<1)>>1]=cp;a[(c[277219]|0)+h|0]=a[1108909]|0;cn=a[1108908]|0;co=c[277219]|0}else{cn=ch;co=ci}}while(0);h=bU+6|0;do{if((cn&255)>(d[co+h|0]|0)){g=a[bS+6|0]|0;f=g&255;if(g<<24>>24==0){ct=cn;cu=co;break}do{if((a[1108928]|0)==0){g=b[(c[277225]|0)+(f<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)!=0){cv=b[(c[277221]|0)+((g&65535|67616)-(b[(c[277213]|0)+(h<<1)>>1]&63454)>>1<<1)>>1]|0;break}a6=c[277228]&65535;a7=g&-2048;i=a6&-2048;bO=(a7&65535)>(i&65535)?a7-i&65535:0;i=g&2016;a7=a6&2016;if((i&65535)>(a7&65535)){cw=(i-a7&65535)+bO&65535}else{cw=bO}bO=g&31;g=a6&31;if((bO&65535)<=(g&65535)){cv=cw;break}cv=(bO-g&65535)+cw&65535}else{g=b[(c[277225]|0)+(f<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)==0){cx=c[277228]&65535}else{cx=b[(c[277213]|0)+(h<<1)>>1]|0}bO=g&-2048;a6=cx&-2048;a7=(bO&65535)>(a6&65535)?bO-a6&65535:0;a6=g&2016;bO=cx&2016;if((a6&65535)>(bO&65535)){cy=(a6-bO&65535)+a7&65535}else{cy=a7}a7=g&31;g=cx&31;if((a7&65535)<=(g&65535)){cv=cy;break}cv=(a7-g&65535)+cy&65535}}while(0);b[(c[277218]|0)+(h<<1)>>1]=cv;a[(c[277219]|0)+h|0]=a[1108909]|0;ct=a[1108908]|0;cu=c[277219]|0}else{ct=cn;cu=co}}while(0);h=bU+7|0;do{if((ct&255)>(d[cu+h|0]|0)){f=a[bS+7|0]|0;g=f&255;if(f<<24>>24==0){break}do{if((a[1108928]|0)==0){f=b[(c[277225]|0)+(g<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)!=0){cz=b[(c[277221]|0)+((f&65535|67616)-(b[(c[277213]|0)+(h<<1)>>1]&63454)>>1<<1)>>1]|0;break}a7=c[277228]&65535;bO=f&-2048;a6=a7&-2048;i=(bO&65535)>(a6&65535)?bO-a6&65535:0;a6=f&2016;bO=a7&2016;if((a6&65535)>(bO&65535)){cA=(a6-bO&65535)+i&65535}else{cA=i}i=f&31;f=a7&31;if((i&65535)<=(f&65535)){cz=cA;break}cz=(i-f&65535)+cA&65535}else{f=b[(c[277225]|0)+(g<<1)>>1]|0;if((a[(c[277215]|0)+h|0]&32)==0){cB=c[277228]&65535}else{cB=b[(c[277213]|0)+(h<<1)>>1]|0}i=f&-2048;a7=cB&-2048;bO=(i&65535)>(a7&65535)?i-a7&65535:0;a7=f&2016;i=cB&2016;if((a7&65535)>(i&65535)){cC=(a7-i&65535)+bO&65535}else{cC=bO}bO=f&31;f=cB&31;if((bO&65535)<=(f&65535)){cz=cC;break}cz=(bO-f&65535)+cC&65535}}while(0);b[(c[277218]|0)+(h<<1)>>1]=cz;a[(c[277219]|0)+h|0]=a[1108909]|0}}while(0);h=bT-1|0;if((h|0)<=0){break}bS=bS-8|0;bT=h;bU=(c[277223]|0)+bU|0}return}}function Xy(){return 1}function Xz(a){a=a|0;c[42366]=a;return}function XA(a){a=a|0;return}function XB(a){a=a|0;c[199558]=a;return}function XC(a){a=a|0;c[59510]=a;return}function XD(a){a=a|0;c[127412]=a;return}function XE(a){a=a|0;var b=0;if((a|0)==3){b=c[263194]|0}else if((a|0)==1){b=1041680}else if((a|0)==2){b=c[263191]|0}else if((a|0)==0){b=c[263193]|0}else{b=0}return b|0}function XF(b){b=b|0;var c=0,d=0,e=0,f=0,g=0;do{if((b|0)==3){c=65536}else if((b|0)==1){if((a[799130]|0)!=0){c=20;break}c=(a[799127]|0)!=0?20:0}else if((b|0)==2){c=131072}else if((b|0)==0){d=a[1097938]|0;if(d<<24>>24==0){e=0;f=e>>>0>131072;g=f?131072:e;return g|0}e=128<<(d&255)+3;f=e>>>0>131072;g=f?131072:e;return g|0}else{c=0}}while(0);return c|0}function XG(b){b=b|0;a[b+12|0]=0;c[b+8>>2]=65432;c[b+4>>2]=55352;c[b>>2]=46024;a[b+13|0]=0;return}function XH(b){b=b|0;c[b>>2]=256;c[b+4>>2]=239;c[b+8>>2]=512;c[b+12>>2]=512;g[b+16>>2]=1.3333333730697632;h[b+24>>3]=(a[799146]|0)==0?60.098811862348406:50.006978908188586;h[b+32>>3]=32040.5;return}function XI(a){a=a|0;c[198896]=a;ft[a&63](16,2448)|0;return}function XJ(b,d){b=b|0;d=d|0;var e=0,f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0;e=i;i=i+192|0;f=e|0;g=e+8|0;h=e+16|0;j=e+24|0;k=e+32|0;l=e+40|0;m=e+56|0;n=e+64|0;o=e+72|0;q=e+80|0;r=e+88|0;s=e+96|0;t=e+104|0;u=e+112|0;v=e+120|0;w=e+128|0;x=e+136|0;y=e+144|0;z=e+152|0;A=e+160|0;B=e+168|0;C=e+176|0;D=e+184|0;L6866:do{switch(d|0){case 1:{c[7072+(b<<2)>>2]=0;c[235736+(b<<2)>>2]=1;break};case 257:{c[7072+(b<<2)>>2]=-1;a[238600+(b<<2)|0]=1;a[238601+(b<<2)|0]=2;a[238602+(b<<2)|0]=3;a[238603+(b<<2)|0]=4;c[235736+(b<<2)>>2]=257;break};case 2:{c[7072+(b<<2)>>2]=8;c[235736+(b<<2)>>2]=2;jW(q,39592);jX(12,q);jW(r,35184);jX(13,r);jW(s,30592);E=s|0;F=a[E]|0;G=E+1|0;E=e+48|0;a[E]=a[G]|0;a[E+1|0]=a[G+1|0]|0;a[E+2|0]=a[G+2|0]|0;a[E+3|0]=a[G+3|0]|0;a[E+4|0]=a[G+4|0]|0;if(((F&255)-1|0)>>>0<4){if((c[59655]|0)==18){c[59655]=-1}if((c[59660]|0)==18){c[59660]=-1}if((c[42374]|0)==18){c[42374]=-1}if((c[127398]|0)==18){c[127398]=-1}if((c[127396]|0)==18){c[127396]=-1}a[503548]=F;a[503549|0]=a[E]|0;a[503550|0]=a[E+1|0]|0;a[503551|0]=a[E+2|0]|0;a[503552|0]=a[E+3|0]|0;a[503553|0]=a[E+4|0]|0}jW(t,26672);E=t|0;F=a[E]|0;G=E+1|0;E=k|0;a[E]=a[G]|0;a[E+1|0]=a[G+1|0]|0;a[E+2|0]=a[G+2|0]|0;a[E+3|0]=a[G+3|0]|0;a[E+4|0]=a[G+4|0]|0;if(((F&255)-1|0)>>>0<4){if((c[59655]|0)==19){c[59655]=-1}if((c[59660]|0)==19){c[59660]=-1}if((c[42374]|0)==19){c[42374]=-1}if((c[127398]|0)==19){c[127398]=-1}if((c[127396]|0)==19){c[127396]=-1}a[503554]=F;a[503555|0]=a[E]|0;a[503556|0]=a[E+1|0]|0;a[503557|0]=a[E+2|0]|0;a[503558|0]=a[E+3|0]|0;a[503559|0]=a[E+4|0]|0}jW(u,22528);E=u|0;F=a[E]|0;G=E+1|0;E=h|0;a[E]=a[G]|0;a[E+1|0]=a[G+1|0]|0;a[E+2|0]=a[G+2|0]|0;a[E+3|0]=a[G+3|0]|0;a[E+4|0]=a[G+4|0]|0;if(((F&255)-1|0)>>>0<4){if((c[59655]|0)==34){c[59655]=-1}if((c[59660]|0)==34){c[59660]=-1}if((c[42374]|0)==34){c[42374]=-1}if((c[127398]|0)==34){c[127398]=-1}if((c[127396]|0)==34){c[127396]=-1}a[503644]=F;a[503645|0]=a[E]|0;a[503646|0]=a[E+1|0]|0;a[503647|0]=a[E+2|0]|0;a[503648|0]=a[E+3|0]|0;a[503649|0]=a[E+4|0]|0}jW(v,100176);E=v|0;F=a[E]|0;G=E+1|0;E=f|0;a[E]=a[G]|0;a[E+1|0]=a[G+1|0]|0;a[E+2|0]=a[G+2|0]|0;a[E+3|0]=a[G+3|0]|0;a[E+4|0]=a[G+4|0]|0;if(((F&255)-1|0)>>>0>=4){break L6866}if((c[59655]|0)==35){c[59655]=-1}if((c[59660]|0)==35){c[59660]=-1}if((c[42374]|0)==35){c[42374]=-1}if((c[127398]|0)==35){c[127398]=-1}if((c[127396]|0)==35){c[127396]=-1}a[503650]=F;a[503651|0]=a[E]|0;a[503652|0]=a[E+1|0]|0;a[503653|0]=a[E+2|0]|0;a[503654|0]=a[E+3|0]|0;a[503655|0]=a[E+4|0]|0;break};case 772:{c[7072+(b<<2)>>2]=12;c[235736+(b<<2)>>2]=772;break};case 516:{c[7072+(b<<2)>>2]=11;c[235736+(b<<2)>>2]=516;jW(C,81640);E=C|0;F=a[E]|0;G=E+1|0;E=n|0;a[E]=a[G]|0;a[E+1|0]=a[G+1|0]|0;a[E+2|0]=a[G+2|0]|0;a[E+3|0]=a[G+3|0]|0;a[E+4|0]=a[G+4|0]|0;if(((F&255)-1|0)>>>0<4){if((c[59655]|0)==34){c[59655]=-1}if((c[59660]|0)==34){c[59660]=-1}if((c[42374]|0)==34){c[42374]=-1}if((c[127398]|0)==34){c[127398]=-1}if((c[127396]|0)==34){c[127396]=-1}a[503644]=F;a[503645|0]=a[E]|0;a[503646|0]=a[E+1|0]|0;a[503647|0]=a[E+2|0]|0;a[503648|0]=a[E+3|0]|0;a[503649|0]=a[E+4|0]|0}jW(D,78208);E=D|0;F=a[E]|0;G=E+1|0;E=o|0;a[E]=a[G]|0;a[E+1|0]=a[G+1|0]|0;a[E+2|0]=a[G+2|0]|0;a[E+3|0]=a[G+3|0]|0;a[E+4|0]=a[G+4|0]|0;if(((F&255)-1|0)>>>0>=4){break L6866}if((c[59655]|0)==35){c[59655]=-1}if((c[59660]|0)==35){c[59660]=-1}if((c[42374]|0)==35){c[42374]=-1}if((c[127398]|0)==35){c[127398]=-1}if((c[127396]|0)==35){c[127396]=-1}a[503650]=F;a[503651|0]=a[E]|0;a[503652|0]=a[E+1|0]|0;a[503653|0]=a[E+2|0]|0;a[503654|0]=a[E+3|0]|0;a[503655|0]=a[E+4|0]|0;break};case 260:{c[7072+(b<<2)>>2]=10;c[235736+(b<<2)>>2]=260;jW(w,39592);jX(12,w);jW(x,35184);jX(13,x);jW(y,95864);E=y|0;F=a[E]|0;G=E+1|0;E=g|0;a[E]=a[G]|0;a[E+1|0]=a[G+1|0]|0;a[E+2|0]=a[G+2|0]|0;a[E+3|0]=a[G+3|0]|0;a[E+4|0]=a[G+4|0]|0;if(((F&255)-1|0)>>>0<4){if((c[59655]|0)==34){c[59655]=-1}if((c[59660]|0)==34){c[59660]=-1}if((c[42374]|0)==34){c[42374]=-1}if((c[127398]|0)==34){c[127398]=-1}if((c[127396]|0)==34){c[127396]=-1}a[503644]=F;a[503645|0]=a[E]|0;a[503646|0]=a[E+1|0]|0;a[503647|0]=a[E+2|0]|0;a[503648|0]=a[E+3|0]|0;a[503649|0]=a[E+4|0]|0}jW(z,91728);E=z|0;F=a[E]|0;G=E+1|0;E=j|0;a[E]=a[G]|0;a[E+1|0]=a[G+1|0]|0;a[E+2|0]=a[G+2|0]|0;a[E+3|0]=a[G+3|0]|0;a[E+4|0]=a[G+4|0]|0;if(((F&255)-1|0)>>>0<4){if((c[59655]|0)==35){c[59655]=-1}if((c[59660]|0)==35){c[59660]=-1}if((c[42374]|0)==35){c[42374]=-1}if((c[127398]|0)==35){c[127398]=-1}if((c[127396]|0)==35){c[127396]=-1}a[503650]=F;a[503651|0]=a[E]|0;a[503652|0]=a[E+1|0]|0;a[503653|0]=a[E+2|0]|0;a[503654|0]=a[E+3|0]|0;a[503655|0]=a[E+4|0]|0}jW(A,88232);E=A|0;F=a[E]|0;G=E+1|0;E=l|0;a[E]=a[G]|0;a[E+1|0]=a[G+1|0]|0;a[E+2|0]=a[G+2|0]|0;a[E+3|0]=a[G+3|0]|0;a[E+4|0]=a[G+4|0]|0;if(((F&255)-1|0)>>>0<4){if((c[59655]|0)==36){c[59655]=-1}if((c[59660]|0)==36){c[59660]=-1}if((c[42374]|0)==36){c[42374]=-1}if((c[127398]|0)==36){c[127398]=-1}if((c[127396]|0)==36){c[127396]=-1}a[503656]=F;a[503657|0]=a[E]|0;a[503658|0]=a[E+1|0]|0;a[503659|0]=a[E+2|0]|0;a[503660|0]=a[E+3|0]|0;a[503661|0]=a[E+4|0]|0}jW(B,85088);E=B|0;F=a[E]|0;G=E+1|0;E=m|0;a[E]=a[G]|0;a[E+1|0]=a[G+1|0]|0;a[E+2|0]=a[G+2|0]|0;a[E+3|0]=a[G+3|0]|0;a[E+4|0]=a[G+4|0]|0;if(((F&255)-1|0)>>>0>=4){break L6866}if((c[59655]|0)==37){c[59655]=-1}if((c[59660]|0)==37){c[59660]=-1}if((c[42374]|0)==37){c[42374]=-1}if((c[127398]|0)==37){c[127398]=-1}if((c[127396]|0)==37){c[127396]=-1}a[503662]=F;a[503663|0]=a[E]|0;a[503664|0]=a[E+1|0]|0;a[503665|0]=a[E+2|0]|0;a[503666|0]=a[E+3|0]|0;a[503667|0]=a[E+4|0]|0;break};default:{a2(74984,28,1,c[p>>2]|0)|0}}}while(0);m=c[58934]|0;B=c[58935]|0;l=(B|0)==1;if(!((m|0)==1&(l|(B|0)==257)|(m|0)==257&l)){i=e;return}a[807392]=1;i=e;return}function XK(){var f=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bJ=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0,bQ=0,bR=0,bS=0,bT=0.0,bU=0,bV=0,bW=0,bX=0,bY=0,bZ=0,b_=0,b$=0,b0=0,b1=0,b2=0,b3=0,b4=0,b5=0,b6=0,b7=0,b8=0,b9=0,ca=0,cb=0,cc=0,ce=0,cf=0,cg=0,ch=0,ci=0,cj=0,ck=0,cl=0;f=i;i=i+968|0;h=f|0;j=f+8|0;k=f+16|0;l=f+24|0;m=f+32|0;n=f+40|0;o=f+48|0;q=f+56|0;r=f+64|0;s=f+72|0;t=f+80|0;u=f+88|0;v=f+96|0;w=f+104|0;x=f+112|0;y=f+120|0;z=f+128|0;A=f+136|0;B=f+144|0;C=f+152|0;D=f+160|0;E=f+168|0;F=f+176|0;G=f+184|0;H=f+192|0;I=f+200|0;J=f+208|0;K=f+216|0;L=f+224|0;M=f+232|0;N=f+240|0;O=f+248|0;P=f+256|0;Q=f+264|0;R=f+272|0;S=f+280|0;T=f+288|0;U=f+296|0;V=f+304|0;W=f+312|0;X=f+320|0;Y=f+328|0;Z=f+336|0;_=f+344|0;$=f+352|0;aa=f+360|0;ac=f+368|0;ad=f+376|0;ae=f+384|0;af=f+392|0;ag=f+400|0;ah=f+408|0;ai=f+416|0;aj=f+424|0;ak=f+432|0;al=f+440|0;am=f+448|0;an=f+456|0;ao=f+464|0;ap=f+472|0;aq=f+480|0;ar=f+488|0;as=f+496|0;at=f+504|0;au=f+512|0;av=f+520|0;aw=f+528|0;ax=f+536|0;ay=f+544|0;az=f+552|0;aA=f+560|0;aB=f+568|0;aC=f+576|0;aD=f+584|0;aE=f+592|0;aF=f+600|0;aG=f+608|0;aH=f+616|0;aI=f+624|0;aJ=f+632|0;aK=f+640|0;aL=f+648|0;aM=f+656|0;aN=f+664|0;aO=f+672|0;aP=f+680|0;aQ=f+688|0;aR=f+696|0;aS=f+704|0;aT=f+712|0;aU=f+720|0;aV=f+728|0;aW=f+736|0;aX=f+744|0;aY=f+752|0;aZ=f+760|0;a_=f+768|0;a$=f+776|0;a0=f+784|0;a1=f+792|0;a3=f+800|0;a4=f+808|0;a5=f+816|0;a6=f+824|0;a7=f+832|0;a8=f+840|0;a9=f+848|0;ba=f+856|0;bb=f+864|0;bc=f+872|0;bd=f+880|0;be=f+888|0;bf=f+896|0;bg=f+904|0;bh=f+912|0;bi=f+920|0;bj=f+928|0;bk=f+936|0;bl=f+944|0;bm=f+952|0;bn=f+960|0;if(!(ft[c[198896]&63](2,169480)|0)){a[169480]=0}c[bn>>2]=2;if(ft[c[198896]&63](10,bn)|0){bn=c[p>>2]|0;a2(71912,62,1,bn|0)|0}X2(799120,0,8280);a[807394]=1;c[199787]=2e4;c[199788]=16667;c[199790]=32e3;c[199791]=32e3;c[201842]=100;a[807364]=1;a[799169]=0;a[803266]=0;c[201844]=1;c[348395]=0;bn=XY(131072)|0;c[263191]=bn;bo=XY(131072)|0;c[263193]=bo;bp=XY(65536)|0;c[263194]=bp;bq=XY(8421888)|0;c[263192]=bq;br=XY(262144)|0;c[276523]=br;bs=XY(131072)|0;c[276524]=bs;bt=XY(65536)|0;c[276525]=bt;bu=XY(262144)|0;c[276526]=bu;bv=XY(262144)|0;c[276527]=bv;bw=XY(131072)|0;c[276528]=bw;bx=XY(131072)|0;c[276529]=bx;by=XY(4096)|0;c[276530]=by;bz=XY(2048)|0;c[276531]=bz;bA=XY(1024)|0;c[276532]=bA;bB=XY(4096)|0;c[276533]=bB;bC=XY(4096)|0;c[276534]=bC;bD=XY(2048)|0;c[276535]=bD;bE=XY(2048)|0;c[276536]=bE;a[1041770]=1;a[1044495]=1;a[17264]=1;if(!((bn|0)!=0&(bo|0)!=0&(bp|0)!=0&(bq|0)!=0&(br|0)!=0&(bs|0)!=0&(bt|0)!=0&(bu|0)!=0&(bv|0)!=0&(bw|0)!=0&(bx|0)!=0&(by|0)!=0&(bz|0)!=0&(bA|0)!=0&(bB|0)!=0&(bC|0)!=0&(bD|0)!=0&(bE|0)!=0)){Hn();Hn();if(a[5704]|0){XZ(c[59010]|0);a[5704]=0}bF=c[125858]|0;if((bF|0)==0){bG=c[p>>2]|0;bH=a2(56072,42,1,bG|0)|0;cd(1)}XZ(bF);c[125858]=0;bG=c[p>>2]|0;bH=a2(56072,42,1,bG|0)|0;cd(1)}X2(bn|0,0,131072);X2(bo|0,0,131072);X2(bp|0,0,65536);X2(bq|0,0,8421888);X2(br|0,0,262144);X2(bs|0,0,131072);X2(bt|0,0,65536);X2(bu|0,0,262144);X2(bv|0,0,262144);X2(bw|0,0,131072);X2(bx|0,0,131072);X2(by|0,0,4096);X2(bz|0,0,2048);X2(bA|0,0,1024);X2(bB|0,0,4096);X2(bC|0,0,4096);X2(bD|0,0,2048);X2(bE|0,0,2048);c[263195]=bq;bE=bq+32768|0;c[263192]=bE;c[263197]=bq+4292608;bD=bq+4227072|0;c[263198]=bD;c[263200]=bq+3178496;c[263199]=bD;c[199766]=bq+12288;a[101720]=1;c[199764]=bo;c[199762]=64;c[199760]=bE;X2(436792,0,66624);c[199289]=437624;c[199292]=797172;c[199290]=797172;c[199291]=797204;X5(795648,15488,128)|0;c[199281]=1;c[199283]=128;c[199282]=795760;c[199246]=1;c[199248]=64;c[199247]=795744;c[199211]=1;c[199213]=32;c[199212]=795728;c[199176]=1;c[199178]=16;c[199177]=795712;c[199141]=1;c[199143]=8;c[199142]=795696;c[199106]=1;c[199108]=4;c[199107]=795680;c[199071]=1;c[199073]=2;c[199072]=795664;c[199036]=1;c[199038]=1;c[199037]=795648;c[198984]=209;c[198989]=78;c[198996]=96;c[198979]=16384;c[198976]=795776;c[198977]=1;c[198981]=0;c[198983]=0;c[198980]=0;c[109232]=256;a[437046]=-1;a[437047]=-64;bE=0;do{bo=a[15616+bE|0]|0;bq=bE<<1;a[437112+bq|0]=(bo&255)>>>4;a[437112+(bq|1)|0]=bo&15;bE=bE+1|0;}while((bE|0)<128);a[798240]=0;c[199302]=436984;c[199303]=437048;X5(235744,5752,256)|0;jC();X5(436984,160824,64)|0;c[125858]=0;a[17360]=1;c2(70896,(bE=i,i=i+16|0,c[bE>>2]=2048,c[bE+8>>2]=512,bE)|0)|0;i=bE;bE=c[125858]|0;if((bE|0)!=0){XZ(bE)}bE=a[17360]|0?2048:0;bo=XY(bE<<1)|0;bq=bo;c[125858]=bq;if((bo|0)!=0){if(a[5704]|0){XZ(c[59010]|0);bo=c[59006]|0;c[59008]=bo;bD=XY(bo)|0;c[59010]=bD;X2(bD|0,0,bo|0);c[59006]=0;c[59004]=0;bI=c[125858]|0;bJ=a[17360]|0?2048:0;bK=bD}else{bD=bE>>>(((a[799120]|0)==0|0)>>>0)<<1;c[59008]=bD;bo=XY(bD)|0;c[59010]=bo;X2(bo|0,0,bD|0);c[59004]=0;c[59006]=0;X2(bo|0,0,bD|0);c[59356]=65536;c[59348]=0;c[59350]=0;c[59352]=0;c[59354]=0;c[59340]=0;c[59342]=0;c[59344]=0;c[59346]=0;a[5704]=1;bI=bq;bJ=bE;bK=bo}c[109233]=c[109233]&31;bo=bJ>>>1;bJ=bI+(bo<<1)|0;c[109234]=bI;c[109235]=bJ;bE=c[109236]|0;bq=(bo|0)!=0;if(bE>>>0>436948>>>0&bq){bo=bI;bD=436948;while(1){bC=bD+2|0;bB=bo+2|0;b[bo>>1]=b[bD>>1]|0;bA=c[109236]|0;bz=bB>>>0<bJ>>>0;if(bC>>>0<bA>>>0&bz){bo=bB;bD=bC}else{bL=bB;bM=bC;bN=bz;bO=bA;break}}}else{bL=bI;bM=436948;bN=bq;bO=bE}do{if(bN){bP=bJ;bQ=bL}else{if(bM>>>0<bO>>>0){bR=797172;bS=bM}else{bP=797204;bQ=797172;break}while(1){bE=bS+2|0;bq=bR+2|0;b[bR>>1]=b[bS>>1]|0;if(bE>>>0<(c[109236]|0)>>>0){bR=bq;bS=bE}else{bP=797204;bQ=bq;break}}}}while(0);bS=(bQ|0)==0;bR=bS?797172:bQ;c[199292]=bR;c[199290]=bR;c[199291]=bR+((bS?16:bP-bQ>>1)<<1);bQ=c[199791]|0;if((bQ|0)==0){c[199791]=32e3;bT=8192.0e3}else{bT=+(bQ>>>0>>>0)*256.0}c[59338]=~~(bT/+((ab(c[202]|0,c[199790]|0)|0)>>>0>>>0)*65536.0);c[59004]=0;c[59006]=0;X2(bK|0,0,c[59008]|0);c[59356]=65536;c[59348]=0;c[59350]=0;c[59352]=0;c[59354]=0;c[59340]=0;c[59342]=0;c[59344]=0;c[59346]=0}bK=(a[169480]&1)!=0?1024:2048;c[277216]=bK;bQ=bK<<10;bK=XY(bQ)|0;do{if((bK|0)!=0){if((c[bK-4>>2]&3|0)==0){break}X2(bK|0,0,bQ|0)}}while(0);c[277212]=bK;bK=0;while(1){bQ=bK>>>3&1;bP=(bK&4|0)==0?bQ:bQ|256;bQ=(bK&2|0)==0?bP:bP|65536;bP=(bK&1|0)==0?bQ:bQ|16777216;c[238048+(bK<<2)>>2]=bP;c[238112+(bK<<2)>>2]=bP<<1;c[238176+(bK<<2)>>2]=bP<<2;c[238240+(bK<<2)>>2]=bP<<3;c[238304+(bK<<2)>>2]=bP<<4;c[238368+(bK<<2)>>2]=bP<<5;c[238432+(bK<<2)>>2]=bP<<6;c[238496+(bK<<2)>>2]=bP<<7;bP=bK+1|0;if((bP|0)<16){bK=bP}else{bU=0;break}}do{bK=(bU&128|0)==0?0:8;bP=(bU&64|0)==0?0:8;bQ=(bU&32|0)==0?bK:bK|4;bK=(bU&16|0)==0?bP:bP|4;a[509672+bU|0]=((bU&4|0)==0?bK:bK|2)|bU&1;a[509928+bU|0]=((bU&8|0)==0?bQ:bQ|2)|bU>>>1&1;bU=bU+1|0;}while((bU|0)<256);a[1108916]=0;a[1108917]=0;bU=(c[277216]|0)>>>1;c[277222]=bU;a[1106088]=1;a[1106089]=1;bQ=7080+(d[1044485]<<5)|0;c[276541]=bQ;bK=0;bP=bQ;while(1){bQ=e[1041774+(bK<<1)>>1]|0;b[1106168+(bK<<1)>>1]=d[bP+(bQ>>>5&31)|0]<<6|d[bP+(bQ&31)|0]<<11|d[bP+(bQ>>>10&31)|0];bQ=bK+1|0;if((bQ|0)>=256){break}bK=bQ;bP=c[276541]|0}bP=XY(131072)|0;c[277220]=bP;bK=XY(131072)|0;c[277221]=bK;bQ=bU*478|0;c[277217]=bQ;bS=XY(bU*956|0)|0;c[277213]=bS;bU=XY(bQ)|0;c[277214]=bU;bR=XY(bQ)|0;c[277215]=bR;if((bP|0)!=0&(bK|0)!=0&(bS|0)!=0&(bU|0)!=0&(bR|0)!=0){X2(bP|0,0,131072);bP=0;do{bR=bP<<1>>>0>31?63488:bP<<12;bU=bP<<11;bS=0;do{bK=(bS<<1>>>0>63?2016:bS<<6)|bR;bQ=bS<<5|bU;bM=0;do{bO=bM<<1;bL=(bK|(bO>>>0>31?31:bO))&65535;bO=bQ|bM;b[(c[277220]|0)+(bO<<1)>>1]=bL;b[(c[277220]|0)+(bO<<1)>>1]=bL;bM=bM+1|0;}while(bM>>>0<32);bS=bS+1|0;}while(bS>>>0<64);bP=bP+1|0;}while(bP>>>0<32);X2(c[277221]|0,0,131072);bP=0;do{bS=bP<<11;bU=(bP&16|0)==0?0:bS&30720;bR=0;do{bM=bR<<5;bQ=((bR&32|0)==0?0:bM&64480)|bU;bK=bM|bS;bM=0;do{bL=(bQ|((bM&16|0)==0?0:bM&65519))&65535;bO=bK|bM;b[(c[277221]|0)+(bO<<1)>>1]=bL;b[(c[277221]|0)+(bO<<1)>>1]=bL;bM=bM+1|0;}while(bM>>>0<32);bR=bR+1|0;}while(bR>>>0<64);bP=bP+1|0;}while(bP>>>0<32);a[797440]=0;a[797441]=1;a[797442]=0;a[797443]=1;a[797444]=0;a[797445]=1;a[797446]=0;a[797447]=1;a[797456]=0;a[797457]=1;a[797458]=16;a[797459]=17;a[797460]=0;a[797461]=1;a[797462]=16;a[797463]=17;a[797488]=0;a[797489]=1;a[797490]=16;a[797491]=17;a[797492]=32;a[797493]=33;a[797494]=48;a[797495]=49}else{Hx()}c[1768]=0;c[58934]=1;c[1769]=1;c[58935]=1;jV();bP=aq|0;bR=ar|0;bS=as|0;bU=at|0;bM=au|0;bK=av|0;bQ=aw|0;bL=ax|0;bO=ay|0;bJ=az|0;bN=aA|0;bq=aB|0;bE=aC|0;bI=aD|0;bD=aE|0;bo=aF|0;bA=aG|0;bz=aH|0;bC=aI|0;bB=aJ|0;by=aK|0;bx=aL|0;bw=aM|0;bv=aN|0;bu=aO|0;bt=aP|0;bs=aQ|0;br=aR|0;bp=aS|0;bn=aT|0;bG=aU|0;bH=aV|0;bF=aW|0;bV=aX|0;bW=aY|0;bX=aZ|0;bY=a_|0;bZ=a$|0;b_=a0|0;b$=a1|0;b0=a3|0;b1=a4|0;b2=a5|0;b3=a6|0;b4=a7|0;b5=a8|0;b6=a9|0;b7=ba|0;b8=bb|0;b9=bc|0;ca=bd|0;cb=be|0;cc=bf|0;ce=bg|0;cf=bh|0;cg=bi|0;ch=bj|0;ci=bk|0;cj=bl|0;ck=bm|0;jW(aq,54864);aq=a[bP]|0;cl=bP+1|0;bP=ap|0;a[bP]=a[cl]|0;a[bP+1|0]=a[cl+1|0]|0;a[bP+2|0]=a[cl+2|0]|0;a[bP+3|0]=a[cl+3|0]|0;a[bP+4|0]=a[cl+4|0]|0;if(((aq&255)-1|0)>>>0<4){if((c[59655]|0)==24){c[59655]=-1}if((c[59660]|0)==24){c[59660]=-1}if((c[42374]|0)==24){c[42374]=-1}if((c[127398]|0)==24){c[127398]=-1}if((c[127396]|0)==24){c[127396]=-1}a[503584]=aq;a[503585|0]=a[bP]|0;a[503586|0]=a[bP+1|0]|0;a[503587|0]=a[bP+2|0]|0;a[503588|0]=a[bP+3|0]|0;a[503589|0]=a[bP+4|0]|0}jW(ar,53976);ar=a[bR]|0;bP=bR+1|0;bR=an|0;a[bR]=a[bP]|0;a[bR+1|0]=a[bP+1|0]|0;a[bR+2|0]=a[bP+2|0]|0;a[bR+3|0]=a[bP+3|0]|0;a[bR+4|0]=a[bP+4|0]|0;if(((ar&255)-1|0)>>>0<4){if((c[59655]|0)==16){c[59655]=-1}if((c[59660]|0)==16){c[59660]=-1}if((c[42374]|0)==16){c[42374]=-1}if((c[127398]|0)==16){c[127398]=-1}if((c[127396]|0)==16){c[127396]=-1}a[503536]=ar;a[503537|0]=a[bR]|0;a[503538|0]=a[bR+1|0]|0;a[503539|0]=a[bR+2|0]|0;a[503540|0]=a[bR+3|0]|0;a[503541|0]=a[bR+4|0]|0}jW(as,53080);as=a[bS]|0;bR=bS+1|0;bS=al|0;a[bS]=a[bR]|0;a[bS+1|0]=a[bR+1|0]|0;a[bS+2|0]=a[bR+2|0]|0;a[bS+3|0]=a[bR+3|0]|0;a[bS+4|0]=a[bR+4|0]|0;if(((as&255)-1|0)>>>0<4){if((c[59655]|0)==25){c[59655]=-1}if((c[59660]|0)==25){c[59660]=-1}if((c[42374]|0)==25){c[42374]=-1}if((c[127398]|0)==25){c[127398]=-1}if((c[127396]|0)==25){c[127396]=-1}a[503590]=as;a[503591|0]=a[bS]|0;a[503592|0]=a[bS+1|0]|0;a[503593|0]=a[bS+2|0]|0;a[503594|0]=a[bS+3|0]|0;a[503595|0]=a[bS+4|0]|0}jW(at,52240);at=a[bU]|0;bS=bU+1|0;bU=aj|0;a[bU]=a[bS]|0;a[bU+1|0]=a[bS+1|0]|0;a[bU+2|0]=a[bS+2|0]|0;a[bU+3|0]=a[bS+3|0]|0;a[bU+4|0]=a[bS+4|0]|0;if(((at&255)-1|0)>>>0<4){if((c[59655]|0)==17){c[59655]=-1}if((c[59660]|0)==17){c[59660]=-1}if((c[42374]|0)==17){c[42374]=-1}if((c[127398]|0)==17){c[127398]=-1}if((c[127396]|0)==17){c[127396]=-1}a[503542]=at;a[503543|0]=a[bU]|0;a[503544|0]=a[bU+1|0]|0;a[503545|0]=a[bU+2|0]|0;a[503546|0]=a[bU+3|0]|0;a[503547|0]=a[bU+4|0]|0}jW(au,51352);au=a[bM]|0;bU=bM+1|0;bM=ah|0;a[bM]=a[bU]|0;a[bM+1|0]=a[bU+1|0]|0;a[bM+2|0]=a[bU+2|0]|0;a[bM+3|0]=a[bU+3|0]|0;a[bM+4|0]=a[bU+4|0]|0;if(((au&255)-1|0)>>>0<4){if((c[59655]|0)==18){c[59655]=-1}if((c[59660]|0)==18){c[59660]=-1}if((c[42374]|0)==18){c[42374]=-1}if((c[127398]|0)==18){c[127398]=-1}if((c[127396]|0)==18){c[127396]=-1}a[503548]=au;a[503549|0]=a[bM]|0;a[503550|0]=a[bM+1|0]|0;a[503551|0]=a[bM+2|0]|0;a[503552|0]=a[bM+3|0]|0;a[503553|0]=a[bM+4|0]|0}jW(av,50480);av=a[bK]|0;bM=bK+1|0;bK=af|0;a[bK]=a[bM]|0;a[bK+1|0]=a[bM+1|0]|0;a[bK+2|0]=a[bM+2|0]|0;a[bK+3|0]=a[bM+3|0]|0;a[bK+4|0]=a[bM+4|0]|0;if(((av&255)-1|0)>>>0<4){if((c[59655]|0)==19){c[59655]=-1}if((c[59660]|0)==19){c[59660]=-1}if((c[42374]|0)==19){c[42374]=-1}if((c[127398]|0)==19){c[127398]=-1}if((c[127396]|0)==19){c[127396]=-1}a[503554]=av;a[503555|0]=a[bK]|0;a[503556|0]=a[bK+1|0]|0;a[503557|0]=a[bK+2|0]|0;a[503558|0]=a[bK+3|0]|0;a[503559|0]=a[bK+4|0]|0}jW(aw,49856);aw=a[bQ]|0;bK=bQ+1|0;bQ=ad|0;a[bQ]=a[bK]|0;a[bQ+1|0]=a[bK+1|0]|0;a[bQ+2|0]=a[bK+2|0]|0;a[bQ+3|0]=a[bK+3|0]|0;a[bQ+4|0]=a[bK+4|0]|0;if(((aw&255)-1|0)>>>0<4){if((c[59655]|0)==26){c[59655]=-1}if((c[59660]|0)==26){c[59660]=-1}if((c[42374]|0)==26){c[42374]=-1}if((c[127398]|0)==26){c[127398]=-1}if((c[127396]|0)==26){c[127396]=-1}a[503596]=aw;a[503597|0]=a[bQ]|0;a[503598|0]=a[bQ+1|0]|0;a[503599|0]=a[bQ+2|0]|0;a[503600|0]=a[bQ+3|0]|0;a[503601|0]=a[bQ+4|0]|0}jW(ax,48832);ax=a[bL]|0;bQ=bL+1|0;bL=aa|0;a[bL]=a[bQ]|0;a[bL+1|0]=a[bQ+1|0]|0;a[bL+2|0]=a[bQ+2|0]|0;a[bL+3|0]=a[bQ+3|0]|0;a[bL+4|0]=a[bQ+4|0]|0;if(((ax&255)-1|0)>>>0<4){if((c[59655]|0)==27){c[59655]=-1}if((c[59660]|0)==27){c[59660]=-1}if((c[42374]|0)==27){c[42374]=-1}if((c[127398]|0)==27){c[127398]=-1}if((c[127396]|0)==27){c[127396]=-1}a[503602]=ax;a[503603|0]=a[bL]|0;a[503604|0]=a[bL+1|0]|0;a[503605|0]=a[bL+2|0]|0;a[503606|0]=a[bL+3|0]|0;a[503607|0]=a[bL+4|0]|0}jW(ay,47928);ay=a[bO]|0;bL=bO+1|0;bO=_|0;a[bO]=a[bL]|0;a[bO+1|0]=a[bL+1|0]|0;a[bO+2|0]=a[bL+2|0]|0;a[bO+3|0]=a[bL+3|0]|0;a[bO+4|0]=a[bL+4|0]|0;if(((ay&255)-1|0)>>>0<4){if((c[59655]|0)==22){c[59655]=-1}if((c[59660]|0)==22){c[59660]=-1}if((c[42374]|0)==22){c[42374]=-1}if((c[127398]|0)==22){c[127398]=-1}if((c[127396]|0)==22){c[127396]=-1}a[503572]=ay;a[503573|0]=a[bO]|0;a[503574|0]=a[bO+1|0]|0;a[503575|0]=a[bO+2|0]|0;a[503576|0]=a[bO+3|0]|0;a[503577|0]=a[bO+4|0]|0}jW(az,46840);az=a[bJ]|0;bO=bJ+1|0;bJ=Y|0;a[bJ]=a[bO]|0;a[bJ+1|0]=a[bO+1|0]|0;a[bJ+2|0]=a[bO+2|0]|0;a[bJ+3|0]=a[bO+3|0]|0;a[bJ+4|0]=a[bO+4|0]|0;if(((az&255)-1|0)>>>0<4){if((c[59655]|0)==23){c[59655]=-1}if((c[59660]|0)==23){c[59660]=-1}if((c[42374]|0)==23){c[42374]=-1}if((c[127398]|0)==23){c[127398]=-1}if((c[127396]|0)==23){c[127396]=-1}a[503578]=az;a[503579|0]=a[bJ]|0;a[503580|0]=a[bJ+1|0]|0;a[503581|0]=a[bJ+2|0]|0;a[503582|0]=a[bJ+3|0]|0;a[503583|0]=a[bJ+4|0]|0}jW(aA,45576);aA=a[bN]|0;bJ=bN+1|0;bN=W|0;a[bN]=a[bJ]|0;a[bN+1|0]=a[bJ+1|0]|0;a[bN+2|0]=a[bJ+2|0]|0;a[bN+3|0]=a[bJ+3|0]|0;a[bN+4|0]=a[bJ+4|0]|0;if(((aA&255)-1|0)>>>0<4){if((c[59655]|0)==20){c[59655]=-1}if((c[59660]|0)==20){c[59660]=-1}if((c[42374]|0)==20){c[42374]=-1}if((c[127398]|0)==20){c[127398]=-1}if((c[127396]|0)==20){c[127396]=-1}a[503560]=aA;a[503561|0]=a[bN]|0;a[503562|0]=a[bN+1|0]|0;a[503563|0]=a[bN+2|0]|0;a[503564|0]=a[bN+3|0]|0;a[503565|0]=a[bN+4|0]|0}jW(aB,44952);aB=a[bq]|0;bN=bq+1|0;bq=U|0;a[bq]=a[bN]|0;a[bq+1|0]=a[bN+1|0]|0;a[bq+2|0]=a[bN+2|0]|0;a[bq+3|0]=a[bN+3|0]|0;a[bq+4|0]=a[bN+4|0]|0;if(((aB&255)-1|0)>>>0<4){if((c[59655]|0)==21){c[59655]=-1}if((c[59660]|0)==21){c[59660]=-1}if((c[42374]|0)==21){c[42374]=-1}if((c[127398]|0)==21){c[127398]=-1}if((c[127396]|0)==21){c[127396]=-1}a[503566]=aB;a[503567|0]=a[bq]|0;a[503568|0]=a[bq+1|0]|0;a[503569|0]=a[bq+2|0]|0;a[503570|0]=a[bq+3|0]|0;a[503571|0]=a[bq+4|0]|0}jW(aC,44384);aC=a[bE]|0;bq=bE+1|0;bE=S|0;a[bE]=a[bq]|0;a[bE+1|0]=a[bq+1|0]|0;a[bE+2|0]=a[bq+2|0]|0;a[bE+3|0]=a[bq+3|0]|0;a[bE+4|0]=a[bq+4|0]|0;if(((aC&255)-1|0)>>>0<4){if((c[59655]|0)==40){c[59655]=-1}if((c[59660]|0)==40){c[59660]=-1}if((c[42374]|0)==40){c[42374]=-1}if((c[127398]|0)==40){c[127398]=-1}if((c[127396]|0)==40){c[127396]=-1}a[503680]=aC;a[503681|0]=a[bE]|0;a[503682|0]=a[bE+1|0]|0;a[503683|0]=a[bE+2|0]|0;a[503684|0]=a[bE+3|0]|0;a[503685|0]=a[bE+4|0]|0}jW(aD,43632);aD=a[bI]|0;bE=bI+1|0;bI=Q|0;a[bI]=a[bE]|0;a[bI+1|0]=a[bE+1|0]|0;a[bI+2|0]=a[bE+2|0]|0;a[bI+3|0]=a[bE+3|0]|0;a[bI+4|0]=a[bE+4|0]|0;if(((aD&255)-1|0)>>>0<4){if((c[59655]|0)==32){c[59655]=-1}if((c[59660]|0)==32){c[59660]=-1}if((c[42374]|0)==32){c[42374]=-1}if((c[127398]|0)==32){c[127398]=-1}if((c[127396]|0)==32){c[127396]=-1}a[503632]=aD;a[503633|0]=a[bI]|0;a[503634|0]=a[bI+1|0]|0;a[503635|0]=a[bI+2|0]|0;a[503636|0]=a[bI+3|0]|0;a[503637|0]=a[bI+4|0]|0}jW(aE,42880);aE=a[bD]|0;bI=bD+1|0;bD=O|0;a[bD]=a[bI]|0;a[bD+1|0]=a[bI+1|0]|0;a[bD+2|0]=a[bI+2|0]|0;a[bD+3|0]=a[bI+3|0]|0;a[bD+4|0]=a[bI+4|0]|0;if(((aE&255)-1|0)>>>0<4){if((c[59655]|0)==41){c[59655]=-1}if((c[59660]|0)==41){c[59660]=-1}if((c[42374]|0)==41){c[42374]=-1}if((c[127398]|0)==41){c[127398]=-1}if((c[127396]|0)==41){c[127396]=-1}a[503686]=aE;a[503687|0]=a[bD]|0;a[503688|0]=a[bD+1|0]|0;a[503689|0]=a[bD+2|0]|0;a[503690|0]=a[bD+3|0]|0;a[503691|0]=a[bD+4|0]|0}jW(aF,42256);aF=a[bo]|0;bD=bo+1|0;bo=M|0;a[bo]=a[bD]|0;a[bo+1|0]=a[bD+1|0]|0;a[bo+2|0]=a[bD+2|0]|0;a[bo+3|0]=a[bD+3|0]|0;a[bo+4|0]=a[bD+4|0]|0;if(((aF&255)-1|0)>>>0<4){if((c[59655]|0)==33){c[59655]=-1}if((c[59660]|0)==33){c[59660]=-1}if((c[42374]|0)==33){c[42374]=-1}if((c[127398]|0)==33){c[127398]=-1}if((c[127396]|0)==33){c[127396]=-1}a[503638]=aF;a[503639|0]=a[bo]|0;a[503640|0]=a[bo+1|0]|0;a[503641|0]=a[bo+2|0]|0;a[503642|0]=a[bo+3|0]|0;a[503643|0]=a[bo+4|0]|0}jW(aG,41616);aG=a[bA]|0;bo=bA+1|0;bA=K|0;a[bA]=a[bo]|0;a[bA+1|0]=a[bo+1|0]|0;a[bA+2|0]=a[bo+2|0]|0;a[bA+3|0]=a[bo+3|0]|0;a[bA+4|0]=a[bo+4|0]|0;if(((aG&255)-1|0)>>>0<4){if((c[59655]|0)==34){c[59655]=-1}if((c[59660]|0)==34){c[59660]=-1}if((c[42374]|0)==34){c[42374]=-1}if((c[127398]|0)==34){c[127398]=-1}if((c[127396]|0)==34){c[127396]=-1}a[503644]=aG;a[503645|0]=a[bA]|0;a[503646|0]=a[bA+1|0]|0;a[503647|0]=a[bA+2|0]|0;a[503648|0]=a[bA+3|0]|0;a[503649|0]=a[bA+4|0]|0}jW(aH,41264);aH=a[bz]|0;bA=bz+1|0;bz=I|0;a[bz]=a[bA]|0;a[bz+1|0]=a[bA+1|0]|0;a[bz+2|0]=a[bA+2|0]|0;a[bz+3|0]=a[bA+3|0]|0;a[bz+4|0]=a[bA+4|0]|0;if(((aH&255)-1|0)>>>0<4){if((c[59655]|0)==35){c[59655]=-1}if((c[59660]|0)==35){c[59660]=-1}if((c[42374]|0)==35){c[42374]=-1}if((c[127398]|0)==35){c[127398]=-1}if((c[127396]|0)==35){c[127396]=-1}a[503650]=aH;a[503651|0]=a[bz]|0;a[503652|0]=a[bz+1|0]|0;a[503653|0]=a[bz+2|0]|0;a[503654|0]=a[bz+3|0]|0;a[503655|0]=a[bz+4|0]|0}jW(aI,40760);aI=a[bC]|0;bz=bC+1|0;bC=G|0;a[bC]=a[bz]|0;a[bC+1|0]=a[bz+1|0]|0;a[bC+2|0]=a[bz+2|0]|0;a[bC+3|0]=a[bz+3|0]|0;a[bC+4|0]=a[bz+4|0]|0;if(((aI&255)-1|0)>>>0<4){if((c[59655]|0)==42){c[59655]=-1}if((c[59660]|0)==42){c[59660]=-1}if((c[42374]|0)==42){c[42374]=-1}if((c[127398]|0)==42){c[127398]=-1}if((c[127396]|0)==42){c[127396]=-1}a[503692]=aI;a[503693|0]=a[bC]|0;a[503694|0]=a[bC+1|0]|0;a[503695|0]=a[bC+2|0]|0;a[503696|0]=a[bC+3|0]|0;a[503697|0]=a[bC+4|0]|0}jW(aJ,40112);aJ=a[bB]|0;bC=bB+1|0;bB=E|0;a[bB]=a[bC]|0;a[bB+1|0]=a[bC+1|0]|0;a[bB+2|0]=a[bC+2|0]|0;a[bB+3|0]=a[bC+3|0]|0;a[bB+4|0]=a[bC+4|0]|0;if(((aJ&255)-1|0)>>>0<4){if((c[59655]|0)==43){c[59655]=-1}if((c[59660]|0)==43){c[59660]=-1}if((c[42374]|0)==43){c[42374]=-1}if((c[127398]|0)==43){c[127398]=-1}if((c[127396]|0)==43){c[127396]=-1}a[503698]=aJ;a[503699|0]=a[bB]|0;a[503700|0]=a[bB+1|0]|0;a[503701|0]=a[bB+2|0]|0;a[503702|0]=a[bB+3|0]|0;a[503703|0]=a[bB+4|0]|0}jW(aK,39208);aK=a[by]|0;bB=by+1|0;by=C|0;a[by]=a[bB]|0;a[by+1|0]=a[bB+1|0]|0;a[by+2|0]=a[bB+2|0]|0;a[by+3|0]=a[bB+3|0]|0;a[by+4|0]=a[bB+4|0]|0;if(((aK&255)-1|0)>>>0<4){if((c[59655]|0)==38){c[59655]=-1}if((c[59660]|0)==38){c[59660]=-1}if((c[42374]|0)==38){c[42374]=-1}if((c[127398]|0)==38){c[127398]=-1}if((c[127396]|0)==38){c[127396]=-1}a[503668]=aK;a[503669|0]=a[by]|0;a[503670|0]=a[by+1|0]|0;a[503671|0]=a[by+2|0]|0;a[503672|0]=a[by+3|0]|0;a[503673|0]=a[by+4|0]|0}jW(aL,38632);aL=a[bx]|0;by=bx+1|0;bx=A|0;a[bx]=a[by]|0;a[bx+1|0]=a[by+1|0]|0;a[bx+2|0]=a[by+2|0]|0;a[bx+3|0]=a[by+3|0]|0;a[bx+4|0]=a[by+4|0]|0;if(((aL&255)-1|0)>>>0<4){if((c[59655]|0)==39){c[59655]=-1}if((c[59660]|0)==39){c[59660]=-1}if((c[42374]|0)==39){c[42374]=-1}if((c[127398]|0)==39){c[127398]=-1}if((c[127396]|0)==39){c[127396]=-1}a[503674]=aL;a[503675|0]=a[bx]|0;a[503676|0]=a[bx+1|0]|0;a[503677|0]=a[bx+2|0]|0;a[503678|0]=a[bx+3|0]|0;a[503679|0]=a[bx+4|0]|0}jW(aM,38224);aM=a[bw]|0;bx=bw+1|0;bw=y|0;a[bw]=a[bx]|0;a[bw+1|0]=a[bx+1|0]|0;a[bw+2|0]=a[bx+2|0]|0;a[bw+3|0]=a[bx+3|0]|0;a[bw+4|0]=a[bx+4|0]|0;if(((aM&255)-1|0)>>>0<4){if((c[59655]|0)==36){c[59655]=-1}if((c[59660]|0)==36){c[59660]=-1}if((c[42374]|0)==36){c[42374]=-1}if((c[127398]|0)==36){c[127398]=-1}if((c[127396]|0)==36){c[127396]=-1}a[503656]=aM;a[503657|0]=a[bw]|0;a[503658|0]=a[bw+1|0]|0;a[503659|0]=a[bw+2|0]|0;a[503660|0]=a[bw+3|0]|0;a[503661|0]=a[bw+4|0]|0}jW(aN,37920);aN=a[bv]|0;bw=bv+1|0;bv=w|0;a[bv]=a[bw]|0;a[bv+1|0]=a[bw+1|0]|0;a[bv+2|0]=a[bw+2|0]|0;a[bv+3|0]=a[bw+3|0]|0;a[bv+4|0]=a[bw+4|0]|0;if(((aN&255)-1|0)>>>0<4){if((c[59655]|0)==37){c[59655]=-1}if((c[59660]|0)==37){c[59660]=-1}if((c[42374]|0)==37){c[42374]=-1}if((c[127398]|0)==37){c[127398]=-1}if((c[127396]|0)==37){c[127396]=-1}a[503662]=aN;a[503663|0]=a[bv]|0;a[503664|0]=a[bv+1|0]|0;a[503665|0]=a[bv+2|0]|0;a[503666|0]=a[bv+3|0]|0;a[503667|0]=a[bv+4|0]|0}jW(aO,37680);aO=a[bu]|0;bv=bu+1|0;bu=u|0;a[bu]=a[bv]|0;a[bu+1|0]=a[bv+1|0]|0;a[bu+2|0]=a[bv+2|0]|0;a[bu+3|0]=a[bv+3|0]|0;a[bu+4|0]=a[bv+4|0]|0;if(((aO&255)-1|0)>>>0<4){if((c[59655]|0)==56){c[59655]=-1}if((c[59660]|0)==56){c[59660]=-1}if((c[42374]|0)==56){c[42374]=-1}if((c[127398]|0)==56){c[127398]=-1}if((c[127396]|0)==56){c[127396]=-1}a[503776]=aO;a[503777|0]=a[bu]|0;a[503778|0]=a[bu+1|0]|0;a[503779|0]=a[bu+2|0]|0;a[503780|0]=a[bu+3|0]|0;a[503781|0]=a[bu+4|0]|0}jW(aP,37344);aP=a[bt]|0;bu=bt+1|0;bt=s|0;a[bt]=a[bu]|0;a[bt+1|0]=a[bu+1|0]|0;a[bt+2|0]=a[bu+2|0]|0;a[bt+3|0]=a[bu+3|0]|0;a[bt+4|0]=a[bu+4|0]|0;if(((aP&255)-1|0)>>>0<4){if((c[59655]|0)==48){c[59655]=-1}if((c[59660]|0)==48){c[59660]=-1}if((c[42374]|0)==48){c[42374]=-1}if((c[127398]|0)==48){c[127398]=-1}if((c[127396]|0)==48){c[127396]=-1}a[503728]=aP;a[503729|0]=a[bt]|0;a[503730|0]=a[bt+1|0]|0;a[503731|0]=a[bt+2|0]|0;a[503732|0]=a[bt+3|0]|0;a[503733|0]=a[bt+4|0]|0}jW(aQ,36928);aQ=a[bs]|0;bt=bs+1|0;bs=q|0;a[bs]=a[bt]|0;a[bs+1|0]=a[bt+1|0]|0;a[bs+2|0]=a[bt+2|0]|0;a[bs+3|0]=a[bt+3|0]|0;a[bs+4|0]=a[bt+4|0]|0;if(((aQ&255)-1|0)>>>0<4){if((c[59655]|0)==57){c[59655]=-1}if((c[59660]|0)==57){c[59660]=-1}if((c[42374]|0)==57){c[42374]=-1}if((c[127398]|0)==57){c[127398]=-1}if((c[127396]|0)==57){c[127396]=-1}a[503782]=aQ;a[503783|0]=a[bs]|0;a[503784|0]=a[bs+1|0]|0;a[503785|0]=a[bs+2|0]|0;a[503786|0]=a[bs+3|0]|0;a[503787|0]=a[bs+4|0]|0}jW(aR,36544);aR=a[br]|0;bs=br+1|0;br=n|0;a[br]=a[bs]|0;a[br+1|0]=a[bs+1|0]|0;a[br+2|0]=a[bs+2|0]|0;a[br+3|0]=a[bs+3|0]|0;a[br+4|0]=a[bs+4|0]|0;if(((aR&255)-1|0)>>>0<4){if((c[59655]|0)==49){c[59655]=-1}if((c[59660]|0)==49){c[59660]=-1}if((c[42374]|0)==49){c[42374]=-1}if((c[127398]|0)==49){c[127398]=-1}if((c[127396]|0)==49){c[127396]=-1}a[503734]=aR;a[503735|0]=a[br]|0;a[503736|0]=a[br+1|0]|0;a[503737|0]=a[br+2|0]|0;a[503738|0]=a[br+3|0]|0;a[503739|0]=a[br+4|0]|0}jW(aS,36128);aS=a[bp]|0;br=bp+1|0;bp=l|0;a[bp]=a[br]|0;a[bp+1|0]=a[br+1|0]|0;a[bp+2|0]=a[br+2|0]|0;a[bp+3|0]=a[br+3|0]|0;a[bp+4|0]=a[br+4|0]|0;if(((aS&255)-1|0)>>>0<4){if((c[59655]|0)==50){c[59655]=-1}if((c[59660]|0)==50){c[59660]=-1}if((c[42374]|0)==50){c[42374]=-1}if((c[127398]|0)==50){c[127398]=-1}if((c[127396]|0)==50){c[127396]=-1}a[503740]=aS;a[503741|0]=a[bp]|0;a[503742|0]=a[bp+1|0]|0;a[503743|0]=a[bp+2|0]|0;a[503744|0]=a[bp+3|0]|0;a[503745|0]=a[bp+4|0]|0}jW(aT,35600);aT=a[bn]|0;bp=bn+1|0;bn=j|0;a[bn]=a[bp]|0;a[bn+1|0]=a[bp+1|0]|0;a[bn+2|0]=a[bp+2|0]|0;a[bn+3|0]=a[bp+3|0]|0;a[bn+4|0]=a[bp+4|0]|0;if(((aT&255)-1|0)>>>0<4){if((c[59655]|0)==51){c[59655]=-1}if((c[59660]|0)==51){c[59660]=-1}if((c[42374]|0)==51){c[42374]=-1}if((c[127398]|0)==51){c[127398]=-1}if((c[127396]|0)==51){c[127396]=-1}a[503746]=aT;a[503747|0]=a[bn]|0;a[503748|0]=a[bn+1|0]|0;a[503749|0]=a[bn+2|0]|0;a[503750|0]=a[bn+3|0]|0;a[503751|0]=a[bn+4|0]|0}jW(aU,34984);aU=a[bG]|0;bn=bG+1|0;bG=h|0;a[bG]=a[bn]|0;a[bG+1|0]=a[bn+1|0]|0;a[bG+2|0]=a[bn+2|0]|0;a[bG+3|0]=a[bn+3|0]|0;a[bG+4|0]=a[bn+4|0]|0;if(((aU&255)-1|0)>>>0<4){if((c[59655]|0)==58){c[59655]=-1}if((c[59660]|0)==58){c[59660]=-1}if((c[42374]|0)==58){c[42374]=-1}if((c[127398]|0)==58){c[127398]=-1}if((c[127396]|0)==58){c[127396]=-1}a[503788]=aU;a[503789|0]=a[bG]|0;a[503790|0]=a[bG+1|0]|0;a[503791|0]=a[bG+2|0]|0;a[503792|0]=a[bG+3|0]|0;a[503793|0]=a[bG+4|0]|0}jW(aV,34560);aV=a[bH]|0;bG=bH+1|0;bH=k|0;a[bH]=a[bG]|0;a[bH+1|0]=a[bG+1|0]|0;a[bH+2|0]=a[bG+2|0]|0;a[bH+3|0]=a[bG+3|0]|0;a[bH+4|0]=a[bG+4|0]|0;if(((aV&255)-1|0)>>>0<4){if((c[59655]|0)==59){c[59655]=-1}if((c[59660]|0)==59){c[59660]=-1}if((c[42374]|0)==59){c[42374]=-1}if((c[127398]|0)==59){c[127398]=-1}if((c[127396]|0)==59){c[127396]=-1}a[503794]=aV;a[503795|0]=a[bH]|0;a[503796|0]=a[bH+1|0]|0;a[503797|0]=a[bH+2|0]|0;a[503798|0]=a[bH+3|0]|0;a[503799|0]=a[bH+4|0]|0}jW(aW,34104);aW=a[bF]|0;bH=bF+1|0;bF=m|0;a[bF]=a[bH]|0;a[bF+1|0]=a[bH+1|0]|0;a[bF+2|0]=a[bH+2|0]|0;a[bF+3|0]=a[bH+3|0]|0;a[bF+4|0]=a[bH+4|0]|0;if(((aW&255)-1|0)>>>0<4){if((c[59655]|0)==54){c[59655]=-1}if((c[59660]|0)==54){c[59660]=-1}if((c[42374]|0)==54){c[42374]=-1}if((c[127398]|0)==54){c[127398]=-1}if((c[127396]|0)==54){c[127396]=-1}a[503764]=aW;a[503765|0]=a[bF]|0;a[503766|0]=a[bF+1|0]|0;a[503767|0]=a[bF+2|0]|0;a[503768|0]=a[bF+3|0]|0;a[503769|0]=a[bF+4|0]|0}jW(aX,33664);aX=a[bV]|0;bF=bV+1|0;bV=o|0;a[bV]=a[bF]|0;a[bV+1|0]=a[bF+1|0]|0;a[bV+2|0]=a[bF+2|0]|0;a[bV+3|0]=a[bF+3|0]|0;a[bV+4|0]=a[bF+4|0]|0;if(((aX&255)-1|0)>>>0<4){if((c[59655]|0)==55){c[59655]=-1}if((c[59660]|0)==55){c[59660]=-1}if((c[42374]|0)==55){c[42374]=-1}if((c[127398]|0)==55){c[127398]=-1}if((c[127396]|0)==55){c[127396]=-1}a[503770]=aX;a[503771|0]=a[bV]|0;a[503772|0]=a[bV+1|0]|0;a[503773|0]=a[bV+2|0]|0;a[503774|0]=a[bV+3|0]|0;a[503775|0]=a[bV+4|0]|0}jW(aY,33304);aY=a[bW]|0;bV=bW+1|0;bW=r|0;a[bW]=a[bV]|0;a[bW+1|0]=a[bV+1|0]|0;a[bW+2|0]=a[bV+2|0]|0;a[bW+3|0]=a[bV+3|0]|0;a[bW+4|0]=a[bV+4|0]|0;if(((aY&255)-1|0)>>>0<4){if((c[59655]|0)==52){c[59655]=-1}if((c[59660]|0)==52){c[59660]=-1}if((c[42374]|0)==52){c[42374]=-1}if((c[127398]|0)==52){c[127398]=-1}if((c[127396]|0)==52){c[127396]=-1}a[503752]=aY;a[503753|0]=a[bW]|0;a[503754|0]=a[bW+1|0]|0;a[503755|0]=a[bW+2|0]|0;a[503756|0]=a[bW+3|0]|0;a[503757|0]=a[bW+4|0]|0}jW(aZ,32872);aZ=a[bX]|0;bW=bX+1|0;bX=t|0;a[bX]=a[bW]|0;a[bX+1|0]=a[bW+1|0]|0;a[bX+2|0]=a[bW+2|0]|0;a[bX+3|0]=a[bW+3|0]|0;a[bX+4|0]=a[bW+4|0]|0;if(((aZ&255)-1|0)>>>0<4){if((c[59655]|0)==53){c[59655]=-1}if((c[59660]|0)==53){c[59660]=-1}if((c[42374]|0)==53){c[42374]=-1}if((c[127398]|0)==53){c[127398]=-1}if((c[127396]|0)==53){c[127396]=-1}a[503758]=aZ;a[503759|0]=a[bX]|0;a[503760|0]=a[bX+1|0]|0;a[503761|0]=a[bX+2|0]|0;a[503762|0]=a[bX+3|0]|0;a[503763|0]=a[bX+4|0]|0}jW(a_,32264);a_=a[bY]|0;bX=bY+1|0;bY=v|0;a[bY]=a[bX]|0;a[bY+1|0]=a[bX+1|0]|0;a[bY+2|0]=a[bX+2|0]|0;a[bY+3|0]=a[bX+3|0]|0;a[bY+4|0]=a[bX+4|0]|0;if(((a_&255)-1|0)>>>0<4){if((c[59655]|0)==72){c[59655]=-1}if((c[59660]|0)==72){c[59660]=-1}if((c[42374]|0)==72){c[42374]=-1}if((c[127398]|0)==72){c[127398]=-1}if((c[127396]|0)==72){c[127396]=-1}a[503872]=a_;a[503873|0]=a[bY]|0;a[503874|0]=a[bY+1|0]|0;a[503875|0]=a[bY+2|0]|0;a[503876|0]=a[bY+3|0]|0;a[503877|0]=a[bY+4|0]|0}jW(a$,31888);a$=a[bZ]|0;bY=bZ+1|0;bZ=x|0;a[bZ]=a[bY]|0;a[bZ+1|0]=a[bY+1|0]|0;a[bZ+2|0]=a[bY+2|0]|0;a[bZ+3|0]=a[bY+3|0]|0;a[bZ+4|0]=a[bY+4|0]|0;if(((a$&255)-1|0)>>>0<4){if((c[59655]|0)==64){c[59655]=-1}if((c[59660]|0)==64){c[59660]=-1}if((c[42374]|0)==64){c[42374]=-1}if((c[127398]|0)==64){c[127398]=-1}if((c[127396]|0)==64){c[127396]=-1}a[503824]=a$;a[503825|0]=a[bZ]|0;a[503826|0]=a[bZ+1|0]|0;a[503827|0]=a[bZ+2|0]|0;a[503828|0]=a[bZ+3|0]|0;a[503829|0]=a[bZ+4|0]|0}jW(a0,31440);a0=a[b_]|0;bZ=b_+1|0;b_=z|0;a[b_]=a[bZ]|0;a[b_+1|0]=a[bZ+1|0]|0;a[b_+2|0]=a[bZ+2|0]|0;a[b_+3|0]=a[bZ+3|0]|0;a[b_+4|0]=a[bZ+4|0]|0;if(((a0&255)-1|0)>>>0<4){if((c[59655]|0)==73){c[59655]=-1}if((c[59660]|0)==73){c[59660]=-1}if((c[42374]|0)==73){c[42374]=-1}if((c[127398]|0)==73){c[127398]=-1}if((c[127396]|0)==73){c[127396]=-1}a[503878]=a0;a[503879|0]=a[b_]|0;a[503880|0]=a[b_+1|0]|0;a[503881|0]=a[b_+2|0]|0;a[503882|0]=a[b_+3|0]|0;a[503883|0]=a[b_+4|0]|0}jW(a1,31016);a1=a[b$]|0;b_=b$+1|0;b$=B|0;a[b$]=a[b_]|0;a[b$+1|0]=a[b_+1|0]|0;a[b$+2|0]=a[b_+2|0]|0;a[b$+3|0]=a[b_+3|0]|0;a[b$+4|0]=a[b_+4|0]|0;if(((a1&255)-1|0)>>>0<4){if((c[59655]|0)==65){c[59655]=-1}if((c[59660]|0)==65){c[59660]=-1}if((c[42374]|0)==65){c[42374]=-1}if((c[127398]|0)==65){c[127398]=-1}if((c[127396]|0)==65){c[127396]=-1}a[503830]=a1;a[503831|0]=a[b$]|0;a[503832|0]=a[b$+1|0]|0;a[503833|0]=a[b$+2|0]|0;a[503834|0]=a[b$+3|0]|0;a[503835|0]=a[b$+4|0]|0}jW(a3,30392);a3=a[b0]|0;b$=b0+1|0;b0=D|0;a[b0]=a[b$]|0;a[b0+1|0]=a[b$+1|0]|0;a[b0+2|0]=a[b$+2|0]|0;a[b0+3|0]=a[b$+3|0]|0;a[b0+4|0]=a[b$+4|0]|0;if(((a3&255)-1|0)>>>0<4){if((c[59655]|0)==66){c[59655]=-1}if((c[59660]|0)==66){c[59660]=-1}if((c[42374]|0)==66){c[42374]=-1}if((c[127398]|0)==66){c[127398]=-1}if((c[127396]|0)==66){c[127396]=-1}a[503836]=a3;a[503837|0]=a[b0]|0;a[503838|0]=a[b0+1|0]|0;a[503839|0]=a[b0+2|0]|0;a[503840|0]=a[b0+3|0]|0;a[503841|0]=a[b0+4|0]|0}jW(a4,3e4);a4=a[b1]|0;b0=b1+1|0;b1=F|0;a[b1]=a[b0]|0;a[b1+1|0]=a[b0+1|0]|0;a[b1+2|0]=a[b0+2|0]|0;a[b1+3|0]=a[b0+3|0]|0;a[b1+4|0]=a[b0+4|0]|0;if(((a4&255)-1|0)>>>0<4){if((c[59655]|0)==67){c[59655]=-1}if((c[59660]|0)==67){c[59660]=-1}if((c[42374]|0)==67){c[42374]=-1}if((c[127398]|0)==67){c[127398]=-1}if((c[127396]|0)==67){c[127396]=-1}a[503842]=a4;a[503843|0]=a[b1]|0;a[503844|0]=a[b1+1|0]|0;a[503845|0]=a[b1+2|0]|0;a[503846|0]=a[b1+3|0]|0;a[503847|0]=a[b1+4|0]|0}jW(a5,29608);a5=a[b2]|0;b1=b2+1|0;b2=H|0;a[b2]=a[b1]|0;a[b2+1|0]=a[b1+1|0]|0;a[b2+2|0]=a[b1+2|0]|0;a[b2+3|0]=a[b1+3|0]|0;a[b2+4|0]=a[b1+4|0]|0;if(((a5&255)-1|0)>>>0<4){if((c[59655]|0)==74){c[59655]=-1}if((c[59660]|0)==74){c[59660]=-1}if((c[42374]|0)==74){c[42374]=-1}if((c[127398]|0)==74){c[127398]=-1}if((c[127396]|0)==74){c[127396]=-1}a[503884]=a5;a[503885|0]=a[b2]|0;a[503886|0]=a[b2+1|0]|0;a[503887|0]=a[b2+2|0]|0;a[503888|0]=a[b2+3|0]|0;a[503889|0]=a[b2+4|0]|0}jW(a6,29248);a6=a[b3]|0;b2=b3+1|0;b3=J|0;a[b3]=a[b2]|0;a[b3+1|0]=a[b2+1|0]|0;a[b3+2|0]=a[b2+2|0]|0;a[b3+3|0]=a[b2+3|0]|0;a[b3+4|0]=a[b2+4|0]|0;if(((a6&255)-1|0)>>>0<4){if((c[59655]|0)==75){c[59655]=-1}if((c[59660]|0)==75){c[59660]=-1}if((c[42374]|0)==75){c[42374]=-1}if((c[127398]|0)==75){c[127398]=-1}if((c[127396]|0)==75){c[127396]=-1}a[503890]=a6;a[503891|0]=a[b3]|0;a[503892|0]=a[b3+1|0]|0;a[503893|0]=a[b3+2|0]|0;a[503894|0]=a[b3+3|0]|0;a[503895|0]=a[b3+4|0]|0}jW(a7,28936);a7=a[b4]|0;b3=b4+1|0;b4=L|0;a[b4]=a[b3]|0;a[b4+1|0]=a[b3+1|0]|0;a[b4+2|0]=a[b3+2|0]|0;a[b4+3|0]=a[b3+3|0]|0;a[b4+4|0]=a[b3+4|0]|0;if(((a7&255)-1|0)>>>0<4){if((c[59655]|0)==70){c[59655]=-1}if((c[59660]|0)==70){c[59660]=-1}if((c[42374]|0)==70){c[42374]=-1}if((c[127398]|0)==70){c[127398]=-1}if((c[127396]|0)==70){c[127396]=-1}a[503860]=a7;a[503861|0]=a[b4]|0;a[503862|0]=a[b4+1|0]|0;a[503863|0]=a[b4+2|0]|0;a[503864|0]=a[b4+3|0]|0;a[503865|0]=a[b4+4|0]|0}jW(a8,28608);a8=a[b5]|0;b4=b5+1|0;b5=N|0;a[b5]=a[b4]|0;a[b5+1|0]=a[b4+1|0]|0;a[b5+2|0]=a[b4+2|0]|0;a[b5+3|0]=a[b4+3|0]|0;a[b5+4|0]=a[b4+4|0]|0;if(((a8&255)-1|0)>>>0<4){if((c[59655]|0)==71){c[59655]=-1}if((c[59660]|0)==71){c[59660]=-1}if((c[42374]|0)==71){c[42374]=-1}if((c[127398]|0)==71){c[127398]=-1}if((c[127396]|0)==71){c[127396]=-1}a[503866]=a8;a[503867|0]=a[b5]|0;a[503868|0]=a[b5+1|0]|0;a[503869|0]=a[b5+2|0]|0;a[503870|0]=a[b5+3|0]|0;a[503871|0]=a[b5+4|0]|0}jW(a9,28272);a9=a[b6]|0;b5=b6+1|0;b6=P|0;a[b6]=a[b5]|0;a[b6+1|0]=a[b5+1|0]|0;a[b6+2|0]=a[b5+2|0]|0;a[b6+3|0]=a[b5+3|0]|0;a[b6+4|0]=a[b5+4|0]|0;if(((a9&255)-1|0)>>>0<4){if((c[59655]|0)==68){c[59655]=-1}if((c[59660]|0)==68){c[59660]=-1}if((c[42374]|0)==68){c[42374]=-1}if((c[127398]|0)==68){c[127398]=-1}if((c[127396]|0)==68){c[127396]=-1}a[503848]=a9;a[503849|0]=a[b6]|0;a[503850|0]=a[b6+1|0]|0;a[503851|0]=a[b6+2|0]|0;a[503852|0]=a[b6+3|0]|0;a[503853|0]=a[b6+4|0]|0}jW(ba,27952);ba=a[b7]|0;b6=b7+1|0;b7=R|0;a[b7]=a[b6]|0;a[b7+1|0]=a[b6+1|0]|0;a[b7+2|0]=a[b6+2|0]|0;a[b7+3|0]=a[b6+3|0]|0;a[b7+4|0]=a[b6+4|0]|0;if(((ba&255)-1|0)>>>0<4){if((c[59655]|0)==69){c[59655]=-1}if((c[59660]|0)==69){c[59660]=-1}if((c[42374]|0)==69){c[42374]=-1}if((c[127398]|0)==69){c[127398]=-1}if((c[127396]|0)==69){c[127396]=-1}a[503854]=ba;a[503855|0]=a[b7]|0;a[503856|0]=a[b7+1|0]|0;a[503857|0]=a[b7+2|0]|0;a[503858|0]=a[b7+3|0]|0;a[503859|0]=a[b7+4|0]|0}jW(bb,27552);bb=a[b8]|0;b7=b8+1|0;b8=T|0;a[b8]=a[b7]|0;a[b8+1|0]=a[b7+1|0]|0;a[b8+2|0]=a[b7+2|0]|0;a[b8+3|0]=a[b7+3|0]|0;a[b8+4|0]=a[b7+4|0]|0;if(((bb&255)-1|0)>>>0<4){if((c[59655]|0)==88){c[59655]=-1}if((c[59660]|0)==88){c[59660]=-1}if((c[42374]|0)==88){c[42374]=-1}if((c[127398]|0)==88){c[127398]=-1}if((c[127396]|0)==88){c[127396]=-1}a[503968]=bb;a[503969|0]=a[b8]|0;a[503970|0]=a[b8+1|0]|0;a[503971|0]=a[b8+2|0]|0;a[503972|0]=a[b8+3|0]|0;a[503973|0]=a[b8+4|0]|0}jW(bc,27080);bc=a[b9]|0;b8=b9+1|0;b9=V|0;a[b9]=a[b8]|0;a[b9+1|0]=a[b8+1|0]|0;a[b9+2|0]=a[b8+2|0]|0;a[b9+3|0]=a[b8+3|0]|0;a[b9+4|0]=a[b8+4|0]|0;if(((bc&255)-1|0)>>>0<4){if((c[59655]|0)==80){c[59655]=-1}if((c[59660]|0)==80){c[59660]=-1}if((c[42374]|0)==80){c[42374]=-1}if((c[127398]|0)==80){c[127398]=-1}if((c[127396]|0)==80){c[127396]=-1}a[503920]=bc;a[503921|0]=a[b9]|0;a[503922|0]=a[b9+1|0]|0;a[503923|0]=a[b9+2|0]|0;a[503924|0]=a[b9+3|0]|0;a[503925|0]=a[b9+4|0]|0}jW(bd,26424);bd=a[ca]|0;b9=ca+1|0;ca=X|0;a[ca]=a[b9]|0;a[ca+1|0]=a[b9+1|0]|0;a[ca+2|0]=a[b9+2|0]|0;a[ca+3|0]=a[b9+3|0]|0;a[ca+4|0]=a[b9+4|0]|0;if(((bd&255)-1|0)>>>0<4){if((c[59655]|0)==89){c[59655]=-1}if((c[59660]|0)==89){c[59660]=-1}if((c[42374]|0)==89){c[42374]=-1}if((c[127398]|0)==89){c[127398]=-1}if((c[127396]|0)==89){c[127396]=-1}a[503974]=bd;a[503975|0]=a[ca]|0;a[503976|0]=a[ca+1|0]|0;a[503977|0]=a[ca+2|0]|0;a[503978|0]=a[ca+3|0]|0;a[503979|0]=a[ca+4|0]|0}jW(be,26008);be=a[cb]|0;ca=cb+1|0;cb=Z|0;a[cb]=a[ca]|0;a[cb+1|0]=a[ca+1|0]|0;a[cb+2|0]=a[ca+2|0]|0;a[cb+3|0]=a[ca+3|0]|0;a[cb+4|0]=a[ca+4|0]|0;if(((be&255)-1|0)>>>0<4){if((c[59655]|0)==81){c[59655]=-1}if((c[59660]|0)==81){c[59660]=-1}if((c[42374]|0)==81){c[42374]=-1}if((c[127398]|0)==81){c[127398]=-1}if((c[127396]|0)==81){c[127396]=-1}a[503926]=be;a[503927|0]=a[cb]|0;a[503928|0]=a[cb+1|0]|0;a[503929|0]=a[cb+2|0]|0;a[503930|0]=a[cb+3|0]|0;a[503931|0]=a[cb+4|0]|0}jW(bf,25504);bf=a[cc]|0;cb=cc+1|0;cc=$|0;a[cc]=a[cb]|0;a[cc+1|0]=a[cb+1|0]|0;a[cc+2|0]=a[cb+2|0]|0;a[cc+3|0]=a[cb+3|0]|0;a[cc+4|0]=a[cb+4|0]|0;if(((bf&255)-1|0)>>>0<4){if((c[59655]|0)==82){c[59655]=-1}if((c[59660]|0)==82){c[59660]=-1}if((c[42374]|0)==82){c[42374]=-1}if((c[127398]|0)==82){c[127398]=-1}if((c[127396]|0)==82){c[127396]=-1}a[503932]=bf;a[503933|0]=a[cc]|0;a[503934|0]=a[cc+1|0]|0;a[503935|0]=a[cc+2|0]|0;a[503936|0]=a[cc+3|0]|0;a[503937|0]=a[cc+4|0]|0}jW(bg,25136);bg=a[ce]|0;cc=ce+1|0;ce=ac|0;a[ce]=a[cc]|0;a[ce+1|0]=a[cc+1|0]|0;a[ce+2|0]=a[cc+2|0]|0;a[ce+3|0]=a[cc+3|0]|0;a[ce+4|0]=a[cc+4|0]|0;if(((bg&255)-1|0)>>>0<4){if((c[59655]|0)==83){c[59655]=-1}if((c[59660]|0)==83){c[59660]=-1}if((c[42374]|0)==83){c[42374]=-1}if((c[127398]|0)==83){c[127398]=-1}if((c[127396]|0)==83){c[127396]=-1}a[503938]=bg;a[503939|0]=a[ce]|0;a[503940|0]=a[ce+1|0]|0;a[503941|0]=a[ce+2|0]|0;a[503942|0]=a[ce+3|0]|0;a[503943|0]=a[ce+4|0]|0}jW(bh,24864);bh=a[cf]|0;ce=cf+1|0;cf=ae|0;a[cf]=a[ce]|0;a[cf+1|0]=a[ce+1|0]|0;a[cf+2|0]=a[ce+2|0]|0;a[cf+3|0]=a[ce+3|0]|0;a[cf+4|0]=a[ce+4|0]|0;if(((bh&255)-1|0)>>>0<4){if((c[59655]|0)==90){c[59655]=-1}if((c[59660]|0)==90){c[59660]=-1}if((c[42374]|0)==90){c[42374]=-1}if((c[127398]|0)==90){c[127398]=-1}if((c[127396]|0)==90){c[127396]=-1}a[503980]=bh;a[503981|0]=a[cf]|0;a[503982|0]=a[cf+1|0]|0;a[503983|0]=a[cf+2|0]|0;a[503984|0]=a[cf+3|0]|0;a[503985|0]=a[cf+4|0]|0}jW(bi,24552);bi=a[cg]|0;cf=cg+1|0;cg=ag|0;a[cg]=a[cf]|0;a[cg+1|0]=a[cf+1|0]|0;a[cg+2|0]=a[cf+2|0]|0;a[cg+3|0]=a[cf+3|0]|0;a[cg+4|0]=a[cf+4|0]|0;if(((bi&255)-1|0)>>>0<4){if((c[59655]|0)==91){c[59655]=-1}if((c[59660]|0)==91){c[59660]=-1}if((c[42374]|0)==91){c[42374]=-1}if((c[127398]|0)==91){c[127398]=-1}if((c[127396]|0)==91){c[127396]=-1}a[503986]=bi;a[503987|0]=a[cg]|0;a[503988|0]=a[cg+1|0]|0;a[503989|0]=a[cg+2|0]|0;a[503990|0]=a[cg+3|0]|0;a[503991|0]=a[cg+4|0]|0}jW(bj,24104);bj=a[ch]|0;cg=ch+1|0;ch=ai|0;a[ch]=a[cg]|0;a[ch+1|0]=a[cg+1|0]|0;a[ch+2|0]=a[cg+2|0]|0;a[ch+3|0]=a[cg+3|0]|0;a[ch+4|0]=a[cg+4|0]|0;if(((bj&255)-1|0)>>>0<4){if((c[59655]|0)==86){c[59655]=-1}if((c[59660]|0)==86){c[59660]=-1}if((c[42374]|0)==86){c[42374]=-1}if((c[127398]|0)==86){c[127398]=-1}if((c[127396]|0)==86){c[127396]=-1}a[503956]=bj;a[503957|0]=a[ch]|0;a[503958|0]=a[ch+1|0]|0;a[503959|0]=a[ch+2|0]|0;a[503960|0]=a[ch+3|0]|0;a[503961|0]=a[ch+4|0]|0}jW(bk,23728);bk=a[ci]|0;ch=ci+1|0;ci=ak|0;a[ci]=a[ch]|0;a[ci+1|0]=a[ch+1|0]|0;a[ci+2|0]=a[ch+2|0]|0;a[ci+3|0]=a[ch+3|0]|0;a[ci+4|0]=a[ch+4|0]|0;if(((bk&255)-1|0)>>>0<4){if((c[59655]|0)==87){c[59655]=-1}if((c[59660]|0)==87){c[59660]=-1}if((c[42374]|0)==87){c[42374]=-1}if((c[127398]|0)==87){c[127398]=-1}if((c[127396]|0)==87){c[127396]=-1}a[503962]=bk;a[503963|0]=a[ci]|0;a[503964|0]=a[ci+1|0]|0;a[503965|0]=a[ci+2|0]|0;a[503966|0]=a[ci+3|0]|0;a[503967|0]=a[ci+4|0]|0}jW(bl,23368);bl=a[cj]|0;ci=cj+1|0;cj=am|0;a[cj]=a[ci]|0;a[cj+1|0]=a[ci+1|0]|0;a[cj+2|0]=a[ci+2|0]|0;a[cj+3|0]=a[ci+3|0]|0;a[cj+4|0]=a[ci+4|0]|0;if(((bl&255)-1|0)>>>0<4){if((c[59655]|0)==84){c[59655]=-1}if((c[59660]|0)==84){c[59660]=-1}if((c[42374]|0)==84){c[42374]=-1}if((c[127398]|0)==84){c[127398]=-1}if((c[127396]|0)==84){c[127396]=-1}a[503944]=bl;a[503945|0]=a[cj]|0;a[503946|0]=a[cj+1|0]|0;a[503947|0]=a[cj+2|0]|0;a[503948|0]=a[cj+3|0]|0;a[503949|0]=a[cj+4|0]|0}jW(bm,22952);bm=a[ck]|0;cj=ck+1|0;ck=ao|0;a[ck]=a[cj]|0;a[ck+1|0]=a[cj+1|0]|0;a[ck+2|0]=a[cj+2|0]|0;a[ck+3|0]=a[cj+3|0]|0;a[ck+4|0]=a[cj+4|0]|0;if(((bm&255)-1|0)>>>0>=4){g[201849]=4378500.0;i=f;return}if((c[59655]|0)==85){c[59655]=-1}if((c[59660]|0)==85){c[59660]=-1}if((c[42374]|0)==85){c[42374]=-1}if((c[127398]|0)==85){c[127398]=-1}if((c[127396]|0)==85){c[127396]=-1}a[503950]=bm;a[503951|0]=a[ck]|0;a[503952|0]=a[ck+1|0]|0;a[503953|0]=a[ck+2|0]|0;a[503954|0]=a[ck+3|0]|0;a[503955|0]=a[ck+4|0]|0;g[201849]=4378500.0;i=f;return}function XL(){var b=0;if(a[5704]|0){XZ(c[59010]|0);a[5704]=0}b=c[125858]|0;if((b|0)!=0){XZ(b);c[125858]=0}Hn();Hx();jV();return}function XM(){var e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0;X2(c[263195]|0,0,32768);if((a[799131]|0)!=0){if((a[799132]|0)!=0){X2(c[263192]|0,0,2097152)}a[1394256]=0;a[1394257]=0;a[1394259]=0;a[1394260]=0;a[1394261]=0;X2(1394264,0,109);if((a[1394258]|0)==0){a[1394343]=(a[1125512]|0)!=0?-128:0;if((c[281374]|0)==524288){e=c[263199]|0;f=c[281376]|0;X5(e|0,f|0,524288)|0;a[1394342]=-128;a[1394344]=-128;a[1394345]=-128;a[1394353]=-128;a[1394354]=-128}else{a[1394344]=-128;a[1394346]=-128;a[1394347]=-128}a[1394355]=-128}else{a[1394349]=-128;a[1394348]=-128}jN()}j$();HL();f=0;do{a[1183776+(f*22|0)|0]=1;a[1183777+(f*22|0)|0]=1;a[1183779+(f*22|0)|0]=1;a[1183780+(f*22|0)|0]=1;a[1183781+(f*22|0)|0]=7;a[1183782+(f*22|0)|0]=-1;b[1183784+(f*22|0)>>1]=-1;a[1183786+(f*22|0)|0]=-1;b[1183788+(f*22|0)>>1]=-1;a[1183790+(f*22|0)|0]=-1;b[1183792+(f*22|0)>>1]=-1;a[1183794+(f*22|0)|0]=0;a[1183795+(f*22|0)|0]=127;a[1183796+(f*22|0)|0]=-1;a[1183797+(f*22|0)|0]=0;a[1183778+(f*22|0)|0]=1;f=f+1|0;}while((f|0)<8);c[59e3]=0;c[42380]=0;X2(436893,0,27);c[109224]=65472;a[436864]=10;a[436865]=-80;c[109221]=0;c[109231]=0;c[109230]=33;c[109198]=1;c[109201]=0;c[109204]=1;c[109207]=0;c[109210]=1;c[109213]=0;if((c[109245]|0)!=128){c[199301]=128;c[109245]=128;X5(437048,503096,64)|0;X5(503096,436984,64)|0}c[109200]=((a[436874]|0)-1&255)+1;c[109202]=0;c[109203]=0;c[109206]=((a[436875]|0)-1&255)+1;c[109208]=0;c[109209]=0;c[109212]=((a[436876]|0)-1&255)+1;c[109214]=0;c[109215]=0;c[109211]=4;c[109205]=7;c[109199]=7;X2(436948,0,((436808+(-436793|0)|0)>>>1<<1)+2|0);c[109236]=((436808+(-436793|0)|0)>>>1<<1)+436950;c[199292]=797172;c[199290]=797172;c[199291]=797204;a[795756]=-32;c[198979]=16384;c[198976]=795776;c[198977]=1;c[198981]=0;c[198983]=0;c[198980]=0;c[109233]=0;f=c[125858]|0;e=a[17360]|0;g=f+((e?1024:0)<<1)|0;c[109234]=f;c[109235]=g;if(e&(((436808+(-436793|0)|0)>>>1<<1)+436950|0)>>>0>436948>>>0){h=f;i=436948;while(1){j=i+2|0;k=h+2|0;b[h>>1]=b[i>>1]|0;l=c[109236]|0;m=k>>>0<g>>>0;if(j>>>0<l>>>0&m){h=k;i=j}else{n=k;o=j;p=m;q=l;break}}}else{n=f;o=436948;p=e;q=((436808+(-436793|0)|0)>>>1<<1)+436950|0}do{if(p){r=g;s=n}else{if(o>>>0<q>>>0){t=797172;u=o}else{r=797204;s=797172;break}while(1){e=u+2|0;f=t+2|0;b[t>>1]=b[u>>1]|0;if(e>>>0<(c[109236]|0)>>>0){t=f;u=e}else{r=797204;s=f;break}}}}while(0);u=(s|0)==0;t=u?797172:s;c[199292]=t;c[199290]=t;c[199291]=t+((u?16:r-s>>1)<<1);c[59004]=0;c[59006]=0;X2(c[59010]|0,0,c[59008]|0);c[59356]=65536;c[59348]=0;c[59350]=0;c[59352]=0;c[59354]=0;c[59340]=0;c[59342]=0;c[59344]=0;c[59346]=0;if((a[799122]|0)!=0){X2(1182304,0,1452);a[1182304]=1;a[1182305]=1;X2(1181224,0,1076);a[1181224]=1;X2(1130928,0,50296);b[565464]=128;b[565465]=132;c[201850]=1702;X2(1129624,0,1304);a[1129624]=1}if((a[799121]|0)!=0){xY()}if((a[799123]|0)!=0){a[808140]=0;a[808141]=0;c[202033]=0;X2((c[263195]|0)+8704|0,0,512);a[(c[263195]|0)+8704|0]=32;a[(c[263195]|0)+8736|0]=0;a[(c[263195]|0)+8737|0]=1;a[(c[263195]|0)+8738|0]=2;a[(c[263195]|0)+8739|0]=3;a[(c[263195]|0)+8744|0]=-1;b[420459]=0;b[420460]=0;c[210231]=0;s=840928;c[s>>2]=0;c[s+4>>2]=0;a[840916]=0;c[202028]=0}if((a[799125]|0)!=0){TS()}if((a[799126]|0)!=0){T4()}if((a[799124]|0)!=0){X2(c[263197]|0,0,8192)}if((a[799128]|0)!=0){s=0;r=c[263198]|0;do{a[r+s|0]=-1;s=s+1|0;r=c[263198]|0}while((s|0)<8192);b[522257]=(a[r+8181|0]&1)==0?7168:6144;s=r+8182|0;b[522256]=a[s]&127;b[522258]=d[s]<<1&6}if((a[799130]|0)==0){v=c[263191]|0;c[348389]=v;w=c[263193]|0;c[348391]=w;x=c[263195]|0;c[348390]=x;return}c[58916]=2;c[58918]=-1;s=eG(0)|0;a[1041696]=s&255;a[1041697]=s>>>8&255;a[1041698]=s>>>16&255;a[1041699]=s>>>24&255;v=c[263191]|0;c[348389]=v;w=c[263193]|0;c[348391]=w;x=c[263195]|0;c[348390]=x;return}function XN(){var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0;f=i;i=i+8|0;g=f|0;a[g]=0;fz[c[59510]&8191]();h=0;do{switch(c[235736+(h<<2)>>2]|0){case 1:{j=509632+(h<<1)|0;k=0;do{l=(fx[c[127412]&15](h,1,0,k)|0)<<16>>16==0;m=b[1736+(k<<1)>>1]|0;if(l){n=b[j>>1]&~m}else{n=b[j>>1]|m}b[j>>1]=n;k=k+1|0;}while((k|0)<12);break};case 260:{k=fx[c[127412]&15](h,260,0,0)|0;b[117852]=(b[117852]|0)+k&65535;k=fx[c[127412]&15](h,260,0,1)|0;j=(b[117848]|0)+k&65535;b[117848]=j;jY(503512,b[117852]|0,j);j=(h<<4)+16|0;jY(503440+((j|2)*6|0)|0,fx[c[127412]&15](h,260,0,2)|0,0);jY(503440+((j|3)*6|0)|0,fx[c[127412]&15](h,260,0,3)|0,0);jY(503440+((j|4)*6|0)|0,fx[c[127412]&15](h,260,0,4)|0,0);jY(503440+((j|5)*6|0)|0,fx[c[127412]&15](h,260,0,5)|0,0);break};case 516:case 772:{j=fx[c[127412]&15](h,516,0,0)|0;b[117864]=(b[117864]|0)+j&65535;j=fx[c[127412]&15](h,516,0,1)|0;k=(b[117860]|0)+j&65535;b[117860]=k;jY(503512,b[117864]|0,k);k=(h<<4)+16|0;jY(503440+((k|2)*6|0)|0,fx[c[127412]&15](h,516,0,2)|0,0);jY(503440+((k|3)*6|0)|0,fx[c[127412]&15](h,516,0,3)|0,0);jY(503440+((k|4)*6|0)|0,fx[c[127412]&15](h,516,0,4)|0,0);jY(503440+((k|5)*6|0)|0,fx[c[127412]&15](h,516,0,5)|0,0);jY(503440+((k|6)*6|0)|0,fx[c[127412]&15](h,516,0,6)|0,0);break};case 2:{k=fx[c[127412]&15](h,2,0,0)|0;j=fx[c[127412]&15](h,2,0,1)|0;m=235712+(h<<2)|0;l=(b[m>>1]|0)+k&65535;b[m>>1]=l;m=235714+(h<<2)|0;k=(b[m>>1]|0)+j&65535;b[m>>1]=k;jY(503440+((h+12|0)*6|0)|0,l,k);k=(h<<4)+16|0;jY(503440+((k|2)*6|0)|0,fx[c[127412]&15](h,2,0,2)|0,0);jY(503440+((k|3)*6|0)|0,fx[c[127412]&15](h,2,0,3)|0,0);break};case 257:{k=0;while(1){l=(fx[c[127412]&15](h,257,0,k)|0)<<16>>16==0;m=b[1736+(k<<1)>>1]|0;if(l){o=b[254816]&~m}else{o=b[254816]|m}b[254816]=o;m=k+1|0;if((m|0)<12){k=m}else{q=0;break}}while(1){k=(fx[c[127412]&15](h,257,1,q)|0)<<16>>16==0;m=b[1736+(q<<1)>>1]|0;if(k){r=b[254817]&~m}else{r=b[254817]|m}b[254817]=r;m=q+1|0;if((m|0)<12){q=m}else{s=0;break}}while(1){m=(fx[c[127412]&15](h,257,2,s)|0)<<16>>16==0;k=b[1736+(s<<1)>>1]|0;if(m){t=b[254818]&~k}else{t=b[254818]|k}b[254818]=t;k=s+1|0;if((k|0)<12){s=k}else{u=0;break}}do{k=(fx[c[127412]&15](h,257,3,u)|0)<<16>>16==0;m=b[1736+(u<<1)>>1]|0;if(k){v=b[254819]&~m}else{v=b[254819]|m}b[254819]=v;u=u+1|0;}while((u|0)<12);break};default:{a2(56968,30,1,c[p>>2]|0)|0}}h=h+1|0;}while((h|0)<2);while(1){h=c[348395]|0;if((h|0)!=0){do{if((h&128|0)==0){w=h}else{u=c[348392]|0;if((c[199748]|0)>(u|0)){w=h;break}c[348395]=h&-129;c[199748]=65535;if((a[1393628]|0)!=0){a[1393628]=0;b[520836]=(b[520836]|0)+1&65535}v=(c[348399]|0)+6+u|0;c[348392]=v;if((v|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}L8331:do{if((b[520829]&256)==0){v=a[1041674|0]|0;u=b[520832]|0;b[520832]=u-1&65535;j2(v,u&65535);j3(b[520836]|0,(e[520832]|0)-1|0,65535);u=b[520832]|0;v=a[1041658]&60|a[1106736]|a[1106720]&-128|((a[1106728]|0)==0)<<1|a[1106712]<<6;a[1041658]=v;b[520832]=u-3&65535;j2(v,u-2&65535);u=a[1041658]|0;a[1044496]=u;a[1041658]=u&-13|4;do{if((a[799123]|0)!=0){u=c[263195]|0;if((a[u+8713|0]&16)==0){break}a[1044496]=a[u+8717|0]|0;v=(c[348392]|0)+16|0;c[348392]=v;if((v|0)<(c[348406]|0)){x=u}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));x=c[263195]|0}j4(d[x+8717|0]<<8|d[x+8716|0]);break L8331}}while(0);u=j5(65514,16777215)|0;a[1044496]=(u&65535)>>>8&255;j4(u&65535)}else{a[1041664]=(a[1041664]|0)-1&255;j3(b[520836]|0,e[520832]|0,255);a[1041664]=(a[1041664]|0)-1&255;u=a[1041658]&60|a[1106736]|a[1106720]&-128|((a[1106728]|0)==0)<<1|a[1106712]<<6;a[1041658]=u;j2(u,e[520832]|0);a[1041664]=(a[1041664]|0)-1&255;u=a[1041658]|0;a[1044496]=u;a[1041658]=u&-13|4;do{if((a[799123]|0)!=0){u=c[263195]|0;if((a[u+8713|0]&16)==0){break}a[1044496]=a[u+8717|0]|0;v=(c[348392]|0)+16|0;c[348392]=v;if((v|0)<(c[348406]|0)){y=u}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));y=c[263195]|0}j4(d[y+8717|0]<<8|d[y+8716|0]);break L8331}}while(0);u=j5(65530,16777215)|0;a[1044496]=(u&65535)>>>8&255;j4(u&65535)}}while(0);w=c[348395]|0}}while(0);do{if((w&2048|0)==0){z=w}else{h=c[348398]|0;if((h|0)!=0){c[348398]=h-1;z=w;break}if((a[1393628]|0)!=0){a[1393628]=0;b[520836]=(b[520836]|0)+1&65535}if((a[1393588]|0)==0){h=w&-2049;c[348395]=h;z=h;break}if((a[1041658]&4)!=0){z=w;break}h=(c[348399]|0)+6+(c[348392]|0)|0;c[348392]=h;if((h|0)>=(c[348406]|0)){do{j1();}while((c[348392]|0)>=(c[348406]|0))}L8370:do{if((b[520829]&256)==0){h=a[1041674|0]|0;u=b[520832]|0;b[520832]=u-1&65535;j2(h,u&65535);j3(b[520836]|0,(e[520832]|0)-1|0,65535);u=b[520832]|0;h=a[1041658]&60|a[1106736]|a[1106720]&-128|((a[1106728]|0)==0)<<1|a[1106712]<<6;a[1041658]=h;b[520832]=u-3&65535;j2(h,u-2&65535);u=a[1041658]|0;a[1044496]=u;a[1041658]=u&-13|4;do{if((a[799123]|0)!=0){u=c[263195]|0;if((a[u+8713|0]&64)==0){break}a[1044496]=a[u+8719|0]|0;h=(c[348392]|0)+16|0;c[348392]=h;if((h|0)<(c[348406]|0)){A=u}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));A=c[263195]|0}j4(d[A+8719|0]<<8|d[A+8718|0]);break L8370}}while(0);u=j5(65518,16777215)|0;a[1044496]=(u&65535)>>>8&255;j4(u&65535)}else{a[1041664]=(a[1041664]|0)-1&255;j3(b[520836]|0,e[520832]|0,255);a[1041664]=(a[1041664]|0)-1&255;u=a[1041658]&60|a[1106736]|a[1106720]&-128|((a[1106728]|0)==0)<<1|a[1106712]<<6;a[1041658]=u;j2(u,e[520832]|0);a[1041664]=(a[1041664]|0)-1&255;u=a[1041658]|0;a[1044496]=u;a[1041658]=u&-13|4;do{if((a[799123]|0)!=0){u=c[263195]|0;if((a[u+8713|0]&64)==0){break}a[1044496]=a[u+8719|0]|0;h=(c[348392]|0)+16|0;c[348392]=h;if((h|0)<(c[348406]|0)){B=u}else{do{j1();}while((c[348392]|0)>=(c[348406]|0));B=c[263195]|0}j4(d[B+8719|0]<<8|d[B+8718|0]);break L8370}}while(0);u=j5(65534,16777215)|0;a[1044496]=(u&65535)>>>8&255;j4(u&65535)}}while(0);z=c[348395]|0}}while(0);if((z&16|0)!=0){break}}u=c[348392]|0;c[348393]=u;h=c[348396]|0;if((h|0)==0){v=j0(c[260418]|0)|0;a[1044496]=v;C=v;D=153656;E=b[520836]|0}else{v=b[520836]|0;s=a[h+(v&65535)|0]|0;c[348392]=(c[348399]|0)+u;C=s;D=c[276688]|0;E=v}v=C&255;do{if(((d[(c[276686]|0)+v|0]|0)+(E&4095)|0)>4095){s=c[348396]|0;u=(c[276676]|0)+(E+4&65535)|0;h=c[1052804+((u>>>12&4095)<<2)>>2]|0;L8400:do{if(h>>>0<19){switch(h|0){case 2:{t=c[274485]|0;if((t&4095|0)!=4095){F=0;break L8400}F=(c[263193]|0)+((t&(u>>>1&8355840|u&32767))-(u&65535))|0;break L8400;break};case 4:{t=c[274485]|0;if((t&4095|0)!=4095){F=0;break L8400}F=(c[263193]|0)+((t&(u&32767)-24576+(u>>>3&122880))-(u&65535))|0;break L8400;break};case 7:{F=(c[263196]|0)+(-24576-(u&32768))|0;break L8400;break};case 13:{if(((u&65535)-32576&65535)<31){F=0;break L8400}F=(c[263197]|0)-24576|0;break L8400;break};case 14:{if(((u&65535)-32752&65535)<7){F=0;break L8400}F=(c[263198]|0)-24576|0;break L8400;break};case 3:{t=c[261136]|0;if((t&4095|0)!=4095){F=0;break L8400}F=(c[261140]|0)+((t&(u>>>1&8355840|u&32767))-(u&65535))|0;break L8400;break};case 6:{F=c[263193]|0;break L8400;break};case 10:{t=u&15728640;if((t|0)==13631488){G=c[198898]|0}else if((t|0)==14680064){G=c[198894]|0}else if((t|0)==15728640){G=c[198890]|0}else{G=0}F=(c[263192]|0)+(G+(u&983040))|0;break L8400;break};default:{F=0;break L8400}}}else{F=h}}while(0);c[348396]=F;if((s|0)==(F|0)){if((E&-4096)<<16>>16!=-4096){H=D;break}}H=153656}else{H=D}}while(0);b[520836]=E+1&65535;fz[c[H+(v<<2)>>2]&8191]();if((a[799123]|0)==0){continue}h=c[202033]|0;do{if((h&128|0)==0){I=h}else{u=c[263195]|0;if((a[u+8704|0]&16)==0){I=h;break}c[202033]=h&-129;t=u+8961|0;a[t]=a[t]|16;if((a[808141]|0)!=0){a[808141]=0;b[404048]=(b[404048]|0)+1&65535}if((b[404041]&256)==0){t=a[808098|0]|0;u=b[404044]|0;b[404044]=u-1&65535;HY(t,u&65535);u=b[404048]|0;t=(e[404044]|0)-1|0;HY((u&65535)>>>8&255,(t&65535)+1&65535|t&-65536);HY(u&255,t);t=b[404044]|0;u=a[808082]&60|a[808120]|a[808122]&-128|((a[808121]|0)==0)<<1|a[808123]<<6;a[808082]=u;b[404044]=t-3&65535;HY(u,t-2&65535);a[808082]=a[808082]&-13|4;t=c[263195]|0;u=a[t+8710|0]|0;a[808104]=u;HR((u&255)<<8|d[t+8709|0])}else{a[808088]=(a[808088]|0)-1&255;t=b[404048]|0;u=b[404044]|0;HY((t&65535)>>>8&255,((u&255)+1&255|u&-256)&65535);HY(t&255,u&65535);a[808088]=(a[808088]|0)-1&255;u=a[808082]&60|a[808120]|a[808122]&-128|((a[808121]|0)==0)<<1|a[808123]<<6;a[808082]=u;HY(u,e[404044]|0);a[808088]=(a[808088]|0)-1&255;a[808082]=a[808082]&-13|4;u=c[263195]|0;t=a[u+8710|0]|0;a[808104]=t;HR((t&255)<<8|d[u+8709|0])}I=c[202033]|0}}while(0);do{if((I&2048|0)!=0){if((a[808140]|0)==0){c[202033]=I&-2049;break}if((a[808141]|0)!=0){a[808141]=0;b[404048]=(b[404048]|0)+1&65535}if((a[808082]&4)!=0){break}if((b[404041]&256)==0){h=a[808098|0]|0;v=b[404044]|0;b[404044]=v-1&65535;HY(h,v&65535);v=b[404048]|0;h=(e[404044]|0)-1|0;HY((v&65535)>>>8&255,(h&65535)+1&65535|h&-65536);HY(v&255,h);h=b[404044]|0;v=a[808082]&60|a[808120]|a[808122]&-128|((a[808121]|0)==0)<<1|a[808123]<<6;a[808082]=v;b[404044]=h-3&65535;HY(v,h-2&65535);a[808082]=a[808082]&-13|4;h=c[263195]|0;v=a[h+8712|0]|0;a[808104]=v;HR((v&255)<<8|d[h+8711|0]);break}else{a[808088]=(a[808088]|0)-1&255;h=b[404048]|0;v=b[404044]|0;HY((h&65535)>>>8&255,((v&255)+1&255|v&-256)&65535);HY(h&255,v&65535);a[808088]=(a[808088]|0)-1&255;v=a[808082]&60|a[808120]|a[808122]&-128|((a[808121]|0)==0)<<1|a[808123]<<6;a[808082]=v;HY(v,e[404044]|0);a[808088]=(a[808088]|0)-1&255;a[808082]=a[808082]&-13|4;v=c[263195]|0;h=a[v+8712|0]|0;a[808104]=h;HR((h&255)<<8|d[v+8711|0]);break}}}while(0);if((a[(c[263195]|0)+8704|0]&96)!=0){continue}v=c[202034]|0;if((v|0)==0){h=TP(c[202024]|0)|0;J=148536;K=h;L=b[404048]|0}else{h=b[404048]|0;u=a[v+(h&65535)|0]|0;a[808104]=u;J=c[202028]|0;K=u;L=h}h=K&255;if(((d[(c[202029]|0)+h|0]|0)+(L&4095)|0)>4095){u=c[202024]|0;HR(u);c[202024]=u;M=148536;N=u&65535}else{M=J;N=L}b[404048]=N+1&65535;fz[c[M+(h<<2)>>2]&8191]();h=c[202034]|0;if((h|0)==0){u=TP(c[202024]|0)|0;O=148536;P=u;Q=b[404048]|0}else{u=b[404048]|0;v=a[h+(u&65535)|0]|0;a[808104]=v;O=c[202028]|0;P=v;Q=u}u=P&255;if(((d[(c[202029]|0)+u|0]|0)+(Q&4095)|0)>4095){v=c[202024]|0;HR(v);c[202024]=v;R=148536;S=v&65535}else{R=O;S=Q}b[404048]=S+1&65535;fz[c[R+(u<<2)>>2]&8191]();u=c[202034]|0;if((u|0)==0){v=TP(c[202024]|0)|0;T=148536;U=v;V=b[404048]|0}else{v=b[404048]|0;h=a[u+(v&65535)|0]|0;a[808104]=h;T=c[202028]|0;U=h;V=v}v=U&255;if(((d[(c[202029]|0)+v|0]|0)+(V&4095)|0)>4095){h=c[202024]|0;HR(h);c[202024]=h;W=148536;X=h&65535}else{W=T;X=V}b[404048]=X+1&65535;fz[c[W+(v<<2)>>2]&8191]()}a[1041658]=a[1041658]&60|a[1106736]|a[1106720]&-128|((a[1106728]|0)==0)<<1|a[1106712]<<6;c[348395]=z&-17;if(!(ft[c[198896]&63](17,g)|0)){i=f;return}if((a[g]&1)==0){i=f;return}XO();i=f;return}function XO(){var a=0,b=0,d=0;a=i;i=i+8|0;b=a|0;c[b>>2]=0;c[b+4>>2]=0;c[b>>2]=70464;if(!(ft[c[198896]&63](15,b)|0)){i=a;return}d=b+4|0;ec(c[p>>2]|0,61912,(b=i,i=i+8|0,c[b>>2]=c[d>>2],b)|0)|0;i=b;b=c[d>>2]|0;do{if((cL(b|0,61048)|0)==0){g[201849]=4378500.0}else{if((cL(b|0,59992)|0)==0){g[201849]=16888500.0;break}if((cL(b|0,59e3)|0)==0){g[201849]=25228500.0;break}if((cL(b|0,58312)|0)==0){g[201849]=33568500.0;break}if((cL(b|0,57632)|0)==0){g[201849]=41908500.0;break}else{i=a;return}}}while(0);xY();i=a;return}function XP(){var a=0,b=0,d=0,e=0;a=XY(5e6)|0;c[198888]=a;c[133748]=5e6;do{if((a|0)!=0){b=XY(12)|0;d=(b|0)==0;do{if(!d){if((c[b-4>>2]&3|0)==0){break}X2(b|0,0,12)}}while(0);c[b>>2]=a;c[b+4>>2]=5e6;e=b+8|0;c[e>>2]=0;c[198888]=0;c[133748]=0;if(d){break}T_(b);c[125856]=c[e>>2];XZ(b)}}while(0);XZ(a);return c[125856]|0}function XQ(a,b){a=a|0;b=b|0;var d=0,e=0,f=0;c[198888]=a;c[133748]=b;if(!((a|0)!=0&(b|0)!=0)){d=0;return d|0}e=XY(12)|0;f=(e|0)==0;do{if(!f){if((c[e-4>>2]&3|0)==0){break}X2(e|0,0,12)}}while(0);c[e>>2]=a;c[e+4>>2]=b;b=e+8|0;c[b>>2]=0;c[198888]=0;c[133748]=0;if(f){d=0;return d|0}T_(e);c[125856]=c[b>>2];XZ(e);d=1;return d|0}function XR(f,g){f=f|0;g=g|0;var h=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0,aH=0,aI=0,aJ=0,aK=0,aL=0,aM=0,aN=0,aO=0,aP=0,aQ=0,aR=0,aS=0,aT=0,aU=0,aV=0,aW=0,aX=0,aY=0,aZ=0,a_=0,a$=0,a0=0,a1=0,a2=0,a3=0,a4=0,a5=0,a6=0,a7=0,a8=0,a9=0,ba=0,bb=0,bc=0,bd=0,be=0,bf=0,bg=0,bh=0,bi=0,bj=0,bk=0,bl=0,bm=0,bn=0,bo=0,bp=0,bq=0,br=0,bs=0,bt=0,bu=0,bv=0,bw=0,bx=0,by=0,bz=0,bA=0,bB=0,bC=0,bD=0,bE=0,bF=0,bG=0,bH=0,bI=0,bK=0,bL=0,bM=0,bN=0,bO=0,bP=0;h=i;i=i+4400|0;j=h|0;k=h+16|0;l=h+32|0;m=h+208|0;n=h+296|0;c[198888]=f;c[133748]=g;do{if((f|0)!=0&(g|0)!=0){o=XY(12)|0;p=(o|0)==0;do{if(!p){if((c[o-4>>2]&3|0)==0){break}X2(o|0,0,12)}}while(0);c[o>>2]=f;c[o+4>>2]=g;q=o+8|0;c[q>>2]=0;c[198888]=0;c[133748]=0;if(p){break}r=o;s=l|0;t=m|0;u=n|0;v=g>>>0<14?g:14;X5(u|0,f|0,v)|0;c[q>>2]=v;do{if((v|0)==14){if((bJ(u|0,96728,8)|0)!=0){x=-1;break}y=e1(n+9|0)|0;if((y|0)>6){x=-2;break}z=T0(r,57192,u,4096)|0;if((z|0)==1){A=0;B=0}else{x=z;break}while(1){do{if((e[145832+(A*24|0)>>1]|0)>(y|0)){C=B}else{if((e[145834+(A*24|0)>>1]|0)<=(y|0)){C=B;break}z=c[145824+(A*24|0)>>2]|0;D=c[145828+(A*24|0)>>2]|0;if((D|0)==3|(D|0)==6){E=z<<2}else if((D|0)==2|(D|0)==5){E=z<<1}else{E=z}C=E+B|0}}while(0);z=A+1|0;if((z|0)<17){A=z;B=C}else{break}}z=XY(C)|0;D=T0(r,56496,z,C)|0;if((D|0)==1){F=0;G=0}else{XZ(z);x=D;break}while(1){do{if((e[105776+(F*24|0)>>1]|0)>(y|0)){H=G}else{if((e[105778+(F*24|0)>>1]|0)<=(y|0)){H=G;break}D=c[105768+(F*24|0)>>2]|0;I=c[105772+(F*24|0)>>2]|0;if((I|0)==3|(I|0)==6){J=D<<2}else if((I|0)==2|(I|0)==5){J=D<<1}else{J=D}H=J+G|0}}while(0);D=F+1|0;if((D|0)<9){F=D;G=H}else{break}}D=XY(H)|0;I=T0(r,47440,D,H)|0;do{if((I|0)==1){K=0;L=0;while(1){do{if((e[105992+(K*24|0)>>1]|0)>(y|0)){M=L}else{if((e[105994+(K*24|0)>>1]|0)<=(y|0)){M=L;break}N=c[105984+(K*24|0)>>2]|0;O=c[105988+(K*24|0)>>2]|0;if((O|0)==3|(O|0)==6){P=N<<2}else if((O|0)==2|(O|0)==5){P=N<<1}else{P=N}M=P+L|0}}while(0);N=K+1|0;if((N|0)<1158){K=N;L=M}else{break}}L=XY(M)|0;K=T0(r,40488,L,M)|0;if((K|0)==1){Q=0;R=0}else{XZ(L);S=D;T=0;U=0;V=0;W=0;X=0;Y=0;Z=0;_=0;$=0;aa=0;ab=0;ac=0;ad=0;ae=0;af=0;ag=0;ah=0;ai=0;aj=0;ak=0;al=0;am=0;an=0;ao=K;break}while(1){do{if((e[142520+(Q*24|0)>>1]|0)>(y|0)){ap=R}else{if((e[142522+(Q*24|0)>>1]|0)<=(y|0)){ap=R;break}K=c[142512+(Q*24|0)>>2]|0;N=c[142516+(Q*24|0)>>2]|0;if((N|0)==3|(N|0)==6){aq=K<<2}else if((N|0)==2|(N|0)==5){aq=K<<1}else{aq=K}ap=aq+R|0}}while(0);K=Q+1|0;if((K|0)<128){Q=K;R=ap}else{break}}K=XY(ap)|0;N=T0(r,35784,K,ap)|0;if((N|0)!=1){XZ(K);S=D;T=L;U=0;V=0;W=0;X=0;Y=0;Z=0;_=0;$=0;aa=0;ab=0;ac=0;ad=0;ae=0;af=0;ag=0;ah=0;ai=0;aj=0;ak=0;al=0;am=0;an=0;ao=N;break}N=XY(65536)|0;O=T0(r,31152,N,65536)|0;if((O|0)!=1){XZ(N);S=D;T=L;U=K;V=0;W=0;X=0;Y=0;Z=0;_=0;$=0;aa=0;ab=0;ac=0;ad=0;ae=0;af=0;ag=0;ah=0;ai=0;aj=0;ak=0;al=0;am=0;an=0;ao=O;break}O=XY(131072)|0;ar=T0(r,27312,O,131072)|0;if((ar|0)!=1){XZ(O);S=D;T=L;U=K;V=N;W=0;X=0;Y=0;Z=0;_=0;$=0;aa=0;ab=0;ac=0;ad=0;ae=0;af=0;ag=0;ah=0;ai=0;aj=0;ak=0;al=0;am=0;an=0;ao=ar;break}ar=XY(131072)|0;as=T0(r,23080,ar,131072)|0;if((as|0)!=1){XZ(ar);S=D;T=L;U=K;V=N;W=O;X=0;Y=0;Z=0;_=0;$=0;aa=0;ab=0;ac=0;ad=0;ae=0;af=0;ag=0;ah=0;ai=0;aj=0;ak=0;al=0;am=0;an=0;ao=as;break}as=XY(32768)|0;at=T0(r,100888,as,32768)|0;if((at|0)!=1){XZ(as);S=D;T=L;U=K;V=N;W=O;X=ar;Y=0;Z=0;_=0;$=0;aa=0;ab=0;ac=0;ad=0;ae=0;af=0;ag=0;ah=0;ai=0;aj=0;ak=0;al=0;am=0;an=0;ao=at;break}at=XY(69640)|0;au=T0(r,96512,at,69640)|0;if((au|0)==1){av=0;aw=0}else{XZ(at);S=D;T=L;U=K;V=N;W=O;X=ar;Y=as;Z=0;_=0;$=0;aa=0;ab=0;ac=0;ad=0;ae=0;af=0;ag=0;ah=0;ai=0;aj=0;ak=0;al=0;am=0;an=0;ao=au;break}while(1){do{if((e[145592+(av*24|0)>>1]|0)>(y|0)){ax=aw}else{if((e[145594+(av*24|0)>>1]|0)<=(y|0)){ax=aw;break}au=c[145584+(av*24|0)>>2]|0;ay=c[145588+(av*24|0)>>2]|0;if((ay|0)==3|(ay|0)==6){az=au<<2}else if((ay|0)==2|(ay|0)==5){az=au<<1}else{az=au}ax=az+aw|0}}while(0);au=av+1|0;if((au|0)<10){av=au;aw=ax}else{break}}au=XY(ax)|0;ay=T0(r,92256,au,ax)|0;if((ay|0)==1){aA=0;aB=0}else{XZ(au);S=D;T=L;U=K;V=N;W=O;X=ar;Y=as;Z=at;_=0;$=0;aa=0;ab=0;ac=0;ad=0;ae=0;af=0;ag=0;ah=0;ai=0;aj=0;ak=0;al=0;am=0;an=0;ao=ay;break}while(1){do{if((e[101744+(aA*24|0)>>1]|0)>(y|0)){aC=aB}else{if((e[101746+(aA*24|0)>>1]|0)<=(y|0)){aC=aB;break}ay=c[101736+(aA*24|0)>>2]|0;aD=c[101740+(aA*24|0)>>2]|0;if((aD|0)==3|(aD|0)==6){aE=ay<<2}else if((aD|0)==2|(aD|0)==5){aE=ay<<1}else{aE=ay}aC=aE+aB|0}}while(0);ay=aA+1|0;if((ay|0)<16){aA=ay;aB=aC}else{break}}ay=XY(aC)|0;aD=T0(r,88720,ay,aC)|0;if((aD|0)==1){aF=0;aG=0}else{XZ(ay);S=D;T=L;U=K;V=N;W=O;X=ar;Y=as;Z=at;_=au;$=0;aa=0;ab=0;ac=0;ad=0;ae=0;af=0;ag=0;ah=0;ai=0;aj=0;ak=0;al=0;am=0;an=0;ao=aD;break}while(1){do{if((e[133856+(aF*24|0)>>1]|0)>(y|0)){aH=aG}else{if((e[133858+(aF*24|0)>>1]|0)<=(y|0)){aH=aG;break}aD=c[133848+(aF*24|0)>>2]|0;aI=c[133852+(aF*24|0)>>2]|0;if((aI|0)==3|(aI|0)==6){aJ=aD<<2}else if((aI|0)==2|(aI|0)==5){aJ=aD<<1}else{aJ=aD}aH=aJ+aG|0}}while(0);aD=aF+1|0;if((aD|0)<79){aF=aD;aG=aH}else{break}}aD=XY(aH)|0;aI=T0(r,85568,aD,aH)|0;if((aI|0)==1){aK=aD}else{XZ(aD);if((a[799121]|0)==0){aK=0}else{S=D;T=L;U=K;V=N;W=O;X=ar;Y=as;Z=at;_=au;$=ay;aa=0;ab=0;ac=0;ad=0;ae=0;af=0;ag=0;ah=0;ai=0;aj=0;ak=0;al=0;am=0;an=0;ao=aI;break}}aI=0;aD=0;while(1){do{if((e[105464+(aI*24|0)>>1]|0)>(y|0)){aL=aD}else{if((e[105466+(aI*24|0)>>1]|0)<=(y|0)){aL=aD;break}aM=c[105456+(aI*24|0)>>2]|0;aN=c[105460+(aI*24|0)>>2]|0;if((aN|0)==3|(aN|0)==6){aO=aM<<2}else if((aN|0)==2|(aN|0)==5){aO=aM<<1}else{aO=aM}aL=aO+aD|0}}while(0);aM=aI+1|0;if((aM|0)<13){aI=aM;aD=aL}else{break}}aD=XY(aL)|0;aI=T0(r,82120,aD,aL)|0;if((aI|0)==1){aP=aD}else{XZ(aD);if((a[799123]|0)==0){aP=0}else{S=D;T=L;U=K;V=N;W=O;X=ar;Y=as;Z=at;_=au;$=ay;aa=aK;ab=0;ac=0;ad=0;ae=0;af=0;ag=0;ah=0;ai=0;aj=0;ak=0;al=0;am=0;an=0;ao=aI;break}}aI=0;aD=0;while(1){do{if((e[105248+(aI*24|0)>>1]|0)>(y|0)){aQ=aD}else{if((e[105250+(aI*24|0)>>1]|0)<=(y|0)){aQ=aD;break}aM=c[105240+(aI*24|0)>>2]|0;aN=c[105244+(aI*24|0)>>2]|0;if((aN|0)==3|(aN|0)==6){aR=aM<<2}else if((aN|0)==2|(aN|0)==5){aR=aM<<1}else{aR=aM}aQ=aR+aD|0}}while(0);aM=aI+1|0;if((aM|0)<9){aI=aM;aD=aQ}else{break}}aD=XY(aQ)|0;aI=T0(r,78736,aD,aQ)|0;if((aI|0)==1){aS=aD}else{XZ(aD);if((a[799123]|0)==0){aS=0}else{S=D;T=L;U=K;V=N;W=O;X=ar;Y=as;Z=at;_=au;$=ay;aa=aK;ab=aP;ac=0;ad=0;ae=0;af=0;ag=0;ah=0;ai=0;aj=0;ak=0;al=0;am=0;an=0;ao=aI;break}}aI=0;aD=0;while(1){do{if((e[137864+(aI*24|0)>>1]|0)>(y|0)){aT=aD}else{if((e[137866+(aI*24|0)>>1]|0)<=(y|0)){aT=aD;break}aM=c[137856+(aI*24|0)>>2]|0;aN=c[137860+(aI*24|0)>>2]|0;if((aN|0)==3|(aN|0)==6){aU=aM<<2}else if((aN|0)==2|(aN|0)==5){aU=aM<<1}else{aU=aM}aT=aU+aD|0}}while(0);aM=aI+1|0;if((aM|0)<194){aI=aM;aD=aT}else{break}}aD=XY(aT)|0;aI=T0(r,75456,aD,aT)|0;if((aI|0)==1){aV=aD}else{XZ(aD);if((a[799122]|0)==1){S=D;T=L;U=K;V=N;W=O;X=ar;Y=as;Z=at;_=au;$=ay;aa=aK;ab=aP;ac=aS;ad=0;ae=0;af=0;ag=0;ah=0;ai=0;aj=0;ak=0;al=0;am=0;an=0;ao=aI;break}else{aV=0}}aI=0;aD=0;while(1){do{if((e[137432+(aI*24|0)>>1]|0)>(y|0)){aW=aD}else{if((e[137434+(aI*24|0)>>1]|0)<=(y|0)){aW=aD;break}aM=c[137424+(aI*24|0)>>2]|0;aN=c[137428+(aI*24|0)>>2]|0;if((aN|0)==3|(aN|0)==6){aX=aM<<2}else if((aN|0)==2|(aN|0)==5){aX=aM<<1}else{aX=aM}aW=aX+aD|0}}while(0);aM=aI+1|0;if((aM|0)<18){aI=aM;aD=aW}else{break}}aD=XY(aW)|0;aI=T0(r,72520,aD,aW)|0;if((aI|0)==1){aY=aD}else{XZ(aD);if((a[799122]|0)==2){S=D;T=L;U=K;V=N;W=O;X=ar;Y=as;Z=at;_=au;$=ay;aa=aK;ab=aP;ac=aS;ad=aV;ae=0;af=0;ag=0;ah=0;ai=0;aj=0;ak=0;al=0;am=0;an=0;ao=aI;break}else{aY=0}}aI=0;aD=0;while(1){do{if((e[135752+(aI*24|0)>>1]|0)>(y|0)){aZ=aD}else{if((e[135754+(aI*24|0)>>1]|0)<=(y|0)){aZ=aD;break}aM=c[135744+(aI*24|0)>>2]|0;aN=c[135748+(aI*24|0)>>2]|0;if((aN|0)==3|(aN|0)==6){a_=aM<<2}else if((aN|0)==2|(aN|0)==5){a_=aM<<1}else{a_=aM}aZ=a_+aD|0}}while(0);aM=aI+1|0;if((aM|0)<70){aI=aM;aD=aZ}else{break}}aD=XY(aZ)|0;aI=T0(r,70056,aD,aZ)|0;if((aI|0)==1){a$=aD}else{XZ(aD);if((a[799122]|0)==4){S=D;T=L;U=K;V=N;W=O;X=ar;Y=as;Z=at;_=au;$=ay;aa=aK;ab=aP;ac=aS;ad=aV;ae=aY;af=0;ag=0;ah=0;ai=0;aj=0;ak=0;al=0;am=0;an=0;ao=aI;break}else{a$=0}}aI=XY(8192)|0;aD=T0(r,68888,aI,8192)|0;if((aD|0)==1){a0=aI}else{XZ(aI);if((a[799124]|0)==0){a0=0}else{S=D;T=L;U=K;V=N;W=O;X=ar;Y=as;Z=at;_=au;$=ay;aa=aK;ab=aP;ac=aS;ad=aV;ae=aY;af=a$;ag=0;ah=0;ai=0;aj=0;ak=0;al=0;am=0;an=0;ao=aD;break}}do{if((e[51064]|0)>(y|0)){a1=0}else{if((e[51065]|0)<=(y|0)){a1=0;break}aD=c[25530]|0;aI=c[25531]|0;if((aI|0)==3|(aI|0)==6){a1=aD<<2;break}else if((aI|0)==2|(aI|0)==5){a1=aD<<1;break}else{a1=aD;break}}}while(0);do{if((e[51076]|0)>(y|0)){a2=a1}else{if((e[51077]|0)<=(y|0)){a2=a1;break}aD=c[25536]|0;aI=c[25537]|0;if((aI|0)==2|(aI|0)==5){a3=aD<<1}else if((aI|0)==3|(aI|0)==6){a3=aD<<2}else{a3=aD}a2=a3+a1|0}}while(0);do{if((e[51088]|0)>(y|0)){a4=a2}else{if((e[51089]|0)<=(y|0)){a4=a2;break}aD=c[25542]|0;aI=c[25543]|0;if((aI|0)==2|(aI|0)==5){a5=aD<<1}else if((aI|0)==3|(aI|0)==6){a5=aD<<2}else{a5=aD}a4=a5+a2|0}}while(0);do{if((e[51100]|0)>(y|0)){a6=a4}else{if((e[51101]|0)<=(y|0)){a6=a4;break}aD=c[25548]|0;aI=c[25549]|0;if((aI|0)==2|(aI|0)==5){a7=aD<<1}else if((aI|0)==3|(aI|0)==6){a7=aD<<2}else{a7=aD}a6=a7+a4|0}}while(0);do{if((e[51112]|0)>(y|0)){a8=a6}else{if((e[51113]|0)<=(y|0)){a8=a6;break}aD=c[25554]|0;aI=c[25555]|0;if((aI|0)==2|(aI|0)==5){a9=aD<<1}else if((aI|0)==3|(aI|0)==6){a9=aD<<2}else{a9=aD}a8=a9+a6|0}}while(0);aD=XY(a8)|0;aI=T0(r,67256,aD,a8)|0;if((aI|0)==1){ba=aD}else{XZ(aD);if((a[799129]|0)==1){S=D;T=L;U=K;V=N;W=O;X=ar;Y=as;Z=at;_=au;$=ay;aa=aK;ab=aP;ac=aS;ad=aV;ae=aY;af=a$;ag=a0;ah=0;ai=0;aj=0;ak=0;al=0;am=0;an=0;ao=aI;break}else{ba=0}}do{if((e[66892]|0)>(y|0)){bb=0}else{if((e[66893]|0)<=(y|0)){bb=0;break}aI=c[33444]|0;aD=c[33445]|0;if((aD|0)==3|(aD|0)==6){bb=aI<<2;break}else if((aD|0)==2|(aD|0)==5){bb=aI<<1;break}else{bb=aI;break}}}while(0);do{if((e[66904]|0)>(y|0)){bc=bb}else{if((e[66905]|0)<=(y|0)){bc=bb;break}aI=c[33450]|0;aD=c[33451]|0;if((aD|0)==2|(aD|0)==5){bd=aI<<1}else if((aD|0)==3|(aD|0)==6){bd=aI<<2}else{bd=aI}bc=bd+bb|0}}while(0);do{if((e[66916]|0)>(y|0)){be=bc}else{if((e[66917]|0)<=(y|0)){be=bc;break}aI=c[33456]|0;aD=c[33457]|0;if((aD|0)==2|(aD|0)==5){bf=aI<<1}else if((aD|0)==3|(aD|0)==6){bf=aI<<2}else{bf=aI}be=bf+bc|0}}while(0);aI=XY(be)|0;aD=T0(r,65120,aI,be)|0;if((aD|0)==1){bg=aI}else{XZ(aI);if((a[799128]|0)==0){bg=0}else{S=D;T=L;U=K;V=N;W=O;X=ar;Y=as;Z=at;_=au;$=ay;aa=aK;ab=aP;ac=aS;ad=aV;ae=aY;af=a$;ag=a0;ah=ba;ai=0;aj=0;ak=0;al=0;am=0;an=0;ao=aD;break}}aD=XY(8192)|0;aI=T0(r,63528,aD,8192)|0;if((aI|0)==1){bh=aD}else{XZ(aD);if((a[799128]|0)==0){bh=0}else{S=D;T=L;U=K;V=N;W=O;X=ar;Y=as;Z=at;_=au;$=ay;aa=aK;ab=aP;ac=aS;ad=aV;ae=aY;af=a$;ag=a0;ah=ba;ai=bg;aj=0;ak=0;al=0;am=0;an=0;ao=aI;break}}aI=0;aD=0;while(1){do{if((e[102296+(aI*24|0)>>1]|0)>(y|0)){bi=aD}else{if((e[102298+(aI*24|0)>>1]|0)<=(y|0)){bi=aD;break}aM=c[102288+(aI*24|0)>>2]|0;aN=c[102292+(aI*24|0)>>2]|0;if((aN|0)==3|(aN|0)==6){bj=aM<<2}else if((aN|0)==2|(aN|0)==5){bj=aM<<1}else{bj=aM}bi=bj+aD|0}}while(0);aM=aI+1|0;if((aM|0)<123){aI=aM;aD=bi}else{break}}aD=XY(bi)|0;aI=T0(r,62160,aD,bi)|0;if((aI|0)==1){bk=aD}else{XZ(aD);if((a[799126]|0)==0){bk=0}else{S=D;T=L;U=K;V=N;W=O;X=ar;Y=as;Z=at;_=au;$=ay;aa=aK;ab=aP;ac=aS;ad=aV;ae=aY;af=a$;ag=a0;ah=ba;ai=bg;aj=bh;ak=0;al=0;am=0;an=0;ao=aI;break}}do{if((e[51124]|0)>(y|0)){bl=0}else{if((e[51125]|0)<=(y|0)){bl=0;break}aI=c[25560]|0;aD=c[25561]|0;if((aD|0)==3|(aD|0)==6){bl=aI<<2;break}else if((aD|0)==2|(aD|0)==5){bl=aI<<1;break}else{bl=aI;break}}}while(0);do{if((e[51136]|0)>(y|0)){bm=bl}else{if((e[51137]|0)<=(y|0)){bm=bl;break}aI=c[25566]|0;aD=c[25567]|0;if((aD|0)==2|(aD|0)==5){bn=aI<<1}else if((aD|0)==3|(aD|0)==6){bn=aI<<2}else{bn=aI}bm=bn+bl|0}}while(0);aI=XY(bm)|0;aD=T0(r,61248,aI,bm)|0;if((aD|0)==1){bo=aI}else{XZ(aI);if((a[799130]|0)==0){bo=0}else{S=D;T=L;U=K;V=N;W=O;X=ar;Y=as;Z=at;_=au;$=ay;aa=aK;ab=aP;ac=aS;ad=aV;ae=aY;af=a$;ag=a0;ah=ba;ai=bg;aj=bh;ak=bk;al=0;am=0;an=0;ao=aD;break}}aD=XY(20)|0;aI=T0(r,60128,aD,20)|0;if((aI|0)==1){bp=aD}else{XZ(aD);if((a[799127]|a[799130])<<24>>24==0){bp=0}else{S=D;T=L;U=K;V=N;W=O;X=ar;Y=as;Z=at;_=au;$=ay;aa=aK;ab=aP;ac=aS;ad=aV;ae=aY;af=a$;ag=a0;ah=ba;ai=bg;aj=bh;ak=bk;al=bo;am=0;an=0;ao=aI;break}}aI=0;aD=0;while(1){do{if((e[146240+(aI*24|0)>>1]|0)>(y|0)){bq=aD}else{if((e[146242+(aI*24|0)>>1]|0)<=(y|0)){bq=aD;break}aM=c[146232+(aI*24|0)>>2]|0;aN=c[146236+(aI*24|0)>>2]|0;if((aN|0)==3|(aN|0)==6){br=aM<<2}else if((aN|0)==2|(aN|0)==5){br=aM<<1}else{br=aM}bq=br+aD|0}}while(0);aM=aI+1|0;if((aM|0)<15){aI=aM;aD=bq}else{break}}aD=XY(bq)|0;aI=T0(r,59224,aD,bq)|0;if((aI|0)==1){bs=aD}else{XZ(aD);aD=(a[799131]|0)==0?1:aI;if((aD|0)==1){bs=0}else{S=D;T=L;U=K;V=N;W=O;X=ar;Y=as;Z=at;_=au;$=ay;aa=aK;ab=aP;ac=aS;ad=aV;ae=aY;af=a$;ag=a0;ah=ba;ai=bg;aj=bh;ak=bk;al=bo;am=bp;an=0;ao=aD;break}}aD=c[348395]|0;aI=c[202033]|0;j_();T1(1393568,145816,17,z,y);T1(1041656,105760,9,D,y);T1(1041704,105976,1158,L,y);T1(s,142504,128,K,y);aM=c[263194]|0;X5(aM|0,N|0,65536)|0;aM=c[263191]|0;X5(aM|0,O|0,131072)|0;aM=c[263193]|0;X5(aM|0,ar|0,131072)|0;aM=c[263195]|0;X5(aM|0,as|0,32768)|0;jE();aM=j|0;if((c[109245]|0)!=0){c[199301]=0;c[109245]=0;X5(503096,437048,64)|0}X5(437624,at|0,65536)|0;aN=at+65536|0;bt=at+65552|0;X5(aM|0,bt|0,16)|0;bt=at+65568|0;X9(436864,aN|0,16);X5(436880,aM|0,16)|0;aM=d[436865]|0;aN=aM&128;if((aN|0)!=0){c[199301]=aN;c[109245]=aN;X5(437048,503096,64)|0;X5(503096,436984,64)|0}c[109224]=d[at+65569|0]<<8|d[bt];c[109225]=d[at+65570|0]|0;c[109226]=d[at+65571|0]|0;c[109227]=d[at+65572|0]|0;c[109228]=d[at+65573|0]|0;c[109229]=d[at+65574|0]|0;bt=a[at+65575|0]|0;aN=at+65576|0;if(bt<<24>>24==0){bu=aN}else{bv=bt&255;bt=aN;while(1){aN=(bv|0)<64?bv:64;bw=bt+aN|0;if((bv|0)==(aN|0)){bu=bw;break}else{bv=bv-aN|0;bt=bw}}}c[109231]=(d[bu+1|0]<<8|d[bu])<<16>>16;bt=bu+4|0;c[109230]=(d[bu+3|0]<<8|d[bu+2|0])<<16>>16;X5(795648,bt|0,128)|0;bt=0;bv=bu+132|0;while(1){bw=0;aN=bv;while(1){bx=(d[aN+1|0]<<8|d[aN])<<16>>16;c[796036+(bt*140|0)+(bw+12<<2)>>2]=bx;c[796036+(bt*140|0)+(bw<<2)>>2]=bx;bx=bw+1|0;if((bx|0)<12){bw=bx;aN=aN+2|0}else{break}}c[796136+(bt*140|0)>>2]=d[bv+25|0]<<8|d[bv+24|0];c[796140+(bt*140|0)>>2]=d[bv+27|0]<<8|d[bv+26|0];c[796164+(bt*140|0)>>2]=d[bv+29|0]<<8|d[bv+28|0];c[796168+(bt*140|0)>>2]=(d[bv+31|0]<<8|d[bv+30|0])<<16>>16;c[796132+(bt*140|0)>>2]=d[bv+32|0]|0;c[796144+(bt*140|0)>>2]=d[bv+33|0]|0;c[796156+(bt*140|0)>>2]=d[bv+34|0]|0;c[796160+(bt*140|0)>>2]=d[bv+35|0]|0;a[796172+(bt*140|0)|0]=a[bv+36|0]|0;aN=a[bv+37|0]|0;bw=bv+38|0;if(aN<<24>>24==0){by=bw}else{bx=aN&255;aN=bw;while(1){bw=(bx|0)<64?bx:64;bz=aN+bw|0;if((bx|0)==(bw|0)){by=bz;break}else{bx=bx-bw|0;aN=bz}}}aN=bt+1|0;if((aN|0)<8){bt=aN;bv=by}else{bA=0;bB=by;break}}while(1){c[795776+(bA<<3)>>2]=(d[bB+1|0]<<8|d[bB])<<16>>16;c[795780+(bA<<3)>>2]=(d[bB+3|0]<<8|d[bB+2|0])<<16>>16;bv=bA+1|0;if((bv|0)<8){bA=bv;bB=bB+4|0}else{break}}bv=by+32|0;c[198976]=795776;X5(795840,795776,64)|0;c[198977]=d[bv]|0;c[198978]=d[by+33|0]|0;c[198979]=d[by+35|0]<<8|d[by+34|0];c[198980]=d[by+37|0]<<8|d[by+36|0];c[198981]=d[by+39|0]<<8|d[by+38|0];c[198982]=d[by+41|0]<<8|d[by+40|0];c[198983]=d[by+42|0]|0;c[198984]=d[by+43|0]|0;a[795940]=a[by+44|0]|0;a[795941]=a[by+45|0]|0;a[795942]=a[by+46|0]|0;c[198986]=d[by+47|0]|0;c[198987]=d[by+48|0]|0;c[198988]=d[by+49|0]|0;c[198989]=d[by+50|0]|0;c[198990]=d[by+51|0]|0;c[198991]=d[by+53|0]<<8|d[by+52|0];c[198992]=d[by+54|0]|0;c[198993]=d[by+55|0]|0;c[198994]=d[by+56|0]|0;c[198995]=d[by+57|0]|0;c[198996]=d[by+58|0]|0;c[198997]=d[by+59|0]|0;c[199003]=(d[by+61|0]<<8|d[by+60|0])<<16>>16;c[199004]=(d[by+63|0]<<8|d[by+62|0])<<16>>16;c[199005]=(d[by+65|0]<<8|d[by+64|0])<<16>>16;c[199006]=(d[by+67|0]<<8|d[by+66|0])<<16>>16;c[199007]=(d[by+69|0]<<8|d[by+68|0])<<16>>16;c[199008]=(d[by+71|0]<<8|d[by+70|0])<<16>>16;c[198998]=d[by+73|0]<<8|d[by+72|0];c[198999]=d[by+75|0]<<8|d[by+74|0];c[199e3]=(d[by+77|0]<<8|d[by+76|0])<<16>>16;c[199002]=d[by+79|0]<<8|d[by+78|0];c[199001]=d[by+80|0]|0;bv=a[by+81|0]|0;bt=by+82|0;if(bv<<24>>24==0){bC=bt}else{aN=bv&255;bv=bt;while(1){bt=(aN|0)<64?aN:64;bx=bv+bt|0;if((aN|0)==(bt|0)){bC=bx;break}else{aN=aN-bt|0;bv=bx}}}c[109200]=((a[436874]|0)-1&255)+1;c[109202]=aM&1;c[109198]=(d[bC+1|0]<<8|d[bC])<<16>>16;c[109201]=d[bC+2|0]|0;c[109203]=d[bC+3|0]|0;bv=a[bC+4|0]|0;aN=bC+5|0;if(bv<<24>>24==0){bD=aN}else{bx=bv&255;bv=aN;while(1){aN=(bx|0)<64?bx:64;bt=bv+aN|0;if((bx|0)==(aN|0)){bD=bt;break}else{bx=bx-aN|0;bv=bt}}}c[109206]=((a[436875]|0)-1&255)+1;c[109208]=aM>>>1&1;c[109204]=(d[bD+1|0]<<8|d[bD])<<16>>16;c[109207]=d[bD+2|0]|0;c[109209]=d[bD+3|0]|0;bv=a[bD+4|0]|0;bx=bD+5|0;if(bv<<24>>24==0){bE=bx}else{bt=bv&255;bv=bx;while(1){bx=(bt|0)<64?bt:64;aN=bv+bx|0;if((bt|0)==(bx|0)){bE=aN;break}else{bt=bt-bx|0;bv=aN}}}c[109212]=((a[436876]|0)-1&255)+1;c[109214]=aM>>>2&1;c[109210]=(d[bE+1|0]<<8|d[bE])<<16>>16;c[109213]=d[bE+2|0]|0;c[109215]=d[bE+3|0]|0;bv=a[bE+4|0]|0;bt=bE+5|0;if(bv<<24>>24==0){bF=bt}else{aN=bv&255;bv=bt;while(1){bt=(aN|0)<64?aN:64;bx=bv+bt|0;if((aN|0)==(bt|0)){bF=bx;break}else{aN=aN-bt|0;bv=bx}}}c[109211]=4;c[109205]=7;c[109199]=7;bv=a[bF]|0;aN=bF+1|0;if(bv<<24>>24==0){bG=aN}else{aM=bv&255;bv=aN;while(1){aN=(aM|0)<64?aM:64;bx=bv+aN|0;if((aM|0)==(aN|0)){bG=bx;break}else{aM=aM-aN|0;bv=bx}}}c[59e3]=d[bG+2|0]<<16|d[bG+3|0]<<24|d[bG+1|0]<<8|d[bG];c[42380]=d[bG+6|0]<<16|d[bG+7|0]<<24|d[bG+5|0]<<8|d[bG+4|0];T1(t,145576,10,au,y);T1(798960,101728,16,ay,y);if((aK|0)!=0){c[277210]=1106800;T1(1106800,133840,79,aK,y)}bv=(aP|0)==0;if(!bv){T1(808112,105448,13,aP,y)}aM=(aS|0)==0;if(!aM){T1(808080,105232,9,aS,y)}if((aV|0)!=0){T1(1182304,137848,194,aV,y)}if((aY|0)!=0){T1(1181224,137416,18,aY,y)}if((a$|0)!=0){T1(1129624,135736,70,a$,y)}if((a0|0)!=0){bx=c[263197]|0;X5(bx|0,a0|0,8192)|0}if((ba|0)!=0){T1(808032,102112,5,ba,y)}if((bg|0)!=0){T1(1044512,133768,3,bg,y)}if((bh|0)!=0){bx=c[263198]|0;X5(bx|0,bh|0,8192)|0}bx=(bk|0)==0;if(!bx){T1(235424,102280,123,bk,y)}aN=(bo|0)==0;if(!aN){T1(169512,102232,2,bo,y)}if((bp|0)!=0){X5(1041680,bp|0,20)|0}bt=(bs|0)==0;if(!bt){T1(1394256,146224,15,bs,y)}c[348395]=c[348395]|aD&7;c[276674]=d[1041656]<<16;bz=c[260418]|0;bw=bz&16777215;c[260418]=bw;bH=bz&16711680;c[276676]=bH;bI=c[1052804+(bw>>>12<<2)>>2]|0;do{if((bz&4227072|0)==0){if((bz+24576&16384|0)!=0){bK=8;break}bK=(bz+16384&32256|0)==0?12:6}else{bK=(bz&8388608|0)==0?8:c[348401]|0}}while(0);c[348399]=bK;c[348400]=bK<<1;L8930:do{if(bI>>>0<19){c[348396]=0;if((bI|0)==18){break}switch(bI|0){case 17:{c[348396]=c[274488];break L8930;break};case 6:{c[348396]=c[263193];break L8930;break};case 10:{aD=bz&15728640;if((aD|0)==13631488){bL=c[198898]|0}else if((aD|0)==14680064){bL=c[198894]|0}else if((aD|0)==15728640){bL=c[198890]|0}else{bL=0}c[348396]=(c[263192]|0)+(bL+(bz&983040));break L8930;break};case 13:{if(((bz&65535)-32576&65535)<31){bM=0}else{bM=(c[263197]|0)-24576|0}c[348396]=bM;break L8930;break};case 14:{if(((bz&65535)-32752&65535)<7){bN=0}else{bN=(c[263198]|0)-24576|0}c[348396]=bN;break L8930;break};case 2:{aD=c[274485]|0;if((aD&4095|0)!=4095){break L8930}c[348396]=(c[263193]|0)+((aD&(bH>>>1|bz&32767))-(bz&65535));break L8930;break};case 3:{aD=c[261136]|0;if((aD&4095|0)!=4095){break L8930}c[348396]=(c[261140]|0)+((aD&(bH>>>1|bz&32767))-(bz&65535));break L8930;break};case 4:{aD=c[274485]|0;if((aD&4095|0)!=4095){break L8930}c[348396]=(c[263193]|0)+((aD&(bz&32767)-24576+(bz>>>3&122880))-(bz&65535));break L8930;break};case 7:{c[348396]=(c[263196]|0)+(-24576-(bz&32768));break L8930;break};default:{break L8930}}}else{c[348396]=bI}}while(0);bI=a[1041658]|0;a[1106728]=(bI&255)>>>1&1^1;a[1106720]=bI&-128;a[1106736]=bI&1;a[1106712]=(bI&255)>>>6&1;bI=b[520829]|0;do{if((bI&256)==0){bz=bI&255;bH=(bz&16|0)!=0;if((bz&32|0)==0){if(bH){c[276688]=156728;c[276686]=160312;break}else{c[276688]=157752;c[276686]=160568;break}}else{if(bH){c[276688]=154680;c[276686]=159800;break}else{c[276688]=155704;c[276686]=160056;break}}}else{c[276688]=158776;c[276686]=159800}}while(0);X5(1183776,s|0,22)|0;bI=l+22|0;X5(1183798,bI|0,22)|0;bI=l+44|0;X5(1183820,bI|0,22)|0;bI=l+66|0;X5(1183842,bI|0,22)|0;bI=l+88|0;X5(1183864,bI|0,22)|0;bI=l+110|0;X5(1183886,bI|0,22)|0;bI=l+132|0;X5(1183908,bI|0,22)|0;bI=l+154|0;X5(1183930,bI|0,22)|0;X2(1393608,0,5);bI=7080+(d[1044485]<<5)|0;c[276541]=bI;bH=0;bz=bI;while(1){bI=e[1041774+(bH<<1)>>1]|0;b[1106168+(bH<<1)>>1]=d[bz+(bI>>>5&31)|0]<<6|d[bz+(bI&31)|0]<<11|d[bz+(bI>>>10&31)|0];bI=bH+1|0;if((bI|0)>=256){break}bH=bI;bz=c[276541]|0}a[1106088]=1;HH(a[(c[263195]|0)+16908|0]|0,16908);bz=a[t]|0;if((c[3936]|0)==-1&bz<<24>>24==0){c[1768]=-1;c[3936]=a[238600]|0;bO=0}else{bO=bz}a[236008]=a[m+1|0]|0;a[236010]=a[m+7|0]|0;a[236009]=a[m+2|0]|0;a[236011]=a[m+8|0]|0;a[238618]=a[m+13|0]<<4&48|a[238618];a[238638]=a[m+14|0]<<4&48|a[238638];bz=a[509608]|0;a[509608]=(a[m+15|0]&1)==0?bz&-9:bz|8;a[1125520]=a[(c[263195]|0)+16406|0]&1;do{if((bO&255)>1){bz=m+25|0;b[254816]=(w=d[bz]|d[bz+1|0]<<8,w<<16>>16);bz=m+27|0;b[254817]=(w=d[bz]|d[bz+1|0]<<8,w<<16>>16);bz=m+29|0;b[254818]=(w=d[bz]|d[bz+1|0]<<8,w<<16>>16);bz=m+31|0;b[254819]=(w=d[bz]|d[bz+1|0]<<8,w<<16>>16);bz=m+33|0;b[254820]=(w=d[bz]|d[bz+1|0]<<8,w<<16>>16);bz=m+35|0;b[254821]=(w=d[bz]|d[bz+1|0]<<8,w<<16>>16);bz=m+37|0;b[254822]=(w=d[bz]|d[bz+1|0]<<8,w<<16>>16);bz=m+39|0;b[254823]=(w=d[bz]|d[bz+1|0]<<8,w<<16>>16);a[238608]=a[m+41|0]|0;a[238609]=a[m+42|0]|0;bz=m+43|0;b[119305]=(w=d[bz]|d[bz+1|0]<<8,w<<16>>16);bz=m+45|0;b[119306]=(w=d[bz]|d[bz+1|0]<<8,w<<16>>16);bz=m+47|0;b[119307]=(w=d[bz]|d[bz+1|0]<<8,w<<16>>16);bz=m+49|0;b[119308]=(w=d[bz]|d[bz+1|0]<<8,w<<16>>16);a[238618]=a[m+51|0]|0;a[238628]=a[m+52|0]|0;a[238629]=a[m+53|0]|0;bz=m+54|0;b[119315]=(w=d[bz]|d[bz+1|0]<<8,w<<16>>16);bz=m+56|0;b[119316]=(w=d[bz]|d[bz+1|0]<<8,w<<16>>16);bz=m+58|0;b[119317]=(w=d[bz]|d[bz+1|0]<<8,w<<16>>16);bz=m+60|0;b[119318]=(w=d[bz]|d[bz+1|0]<<8,w<<16>>16);a[238638]=a[m+62|0]|0;bz=m+63|0;b[84744]=(w=d[bz]|d[bz+1|0]<<8,w<<16>>16);bz=m+65|0;b[84745]=(w=d[bz]|d[bz+1|0]<<8,w<<16>>16);a[169492]=a[m+67|0]|0;a[169493]=a[m+68|0]|0;a[169494]=a[m+69|0]|0;bz=m+70|0;b[254812]=(w=d[bz]|d[bz+1|0]<<8,w<<16>>16);bz=m+72|0;b[254813]=(w=d[bz]|d[bz+1|0]<<8,w<<16>>16);bz=m+74|0;b[254808]=(w=d[bz]|d[bz+1|0]<<8,w<<16>>16);bz=m+76|0;b[254809]=(w=d[bz]|d[bz+1|0]<<8,w<<16>>16);a[509608]=a[m+78|0]|0;a[509600]=a[m+79|0]|0;a[509601]=a[m+80|0]|0;a[238600]=a[m+81|0]|0;a[238601]=a[m+82|0]|0;a[238604]=a[m+83|0]|0;a[238605]=a[m+84|0]|0;if((bO&255)<=2){break}a[238560]=a[m+24|0]|0}}while(0);if(!(bv|aM)){c[202033]=c[202033]|aI&2;c[202031]=d[808098|0]<<16;c[202032]=d[808080]<<16;HR(c[202024]|0);bz=a[808082]|0;a[808121]=(bz&255)>>>1&1^1;a[808122]=bz&-128;a[808120]=bz&1;a[808123]=(bz&255)>>>6&1;bz=b[404041]|0;do{if((bz&256)==0){bH=bz&255;bI=(bH&16|0)!=0;if((bH&32|0)==0){if(bI){c[202028]=151608;c[202029]=160312;break}else{c[202028]=152632;c[202029]=160568;break}}else{if(bI){c[202028]=149560;c[202029]=159800;break}else{c[202028]=150584;c[202029]=160056;break}}}else{c[202028]=149560;c[202029]=159800}}while(0);bz=c[263195]|0;a[840936]=(a[bz+8767|0]>>7)+4&255&-2;c[263196]=(c[263193]|0)+(d[bz+8740|0]<<13&57344);HU(a[bz+8741|0]|0)}if((a[799125]|0)!=0){bz=d[(c[263195]|0)+18436|0]<<20;aI=0;while(1){aM=(c[263192]|0)+((aI<<12)+bz)|0;bv=aI+16|0;bI=aI;do{c[1052804+(bI+3072<<2)>>2]=aM;bI=bI+1|0;}while((bI|0)<(bv|0));if((bv|0)<256){aI=bv}else{break}}aI=d[(c[263195]|0)+18437|0]<<20;bz=0;while(1){bI=(c[263192]|0)+((bz<<12)+aI)|0;aM=bz+16|0;bH=bz;do{c[1052804+(bH+3328<<2)>>2]=bI;bH=bH+1|0;}while((bH|0)<(aM|0));if((aM|0)<256){bz=aM}else{break}}bz=d[(c[263195]|0)+18438|0]<<20;aI=0;while(1){bH=(c[263192]|0)+((aI<<12)+bz)|0;bI=aI+16|0;bv=aI;do{c[1052804+(bv+3584<<2)>>2]=bH;bv=bv+1|0;}while((bv|0)<(bI|0));if((bI|0)<256){aI=bI}else{break}}aI=d[(c[263195]|0)+18439|0]<<20;bz=0;while(1){bv=(c[263192]|0)+((bz<<12)+aI)|0;bH=bz+16|0;aM=bz;do{c[1052804+(aM+3840<<2)>>2]=bv;aM=aM+1|0;}while((aM|0)<(bH|0));if((bH|0)<256){bz=bH}else{break}}}if(!bx){a[237800]=a[235424]|0;a[237792]=a[235425]|0;a[237784]=a[235426]|0;a[237776]=a[235427]|0;a[237768]=a[235428]|0;a[237760]=a[235429]|0;a[237752]=a[235430]|0;a[237744]=a[235431]|0;a[237736]=a[235432]|0;a[237728]=a[235433]|0;a[237720]=a[235434]|0;a[237712]=a[235435]|0;a[237704]=a[235436]|0;a[237696]=a[235437]|0;a[237688]=a[235438]|0;a[237680]=a[235439]|0;a[237664]=a[235440]|0;a[237648]=a[235441]|0;a[237640]=a[235442]|0;a[237632]=a[235443]|0;a[237624]=a[235444]|0;a[237672]=(a[235445]|0)!=0|0;a[237656]=(a[235446]|0)!=0|0;a[237616]=a[235447]|0;a[237608]=a[235448]|0;a[237600]=a[235449]|0;a[237592]=a[235450]|0;a[237584]=a[235451]|0;a[237576]=a[235452]|0;a[237568]=a[235453]|0;a[237560]=a[235454]|0;a[237552]=a[235455]|0;a[237544]=a[235456]|0;a[237536]=a[235457]|0;a[237528]=a[235458]|0;a[237520]=a[235459]|0;a[237512]=a[235460]|0;a[237504]=a[235461]|0;a[237496]=a[235462]|0;a[237488]=a[235463]|0;a[237480]=a[235464]|0;a[237472]=a[235465]|0;a[237464]=a[235466]|0;a[237456]=a[235467]|0;c[198898]=c[58867];c[198894]=c[58868];c[198890]=c[58869];a[237448]=a[235480]|0;a[237440]=a[235481]|0;a[237432]=a[235482]|0;c[58912]=c[58871];c[58914]=c[58872];c[58920]=c[58873];c[199378]=c[58874];c[199376]=c[58875];bz=c[199386]|0;aI=0;do{a[bz+aI|0]=a[235504+aI|0]|0;aI=aI+1|0;}while((aI|0)<64);c[199382]=c[58892];c[199380]=c[58893];c[199384]=c[58894];aI=0;do{a[797712+(aI<<1)|0]=a[235580+(aI<<1)|0]|0;a[797713+(aI<<1)|0]=a[235581+(aI<<1)|0]|0;aI=aI+1|0;}while((aI|0)<32);aI=eG(0)|0;a[1041696]=aI&255;a[1041697]=aI>>>8&255;a[1041698]=aI>>>16&255;a[1041699]=aI>>>24&255}if(!aN){c[58916]=c[42378];c[58918]=c[42379];aI=eG(0)|0;a[1041696]=aI&255;a[1041697]=aI>>>8&255;a[1041698]=aI>>>16&255;a[1041699]=aI>>>24&255}if(bt){S=D;T=L;U=K;V=N;W=O;X=ar;Y=as;Z=at;_=au;$=ay;aa=aK;ab=aP;ac=aS;ad=aV;ae=aY;af=a$;ag=a0;ah=ba;ai=bg;aj=bh;ak=bk;al=bo;am=bp;an=0;ao=1;break}aI=k|0;bz=a[1394256]|0;bx=a[1394257]|0;X5(aI|0,1394341,16)|0;X5(1394341,1394357,16)|0;jN();X5(1394341,aI|0,16)|0;a[1394256]=bz;a[1394257]=bx;S=D;T=L;U=K;V=N;W=O;X=ar;Y=as;Z=at;_=au;$=ay;aa=aK;ab=aP;ac=aS;ad=aV;ae=aY;af=a$;ag=a0;ah=ba;ai=bg;aj=bh;ak=bk;al=bo;am=bp;an=bs;ao=1}else{XZ(D);S=0;T=0;U=0;V=0;W=0;X=0;Y=0;Z=0;_=0;$=0;aa=0;ab=0;ac=0;ad=0;ae=0;af=0;ag=0;ah=0;ai=0;aj=0;ak=0;al=0;am=0;an=0;ao=I}}while(0);if((z|0)!=0){XZ(z)}if((S|0)!=0){XZ(S)}if((T|0)!=0){XZ(T)}if((U|0)!=0){XZ(U)}if((V|0)!=0){XZ(V)}if((W|0)!=0){XZ(W)}if((X|0)!=0){XZ(X)}if((Y|0)!=0){XZ(Y)}if((Z|0)!=0){XZ(Z)}if((_|0)!=0){XZ(_)}if(($|0)!=0){XZ($)}if((aa|0)!=0){XZ(aa)}if((ab|0)!=0){XZ(ab)}if((ac|0)!=0){XZ(ac)}if((ad|0)!=0){XZ(ad)}if((ae|0)!=0){XZ(ae)}if((af|0)!=0){XZ(af)}if((ag|0)!=0){XZ(ag)}if((ah|0)!=0){XZ(ah)}if((ai|0)!=0){XZ(ai)}if((aj|0)!=0){XZ(aj)}if((ak|0)!=0){XZ(ak)}if((al|0)!=0){XZ(al)}if((am|0)!=0){XZ(am)}if((an|0)==0){x=ao;break}XZ(an);x=ao}else{x=-1}}while(0);c[125856]=c[q>>2];XZ(o);if((x|0)==1){bP=1}else{break}i=h;return bP|0}}while(0);bP=0;i=h;return bP|0}function XS(){return}function XT(a,b,c){a=a|0;b=b|0;c=c|0;return}function XU(a,b,c){a=a|0;b=b|0;c=c|0;return 0}function XV(){return}function XW(){return(a[799146]|0)!=0|0}function XX(e){e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0,n=0,o=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0;f=i;i=i+288|0;g=f|0;h=f+32|0;j=c[e+8>>2]|0;c[198888]=c[e+4>>2];c[133748]=j;j=c[263192]|0;X2(j|0,0,8388608);X2(1044520,0,8240);c[274486]=0;a[1093764]=0;e=Ho(j)|0;L9123:do{if((e|0)!=0){j=0;k=e;L9125:while(1){l=c[274486]|0;m=c[263192]|0;n=Hp(l,m,0,0)|0;o=Hq(l,m,0,0)|0;do{if((c[263190]|0)!=0|(a[799137]|0)!=0){q=k}else{if((n|0)>(o|0)){if((Hp(l,m,1,0)|0)<=(n|0)){q=k;break}}else{if((Hq(l,m,1,0)|0)<=(o|0)){q=k;break}}r=k-512|0;X9(m|0,m+512|0,r|0);s=c[p>>2]|0;ec(s|0,65208,(t=i,i=i+8|0,c[t>>2]=20008,t)|0)|0;i=t;q=r}}while(0);m=((q|0)/8192|0)<<13;c[274486]=m;do{if(m>>>0>4194304){o=c[263192]|0;l=d[o+32726|0]<<8|d[o+32725|0];if((l|0)==17202|(l|0)==17714){u=6534;break}l=d[o+65494|0]<<8|d[o+65493|0];if((l|0)==63802|(l|0)==62778){u=6534;break}a[1093764]=1;v=1;w=m}else{u=6534}}while(0);do{if((u|0)==6534){u=0;l=a[1093764]|0;if(l<<24>>24!=0){v=l;w=m;break}l=c[263192]|0;if(d[l+32765|0]<<8>>>0>=32768){v=0;w=m;break}if(d[l+65533|0]<<8>>>0>=32768){v=0;w=m;break}if((a[799141]|a[799138])<<24>>24!=0){v=0;w=m;break}Hr(q,l);v=a[1093764]|0;w=c[274486]|0}}while(0);m=c[263192]|0;l=Hp(w,m,0,0)|0;o=Hq(w,m,0,0)|0;do{if(v<<24>>24==0){x=l;y=o;z=m;A=0}else{n=Hp(w,m,0,4194304)|0;r=Hq(w,m,0,4194304)|0;if((((r|0)>(n|0)?r:n)|0)<(((o|0)>(l|0)?o:l)|0)){a[1093764]=3;x=l;y=o;z=m;A=3;break}else{a[1093764]=2;x=n;y=r;z=m+4194304|0;A=2;break}}}while(0);if((a[799139]|a[799138])<<24>>24==0){B=(a[799140]|0)!=0|0}else{B=1}o=a[799134]|0;do{if(o<<24>>24==0){if(!((a[799135]|0)!=0|(y|0)<(x|0))){u=6547;break}a[1097937]=0;a[1097936]=1;l=d[z+65493|0]|0;r=l&240;if(!((r|0)==32|(r|0)==48)){C=B;D=0;break}r=l&15;if(!((r|0)==0|(r|0)==3)){C=B;D=0;break}C=1;D=0}else{u=6547}}while(0);do{if((u|0)==6547){u=0;a[1097937]=1;a[1097936]=0;r=d[z+32725|0]|0;l=r&240;if(!((l|0)==32|(l|0)==48)){C=B;D=0;break}l=r&15;if((l|0)==1){C=1;D=0;break}else if((l|0)==5){C=1;D=1;break}else{C=B;D=0;break}}}while(0);if((a[799135]|o)<<24>>24==0){if((bJ(m+32704|0,96904,22)|0)==0){u=6557;break}if((bJ(m+65472|0,67520,21)|0)==0){u=6557;break}}if((a[799141]|0)!=0|C<<24>>24==0){E=w;u=6588;break}ec(c[p>>2]|0,65208,(t=i,i=i+8|0,c[t>>2]=56536,t)|0)|0;i=t;if(D<<24>>24==0){l=c[274486]|0;do{if((a[799140]|0)!=0&(l|0)==3145728){r=a[1097937]|0;a[1097937]=a[1097936]|0;a[1097936]=r;r=c[263192]|0;n=XY(524288)|0;if((n|0)==0){break}s=r+1572864|0;X5(n|0,s|0,524288)|0;F=r+2097152|0;X5(s|0,F|0,524288)|0;s=r+2621440|0;X5(F|0,s|0,524288)|0;X5(s|0,n|0,524288)|0;XZ(n);Hr(3145728,r)}else{if((a[799139]|0)==0){r=a[1097937]|0;a[1097937]=a[1097936]|0;a[1097936]=r;Hr(l,c[263192]|0);break}r=c[263192]|0;n=l>>16;s=64;while(1){if((n|0)>(s|0)){break}else{s=s>>1}}n=s<<1;F=(n|0)>0;if(F){G=0;do{a[h+G|0]=(G<<2&12|G&240|G>>>2&3)&255;G=G+1|0;}while((G|0)<(n|0))}G=XY(65536)|0;if((G|0)==0){break}if(F){s=0;do{H=s;while(1){if((H|0)>=(n|0)){break}I=h+H|0;J=a[I]|0;if((J&255|0)==(s|0)){u=6577;break}else{H=H+1|0}}if((u|0)==6577){u=0;H=r+(s<<16)|0;X5(G|0,H|0,65536)|0;K=h+s|0;L=a[K]|0;M=r+((L&255)<<16)|0;X9(H|0,M|0,65536);X5(M|0,G|0,65536)|0;a[I]=L;a[K]=J}s=s+1|0;}while((s|0)<(n|0))}XZ(G)}}while(0);N=(a[1097936]|0)==0}else{if((a[1093764]|0)==2){Hr(4194304,c[263192]|0);Hr((c[274486]|0)-4194304|0,(c[263192]|0)+4194304|0)}else{Hr((c[274486]|0)-4194304|0,c[263192]|0);Hr(4194304,(c[263192]|0)+((c[274486]|0)-4194304)|0)}a[1097937]=0;a[1097936]=1;N=0}l=c[274486]|0;m=c[263192]|0;o=Hp(l,m,0,0)|0;n=Hq(l,m,0,0)|0;do{if(N){u=6584}else{if(!((n|0)>=(o|0)|(o|0)<0)){u=6584;break}if((j|0)!=0){E=l;u=6588;break L9125}}}while(0);if((u|0)==6584){u=0;if((a[1097937]|0)==0){E=l;u=6588;break}if(!(((o|0)>(n|0)|(n|0)<0)&(j|0)==0)){E=l;u=6588;break}}ec(c[p>>2]|0,65208,(t=i,i=i+8|0,c[t>>2]=47472,t)|0)|0;i=t;a[799141]=1;a[799138]=0;c[274486]=0;a[1093764]=0;m=Ho(c[263192]|0)|0;if((m|0)==0){break L9123}else{j=j+1|0;k=m}}if((u|0)==6557){a[1097937]=1;a[1097936]=0;O=0;P=A;Q=w}else if((u|0)==6588){O=D;P=a[1093764]|0;Q=E}do{if(!(O<<24>>24==0&P<<24>>24!=3)){k=XY(Q-4194304|0)|0;if((k|0)==0){break}j=c[p>>2]|0;ec(j|0,65208,(t=i,i=i+8|0,c[t>>2]=40528,t)|0)|0;i=t;j=c[263192]|0;m=(c[274486]|0)-4194304|0;X5(k|0,j|0,m)|0;X9(j|0,j+m|0,4194304);m=(c[263192]|0)+4194304|0;j=(c[274486]|0)-4194304|0;X5(m|0,k|0,j)|0;XZ(k)}}while(0);b[404036]=0;a[808072]=96;k=g|0;c[297188]=0;j=c5(35792,23072)|0;if((j|0)!=0){m=(d6(k|0,1,28,j|0)|0)==28;s=c[297188]|0;if(m&s>>>0<150){m=g+1|0;r=g+2|0;F=g+3|0;K=g+4|0;L=g+5|0;M=g+8|0;H=s;do{s=a[k]|0;a[1183958+(H<<5)|0]=(s&255)>>>2&1^1;a[1183956+(H<<5)|0]=a[m]|0;c[1183952+(H<<5)>>2]=d[F]<<8|d[r]|d[K]<<16;R=c[297188]|0;a[1183957+(R<<5)|0]=a[L]|0;a[1183959+(R<<5)|0]=(s&255)>>>3&1;s=1183960+(R<<5)|0;X5(s|0,M|0,20)|0;c[297188]=R+1;a[1183980+(R<<5)|0]=0;R=(d6(k|0,1,28,j|0)|0)==28;H=c[297188]|0;}while(R&H>>>0<150)}aQ(j|0)|0}Hs();c[348389]=c[263191];c[348391]=c[263193];c[348390]=c[263195];if(!((a[799144]|0)==0|(c[297188]|0)==0)){H=0;do{do{if((a[1183958+(H<<5)|0]|0)!=0){k=c[1183952+(H<<5)>>2]|0;M=1183959+(H<<5)|0;if((a[M]|0)==0){a[1183957+(H<<5)|0]=jT(k)|0;a[M]=1}M=c[1052804+((k>>>12&4095)<<2)>>2]|0;L=a[1183956+(H<<5)|0]|0;if(M>>>0<19){jU(L,k);break}else{a[M+(k&65535)|0]=L;break}}}while(0);H=H+1|0;}while(H>>>0<(c[297188]|0)>>>0)}j_();XO();S=1;i=f;return S|0}}while(0);a2(68480,34,1,c[p>>2]|0)|0;S=0;i=f;return S|0}function XY(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0,P=0,Q=0,R=0,S=0,T=0,U=0,V=0,W=0,X=0,Y=0,Z=0,_=0,$=0,aa=0,ab=0,ac=0,ad=0,ae=0,af=0,ag=0,ah=0,ai=0,aj=0,ak=0,al=0,am=0,an=0,ao=0,ap=0,aq=0,ar=0,as=0,at=0,au=0,av=0,aw=0,ax=0,ay=0,az=0,aA=0,aB=0,aC=0,aD=0,aE=0,aF=0,aG=0;do{if(a>>>0<245){if(a>>>0<11){b=16}else{b=a+11&-8}d=b>>>3;e=c[199566]|0;f=e>>>(d>>>0);if((f&3|0)!=0){g=(f&1^1)+d|0;h=g<<1;i=798304+(h<<2)|0;j=798304+(h+2<<2)|0;h=c[j>>2]|0;k=h+8|0;l=c[k>>2]|0;do{if((i|0)==(l|0)){c[199566]=e&~(1<<g)}else{if(l>>>0<(c[199570]|0)>>>0){b3();return 0}m=l+12|0;if((c[m>>2]|0)==(h|0)){c[m>>2]=i;c[j>>2]=l;break}else{b3();return 0}}}while(0);l=g<<3;c[h+4>>2]=l|3;j=h+(l|4)|0;c[j>>2]=c[j>>2]|1;n=k;return n|0}if(b>>>0<=(c[199568]|0)>>>0){o=b;break}if((f|0)!=0){j=2<<d;l=f<<d&(j|-j);j=(l&-l)-1|0;l=j>>>12&16;i=j>>>(l>>>0);j=i>>>5&8;m=i>>>(j>>>0);i=m>>>2&4;p=m>>>(i>>>0);m=p>>>1&2;q=p>>>(m>>>0);p=q>>>1&1;r=(j|l|i|m|p)+(q>>>(p>>>0))|0;p=r<<1;q=798304+(p<<2)|0;m=798304+(p+2<<2)|0;p=c[m>>2]|0;i=p+8|0;l=c[i>>2]|0;do{if((q|0)==(l|0)){c[199566]=e&~(1<<r)}else{if(l>>>0<(c[199570]|0)>>>0){b3();return 0}j=l+12|0;if((c[j>>2]|0)==(p|0)){c[j>>2]=q;c[m>>2]=l;break}else{b3();return 0}}}while(0);l=r<<3;m=l-b|0;c[p+4>>2]=b|3;q=p;e=q+b|0;c[q+(b|4)>>2]=m|1;c[q+l>>2]=m;l=c[199568]|0;if((l|0)!=0){q=c[199571]|0;d=l>>>3;l=d<<1;f=798304+(l<<2)|0;k=c[199566]|0;h=1<<d;do{if((k&h|0)==0){c[199566]=k|h;s=f;t=798304+(l+2<<2)|0}else{d=798304+(l+2<<2)|0;g=c[d>>2]|0;if(g>>>0>=(c[199570]|0)>>>0){s=g;t=d;break}b3();return 0}}while(0);c[t>>2]=q;c[s+12>>2]=q;c[q+8>>2]=s;c[q+12>>2]=f}c[199568]=m;c[199571]=e;n=i;return n|0}l=c[199567]|0;if((l|0)==0){o=b;break}h=(l&-l)-1|0;l=h>>>12&16;k=h>>>(l>>>0);h=k>>>5&8;p=k>>>(h>>>0);k=p>>>2&4;r=p>>>(k>>>0);p=r>>>1&2;d=r>>>(p>>>0);r=d>>>1&1;g=c[798568+((h|l|k|p|r)+(d>>>(r>>>0))<<2)>>2]|0;r=g;d=g;p=(c[g+4>>2]&-8)-b|0;while(1){g=c[r+16>>2]|0;if((g|0)==0){k=c[r+20>>2]|0;if((k|0)==0){break}else{u=k}}else{u=g}g=(c[u+4>>2]&-8)-b|0;k=g>>>0<p>>>0;r=u;d=k?u:d;p=k?g:p}r=d;i=c[199570]|0;if(r>>>0<i>>>0){b3();return 0}e=r+b|0;m=e;if(r>>>0>=e>>>0){b3();return 0}e=c[d+24>>2]|0;f=c[d+12>>2]|0;do{if((f|0)==(d|0)){q=d+20|0;g=c[q>>2]|0;if((g|0)==0){k=d+16|0;l=c[k>>2]|0;if((l|0)==0){v=0;break}else{w=l;x=k}}else{w=g;x=q}while(1){q=w+20|0;g=c[q>>2]|0;if((g|0)!=0){w=g;x=q;continue}q=w+16|0;g=c[q>>2]|0;if((g|0)==0){break}else{w=g;x=q}}if(x>>>0<i>>>0){b3();return 0}else{c[x>>2]=0;v=w;break}}else{q=c[d+8>>2]|0;if(q>>>0<i>>>0){b3();return 0}g=q+12|0;if((c[g>>2]|0)!=(d|0)){b3();return 0}k=f+8|0;if((c[k>>2]|0)==(d|0)){c[g>>2]=f;c[k>>2]=q;v=f;break}else{b3();return 0}}}while(0);L9322:do{if((e|0)!=0){f=d+28|0;i=798568+(c[f>>2]<<2)|0;do{if((d|0)==(c[i>>2]|0)){c[i>>2]=v;if((v|0)!=0){break}c[199567]=c[199567]&~(1<<c[f>>2]);break L9322}else{if(e>>>0<(c[199570]|0)>>>0){b3();return 0}q=e+16|0;if((c[q>>2]|0)==(d|0)){c[q>>2]=v}else{c[e+20>>2]=v}if((v|0)==0){break L9322}}}while(0);if(v>>>0<(c[199570]|0)>>>0){b3();return 0}c[v+24>>2]=e;f=c[d+16>>2]|0;do{if((f|0)!=0){if(f>>>0<(c[199570]|0)>>>0){b3();return 0}else{c[v+16>>2]=f;c[f+24>>2]=v;break}}}while(0);f=c[d+20>>2]|0;if((f|0)==0){break}if(f>>>0<(c[199570]|0)>>>0){b3();return 0}else{c[v+20>>2]=f;c[f+24>>2]=v;break}}}while(0);if(p>>>0<16){e=p+b|0;c[d+4>>2]=e|3;f=r+(e+4)|0;c[f>>2]=c[f>>2]|1}else{c[d+4>>2]=b|3;c[r+(b|4)>>2]=p|1;c[r+(p+b)>>2]=p;f=c[199568]|0;if((f|0)!=0){e=c[199571]|0;i=f>>>3;f=i<<1;q=798304+(f<<2)|0;k=c[199566]|0;g=1<<i;do{if((k&g|0)==0){c[199566]=k|g;y=q;z=798304+(f+2<<2)|0}else{i=798304+(f+2<<2)|0;l=c[i>>2]|0;if(l>>>0>=(c[199570]|0)>>>0){y=l;z=i;break}b3();return 0}}while(0);c[z>>2]=e;c[y+12>>2]=e;c[e+8>>2]=y;c[e+12>>2]=q}c[199568]=p;c[199571]=m}f=d+8|0;if((f|0)==0){o=b;break}else{n=f}return n|0}else{if(a>>>0>4294967231){o=-1;break}f=a+11|0;g=f&-8;k=c[199567]|0;if((k|0)==0){o=g;break}r=-g|0;i=f>>>8;do{if((i|0)==0){A=0}else{if(g>>>0>16777215){A=31;break}f=(i+1048320|0)>>>16&8;l=i<<f;h=(l+520192|0)>>>16&4;j=l<<h;l=(j+245760|0)>>>16&2;B=14-(h|f|l)+(j<<l>>>15)|0;A=g>>>((B+7|0)>>>0)&1|B<<1}}while(0);i=c[798568+(A<<2)>>2]|0;L9370:do{if((i|0)==0){C=0;D=r;E=0}else{if((A|0)==31){F=0}else{F=25-(A>>>1)|0}d=0;m=r;p=i;q=g<<F;e=0;while(1){B=c[p+4>>2]&-8;l=B-g|0;if(l>>>0<m>>>0){if((B|0)==(g|0)){C=p;D=l;E=p;break L9370}else{G=p;H=l}}else{G=d;H=m}l=c[p+20>>2]|0;B=c[p+16+(q>>>31<<2)>>2]|0;j=(l|0)==0|(l|0)==(B|0)?e:l;if((B|0)==0){C=G;D=H;E=j;break}else{d=G;m=H;p=B;q=q<<1;e=j}}}}while(0);if((E|0)==0&(C|0)==0){i=2<<A;r=(i|-i)&k;if((r|0)==0){o=g;break}i=(r&-r)-1|0;r=i>>>12&16;e=i>>>(r>>>0);i=e>>>5&8;q=e>>>(i>>>0);e=q>>>2&4;p=q>>>(e>>>0);q=p>>>1&2;m=p>>>(q>>>0);p=m>>>1&1;I=c[798568+((i|r|e|q|p)+(m>>>(p>>>0))<<2)>>2]|0}else{I=E}if((I|0)==0){J=D;K=C}else{p=I;m=D;q=C;while(1){e=(c[p+4>>2]&-8)-g|0;r=e>>>0<m>>>0;i=r?e:m;e=r?p:q;r=c[p+16>>2]|0;if((r|0)!=0){p=r;m=i;q=e;continue}r=c[p+20>>2]|0;if((r|0)==0){J=i;K=e;break}else{p=r;m=i;q=e}}}if((K|0)==0){o=g;break}if(J>>>0>=((c[199568]|0)-g|0)>>>0){o=g;break}q=K;m=c[199570]|0;if(q>>>0<m>>>0){b3();return 0}p=q+g|0;k=p;if(q>>>0>=p>>>0){b3();return 0}e=c[K+24>>2]|0;i=c[K+12>>2]|0;do{if((i|0)==(K|0)){r=K+20|0;d=c[r>>2]|0;if((d|0)==0){j=K+16|0;B=c[j>>2]|0;if((B|0)==0){L=0;break}else{M=B;N=j}}else{M=d;N=r}while(1){r=M+20|0;d=c[r>>2]|0;if((d|0)!=0){M=d;N=r;continue}r=M+16|0;d=c[r>>2]|0;if((d|0)==0){break}else{M=d;N=r}}if(N>>>0<m>>>0){b3();return 0}else{c[N>>2]=0;L=M;break}}else{r=c[K+8>>2]|0;if(r>>>0<m>>>0){b3();return 0}d=r+12|0;if((c[d>>2]|0)!=(K|0)){b3();return 0}j=i+8|0;if((c[j>>2]|0)==(K|0)){c[d>>2]=i;c[j>>2]=r;L=i;break}else{b3();return 0}}}while(0);L9420:do{if((e|0)!=0){i=K+28|0;m=798568+(c[i>>2]<<2)|0;do{if((K|0)==(c[m>>2]|0)){c[m>>2]=L;if((L|0)!=0){break}c[199567]=c[199567]&~(1<<c[i>>2]);break L9420}else{if(e>>>0<(c[199570]|0)>>>0){b3();return 0}r=e+16|0;if((c[r>>2]|0)==(K|0)){c[r>>2]=L}else{c[e+20>>2]=L}if((L|0)==0){break L9420}}}while(0);if(L>>>0<(c[199570]|0)>>>0){b3();return 0}c[L+24>>2]=e;i=c[K+16>>2]|0;do{if((i|0)!=0){if(i>>>0<(c[199570]|0)>>>0){b3();return 0}else{c[L+16>>2]=i;c[i+24>>2]=L;break}}}while(0);i=c[K+20>>2]|0;if((i|0)==0){break}if(i>>>0<(c[199570]|0)>>>0){b3();return 0}else{c[L+20>>2]=i;c[i+24>>2]=L;break}}}while(0);do{if(J>>>0<16){e=J+g|0;c[K+4>>2]=e|3;i=q+(e+4)|0;c[i>>2]=c[i>>2]|1}else{c[K+4>>2]=g|3;c[q+(g|4)>>2]=J|1;c[q+(J+g)>>2]=J;i=J>>>3;if(J>>>0<256){e=i<<1;m=798304+(e<<2)|0;r=c[199566]|0;j=1<<i;do{if((r&j|0)==0){c[199566]=r|j;O=m;P=798304+(e+2<<2)|0}else{i=798304+(e+2<<2)|0;d=c[i>>2]|0;if(d>>>0>=(c[199570]|0)>>>0){O=d;P=i;break}b3();return 0}}while(0);c[P>>2]=k;c[O+12>>2]=k;c[q+(g+8)>>2]=O;c[q+(g+12)>>2]=m;break}e=p;j=J>>>8;do{if((j|0)==0){Q=0}else{if(J>>>0>16777215){Q=31;break}r=(j+1048320|0)>>>16&8;i=j<<r;d=(i+520192|0)>>>16&4;B=i<<d;i=(B+245760|0)>>>16&2;l=14-(d|r|i)+(B<<i>>>15)|0;Q=J>>>((l+7|0)>>>0)&1|l<<1}}while(0);j=798568+(Q<<2)|0;c[q+(g+28)>>2]=Q;c[q+(g+20)>>2]=0;c[q+(g+16)>>2]=0;m=c[199567]|0;l=1<<Q;if((m&l|0)==0){c[199567]=m|l;c[j>>2]=e;c[q+(g+24)>>2]=j;c[q+(g+12)>>2]=e;c[q+(g+8)>>2]=e;break}if((Q|0)==31){R=0}else{R=25-(Q>>>1)|0}l=J<<R;m=c[j>>2]|0;while(1){if((c[m+4>>2]&-8|0)==(J|0)){break}S=m+16+(l>>>31<<2)|0;j=c[S>>2]|0;if((j|0)==0){T=6760;break}else{l=l<<1;m=j}}if((T|0)==6760){if(S>>>0<(c[199570]|0)>>>0){b3();return 0}else{c[S>>2]=e;c[q+(g+24)>>2]=m;c[q+(g+12)>>2]=e;c[q+(g+8)>>2]=e;break}}l=m+8|0;j=c[l>>2]|0;i=c[199570]|0;if(m>>>0<i>>>0){b3();return 0}if(j>>>0<i>>>0){b3();return 0}else{c[j+12>>2]=e;c[l>>2]=e;c[q+(g+8)>>2]=j;c[q+(g+12)>>2]=m;c[q+(g+24)>>2]=0;break}}}while(0);q=K+8|0;if((q|0)==0){o=g;break}else{n=q}return n|0}}while(0);K=c[199568]|0;if(o>>>0<=K>>>0){S=K-o|0;J=c[199571]|0;if(S>>>0>15){R=J;c[199571]=R+o;c[199568]=S;c[R+(o+4)>>2]=S|1;c[R+K>>2]=S;c[J+4>>2]=o|3}else{c[199568]=0;c[199571]=0;c[J+4>>2]=K|3;S=J+(K+4)|0;c[S>>2]=c[S>>2]|1}n=J+8|0;return n|0}J=c[199569]|0;if(o>>>0<J>>>0){S=J-o|0;c[199569]=S;J=c[199572]|0;K=J;c[199572]=K+o;c[K+(o+4)>>2]=S|1;c[J+4>>2]=o|3;n=J+8|0;return n|0}do{if((c[59644]|0)==0){J=aP(8)|0;if((J-1&J|0)==0){c[59646]=J;c[59645]=J;c[59647]=-1;c[59648]=-1;c[59649]=0;c[199677]=0;c[59644]=(eG(0)|0)&-16^1431655768;break}else{b3();return 0}}}while(0);J=o+48|0;S=c[59646]|0;K=o+47|0;R=S+K|0;Q=-S|0;S=R&Q;if(S>>>0<=o>>>0){n=0;return n|0}O=c[199676]|0;do{if((O|0)!=0){P=c[199674]|0;L=P+S|0;if(L>>>0<=P>>>0|L>>>0>O>>>0){n=0}else{break}return n|0}}while(0);L9512:do{if((c[199677]&4|0)==0){O=c[199572]|0;L9514:do{if((O|0)==0){T=6790}else{L=O;P=798712;while(1){U=P|0;M=c[U>>2]|0;if(M>>>0<=L>>>0){V=P+4|0;if((M+(c[V>>2]|0)|0)>>>0>L>>>0){break}}M=c[P+8>>2]|0;if((M|0)==0){T=6790;break L9514}else{P=M}}if((P|0)==0){T=6790;break}L=R-(c[199569]|0)&Q;if(L>>>0>=2147483647){W=0;break}m=dY(L|0)|0;e=(m|0)==((c[U>>2]|0)+(c[V>>2]|0)|0);X=e?m:-1;Y=e?L:0;Z=m;_=L;T=6799}}while(0);do{if((T|0)==6790){O=dY(0)|0;if((O|0)==-1){W=0;break}g=O;L=c[59645]|0;m=L-1|0;if((m&g|0)==0){$=S}else{$=S-g+(m+g&-L)|0}L=c[199674]|0;g=L+$|0;if(!($>>>0>o>>>0&$>>>0<2147483647)){W=0;break}m=c[199676]|0;if((m|0)!=0){if(g>>>0<=L>>>0|g>>>0>m>>>0){W=0;break}}m=dY($|0)|0;g=(m|0)==(O|0);X=g?O:-1;Y=g?$:0;Z=m;_=$;T=6799}}while(0);L9534:do{if((T|0)==6799){m=-_|0;if((X|0)!=-1){aa=Y;ab=X;T=6810;break L9512}do{if((Z|0)!=-1&_>>>0<2147483647&_>>>0<J>>>0){g=c[59646]|0;O=K-_+g&-g;if(O>>>0>=2147483647){ac=_;break}if((dY(O|0)|0)==-1){dY(m|0)|0;W=Y;break L9534}else{ac=O+_|0;break}}else{ac=_}}while(0);if((Z|0)==-1){W=Y}else{aa=ac;ab=Z;T=6810;break L9512}}}while(0);c[199677]=c[199677]|4;ad=W;T=6807}else{ad=0;T=6807}}while(0);do{if((T|0)==6807){if(S>>>0>=2147483647){break}W=dY(S|0)|0;Z=dY(0)|0;if(!((Z|0)!=-1&(W|0)!=-1&W>>>0<Z>>>0)){break}ac=Z-W|0;Z=ac>>>0>(o+40|0)>>>0;Y=Z?W:-1;if((Y|0)!=-1){aa=Z?ac:ad;ab=Y;T=6810}}}while(0);do{if((T|0)==6810){ad=(c[199674]|0)+aa|0;c[199674]=ad;if(ad>>>0>(c[199675]|0)>>>0){c[199675]=ad}ad=c[199572]|0;L9554:do{if((ad|0)==0){S=c[199570]|0;if((S|0)==0|ab>>>0<S>>>0){c[199570]=ab}c[199678]=ab;c[199679]=aa;c[199681]=0;c[199575]=c[59644];c[199574]=-1;S=0;do{Y=S<<1;ac=798304+(Y<<2)|0;c[798304+(Y+3<<2)>>2]=ac;c[798304+(Y+2<<2)>>2]=ac;S=S+1|0;}while(S>>>0<32);S=ab+8|0;if((S&7|0)==0){ae=0}else{ae=-S&7}S=aa-40-ae|0;c[199572]=ab+ae;c[199569]=S;c[ab+(ae+4)>>2]=S|1;c[ab+(aa-36)>>2]=40;c[199573]=c[59648]}else{S=798712;while(1){af=c[S>>2]|0;ag=S+4|0;ah=c[ag>>2]|0;if((ab|0)==(af+ah|0)){T=6822;break}ac=c[S+8>>2]|0;if((ac|0)==0){break}else{S=ac}}do{if((T|0)==6822){if((c[S+12>>2]&8|0)!=0){break}ac=ad;if(!(ac>>>0>=af>>>0&ac>>>0<ab>>>0)){break}c[ag>>2]=ah+aa;ac=c[199572]|0;Y=(c[199569]|0)+aa|0;Z=ac;W=ac+8|0;if((W&7|0)==0){ai=0}else{ai=-W&7}W=Y-ai|0;c[199572]=Z+ai;c[199569]=W;c[Z+(ai+4)>>2]=W|1;c[Z+(Y+4)>>2]=40;c[199573]=c[59648];break L9554}}while(0);if(ab>>>0<(c[199570]|0)>>>0){c[199570]=ab}S=ab+aa|0;Y=798712;while(1){aj=Y|0;if((c[aj>>2]|0)==(S|0)){T=6832;break}Z=c[Y+8>>2]|0;if((Z|0)==0){break}else{Y=Z}}do{if((T|0)==6832){if((c[Y+12>>2]&8|0)!=0){break}c[aj>>2]=ab;S=Y+4|0;c[S>>2]=(c[S>>2]|0)+aa;S=ab+8|0;if((S&7|0)==0){ak=0}else{ak=-S&7}S=ab+(aa+8)|0;if((S&7|0)==0){al=0}else{al=-S&7}S=ab+(al+aa)|0;Z=S;W=ak+o|0;ac=ab+W|0;_=ac;K=S-(ab+ak)-o|0;c[ab+(ak+4)>>2]=o|3;do{if((Z|0)==(c[199572]|0)){J=(c[199569]|0)+K|0;c[199569]=J;c[199572]=_;c[ab+(W+4)>>2]=J|1}else{if((Z|0)==(c[199571]|0)){J=(c[199568]|0)+K|0;c[199568]=J;c[199571]=_;c[ab+(W+4)>>2]=J|1;c[ab+(J+W)>>2]=J;break}J=aa+4|0;X=c[ab+(al+J)>>2]|0;if((X&3|0)==1){$=X&-8;V=X>>>3;L9598:do{if(X>>>0<256){U=c[ab+((al|8)+aa)>>2]|0;Q=c[ab+(aa+12+al)>>2]|0;R=798304+(V<<1<<2)|0;do{if((U|0)!=(R|0)){if(U>>>0<(c[199570]|0)>>>0){b3();return 0}if((c[U+12>>2]|0)==(Z|0)){break}b3();return 0}}while(0);if((Q|0)==(U|0)){c[199566]=c[199566]&~(1<<V);break}do{if((Q|0)==(R|0)){am=Q+8|0}else{if(Q>>>0<(c[199570]|0)>>>0){b3();return 0}m=Q+8|0;if((c[m>>2]|0)==(Z|0)){am=m;break}b3();return 0}}while(0);c[U+12>>2]=Q;c[am>>2]=U}else{R=S;m=c[ab+((al|24)+aa)>>2]|0;P=c[ab+(aa+12+al)>>2]|0;do{if((P|0)==(R|0)){O=al|16;g=ab+(O+J)|0;L=c[g>>2]|0;if((L|0)==0){e=ab+(O+aa)|0;O=c[e>>2]|0;if((O|0)==0){an=0;break}else{ao=O;ap=e}}else{ao=L;ap=g}while(1){g=ao+20|0;L=c[g>>2]|0;if((L|0)!=0){ao=L;ap=g;continue}g=ao+16|0;L=c[g>>2]|0;if((L|0)==0){break}else{ao=L;ap=g}}if(ap>>>0<(c[199570]|0)>>>0){b3();return 0}else{c[ap>>2]=0;an=ao;break}}else{g=c[ab+((al|8)+aa)>>2]|0;if(g>>>0<(c[199570]|0)>>>0){b3();return 0}L=g+12|0;if((c[L>>2]|0)!=(R|0)){b3();return 0}e=P+8|0;if((c[e>>2]|0)==(R|0)){c[L>>2]=P;c[e>>2]=g;an=P;break}else{b3();return 0}}}while(0);if((m|0)==0){break}P=ab+(aa+28+al)|0;U=798568+(c[P>>2]<<2)|0;do{if((R|0)==(c[U>>2]|0)){c[U>>2]=an;if((an|0)!=0){break}c[199567]=c[199567]&~(1<<c[P>>2]);break L9598}else{if(m>>>0<(c[199570]|0)>>>0){b3();return 0}Q=m+16|0;if((c[Q>>2]|0)==(R|0)){c[Q>>2]=an}else{c[m+20>>2]=an}if((an|0)==0){break L9598}}}while(0);if(an>>>0<(c[199570]|0)>>>0){b3();return 0}c[an+24>>2]=m;R=al|16;P=c[ab+(R+aa)>>2]|0;do{if((P|0)!=0){if(P>>>0<(c[199570]|0)>>>0){b3();return 0}else{c[an+16>>2]=P;c[P+24>>2]=an;break}}}while(0);P=c[ab+(R+J)>>2]|0;if((P|0)==0){break}if(P>>>0<(c[199570]|0)>>>0){b3();return 0}else{c[an+20>>2]=P;c[P+24>>2]=an;break}}}while(0);aq=ab+(($|al)+aa)|0;ar=$+K|0}else{aq=Z;ar=K}J=aq+4|0;c[J>>2]=c[J>>2]&-2;c[ab+(W+4)>>2]=ar|1;c[ab+(ar+W)>>2]=ar;J=ar>>>3;if(ar>>>0<256){V=J<<1;X=798304+(V<<2)|0;P=c[199566]|0;m=1<<J;do{if((P&m|0)==0){c[199566]=P|m;as=X;at=798304+(V+2<<2)|0}else{J=798304+(V+2<<2)|0;U=c[J>>2]|0;if(U>>>0>=(c[199570]|0)>>>0){as=U;at=J;break}b3();return 0}}while(0);c[at>>2]=_;c[as+12>>2]=_;c[ab+(W+8)>>2]=as;c[ab+(W+12)>>2]=X;break}V=ac;m=ar>>>8;do{if((m|0)==0){au=0}else{if(ar>>>0>16777215){au=31;break}P=(m+1048320|0)>>>16&8;$=m<<P;J=($+520192|0)>>>16&4;U=$<<J;$=(U+245760|0)>>>16&2;Q=14-(J|P|$)+(U<<$>>>15)|0;au=ar>>>((Q+7|0)>>>0)&1|Q<<1}}while(0);m=798568+(au<<2)|0;c[ab+(W+28)>>2]=au;c[ab+(W+20)>>2]=0;c[ab+(W+16)>>2]=0;X=c[199567]|0;Q=1<<au;if((X&Q|0)==0){c[199567]=X|Q;c[m>>2]=V;c[ab+(W+24)>>2]=m;c[ab+(W+12)>>2]=V;c[ab+(W+8)>>2]=V;break}if((au|0)==31){av=0}else{av=25-(au>>>1)|0}Q=ar<<av;X=c[m>>2]|0;while(1){if((c[X+4>>2]&-8|0)==(ar|0)){break}aw=X+16+(Q>>>31<<2)|0;m=c[aw>>2]|0;if((m|0)==0){T=6905;break}else{Q=Q<<1;X=m}}if((T|0)==6905){if(aw>>>0<(c[199570]|0)>>>0){b3();return 0}else{c[aw>>2]=V;c[ab+(W+24)>>2]=X;c[ab+(W+12)>>2]=V;c[ab+(W+8)>>2]=V;break}}Q=X+8|0;m=c[Q>>2]|0;$=c[199570]|0;if(X>>>0<$>>>0){b3();return 0}if(m>>>0<$>>>0){b3();return 0}else{c[m+12>>2]=V;c[Q>>2]=V;c[ab+(W+8)>>2]=m;c[ab+(W+12)>>2]=X;c[ab+(W+24)>>2]=0;break}}}while(0);n=ab+(ak|8)|0;return n|0}}while(0);Y=ad;W=798712;while(1){ax=c[W>>2]|0;if(ax>>>0<=Y>>>0){ay=c[W+4>>2]|0;az=ax+ay|0;if(az>>>0>Y>>>0){break}}W=c[W+8>>2]|0}W=ax+(ay-39)|0;if((W&7|0)==0){aA=0}else{aA=-W&7}W=ax+(ay-47+aA)|0;ac=W>>>0<(ad+16|0)>>>0?Y:W;W=ac+8|0;_=ab+8|0;if((_&7|0)==0){aB=0}else{aB=-_&7}_=aa-40-aB|0;c[199572]=ab+aB;c[199569]=_;c[ab+(aB+4)>>2]=_|1;c[ab+(aa-36)>>2]=40;c[199573]=c[59648];c[ac+4>>2]=27;c[W>>2]=c[199678];c[W+4>>2]=c[798716>>2];c[W+8>>2]=c[798720>>2];c[W+12>>2]=c[798724>>2];c[199678]=ab;c[199679]=aa;c[199681]=0;c[199680]=W;W=ac+28|0;c[W>>2]=7;if((ac+32|0)>>>0<az>>>0){_=W;while(1){W=_+4|0;c[W>>2]=7;if((_+8|0)>>>0<az>>>0){_=W}else{break}}}if((ac|0)==(Y|0)){break}_=ac-ad|0;W=Y+(_+4)|0;c[W>>2]=c[W>>2]&-2;c[ad+4>>2]=_|1;c[Y+_>>2]=_;W=_>>>3;if(_>>>0<256){K=W<<1;Z=798304+(K<<2)|0;S=c[199566]|0;m=1<<W;do{if((S&m|0)==0){c[199566]=S|m;aC=Z;aD=798304+(K+2<<2)|0}else{W=798304+(K+2<<2)|0;Q=c[W>>2]|0;if(Q>>>0>=(c[199570]|0)>>>0){aC=Q;aD=W;break}b3();return 0}}while(0);c[aD>>2]=ad;c[aC+12>>2]=ad;c[ad+8>>2]=aC;c[ad+12>>2]=Z;break}K=ad;m=_>>>8;do{if((m|0)==0){aE=0}else{if(_>>>0>16777215){aE=31;break}S=(m+1048320|0)>>>16&8;Y=m<<S;ac=(Y+520192|0)>>>16&4;W=Y<<ac;Y=(W+245760|0)>>>16&2;Q=14-(ac|S|Y)+(W<<Y>>>15)|0;aE=_>>>((Q+7|0)>>>0)&1|Q<<1}}while(0);m=798568+(aE<<2)|0;c[ad+28>>2]=aE;c[ad+20>>2]=0;c[ad+16>>2]=0;Z=c[199567]|0;Q=1<<aE;if((Z&Q|0)==0){c[199567]=Z|Q;c[m>>2]=K;c[ad+24>>2]=m;c[ad+12>>2]=ad;c[ad+8>>2]=ad;break}if((aE|0)==31){aF=0}else{aF=25-(aE>>>1)|0}Q=_<<aF;Z=c[m>>2]|0;while(1){if((c[Z+4>>2]&-8|0)==(_|0)){break}aG=Z+16+(Q>>>31<<2)|0;m=c[aG>>2]|0;if((m|0)==0){T=6940;break}else{Q=Q<<1;Z=m}}if((T|0)==6940){if(aG>>>0<(c[199570]|0)>>>0){b3();return 0}else{c[aG>>2]=K;c[ad+24>>2]=Z;c[ad+12>>2]=ad;c[ad+8>>2]=ad;break}}Q=Z+8|0;_=c[Q>>2]|0;m=c[199570]|0;if(Z>>>0<m>>>0){b3();return 0}if(_>>>0<m>>>0){b3();return 0}else{c[_+12>>2]=K;c[Q>>2]=K;c[ad+8>>2]=_;c[ad+12>>2]=Z;c[ad+24>>2]=0;break}}}while(0);ad=c[199569]|0;if(ad>>>0<=o>>>0){break}_=ad-o|0;c[199569]=_;ad=c[199572]|0;Q=ad;c[199572]=Q+o;c[Q+(o+4)>>2]=_|1;c[ad+4>>2]=o|3;n=ad+8|0;return n|0}}while(0);c[(dS()|0)>>2]=12;n=0;return n|0}function XZ(a){a=a|0;var b=0,d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0,N=0,O=0;if((a|0)==0){return}b=a-8|0;d=b;e=c[199570]|0;if(b>>>0<e>>>0){b3()}f=c[a-4>>2]|0;g=f&3;if((g|0)==1){b3()}h=f&-8;i=a+(h-8)|0;j=i;L9771:do{if((f&1|0)==0){k=c[b>>2]|0;if((g|0)==0){return}l=-8-k|0;m=a+l|0;n=m;o=k+h|0;if(m>>>0<e>>>0){b3()}if((n|0)==(c[199571]|0)){p=a+(h-4)|0;if((c[p>>2]&3|0)!=3){q=n;r=o;break}c[199568]=o;c[p>>2]=c[p>>2]&-2;c[a+(l+4)>>2]=o|1;c[i>>2]=o;return}p=k>>>3;if(k>>>0<256){k=c[a+(l+8)>>2]|0;s=c[a+(l+12)>>2]|0;t=798304+(p<<1<<2)|0;do{if((k|0)!=(t|0)){if(k>>>0<e>>>0){b3()}if((c[k+12>>2]|0)==(n|0)){break}b3()}}while(0);if((s|0)==(k|0)){c[199566]=c[199566]&~(1<<p);q=n;r=o;break}do{if((s|0)==(t|0)){u=s+8|0}else{if(s>>>0<e>>>0){b3()}v=s+8|0;if((c[v>>2]|0)==(n|0)){u=v;break}b3()}}while(0);c[k+12>>2]=s;c[u>>2]=k;q=n;r=o;break}t=m;p=c[a+(l+24)>>2]|0;v=c[a+(l+12)>>2]|0;do{if((v|0)==(t|0)){w=a+(l+20)|0;x=c[w>>2]|0;if((x|0)==0){y=a+(l+16)|0;z=c[y>>2]|0;if((z|0)==0){A=0;break}else{B=z;C=y}}else{B=x;C=w}while(1){w=B+20|0;x=c[w>>2]|0;if((x|0)!=0){B=x;C=w;continue}w=B+16|0;x=c[w>>2]|0;if((x|0)==0){break}else{B=x;C=w}}if(C>>>0<e>>>0){b3()}else{c[C>>2]=0;A=B;break}}else{w=c[a+(l+8)>>2]|0;if(w>>>0<e>>>0){b3()}x=w+12|0;if((c[x>>2]|0)!=(t|0)){b3()}y=v+8|0;if((c[y>>2]|0)==(t|0)){c[x>>2]=v;c[y>>2]=w;A=v;break}else{b3()}}}while(0);if((p|0)==0){q=n;r=o;break}v=a+(l+28)|0;m=798568+(c[v>>2]<<2)|0;do{if((t|0)==(c[m>>2]|0)){c[m>>2]=A;if((A|0)!=0){break}c[199567]=c[199567]&~(1<<c[v>>2]);q=n;r=o;break L9771}else{if(p>>>0<(c[199570]|0)>>>0){b3()}k=p+16|0;if((c[k>>2]|0)==(t|0)){c[k>>2]=A}else{c[p+20>>2]=A}if((A|0)==0){q=n;r=o;break L9771}}}while(0);if(A>>>0<(c[199570]|0)>>>0){b3()}c[A+24>>2]=p;t=c[a+(l+16)>>2]|0;do{if((t|0)!=0){if(t>>>0<(c[199570]|0)>>>0){b3()}else{c[A+16>>2]=t;c[t+24>>2]=A;break}}}while(0);t=c[a+(l+20)>>2]|0;if((t|0)==0){q=n;r=o;break}if(t>>>0<(c[199570]|0)>>>0){b3()}else{c[A+20>>2]=t;c[t+24>>2]=A;q=n;r=o;break}}else{q=d;r=h}}while(0);d=q;if(d>>>0>=i>>>0){b3()}A=a+(h-4)|0;e=c[A>>2]|0;if((e&1|0)==0){b3()}do{if((e&2|0)==0){if((j|0)==(c[199572]|0)){B=(c[199569]|0)+r|0;c[199569]=B;c[199572]=q;c[q+4>>2]=B|1;if((q|0)!=(c[199571]|0)){return}c[199571]=0;c[199568]=0;return}if((j|0)==(c[199571]|0)){B=(c[199568]|0)+r|0;c[199568]=B;c[199571]=q;c[q+4>>2]=B|1;c[d+B>>2]=B;return}B=(e&-8)+r|0;C=e>>>3;L9874:do{if(e>>>0<256){u=c[a+h>>2]|0;g=c[a+(h|4)>>2]|0;b=798304+(C<<1<<2)|0;do{if((u|0)!=(b|0)){if(u>>>0<(c[199570]|0)>>>0){b3()}if((c[u+12>>2]|0)==(j|0)){break}b3()}}while(0);if((g|0)==(u|0)){c[199566]=c[199566]&~(1<<C);break}do{if((g|0)==(b|0)){D=g+8|0}else{if(g>>>0<(c[199570]|0)>>>0){b3()}f=g+8|0;if((c[f>>2]|0)==(j|0)){D=f;break}b3()}}while(0);c[u+12>>2]=g;c[D>>2]=u}else{b=i;f=c[a+(h+16)>>2]|0;t=c[a+(h|4)>>2]|0;do{if((t|0)==(b|0)){p=a+(h+12)|0;v=c[p>>2]|0;if((v|0)==0){m=a+(h+8)|0;k=c[m>>2]|0;if((k|0)==0){E=0;break}else{F=k;G=m}}else{F=v;G=p}while(1){p=F+20|0;v=c[p>>2]|0;if((v|0)!=0){F=v;G=p;continue}p=F+16|0;v=c[p>>2]|0;if((v|0)==0){break}else{F=v;G=p}}if(G>>>0<(c[199570]|0)>>>0){b3()}else{c[G>>2]=0;E=F;break}}else{p=c[a+h>>2]|0;if(p>>>0<(c[199570]|0)>>>0){b3()}v=p+12|0;if((c[v>>2]|0)!=(b|0)){b3()}m=t+8|0;if((c[m>>2]|0)==(b|0)){c[v>>2]=t;c[m>>2]=p;E=t;break}else{b3()}}}while(0);if((f|0)==0){break}t=a+(h+20)|0;u=798568+(c[t>>2]<<2)|0;do{if((b|0)==(c[u>>2]|0)){c[u>>2]=E;if((E|0)!=0){break}c[199567]=c[199567]&~(1<<c[t>>2]);break L9874}else{if(f>>>0<(c[199570]|0)>>>0){b3()}g=f+16|0;if((c[g>>2]|0)==(b|0)){c[g>>2]=E}else{c[f+20>>2]=E}if((E|0)==0){break L9874}}}while(0);if(E>>>0<(c[199570]|0)>>>0){b3()}c[E+24>>2]=f;b=c[a+(h+8)>>2]|0;do{if((b|0)!=0){if(b>>>0<(c[199570]|0)>>>0){b3()}else{c[E+16>>2]=b;c[b+24>>2]=E;break}}}while(0);b=c[a+(h+12)>>2]|0;if((b|0)==0){break}if(b>>>0<(c[199570]|0)>>>0){b3()}else{c[E+20>>2]=b;c[b+24>>2]=E;break}}}while(0);c[q+4>>2]=B|1;c[d+B>>2]=B;if((q|0)!=(c[199571]|0)){H=B;break}c[199568]=B;return}else{c[A>>2]=e&-2;c[q+4>>2]=r|1;c[d+r>>2]=r;H=r}}while(0);r=H>>>3;if(H>>>0<256){d=r<<1;e=798304+(d<<2)|0;A=c[199566]|0;E=1<<r;do{if((A&E|0)==0){c[199566]=A|E;I=e;J=798304+(d+2<<2)|0}else{r=798304+(d+2<<2)|0;h=c[r>>2]|0;if(h>>>0>=(c[199570]|0)>>>0){I=h;J=r;break}b3()}}while(0);c[J>>2]=q;c[I+12>>2]=q;c[q+8>>2]=I;c[q+12>>2]=e;return}e=q;I=H>>>8;do{if((I|0)==0){K=0}else{if(H>>>0>16777215){K=31;break}J=(I+1048320|0)>>>16&8;d=I<<J;E=(d+520192|0)>>>16&4;A=d<<E;d=(A+245760|0)>>>16&2;r=14-(E|J|d)+(A<<d>>>15)|0;K=H>>>((r+7|0)>>>0)&1|r<<1}}while(0);I=798568+(K<<2)|0;c[q+28>>2]=K;c[q+20>>2]=0;c[q+16>>2]=0;r=c[199567]|0;d=1<<K;do{if((r&d|0)==0){c[199567]=r|d;c[I>>2]=e;c[q+24>>2]=I;c[q+12>>2]=q;c[q+8>>2]=q}else{if((K|0)==31){L=0}else{L=25-(K>>>1)|0}A=H<<L;J=c[I>>2]|0;while(1){if((c[J+4>>2]&-8|0)==(H|0)){break}M=J+16+(A>>>31<<2)|0;E=c[M>>2]|0;if((E|0)==0){N=7117;break}else{A=A<<1;J=E}}if((N|0)==7117){if(M>>>0<(c[199570]|0)>>>0){b3()}else{c[M>>2]=e;c[q+24>>2]=J;c[q+12>>2]=q;c[q+8>>2]=q;break}}A=J+8|0;B=c[A>>2]|0;E=c[199570]|0;if(J>>>0<E>>>0){b3()}if(B>>>0<E>>>0){b3()}else{c[B+12>>2]=e;c[A>>2]=e;c[q+8>>2]=B;c[q+12>>2]=J;c[q+24>>2]=0;break}}}while(0);q=(c[199574]|0)-1|0;c[199574]=q;if((q|0)==0){O=798720}else{return}while(1){q=c[O>>2]|0;if((q|0)==0){break}else{O=q+8|0}}c[199574]=-1;return}function X_(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0;if((a|0)==0){d=XY(b)|0;return d|0}if(b>>>0>4294967231){c[(dS()|0)>>2]=12;d=0;return d|0}if(b>>>0<11){e=16}else{e=b+11&-8}f=a-8|0;g=a-4|0;h=c[g>>2]|0;i=h&-8;j=i-8|0;k=a+j|0;l=k;m=c[199570]|0;if(f>>>0<m>>>0){b3();return 0}n=h&3;if(!((n|0)!=1&(j|0)>-8)){b3();return 0}j=i|4;o=a+(j-8)|0;p=c[o>>2]|0;if((p&1|0)==0){b3();return 0}L10009:do{if((n|0)==0){if(e>>>0<256|i>>>0<(e|4)>>>0){break}if((i-e|0)>>>0>c[59646]<<1>>>0|(f|0)==0){break}else{d=a}return d|0}else{do{if(i>>>0<e>>>0){if((l|0)==(c[199572]|0)){q=(c[199569]|0)+i|0;if(q>>>0<=e>>>0){break L10009}r=q-e|0;c[g>>2]=h&1|e|2;c[a+((e|4)-8)>>2]=r|1;c[199572]=a+(e-8);c[199569]=r;break}if((l|0)==(c[199571]|0)){r=(c[199568]|0)+i|0;if(r>>>0<e>>>0){break L10009}q=r-e|0;if(q>>>0>15){c[g>>2]=h&1|e|2;c[a+((e|4)-8)>>2]=q|1;c[a+(r-8)>>2]=q;s=a+(r-4)|0;c[s>>2]=c[s>>2]&-2;t=a+(e-8)|0;u=q}else{c[g>>2]=h&1|r|2;q=a+(r-4)|0;c[q>>2]=c[q>>2]|1;t=0;u=0}c[199568]=u;c[199571]=t;break}if((p&2|0)!=0){break L10009}q=(p&-8)+i|0;if(q>>>0<e>>>0){break L10009}r=q-e|0;s=p>>>3;L10033:do{if(p>>>0<256){v=c[a+i>>2]|0;w=c[a+j>>2]|0;x=798304+(s<<1<<2)|0;do{if((v|0)!=(x|0)){if(v>>>0<m>>>0){b3();return 0}if((c[v+12>>2]|0)==(l|0)){break}b3();return 0}}while(0);if((w|0)==(v|0)){c[199566]=c[199566]&~(1<<s);break}do{if((w|0)==(x|0)){y=w+8|0}else{if(w>>>0<m>>>0){b3();return 0}z=w+8|0;if((c[z>>2]|0)==(l|0)){y=z;break}b3();return 0}}while(0);c[v+12>>2]=w;c[y>>2]=v}else{x=k;z=c[a+(i+16)>>2]|0;A=c[a+j>>2]|0;do{if((A|0)==(x|0)){B=a+(i+12)|0;C=c[B>>2]|0;if((C|0)==0){D=a+(i+8)|0;E=c[D>>2]|0;if((E|0)==0){F=0;break}else{G=E;H=D}}else{G=C;H=B}while(1){B=G+20|0;C=c[B>>2]|0;if((C|0)!=0){G=C;H=B;continue}B=G+16|0;C=c[B>>2]|0;if((C|0)==0){break}else{G=C;H=B}}if(H>>>0<m>>>0){b3();return 0}else{c[H>>2]=0;F=G;break}}else{B=c[a+i>>2]|0;if(B>>>0<m>>>0){b3();return 0}C=B+12|0;if((c[C>>2]|0)!=(x|0)){b3();return 0}D=A+8|0;if((c[D>>2]|0)==(x|0)){c[C>>2]=A;c[D>>2]=B;F=A;break}else{b3();return 0}}}while(0);if((z|0)==0){break}A=a+(i+20)|0;v=798568+(c[A>>2]<<2)|0;do{if((x|0)==(c[v>>2]|0)){c[v>>2]=F;if((F|0)!=0){break}c[199567]=c[199567]&~(1<<c[A>>2]);break L10033}else{if(z>>>0<(c[199570]|0)>>>0){b3();return 0}w=z+16|0;if((c[w>>2]|0)==(x|0)){c[w>>2]=F}else{c[z+20>>2]=F}if((F|0)==0){break L10033}}}while(0);if(F>>>0<(c[199570]|0)>>>0){b3();return 0}c[F+24>>2]=z;x=c[a+(i+8)>>2]|0;do{if((x|0)!=0){if(x>>>0<(c[199570]|0)>>>0){b3();return 0}else{c[F+16>>2]=x;c[x+24>>2]=F;break}}}while(0);x=c[a+(i+12)>>2]|0;if((x|0)==0){break}if(x>>>0<(c[199570]|0)>>>0){b3();return 0}else{c[F+20>>2]=x;c[x+24>>2]=F;break}}}while(0);if(r>>>0>=16){c[g>>2]=c[g>>2]&1|e|2;c[a+((e|4)-8)>>2]=r|3;s=a+((q|4)-8)|0;c[s>>2]=c[s>>2]|1;X$(a+(e-8)|0,r);break}c[g>>2]=q|c[g>>2]&1|2;s=a+((q|4)-8)|0;c[s>>2]=c[s>>2]|1;d=a;return d|0}else{s=i-e|0;if(s>>>0<=15){break}c[g>>2]=h&1|e|2;c[a+((e|4)-8)>>2]=s|3;c[o>>2]=c[o>>2]|1;X$(a+(e-8)|0,s);d=a;return d|0}}while(0);if((f|0)==0){break}else{d=a}return d|0}}while(0);f=XY(b)|0;if((f|0)==0){d=0;return d|0}e=c[g>>2]|0;g=(e&-8)-((e&3|0)==0?8:4)|0;e=g>>>0<b>>>0?g:b;X5(f|0,a|0,e)|0;XZ(a);d=f;return d|0}function X$(a,b){a=a|0;b=b|0;var d=0,e=0,f=0,g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0,K=0,L=0;d=a;e=d+b|0;f=e;g=c[a+4>>2]|0;L10115:do{if((g&1|0)==0){h=c[a>>2]|0;if((g&3|0)==0){return}i=d+(-h|0)|0;j=i;k=h+b|0;l=c[199570]|0;if(i>>>0<l>>>0){b3()}if((j|0)==(c[199571]|0)){m=d+(b+4)|0;if((c[m>>2]&3|0)!=3){n=j;o=k;break}c[199568]=k;c[m>>2]=c[m>>2]&-2;c[d+(4-h)>>2]=k|1;c[e>>2]=k;return}m=h>>>3;if(h>>>0<256){p=c[d+(8-h)>>2]|0;q=c[d+(12-h)>>2]|0;r=798304+(m<<1<<2)|0;do{if((p|0)!=(r|0)){if(p>>>0<l>>>0){b3()}if((c[p+12>>2]|0)==(j|0)){break}b3()}}while(0);if((q|0)==(p|0)){c[199566]=c[199566]&~(1<<m);n=j;o=k;break}do{if((q|0)==(r|0)){s=q+8|0}else{if(q>>>0<l>>>0){b3()}t=q+8|0;if((c[t>>2]|0)==(j|0)){s=t;break}b3()}}while(0);c[p+12>>2]=q;c[s>>2]=p;n=j;o=k;break}r=i;m=c[d+(24-h)>>2]|0;t=c[d+(12-h)>>2]|0;do{if((t|0)==(r|0)){u=16-h|0;v=d+(u+4)|0;w=c[v>>2]|0;if((w|0)==0){x=d+u|0;u=c[x>>2]|0;if((u|0)==0){y=0;break}else{z=u;A=x}}else{z=w;A=v}while(1){v=z+20|0;w=c[v>>2]|0;if((w|0)!=0){z=w;A=v;continue}v=z+16|0;w=c[v>>2]|0;if((w|0)==0){break}else{z=w;A=v}}if(A>>>0<l>>>0){b3()}else{c[A>>2]=0;y=z;break}}else{v=c[d+(8-h)>>2]|0;if(v>>>0<l>>>0){b3()}w=v+12|0;if((c[w>>2]|0)!=(r|0)){b3()}x=t+8|0;if((c[x>>2]|0)==(r|0)){c[w>>2]=t;c[x>>2]=v;y=t;break}else{b3()}}}while(0);if((m|0)==0){n=j;o=k;break}t=d+(28-h)|0;l=798568+(c[t>>2]<<2)|0;do{if((r|0)==(c[l>>2]|0)){c[l>>2]=y;if((y|0)!=0){break}c[199567]=c[199567]&~(1<<c[t>>2]);n=j;o=k;break L10115}else{if(m>>>0<(c[199570]|0)>>>0){b3()}i=m+16|0;if((c[i>>2]|0)==(r|0)){c[i>>2]=y}else{c[m+20>>2]=y}if((y|0)==0){n=j;o=k;break L10115}}}while(0);if(y>>>0<(c[199570]|0)>>>0){b3()}c[y+24>>2]=m;r=16-h|0;t=c[d+r>>2]|0;do{if((t|0)!=0){if(t>>>0<(c[199570]|0)>>>0){b3()}else{c[y+16>>2]=t;c[t+24>>2]=y;break}}}while(0);t=c[d+(r+4)>>2]|0;if((t|0)==0){n=j;o=k;break}if(t>>>0<(c[199570]|0)>>>0){b3()}else{c[y+20>>2]=t;c[t+24>>2]=y;n=j;o=k;break}}else{n=a;o=b}}while(0);a=c[199570]|0;if(e>>>0<a>>>0){b3()}y=d+(b+4)|0;z=c[y>>2]|0;do{if((z&2|0)==0){if((f|0)==(c[199572]|0)){A=(c[199569]|0)+o|0;c[199569]=A;c[199572]=n;c[n+4>>2]=A|1;if((n|0)!=(c[199571]|0)){return}c[199571]=0;c[199568]=0;return}if((f|0)==(c[199571]|0)){A=(c[199568]|0)+o|0;c[199568]=A;c[199571]=n;c[n+4>>2]=A|1;c[n+A>>2]=A;return}A=(z&-8)+o|0;s=z>>>3;L10214:do{if(z>>>0<256){g=c[d+(b+8)>>2]|0;t=c[d+(b+12)>>2]|0;h=798304+(s<<1<<2)|0;do{if((g|0)!=(h|0)){if(g>>>0<a>>>0){b3()}if((c[g+12>>2]|0)==(f|0)){break}b3()}}while(0);if((t|0)==(g|0)){c[199566]=c[199566]&~(1<<s);break}do{if((t|0)==(h|0)){B=t+8|0}else{if(t>>>0<a>>>0){b3()}m=t+8|0;if((c[m>>2]|0)==(f|0)){B=m;break}b3()}}while(0);c[g+12>>2]=t;c[B>>2]=g}else{h=e;m=c[d+(b+24)>>2]|0;l=c[d+(b+12)>>2]|0;do{if((l|0)==(h|0)){i=d+(b+20)|0;p=c[i>>2]|0;if((p|0)==0){q=d+(b+16)|0;v=c[q>>2]|0;if((v|0)==0){C=0;break}else{D=v;E=q}}else{D=p;E=i}while(1){i=D+20|0;p=c[i>>2]|0;if((p|0)!=0){D=p;E=i;continue}i=D+16|0;p=c[i>>2]|0;if((p|0)==0){break}else{D=p;E=i}}if(E>>>0<a>>>0){b3()}else{c[E>>2]=0;C=D;break}}else{i=c[d+(b+8)>>2]|0;if(i>>>0<a>>>0){b3()}p=i+12|0;if((c[p>>2]|0)!=(h|0)){b3()}q=l+8|0;if((c[q>>2]|0)==(h|0)){c[p>>2]=l;c[q>>2]=i;C=l;break}else{b3()}}}while(0);if((m|0)==0){break}l=d+(b+28)|0;g=798568+(c[l>>2]<<2)|0;do{if((h|0)==(c[g>>2]|0)){c[g>>2]=C;if((C|0)!=0){break}c[199567]=c[199567]&~(1<<c[l>>2]);break L10214}else{if(m>>>0<(c[199570]|0)>>>0){b3()}t=m+16|0;if((c[t>>2]|0)==(h|0)){c[t>>2]=C}else{c[m+20>>2]=C}if((C|0)==0){break L10214}}}while(0);if(C>>>0<(c[199570]|0)>>>0){b3()}c[C+24>>2]=m;h=c[d+(b+16)>>2]|0;do{if((h|0)!=0){if(h>>>0<(c[199570]|0)>>>0){b3()}else{c[C+16>>2]=h;c[h+24>>2]=C;break}}}while(0);h=c[d+(b+20)>>2]|0;if((h|0)==0){break}if(h>>>0<(c[199570]|0)>>>0){b3()}else{c[C+20>>2]=h;c[h+24>>2]=C;break}}}while(0);c[n+4>>2]=A|1;c[n+A>>2]=A;if((n|0)!=(c[199571]|0)){F=A;break}c[199568]=A;return}else{c[y>>2]=z&-2;c[n+4>>2]=o|1;c[n+o>>2]=o;F=o}}while(0);o=F>>>3;if(F>>>0<256){z=o<<1;y=798304+(z<<2)|0;C=c[199566]|0;b=1<<o;do{if((C&b|0)==0){c[199566]=C|b;G=y;H=798304+(z+2<<2)|0}else{o=798304+(z+2<<2)|0;d=c[o>>2]|0;if(d>>>0>=(c[199570]|0)>>>0){G=d;H=o;break}b3()}}while(0);c[H>>2]=n;c[G+12>>2]=n;c[n+8>>2]=G;c[n+12>>2]=y;return}y=n;G=F>>>8;do{if((G|0)==0){I=0}else{if(F>>>0>16777215){I=31;break}H=(G+1048320|0)>>>16&8;z=G<<H;b=(z+520192|0)>>>16&4;C=z<<b;z=(C+245760|0)>>>16&2;o=14-(b|H|z)+(C<<z>>>15)|0;I=F>>>((o+7|0)>>>0)&1|o<<1}}while(0);G=798568+(I<<2)|0;c[n+28>>2]=I;c[n+20>>2]=0;c[n+16>>2]=0;o=c[199567]|0;z=1<<I;if((o&z|0)==0){c[199567]=o|z;c[G>>2]=y;c[n+24>>2]=G;c[n+12>>2]=n;c[n+8>>2]=n;return}if((I|0)==31){J=0}else{J=25-(I>>>1)|0}I=F<<J;J=c[G>>2]|0;while(1){if((c[J+4>>2]&-8|0)==(F|0)){break}K=J+16+(I>>>31<<2)|0;G=c[K>>2]|0;if((G|0)==0){L=7383;break}else{I=I<<1;J=G}}if((L|0)==7383){if(K>>>0<(c[199570]|0)>>>0){b3()}c[K>>2]=y;c[n+24>>2]=J;c[n+12>>2]=n;c[n+8>>2]=n;return}K=J+8|0;L=c[K>>2]|0;I=c[199570]|0;if(J>>>0<I>>>0){b3()}if(L>>>0<I>>>0){b3()}c[L+12>>2]=y;c[K>>2]=y;c[n+8>>2]=L;c[n+12>>2]=J;c[n+24>>2]=0;return}function X0(b){b=b|0;var d=0,e=0,f=0,g=0,i=0,j=0,k=0,l=0,m=0,n=0.0,o=0,p=0,q=0,r=0,s=0.0,t=0,u=0,v=0,w=0.0,x=0.0,y=0,z=0,A=0,B=0.0,C=0,D=0,E=0,F=0,G=0,H=0,I=0,J=0.0,K=0,L=0,M=0.0,N=0.0,O=0.0;d=b;while(1){e=d+1|0;if((bc(a[d]|0)|0)==0){break}else{d=e}}b=a[d]|0;if((b<<24>>24|0)==43){f=e;g=0}else if((b<<24>>24|0)==45){f=e;g=1}else{f=d;g=0}d=-1;e=0;b=f;while(1){i=a[b]|0;if(((i<<24>>24)-48|0)>>>0<10){j=d}else{if(i<<24>>24!=46|(d|0)>-1){break}else{j=e}}d=j;e=e+1|0;b=b+1|0}j=b+(-e|0)|0;f=(d|0)<0;k=((f^1)<<31>>31)+e|0;l=(k|0)>18;m=(l?-18:-k|0)+(f?e:d)|0;d=l?18:k;do{if((d|0)==0){n=0.0}else{if((d|0)>9){k=j;l=d;e=0;while(1){f=a[k]|0;o=k+1|0;if(f<<24>>24==46){p=a[o]|0;q=k+2|0}else{p=f;q=o}r=(e*10|0)-48+(p<<24>>24)|0;o=l-1|0;if((o|0)>9){k=q;l=o;e=r}else{break}}s=+(r|0)*1.0e9;t=9;u=q;v=7431}else{if((d|0)>0){s=0.0;t=d;u=j;v=7431}else{w=0.0;x=0.0}}if((v|0)==7431){e=u;l=t;k=0;while(1){o=a[e]|0;f=e+1|0;if(o<<24>>24==46){y=a[f]|0;z=e+2|0}else{y=o;z=f}A=(k*10|0)-48+(y<<24>>24)|0;f=l-1|0;if((f|0)>0){e=z;l=f;k=A}else{break}}w=+(A|0);x=s}B=x+w;do{if((i<<24>>24|0)==69|(i<<24>>24|0)==101){k=b+1|0;l=a[k]|0;if((l<<24>>24|0)==45){C=b+2|0;D=1}else if((l<<24>>24|0)==43){C=b+2|0;D=0}else{C=k;D=0}k=a[C]|0;if(((k<<24>>24)-48|0)>>>0<10){E=C;F=0;G=k}else{H=0;I=D;break}while(1){k=(G<<24>>24)-48+(F*10|0)|0;l=E+1|0;e=a[l]|0;if(((e<<24>>24)-48|0)>>>0<10){E=l;F=k;G=e}else{H=k;I=D;break}}}else{H=0;I=0}}while(0);k=m+((I|0)==0?H:-H|0)|0;e=(k|0)<0?-k|0:k;if((e|0)>511){c[(dS()|0)>>2]=34;J=1.0;K=6704;L=511;v=7448}else{if((e|0)==0){M=1.0}else{J=1.0;K=6704;L=e;v=7448}}if((v|0)==7448){while(1){v=0;if((L&1|0)==0){N=J}else{N=J*+h[K>>3]}e=L>>1;if((e|0)==0){M=N;break}else{J=N;K=K+8|0;L=e;v=7448}}}if((k|0)>-1){n=B*M;break}else{n=B/M;break}}}while(0);if((g|0)==0){O=n;return+O}O=-0.0-n;return+O}function X1(b){b=b|0;var c=0;c=b;while(a[c]|0){c=c+1|0}return c-b|0}function X2(b,d,e){b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0;f=b+e|0;if((e|0)>=20){d=d&255;e=b&3;g=d|d<<8|d<<16|d<<24;h=f&~3;if(e){e=b+4-e|0;while((b|0)<(e|0)){a[b]=d;b=b+1|0}}while((b|0)<(h|0)){c[b>>2]=g;b=b+4|0}}while((b|0)<(f|0)){a[b]=d;b=b+1|0}}function X3(a,b,d){a=a|0;b=b|0;d=d|0;var e=0;u=u+1|0;c[a>>2]=u;while((e|0)<40){if((c[d+(e<<2)>>2]|0)==0){c[d+(e<<2)>>2]=u;c[d+((e<<2)+4)>>2]=b;c[d+((e<<2)+8)>>2]=0;return 0}e=e+2|0}cG(116);cG(111);cG(111);cG(32);cG(109);cG(97);cG(110);cG(121);cG(32);cG(115);cG(101);cG(116);cG(106);cG(109);cG(112);cG(115);cG(32);cG(105);cG(110);cG(32);cG(97);cG(32);cG(102);cG(117);cG(110);cG(99);cG(116);cG(105);cG(111);cG(110);cG(32);cG(99);cG(97);cG(108);cG(108);cG(44);cG(32);cG(98);cG(117);cG(105);cG(108);cG(100);cG(32);cG(119);cG(105);cG(116);cG(104);cG(32);cG(97);cG(32);cG(104);cG(105);cG(103);cG(104);cG(101);cG(114);cG(32);cG(118);cG(97);cG(108);cG(117);cG(101);cG(32);cG(102);cG(111);cG(114);cG(32);cG(77);cG(65);cG(88);cG(95);cG(83);cG(69);cG(84);cG(74);cG(77);cG(80);cG(83);cG(10);ac(0);return 0}function X4(a,b){a=a|0;b=b|0;var d=0,e=0;while((d|0)<20){e=c[b+(d<<2)>>2]|0;if((e|0)==0)break;if((e|0)==(a|0)){return c[b+((d<<2)+4)>>2]|0}d=d+2|0}return 0}function X5(b,d,e){b=b|0;d=d|0;e=e|0;var f=0;f=b|0;if((b&3)==(d&3)){while(b&3){if((e|0)==0)return f|0;a[b]=a[d]|0;b=b+1|0;d=d+1|0;e=e-1|0}while((e|0)>=4){c[b>>2]=c[d>>2];b=b+4|0;d=d+4|0;e=e-4|0}}while((e|0)>0){a[b]=a[d]|0;b=b+1|0;d=d+1|0;e=e-1|0}return f|0}function X6(a){a=a|0;if((a|0)<65)return a|0;if((a|0)>90)return a|0;return a-65+97|0}function X7(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0;while(e>>>0<d>>>0){f=X6(a[b+e|0]|0)|0;g=X6(a[c+e|0]|0)|0;if((f|0)==(g|0)&(f|0)==0)return 0;if((f|0)==0)return-1;if((g|0)==0)return 1;if((f|0)==(g|0)){e=e+1|0;continue}else{return(f>>>0>g>>>0?1:-1)|0}}return 0}function X8(a,b){a=a|0;b=b|0;return X7(a,b,-1)|0}function X9(b,c,d){b=b|0;c=c|0;d=d|0;if((c|0)<(b|0)&(b|0)<(c+d|0)){c=c+d|0;b=b+d|0;while((d|0)>0){b=b-1|0;c=c-1|0;d=d-1|0;a[b]=a[c]|0}}else{X5(b,c,d)|0}}function Ya(a,b,c){a=a|0;b=b|0;c=c|0;var e=0,f=0,g=0;while((e|0)<(c|0)){f=d[a+e|0]|0;g=d[b+e|0]|0;if((f|0)!=(g|0))return((f|0)>(g|0)?1:-1)|0;e=e+1|0}return 0}function Yb(b,c){b=b|0;c=c|0;var d=0;do{a[b+d|0]=a[c+d|0];d=d+1|0}while(a[c+(d-1)|0]|0);return b|0}function Yc(b,c,d){b=b|0;c=c|0;d=d|0;var e=0,f=0;while((e|0)<(d|0)){a[b+e|0]=f?0:a[c+e|0]|0;f=f?1:(a[c+e|0]|0)==0;e=e+1|0}return b|0}function Yd(b,c){b=b|0;c=c|0;var d=0,e=0;d=b+(X1(b)|0)|0;do{a[d+e|0]=a[c+e|0];e=e+1|0}while(a[c+(e-1)|0]|0);return b|0}function Ye(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=a+c>>>0;return(F=b+d+(e>>>0<a>>>0|0)>>>0,e|0)|0}function Yf(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=b-d>>>0;e=b-d-(c>>>0>a>>>0|0)>>>0;return(F=e,a-c>>>0|0)|0}function Yg(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)<32){F=b<<c|(a&(1<<c)-1<<32-c)>>>32-c;return a<<c}F=a<<c-32;return 0}function Yh(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)<32){F=b>>>c;return a>>>c|(b&(1<<c)-1)<<32-c}F=0;return b>>>c-32|0}function Yi(a,b,c){a=a|0;b=b|0;c=c|0;if((c|0)<32){F=b>>c;return a>>>c|(b&(1<<c)-1)<<32-c}F=(b|0)<0?-1:0;return b>>c-32|0}function Yj(b){b=b|0;var c=0;c=a[n+(b>>>24)|0]|0;if((c|0)<8)return c|0;c=a[n+(b>>16&255)|0]|0;if((c|0)<8)return c+8|0;c=a[n+(b>>8&255)|0]|0;if((c|0)<8)return c+16|0;return(a[n+(b&255)|0]|0)+24|0}function Yk(b){b=b|0;var c=0;c=a[m+(b&255)|0]|0;if((c|0)<8)return c|0;c=a[m+(b>>8&255)|0]|0;if((c|0)<8)return c+8|0;c=a[m+(b>>16&255)|0]|0;if((c|0)<8)return c+16|0;return(a[m+(b>>>24)|0]|0)+24|0}function Yl(a,b){a=a|0;b=b|0;var c=0,d=0,e=0,f=0;c=a&65535;d=b&65535;e=ab(d,c)|0;f=a>>>16;a=(e>>>16)+(ab(d,f)|0)|0;d=b>>>16;b=ab(d,c)|0;return(F=(a>>>16)+(ab(d,f)|0)+(((a&65535)+b|0)>>>16)|0,a+b<<16|e&65535|0)|0}function Ym(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0,g=0,h=0,i=0;e=b>>31|((b|0)<0?-1:0)<<1;f=((b|0)<0?-1:0)>>31|((b|0)<0?-1:0)<<1;g=d>>31|((d|0)<0?-1:0)<<1;h=((d|0)<0?-1:0)>>31|((d|0)<0?-1:0)<<1;i=Yf(e^a,f^b,e,f)|0;b=F;a=g^e;e=h^f;f=Yf((Yr(i,b,Yf(g^c,h^d,g,h)|0,F,0)|0)^a,F^e,a,e)|0;return(F=F,f)|0}function Yn(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0,h=0,j=0,k=0,l=0,m=0;f=i;i=i+8|0;g=f|0;h=b>>31|((b|0)<0?-1:0)<<1;j=((b|0)<0?-1:0)>>31|((b|0)<0?-1:0)<<1;k=e>>31|((e|0)<0?-1:0)<<1;l=((e|0)<0?-1:0)>>31|((e|0)<0?-1:0)<<1;m=Yf(h^a,j^b,h,j)|0;b=F;a=Yf(k^d,l^e,k,l)|0;Yr(m,b,a,F,g)|0;a=Yf(c[g>>2]^h,c[g+4>>2]^j,h,j)|0;j=F;i=f;return(F=j,a)|0}function Yo(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0,f=0;e=a;a=c;c=Yl(e,a)|0;f=F;return(F=(ab(b,a)|0)+(ab(d,e)|0)+f|f&0,c|0|0)|0}function Yp(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;var e=0;e=Yr(a,b,c,d,0)|0;return(F=F,e)|0}function Yq(a,b,d,e){a=a|0;b=b|0;d=d|0;e=e|0;var f=0,g=0;f=i;i=i+8|0;g=f|0;Yr(a,b,d,e,g)|0;i=f;return(F=c[g+4>>2]|0,c[g>>2]|0)|0}function Yr(a,b,d,e,f){a=a|0;b=b|0;d=d|0;e=e|0;f=f|0;var g=0,h=0,i=0,j=0,k=0,l=0,m=0,n=0,o=0,p=0,q=0,r=0,s=0,t=0,u=0,v=0,w=0,x=0,y=0,z=0,A=0,B=0,C=0,D=0,E=0,G=0,H=0,I=0,J=0,K=0,L=0,M=0;g=a;h=b;i=h;j=d;k=e;l=k;if((i|0)==0){m=(f|0)!=0;if((l|0)==0){if(m){c[f>>2]=(g>>>0)%(j>>>0);c[f+4>>2]=0}n=0;o=(g>>>0)/(j>>>0)>>>0;return(F=n,o)|0}else{if(!m){n=0;o=0;return(F=n,o)|0}c[f>>2]=a|0;c[f+4>>2]=b&0;n=0;o=0;return(F=n,o)|0}}m=(l|0)==0;do{if((j|0)==0){if(m){if((f|0)!=0){c[f>>2]=(i>>>0)%(j>>>0);c[f+4>>2]=0}n=0;o=(i>>>0)/(j>>>0)>>>0;return(F=n,o)|0}if((g|0)==0){if((f|0)!=0){c[f>>2]=0;c[f+4>>2]=(i>>>0)%(l>>>0)}n=0;o=(i>>>0)/(l>>>0)>>>0;return(F=n,o)|0}p=l-1|0;if((p&l|0)==0){if((f|0)!=0){c[f>>2]=a|0;c[f+4>>2]=p&i|b&0}n=0;o=i>>>((Yk(l|0)|0)>>>0);return(F=n,o)|0}p=(Yj(l|0)|0)-(Yj(i|0)|0)|0;if(p>>>0<=30){q=p+1|0;r=31-p|0;s=q;t=i<<r|g>>>(q>>>0);u=i>>>(q>>>0);v=0;w=g<<r;break}if((f|0)==0){n=0;o=0;return(F=n,o)|0}c[f>>2]=a|0;c[f+4>>2]=h|b&0;n=0;o=0;return(F=n,o)|0}else{if(!m){r=(Yj(l|0)|0)-(Yj(i|0)|0)|0;if(r>>>0<=31){q=r+1|0;p=31-r|0;x=r-31>>31;s=q;t=g>>>(q>>>0)&x|i<<p;u=i>>>(q>>>0)&x;v=0;w=g<<p;break}if((f|0)==0){n=0;o=0;return(F=n,o)|0}c[f>>2]=a|0;c[f+4>>2]=h|b&0;n=0;o=0;return(F=n,o)|0}p=j-1|0;if((p&j|0)!=0){x=(Yj(j|0)|0)+33-(Yj(i|0)|0)|0;q=64-x|0;r=32-x|0;y=r>>31;z=x-32|0;A=z>>31;s=x;t=r-1>>31&i>>>(z>>>0)|(i<<r|g>>>(x>>>0))&A;u=A&i>>>(x>>>0);v=g<<q&y;w=(i<<q|g>>>(z>>>0))&y|g<<r&x-33>>31;break}if((f|0)!=0){c[f>>2]=p&g;c[f+4>>2]=0}if((j|0)==1){n=h|b&0;o=a|0|0;return(F=n,o)|0}else{p=Yk(j|0)|0;n=i>>>(p>>>0)|0;o=i<<32-p|g>>>(p>>>0)|0;return(F=n,o)|0}}}while(0);if((s|0)==0){B=w;C=v;D=u;E=t;G=0;H=0}else{g=d|0|0;d=k|e&0;e=Ye(g,d,-1,-1)|0;k=F;i=w;w=v;v=u;u=t;t=s;s=0;while(1){I=w>>>31|i<<1;J=s|w<<1;j=u<<1|i>>>31|0;a=u>>>31|v<<1|0;Yf(e,k,j,a)|0;b=F;h=b>>31|((b|0)<0?-1:0)<<1;K=h&1;L=Yf(j,a,h&g,(((b|0)<0?-1:0)>>31|((b|0)<0?-1:0)<<1)&d)|0;M=F;b=t-1|0;if((b|0)==0){break}else{i=I;w=J;v=M;u=L;t=b;s=K}}B=I;C=J;D=M;E=L;G=0;H=K}K=C;C=0;if((f|0)!=0){c[f>>2]=E;c[f+4>>2]=D}n=(K|0)>>>31|(B|C)<<1|(C<<1|K>>>31)&0|G;o=(K<<1|0>>>31)&-2|H;return(F=n,o)|0}function Ys(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;de(a|0,b|0,c|0,d|0,e|0)}function Yt(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;ev(a|0,b|0,c|0,d|0,e|0)}function Yu(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;dt(a|0,b|0,c|0,d|0,e|0)}function Yv(a,b){a=a|0;b=+b;bB(a|0,+b)}function Yw(a){a=a|0;bq(a|0)}function Yx(a){a=a|0;c$(a|0)}function Yy(a){a=a|0;eP(a|0)}function Yz(a){a=a|0;cO(a|0)}function YA(a){a=a|0;eX(a|0)}function YB(a){a=a|0;cK(a|0)}function YC(a){a=a|0;by(a|0)}function YD(a){a=a|0;bl(a|0)}function YE(a){a=a|0;eY(a|0)}function YF(a){a=a|0;bM(a|0)}function YG(a){a=a|0;d1(a|0)}function YH(a){a=a|0;dg(a|0)}function YI(a){a=a|0;cc(a|0)}function YJ(a){a=a|0;ek(a|0)}function YK(a){a=a|0;bn(a|0)}function YL(a){a=a|0;bb(a|0)}function YM(a){a=a|0;d5(a|0)}function YN(a){a=a|0;c_(a|0)}function YO(a){a=a|0;cI(a|0)}function YP(a){a=a|0;dl(a|0)}function YQ(a){a=a|0;dc(a|0)}function YR(a){a=a|0;e6(a|0)}function YS(a){a=a|0;bv(a|0)}function YT(a){a=a|0;a6(a|0)}function YU(a){a=a|0;cd(a|0)}function YV(a,b){a=a|0;b=b|0;dO(a|0,b|0)}function YW(a,b){a=a|0;b=b|0;bx(a|0,b|0)}function YX(a,b){a=a|0;b=b|0;dK(a|0,b|0)}function YY(a,b){a=a|0;b=b|0;d$(a|0,b|0)}function YZ(a,b){a=a|0;b=b|0;c3(a|0,b|0)}function Y_(a,b){a=a|0;b=b|0;be(a|0,b|0)}function Y$(a,b){a=a|0;b=b|0;bL(a|0,b|0)}function Y0(a,b){a=a|0;b=b|0;cV(a|0,b|0)}function Y1(a,b){a=a|0;b=b|0;ey(a|0,b|0)}function Y2(a,b){a=a|0;b=b|0;cZ(a|0,b|0)}function Y3(a,b){a=a|0;b=b|0;bV(a|0,b|0)}function Y4(a,b){a=a|0;b=b|0;b$(a|0,b|0)}function Y5(a,b){a=a|0;b=b|0;es(a|0,b|0)}function Y6(a,b){a=a|0;b=b|0;cM(a|0,b|0)}function Y7(a,b){a=a|0;b=b|0;cQ(a|0,b|0)}function Y8(a,b){a=a|0;b=b|0;e4(a|0,b|0)}function Y9(a,b){a=a|0;b=b|0;e_(a|0,b|0)}function Za(a,b){a=a|0;b=b|0;e7(a|0,b|0)}function Zb(a,b){a=a|0;b=b|0;b5(a|0,b|0)}function Zc(a,b){a=a|0;b=b|0;eZ(a|0,b|0)}function Zd(a,b){a=a|0;b=b|0;bF(a|0,b|0)}function Ze(a,b){a=a|0;b=b|0;eC(a|0,b|0)}function Zf(a,b){a=a|0;b=b|0;ch(a|0,b|0)}function Zg(a,b){a=a|0;b=b|0;ct(a|0,b|0)}function Zh(a,b){a=a|0;b=b|0;bU(a|0,b|0)}function Zi(a,b){a=a|0;b=b|0;dT(a|0,b|0)}function Zj(a,b){a=a|0;b=b|0;aX(a|0,b|0)}function Zk(a,b){a=a|0;b=b|0;cD(a|0,b|0)}function Zl(a,b){a=a|0;b=b|0;e2(a|0,b|0)}function Zm(a,b){a=a|0;b=b|0;eu(a|0,b|0)}function Zn(a,b){a=a|0;b=b|0;dr(a|0,b|0)}function Zo(a,b){a=a|0;b=b|0;bI(a|0,b|0)}function Zp(a,b){a=a|0;b=b|0;dJ(a|0,b|0)}function Zq(a){a=a|0;return cG(a|0)|0}function Zr(a){a=a|0;return dC(a|0)|0}function Zs(a){a=a|0;return ea(a|0)|0}function Zt(a){a=a|0;return dW(a|0)|0}function Zu(a){a=a|0;return aQ(a|0)|0}function Zv(a){a=a|0;return b0(a|0)|0}function Zw(a){a=a|0;return bG(a|0)|0}function Zx(a){a=a|0;return bt(a|0)|0}function Zy(a){a=a|0;return a1(a|0)|0}function Zz(a){a=a|0;return dd(a|0)|0}function ZA(a){a=a|0;return cl(a|0)|0}function ZB(a){a=a|0;return dq(a|0)|0}function ZC(a){a=a|0;return b8(a|0)|0}function ZD(a){a=a|0;return ck(a|0)|0}function ZE(a){a=a|0;return aY(a|0)|0}function ZF(a,b,c,d,e){a=a|0;b=+b;c=+c;d=+d;e=+e;ds(a|0,+b,+c,+d,+e)}function ZG(a,b,c){a=a|0;b=b|0;c=c|0;return bJ(a|0,b|0,c|0)|0}function ZH(a,b,c){a=a|0;b=b|0;c=c|0;return aV(a|0,b|0,c|0)|0}function ZI(a,b,c){a=a|0;b=b|0;c=c|0;return d8(a|0,b|0,c|0)|0}function ZJ(a,b,c){a=a|0;b=b|0;c=c|0;return a$(a|0,b|0,c|0)|0}function ZK(a,b,c){a=a|0;b=b|0;c=c|0;return cP(a|0,b|0,c|0)|0}function ZL(a,b,c){a=a|0;b=b|0;c=c|0;return ec(a|0,b|0,c|0)|0}function ZM(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;bT(a|0,b|0,c|0,d|0,e|0,f|0)}function ZN(a){a=+a;return+bH(+a)}function ZO(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;d2(a|0,b|0,c|0,d|0,e|0,f|0,g|0,h|0,i|0)}function ZP(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;d4(a|0,b|0,c|0,d|0,e|0,f|0,g|0,h|0,i|0)}function ZQ(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;bA(a|0,b|0,c|0,d|0,e|0,f|0,g|0,h|0,i|0)}function ZR(a,b){a=a|0;b=b|0;return c5(a|0,b|0)|0}function ZS(a,b){a=a|0;b=b|0;return dB(a|0,b|0)|0}function ZT(a,b){a=a|0;b=b|0;return c2(a|0,b|0)|0}function ZU(a,b){a=a|0;b=b|0;return eB(a|0,b|0)|0}function ZV(a,b){a=a|0;b=b|0;return cL(a|0,b|0)|0}function ZW(){return+a8()}function ZX(){return dF()|0}function ZY(){return ez()|0}function ZZ(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return bN(a|0,b|0,c|0,d|0)|0}function Z_(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return a2(a|0,b|0,c|0,d|0)|0}function Z$(a,b,c){a=a|0;b=b|0;c=c|0;dI(a|0,b|0,c|0)}function Z0(a,b,c){a=a|0;b=b|0;c=c|0;eH(a|0,b|0,c|0)}function Z1(a,b,c){a=a|0;b=b|0;c=c|0;b7(a|0,b|0,c|0)}function Z2(a,b,c){a=a|0;b=b|0;c=c|0;aT(a|0,b|0,c|0)}function Z3(a,b,c){a=a|0;b=b|0;c=c|0;cR(a|0,b|0,c|0)}function Z4(a,b,c){a=a|0;b=b|0;c=c|0;dp(a|0,b|0,c|0)}function Z5(a,b,c){a=a|0;b=b|0;c=c|0;ba(a|0,b|0,c|0)}function Z6(a,b,c){a=a|0;b=b|0;c=c|0;c7(a|0,b|0,c|0)}function Z7(a,b,c){a=a|0;b=b|0;c=c|0;cH(a|0,b|0,c|0)}function Z8(a,b,c){a=a|0;b=b|0;c=c|0;eU(a|0,b|0,c|0)}function Z9(a,b,c){a=a|0;b=b|0;c=c|0;bs(a|0,b|0,c|0)}function _a(a,b,c){a=a|0;b=b|0;c=c|0;b2(a|0,b|0,c|0)}function _b(a,b,c){a=a|0;b=b|0;c=c|0;eq(a|0,b|0,c|0)}function _c(a,b,c){a=a|0;b=b|0;c=c|0;bD(a|0,b|0,c|0)}function _d(a,b,c){a=a|0;b=b|0;c=c|0;cr(a|0,b|0,c|0)}function _e(a,b,c){a=a|0;b=b|0;c=c|0;bp(a|0,b|0,c|0)}function _f(a,b,c){a=a|0;b=b|0;c=c|0;aS(a|0,b|0,c|0)}function _g(a,b,c){a=a|0;b=b|0;c=c|0;a7(a|0,b|0,c|0)}function _h(a,b,c){a=a|0;b=b|0;c=c|0;dH(a|0,b|0,c|0)}function _i(a,b,c){a=a|0;b=b|0;c=c|0;bQ(a|0,b|0,c|0)}function _j(a,b,c){a=a|0;b=b|0;c=c|0;dn(a|0,b|0,c|0)}function _k(a,b,c){a=a|0;b=b|0;c=c|0;bO(a|0,b|0,c|0)}function _l(a,b,c){a=a|0;b=b|0;c=c|0;dM(a|0,b|0,c|0)}function _m(a,b,c){a=a|0;b=b|0;c=c|0;cE(a|0,b|0,c|0)}function _n(a,b,c){a=a|0;b=b|0;c=c|0;aZ(a|0,b|0,c|0)}function _o(a,b,c){a=a|0;b=b|0;c=c|0;bo(a|0,b|0,c|0)}function _p(a,b,c){a=a|0;b=b|0;c=c|0;dG(a|0,b|0,c|0)}function _q(a,b,c){a=a|0;b=b|0;c=c|0;eL(a|0,b|0,c|0)}function _r(a,b,c){a=a|0;b=b|0;c=c|0;eW(a|0,b|0,c|0)}function _s(){et()}function _t(){cs()}function _u(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;du(a|0,b|0,c|0,d|0)}function _v(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;eO(a|0,b|0,c|0,d|0)}function _w(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;b_(a|0,b|0,c|0,d|0)}function _x(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;el(a|0,b|0,c|0,d|0)}function _y(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ej(a|0,b|0,c|0,d|0)}function _z(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;bR(a|0,b|0,c|0,d|0)}function _A(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;dz(a|0,b|0,c|0,d|0)}function _B(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;cU(a|0,b|0,c|0,d|0)}function _C(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;dP(a|0,b|0,c|0,d|0)}function _D(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;dx(a|0,b|0,c|0,d|0)}function _E(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;d0(a|0,b|0,c|0,d|0)}function _F(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;eE(a|0,b|0,c|0,d|0)}function _G(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;aO(a|0,b|0,c|0,d|0)}function _H(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;cw(a|0,b|0,c|0,d|0)}function _I(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;d7(a|0,b|0,c|0,d|0)}function _J(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;dA(a|0,b|0,c|0,d|0)}function _K(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;cx(a|0,b|0,c|0,d|0)}function _L(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;d9(a|0,b|0,c|0,d|0)}function _M(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;dL(a|0,b|0,c|0,d|0)}function _N(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;cj(a|0,b|0,c|0,d|0)}function _O(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;cf(a|0,b|0,c|0,d|0)}function _P(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;bi(a|0,b|0,c|0,d|0)}function _Q(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ed(a|0,b|0,c|0,d|0)}function _R(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;d3(a|0,b|0,c|0,d|0)}function _S(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;bg(a|0,b|0,c|0,d|0,e|0,f|0,g|0,h|0)}function _T(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;db(a|0,b|0,c|0,d|0,e|0,f|0,g|0,h|0)}function _U(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;cv(a|0,b|0,c|0,d|0,e|0,f|0,g|0,h|0)}function _V(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;en(a|0,b|0,c|0,d|0,e|0,f|0,g|0)}function _W(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;eQ(a|0,b|0,c|0,d|0,e|0,f|0,g|0)}function _X(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;dN(a|0,b|0,c|0,d|0,e|0,f|0,g|0)}function _Y(a,b,c){a=a|0;b=+b;c=+c;di(a|0,+b,+c)}function _Z(a,b,c,d){a=a|0;b=+b;c=+c;d=+d;cq(a|0,+b,+c,+d)}function __(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;return e8[a&3](b|0,c|0,d|0,e|0,f|0,g|0,h|0)|0}function _$(a,b,c){a=a|0;b=b|0;c=+c;e9[a&7](b|0,+c)}function _0(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;fa[a&15](b|0,c|0,d|0,e|0,f|0)}function _1(a,b){a=a|0;b=b|0;fb[a&127](b|0)}function _2(a,b,c){a=a|0;b=b|0;c=c|0;fc[a&127](b|0,c|0)}function _3(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;return fd[a&15](b|0,c|0,d|0,e|0,f|0,g|0)|0}function _4(a,b){a=a|0;b=b|0;return fe[a&127](b|0)|0}function _5(a,b,c,d,e,f,g,h,i,j,k,l){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;l=l|0;ff[a&3](b|0,c|0,d|0,e|0,f|0,g|0,h|0,i|0,j|0,k|0,l|0)}function _6(a,b,c,d,e,f){a=a|0;b=b|0;c=+c;d=+d;e=+e;f=+f;fg[a&7](b|0,+c,+d,+e,+f)}function _7(a,b){a=a|0;b=+b;return fh[a&3](+b)|0}function _8(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;return fi[a&63](b|0,c|0,d|0)|0}function _9(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=+g;fj[a&3](b|0,c|0,d|0,e|0,f|0,+g)}function $a(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;fk[a&7](b|0,c|0,d|0,e|0,f|0,g|0,h|0,i|0)}function $b(a,b,c,d,e){a=a|0;b=b|0;c=+c;d=+d;e=+e;fl[a&3](b|0,+c,+d,+e)}function $c(a,b,c){a=a|0;b=b|0;c=c|0;return+fm[a&3](b|0,c|0)}function $d(a,b,c,d){a=a|0;b=b|0;c=c|0;d=+d;return fn[a&3](b|0,c|0,+d)|0}function $e(a,b,c,d){a=a|0;b=b|0;c=+c;d=+d;fo[a&3](b|0,+c,+d)}function $f(a,b,c){a=a|0;b=b|0;c=+c;return fp[a&3](b|0,+c)|0}function $g(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;fq[a&7](b|0,c|0,d|0,e|0,f|0,g|0,h|0)}function $h(a,b){a=a|0;b=+b;return+fr[a&3](+b)}function $i(a,b,c,d,e,f,g,h,i,j){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;fs[a&15](b|0,c|0,d|0,e|0,f|0,g|0,h|0,i|0,j|0)}function $j(a,b,c){a=a|0;b=b|0;c=c|0;return ft[a&63](b|0,c|0)|0}function $k(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;fu[a&255](b|0,c|0,d|0,e|0,f|0,g|0)}function $l(a){a=a|0;return+fv[a&3]()}function $m(a){a=a|0;return fw[a&31]()|0}function $n(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;return fx[a&15](b|0,c|0,d|0,e|0)|0}function $o(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;fy[a&511](b|0,c|0,d|0)}function $p(a){a=a|0;fz[a&8191]()}function $q(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;fA[a&127](b|0,c|0,d|0,e|0)}function $r(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;ac(0);return 0}function $s(a,b){a=a|0;b=+b;ac(1)}function $t(a,b,c,d,e){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;ac(2)}function $u(a){a=a|0;ac(3)}function $v(a,b){a=a|0;b=b|0;ac(4)}function $w(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;ac(5);return 0}function $x(a){a=a|0;ac(6);return 0}function $y(a,b,c,d,e,f,g,h,i,j,k){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;j=j|0;k=k|0;ac(7)}function $z(a,b,c,d,e){a=a|0;b=+b;c=+c;d=+d;e=+e;ac(8)}function $A(a){a=+a;ac(9);return 0}function $B(a,b,c){a=a|0;b=b|0;c=c|0;ac(10);return 0}function $C(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=+f;ac(11)}function $D(a,b,c,d,e,f,g,h){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;ac(12)}function $E(a,b,c,d){a=a|0;b=+b;c=+c;d=+d;ac(13)}function $F(a,b){a=a|0;b=b|0;ac(14);return 0.0}function $G(a,b,c){a=a|0;b=b|0;c=+c;ac(15);return 0}function $H(a,b,c){a=a|0;b=+b;c=+c;ac(16)}function $I(a,b){a=a|0;b=+b;ac(17);return 0}function $J(a,b,c,d,e,f,g){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;ac(18)}function $K(a){a=+a;ac(19);return 0.0}function $L(a,b,c,d,e,f,g,h,i){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;g=g|0;h=h|0;i=i|0;ac(20)}function $M(a,b){a=a|0;b=b|0;ac(21);return 0}function $N(a,b,c,d,e,f){a=a|0;b=b|0;c=c|0;d=d|0;e=e|0;f=f|0;ac(22)}function $O(){ac(23);return 0.0}function $P(){ac(24);return 0}function $Q(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ac(25);return 0}function $R(a,b,c){a=a|0;b=b|0;c=c|0;ac(26)}function $S(){ac(27)}function $T(a,b,c,d){a=a|0;b=b|0;c=c|0;d=d|0;ac(28)}
// EMSCRIPTEN_END_FUNCS
var e8=[$r,$r,i7,$r];var e9=[$s,$s,iS,$s,Yv,$s,$s,$s];var fa=[$t,$t,jg,$t,Ys,$t,Yt,$t,Yu,$t,$t,$t,$t,$t,$t,$t];var fb=[$u,$u,Yw,$u,Yx,$u,ij,$u,Yy,$u,i3,$u,Yz,$u,i0,$u,YA,$u,XI,$u,gT,$u,YB,$u,hn,$u,hx,$u,ht,$u,YC,$u,gi,$u,h7,$u,XZ,$u,g9,$u,YD,$u,jp,$u,YE,$u,hE,$u,gS,$u,YF,$u,XD,$u,YG,$u,XA,$u,f7,$u,gU,$u,gV,$u,g6,$u,YH,$u,gG,$u,gF,$u,gR,$u,YI,$u,iN,$u,XC,$u,XH,$u,YJ,$u,XB,$u,YK,$u,YL,$u,XG,$u,YM,$u,hm,$u,YN,$u,ha,$u,YO,$u,YP,$u,ie,$u,YQ,$u,YR,$u,hi,$u,iG,$u,YS,$u,Xz,$u,YT,$u,YU,$u,$u,$u,$u,$u,$u,$u];var fc=[$v,$v,iJ,$v,TY,$v,TW,$v,xe,$v,xm,$v,YV,$v,xk,$v,YW,$v,YX,$v,gb,$v,jr,$v,YY,$v,YZ,$v,Y_,$v,h6,$v,Y$,$v,iX,$v,iT,$v,iz,$v,Y0,$v,hj,$v,Y1,$v,Y2,$v,id,$v,Y3,$v,Y4,$v,Y5,$v,Y6,$v,Y7,$v,Y8,$v,i4,$v,gd,$v,Y9,$v,Za,$v,i9,$v,iC,$v,Zb,$v,iW,$v,Zc,$v,XJ,$v,Zd,$v,iR,$v,xh,$v,gA,$v,Ze,$v,gQ,$v,Zf,$v,Zg,$v,jh,$v,Zh,$v,Zi,$v,Zj,$v,Zk,$v,hD,$v,Zl,$v,iA,$v,iK,$v,Zm,$v,Zn,$v,Zo,$v,Zp,$v,ih,$v,$v,$v];var fd=[$w,$w,hk,$w,iy,$w,hp,$w,hq,$w,ho,$w,$w,$w,$w,$w];var fe=[$x,$x,Zq,$x,XF,$x,ig,$x,gX,$x,X1,$x,Zr,$x,Zs,$x,gl,$x,TX,$x,ib,$x,hG,$x,gx,$x,iB,$x,hB,$x,i6,$x,jj,$x,iE,$x,hv,$x,gM,$x,Zt,$x,hC,$x,xi,$x,Zu,$x,XX,$x,g2,$x,ic,$x,xj,$x,g3,$x,Zv,$x,Zw,$x,Zx,$x,TU,$x,Zy,$x,gj,$x,xl,$x,ji,$x,XE,$x,jn,$x,hF,$x,Zz,$x,iD,$x,XY,$x,xz,$x,ZA,$x,jt,$x,ZB,$x,ZC,$x,hr,$x,js,$x,ZD,$x,ZE,$x,$x,$x,$x,$x,$x,$x,$x,$x,$x,$x,$x,$x,$x,$x,$x,$x,$x,$x,$x,$x,$x,$x,$x,$x];var ff=[$y,$y,jo,$y];var fg=[$z,$z,ZF,$z,iP,$z,iQ,$z];var fh=[$A,$A,ii,$A];var fi=[$B,$B,ZG,$B,ZH,$B,ia,$B,ix,$B,ZI,$B,hz,$B,Ud,$B,T9,$B,T8,$B,ZJ,$B,h9,$B,ZK,$B,Uc,$B,Ub,$B,iF,$B,gq,$B,hA,$B,Ue,$B,XU,$B,g_,$B,je,$B,i8,$B,ZL,$B,Uf,$B,$B,$B,$B,$B,$B,$B,$B,$B,$B,$B,$B,$B,$B,$B];var fj=[$C,$C,iU,$C];var fk=[$D,$D,_S,$D,_T,$D,_U,$D];var fl=[$E,$E,_Z,$E];var fm=[$F,$F,jb,$F];var fn=[$G,$G,i1,$G];var fo=[$H,$H,_Y,$H];var fp=[$I,$I,h4,$I];var fq=[$J,$J,_V,$J,_W,$J,_X,$J];var fr=[$K,$K,ZN,$K];var fs=[$L,$L,ZO,$L,ZP,$L,hY,$L,ZQ,$L,$L,$L,$L,$L,$L,$L];var ft=[$M,$M,gg,$M,ZR,$M,iM,$M,ZS,$M,gO,$M,g0,$M,X8,$M,hl,$M,fY,$M,X_,$M,XR,$M,ZT,$M,go,$M,ZU,$M,gH,$M,gn,$M,fU,$M,gL,$M,ZV,$M,iL,$M,jm,$M,hd,$M,g1,$M,XQ,$M,$M,$M,$M,$M,$M,$M,$M,$M,$M,$M,$M,$M,$M,$M];var fu=[$N,$N,Vl,$N,Wp,$N,VE,$N,Wm,$N,Xb,$N,Vt,$N,Xn,$N,hP,$N,Xm,$N,Vc,$N,Uj,$N,Wt,$N,Ur,$N,Vj,$N,hO,$N,Ww,$N,Vb,$N,Xc,$N,Ut,$N,Vz,$N,Wy,$N,Xl,$N,Ws,$N,W7,$N,Um,$N,hW,$N,Wv,$N,Up,$N,hK,$N,Vu,$N,Xo,$N,VB,$N,VG,$N,Vf,$N,hQ,$N,hL,$N,Un,$N,hT,$N,VD,$N,Va,$N,Ui,$N,Ul,$N,Wq,$N,Us,$N,Wo,$N,VA,$N,ZM,$N,Wu,$N,Uo,$N,VF,$N,Vh,$N,Xd,$N,Vw,$N,Wn,$N,Vg,$N,hN,$N,VC,$N,hM,$N,Ve,$N,Vd,$N,Uq,$N,Vx,$N,W9,$N,Xk,$N,Vv,$N,Wx,$N,hR,$N,Xq,$N,Xp,$N,U9,$N,Vi,$N,U8,$N,Uh,$N,hS,$N,Ug,$N,Wl,$N,Uk,$N,Vk,$N,Vy,$N,Wr,$N,W6,$N,W8,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N,$N];var fv=[$O,$O,ZW,$O];var fw=[$P,$P,h$,$P,XW,$P,XP,$P,ZX,$P,g$,$P,ZY,$P,gw,$P,gP,$P,Xy,$P,jl,$P,jc,$P,gZ,$P,ja,$P,hh,$P,jq,$P];var fx=[$Q,$Q,ZZ,$Q,Z_,$Q,iY,$Q,ge,$Q,$Q,$Q,$Q,$Q,$Q,$Q];var fy=[$R,$R,UM,$R,We,$R,UH,$R,WP,$R,Xj,$R,UW,$R,U_,$R,Z$,$R,W0,$R,V3,$R,Z0,$R,UR,$R,WU,$R,WN,$R,UV,$R,Z1,$R,UF,$R,Wa,$R,US,$R,Wj,$R,WZ,$R,Z2,$R,WI,$R,V_,$R,Z3,$R,gt,$R,Z4,$R,UZ,$R,Z5,$R,UE,$R,h5,$R,U2,$R,Wd,$R,VO,$R,WJ,$R,WR,$R,Xi,$R,U5,$R,Z6,$R,WH,$R,hu,$R,UD,$R,Z7,$R,Z8,$R,Wk,$R,UK,$R,VT,$R,Z9,$R,_a,$R,VQ,$R,_b,$R,U3,$R,UX,$R,WV,$R,VV,$R,UT,$R,UC,$R,gK,$R,_c,$R,_d,$R,V0,$R,WG,$R,U4,$R,W3,$R,W$,$R,W5,$R,iO,$R,V7,$R,_e,$R,Xe,$R,_f,$R,VZ,$R,WK,$R,WX,$R,VX,$R,WT,$R,gz,$R,U6,$R,W1,$R,UG,$R,W2,$R,U7,$R,Xh,$R,_g,$R,Wf,$R,U1,$R,UL,$R,Xa,$R,UO,$R,UN,$R,V$,$R,W4,$R,Wh,$R,VP,$R,WS,$R,X9,$R,Xf,$R,UI,$R,VY,$R,V8,$R,_h,$R,_i,$R,_j,$R,V5,$R,WM,$R,Wi,$R,UP,$R,_k,$R,hX,$R,_l,$R,i2,$R,WW,$R,Wb,$R,VW,$R,iV,$R,V1,$R,Wc,$R,WQ,$R,UQ,$R,WL,$R,WY,$R,UU,$R,Wg,$R,_m,$R,_n,$R,_o,$R,W_,$R,UB,$R,_p,$R,VR,$R,WO,$R,V9,$R,_q,$R,U0,$R,Xg,$R,UJ,$R,hU,$R,V6,$R,_r,$R,XT,$R,V2,$R,g5,$R,U$,$R,VU,$R,VS,$R,V4,$R,UY,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R,$R];var fz=[$S,$S,PL,$S,SZ,$S,pK,$S,mx,$S,PI,$S,P$,$S,Ky,$S,zR,$S,zS,$S,zP,$S,zQ,$S,zN,$S,zO,$S,zM,$S,CK,$S,CJ,$S,CM,$S,CL,$S,CG,$S,CF,$S,zT,$S,zU,$S,Kz,$S,u_,$S,tV,$S,NW,$S,QG,$S,F_,$S,F$,$S,FY,$S,FZ,$S,FW,$S,FX,$S,MY,$S,vL,$S,nz,$S,qa,$S,kJ,$S,qP,$S,yo,$S,yn,$S,x4,$S,x3,$S,ym,$S,x0,$S,x$,$S,x2,$S,x1,$S,qY,$S,Qi,$S,IC,$S,kV,$S,m_,$S,MX,$S,C7,$S,C6,$S,C3,$S,C2,$S,C5,$S,C4,$S,H2,$S,l1,$S,l2,$S,BI,$S,Bn,$S,Bm,$S,Bl,$S,Bk,$S,ld,$S,rb,$S,RV,$S,vM,$S,mS,$S,oV,$S,uW,$S,t7,$S,NN,$S,TI,$S,QF,$S,Sf,$S,oh,$S,l_,$S,oL,$S,CO,$S,NA,$S,Kn,$S,H1,$S,qZ,$S,kW,$S,Sc,$S,r1,$S,td,$S,IU,$S,M3,$S,JY,$S,S$,$S,rN,$S,tb,$S,CI,$S,CH,$S,yN,$S,yM,$S,yL,$S,NP,$S,mV,$S,m$,$S,Ru,$S,Kf,$S,Py,$S,lh,$S,or,$S,KH,$S,O6,$S,Ly,$S,SI,$S,CV,$S,CX,$S,CW,$S,CZ,$S,CY,$S,C$,$S,C_,$S,pp,$S,q$,$S,LT,$S,xW,$S,vi,$S,PH,$S,FL,$S,LI,$S,vu,$S,MH,$S,IH,$S,xI,$S,H4,$S,N$,$S,l9,$S,rQ,$S,Qc,$S,IA,$S,nS,$S,o8,$S,Pi,$S,mq,$S,pH,$S,qF,$S,kw,$S,uN,$S,Hh,$S,Q7,$S,wa,$S,N0,$S,k6,$S,I7,$S,BD,$S,KZ,$S,BF,$S,BE,$S,BH,$S,BG,$S,qC,$S,ks,$S,kg,$S,qs,$S,Ra,$S,O$,$S,Lv,$S,B2,$S,u0,$S,M8,$S,Lp,$S,uE,$S,H9,$S,Ps,$S,vN,$S,nV,$S,sP,$S,Se,$S,PX,$S,QT,$S,pN,$S,L1,$S,S3,$S,MC,$S,yb,$S,ub,$S,Lh,$S,J7,$S,OV,$S,Kx,$S,nZ,$S,sS,$S,nh,$S,K6,$S,B9,$S,wu,$S,EZ,$S,JW,$S,EY,$S,Qn,$S,EX,$S,ki,$S,qt,$S,J5,$S,qT,$S,ut,$S,N2,$S,y1,$S,yl,$S,mh,$S,oM,$S,y2,$S,y$,$S,y0,$S,g4,$S,pI,$S,y6,$S,y7,$S,C8,$S,C9,$S,Da,$S,Db,$S,Dc,$S,Dd,$S,De,$S,Df,$S,Dg,$S,Dh,$S,y5,$S,ME,$S,sy,$S,Ti,$S,Nh,$S,tS,$S,tz,$S,II,$S,lE,$S,oA,$S,ql,$S,j7,$S,S8,$S,qI,$S,s_,$S,On,$S,NO,$S,Im,$S,R5,$S,tD,$S,ou,$S,u5,$S,SC,$S,nQ,$S,Ry,$S,O4,$S,m3,$S,p0,$S,NM,$S,rZ,$S,mp,$S,mK,$S,li,$S,Qk,$S,Km,$S,Ds,$S,Dr,$S,Du,$S,Dt,$S,R8,$S,vs,$S,KY,$S,OY,$S,Rc,$S,N_,$S,Sa,$S,Hl,$S,k9,$S,oU,$S,mN,$S,q8,$S,wp,$S,L6,$S,P_,$S,p$,$S,m2,$S,Lo,$S,A3,$S,tM,$S,Q2,$S,rz,$S,Sj,$S,up,$S,zZ,$S,z_,$S,E8,$S,E7,$S,ud,$S,E0,$S,E$,$S,E2,$S,E1,$S,E4,$S,E3,$S,E6,$S,E5,$S,Kt,$S,f_,$S,oQ,$S,ON,$S,xD,$S,IR,$S,Iv,$S,x5,$S,y_,$S,Td,$S,AO,$S,AL,$S,mW,$S,AR,$S,AS,$S,AP,$S,AQ,$S,AT,$S,AU,$S,uG,$S,pn,$S,k3,$S,o2,$S,Tk,$S,Mp,$S,iI,$S,In,$S,I3,$S,L2,$S,Ki,$S,SU,$S,KP,$S,Nq,$S,xy,$S,ST,$S,uJ,$S,Ig,$S,SO,$S,K5,$S,qr,$S,ws,$S,oY,$S,OH,$S,Hf,$S,Ce,$S,AN,$S,Pc,$S,lg,$S,re,$S,nj,$S,sr,$S,l5,$S,rO,$S,rn,$S,lt,$S,uV,$S,xF,$S,TK,$S,kK,$S,H8,$S,v3,$S,s$,$S,qW,$S,Dp,$S,Ow,$S,JV,$S,rf,$S,lj,$S,mv,$S,pJ,$S,NZ,$S,O3,$S,Q4,$S,l4,$S,pA,$S,nO,$S,OA,$S,Mx,$S,rD,$S,lx,$S,vr,$S,KO,$S,tG,$S,BC,$S,BB,$S,BA,$S,Bz,$S,Ls,$S,BJ,$S,MS,$S,lu,$S,Lz,$S,sm,$S,m9,$S,I2,$S,P0,$S,Jv,$S,Po,$S,Sl,$S,w2,$S,K8,$S,KG,$S,va,$S,Lc,$S,sp,$S,Lx,$S,w8,$S,JT,$S,La,$S,QN,$S,nl,$S,st,$S,I4,$S,Q5,$S,w4,$S,GJ,$S,GK,$S,GH,$S,GI,$S,GF,$S,GG,$S,wr,$S,wB,$S,QP,$S,D5,$S,B$,$S,B0,$S,B1,$S,P8,$S,B3,$S,B4,$S,B5,$S,B6,$S,B7,$S,B8,$S,l6,$S,oK,$S,vG,$S,yK,$S,mC,$S,Rv,$S,At,$S,wS,$S,NH,$S,Bh,$S,Bg,$S,Bf,$S,Be,$S,Bd,$S,Bc,$S,Bb,$S,Ba,$S,y8,$S,y9,$S,Bj,$S,Bi,$S,G1,$S,G0,$S,G$,$S,G5,$S,G4,$S,pR,$S,G2,$S,ze,$S,G7,$S,G6,$S,xZ,$S,JU,$S,uh,$S,A0,$S,A2,$S,A1,$S,A4,$S,A6,$S,A5,$S,A8,$S,A7,$S,Ji,$S,zV,$S,zW,$S,zX,$S,zY,$S,f0,$S,Mb,$S,Rj,$S,vC,$S,wf,$S,p3,$S,na,$S,th,$S,si,$S,SF,$S,Rs,$S,S9,$S,Tl,$S,Lg,$S,R1,$S,J0,$S,Q6,$S,mr,$S,r_,$S,rE,$S,IL,$S,Dk,$S,Dl,$S,Di,$S,Dj,$S,Dm,$S,Dn,$S,K$,$S,rU,$S,KL,$S,wx,$S,zL,$S,J3,$S,Pl,$S,SQ,$S,wW,$S,Tp,$S,nU,$S,sO,$S,Ln,$S,Ev,$S,Eu,$S,Er,$S,Eq,$S,Et,$S,Es,$S,xB,$S,xx,$S,xw,$S,Kr,$S,M0,$S,Ny,$S,KI,$S,RR,$S,FC,$S,RZ,$S,xL,$S,pe,$S,pd,$S,g8,$S,uL,$S,rB,$S,r9,$S,mJ,$S,u1,$S,N1,$S,tB,$S,vx,$S,tI,$S,Ko,$S,KV,$S,om,$S,XM,$S,Tv,$S,TB,$S,oo,$S,pY,$S,SX,$S,BK,$S,sf,$S,MI,$S,K0,$S,wy,$S,wk,$S,Kh,$S,Js,$S,Ck,$S,Cj,$S,M2,$S,Cg,$S,Cf,$S,Ci,$S,vz,$S,Cc,$S,Cb,$S,FK,$S,Cd,$S,Q1,$S,Pm,$S,IY,$S,MK,$S,zc,$S,TJ,$S,tY,$S,uu,$S,XN,$S,Ns,$S,GD,$S,Pk,$S,Lq,$S,ug,$S,If,$S,IB,$S,Th,$S,H_,$S,kF,$S,rq,$S,s7,$S,GX,$S,RI,$S,wJ,$S,oO,$S,P7,$S,mG,$S,kd,$S,qq,$S,Kp,$S,RF,$S,Jb,$S,j9,$S,qM,$S,kG,$S,Pv,$S,lf,$S,rd,$S,Jl,$S,C1,$S,rH,$S,lW,$S,NL,$S,pi,$S,C0,$S,s2,$S,Rw,$S,Ov,$S,sE,$S,RE,$S,S4,$S,ya,$S,os,$S,lm,$S,MT,$S,I5,$S,KW,$S,RP,$S,Cm,$S,Cl,$S,O0,$S,O8,$S,MR,$S,m1,$S,p_,$S,yt,$S,yO,$S,yq,$S,yp,$S,ys,$S,yr,$S,Sb,$S,Pf,$S,PJ,$S,iH,$S,o5,$S,M$,$S,v$,$S,xo,$S,vE,$S,SA,$S,Bo,$S,Pb,$S,Cq,$S,Hj,$S,Nr,$S,Fi,$S,Cs,$S,rw,$S,It,$S,Pd,$S,v5,$S,Cr,$S,RS,$S,qK,$S,Cu,$S,J8,$S,pL,$S,Fm,$S,Cw,$S,PU,$S,Tn,$S,xK,$S,Cv,$S,JB,$S,KF,$S,Af,$S,ra,$S,lc,$S,KT,$S,Tt,$S,Jh,$S,Do,$S,Ag,$S,xP,$S,OJ,$S,vU,$S,Os,$S,tQ,$S,kL,$S,qQ,$S,QB,$S,NT,$S,Tr,$S,mZ,$S,sh,$S,n_,$S,PG,$S,op,$S,rL,$S,wG,$S,I$,$S,Sv,$S,jk,$S,Re,$S,oX,$S,tr,$S,ye,$S,JQ,$S,lo,$S,Pg,$S,vy,$S,mQ,$S,pU,$S,Rn,$S,ov,$S,n1,$S,To,$S,wL,$S,Lu,$S,Bp,$S,KB,$S,Mv,$S,Bx,$S,te,$S,tn,$S,Ll,$S,IJ,$S,QO,$S,LJ,$S,lK,$S,ry,$S,AD,$S,AE,$S,Kq,$S,Ax,$S,Ay,$S,Av,$S,Aw,$S,AB,$S,AC,$S,Az,$S,AA,$S,H5,$S,wh,$S,GL,$S,OK,$S,Ts,$S,Mi,$S,Oy,$S,Jp,$S,Fd,$S,Fa,$S,E9,$S,Fc,$S,Fb,$S,wd,$S,H7,$S,oq,$S,SS,$S,M9,$S,Na,$S,AZ,$S,A_,$S,FT,$S,AV,$S,AW,$S,AX,$S,AY,$S,l$,$S,px,$S,tv,$S,sY,$S,DV,$S,DW,$S,DX,$S,DY,$S,DZ,$S,D_,$S,Q9,$S,Sk,$S,Qd,$S,ND,$S,tu,$S,Ga,$S,F9,$S,F8,$S,F7,$S,F6,$S,F5,$S,F4,$S,F3,$S,Iu,$S,vD,$S,Gc,$S,Gb,$S,Iq,$S,N7,$S,R4,$S,qc,$S,nC,$S,la,$S,L7,$S,qG,$S,ky,$S,NI,$S,Mz,$S,MO,$S,Nv,$S,o$,$S,Pt,$S,oB,$S,nT,$S,qg,$S,wj,$S,vt,$S,u4,$S,pf,$S,XK,$S,n2,$S,PF,$S,mB,$S,r5,$S,vW,$S,qX,$S,kU,$S,Og,$S,Gv,$S,Gh,$S,Gg,$S,Gf,$S,Ge,$S,Gd,$S,CS,$S,IF,$S,ux,$S,PC,$S,xf,$S,k4,$S,QK,$S,pZ,$S,lA,$S,pv,$S,vV,$S,k5,$S,q6,$S,w_,$S,SY,$S,Su,$S,BO,$S,BN,$S,BM,$S,BL,$S,BS,$S,BR,$S,BQ,$S,BP,$S,BU,$S,BT,$S,Si,$S,IS,$S,qw,$S,kl,$S,Jy,$S,r$,$S,mt,$S,JN,$S,vO,$S,tX,$S,IT,$S,J_,$S,wN,$S,vX,$S,SR,$S,kv,$S,l8,$S,K3,$S,IP,$S,Q8,$S,IX,$S,Cy,$S,Cx,$S,Fn,$S,Fo,$S,Fh,$S,Co,$S,Ff,$S,Fg,$S,Fl,$S,Ct,$S,Fj,$S,Fk,$S,sD,$S,nB,$S,SB,$S,OS,$S,TF,$S,sZ,$S,qH,$S,Le,$S,sG,$S,nH,$S,A9,$S,Pa,$S,Ir,$S,Aq,$S,uy,$S,oR,$S,v7,$S,vo,$S,i5,$S,As,$S,tt,$S,Ma,$S,o6,$S,N6,$S,x7,$S,m0,$S,rW,$S,ml,$S,GY,$S,uY,$S,Pr,$S,w$,$S,DN,$S,DO,$S,DM,$S,DR,$S,DS,$S,DP,$S,DQ,$S,DT,$S,DU,$S,QM,$S,xu,$S,kN,$S,QR,$S,PS,$S,AF,$S,AG,$S,AH,$S,AI,$S,AJ,$S,AK,$S,kq,$S,qA,$S,Sr,$S,Is,$S,Qb,$S,An,$S,Ao,$S,Al,$S,Am,$S,z9,$S,Aa,$S,SN,$S,R0,$S,pO,$S,mE,$S,u2,$S,Ik,$S,rk,$S,lp,$S,wA,$S,P2,$S,Nk,$S,Lf,$S,uI,$S,zt,$S,zu,$S,zr,$S,zs,$S,zp,$S,zq,$S,nm,$S,o0,$S,SL,$S,ua,$S,Sx,$S,IZ,$S,Jr,$S,wO,$S,tO,$S,Rl,$S,of,$S,Ja,$S,PP,$S,tj,$S,vc,$S,Ch,$S,M7,$S,QJ,$S,QD,$S,RW,$S,IG,$S,I8,$S,sa,$S,mL,$S,MD,$S,RA,$S,ma,$S,pB,$S,LQ,$S,IW,$S,LV,$S,ps,$S,ot,$S,RG,$S,ny,$S,ns,$S,uO,$S,SD,$S,y3,$S,H3,$S,Ql,$S,qk,$S,n4,$S,xU,$S,yg,$S,lk,$S,P3,$S,rg,$S,He,$S,yf,$S,q1,$S,s0,$S,SH,$S,JF,$S,Ng,$S,Mc,$S,sk,$S,m5,$S,MZ,$S,nv,$S,wE,$S,Mg,$S,u8,$S,MP,$S,Fp,$S,Fq,$S,Fr,$S,Fs,$S,Ft,$S,Fu,$S,Kl,$S,t2,$S,_s,$S,Q0,$S,Lb,$S,Dv,$S,IE,$S,vA,$S,Nn,$S,Oi,$S,mw,$S,JJ,$S,x6,$S,JG,$S,v4,$S,Oh,$S,GM,$S,nd,$S,xt,$S,LA,$S,Ke,$S,GO,$S,OQ,$S,JC,$S,GN,$S,TM,$S,GQ,$S,RC,$S,GP,$S,JL,$S,GS,$S,GR,$S,Kw,$S,vb,$S,Pu,$S,Iz,$S,oJ,$S,Nj,$S,qb,$S,nA,$S,vh,$S,oT,$S,vm,$S,Ty,$S,QY,$S,S2,$S,xT,$S,x_,$S,JA,$S,KU,$S,IM,$S,ty,$S,t8,$S,hb,$S,JE,$S,Ro,$S,Ad,$S,Ac,$S,Ab,$S,Qz,$S,K7,$S,LN,$S,uq,$S,z6,$S,f$,$S,MG,$S,Tz,$S,JZ,$S,L4,$S,kX,$S,q_,$S,sQ,$S,nX,$S,Ie,$S,Jq,$S,NB,$S,PO,$S,vB,$S,Kj,$S,pG,$S,mn,$S,H$,$S,Qe,$S,PY,$S,K9,$S,JK,$S,mo,$S,Mh,$S,u9,$S,vp,$S,t4,$S,JS,$S,vw,$S,L5,$S,KJ,$S,n9,$S,pw,$S,lT,$S,ve,$S,OC,$S,rs,$S,lD,$S,tm,$S,sC,$S,Je,$S,pP,$S,oz,$S,tc,$S,rX,$S,uk,$S,x8,$S,RD,$S,EH,$S,G3,$S,XV,$S,tP,$S,LF,$S,qp,$S,kc,$S,Ef,$S,Ee,$S,Ed,$S,Ec,$S,Eb,$S,Ea,$S,Sq,$S,uD,$S,O5,$S,oH,$S,m8,$S,KX,$S,lL,$S,rJ,$S,Pz,$S,lY,$S,Jo,$S,nE,$S,yZ,$S,Qr,$S,MA,$S,wH,$S,nu,$S,sz,$S,nN,$S,Ob,$S,kf,$S,qm,$S,qh,$S,n$,$S,tJ,$S,Op,$S,KQ,$S,I1,$S,CE,$S,CD,$S,CA,$S,Cz,$S,CC,$S,CB,$S,Ca,$S,f8,$S,MN,$S,LP,$S,D7,$S,D6,$S,Ic,$S,D4,$S,D3,$S,D2,$S,D1,$S,D0,$S,Ot,$S,p8,$S,nw,$S,D9,$S,D8,$S,Ix,$S,s6,$S,rp,$S,s8,$S,JO,$S,vf,$S,wi,$S,ue,$S,Jn,$S,np,$S,sw,$S,gW,$S,NF,$S,ID,$S,Gz,$S,GA,$S,GB,$S,Oe,$S,Gw,$S,Gx,$S,Gy,$S,MQ,$S,GE,$S,FG,$S,FH,$S,FE,$S,FF,$S,FI,$S,FJ,$S,kO,$S,qS,$S,LW,$S,NJ,$S,NR,$S,GC,$S,PD,$S,tk,$S,sA,$S,ob,$S,SM,$S,su,$S,Ks,$S,uZ,$S,Sg,$S,Hk,$S,Ar,$S,kz,$S,P9,$S,wI,$S,q4,$S,FQ,$S,FR,$S,FS,$S,Tg,$S,FM,$S,FN,$S,OR,$S,FP,$S,nD,$S,FU,$S,FV,$S,XL,$S,O7,$S,zI,$S,OE,$S,ok,$S,o_,$S,zH,$S,wv,$S,oF,$S,zd,$S,uA,$S,L$,$S,HZ,$S,k8,$S,uX,$S,Qg,$S,MV,$S,RJ,$S,g7,$S,RY,$S,Ii,$S,u$,$S,nt,$S,Jf,$S,vn,$S,tU,$S,M5,$S,XS,$S,k$,$S,pl,$S,Jk,$S,KN,$S,NS,$S,lX,$S,rI,$S,Qu,$S,vS,$S,Pj,$S,RL,$S,kY,$S,Iy,$S,Oo,$S,Qp,$S,KA,$S,mO,$S,pT,$S,xQ,$S,xR,$S,mc,$S,pC,$S,PT,$S,lB,$S,rr,$S,PR,$S,kP,$S,TL,$S,Np,$S,Sw,$S,Tm,$S,xC,$S,KC,$S,SE,$S,rh,$S,ll,$S,pb,$S,um,$S,gD,$S,Kb,$S,Ka,$S,Mf,$S,pa,$S,lv,$S,uo,$S,NU,$S,vI,$S,lQ,$S,rC,$S,xp,$S,u6,$S,LY,$S,Sy,$S,nY,$S,SK,$S,gY,$S,KK,$S,P6,$S,A$,$S,Ij,$S,FO,$S,LZ,$S,Qx,$S,sL,$S,DB,$S,pr,$S,lq,$S,OG,$S,J2,$S,J$,$S,Hm,$S,S7,$S,ol,$S,pV,$S,MM,$S,p2,$S,m6,$S,qV,$S,kR,$S,gC,$S,uU,$S,Jx,$S,wR,$S,RN,$S,vl,$S,rc,$S,SV,$S,tp,$S,O_,$S,JD,$S,Id,$S,yw,$S,yx,$S,yu,$S,yv,$S,yA,$S,yB,$S,yy,$S,yz,$S,yC,$S,yD,$S,Tq,$S,xv,$S,J6,$S,LU,$S,wD,$S,Od,$S,L_,$S,RX,$S,LG,$S,I6,$S,N8,$S,Ia,$S,uR,$S,wX,$S,J4,$S,v_,$S,nr,$S,Ph,$S,sv,$S,Mr,$S,sg,$S,mX,$S,Rz,$S,qu,$S,kj,$S,Rd,$S,uB,$S,SP,$S,yd,$S,Rh,$S,to,$S,sT,$S,Jj,$S,uF,$S,ES,$S,S0,$S,EQ,$S,EP,$S,EO,$S,EN,$S,EM,$S,yW,$S,nR,$S,sM,$S,RT,$S,EU,$S,ET,$S,yU,$S,Ku,$S,yT,$S,LB,$S,Pp,$S,QL,$S,Ol,$S,LD,$S,Ne,$S,M6,$S,zj,$S,zk,$S,zl,$S,zm,$S,zf,$S,zg,$S,zh,$S,zi,$S,zn,$S,zo,$S,n3,$S,Ml,$S,rP,$S,l7,$S,sI,$S,nJ,$S,pc,$S,Qw,$S,S_,$S,nq,$S,o3,$S,Om,$S,I_,$S,Jz,$S,Md,$S,rV,$S,mj,$S,mR,$S,sc,$S,MW,$S,Nu,$S,uz,$S,L8,$S,rK,$S,lZ,$S,lC,$S,oy,$S,Nm,$S,CQ,$S,CP,$S,E_,$S,CR,$S,CU,$S,CT,$S,EW,$S,EV,$S,J1,$S,Gt,$S,Gu,$S,wm,$S,Gs,$S,Gp,$S,Gq,$S,wC,$S,QE,$S,KE,$S,Of,$S,nn,$S,p7,$S,Tw,$S,lI,$S,od,$S,tR,$S,Kv,$S,LC,$S,S5,$S,vj,$S,DJ,$S,DI,$S,DH,$S,DG,$S,KR,$S,DL,$S,DK,$S,Jd,$S,kC,$S,oe,$S,SW,$S,sR,$S,kD,$S,qz,$S,kp,$S,N3,$S,vJ,$S,zK,$S,zJ,$S,zG,$S,zF,$S,sq,$S,nf,$S,ro,$S,s5,$S,Nf,$S,mz,$S,uT,$S,vF,$S,Mo,$S,RH,$S,Fv,$S,Fw,$S,Fx,$S,Fy,$S,Fz,$S,FA,$S,FB,$S,FD,$S,Kd,$S,wM,$S,Ni,$S,My,$S,km,$S,Lm,$S,PA,$S,tq,$S,sV,$S,GW,$S,GV,$S,sn,$S,nb,$S,G_,$S,GZ,$S,uw,$S,JX,$S,pE,$S,mi,$S,t3,$S,tH,$S,RB,$S,Io,$S,OU,$S,P5,$S,Au,$S,uc,$S,qL,$S,Nw,$S,n6,$S,ox,$S,uv,$S,QC,$S,By,$S,wV,$S,gf,$S,Jt,$S,LL,$S,Bs,$S,Br,$S,Bq,$S,sl,$S,Bw,$S,Bv,$S,Bu,$S,Bt,$S,MF,$S,w3,$S,H6,$S,x9,$S,vH,$S,mg,$S,rR,$S,Te,$S,vk,$S,uP,$S,LM,$S,TH,$S,IK,$S,Mt,$S,tx,$S,Dq,$S,No,$S,NV,$S,v0,$S,Sd,$S,_t,$S,Mm,$S,ML,$S,pg,$S,kn,$S,Oz,$S,k1,$S,pX,$S,mY,$S,tE,$S,kr,$S,qB,$S,wg,$S,EA,$S,EB,$S,EC,$S,ED,$S,Ew,$S,Ex,$S,Ey,$S,Ez,$S,GU,$S,GT,$S,qO,$S,kI,$S,EE,$S,EF,$S,k_,$S,yh,$S,z7,$S,z8,$S,mM,$S,pS,$S,z3,$S,z4,$S,z5,$S,H0,$S,z$,$S,z0,$S,z1,$S,z2,$S,xN,$S,ph,$S,Nz,$S,Q_,$S,Px,$S,NK,$S,vq,$S,P4,$S,oW,$S,Ju,$S,N5,$S,KS,$S,r4,$S,tf,$S,tF,$S,xq,$S,v9,$S,Nc,$S,v1,$S,PE,$S,ui,$S,wT,$S,SJ,$S,Jw,$S,yX,$S,K1,$S,Rt,$S,t9,$S,PV,$S,Rm,$S,L0,$S,kA,$S,pj,$S,Tx,$S,yS,$S,yR,$S,yQ,$S,yP,$S,yV,$S,qd,$S,nG,$S,OM,$S,yY,$S,wb,$S,Hi,$S,Kg,$S,oE,$S,Qa,$S,uS,$S,Rf,$S,TD,$S,w5,$S,TA,$S,xs,$S,Ox,$S,Qo,$S,Ib,$S,pW,$S,O9,$S,mb,$S,AM,$S,Il,$S,yi,$S,yI,$S,LR,$S,sU,$S,lF,$S,rt,$S,wc,$S,v2,$S,o9,$S,K_,$S,Rr,$S,un,$S,QQ,$S,uH,$S,ts,$S,OP,$S,vK,$S,xM,$S,JP,$S,Lt,$S,t6,$S,QZ,$S,s9,$S,Jg,$S,SG,$S,Tu,$S,qn,$S,ka,$S,Qt,$S,LH,$S,TO,$S,nx,$S,p9,$S,R_,$S,p6,$S,tC,$S,lJ,$S,rx,$S,M_,$S,uM,$S,xO,$S,N9,$S,we,$S,uK,$S,pt,$S,lw,$S,mu,$S,r0,$S,Cp,$S,vY,$S,OO,$S,vT,$S,kk,$S,qv,$S,ng,$S,p5,$S,tN,$S,oi,$S,wY,$S,Sm,$S,m7,$S,za,$S,zb,$S,md,$S,rS,$S,IO,$S,wq,$S,NX,$S,j8,$S,j6,$S,o1,$S,NG,$S,qJ,$S,Pq,$S,Ri,$S,J9,$S,kQ,$S,qU,$S,r2,$S,my,$S,xE,$S,Qj,$S,lH,$S,lU,$S,Ta,$S,PK,$S,LK,$S,KM,$S,Pe,$S,tL,$S,nI,$S,t5,$S,Gr,$S,q3,$S,s1,$S,L9,$S,R2,$S,Pw,$S,sd,$S,tg,$S,uf,$S,ke,$S,n7,$S,xH,$S,w1,$S,Jm,$S,kM,$S,qR,$S,R3,$S,xr,$S,Q3,$S,QV,$S,oP,$S,q0,$S,kZ,$S,Qh,$S,Mu,$S,Nd,$S,NC,$S,Pn,$S,Rp,$S,q5,$S,s3,$S,Nx,$S,mU,$S,NY,$S,QA,$S,Ld,$S,rj,$S,se,$S,u7,$S,f4,$S,vv,$S,pF,$S,mk,$S,wP,$S,sx,$S,xS,$S,IN,$S,vP,$S,Mw,$S,pu,$S,lz,$S,t$,$S,qe,$S,nK,$S,Hb,$S,Ha,$S,G9,$S,G8,$S,Hd,$S,Hc,$S,pz,$S,l3,$S,jf,$S,no,$S,k2,$S,pm,$S,uC,$S,sX,$S,qx,$S,mT,$S,on,$S,Aj,$S,Ak,$S,Ah,$S,Ai,$S,p4,$S,P1,$S,ne,$S,Ap,$S,yc,$S,Ss,$S,Sn,$S,qy,$S,ko,$S,uQ,$S,wU,$S,pq,$S,ln,$S,Qs,$S,zE,$S,KD,$S,zD,$S,me,$S,pD,$S,wZ,$S,v6,$S,Oa,$S,wo,$S,Gj,$S,Gk,$S,Gl,$S,Gm,$S,F0,$S,F1,$S,F2,$S,Gi,$S,Gn,$S,Go,$S,Cn,$S,OD,$S,Qf,$S,OX,$S,Rk,$S,zB,$S,Tc,$S,MB,$S,oZ,$S,lP,$S,nM,$S,k7,$S,kx,$S,So,$S,Ae,$S,oG,$S,y4,$S,LO,$S,St,$S,Rb,$S,ku,$S,LE,$S,Or,$S,tA,$S,t1,$S,Dy,$S,QH,$S,CN,$S,JM,$S,Nt,$S,sN,$S,r3,$S,RK,$S,pk,$S,kT,$S,sJ,$S,nL,$S,Ms,$S,OW,$S,Rx,$S,Ep,$S,Eo,$S,Eh,$S,Eg,$S,Ej,$S,Ei,$S,El,$S,Ek,$S,En,$S,Em,$S,BY,$S,BX,$S,BW,$S,BV,$S,PM,$S,B_,$S,BZ,$S,s4,$S,ri,$S,Mq,$S,TE,$S,RU,$S,Oq,$S,S6,$S,Rg,$S,vd,$S,Mn,$S,OT,$S,mA,$S,pM,$S,ur,$S,QX,$S,TN,$S,Nl,$S,Kc,$S,MJ,$S,OB,$S,MU,$S,wK,$S,OI,$S,kB,$S,gE,$S,kh,$S,n8,$S,D$,$S,vR,$S,t_,$S,Ip,$S,u3,$S,EK,$S,EL,$S,EI,$S,EJ,$S,EG,$S,PQ,$S,lM,$S,rA,$S,Rq,$S,po,$S,Lk,$S,ms,$S,n0,$S,qi,$S,xG,$S,Lj,$S,Sp,$S,ER,$S,S1,$S,QS,$S,sF,$S,nF,$S,R6,$S,PN,$S,JH,$S,wt,$S,lN,$S,oC,$S,nP,$S,sK,$S,PZ,$S,IV,$S,nW,$S,Fe,$S,TG,$S,R7,$S,OZ,$S,w0,$S,wn,$S,wl,$S,Tf,$S,tZ,$S,rG,$S,lV,$S,sj,$S,ti,$S,r8,$S,mH,$S,Iw,$S,QU,$S,l0,$S,o4,$S,QI,$S,tT,$S,LS,$S,Nb,$S,tW,$S,us,$S,K2,$S,IQ,$S,oj,$S,kS,$S,PW,$S,mf,$S,rF,$S,wz,$S,rv,$S,Q$,$S,rm,$S,ls,$S,rT,$S,qD,$S,kt,$S,M4,$S,o7,$S,oD,$S,lS,$S,L3,$S,OF,$S,PB,$S,RQ,$S,Tb,$S,mP,$S,sb,$S,O2,$S,p1,$S,m4,$S,vZ,$S,tK,$S,Mk,$S,JR,$S,q2,$S,ww,$S,wF,$S,k0,$S,r7,$S,mF,$S,O1,$S,Tj,$S,Lw,$S,oS,$S,NE,$S,tw,$S,yJ,$S,yE,$S,yF,$S,yG,$S,yH,$S,lO,$S,ni,$S,Oc,$S,qf,$S,vg,$S,Ou,$S,oa,$S,wQ,$S,M1,$S,lR,$S,oI,$S,rY,$S,sW,$S,n5,$S,jd,$S,Qm,$S,Sz,$S,pQ,$S,mI,$S,kb,$S,qo,$S,v8,$S,le,$S,kE,$S,og,$S,ly,$S,uj,$S,NQ,$S,Mj,$S,sH,$S,Lr,$S,py,$S,mD,$S,r6,$S,ow,$S,Qv,$S,Oj,$S,K4,$S,vQ,$S,zw,$S,zv,$S,zy,$S,zx,$S,zA,$S,zz,$S,zC,$S,Sh,$S,DF,$S,DE,$S,sB,$S,tl,$S,Dz,$S,Dx,$S,Dw,$S,DD,$S,DC,$S,Ih,$S,DA,$S,lr,$S,RM,$S,rl,$S,qj,$S,N4,$S,RO,$S,Jc,$S,Qy,$S,QW,$S,ta,$S,rM,$S,Me,$S,Kk,$S,Li,$S,kH,$S,qN,$S,JI,$S,oc,$S,qE,$S,ss,$S,nk,$S,Qq,$S,R9,$S,R$,$S,q7,$S,LX,$S,ul,$S,OL,$S,TC,$S,I0,$S,Ok,$S,nc,$S,so,$S,fT,$S,oN,$S,mm,$S,t0,$S,ru,$S,lG,$S,I9,$S,lb,$S,q9,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S,$S];var fA=[$T,$T,_u,$T,_v,$T,Vq,$T,Vr,$T,_w,$T,_x,$T,Xw,$T,_y,$T,_z,$T,_A,$T,VL,$T,_B,$T,_C,$T,Ux,$T,Xt,$T,Wz,$T,_D,$T,VK,$T,VI,$T,VN,$T,WA,$T,_E,$T,Vp,$T,Uz,$T,Uw,$T,Xu,$T,Xr,$T,WB,$T,fX,$T,_F,$T,_G,$T,Vo,$T,Xs,$T,_H,$T,_I,$T,_J,$T,WC,$T,_K,$T,VM,$T,VH,$T,_L,$T,Uv,$T,WF,$T,Uy,$T,Uu,$T,VJ,$T,WE,$T,_M,$T,_N,$T,Vn,$T,Vm,$T,_O,$T,_P,$T,_Q,$T,Vs,$T,Xv,$T,_R,$T,WD,$T,Xx,$T,UA,$T,$T,$T,$T,$T,$T,$T];return{_memcmp:Ya,_strlen:X1,_strcat:Yd,_free:XZ,_main:fS,_testSetjmp:X4,_strncpy:Yc,_memmove:X9,_realloc:X_,_saveSetjmp:X3,_memset:X2,_malloc:XY,_memcpy:X5,_strcasecmp:X8,_strncasecmp:X7,_tolower:X6,_strcpy:Yb,runPostSets:fR,stackAlloc:fB,stackSave:fC,stackRestore:fD,setThrew:fE,setTempRet0:fH,setTempRet1:fI,setTempRet2:fJ,setTempRet3:fK,setTempRet4:fL,setTempRet5:fM,setTempRet6:fN,setTempRet7:fO,setTempRet8:fP,setTempRet9:fQ,dynCall_iiiiiiii:__,dynCall_vif:_$,dynCall_viiiii:_0,dynCall_vi:_1,dynCall_vii:_2,dynCall_iiiiiii:_3,dynCall_ii:_4,dynCall_viiiiiiiiiii:_5,dynCall_viffff:_6,dynCall_if:_7,dynCall_iiii:_8,dynCall_viiiiif:_9,dynCall_viiiiiiii:$a,dynCall_vifff:$b,dynCall_fii:$c,dynCall_iiif:$d,dynCall_viff:$e,dynCall_iif:$f,dynCall_viiiiiii:$g,dynCall_ff:$h,dynCall_viiiiiiiii:$i,dynCall_iii:$j,dynCall_viiiiii:$k,dynCall_f:$l,dynCall_i:$m,dynCall_iiiii:$n,dynCall_viii:$o,dynCall_v:$p,dynCall_viiii:$q}})
// EMSCRIPTEN_END_ASM
({ "Math": Math, "Int8Array": Int8Array, "Int16Array": Int16Array, "Int32Array": Int32Array, "Uint8Array": Uint8Array, "Uint16Array": Uint16Array, "Uint32Array": Uint32Array, "Float32Array": Float32Array, "Float64Array": Float64Array }, { "abort": abort, "assert": assert, "asmPrintInt": asmPrintInt, "asmPrintFloat": asmPrintFloat, "min": Math_min, "invoke_iiiiiiii": invoke_iiiiiiii, "invoke_vif": invoke_vif, "invoke_viiiii": invoke_viiiii, "invoke_vi": invoke_vi, "invoke_vii": invoke_vii, "invoke_iiiiiii": invoke_iiiiiii, "invoke_ii": invoke_ii, "invoke_viiiiiiiiiii": invoke_viiiiiiiiiii, "invoke_viffff": invoke_viffff, "invoke_if": invoke_if, "invoke_iiii": invoke_iiii, "invoke_viiiiif": invoke_viiiiif, "invoke_viiiiiiii": invoke_viiiiiiii, "invoke_vifff": invoke_vifff, "invoke_fii": invoke_fii, "invoke_iiif": invoke_iiif, "invoke_viff": invoke_viff, "invoke_iif": invoke_iif, "invoke_viiiiiii": invoke_viiiiiii, "invoke_ff": invoke_ff, "invoke_viiiiiiiii": invoke_viiiiiiiii, "invoke_iii": invoke_iii, "invoke_viiiiii": invoke_viiiiii, "invoke_f": invoke_f, "invoke_i": invoke_i, "invoke_iiiii": invoke_iiiii, "invoke_viii": invoke_viii, "invoke_v": invoke_v, "invoke_viiii": invoke_viiii, "_llvm_lifetime_end": _llvm_lifetime_end, "_lseek": _lseek, "_RWebInputDestroy": _RWebInputDestroy, "_RWebAudioStop": _RWebAudioStop, "_glClearColor": _glClearColor, "_sysconf": _sysconf, "_fclose": _fclose, "_RWebAudioInit": _RWebAudioInit, "_glGetVertexAttribPointerv": _glGetVertexAttribPointerv, "_glGetRenderbufferParameteriv": _glGetRenderbufferParameteriv, "_eglDestroySurface": _eglDestroySurface, "_strtoul": _strtoul, "_strtoull": _strtoull, "_glBindTexture": _glBindTexture, "_fflush": _fflush, "_glGetUniformiv": _glGetUniformiv, "_fabsf": _fabsf, "_strtol": _strtol, "_fputc": _fputc, "_glGetString": _glGetString, "_fwrite": _fwrite, "_gluUnProject": _gluUnProject, "_send": _send, "_fputs": _fputs, "_glLineWidth": _glLineWidth, "_glUniform2fv": _glUniform2fv, "_emscripten_get_now": _emscripten_get_now, "_eglCreateContext": _eglCreateContext, "_glBindAttribLocation": _glBindAttribLocation, "_glCompileShader": _glCompileShader, "_isspace": _isspace, "_localtime": _localtime, "_glDeleteTextures": _glDeleteTextures, "_eglBindAPI": _eglBindAPI, "_glCompressedTexImage2D": _glCompressedTexImage2D, "_isalnum": _isalnum, "_glStencilFuncSeparate": _glStencilFuncSeparate, "_read": _read, "_RWebAudioBufferSize": _RWebAudioBufferSize, "_glDeleteShader": _glDeleteShader, "_RWebInputInit": _RWebInputInit, "_glClearDepthf": _glClearDepthf, "_glUniform4iv": _glUniform4iv, "_glGetTexParameteriv": _glGetTexParameteriv, "_glClearStencil": _glClearStencil, "_glLoadIdentity": _glLoadIdentity, "_glUniform1fv": _glUniform1fv, "_glIsShader": _glIsShader, "_strstr": _strstr, "_glSampleCoverage": _glSampleCoverage, "_fsync": _fsync, "_glGenTextures": _glGenTextures, "_glDepthFunc": _glDepthFunc, "_remove": _remove, "_glCompressedTexSubImage2D": _glCompressedTexSubImage2D, "_glUniform1f": _glUniform1f, "_opendir": _opendir, "_glGetTexParameterfv": _glGetTexParameterfv, "_RWebAudioWrite": _RWebAudioWrite, "_glStencilMaskSeparate": _glStencilMaskSeparate, "_glCreateShader": _glCreateShader, "_round": _round, "_glUniform1i": _glUniform1i, "_strncmp": _strncmp, "_cosf": _cosf, "_glDeleteRenderbuffers": _glDeleteRenderbuffers, "_glLinkProgram": _glLinkProgram, "_snprintf": _snprintf, "_glUniform2i": _glUniform2i, "_fgetc": _fgetc, "_glStencilFunc": _glStencilFunc, "_glShaderSource": _glShaderSource, "_readdir": _readdir, "_glVertexAttribPointer": _glVertexAttribPointer, "_glHint": _glHint, "_glBindBuffer": _glBindBuffer, "_glVertexPointer": _glVertexPointer, "_fgets": _fgets, "_close": _close, "_getgid": _getgid, "_glGetAttachedShaders": _glGetAttachedShaders, "_glBindFramebuffer": _glBindFramebuffer, "_glIsFramebuffer": _glIsFramebuffer, "_strchr": _strchr, "_glUniform4fv": _glUniform4fv, "_abort": _abort, "___setErrNo": ___setErrNo, "_glDeleteFramebuffers": _glDeleteFramebuffers, "_eglTerminate": _eglTerminate, "_glGetVertexAttribfv": _glGetVertexAttribfv, "_glIsBuffer": _glIsBuffer, "_emscripten_GetProcAddress": _emscripten_GetProcAddress, "_eglGetProcAddress": _eglGetProcAddress, "_ftell": _ftell, "_glDeleteProgram": _glDeleteProgram, "_exit": _exit, "_sprintf": _sprintf, "_glRenderbufferStorage": _glRenderbufferStorage, "_strrchr": _strrchr, "_glAttachShader": _glAttachShader, "_RWebInputPoll": _RWebInputPoll, "_glUniform3i": _glUniform3i, "_glIsProgram": _glIsProgram, "_glCheckFramebufferStatus": _glCheckFramebufferStatus, "__isLeapYear": __isLeapYear, "_gluProject": _gluProject, "_llvm_uadd_with_overflow_i32": _llvm_uadd_with_overflow_i32, "_localtime_r": _localtime_r, "_glUniform3f": _glUniform3f, "_glGetBufferParameteriv": _glGetBufferParameteriv, "_glFlush": _glFlush, "_glBlendEquationSeparate": _glBlendEquationSeparate, "_emscripten_get_canvas_size": _emscripten_get_canvas_size, "_glCopyTexImage2D": _glCopyTexImage2D, "_glDrawElements": _glDrawElements, "_glColorMask": _glColorMask, "_sinf": _sinf, "_gluLookAt": _gluLookAt, "_eglInitialize": _eglInitialize, "_recv": _recv, "__parseInt64": __parseInt64, "_glVertexAttrib1fv": _glVertexAttrib1fv, "_glUniform2iv": _glUniform2iv, "_cos": _cos, "_putchar": _putchar, "_glUniform1iv": _glUniform1iv, "_glActiveTexture": _glActiveTexture, "_glMatrixMode": _glMatrixMode, "_glBlendEquation": _glBlendEquation, "_strcmp": _strcmp, "_glVertexAttrib1f": _glVertexAttrib1f, "_RWebAudioWriteAvail": _RWebAudioWriteAvail, "_glGenerateMipmap": _glGenerateMipmap, "_memchr": _memchr, "_glDetachShader": _glDetachShader, "_glGetShaderiv": _glGetShaderiv, "__exit": __exit, "_strftime": _strftime, "_glVertexAttrib3f": _glVertexAttrib3f, "_glGenRenderbuffers": _glGenRenderbuffers, "_tzset": _tzset, "_RWebAudioSampleRate": _RWebAudioSampleRate, "_glGetShaderPrecisionFormat": _glGetShaderPrecisionFormat, "_glVertexAttrib4fv": _glVertexAttrib4fv, "_glDepthMask": _glDepthMask, "_glDisableVertexAttribArray": _glDisableVertexAttribArray, "_glBegin": _glBegin, "_toupper": _toupper, "_printf": _printf, "_glBindRenderbuffer": _glBindRenderbuffer, "_pread": _pread, "_fopen": _fopen, "_open": _open, "_glDrawArrays": _glDrawArrays, "_usleep": _usleep, "_llvm_pow_f32": _llvm_pow_f32, "__arraySum": __arraySum, "_glCopyTexSubImage2D": _glCopyTexSubImage2D, "_glDisable": _glDisable, "_puts": _puts, "_glUniform4i": _glUniform4i, "_nanosleep": _nanosleep, "_glClear": _glClear, "_qsort": _qsort, "_glUniform2f": _glUniform2f, "_eglDestroyContext": _eglDestroyContext, "_isalpha": _isalpha, "_glEnableVertexAttribArray": _glEnableVertexAttribArray, "_rmdir": _rmdir, "_glUniform3fv": _glUniform3fv, "_glStencilOp": _glStencilOp, "_strdup": _strdup, "_glDepthRange": _glDepthRange, "_glUniform4f": _glUniform4f, "_glFramebufferTexture2D": _glFramebufferTexture2D, "_glUniformMatrix2fv": _glUniformMatrix2fv, "_glGenVertexArrays": _glGenVertexArrays, "_eglMakeCurrent": _eglMakeCurrent, "_glUniformMatrix3fv": _glUniformMatrix3fv, "_glutCreateWindow": _glutCreateWindow, "_glBufferData": _glBufferData, "_glBlendColor": _glBlendColor, "_glGetUniformLocation": _glGetUniformLocation, "_glIsEnabled": _glIsEnabled, "__formatString": __formatString, "_getenv": _getenv, "_glGetError": _glGetError, "_glGetVertexAttribiv": _glGetVertexAttribiv, "_glTexParameteriv": _glTexParameteriv, "_glGetProgramiv": _glGetProgramiv, "_glVertexAttrib3fv": _glVertexAttrib3fv, "_glGetFloatv": _glGetFloatv, "_glBufferSubData": _glBufferSubData, "_glUniform3iv": _glUniform3iv, "_glReadPixels": _glReadPixels, "_glGenFramebuffers": _glGenFramebuffers, "_glFramebufferRenderbuffer": _glFramebufferRenderbuffer, "_emscripten_procAddressTable": _emscripten_procAddressTable, "_ceil": _ceil, "___errno_location": ___errno_location, "_glGetIntegerv": _glGetIntegerv, "_RWebAudioFree": _RWebAudioFree, "_llvm_lifetime_start": _llvm_lifetime_start, "_glIsRenderbuffer": _glIsRenderbuffer, "_llvm_bswap_i32": _llvm_bswap_i32, "_sbrk": _sbrk, "__parseInt": __parseInt, "_RWebAudioSetNonblockState": _RWebAudioSetNonblockState, "_glVertexAttrib2fv": _glVertexAttrib2fv, "_glGetFramebufferAttachmentParameteriv": _glGetFramebufferAttachmentParameteriv, "_glUseProgram": _glUseProgram, "_glTexImage2D": _glTexImage2D, "_glGetProgramInfoLog": _glGetProgramInfoLog, "_glTexSubImage2D": _glTexSubImage2D, "_glStencilMask": _glStencilMask, "_fread": _fread, "_glStencilOpSeparate": _glStencilOpSeparate, "_strtok_r": _strtok_r, "_glGetShaderInfoLog": _glGetShaderInfoLog, "_glIsTexture": _glIsTexture, "_eglCreateWindowSurface": _eglCreateWindowSurface, "_fprintf": _fprintf, "_glGetShaderSource": _glGetShaderSource, "_gluPerspective": _gluPerspective, "_eglChooseConfig": _eglChooseConfig, "___buildEnvironment": ___buildEnvironment, "_feof": _feof, "__addDays": __addDays, "_glScissor": _glScissor, "_glEnable": _glEnable, "_glBlendFuncSeparate": _glBlendFuncSeparate, "__reallyNegative": __reallyNegative, "_glGetActiveAttrib": _glGetActiveAttrib, "_fseek": _fseek, "_sqrt": _sqrt, "_glTexParameterfv": _glTexParameterfv, "_write": _write, "_glGenBuffers": _glGenBuffers, "_glFinish": _glFinish, "_glGetAttribLocation": _glGetAttribLocation, "_glVertexAttrib4f": _glVertexAttrib4f, "_rewind": _rewind, "_sin": _sin, "_glBlendFunc": _glBlendFunc, "_glCreateProgram": _glCreateProgram, "_realpath": _realpath, "_stat": _stat, "_longjmp": _longjmp, "_atan": _atan, "_glViewport": _glViewport, "_emscripten_set_main_loop": _emscripten_set_main_loop, "_time": _time, "_glVertexAttrib2f": _glVertexAttrib2f, "_closedir": _closedir, "_isgraph": _isgraph, "_readlink": _readlink, "_glGetUniformfv": _glGetUniformfv, "_unlink": _unlink, "_gluOrtho2D": _gluOrtho2D, "_glUniformMatrix4fv": _glUniformMatrix4fv, "_glClearDepth": _glClearDepth, "_glGetActiveUniform": _glGetActiveUniform, "_glutDestroyWindow": _glutDestroyWindow, "_pwrite": _pwrite, "_fabs": _fabs, "_glTexParameterf": _glTexParameterf, "_RWebAudioStart": _RWebAudioStart, "_glTexParameteri": _glTexParameteri, "_glFrontFace": _glFrontFace, "_glCullFace": _glCullFace, "_glDepthRangef": _glDepthRangef, "_glDeleteBuffers": _glDeleteBuffers, "_eglGetDisplay": _eglGetDisplay, "_emscripten_set_canvas_size": _emscripten_set_canvas_size, "_atoi": _atoi, "_glGetBooleanv": _glGetBooleanv, "_eglQuerySurface": _eglQuerySurface, "_glPixelStorei": _glPixelStorei, "_readdir_r": _readdir_r, "_glValidateProgram": _glValidateProgram, "_glPolygonOffset": _glPolygonOffset, "STACKTOP": STACKTOP, "STACK_MAX": STACK_MAX, "tempDoublePtr": tempDoublePtr, "ABORT": ABORT, "cttz_i8": cttz_i8, "ctlz_i8": ctlz_i8, "NaN": NaN, "Infinity": Infinity, "_stdout": _stdout, "_stderr": _stderr }, buffer);
var _memcmp = Module["_memcmp"] = asm["_memcmp"];
var _strlen = Module["_strlen"] = asm["_strlen"];
var _strcat = Module["_strcat"] = asm["_strcat"];
var _free = Module["_free"] = asm["_free"];
var _main = Module["_main"] = asm["_main"];
var _testSetjmp = Module["_testSetjmp"] = asm["_testSetjmp"];
var _strncpy = Module["_strncpy"] = asm["_strncpy"];
var _memmove = Module["_memmove"] = asm["_memmove"];
var _realloc = Module["_realloc"] = asm["_realloc"];
var _saveSetjmp = Module["_saveSetjmp"] = asm["_saveSetjmp"];
var _memset = Module["_memset"] = asm["_memset"];
var _malloc = Module["_malloc"] = asm["_malloc"];
var _memcpy = Module["_memcpy"] = asm["_memcpy"];
var _strcasecmp = Module["_strcasecmp"] = asm["_strcasecmp"];
var _strncasecmp = Module["_strncasecmp"] = asm["_strncasecmp"];
var _tolower = Module["_tolower"] = asm["_tolower"];
var _strcpy = Module["_strcpy"] = asm["_strcpy"];
var runPostSets = Module["runPostSets"] = asm["runPostSets"];
var dynCall_iiiiiiii = Module["dynCall_iiiiiiii"] = asm["dynCall_iiiiiiii"];
var dynCall_vif = Module["dynCall_vif"] = asm["dynCall_vif"];
var dynCall_viiiii = Module["dynCall_viiiii"] = asm["dynCall_viiiii"];
var dynCall_vi = Module["dynCall_vi"] = asm["dynCall_vi"];
var dynCall_vii = Module["dynCall_vii"] = asm["dynCall_vii"];
var dynCall_iiiiiii = Module["dynCall_iiiiiii"] = asm["dynCall_iiiiiii"];
var dynCall_ii = Module["dynCall_ii"] = asm["dynCall_ii"];
var dynCall_viiiiiiiiiii = Module["dynCall_viiiiiiiiiii"] = asm["dynCall_viiiiiiiiiii"];
var dynCall_viffff = Module["dynCall_viffff"] = asm["dynCall_viffff"];
var dynCall_if = Module["dynCall_if"] = asm["dynCall_if"];
var dynCall_iiii = Module["dynCall_iiii"] = asm["dynCall_iiii"];
var dynCall_viiiiif = Module["dynCall_viiiiif"] = asm["dynCall_viiiiif"];
var dynCall_viiiiiiii = Module["dynCall_viiiiiiii"] = asm["dynCall_viiiiiiii"];
var dynCall_vifff = Module["dynCall_vifff"] = asm["dynCall_vifff"];
var dynCall_fii = Module["dynCall_fii"] = asm["dynCall_fii"];
var dynCall_iiif = Module["dynCall_iiif"] = asm["dynCall_iiif"];
var dynCall_viff = Module["dynCall_viff"] = asm["dynCall_viff"];
var dynCall_iif = Module["dynCall_iif"] = asm["dynCall_iif"];
var dynCall_viiiiiii = Module["dynCall_viiiiiii"] = asm["dynCall_viiiiiii"];
var dynCall_ff = Module["dynCall_ff"] = asm["dynCall_ff"];
var dynCall_viiiiiiiii = Module["dynCall_viiiiiiiii"] = asm["dynCall_viiiiiiiii"];
var dynCall_iii = Module["dynCall_iii"] = asm["dynCall_iii"];
var dynCall_viiiiii = Module["dynCall_viiiiii"] = asm["dynCall_viiiiii"];
var dynCall_f = Module["dynCall_f"] = asm["dynCall_f"];
var dynCall_i = Module["dynCall_i"] = asm["dynCall_i"];
var dynCall_iiiii = Module["dynCall_iiiii"] = asm["dynCall_iiiii"];
var dynCall_viii = Module["dynCall_viii"] = asm["dynCall_viii"];
var dynCall_v = Module["dynCall_v"] = asm["dynCall_v"];
var dynCall_viiii = Module["dynCall_viiii"] = asm["dynCall_viiii"];
Runtime.stackAlloc = function(size) { return asm['stackAlloc'](size) };
Runtime.stackSave = function() { return asm['stackSave']() };
Runtime.stackRestore = function(top) { asm['stackRestore'](top) };
// TODO: strip out parts of this we do not need
//======= begin closure i64 code =======
// Copyright 2009 The Closure Library Authors. All Rights Reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS-IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
/**
 * @fileoverview Defines a Long class for representing a 64-bit two's-complement
 * integer value, which faithfully simulates the behavior of a Java "long". This
 * implementation is derived from LongLib in GWT.
 *
 */
var i64Math = (function() { // Emscripten wrapper
  var goog = { math: {} };
  /**
   * Constructs a 64-bit two's-complement integer, given its low and high 32-bit
   * values as *signed* integers.  See the from* functions below for more
   * convenient ways of constructing Longs.
   *
   * The internal representation of a long is the two given signed, 32-bit values.
   * We use 32-bit pieces because these are the size of integers on which
   * Javascript performs bit-operations.  For operations like addition and
   * multiplication, we split each number into 16-bit pieces, which can easily be
   * multiplied within Javascript's floating-point representation without overflow
   * or change in sign.
   *
   * In the algorithms below, we frequently reduce the negative case to the
   * positive case by negating the input(s) and then post-processing the result.
   * Note that we must ALWAYS check specially whether those values are MIN_VALUE
   * (-2^63) because -MIN_VALUE == MIN_VALUE (since 2^63 cannot be represented as
   * a positive number, it overflows back into a negative).  Not handling this
   * case would often result in infinite recursion.
   *
   * @param {number} low  The low (signed) 32 bits of the long.
   * @param {number} high  The high (signed) 32 bits of the long.
   * @constructor
   */
  goog.math.Long = function(low, high) {
    /**
     * @type {number}
     * @private
     */
    this.low_ = low | 0;  // force into 32 signed bits.
    /**
     * @type {number}
     * @private
     */
    this.high_ = high | 0;  // force into 32 signed bits.
  };
  // NOTE: Common constant values ZERO, ONE, NEG_ONE, etc. are defined below the
  // from* methods on which they depend.
  /**
   * A cache of the Long representations of small integer values.
   * @type {!Object}
   * @private
   */
  goog.math.Long.IntCache_ = {};
  /**
   * Returns a Long representing the given (32-bit) integer value.
   * @param {number} value The 32-bit integer in question.
   * @return {!goog.math.Long} The corresponding Long value.
   */
  goog.math.Long.fromInt = function(value) {
    if (-128 <= value && value < 128) {
      var cachedObj = goog.math.Long.IntCache_[value];
      if (cachedObj) {
        return cachedObj;
      }
    }
    var obj = new goog.math.Long(value | 0, value < 0 ? -1 : 0);
    if (-128 <= value && value < 128) {
      goog.math.Long.IntCache_[value] = obj;
    }
    return obj;
  };
  /**
   * Returns a Long representing the given value, provided that it is a finite
   * number.  Otherwise, zero is returned.
   * @param {number} value The number in question.
   * @return {!goog.math.Long} The corresponding Long value.
   */
  goog.math.Long.fromNumber = function(value) {
    if (isNaN(value) || !isFinite(value)) {
      return goog.math.Long.ZERO;
    } else if (value <= -goog.math.Long.TWO_PWR_63_DBL_) {
      return goog.math.Long.MIN_VALUE;
    } else if (value + 1 >= goog.math.Long.TWO_PWR_63_DBL_) {
      return goog.math.Long.MAX_VALUE;
    } else if (value < 0) {
      return goog.math.Long.fromNumber(-value).negate();
    } else {
      return new goog.math.Long(
          (value % goog.math.Long.TWO_PWR_32_DBL_) | 0,
          (value / goog.math.Long.TWO_PWR_32_DBL_) | 0);
    }
  };
  /**
   * Returns a Long representing the 64-bit integer that comes by concatenating
   * the given high and low bits.  Each is assumed to use 32 bits.
   * @param {number} lowBits The low 32-bits.
   * @param {number} highBits The high 32-bits.
   * @return {!goog.math.Long} The corresponding Long value.
   */
  goog.math.Long.fromBits = function(lowBits, highBits) {
    return new goog.math.Long(lowBits, highBits);
  };
  /**
   * Returns a Long representation of the given string, written using the given
   * radix.
   * @param {string} str The textual representation of the Long.
   * @param {number=} opt_radix The radix in which the text is written.
   * @return {!goog.math.Long} The corresponding Long value.
   */
  goog.math.Long.fromString = function(str, opt_radix) {
    if (str.length == 0) {
      throw Error('number format error: empty string');
    }
    var radix = opt_radix || 10;
    if (radix < 2 || 36 < radix) {
      throw Error('radix out of range: ' + radix);
    }
    if (str.charAt(0) == '-') {
      return goog.math.Long.fromString(str.substring(1), radix).negate();
    } else if (str.indexOf('-') >= 0) {
      throw Error('number format error: interior "-" character: ' + str);
    }
    // Do several (8) digits each time through the loop, so as to
    // minimize the calls to the very expensive emulated div.
    var radixToPower = goog.math.Long.fromNumber(Math.pow(radix, 8));
    var result = goog.math.Long.ZERO;
    for (var i = 0; i < str.length; i += 8) {
      var size = Math.min(8, str.length - i);
      var value = parseInt(str.substring(i, i + size), radix);
      if (size < 8) {
        var power = goog.math.Long.fromNumber(Math.pow(radix, size));
        result = result.multiply(power).add(goog.math.Long.fromNumber(value));
      } else {
        result = result.multiply(radixToPower);
        result = result.add(goog.math.Long.fromNumber(value));
      }
    }
    return result;
  };
  // NOTE: the compiler should inline these constant values below and then remove
  // these variables, so there should be no runtime penalty for these.
  /**
   * Number used repeated below in calculations.  This must appear before the
   * first call to any from* function below.
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_16_DBL_ = 1 << 16;
  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_24_DBL_ = 1 << 24;
  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_32_DBL_ =
      goog.math.Long.TWO_PWR_16_DBL_ * goog.math.Long.TWO_PWR_16_DBL_;
  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_31_DBL_ =
      goog.math.Long.TWO_PWR_32_DBL_ / 2;
  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_48_DBL_ =
      goog.math.Long.TWO_PWR_32_DBL_ * goog.math.Long.TWO_PWR_16_DBL_;
  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_64_DBL_ =
      goog.math.Long.TWO_PWR_32_DBL_ * goog.math.Long.TWO_PWR_32_DBL_;
  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_63_DBL_ =
      goog.math.Long.TWO_PWR_64_DBL_ / 2;
  /** @type {!goog.math.Long} */
  goog.math.Long.ZERO = goog.math.Long.fromInt(0);
  /** @type {!goog.math.Long} */
  goog.math.Long.ONE = goog.math.Long.fromInt(1);
  /** @type {!goog.math.Long} */
  goog.math.Long.NEG_ONE = goog.math.Long.fromInt(-1);
  /** @type {!goog.math.Long} */
  goog.math.Long.MAX_VALUE =
      goog.math.Long.fromBits(0xFFFFFFFF | 0, 0x7FFFFFFF | 0);
  /** @type {!goog.math.Long} */
  goog.math.Long.MIN_VALUE = goog.math.Long.fromBits(0, 0x80000000 | 0);
  /**
   * @type {!goog.math.Long}
   * @private
   */
  goog.math.Long.TWO_PWR_24_ = goog.math.Long.fromInt(1 << 24);
  /** @return {number} The value, assuming it is a 32-bit integer. */
  goog.math.Long.prototype.toInt = function() {
    return this.low_;
  };
  /** @return {number} The closest floating-point representation to this value. */
  goog.math.Long.prototype.toNumber = function() {
    return this.high_ * goog.math.Long.TWO_PWR_32_DBL_ +
           this.getLowBitsUnsigned();
  };
  /**
   * @param {number=} opt_radix The radix in which the text should be written.
   * @return {string} The textual representation of this value.
   */
  goog.math.Long.prototype.toString = function(opt_radix) {
    var radix = opt_radix || 10;
    if (radix < 2 || 36 < radix) {
      throw Error('radix out of range: ' + radix);
    }
    if (this.isZero()) {
      return '0';
    }
    if (this.isNegative()) {
      if (this.equals(goog.math.Long.MIN_VALUE)) {
        // We need to change the Long value before it can be negated, so we remove
        // the bottom-most digit in this base and then recurse to do the rest.
        var radixLong = goog.math.Long.fromNumber(radix);
        var div = this.div(radixLong);
        var rem = div.multiply(radixLong).subtract(this);
        return div.toString(radix) + rem.toInt().toString(radix);
      } else {
        return '-' + this.negate().toString(radix);
      }
    }
    // Do several (6) digits each time through the loop, so as to
    // minimize the calls to the very expensive emulated div.
    var radixToPower = goog.math.Long.fromNumber(Math.pow(radix, 6));
    var rem = this;
    var result = '';
    while (true) {
      var remDiv = rem.div(radixToPower);
      var intval = rem.subtract(remDiv.multiply(radixToPower)).toInt();
      var digits = intval.toString(radix);
      rem = remDiv;
      if (rem.isZero()) {
        return digits + result;
      } else {
        while (digits.length < 6) {
          digits = '0' + digits;
        }
        result = '' + digits + result;
      }
    }
  };
  /** @return {number} The high 32-bits as a signed value. */
  goog.math.Long.prototype.getHighBits = function() {
    return this.high_;
  };
  /** @return {number} The low 32-bits as a signed value. */
  goog.math.Long.prototype.getLowBits = function() {
    return this.low_;
  };
  /** @return {number} The low 32-bits as an unsigned value. */
  goog.math.Long.prototype.getLowBitsUnsigned = function() {
    return (this.low_ >= 0) ?
        this.low_ : goog.math.Long.TWO_PWR_32_DBL_ + this.low_;
  };
  /**
   * @return {number} Returns the number of bits needed to represent the absolute
   *     value of this Long.
   */
  goog.math.Long.prototype.getNumBitsAbs = function() {
    if (this.isNegative()) {
      if (this.equals(goog.math.Long.MIN_VALUE)) {
        return 64;
      } else {
        return this.negate().getNumBitsAbs();
      }
    } else {
      var val = this.high_ != 0 ? this.high_ : this.low_;
      for (var bit = 31; bit > 0; bit--) {
        if ((val & (1 << bit)) != 0) {
          break;
        }
      }
      return this.high_ != 0 ? bit + 33 : bit + 1;
    }
  };
  /** @return {boolean} Whether this value is zero. */
  goog.math.Long.prototype.isZero = function() {
    return this.high_ == 0 && this.low_ == 0;
  };
  /** @return {boolean} Whether this value is negative. */
  goog.math.Long.prototype.isNegative = function() {
    return this.high_ < 0;
  };
  /** @return {boolean} Whether this value is odd. */
  goog.math.Long.prototype.isOdd = function() {
    return (this.low_ & 1) == 1;
  };
  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long equals the other.
   */
  goog.math.Long.prototype.equals = function(other) {
    return (this.high_ == other.high_) && (this.low_ == other.low_);
  };
  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long does not equal the other.
   */
  goog.math.Long.prototype.notEquals = function(other) {
    return (this.high_ != other.high_) || (this.low_ != other.low_);
  };
  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long is less than the other.
   */
  goog.math.Long.prototype.lessThan = function(other) {
    return this.compare(other) < 0;
  };
  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long is less than or equal to the other.
   */
  goog.math.Long.prototype.lessThanOrEqual = function(other) {
    return this.compare(other) <= 0;
  };
  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long is greater than the other.
   */
  goog.math.Long.prototype.greaterThan = function(other) {
    return this.compare(other) > 0;
  };
  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long is greater than or equal to the other.
   */
  goog.math.Long.prototype.greaterThanOrEqual = function(other) {
    return this.compare(other) >= 0;
  };
  /**
   * Compares this Long with the given one.
   * @param {goog.math.Long} other Long to compare against.
   * @return {number} 0 if they are the same, 1 if the this is greater, and -1
   *     if the given one is greater.
   */
  goog.math.Long.prototype.compare = function(other) {
    if (this.equals(other)) {
      return 0;
    }
    var thisNeg = this.isNegative();
    var otherNeg = other.isNegative();
    if (thisNeg && !otherNeg) {
      return -1;
    }
    if (!thisNeg && otherNeg) {
      return 1;
    }
    // at this point, the signs are the same, so subtraction will not overflow
    if (this.subtract(other).isNegative()) {
      return -1;
    } else {
      return 1;
    }
  };
  /** @return {!goog.math.Long} The negation of this value. */
  goog.math.Long.prototype.negate = function() {
    if (this.equals(goog.math.Long.MIN_VALUE)) {
      return goog.math.Long.MIN_VALUE;
    } else {
      return this.not().add(goog.math.Long.ONE);
    }
  };
  /**
   * Returns the sum of this and the given Long.
   * @param {goog.math.Long} other Long to add to this one.
   * @return {!goog.math.Long} The sum of this and the given Long.
   */
  goog.math.Long.prototype.add = function(other) {
    // Divide each number into 4 chunks of 16 bits, and then sum the chunks.
    var a48 = this.high_ >>> 16;
    var a32 = this.high_ & 0xFFFF;
    var a16 = this.low_ >>> 16;
    var a00 = this.low_ & 0xFFFF;
    var b48 = other.high_ >>> 16;
    var b32 = other.high_ & 0xFFFF;
    var b16 = other.low_ >>> 16;
    var b00 = other.low_ & 0xFFFF;
    var c48 = 0, c32 = 0, c16 = 0, c00 = 0;
    c00 += a00 + b00;
    c16 += c00 >>> 16;
    c00 &= 0xFFFF;
    c16 += a16 + b16;
    c32 += c16 >>> 16;
    c16 &= 0xFFFF;
    c32 += a32 + b32;
    c48 += c32 >>> 16;
    c32 &= 0xFFFF;
    c48 += a48 + b48;
    c48 &= 0xFFFF;
    return goog.math.Long.fromBits((c16 << 16) | c00, (c48 << 16) | c32);
  };
  /**
   * Returns the difference of this and the given Long.
   * @param {goog.math.Long} other Long to subtract from this.
   * @return {!goog.math.Long} The difference of this and the given Long.
   */
  goog.math.Long.prototype.subtract = function(other) {
    return this.add(other.negate());
  };
  /**
   * Returns the product of this and the given long.
   * @param {goog.math.Long} other Long to multiply with this.
   * @return {!goog.math.Long} The product of this and the other.
   */
  goog.math.Long.prototype.multiply = function(other) {
    if (this.isZero()) {
      return goog.math.Long.ZERO;
    } else if (other.isZero()) {
      return goog.math.Long.ZERO;
    }
    if (this.equals(goog.math.Long.MIN_VALUE)) {
      return other.isOdd() ? goog.math.Long.MIN_VALUE : goog.math.Long.ZERO;
    } else if (other.equals(goog.math.Long.MIN_VALUE)) {
      return this.isOdd() ? goog.math.Long.MIN_VALUE : goog.math.Long.ZERO;
    }
    if (this.isNegative()) {
      if (other.isNegative()) {
        return this.negate().multiply(other.negate());
      } else {
        return this.negate().multiply(other).negate();
      }
    } else if (other.isNegative()) {
      return this.multiply(other.negate()).negate();
    }
    // If both longs are small, use float multiplication
    if (this.lessThan(goog.math.Long.TWO_PWR_24_) &&
        other.lessThan(goog.math.Long.TWO_PWR_24_)) {
      return goog.math.Long.fromNumber(this.toNumber() * other.toNumber());
    }
    // Divide each long into 4 chunks of 16 bits, and then add up 4x4 products.
    // We can skip products that would overflow.
    var a48 = this.high_ >>> 16;
    var a32 = this.high_ & 0xFFFF;
    var a16 = this.low_ >>> 16;
    var a00 = this.low_ & 0xFFFF;
    var b48 = other.high_ >>> 16;
    var b32 = other.high_ & 0xFFFF;
    var b16 = other.low_ >>> 16;
    var b00 = other.low_ & 0xFFFF;
    var c48 = 0, c32 = 0, c16 = 0, c00 = 0;
    c00 += a00 * b00;
    c16 += c00 >>> 16;
    c00 &= 0xFFFF;
    c16 += a16 * b00;
    c32 += c16 >>> 16;
    c16 &= 0xFFFF;
    c16 += a00 * b16;
    c32 += c16 >>> 16;
    c16 &= 0xFFFF;
    c32 += a32 * b00;
    c48 += c32 >>> 16;
    c32 &= 0xFFFF;
    c32 += a16 * b16;
    c48 += c32 >>> 16;
    c32 &= 0xFFFF;
    c32 += a00 * b32;
    c48 += c32 >>> 16;
    c32 &= 0xFFFF;
    c48 += a48 * b00 + a32 * b16 + a16 * b32 + a00 * b48;
    c48 &= 0xFFFF;
    return goog.math.Long.fromBits((c16 << 16) | c00, (c48 << 16) | c32);
  };
  /**
   * Returns this Long divided by the given one.
   * @param {goog.math.Long} other Long by which to divide.
   * @return {!goog.math.Long} This Long divided by the given one.
   */
  goog.math.Long.prototype.div = function(other) {
    if (other.isZero()) {
      throw Error('division by zero');
    } else if (this.isZero()) {
      return goog.math.Long.ZERO;
    }
    if (this.equals(goog.math.Long.MIN_VALUE)) {
      if (other.equals(goog.math.Long.ONE) ||
          other.equals(goog.math.Long.NEG_ONE)) {
        return goog.math.Long.MIN_VALUE;  // recall that -MIN_VALUE == MIN_VALUE
      } else if (other.equals(goog.math.Long.MIN_VALUE)) {
        return goog.math.Long.ONE;
      } else {
        // At this point, we have |other| >= 2, so |this/other| < |MIN_VALUE|.
        var halfThis = this.shiftRight(1);
        var approx = halfThis.div(other).shiftLeft(1);
        if (approx.equals(goog.math.Long.ZERO)) {
          return other.isNegative() ? goog.math.Long.ONE : goog.math.Long.NEG_ONE;
        } else {
          var rem = this.subtract(other.multiply(approx));
          var result = approx.add(rem.div(other));
          return result;
        }
      }
    } else if (other.equals(goog.math.Long.MIN_VALUE)) {
      return goog.math.Long.ZERO;
    }
    if (this.isNegative()) {
      if (other.isNegative()) {
        return this.negate().div(other.negate());
      } else {
        return this.negate().div(other).negate();
      }
    } else if (other.isNegative()) {
      return this.div(other.negate()).negate();
    }
    // Repeat the following until the remainder is less than other:  find a
    // floating-point that approximates remainder / other *from below*, add this
    // into the result, and subtract it from the remainder.  It is critical that
    // the approximate value is less than or equal to the real value so that the
    // remainder never becomes negative.
    var res = goog.math.Long.ZERO;
    var rem = this;
    while (rem.greaterThanOrEqual(other)) {
      // Approximate the result of division. This may be a little greater or
      // smaller than the actual value.
      var approx = Math.max(1, Math.floor(rem.toNumber() / other.toNumber()));
      // We will tweak the approximate result by changing it in the 48-th digit or
      // the smallest non-fractional digit, whichever is larger.
      var log2 = Math.ceil(Math.log(approx) / Math.LN2);
      var delta = (log2 <= 48) ? 1 : Math.pow(2, log2 - 48);
      // Decrease the approximation until it is smaller than the remainder.  Note
      // that if it is too large, the product overflows and is negative.
      var approxRes = goog.math.Long.fromNumber(approx);
      var approxRem = approxRes.multiply(other);
      while (approxRem.isNegative() || approxRem.greaterThan(rem)) {
        approx -= delta;
        approxRes = goog.math.Long.fromNumber(approx);
        approxRem = approxRes.multiply(other);
      }
      // We know the answer can't be zero... and actually, zero would cause
      // infinite recursion since we would make no progress.
      if (approxRes.isZero()) {
        approxRes = goog.math.Long.ONE;
      }
      res = res.add(approxRes);
      rem = rem.subtract(approxRem);
    }
    return res;
  };
  /**
   * Returns this Long modulo the given one.
   * @param {goog.math.Long} other Long by which to mod.
   * @return {!goog.math.Long} This Long modulo the given one.
   */
  goog.math.Long.prototype.modulo = function(other) {
    return this.subtract(this.div(other).multiply(other));
  };
  /** @return {!goog.math.Long} The bitwise-NOT of this value. */
  goog.math.Long.prototype.not = function() {
    return goog.math.Long.fromBits(~this.low_, ~this.high_);
  };
  /**
   * Returns the bitwise-AND of this Long and the given one.
   * @param {goog.math.Long} other The Long with which to AND.
   * @return {!goog.math.Long} The bitwise-AND of this and the other.
   */
  goog.math.Long.prototype.and = function(other) {
    return goog.math.Long.fromBits(this.low_ & other.low_,
                                   this.high_ & other.high_);
  };
  /**
   * Returns the bitwise-OR of this Long and the given one.
   * @param {goog.math.Long} other The Long with which to OR.
   * @return {!goog.math.Long} The bitwise-OR of this and the other.
   */
  goog.math.Long.prototype.or = function(other) {
    return goog.math.Long.fromBits(this.low_ | other.low_,
                                   this.high_ | other.high_);
  };
  /**
   * Returns the bitwise-XOR of this Long and the given one.
   * @param {goog.math.Long} other The Long with which to XOR.
   * @return {!goog.math.Long} The bitwise-XOR of this and the other.
   */
  goog.math.Long.prototype.xor = function(other) {
    return goog.math.Long.fromBits(this.low_ ^ other.low_,
                                   this.high_ ^ other.high_);
  };
  /**
   * Returns this Long with bits shifted to the left by the given amount.
   * @param {number} numBits The number of bits by which to shift.
   * @return {!goog.math.Long} This shifted to the left by the given amount.
   */
  goog.math.Long.prototype.shiftLeft = function(numBits) {
    numBits &= 63;
    if (numBits == 0) {
      return this;
    } else {
      var low = this.low_;
      if (numBits < 32) {
        var high = this.high_;
        return goog.math.Long.fromBits(
            low << numBits,
            (high << numBits) | (low >>> (32 - numBits)));
      } else {
        return goog.math.Long.fromBits(0, low << (numBits - 32));
      }
    }
  };
  /**
   * Returns this Long with bits shifted to the right by the given amount.
   * @param {number} numBits The number of bits by which to shift.
   * @return {!goog.math.Long} This shifted to the right by the given amount.
   */
  goog.math.Long.prototype.shiftRight = function(numBits) {
    numBits &= 63;
    if (numBits == 0) {
      return this;
    } else {
      var high = this.high_;
      if (numBits < 32) {
        var low = this.low_;
        return goog.math.Long.fromBits(
            (low >>> numBits) | (high << (32 - numBits)),
            high >> numBits);
      } else {
        return goog.math.Long.fromBits(
            high >> (numBits - 32),
            high >= 0 ? 0 : -1);
      }
    }
  };
  /**
   * Returns this Long with bits shifted to the right by the given amount, with
   * the new top bits matching the current sign bit.
   * @param {number} numBits The number of bits by which to shift.
   * @return {!goog.math.Long} This shifted to the right by the given amount, with
   *     zeros placed into the new leading bits.
   */
  goog.math.Long.prototype.shiftRightUnsigned = function(numBits) {
    numBits &= 63;
    if (numBits == 0) {
      return this;
    } else {
      var high = this.high_;
      if (numBits < 32) {
        var low = this.low_;
        return goog.math.Long.fromBits(
            (low >>> numBits) | (high << (32 - numBits)),
            high >>> numBits);
      } else if (numBits == 32) {
        return goog.math.Long.fromBits(high, 0);
      } else {
        return goog.math.Long.fromBits(high >>> (numBits - 32), 0);
      }
    }
  };
  //======= begin jsbn =======
  var navigator = { appName: 'Modern Browser' }; // polyfill a little
  // Copyright (c) 2005  Tom Wu
  // All Rights Reserved.
  // http://www-cs-students.stanford.edu/~tjw/jsbn/
  /*
   * Copyright (c) 2003-2005  Tom Wu
   * All Rights Reserved.
   *
   * Permission is hereby granted, free of charge, to any person obtaining
   * a copy of this software and associated documentation files (the
   * "Software"), to deal in the Software without restriction, including
   * without limitation the rights to use, copy, modify, merge, publish,
   * distribute, sublicense, and/or sell copies of the Software, and to
   * permit persons to whom the Software is furnished to do so, subject to
   * the following conditions:
   *
   * The above copyright notice and this permission notice shall be
   * included in all copies or substantial portions of the Software.
   *
   * THE SOFTWARE IS PROVIDED "AS-IS" AND WITHOUT WARRANTY OF ANY KIND, 
   * EXPRESS, IMPLIED OR OTHERWISE, INCLUDING WITHOUT LIMITATION, ANY 
   * WARRANTY OF MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.  
   *
   * IN NO EVENT SHALL TOM WU BE LIABLE FOR ANY SPECIAL, INCIDENTAL,
   * INDIRECT OR CONSEQUENTIAL DAMAGES OF ANY KIND, OR ANY DAMAGES WHATSOEVER
   * RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER OR NOT ADVISED OF
   * THE POSSIBILITY OF DAMAGE, AND ON ANY THEORY OF LIABILITY, ARISING OUT
   * OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
   *
   * In addition, the following condition applies:
   *
   * All redistributions must retain an intact copy of this copyright notice
   * and disclaimer.
   */
  // Basic JavaScript BN library - subset useful for RSA encryption.
  // Bits per digit
  var dbits;
  // JavaScript engine analysis
  var canary = 0xdeadbeefcafe;
  var j_lm = ((canary&0xffffff)==0xefcafe);
  // (public) Constructor
  function BigInteger(a,b,c) {
    if(a != null)
      if("number" == typeof a) this.fromNumber(a,b,c);
      else if(b == null && "string" != typeof a) this.fromString(a,256);
      else this.fromString(a,b);
  }
  // return new, unset BigInteger
  function nbi() { return new BigInteger(null); }
  // am: Compute w_j += (x*this_i), propagate carries,
  // c is initial carry, returns final carry.
  // c < 3*dvalue, x < 2*dvalue, this_i < dvalue
  // We need to select the fastest one that works in this environment.
  // am1: use a single mult and divide to get the high bits,
  // max digit bits should be 26 because
  // max internal value = 2*dvalue^2-2*dvalue (< 2^53)
  function am1(i,x,w,j,c,n) {
    while(--n >= 0) {
      var v = x*this[i++]+w[j]+c;
      c = Math.floor(v/0x4000000);
      w[j++] = v&0x3ffffff;
    }
    return c;
  }
  // am2 avoids a big mult-and-extract completely.
  // Max digit bits should be <= 30 because we do bitwise ops
  // on values up to 2*hdvalue^2-hdvalue-1 (< 2^31)
  function am2(i,x,w,j,c,n) {
    var xl = x&0x7fff, xh = x>>15;
    while(--n >= 0) {
      var l = this[i]&0x7fff;
      var h = this[i++]>>15;
      var m = xh*l+h*xl;
      l = xl*l+((m&0x7fff)<<15)+w[j]+(c&0x3fffffff);
      c = (l>>>30)+(m>>>15)+xh*h+(c>>>30);
      w[j++] = l&0x3fffffff;
    }
    return c;
  }
  // Alternately, set max digit bits to 28 since some
  // browsers slow down when dealing with 32-bit numbers.
  function am3(i,x,w,j,c,n) {
    var xl = x&0x3fff, xh = x>>14;
    while(--n >= 0) {
      var l = this[i]&0x3fff;
      var h = this[i++]>>14;
      var m = xh*l+h*xl;
      l = xl*l+((m&0x3fff)<<14)+w[j]+c;
      c = (l>>28)+(m>>14)+xh*h;
      w[j++] = l&0xfffffff;
    }
    return c;
  }
  if(j_lm && (navigator.appName == "Microsoft Internet Explorer")) {
    BigInteger.prototype.am = am2;
    dbits = 30;
  }
  else if(j_lm && (navigator.appName != "Netscape")) {
    BigInteger.prototype.am = am1;
    dbits = 26;
  }
  else { // Mozilla/Netscape seems to prefer am3
    BigInteger.prototype.am = am3;
    dbits = 28;
  }
  BigInteger.prototype.DB = dbits;
  BigInteger.prototype.DM = ((1<<dbits)-1);
  BigInteger.prototype.DV = (1<<dbits);
  var BI_FP = 52;
  BigInteger.prototype.FV = Math.pow(2,BI_FP);
  BigInteger.prototype.F1 = BI_FP-dbits;
  BigInteger.prototype.F2 = 2*dbits-BI_FP;
  // Digit conversions
  var BI_RM = "0123456789abcdefghijklmnopqrstuvwxyz";
  var BI_RC = new Array();
  var rr,vv;
  rr = "0".charCodeAt(0);
  for(vv = 0; vv <= 9; ++vv) BI_RC[rr++] = vv;
  rr = "a".charCodeAt(0);
  for(vv = 10; vv < 36; ++vv) BI_RC[rr++] = vv;
  rr = "A".charCodeAt(0);
  for(vv = 10; vv < 36; ++vv) BI_RC[rr++] = vv;
  function int2char(n) { return BI_RM.charAt(n); }
  function intAt(s,i) {
    var c = BI_RC[s.charCodeAt(i)];
    return (c==null)?-1:c;
  }
  // (protected) copy this to r
  function bnpCopyTo(r) {
    for(var i = this.t-1; i >= 0; --i) r[i] = this[i];
    r.t = this.t;
    r.s = this.s;
  }
  // (protected) set from integer value x, -DV <= x < DV
  function bnpFromInt(x) {
    this.t = 1;
    this.s = (x<0)?-1:0;
    if(x > 0) this[0] = x;
    else if(x < -1) this[0] = x+DV;
    else this.t = 0;
  }
  // return bigint initialized to value
  function nbv(i) { var r = nbi(); r.fromInt(i); return r; }
  // (protected) set from string and radix
  function bnpFromString(s,b) {
    var k;
    if(b == 16) k = 4;
    else if(b == 8) k = 3;
    else if(b == 256) k = 8; // byte array
    else if(b == 2) k = 1;
    else if(b == 32) k = 5;
    else if(b == 4) k = 2;
    else { this.fromRadix(s,b); return; }
    this.t = 0;
    this.s = 0;
    var i = s.length, mi = false, sh = 0;
    while(--i >= 0) {
      var x = (k==8)?s[i]&0xff:intAt(s,i);
      if(x < 0) {
        if(s.charAt(i) == "-") mi = true;
        continue;
      }
      mi = false;
      if(sh == 0)
        this[this.t++] = x;
      else if(sh+k > this.DB) {
        this[this.t-1] |= (x&((1<<(this.DB-sh))-1))<<sh;
        this[this.t++] = (x>>(this.DB-sh));
      }
      else
        this[this.t-1] |= x<<sh;
      sh += k;
      if(sh >= this.DB) sh -= this.DB;
    }
    if(k == 8 && (s[0]&0x80) != 0) {
      this.s = -1;
      if(sh > 0) this[this.t-1] |= ((1<<(this.DB-sh))-1)<<sh;
    }
    this.clamp();
    if(mi) BigInteger.ZERO.subTo(this,this);
  }
  // (protected) clamp off excess high words
  function bnpClamp() {
    var c = this.s&this.DM;
    while(this.t > 0 && this[this.t-1] == c) --this.t;
  }
  // (public) return string representation in given radix
  function bnToString(b) {
    if(this.s < 0) return "-"+this.negate().toString(b);
    var k;
    if(b == 16) k = 4;
    else if(b == 8) k = 3;
    else if(b == 2) k = 1;
    else if(b == 32) k = 5;
    else if(b == 4) k = 2;
    else return this.toRadix(b);
    var km = (1<<k)-1, d, m = false, r = "", i = this.t;
    var p = this.DB-(i*this.DB)%k;
    if(i-- > 0) {
      if(p < this.DB && (d = this[i]>>p) > 0) { m = true; r = int2char(d); }
      while(i >= 0) {
        if(p < k) {
          d = (this[i]&((1<<p)-1))<<(k-p);
          d |= this[--i]>>(p+=this.DB-k);
        }
        else {
          d = (this[i]>>(p-=k))&km;
          if(p <= 0) { p += this.DB; --i; }
        }
        if(d > 0) m = true;
        if(m) r += int2char(d);
      }
    }
    return m?r:"0";
  }
  // (public) -this
  function bnNegate() { var r = nbi(); BigInteger.ZERO.subTo(this,r); return r; }
  // (public) |this|
  function bnAbs() { return (this.s<0)?this.negate():this; }
  // (public) return + if this > a, - if this < a, 0 if equal
  function bnCompareTo(a) {
    var r = this.s-a.s;
    if(r != 0) return r;
    var i = this.t;
    r = i-a.t;
    if(r != 0) return (this.s<0)?-r:r;
    while(--i >= 0) if((r=this[i]-a[i]) != 0) return r;
    return 0;
  }
  // returns bit length of the integer x
  function nbits(x) {
    var r = 1, t;
    if((t=x>>>16) != 0) { x = t; r += 16; }
    if((t=x>>8) != 0) { x = t; r += 8; }
    if((t=x>>4) != 0) { x = t; r += 4; }
    if((t=x>>2) != 0) { x = t; r += 2; }
    if((t=x>>1) != 0) { x = t; r += 1; }
    return r;
  }
  // (public) return the number of bits in "this"
  function bnBitLength() {
    if(this.t <= 0) return 0;
    return this.DB*(this.t-1)+nbits(this[this.t-1]^(this.s&this.DM));
  }
  // (protected) r = this << n*DB
  function bnpDLShiftTo(n,r) {
    var i;
    for(i = this.t-1; i >= 0; --i) r[i+n] = this[i];
    for(i = n-1; i >= 0; --i) r[i] = 0;
    r.t = this.t+n;
    r.s = this.s;
  }
  // (protected) r = this >> n*DB
  function bnpDRShiftTo(n,r) {
    for(var i = n; i < this.t; ++i) r[i-n] = this[i];
    r.t = Math.max(this.t-n,0);
    r.s = this.s;
  }
  // (protected) r = this << n
  function bnpLShiftTo(n,r) {
    var bs = n%this.DB;
    var cbs = this.DB-bs;
    var bm = (1<<cbs)-1;
    var ds = Math.floor(n/this.DB), c = (this.s<<bs)&this.DM, i;
    for(i = this.t-1; i >= 0; --i) {
      r[i+ds+1] = (this[i]>>cbs)|c;
      c = (this[i]&bm)<<bs;
    }
    for(i = ds-1; i >= 0; --i) r[i] = 0;
    r[ds] = c;
    r.t = this.t+ds+1;
    r.s = this.s;
    r.clamp();
  }
  // (protected) r = this >> n
  function bnpRShiftTo(n,r) {
    r.s = this.s;
    var ds = Math.floor(n/this.DB);
    if(ds >= this.t) { r.t = 0; return; }
    var bs = n%this.DB;
    var cbs = this.DB-bs;
    var bm = (1<<bs)-1;
    r[0] = this[ds]>>bs;
    for(var i = ds+1; i < this.t; ++i) {
      r[i-ds-1] |= (this[i]&bm)<<cbs;
      r[i-ds] = this[i]>>bs;
    }
    if(bs > 0) r[this.t-ds-1] |= (this.s&bm)<<cbs;
    r.t = this.t-ds;
    r.clamp();
  }
  // (protected) r = this - a
  function bnpSubTo(a,r) {
    var i = 0, c = 0, m = Math.min(a.t,this.t);
    while(i < m) {
      c += this[i]-a[i];
      r[i++] = c&this.DM;
      c >>= this.DB;
    }
    if(a.t < this.t) {
      c -= a.s;
      while(i < this.t) {
        c += this[i];
        r[i++] = c&this.DM;
        c >>= this.DB;
      }
      c += this.s;
    }
    else {
      c += this.s;
      while(i < a.t) {
        c -= a[i];
        r[i++] = c&this.DM;
        c >>= this.DB;
      }
      c -= a.s;
    }
    r.s = (c<0)?-1:0;
    if(c < -1) r[i++] = this.DV+c;
    else if(c > 0) r[i++] = c;
    r.t = i;
    r.clamp();
  }
  // (protected) r = this * a, r != this,a (HAC 14.12)
  // "this" should be the larger one if appropriate.
  function bnpMultiplyTo(a,r) {
    var x = this.abs(), y = a.abs();
    var i = x.t;
    r.t = i+y.t;
    while(--i >= 0) r[i] = 0;
    for(i = 0; i < y.t; ++i) r[i+x.t] = x.am(0,y[i],r,i,0,x.t);
    r.s = 0;
    r.clamp();
    if(this.s != a.s) BigInteger.ZERO.subTo(r,r);
  }
  // (protected) r = this^2, r != this (HAC 14.16)
  function bnpSquareTo(r) {
    var x = this.abs();
    var i = r.t = 2*x.t;
    while(--i >= 0) r[i] = 0;
    for(i = 0; i < x.t-1; ++i) {
      var c = x.am(i,x[i],r,2*i,0,1);
      if((r[i+x.t]+=x.am(i+1,2*x[i],r,2*i+1,c,x.t-i-1)) >= x.DV) {
        r[i+x.t] -= x.DV;
        r[i+x.t+1] = 1;
      }
    }
    if(r.t > 0) r[r.t-1] += x.am(i,x[i],r,2*i,0,1);
    r.s = 0;
    r.clamp();
  }
  // (protected) divide this by m, quotient and remainder to q, r (HAC 14.20)
  // r != q, this != m.  q or r may be null.
  function bnpDivRemTo(m,q,r) {
    var pm = m.abs();
    if(pm.t <= 0) return;
    var pt = this.abs();
    if(pt.t < pm.t) {
      if(q != null) q.fromInt(0);
      if(r != null) this.copyTo(r);
      return;
    }
    if(r == null) r = nbi();
    var y = nbi(), ts = this.s, ms = m.s;
    var nsh = this.DB-nbits(pm[pm.t-1]);	// normalize modulus
    if(nsh > 0) { pm.lShiftTo(nsh,y); pt.lShiftTo(nsh,r); }
    else { pm.copyTo(y); pt.copyTo(r); }
    var ys = y.t;
    var y0 = y[ys-1];
    if(y0 == 0) return;
    var yt = y0*(1<<this.F1)+((ys>1)?y[ys-2]>>this.F2:0);
    var d1 = this.FV/yt, d2 = (1<<this.F1)/yt, e = 1<<this.F2;
    var i = r.t, j = i-ys, t = (q==null)?nbi():q;
    y.dlShiftTo(j,t);
    if(r.compareTo(t) >= 0) {
      r[r.t++] = 1;
      r.subTo(t,r);
    }
    BigInteger.ONE.dlShiftTo(ys,t);
    t.subTo(y,y);	// "negative" y so we can replace sub with am later
    while(y.t < ys) y[y.t++] = 0;
    while(--j >= 0) {
      // Estimate quotient digit
      var qd = (r[--i]==y0)?this.DM:Math.floor(r[i]*d1+(r[i-1]+e)*d2);
      if((r[i]+=y.am(0,qd,r,j,0,ys)) < qd) {	// Try it out
        y.dlShiftTo(j,t);
        r.subTo(t,r);
        while(r[i] < --qd) r.subTo(t,r);
      }
    }
    if(q != null) {
      r.drShiftTo(ys,q);
      if(ts != ms) BigInteger.ZERO.subTo(q,q);
    }
    r.t = ys;
    r.clamp();
    if(nsh > 0) r.rShiftTo(nsh,r);	// Denormalize remainder
    if(ts < 0) BigInteger.ZERO.subTo(r,r);
  }
  // (public) this mod a
  function bnMod(a) {
    var r = nbi();
    this.abs().divRemTo(a,null,r);
    if(this.s < 0 && r.compareTo(BigInteger.ZERO) > 0) a.subTo(r,r);
    return r;
  }
  // Modular reduction using "classic" algorithm
  function Classic(m) { this.m = m; }
  function cConvert(x) {
    if(x.s < 0 || x.compareTo(this.m) >= 0) return x.mod(this.m);
    else return x;
  }
  function cRevert(x) { return x; }
  function cReduce(x) { x.divRemTo(this.m,null,x); }
  function cMulTo(x,y,r) { x.multiplyTo(y,r); this.reduce(r); }
  function cSqrTo(x,r) { x.squareTo(r); this.reduce(r); }
  Classic.prototype.convert = cConvert;
  Classic.prototype.revert = cRevert;
  Classic.prototype.reduce = cReduce;
  Classic.prototype.mulTo = cMulTo;
  Classic.prototype.sqrTo = cSqrTo;
  // (protected) return "-1/this % 2^DB"; useful for Mont. reduction
  // justification:
  //         xy == 1 (mod m)
  //         xy =  1+km
  //   xy(2-xy) = (1+km)(1-km)
  // x[y(2-xy)] = 1-k^2m^2
  // x[y(2-xy)] == 1 (mod m^2)
  // if y is 1/x mod m, then y(2-xy) is 1/x mod m^2
  // should reduce x and y(2-xy) by m^2 at each step to keep size bounded.
  // JS multiply "overflows" differently from C/C++, so care is needed here.
  function bnpInvDigit() {
    if(this.t < 1) return 0;
    var x = this[0];
    if((x&1) == 0) return 0;
    var y = x&3;		// y == 1/x mod 2^2
    y = (y*(2-(x&0xf)*y))&0xf;	// y == 1/x mod 2^4
    y = (y*(2-(x&0xff)*y))&0xff;	// y == 1/x mod 2^8
    y = (y*(2-(((x&0xffff)*y)&0xffff)))&0xffff;	// y == 1/x mod 2^16
    // last step - calculate inverse mod DV directly;
    // assumes 16 < DB <= 32 and assumes ability to handle 48-bit ints
    y = (y*(2-x*y%this.DV))%this.DV;		// y == 1/x mod 2^dbits
    // we really want the negative inverse, and -DV < y < DV
    return (y>0)?this.DV-y:-y;
  }
  // Montgomery reduction
  function Montgomery(m) {
    this.m = m;
    this.mp = m.invDigit();
    this.mpl = this.mp&0x7fff;
    this.mph = this.mp>>15;
    this.um = (1<<(m.DB-15))-1;
    this.mt2 = 2*m.t;
  }
  // xR mod m
  function montConvert(x) {
    var r = nbi();
    x.abs().dlShiftTo(this.m.t,r);
    r.divRemTo(this.m,null,r);
    if(x.s < 0 && r.compareTo(BigInteger.ZERO) > 0) this.m.subTo(r,r);
    return r;
  }
  // x/R mod m
  function montRevert(x) {
    var r = nbi();
    x.copyTo(r);
    this.reduce(r);
    return r;
  }
  // x = x/R mod m (HAC 14.32)
  function montReduce(x) {
    while(x.t <= this.mt2)	// pad x so am has enough room later
      x[x.t++] = 0;
    for(var i = 0; i < this.m.t; ++i) {
      // faster way of calculating u0 = x[i]*mp mod DV
      var j = x[i]&0x7fff;
      var u0 = (j*this.mpl+(((j*this.mph+(x[i]>>15)*this.mpl)&this.um)<<15))&x.DM;
      // use am to combine the multiply-shift-add into one call
      j = i+this.m.t;
      x[j] += this.m.am(0,u0,x,i,0,this.m.t);
      // propagate carry
      while(x[j] >= x.DV) { x[j] -= x.DV; x[++j]++; }
    }
    x.clamp();
    x.drShiftTo(this.m.t,x);
    if(x.compareTo(this.m) >= 0) x.subTo(this.m,x);
  }
  // r = "x^2/R mod m"; x != r
  function montSqrTo(x,r) { x.squareTo(r); this.reduce(r); }
  // r = "xy/R mod m"; x,y != r
  function montMulTo(x,y,r) { x.multiplyTo(y,r); this.reduce(r); }
  Montgomery.prototype.convert = montConvert;
  Montgomery.prototype.revert = montRevert;
  Montgomery.prototype.reduce = montReduce;
  Montgomery.prototype.mulTo = montMulTo;
  Montgomery.prototype.sqrTo = montSqrTo;
  // (protected) true iff this is even
  function bnpIsEven() { return ((this.t>0)?(this[0]&1):this.s) == 0; }
  // (protected) this^e, e < 2^32, doing sqr and mul with "r" (HAC 14.79)
  function bnpExp(e,z) {
    if(e > 0xffffffff || e < 1) return BigInteger.ONE;
    var r = nbi(), r2 = nbi(), g = z.convert(this), i = nbits(e)-1;
    g.copyTo(r);
    while(--i >= 0) {
      z.sqrTo(r,r2);
      if((e&(1<<i)) > 0) z.mulTo(r2,g,r);
      else { var t = r; r = r2; r2 = t; }
    }
    return z.revert(r);
  }
  // (public) this^e % m, 0 <= e < 2^32
  function bnModPowInt(e,m) {
    var z;
    if(e < 256 || m.isEven()) z = new Classic(m); else z = new Montgomery(m);
    return this.exp(e,z);
  }
  // protected
  BigInteger.prototype.copyTo = bnpCopyTo;
  BigInteger.prototype.fromInt = bnpFromInt;
  BigInteger.prototype.fromString = bnpFromString;
  BigInteger.prototype.clamp = bnpClamp;
  BigInteger.prototype.dlShiftTo = bnpDLShiftTo;
  BigInteger.prototype.drShiftTo = bnpDRShiftTo;
  BigInteger.prototype.lShiftTo = bnpLShiftTo;
  BigInteger.prototype.rShiftTo = bnpRShiftTo;
  BigInteger.prototype.subTo = bnpSubTo;
  BigInteger.prototype.multiplyTo = bnpMultiplyTo;
  BigInteger.prototype.squareTo = bnpSquareTo;
  BigInteger.prototype.divRemTo = bnpDivRemTo;
  BigInteger.prototype.invDigit = bnpInvDigit;
  BigInteger.prototype.isEven = bnpIsEven;
  BigInteger.prototype.exp = bnpExp;
  // public
  BigInteger.prototype.toString = bnToString;
  BigInteger.prototype.negate = bnNegate;
  BigInteger.prototype.abs = bnAbs;
  BigInteger.prototype.compareTo = bnCompareTo;
  BigInteger.prototype.bitLength = bnBitLength;
  BigInteger.prototype.mod = bnMod;
  BigInteger.prototype.modPowInt = bnModPowInt;
  // "constants"
  BigInteger.ZERO = nbv(0);
  BigInteger.ONE = nbv(1);
  // jsbn2 stuff
  // (protected) convert from radix string
  function bnpFromRadix(s,b) {
    this.fromInt(0);
    if(b == null) b = 10;
    var cs = this.chunkSize(b);
    var d = Math.pow(b,cs), mi = false, j = 0, w = 0;
    for(var i = 0; i < s.length; ++i) {
      var x = intAt(s,i);
      if(x < 0) {
        if(s.charAt(i) == "-" && this.signum() == 0) mi = true;
        continue;
      }
      w = b*w+x;
      if(++j >= cs) {
        this.dMultiply(d);
        this.dAddOffset(w,0);
        j = 0;
        w = 0;
      }
    }
    if(j > 0) {
      this.dMultiply(Math.pow(b,j));
      this.dAddOffset(w,0);
    }
    if(mi) BigInteger.ZERO.subTo(this,this);
  }
  // (protected) return x s.t. r^x < DV
  function bnpChunkSize(r) { return Math.floor(Math.LN2*this.DB/Math.log(r)); }
  // (public) 0 if this == 0, 1 if this > 0
  function bnSigNum() {
    if(this.s < 0) return -1;
    else if(this.t <= 0 || (this.t == 1 && this[0] <= 0)) return 0;
    else return 1;
  }
  // (protected) this *= n, this >= 0, 1 < n < DV
  function bnpDMultiply(n) {
    this[this.t] = this.am(0,n-1,this,0,0,this.t);
    ++this.t;
    this.clamp();
  }
  // (protected) this += n << w words, this >= 0
  function bnpDAddOffset(n,w) {
    if(n == 0) return;
    while(this.t <= w) this[this.t++] = 0;
    this[w] += n;
    while(this[w] >= this.DV) {
      this[w] -= this.DV;
      if(++w >= this.t) this[this.t++] = 0;
      ++this[w];
    }
  }
  // (protected) convert to radix string
  function bnpToRadix(b) {
    if(b == null) b = 10;
    if(this.signum() == 0 || b < 2 || b > 36) return "0";
    var cs = this.chunkSize(b);
    var a = Math.pow(b,cs);
    var d = nbv(a), y = nbi(), z = nbi(), r = "";
    this.divRemTo(d,y,z);
    while(y.signum() > 0) {
      r = (a+z.intValue()).toString(b).substr(1) + r;
      y.divRemTo(d,y,z);
    }
    return z.intValue().toString(b) + r;
  }
  // (public) return value as integer
  function bnIntValue() {
    if(this.s < 0) {
      if(this.t == 1) return this[0]-this.DV;
      else if(this.t == 0) return -1;
    }
    else if(this.t == 1) return this[0];
    else if(this.t == 0) return 0;
    // assumes 16 < DB < 32
    return ((this[1]&((1<<(32-this.DB))-1))<<this.DB)|this[0];
  }
  // (protected) r = this + a
  function bnpAddTo(a,r) {
    var i = 0, c = 0, m = Math.min(a.t,this.t);
    while(i < m) {
      c += this[i]+a[i];
      r[i++] = c&this.DM;
      c >>= this.DB;
    }
    if(a.t < this.t) {
      c += a.s;
      while(i < this.t) {
        c += this[i];
        r[i++] = c&this.DM;
        c >>= this.DB;
      }
      c += this.s;
    }
    else {
      c += this.s;
      while(i < a.t) {
        c += a[i];
        r[i++] = c&this.DM;
        c >>= this.DB;
      }
      c += a.s;
    }
    r.s = (c<0)?-1:0;
    if(c > 0) r[i++] = c;
    else if(c < -1) r[i++] = this.DV+c;
    r.t = i;
    r.clamp();
  }
  BigInteger.prototype.fromRadix = bnpFromRadix;
  BigInteger.prototype.chunkSize = bnpChunkSize;
  BigInteger.prototype.signum = bnSigNum;
  BigInteger.prototype.dMultiply = bnpDMultiply;
  BigInteger.prototype.dAddOffset = bnpDAddOffset;
  BigInteger.prototype.toRadix = bnpToRadix;
  BigInteger.prototype.intValue = bnIntValue;
  BigInteger.prototype.addTo = bnpAddTo;
  //======= end jsbn =======
  // Emscripten wrapper
  var Wrapper = {
    abs: function(l, h) {
      var x = new goog.math.Long(l, h);
      var ret;
      if (x.isNegative()) {
        ret = x.negate();
      } else {
        ret = x;
      }
      HEAP32[tempDoublePtr>>2] = ret.low_;
      HEAP32[tempDoublePtr+4>>2] = ret.high_;
    },
    ensureTemps: function() {
      if (Wrapper.ensuredTemps) return;
      Wrapper.ensuredTemps = true;
      Wrapper.two32 = new BigInteger();
      Wrapper.two32.fromString('4294967296', 10);
      Wrapper.two64 = new BigInteger();
      Wrapper.two64.fromString('18446744073709551616', 10);
      Wrapper.temp1 = new BigInteger();
      Wrapper.temp2 = new BigInteger();
    },
    lh2bignum: function(l, h) {
      var a = new BigInteger();
      a.fromString(h.toString(), 10);
      var b = new BigInteger();
      a.multiplyTo(Wrapper.two32, b);
      var c = new BigInteger();
      c.fromString(l.toString(), 10);
      var d = new BigInteger();
      c.addTo(b, d);
      return d;
    },
    stringify: function(l, h, unsigned) {
      var ret = new goog.math.Long(l, h).toString();
      if (unsigned && ret[0] == '-') {
        // unsign slowly using jsbn bignums
        Wrapper.ensureTemps();
        var bignum = new BigInteger();
        bignum.fromString(ret, 10);
        ret = new BigInteger();
        Wrapper.two64.addTo(bignum, ret);
        ret = ret.toString(10);
      }
      return ret;
    },
    fromString: function(str, base, min, max, unsigned) {
      Wrapper.ensureTemps();
      var bignum = new BigInteger();
      bignum.fromString(str, base);
      var bigmin = new BigInteger();
      bigmin.fromString(min, 10);
      var bigmax = new BigInteger();
      bigmax.fromString(max, 10);
      if (unsigned && bignum.compareTo(BigInteger.ZERO) < 0) {
        var temp = new BigInteger();
        bignum.addTo(Wrapper.two64, temp);
        bignum = temp;
      }
      var error = false;
      if (bignum.compareTo(bigmin) < 0) {
        bignum = bigmin;
        error = true;
      } else if (bignum.compareTo(bigmax) > 0) {
        bignum = bigmax;
        error = true;
      }
      var ret = goog.math.Long.fromString(bignum.toString()); // min-max checks should have clamped this to a range goog.math.Long can handle well
      HEAP32[tempDoublePtr>>2] = ret.low_;
      HEAP32[tempDoublePtr+4>>2] = ret.high_;
      if (error) throw 'range error';
    }
  };
  return Wrapper;
})();
//======= end closure i64 code =======
// === Auto-generated postamble setup entry stuff ===
function ExitStatus(status) {
  this.name = "ExitStatus";
  this.message = "Program terminated with exit(" + status + ")";
  this.status = status;
};
ExitStatus.prototype = new Error();
ExitStatus.prototype.constructor = ExitStatus;
var initialStackTop;
var preloadStartTime = null;
Module['callMain'] = Module.callMain = function callMain(args) {
  assert(runDependencies == 0, 'cannot call main when async dependencies remain! (listen on __ATMAIN__)');
  assert(__ATPRERUN__.length == 0, 'cannot call main when preRun functions remain to be called');
  args = args || [];
  if (ENVIRONMENT_IS_WEB && preloadStartTime !== null) {
    Module.printErr('preload time: ' + (Date.now() - preloadStartTime) + ' ms');
  }
  ensureInitRuntime();
  var argc = args.length+1;
  function pad() {
    for (var i = 0; i < 4-1; i++) {
      argv.push(0);
    }
  }
  var argv = [allocate(intArrayFromString("/bin/this.program"), 'i8', ALLOC_NORMAL) ];
  pad();
  for (var i = 0; i < argc-1; i = i + 1) {
    argv.push(allocate(intArrayFromString(args[i]), 'i8', ALLOC_NORMAL));
    pad();
  }
  argv.push(0);
  argv = allocate(argv, 'i32', ALLOC_NORMAL);
  initialStackTop = STACKTOP;
  try {
    var ret = Module['_main'](argc, argv, 0);
    // if we're not running an evented main loop, it's time to exit
    if (!Module['noExitRuntime']) {
      exit(ret);
    }
  }
  catch(e) {
    if (e instanceof ExitStatus) {
      // exit() throws this once it's done to make sure execution
      // has been stopped completely
      return;
    } else if (e == 'SimulateInfiniteLoop') {
      // running an evented main loop, don't immediately exit
      Module['noExitRuntime'] = true;
      return;
    } else {
      throw e;
    }
  }
}
function run(args) {
  args = args || Module['arguments'];
  if (preloadStartTime === null) preloadStartTime = Date.now();
  if (runDependencies > 0) {
    Module.printErr('run() called, but dependencies remain, so not running');
    return;
  }
  preRun();
  if (runDependencies > 0) {
    // a preRun added a dependency, run will be called later
    return;
  }
  function doRun() {
    ensureInitRuntime();
    preMain();
    calledRun = true;
    if (Module['_main'] && shouldRunNow) {
      Module['callMain'](args);
    }
    postRun();
  }
  if (Module['setStatus']) {
    Module['setStatus']('Running...');
    setTimeout(function() {
      setTimeout(function() {
        Module['setStatus']('');
      }, 1);
      if (!ABORT) doRun();
    }, 1);
  } else {
    doRun();
  }
}
Module['run'] = Module.run = run;
function exit(status) {
  ABORT = true;
  EXITSTATUS = status;
  STACKTOP = initialStackTop;
  // exit the runtime
  exitRuntime();
  // throw an exception to halt the current execution
  throw new ExitStatus(status);
}
Module['exit'] = Module.exit = exit;
function abort(text) {
  if (text) {
    Module.print(text);
    Module.printErr(text);
  }
  ABORT = true;
  EXITSTATUS = 1;
  throw 'abort() at ' + (new Error().stack);
}
Module['abort'] = Module.abort = abort;
// {{PRE_RUN_ADDITIONS}}
if (Module['preInit']) {
  if (typeof Module['preInit'] == 'function') Module['preInit'] = [Module['preInit']];
  while (Module['preInit'].length > 0) {
    Module['preInit'].pop()();
  }
}
// shouldRunNow refers to calling main(), not run().
var shouldRunNow = true;
if (Module['noInitialRun']) {
  shouldRunNow = false;
}
run();
// {{POST_RUN_ADDITIONS}}
// {{MODULE_ADDITIONS}}
